(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  10166176,     228401]*)
(*NotebookOutlinePosition[  10211989,     229843]*)
(*  CellTagsIndexPosition[  10211867,     229836]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference\nSultan Qaboos University, Muscat Oman\n26 January 2004"
}], "Text",
  CellMargins->{{0, 0}, {-2, 0}},
  TextAlignment->Center,
  FontSize->16,
  FontColor->GrayLevel[1],
  Background->GrayLevel[0]],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5\[Ellipsis]and Beyond"
}], "Title"],

Cell["\<\
Paul Wellin
Manager, Wolfram Education Group
Wolfram Research\
\>", "Author"],

Cell[TextData[{
  "\nThis talk will give a brief survey of the technical developments present \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5 including dense and sparse linear algebra, linear programming, \
optimization, differential equations, and a host of connection technologies \
that enable ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to communicate with a vast collection of other programs. (This talk is a \
variant of one given by Roger Germundsson at the Developer\[CloseCurlyQuote]s \
Conference 2003.)"
}], "Text"],

Cell[CellGroupData[{

Cell["Initializations", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True],

Cell["\<\
Set the directory to be $PresentationDirectory/Data where we have data files \
and where we can write things. \
\>", "MathCaption",
  InitializationCell->True],

Cell[BoxData[
    \(\($PresentationDirectory\  = 
        ToFileName[{$UserBaseDirectory, "\<Applications\>", "\<GulfConference\
\>"}];\)\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetDirectory[\ 
        ToFileName[$PresentationDirectory, \ "\<Data\>"]\ ];\)\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True],

Cell["\<\
Temporary version of MPS importer, before we have it part of the layout. \
\>", "MathCaption",
  InitializationCell->True],

Cell[BoxData[
    \( (*\ << MPSData . m\ *) \)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \( (*\ GetMPS[\ file_String\ ]\  := \ 
        Import[\ file, \ "\<MPSData\>"\ ]\ @\ toLPData[]\ *) \)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell["Temporary bug fixes ... ", "MathCaption",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Unprotect[\ VectorQ, \ MatrixQ, \ 
        TensorQ\ ];\)\), "\[IndentingNewLine]", 
    \(\(VectorQ[\ s_SparseArray\ ]\  := \ 
        TensorRank[s]\  === \ 1;\)\), "\[IndentingNewLine]", 
    \(\(MatrixQ[\ s_SparseArray\ ]\  := \ 
        TensorRank[s]\  === \ 2;\)\), "\[IndentingNewLine]", 
    \(\(TensorQ[\ s_SparseArray\ ]\  := \ True;\)\), "\[IndentingNewLine]", 
    \(\(Protect[\ VectorQ, \ MatrixQ, \ TensorQ\ ];\)\)}], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[\ General::spell1];\)\)], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True],

Cell[BoxData[
    \( (*\[IndentingNewLine]SparseArrayQ[\ s_SparseArray\ ]\  := \ 
        True; \[IndentingNewLine]SparseArrayQ[\ _\ ]\  := \ 
        False;\[IndentingNewLine]*) \)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(matrixPlot[\ 
          m_?MatrixQ\ ]\  := \ \[IndentingNewLine]ListDensityPlot[\ 
          Reverse\ @\ m, \ \ ColorFunctionScaling \[Rule] False, 
          ColorFunction \[Rule] \((If[# \[Equal] 0, GrayLevel[1], 
                  GrayLevel[0]] &)\), \ Mesh \[Rule] False];\)\)], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True],

Cell["Parallel Computing Toolkit Initialization", "SubsubsectionIcon",
  InitializationCell->True],

Cell["This loads Parallel Computing Toolkit", "MathCaption",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Parallel`\)], "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True],

Cell[BoxData[
    \("Parallel Computing Toolkit, Version 2. \[Alpha]"\)], "Print",
  CellLabel->"From In[15]:="],

Cell[BoxData[
    \("Created by Roman E. Maeder"\)], "Print",
  CellLabel->"From In[15]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(M50\  = \ 
      LaunchSlave["\<localhost\>", \ \[IndentingNewLine]"\<\"C:\\Program \
Files\\Wolfram Research\\Mathematica\\5.0\\MathKernel\" -mathlink\>"\ ]\)], \
"Input",
  CellLabel->"In[16]:=",
  InitializationCell->True],

Cell[BoxData[
    \("slave"\_1["localhost"]\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(M42\  = \ 
      LaunchSlave["\<localhost\>", \ \[IndentingNewLine]"\<\"C:\\Program \
Files\\Wolfram Research\\Mathematica\\4.2\\MathKernel\" -mathlink\>"\ ]\)], \
"Input",
  CellLabel->"In[17]:=",
  InitializationCell->True],

Cell[BoxData[
    \("slave"\_2["localhost"]\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RemoteEvaluate[\ $Version, \ {M42, \ M50}\ ]\)], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True],

Cell[BoxData[
    \({"4.2 for Microsoft Windows (August 23, 2002)", 
      "5.0 for Microsoft Windows (November 18, 2003)"}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[BoxData[
    \(\(R\  = \ RemoteEvaluate;\)\)], "Input",
  CellLabel->"In[19]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\  // \ R\)], "Input",
  CellLabel->"In[20]:=",
  InitializationCell->True],

Cell[BoxData[
    \({"5.0 for Microsoft Windows (November 18, 2003)", 
      "4.2 for Microsoft Windows (August 23, 2002)"}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
Need to do some setup for 4.2 in order to compare performance.\
\>", "MathCaption",
  InitializationCell->True],

Cell[BoxData[
    \(\(RemoteEvaluate[\ 
        SetAttributes[\ AbsoluteTiming, \ HoldAll\ ], \ {M42}];\)\)], "Input",\

  CellLabel->"In[21]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RemoteEvaluate[\ \(AbsoluteTiming[\ 
              expr_\ ]\  := \[IndentingNewLine]Module[\ {t\  = \ 
                  AbsoluteTime[], \ e}, \[IndentingNewLine]e\  = \ 
                expr; \[IndentingNewLine]{AbsoluteTime[] - t, \ 
                e}\[IndentingNewLine]];\), \ {M42}];\)\)], "Input",
  CellLabel->"In[22]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Outline", "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematica",
  FontSlant->"Italic"]], "Subsection"],

Cell["The system for technical computation and communication.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Applications", "Subsection"],

Cell[TextData[{
  "Extentions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in specific domains or with specific interfaces. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Courses", "Subsection"],

Cell[TextData[{
  "Training on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and related products. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enterprise Products", "Subsection"],

Cell[TextData[{
  "Products for groups of people. \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " + Application + License."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Retail Products", "Subsection"],

Cell[TextData[{
  "Lower cost products for individuals\n\nCustom ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " + Application + License."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematica",
  FontSlant->"Italic"]], "Section"],

Cell[TextData[{
  StyleBox["\[Bullet] Mathematica",
    FontSlant->"Italic"],
  " 4.2 \[Dash] Web Technologies Release (2002)"
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \[Dash] Advanced Algorithms Release (2003)"
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 6.0 \[Dash] Advanced User Interface Release (2004)"
}], "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Applications", "Section"],

Cell[TextData[{
  "Extentions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in specific domains or with specific interfaces. "
}], "Text"],

Cell[CellGroupData[{

Cell["Wolfram Applications", "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Digital Image Processing 1.1"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Neural Networks 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Control Systems Professional 2.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Advanced Numerical Methods 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "NKS Explorer Mathematica Kit 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Experimental Data Analyst 1.1"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Fuzzy Logic 2.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] see complete list at ",
    FontSlant->"Italic"],
  ButtonBox["store.wolfram.com/catalog/apps/",
    ButtonData:>{
      URL[ "http://store.wolfram.com/catalog/apps/"], None},
    ButtonStyle->"Hyperlink"]
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Third Party Applications", "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Analog Insydes 2.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] Mathematica",
    FontSlant->"Italic"],
  " Link for LabView 2.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "machine learning framework 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Derivatives Expert III "
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Global Optimization 4.2"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "MathOptimizer 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "UnRisk Standard 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "UnRisk Pricing Engine 1.7"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Operations Research 3.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Geometrica02"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "RiskQ 4.2"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "SchematicSolver 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "MathCode C++ 2.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "MathCode Fortran 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "MathCode Java 1.0"
}], "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {0, Inherited}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Courses", "Section"],

Cell[TextData[{
  "Training on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and related products. "
}], "Text"],

Cell[CellGroupData[{

Cell["Why Certified Training?", "Subsection"],

Cell["From the user/client perspective:", "Text"],

Cell["\<\
support beginners \[LongDash] overcome startup hurdle\
\>", "BulletText"],

Cell[TextData[{
  "help overcome perception that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a large, difficult program to master"
}], "BulletText"],

Cell["\<\
expand usage from stock computation to an organization-wide tool \[LongDash] \
the \[OpenCurlyDoubleQuote]development hurdle\[CloseCurlyDoubleQuote]\
\>", "BulletText"],

Cell["\<\
a way to meet peers across industry and academia\
\>", "BulletText"],

Cell[TextData[{
  "increase in capability ",
  StyleBox["and",
    FontSlant->"Italic"],
  " productivity as standardization on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " grows within organizations"
}], "BulletText"],

Cell["\<\
something to put on your resum\[EAcute]\
\>", "BulletText"],

Cell["the company is paying for it", "BulletText"],

Cell["\<\
expected/required service for professional software\
\>", "BulletText"],

Cell["needed when bringing new people online", "BulletText"],

Cell["\<\


From the sales perspective:\
\>", "Text"],

Cell["\<\
expectation by companies when purchasing professional software\
\>", "BulletText"],

Cell["\<\
high quality source of leads for further development\
\>", "BulletText"],

Cell["\<\
obtain deeper penetration into large companies (50-60% of managers allocate \
funds for training of their employees)\
\>", "BulletText"],

Cell["\<\
indirect revenue source: integrated package as a sales tool; clients are \
coming to expect training as a bundled item in their software purchase\
\>", "BulletText"],

Cell["direct revenue source", "BulletText"],

Cell["\<\
grow revenues through expanded sales offerings (\[Euro]25.2 billion/year \
spent globally on training in 2000, expected to grow to \[Euro]41 billion by \
2004)\
\>", "BulletText"],

Cell[TextData[{
  "synergistic with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " related products: ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", Network ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", web",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", Applications, etc."
}], "BulletText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Courses", "Subsection"],

Cell["Current Wolfram Education course offerings:", "Text"],

Cell[TextData[{
  "M100 An Introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (1 day)"
}], "BulletText"],

Cell[TextData[{
  "M101 A First Course in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (2 day)"
}], "BulletText"],

Cell[TextData[{
  "M110 Working with Data Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (1 day)"
}], "BulletText"],

Cell[TextData[{
  "M220 Programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (2 day)"
}], "BulletText"],

Cell["\<\
M245 Parallel Computation (1 day)\
\>", "BulletText"],

Cell["\<\
M310 Digital Image Processing (2 day)\
\>", "BulletText"],

Cell["M330 Neural Networks (2 day)", "BulletText"],

Cell["\<\
M360 Pricing and Financial Derivatives with UnRisk (1 day)\
\>", "BulletText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delivery Methods", "Subsection"],

Cell["Wolfram Education Staff or Certified Trainer", "Text"],

Cell["Onsite ", "BulletText"],

Cell["Center Based ", "BulletText"],

Cell["Online", "BulletText"],

Cell["DVD (Q3-04)", "BulletText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Countries", "Subsection"],

Cell["\<\
In several countries Certified Training Providers (CTP) organize, market and \
sell the training events.\
\>", "Text"],

Cell["Australia", "BulletText"],

Cell["Austria", "BulletText"],

Cell["Canada", "BulletText"],

Cell["Denmark", "BulletText"],

Cell["Finland", "BulletText"],

Cell["Germany", "BulletText"],

Cell["Ireland", "BulletText"],

Cell["Norway", "BulletText"],

Cell["Sweden", "BulletText"],

Cell["Switzerland", "BulletText"],

Cell["United Kingdom", "BulletText"],

Cell["United States", "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Enterprise Products", "Section"],

Cell[TextData[{
  "Products for groups of people. \n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " + Application + License."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Network ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for workgroups. Economic way to deploy ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for groups. "
}], "BulletText"],

Cell[TextData[{
  "Network ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 (2Q-02)"
}], "BulletText"],

Cell[TextData[{
  "Network ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 (03)"
}], "BulletText"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"web", 
          StyleBox[
            AdjustmentBox["Mathematica",
              BoxMargins->{{-0.175, 0}, {0, 0}}],
            FontSlant->"Italic"]}], TextForm]]],
  " "
}], "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the web. Effective way to deploy ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " with web interfaces."
}], "BulletText"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"web", 
          StyleBox[
            AdjustmentBox["Mathematica",
              BoxMargins->{{-0.175, 0}, {0, 0}}],
            FontSlant->"Italic"]}], TextForm]]],
  " 2.0 (2Q-03)"
}], "BulletText"],

Cell[TextData[{
  "examples: ",
  ButtonBox["eFunda",
    ButtonData:>{
      URL[ "http://www.efunda.com/math/taylor_series/taylor_series.cfm"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Analytic Cycling",
    ButtonData:>{
      URL[ "http://www.analyticcycling.com/ForcesPower_Page.html"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Mobile communication",
    ButtonData:>{
      URL[ 
      "http://www.wolfram.com/products/webmathematica/examples/wireless.html"]\
, None},
    ButtonStyle->"Hyperlink"]
}], "BulletText"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "grid",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the grid. Economic way to deploy ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for grid computing."
}], "BulletText"],

Cell[TextData[{
  StyleBox[ButtonBox["gridMathematica 1.1",
    ButtonData:>{
      URL[ "http://www.wolfram.com/products/gridmathematica/whatis.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  " (3Q-03)"
}], "BulletText"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Retail Products", "Section"],

Cell[TextData[{
  "Lower cost products for individuals. \nCustom ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " + Application + License."
}], "Text"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["Mathematica for Students",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[StyleBox["\[Bullet] Mathematica Teachers Edition",
  FontSlant->"Italic"]], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["CalculationCenter",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["The Mathematical Explorer",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet]",
    FontSlant->"Italic"],
  StyleBox[" A New Kind of Science Explorer",
    FontSlant->"Italic"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  StyleBox["Calculus WIZ",
    FontSlant->"Italic"]
}], "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0 \[Dash] Advanced Algorithms Release"
}], "Section"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Scope"
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Speed"
}], "Subsection"],

Cell[TextData[{
  StyleBox["\[Bullet] ",
    FontSlant->"Italic"],
  "Scalability"
}], "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Dense Numerical Linear Algebra", "Section"],

Cell["\<\
Key for most other numerical analysis functionality. \
\>", "BulletText"],

Cell["\<\
Top of class performance on modern microprocessors. \
\>", "BulletText"],

Cell[TextData[{
  "Filling out the feature set, ",
  StyleBox["e.g.,",
    FontSlant->"Italic"],
  " matrix rank, norm, generalized eigenvalue, generalized Schur \
decomposition and generalized singular value decomposition, etc. "
}], "BulletText"],

Cell[TextData[{
  "Competitive Situation: On par or better than Matlab or Fortran libraries \
(",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", NAG)."
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  "These commands use ",
  StyleBox["Parallel Computing Toolkit",
    FontSlant->"Italic"],
  " in order to perform the same operation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 and 5.0"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version\  // R\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({"5.0 for Microsoft Windows (November 18, 2003)", 
      "4.2 for Microsoft Windows (August 23, 2002)"}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
This is probably the most important basic operation for linear algebra. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"R", "[", " ", 
      RowBox[{\(A\  = \ Table[\ Random[], \ {10\^3}, \ {10\^3}]\), ";", " ", 
        RowBox[{"Timing", "[", 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox[\(A\  . \ A\),
              FontColor->RGBColor[1, 0, 0]], ";"}], " ", "]"}]}], " ", 
      "]"}]], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{1.662`\ Second, Null}, {6.259`\ Second, Null}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["This is essentially the inverse of the last operation. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"R", "[", " ", 
      RowBox[{\(A\  = \ Table[\ Random[], \ {10\^3}, \ {10\^3}]\), 
        ";", \(b\  = \ Table[\ Random[], \ {10\^3}]\), ";", "  ", 
        RowBox[{"Timing", "[", " ", 
          RowBox[{
            StyleBox[\(LinearSolve[A, \ b]\),
              FontColor->RGBColor[1, 0, 0]], ";"}], " ", "]"}]}], " ", 
      "]"}]], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({{0.7109999999999999`\ Second, Null}, {4.617`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["This is another example of greater speedup. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"R", "[", " ", 
      RowBox[{\(A\  = \ Table[\ Random[], \ {10\^3}, \ {10\^3}]\), ";", " ", 
        RowBox[{"Timing", "[", 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox[\(Inverse[A]\),
              FontColor->RGBColor[1, 0, 0]], ";"}], " ", "]"}]}], " ", 
      "]"}]], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{1.983`\ Second, Null}, {16.614`\ Second, Null}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Dot Product Windows (Pentium 4, 2.4MHz)", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68061 
%%ImageSize: 850 578.522 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497631 0.473821 0.371571 0.473821 [
[ 0 0 0 0 ]
[ 1 .68061 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0787334 0.971452 0.664409 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000463897 0.0147151 0.000165043 [
[.02381 -0.0125 -6.4375 -18 ]
[.02381 -0.0125 6.4375 0 ]
[.25576 -0.0125 -15.3125 -18 ]
[.25576 -0.0125 15.3125 0 ]
[.48771 -0.0125 -19.75 -18 ]
[.48771 -0.0125 19.75 0 ]
[.71966 -0.0125 -19.75 -18 ]
[.71966 -0.0125 19.75 0 ]
[.9516 -0.0125 -19.75 -18 ]
[.9516 -0.0125 19.75 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -55.625 -36 ]
[.5 -0.0125 55.625 -18 ]
[-0.0125 .01472 -12.875 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .09724 -30.625 -9 ]
[-0.0125 .09724 0 9 ]
[-0.0125 .17976 -39.5 -9 ]
[-0.0125 .17976 0 9 ]
[-0.0125 .26228 -39.5 -9 ]
[-0.0125 .26228 0 9 ]
[-0.0125 .3448 -39.5 -9 ]
[-0.0125 .3448 0 9 ]
[-0.0125 .42732 -39.5 -9 ]
[-0.0125 .42732 0 9 ]
[-0.0125 .50984 -39.5 -9 ]
[-0.0125 .50984 0 9 ]
[-0.0125 .59237 -39.5 -9 ]
[-0.0125 .59237 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -110 -9 ]
[-0.01875 .30902 -39.5 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.25576 0 m
.25576 .61803 L
s
.48771 0 m
.48771 .61803 L
s
.71966 0 m
.71966 .61803 L
s
.9516 0 m
.9516 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .09724 m
1 .09724 L
s
0 .17976 m
1 .17976 L
s
0 .26228 m
1 .26228 L
s
0 .3448 m
1 .3448 L
s
0 .42732 m
1 .42732 L
s
0 .50984 m
1 .50984 L
s
0 .59237 m
1 .59237 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.4375 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25576 0 m
.25576 .00625 L
s
gsave
.25576 -0.0125 -76.3125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.48771 0 m
.48771 .00625 L
s
gsave
.48771 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.71966 0 m
.71966 .00625 L
s
gsave
.71966 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.9516 0 m
.9516 .00625 L
s
gsave
.9516 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.125 Mabswid
.0702 0 m
.0702 .00375 L
s
.11659 0 m
.11659 .00375 L
s
.16298 0 m
.16298 .00375 L
s
.20937 0 m
.20937 .00375 L
s
.30215 0 m
.30215 .00375 L
s
.34854 0 m
.34854 .00375 L
s
.39493 0 m
.39493 .00375 L
s
.44132 0 m
.44132 .00375 L
s
.5341 0 m
.5341 .00375 L
s
.58049 0 m
.58049 .00375 L
s
.62688 0 m
.62688 .00375 L
s
.67327 0 m
.67327 .00375 L
s
.76605 0 m
.76605 .00375 L
s
.81243 0 m
.81243 .00375 L
s
.85882 0 m
.85882 .00375 L
s
.90521 0 m
.90521 .00375 L
s
.99799 0 m
.99799 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -116.625 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vector) show
117.062 17.000 moveto
(Length) show
170.250 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -73.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09724 m
.00625 .09724 L
s
gsave
-0.0125 .09724 -91.625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .17976 m
.00625 .17976 L
s
gsave
-0.0125 .17976 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
0 .26228 m
.00625 .26228 L
s
gsave
-0.0125 .26228 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
0 .3448 m
.00625 .3448 L
s
gsave
-0.0125 .3448 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
0 .42732 m
.00625 .42732 L
s
gsave
-0.0125 .42732 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2500) show
1.000 setlinewidth
grestore
0 .50984 m
.00625 .50984 L
s
gsave
-0.0125 .50984 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
0 .59237 m
.00625 .59237 L
s
gsave
-0.0125 .59237 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03122 m
.00375 .03122 L
s
0 .04772 m
.00375 .04772 L
s
0 .06423 m
.00375 .06423 L
s
0 .08073 m
.00375 .08073 L
s
0 .11374 m
.00375 .11374 L
s
0 .13025 m
.00375 .13025 L
s
0 .14675 m
.00375 .14675 L
s
0 .16325 m
.00375 .16325 L
s
0 .19626 m
.00375 .19626 L
s
0 .21277 m
.00375 .21277 L
s
0 .22927 m
.00375 .22927 L
s
0 .24578 m
.00375 .24578 L
s
0 .27878 m
.00375 .27878 L
s
0 .29529 m
.00375 .29529 L
s
0 .31179 m
.00375 .31179 L
s
0 .3283 m
.00375 .3283 L
s
0 .36131 m
.00375 .36131 L
s
0 .37781 m
.00375 .37781 L
s
0 .39431 m
.00375 .39431 L
s
0 .41082 m
.00375 .41082 L
s
0 .44383 m
.00375 .44383 L
s
0 .46033 m
.00375 .46033 L
s
0 .47684 m
.00375 .47684 L
s
0 .49334 m
.00375 .49334 L
s
0 .52635 m
.00375 .52635 L
s
0 .54285 m
.00375 .54285 L
s
0 .55936 m
.00375 .55936 L
s
0 .57586 m
.00375 .57586 L
s
0 .60887 m
.00375 .60887 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -171 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MFLOPS) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25576 .61178 m
.25576 .61803 L
s
.48771 .61178 m
.48771 .61803 L
s
.71966 .61178 m
.71966 .61803 L
s
.9516 .61178 m
.9516 .61803 L
s
.125 Mabswid
.0702 .61428 m
.0702 .61803 L
s
.11659 .61428 m
.11659 .61803 L
s
.16298 .61428 m
.16298 .61803 L
s
.20937 .61428 m
.20937 .61803 L
s
.30215 .61428 m
.30215 .61803 L
s
.34854 .61428 m
.34854 .61803 L
s
.39493 .61428 m
.39493 .61803 L
s
.44132 .61428 m
.44132 .61803 L
s
.5341 .61428 m
.5341 .61803 L
s
.58049 .61428 m
.58049 .61803 L
s
.62688 .61428 m
.62688 .61803 L
s
.67327 .61428 m
.67327 .61803 L
s
.76605 .61428 m
.76605 .61803 L
s
.81243 .61428 m
.81243 .61803 L
s
.85882 .61428 m
.85882 .61803 L
s
.90521 .61428 m
.90521 .61803 L
s
.99799 .61428 m
.99799 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09724 m
1 .09724 L
s
.99375 .17976 m
1 .17976 L
s
.99375 .26228 m
1 .26228 L
s
.99375 .3448 m
1 .3448 L
s
.99375 .42732 m
1 .42732 L
s
.99375 .50984 m
1 .50984 L
s
.99375 .59237 m
1 .59237 L
s
.125 Mabswid
.99625 .03122 m
1 .03122 L
s
.99625 .04772 m
1 .04772 L
s
.99625 .06423 m
1 .06423 L
s
.99625 .08073 m
1 .08073 L
s
.99625 .11374 m
1 .11374 L
s
.99625 .13025 m
1 .13025 L
s
.99625 .14675 m
1 .14675 L
s
.99625 .16325 m
1 .16325 L
s
.99625 .19626 m
1 .19626 L
s
.99625 .21277 m
1 .21277 L
s
.99625 .22927 m
1 .22927 L
s
.99625 .24578 m
1 .24578 L
s
.99625 .27878 m
1 .27878 L
s
.99625 .29529 m
1 .29529 L
s
.99625 .31179 m
1 .31179 L
s
.99625 .3283 m
1 .3283 L
s
.99625 .36131 m
1 .36131 L
s
.99625 .37781 m
1 .37781 L
s
.99625 .39431 m
1 .39431 L
s
.99625 .41082 m
1 .41082 L
s
.99625 .44383 m
1 .44383 L
s
.99625 .46033 m
1 .46033 L
s
.99625 .47684 m
1 .47684 L
s
.99625 .49334 m
1 .49334 L
s
.99625 .52635 m
1 .52635 L
s
.99625 .54285 m
1 .54285 L
s
.99625 .55936 m
1 .55936 L
s
.99625 .57586 m
1 .57586 L
s
.99625 .60887 m
1 .60887 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .4 .4 r
.004 w
.09339 .08898 m
.13978 .33707 L
.14025 .3627 L
.14257 .36084 L
.14489 .20403 L
.18617 .31583 L
.23256 .28816 L
.25901 .31981 L
.26132 .29871 L
.26364 .30711 L
.27895 .30683 L
.32534 .30526 L
.37173 .31163 L
.41812 .30936 L
.46451 .31168 L
.49652 .30895 L
.49884 .29489 L
.50116 .30593 L
.5109 .30245 L
.55729 .30406 L
.60368 .30736 L
.65007 .30507 L
.69646 .30092 L
.74285 .30496 L
.78924 .3058 L
.83563 .3043 L
.88202 .30299 L
.92841 .30212 L
.97155 .29709 L
.97387 .27924 L
.97619 .29595 L
s
.4 .4 1 r
.08087 .39228 m
.08319 .4713 L
.08551 .29846 L
.09339 .30618 L
.13978 .45601 L
.14025 .45895 L
.14257 .4512 L
.14489 .48547 L
.18617 .468 L
.23256 .49675 L
.25901 .47728 L
.26132 .41747 L
.26364 .49997 L
.27895 .59895 L
.32534 .4969 L
.37173 .53823 L
.41812 .55529 L
.46451 .56318 L
.49652 .57353 L
.49884 .47741 L
.50116 .56295 L
.5109 .57092 L
.55729 .57815 L
.60368 .57975 L
.65007 .57948 L
.69646 .58975 L
.74285 .58458 L
.78924 .59689 L
.83563 .59837 L
.88202 .59382 L
.92841 .59913 L
.97155 .60332 L
.97387 .54381 L
.97619 .59127 L
s
.4 .8 .4 r
.08087 .25399 m
.08319 .26424 L
.08551 .27207 L
.09339 .24468 L
.13978 .26631 L
.14025 .2467 L
.14257 .26153 L
.14489 .24947 L
.18617 .27788 L
.23256 .27492 L
.25901 .28872 L
.26132 .25037 L
.26364 .25734 L
.27895 .28525 L
.32534 .27823 L
.37173 .29323 L
.41812 .285 L
.46451 .29327 L
.49652 .28072 L
.49884 .21372 L
.50116 .27327 L
.5109 .28063 L
.55729 .29408 L
.60368 .29165 L
.65007 .29123 L
.69646 .29232 L
.74285 .286 L
.78924 .29715 L
.83563 .28954 L
.88202 .29454 L
.92841 .29492 L
.97155 .28199 L
.97387 .17999 L
.97619 .27475 L
s
.8 .4 .8 r
.08087 .03514 m
.08319 .03507 L
.08551 .03481 L
.09339 .03503 L
.13978 .03487 L
.14025 .03504 L
.14257 .03497 L
.14489 .03491 L
.18617 .03484 L
.23256 .03485 L
.25901 .03496 L
.26132 .03483 L
.26364 .03485 L
.27895 .0348 L
.32534 .035 L
.37173 .03497 L
.41812 .03499 L
.46451 .03497 L
.49652 .03502 L
.49884 .03474 L
.50116 .03498 L
.5109 .03499 L
.55729 .03502 L
.60368 .03501 L
.65007 .03504 L
.69646 .03504 L
.74285 .03504 L
.78924 .03487 L
.83563 .03505 L
.88202 .03506 L
.92841 .03506 L
.97155 .03507 L
.97387 .03455 L
.97619 .03506 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
1 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
0 g
.001 w
[ ] 0 setdash
.07593 .01621 m
.97619 .01621 L
.97619 .06359 L
.07593 .06359 L
.07593 .01621 L
s
% Start of sub-graphic
p
0.0759299 0.0162051 0.97619 0.0635872 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0206612 0.206612 0.00223015 0.0223015 [
[ 0 0 0 0 ]
[ 1 .05263 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .05263 L
0 .05263 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0371901 0.00401427 0.243802 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .4 .4 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.1405 .0281 -109.969 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MATLAB) show
134.750 17.000 moveto
(6.0) show
156.938 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.27686 0.00401427 0.483471 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .4 1 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38017 .0281 -116.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P4) show
82.500 17.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.312 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Optimized) show
170.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.516529 0.00401427 0.72314 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .8 .4 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.61983 .0281 -125.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PPro) show
100.188 17.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
111.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Optimized) show
188.188 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.756198 0.00401427 0.96281 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.8 .4 .8 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.8595 .0281 -101.562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Reference) show
140.125 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .68061 L
0 .68061 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{579.5, 394},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=U0002Cb000`400?l00000o`00003oo`3ooooo
0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0oooo
o`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?oo
ool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo
003o0?ooool0ooooo`3ooomX0?ooo`00@P3ooooo00000?l00000o`00000@000001H0oooo00120?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3oool0503oool00480
oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`0D0?ooo`00
@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool<0?ooo`030000003oool0oooo01@0oooo
00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3oool0503o
ool00480oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`0D
0?ooo`00@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool<0?ooo`030000003oool0oooo
01@0oooo00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3o
ool0503oool00480oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo
0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`1R0?oooa80ofIVZ@3ooolB06IVojT0oooo4P1V
c6JY0?oooa80c6K<I03oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`1R
0?oooa80ofIVZ@3ooolB06IVojT0oooo4P1Vc6JY0?oooa80c6K<I03oool00`000000oooo0?ooo`0D
0?ooo`00@P3oool00`000000oooo0?ooo`1R0?oooa80ofIVZ@3ooolB06IVojT0oooo4P1Vc6JY0?oo
oa80c6K<I03oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`1R0?oooa80
ofIVZ@3ooolB06IVojT0oooo4P1Vc6JY0?oooa80c6K<I03oool00`000000oooo0?ooo`0D0?ooo`00
@P3oool00`000000oooo0?ooo`1R0?oooa80ofIVZ@3ooolB06IVojT0oooo4P1Vc6JY0?oooa80c6K<
I03oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool<0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooo``0oooo00<000000?ooo`3oool0503oool00480oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo303oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool<0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooo``0oooo00<000000?ooo`3oool0503oool00480oooo00<000000?ooo`3oool0o`3o
oooo0?ooool0oooo303oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`3o
0?ooool0ooooo`3oool<0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003oool0oooo
0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3oool0503oool00480oooo00<000000?ooo`3o
ool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3oool<0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3oool0503oool00480oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`050?noM000000000000000M02oool0``3oool01@3o_g@000000000
000007@0_ooo0?l0oooo9`3oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?oo
o`3o0?oooaL0oooo00D0okmd000000000000001d0;ooo`330?ooo`050?noM000000000000000M02o
ool0o`3ooolW0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003oool0oooo0?l0oooo
5`3oool01@3o_g@000000000000007@0_ooo0<<0oooo00D0okmd000000000000001d0;ooo`3o0?oo
obL0oooo00<000000?ooo`3oool0503oool00480oooo00<000000?ooo`3oool0o`3ooolG0?ooo`05
0?noM000000000000000M02oool0``3oool01@3o_g@000000000000007@0_ooo0?l0oooo9`3oool0
0`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo0?ooo`3o0?oooaL0oooo00D0okmd0000
00000000001d0;ooo`330?ooo`050?noM000000000000000M02oool0o`3ooolW0?ooo`030000003o
ool0oooo01@0oooo00120?ooo`030000003oool0oooo02D0oooo00D0omnL04P000000000001809cO
o`020?ooo`050?noM000000000000000001d_ol00P3oool01`3ogi`0B0000000000004P0W=oo0?oo
g`2LB0000P0000000`00B9`0gooo0?ooo`060?ooo`050?oOW0180000000000000018W=l01P3oool0
1@3o_g@000000000000007@0_ooo00D0oooo00<0oono07@0000000002P0000001P1d_ml0W4P00000
0000000004RL0=ooo`L0oooo00P0omnL04P000000000000004RLg`3oool0oono07@000X0000000<0
M;oo0?ooo`3oool02`3oool01P3OW4P00000000000000000001809cOo`@0oooo00D0oono07@00000
0000001809cOo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool09`3oool01@3o
_g@000000000000007@0_ooo0100oooo00D0oooO09a800000000000004RLg`0H0?ooo`030?oOW018
0000000000<0000000<0001809cOo`3oool01@3oool01P3o_g@000000000000007@0_ooo0?noM0<0
000000<004RL0=ooo`3oool0103oool00`3ooml0W4P000000002000000070018W03Oool0oono07@0
00000000001809cOo`020?ooo`040;md000000000000001d_`<0oooo00D0okmd000000000000001d
0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3oool01`3ookl0M0000000000004P0W=oo
0?ooo`3OW4P02P0000001P18W=l0oooo0?ooo`3oool0omnL04P000<0000000<0001d0;ooo`3oool0
1P3oool01`2oM000000000000000000004RL0=ooo`2oM0000P0000000`18W=l0oooo0?ooo`0<0?oo
o`050?noM000000000000000M02oool02`3oool01@3o_g@000000000000007@0_ooo00/0oooo00D0
gia800000000000004RL0=ooo`070?ooo`030?oo_`1d000000000080000000<0001809cOo`3oool0
603oool00`3ogi`0B00000000003000000030000B02Lgol0oooo00D0oooo00H0okmd000000000000
001d0;ooo`3o_g@3000000030018W03Oool0oooo00@0oooo00<0oooO09a8000000000P0000001`00
B9`0gooo0?oo_`1d000000000000B02Lgol00P3oool0102oM000000000000000M;l30?ooo`050?no
M000000000000000M02oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00L0oono07@0
00000000001809cOo`3oool0gia800X0000000H0B9cO0?ooo`3oool0oooo0?oOW018000300000003
0000M02oool0oooo00H0oooo00L0_g@000000000000000000018W03Oool0_g@00080000000<0B9cO
0?ooo`3oool08`3oool01@3ookl0M000000000000000M;oo00H0oooo00D0_g@00000000000000000
04RLg`030?ooo`030?oOW018000000000080000000<0001d0;ooo`3oool00`3oool01@3ookl0M000
000000000000M;oo00D0oooo00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`030?ooo`05
0=nLB000000000000018W03Oool01P3oool00`3ogi`0B00000000002000000030000M02oool0oooo
00<0oooo00D0omnL04P000000000001d0;ooo`030?ooo`050?oo_`1d000000000000001d_ol01@3o
ool00`2oM00000000000000200000003001d_`3oool0oooo00@0oooo00<0omnL04P0000000000P00
00000`0007@0_ooo0?ooo`0g0?ooo`030000003oool0oooo01@0oooo00120?ooo`030000003oool0
oooo02D0oooo00D0omnL04P000000000001809cOo`020?ooo`050;md00000000000000000018W=l0
0P3oool01`3ogi`0B0000000000004P0W=oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?oo
o`050=nLB000000000000000B02Lgol01P3oool01@3o_g@000000000000007@0_ooo00D0oooo00<0
oono07@0000000002P0000001P1d_ol0gia8000000000000001809cOo`L0oooo00P0gia800000000
0000001809cOo`3oool0oono07@000/0000000<007Bo0?ooo`3oool0203oool00`3ookl0M0000000
000500000009001d_`3oool0oooo0?ooo`3ookl0M0000000000004P0W=oo00<0oooo00<0omnL04P0
00000000100000000`0004P0W=oo0?ooo`0V0?ooo`050?noM000000000000000M02oool0403oool0
1@3ooml0W4P0000000000000B9cO01H0oooo00<0oono07@0000000001`0000000`0007@0_ooo0?oo
o`030?ooo`050?noM000000000000000M01dM0001@0000000`0004P0W=oo0?ooo`030?ooo`030;md
0000000000000080000000L004RL0=ooo`3ookl0M0000000000004P0W=oo0080oooo00@0_g@00000
0000000007Bo0`3oool01@3o_g@000000000000007@0_ooo0080oooo00D0oono07@0000000000000
07Boo`020?ooo`070?oo_`1d000000000000B02Lgol0oooo0=nLB00:0000000404RLg`3oool0oooo
0=nLB0L0000000<0B9cO0?ooo`3oool00P3oool00`3ookl0M00000000004000000050000B018B000
000000000018W=l03P3oool01@3o_g@000000000000007@0_ooo00/0oooo00D0okmd000000000000
001d0;ooo`0;0?ooo`050=nLB000000000000018W03Oool01@3oool00`3ooml0W4P0000000060000
00030018W03Oool0oooo01@0oooo00<0oono07@0000000001`0000000`0007@0_ooo0?ooo`030?oo
o`050?noM000000000000000M01dM0001@0000000`0004P0W=oo0?ooo`030?ooo`030;md00000000
00000080000000L004RL0=ooo`3ookl0M0000000000004P0W=oo0080oooo00@0_g@0000000000000
07Bo0`3oool01@3o_g@000000000000007@0_ooo0080oooo00D0oono07@000000000000007Boo`02
0?ooo`070?oo_`1d000000000000B02Lgol0oooo0=nLB00:0000000404RLg`3oool0oooo0=nLB0L0
000000<0B9cO0?ooo`3oool00P3oool00`3ookl0M00000000004000000050000B018B00000000000
0018W=l09@3oool01@3ookl0M000000000000000M;oo00D0oooo00H0omnL04P00000000000000000
M02oool20?ooo`030=nLB0000000000000D0000000H0B9cO0?ooo`3oool0oooo0?oo_`1d00020000
000307Boo`3oool0oooo0080oooo00<0gia80000000000001@0000001@18W=l0oooo0?ooo`3oool0
gia80080000000<004RL0=ooo`3oool0103oool00`3OW4P00000000000050000000904RLg`3oool0
oooo0?ooo`3ogi`0B0000000000007@0_ooo00<0oooo00D0oono07@000000000000007Boo`030?oo
o`030?oOW0180000000000D0000000<0001809cOo`3oool00P3oool00`3OW4P00000000000050000
000304RLg`3oool0oooo03D0oooo00<000000?ooo`3oool0503oool00480oooo00<000000?ooo`3o
ool09@3oool0203ogi`0B000000000000000M;oo0?ooo`3ooml0W4P00`0000001000B9`0gooo0?oo
o`3o_g@2000000050000B02Lgol0oooo0?oOW01800000P0000000`18W=l0oooo0?ooo`040?ooo`06
0?oog`2LB000000000000000B9`0gooo1P3oool01@3o_g@000000000000007@0_ooo00D0oooo00<0
oono07@0000000002P0000000`1d_ol0omnL04P000020000000304RLg`3oool0oooo00@0oooo00T0
oooO09a80000000000000018W03Oool0oooo0?oo_`1d0000300000000`1d_ol0oooo0?ooo`060?oo
o`030?oog`2LB000000000L0000000P0B9cO0?ooo`3oool0oono07@000000000001809cOo`80oooo
00<0oono07@0000000001P0000000`00B9`0gooo0?ooo`0U0?ooo`050?noM000000000000000M02o
ool0403oool01@3ooml0W4P0000000000000B9cO01D0oooo00<0omnL04P0000000002@0000000`00
04P0W=oo0?ooo`020?ooo`030?noM0000000000000P0000000H0001d0;ooo`3oool0oooo0?oo_`1d
0004000000070018W03Oool0oono07@000000000001809cOo`020?ooo`040;md000000000000001d
_`<0oooo00D0okmd000000000000001d0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3o
ool0203ookl0M0000000000004P0W=oo0?ooo`3ookl0M0002@0000000`18W=l0oooo0?noM0080000
00060000B02Lgol0oooo0?ooo`3ooml0W4P02P0000000`18W=l0oooo0?ooo`0<0?ooo`050?noM000
000000000000M02oool02`3oool01@3o_g@000000000000007@0_ooo00/0oooo00D0gia800000000
000004RL0=ooo`050?ooo`030;md00000000000000L0000000<007Bo0?ooo`3oool04P3oool00`3o
gi`0B00000000009000000030000B02Lgol0oooo0080oooo00<0okmd000000000000200000001P00
07@0_ooo0?ooo`3oool0oono07@000@0000000L004RL0=ooo`3ookl0M0000000000004P0W=oo0080
oooo00@0_g@000000000000007Bo0`3oool01@3o_g@000000000000007@0_ooo0080oooo00D0oono
07@000000000000007Boo`020?ooo`080?oo_`1d000000000000B02Lgol0oooo0?oo_`1d00090000
000304RLg`3oool0okmd00P0000000H0001809cOo`3oool0oooo0?oog`2LB00:0000000304RLg`3o
ool0oooo02<0oooo00D0oono07@000000000000007Boo`040?ooo`030?oog`2LB000000000800000
00@0M;oo0?ooo`3oool0okmd200000001P0004P0W=oo0?ooo`3oool0oono07@00080000000D0M;oo
0?ooo`3oool0oooo0?noM008000000050000B02Lgol0oooo0?ooo`3OW4P00P0000000`00B9`0gooo
0?ooo`030?ooo`030?noM0000000000000H0000000T0001809cOo`3oool0oooo0?oOW01800000000
0000M02oool00`3oool01@3ookl0M000000000000000M;oo0080oooo00<0oono07@0000000001`00
00001000B9`0gooo0?ooo`3o_g@8000000030000B02Lgol0oooo03D0oooo00<000000?ooo`3oool0
503oool00480oooo00<000000?ooo`3oool09@3oool0203ogi`0B000000000000000M;oo0?ooo`3o
okl0M0000`000000100007@0_ooo0?ooo`3o_g@2000000050000B02Lgol0oooo0?ooo`2oM0000P00
00000`00B9`0gooo0?ooo`040?ooo`050?oOW0180000000000000018W=l01`3oool01@3o_g@00000
0000000007@0_ooo00D0oooo00D0oono07@000000000000007Boo`0:0?ooo`050;md000000000000
0018W03Oool01@3oool01@3ogi`0B000000000000000B9cO0080oooo00D0oono07@0000000000000
07Boo`050?ooo`060?noM0000000000000000000B9`0gooo1`3oool0203o_g@00000000000000000
B9cO0?ooo`3ooml0W4P00P0000000`00B9`0gooo0?ooo`070?ooo`070?noM000000000000000B02L
gol0oooo0?noM0030000000307Boo`3oool0oooo02@0oooo00D0okmd000000000000001d0;ooo`0:
0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`3oool0403oool00`3ooml0W4P000000002
000000060000M02oool0oooo0?ooo`3ooml0W4P00`0000001@00B9`0gooo0?ooo`3oool0okmd00@0
000000@0M;oo0?ooo`3oool0gia80`0000001@18W=l0oooo0?ooo`3ookl0M0000080000000T0M;oo
0?ooo`3oool0oooo0?oo_`1d000000000000B02Lgol00P3oool0102oM000000000000000M;l30?oo
o`050?noM000000000000000M02oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00D0
oono07@000000000001809cOo`020?ooo`050?noM000000000000000B02Lgol01P3oool02@3ooml0
W4P0000000000000001d0;ooo`3oool0oooO09a8000200000004001d_`3oool0oooo0?noM0<00000
00D007Bo0?ooo`3oool0oono07@000030000000304RLg`3oool0oooo00`0oooo00D0okmd00000000
0000001d0;ooo`0;0?ooo`050?noM000000000000000M02oool02`3oool01@3OW4P0000000000000
B9`0gooo00@0oooo00H0omnL04P00000000000000018W03Oool20?ooo`050;md0000000000000000
001d_ol04P3oool00`3ooml0W4P000000002000000060000M02oool0oooo0?ooo`3ooml0W4P00`00
00001@00B9`0gooo0?ooo`3oool0okmd00@0000000@0M;oo0?ooo`3oool0gia80`0000001@18W=l0
oooo0?ooo`3ookl0M0000080000000T0M;oo0?ooo`3oool0oooo0?oo_`1d000000000000B02Lgol0
0P3oool0102oM000000000000000M;l30?ooo`050?noM000000000000000M02oool00P3oool01@3o
okl0M000000000000000M;oo0080oooo00D0oono07@000000000001809cOo`020?ooo`050?noM000
000000000000B02Lgol01P3oool02@3ooml0W4P0000000000000001d0;ooo`3oool0oooO09a80002
00000004001d_`3oool0oooo0?noM0<0000000D007Bo0?ooo`3oool0oono07@000030000000304RL
g`3oool0oooo02<0oooo00D0oono07@000000000000007Boo`040?ooo`050=nLB000000000000000
0000M;l00P3oool02@3ooml0W4P0000000000000001d0;ooo`3oool0oooO09a8000200000005001d
_`3oool0oooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3ooml0W4P00080000000D0001d0;oo
o`3oool0oooO09a8000200000004001d_`3oool0oooo0=nLB080000000<004RL0=ooo`3oool00P3o
ool02@3ooml0W4P0000000000000001d0;ooo`3oool0oooO09a8000200000008001d_`3oool0oooo
0?oOW018000000000000M02oool30?ooo`050?oo_`1d000000000000001d_ol00P3oool01@3OW4P0
0000000000000000M;oo0080oooo00L0gia8000000000000000007Boo`3ooml0W4P00080000000D0
001d0;ooo`3oool0oooO09a8000200000003001d_`3oool0oooo03@0oooo00<000000?ooo`3oool0
503oool00480oooo00<000000?ooo`3oool09@3oool03`3ogi`0B000000000000000M;oo0?ooo`3o
gi`0B0000000001dM7@000000000B02Lgol0oooo0?noM002000000050000B02Lgol0oooo0?ooo`3o
_g@0300000000`0007@0_ooo0?ooo`060?ooo`050?noM000000000000000M02oool01@3oool01@3o
okl0M000000000000000M;oo00X0oooo00<0okmd0000000000002P0000001P0007@0_ooo0?ooo`3o
ool0oono07@00080000000<0M;oo0?ooo`3oool0103oool01@2oM00000000000000007@0_ooo00L0
oooo00D0_g@000000000000004RL0=ooo`020?ooo`050?oOW018000000000000B02Lgol0203oool0
102oM000000000000000M;l30?ooo`040;md00000000000004RLgbH0oooo00D0okmd000000000000
001d0;ooo`0:0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`3oool0403oool01@3o_g@0
000000000000000007Bo00H0oooo00D0_g@0000000000000000007Boo`020?ooo`050?noM0000000
00000000001d_ol0103oool0202oM000000000000000B9`0gooo0?ooo`3ookl0M0000P0000002@1d
_ol0oooo0?ooo`3oool0oono07@000000000001809cOo`020?ooo`040;md000000000000001d_`<0
oooo00D0okmd000000000000001d0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@3ookl0M0000000000004P0W=oo00<0oooo00D0gia8000000000000001d0;ooo`050?ooo`050?oO
W018000000000000001d_ol02@3oool01@2oM000000000000000B9`0gooo00<0oooo00D0omnL04P0
00000000000004RLg`0>0?ooo`050?noM000000000000000M02oool02`3oool01@3o_g@000000000
000007@0_ooo00/0oooo00D0gia800000000000004RL0=ooo`040?ooo`050=nLB000000000000000
M02oool00`3oool01@3ooml0W4P000000000000007Bo0180oooo00D0okmd0000000000000000001d
_`060?ooo`050;md0000000000000000001d_ol00P3oool01@3o_g@00000000000000000M;oo00@0
oooo00P0_g@000000000000004RL0=ooo`3oool0oono07@00080000000T0M;oo0?ooo`3oool0oooo
0?oo_`1d000000000000B02Lgol00P3oool0102oM000000000000000M;l30?ooo`050?noM0000000
00000000M02oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00D0oono07@000000000
001809cOo`030?ooo`050=nLB000000000000000M02oool01@3oool01@3ogi`0B000000000000000
M;oo00T0oooo00D0_g@000000000000004RL0=ooo`030?ooo`050?oOW0180000000000000018W=l0
9@3oool01@3ookl0M000000000000000M;oo00<0oooo00H0omnL04P00000000000000000M02oool2
0?ooo`050?oOW018000000000000001d_ol02@3oool01@3ookl0M000000000000000M;oo0080oooo
00D0omnL04P000000000000007Boo`090?ooo`050=nLB000000000000018W03Oool00`3oool01@3o
gi`0B000000000000000M;oo00T0oooo00D0omnL04P000000000001d0;ooo`030?ooo`080?oo_`1d
000000000000001d_ol0oooo0?oog`2LB0020000000;001d_`3oool0oooo0?ooo`3ookl0M0000018
W03Oool0oooo0?oOW01800000P0000000`1d_ol0oooo0?ooo`0k0?ooo`030000003oool0oooo01@0
oooo00120?ooo`030000003oool0oooo02D0oooo00l0omnL04P000000000000007Boo`3oool0gia8
0000000004P0W=no07@000000000B9cO0?ooo`3o_g@00P0000001P0004P0W=oo0?ooo`3oool0oono
07@000/0000000<007Bo0?ooo`3oool01P3oool01@3o_g@000000000000007@0_ooo00D0oooo00D0
oono07@000000000000007Boo`0:0?ooo`030?oo_`1d0000000000X0000000H007Bo0?ooo`3oool0
oooo0?oo_`1d00020000000307Boo`3oool0oooo00@0oooo00D0_g@0000000000000001d0;ooo`06
0?ooo`050?oog`2LB000000000000000M;l00`3oool01@3ogi`0B0000000000004P0W=oo00L0oooo
00D0oooO09a800000000000007Boo`030?ooo`050=nLB000000000000018W03Oool09@3oool01@3o
_g@000000000000007@0_ooo00X0oooo00<0gia80000000000002@0000000`18W=l0oooo0=nLB00<
000000050018W03Oool0oooo0?ooo`2oM0000P0000000`0007@0_ooo0?ooo`050?ooo`050?oo_`1d
0000000000000000M;l00P3oool01@3o_g@000000000000007@0_ooo00@0oooo00P0okmd00000000
0000001d0;ooo`3oool0oono07@00080000000T0M;oo0?ooo`3oool0oooo0?oo_`1d000000000000
B02Lgol00P3oool0102oM000000000000000M;l30?ooo`050?noM000000000000000M02oool00P3o
ool01@3ookl0M000000000000000M;oo0080oooo00D0oono07@000000000001809cOo`030?ooo`06
0?oog`2LB000000000000000B9`0gooo103oool01@3o_g@000000000000007@0_ooo00P0oooo00D0
oooO09a8000000000000001d_`040?ooo`050?oog`2LB000000000000018W=l03P3oool01@3o_g@0
00000000000007@0_ooo00/0oooo00D0okmd000000000000001d0;ooo`0;0?ooo`050=nLB0000000
00000018W03Oool0103oool0102oM000000000000000M;l50?ooo`070=nLB000000000000018W03O
ool0oooo0=nLB00<000000040018W03Oool0oooo0;md0080000000<0001d0;ooo`3oool01@3oool0
1@3ookl0M00000000000000007Bo0080oooo00D0okmd000000000000001d0;ooo`040?ooo`080?no
M000000000000000M02oool0oooo0?oo_`1d00020000000907Boo`3oool0oooo0?ooo`3ookl0M000
0000000004P0W=oo0080oooo00@0_g@000000000000007Bo0`3oool01@3o_g@000000000000007@0
_ooo0080oooo00D0oono07@000000000000007Boo`020?ooo`050?oo_`1d000000000000B02Lgol0
0`3oool01P3ooml0W4P000000000000004RL0=ooo`@0oooo00D0okmd000000000000001d0;ooo`08
0?ooo`050?oog`2LB000000000000000M;l0103oool01@3ooml0W4P0000000000000B9cO02D0oooo
00D0oono07@000000000000007Boo`020?ooo`030?oog`2LB00000000080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000030000M02oool0oooo00P0oooo00D0oono07@000000000000007Boo`02
0?ooo`050?noM000000000000000M02oool02@3oool01@3OW4P0000000000000B9`0gooo00<0oooo
00D0okmd000000000000001d0;ooo`090?ooo`050?oOW018000000000000M02oool00`3oool0203o
okl0M000000000000000M;oo0?ooo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`060?ooo`050?no
M000000000000000M02oool0?@3oool00`000000oooo0?ooo`0D0?ooo`00@P3oool00`000000oooo
0?ooo`0U0?ooo`0?0?oOW018000000000000001d_ol0oooo0;md0000000004RL0=oog`2LB0000000
001d_`3oool0okmd0080000000<0001809cOo`3oool00P3oool00`2oM00000000000000900000003
07Boo`3oool0oooo00H0oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oo_`1d00000000
0000001d_ol02`3oool00`2oM0000000000000090000000607Boo`3oool0oooo0?ooo`3ookl0M000
0P0000000`1d_ol0oooo0?ooo`030?ooo`050=nLB0000000000000000000M;l01`3oool01@3ookl0
M00000000000000007Bo00<0oooo00D0omnL04P000000000001809cOo`070?ooo`050?oo_`1d0000
00000000001d_ol00`3oool01@3o_g@0000000000000B9`0gooo02D0oooo00<0okmd000000000000
1`0000000`00B9`0gooo0?ooo`020?ooo`040?oOW01800000000001d_`80oooo00D0oooO09a80000
0000000004RLg`030?ooo`030=nLB0000000000000X0000000D004RL0=ooo`3oool0oooO09a80002
00000003001d_`3oool0oooo00H0oooo00L0_g@000000000000004RL0=ooo`3oool0okmd00800000
00<0001d0;ooo`3oool00`3oool0203o_g@000000000000007@0_ooo0?ooo`3ookl0M0000P000000
2@1d_ol0oooo0?ooo`3oool0oono07@000000000001809cOo`020?ooo`040;md000000000000001d
_`<0oooo00D0okmd000000000000001d0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3o
ool01@3ookl0M0000000000004P0W=oo00@0oooo00D0oono07@000000000000004RLg`040?ooo`03
0?noM0000000000000P0000000@0001809cOo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`020?oo
o`050?oog`2LB000000000000018W=l03P3oool00`3o_g@0000000000007000000030018W03Oool0
oooo00<0oooo00<0okmd0000000000001`0000000`00B9`0gooo0?ooo`030?ooo`050=nLB0000000
00000018W03Oool00`3oool01@3ooml0W4P0000000000000B9cO00D0oooo00L0okmd000000000000
001d0;ooo`3oool0gia800`0000000@004RL0=ooo`3ooml0W4P00P0000000`00M;l0oooo0?ooo`06
0?ooo`070;md0000000000000018W03Oool0oooo0?noM002000000030000M02oool0oooo00<0oooo
00P0okmd000000000000001d0;ooo`3oool0oono07@00080000000T0M;oo0?ooo`3oool0oooo0?oo
_`1d000000000000B02Lgol00P3oool0102oM000000000000000M;l30?ooo`050?noM00000000000
0000M02oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00D0oono07@0000000000018
09cOo`040?ooo`050?oo_`1d0000000000000018W=l0103oool00`3o_g@000000000000800000004
0000B02Lgol0oooO09a80080000000<0B9cO0?ooo`3oool00P3oool01@3ooml0W4P0000000000000
B9cO02D0oooo00P0oono07@000000000000007Boo`3oool0oooO09a800<0000000<0B9cO0?ooo`3o
ool00P3oool00`3o_g@0000000000008000000050000B02Lgol0oooo0?oo_`1d00000P000000101d
_ol0oooo0?ooo`3o_g@:000000040000B02Lgol0oooo0=nLB080000000<004RL0=ooo`3oool00P3o
ool00`3o_g@0000000000008000000080000B02Lgol0oooo0?oOW018000000000000B02Lgol30?oo
o`080?oo_`1d000000000000001d_ol0oooo0?oo_`1d00020000000307Boo`3oool0oooo00H0oooo
00<0okmd000000000000200000000`0004P0W=oo0?ooo`0d0?ooo`030000003oool0oooo01@0oooo
00120?ooo`030000003oool0oooo02D0oooo00l0omnL04P000000000000004RLg`3ooml0W4P00000
0000M;l0oooo0;md0000000004RL0=ooo`3OW4P00P0000000`0004P0W=oo0?ooo`020?ooo`050?no
M000000000000000M02oool00`3oool01@3OW4P000000000000007@0_ooo00P0oooo00D0okmd0000
00000000001d0;ooo`050?ooo`050?oo_`1d000000000000001d_ol02`3oool01@3o_g@000000000
000007@0_ooo00<0oooo00D0gia8000000000000001d0;ooo`030?ooo`030?oo_`1d0000000000X0
000000<004RL0=ooo`3oool01P3oool00`3ookl0M000000000020000000407Boo`3oool0oooO09a8
0080000000<0001d0;ooo`3oool01P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd
000000000000001d0;ooo`0U0?ooo`030?noM0000000000000T0000000D0M;oo0?ooo`3oool0oooo
0=nLB0020000000407Boo`3oool0oooO09a80080000000<0B9cO0?ooo`3oool04@3oool01@3ookl0
M000000000000000B9cO00P0oooo00L0gia8000000000000001d0;ooo`3oool0okmd0080000000<0
001d0;ooo`3oool00`3oool0203o_g@000000000000007@0_ooo0?ooo`3ookl0M0000P0000002@1d
_ol0oooo0?ooo`3oool0oono07@000000000001809cOo`020?ooo`040;md000000000000001d_`<0
oooo00D0okmd000000000000001d0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@3ookl0M0000000000004P0W=oo00D0oooo00D0okmd000000000000000007Boo`030?ooo`030?no
M0000000000000P0000000@0001d0;ooo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`020?ooo`05
0?oog`2LB000000000000018W=l03P3oool00`3o_g@00000000000090000000507Boo`3oool0oooo
0?ooo`3o_g@02`0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool00P3o
ool01@3ooml0W4P000000000000007Bo00D0oooo00D0gia800000000000004RL0=ooo`0@0?ooo`05
0?oo_`1d0000000000000018W=l0203oool01`3OW4P000000000000007@0_ooo0?ooo`3o_g@00P00
00000`0007@0_ooo0?ooo`030?ooo`080?noM000000000000000M02oool0oooo0?oo_`1d00020000
000907Boo`3oool0oooo0?ooo`3ookl0M0000000000004P0W=oo0080oooo00@0_g@0000000000000
07Bo0`3oool01@3o_g@000000000000007@0_ooo0080oooo00D0oono07@000000000000007Boo`02
0?ooo`050?oo_`1d000000000000B02Lgol01@3oool01@3o_g@00000000000000000M;oo00<0oooo
00<0okmd00000000000020000000100007@0_ooo0?oog`2LB0020000000304RLg`3oool0oooo0080
oooo00D0oooO09a800000000000004RLg`0U0?ooo`030?oo_`1d0000000000L0000000<0M;oo0?oo
o`3oool00`3oool00`3o_g@0000000000008000000050000M02oool0oooo0?oo_`1d00000P000000
101d_ol0oooo0?ooo`3o_g@:000000040000M02oool0oooo0=nLB080000000<004RL0=ooo`3oool0
0P3oool00`3o_g@0000000000008000000080000M02oool0oooo0?oOW018000000000000B02Lgol3
0?ooo`080?oo_`1d000000000000001d_ol0oooo0?oog`2LB0020000000307Boo`3oool0oooo00H0
oooo00<0okmd000000000000200000000`0007@0_ooo0?ooo`0d0?ooo`030000003oool0oooo01@0
oooo00120?ooo`030000003oool0oooo02D0oooo00l0omnL04P000000000000004RLg`3ookl0M000
0000001d_ol0oooo0?noM0000000001d0;ooo`3OW4P00P0000000`0004P0W=oo0?ooo`020?ooo`05
0?oo_`1d000000000000001d_ol00P3oool01@3ooml0W4P0000000000000B9cO00T0oooo00D0okmd
000000000000001d0;ooo`050?ooo`050?oo_`1d000000000000001d_ol02`3oool01@3ookl0M000
000000000000M;oo0080oooo00D0oooO09a800000000000004RLg`040?ooo`030?oo_`1d00000000
00T0000000<0M;oo0?ooo`3oool01`3oool00`3ookl0M000000000080000000304RLg`3oool0oooo
00H0oooo00D0oono07@000000000000007Boo`030?ooo`050?noM000000000000000M02oool09@3o
ool00`3o_g@00000000000090000000;0000B02Lgol0oooo0?ooo`3ookl0M0000000000007@0_ooo
0?oog`2LB0000P0000000`18W=l0oooo0?ooo`0A0?ooo`050?oo_`1d0000000000000018W=l0203o
ool01`3OW4P000000000000007@0_ooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`020?ooo`08
0;md0000000000000018W03Oool0oooo0?oo_`1d00020000000907Boo`3oool0oooo0?ooo`3ookl0
M0000000000004P0W=oo0080oooo00D0_g@000000000000004RL0=ooo`020?ooo`050=nLB0000000
00000000001d_ol00P3oool01@3ogi`0B000000000000000M;oo0080oooo00D0oono07@000000000
001809cOo`060?ooo`050=nLB000000000000000M02oool00P3oool01@3ogi`0B0000000000004P0
W=oo00<0oooo00L0okmd00000000000004RL0=ooo`3oool0_g@00080000000<004RL0=ooo`3oool0
0P3oool01@3ogi`0B000000000000000B9cO00h0oooo00<0okmd0000000000002@0000001@0004P0
W=oo0?ooo`3oool0okmd00/0000000D0001809cOo`3oool0oooo0=nLB002000000030000B02Lgol0
oooo00<0oooo00D0gia8000000000000001d0;ooo`030?ooo`050?oog`2LB000000000000000M;l0
4@3oool01@3ookl0M000000000000000B9cO00P0oooo00L0gia8000000000000001d0;ooo`3oool0
okmd00<0000000<0M;oo0?ooo`3oool00P3oool0202oM000000000000000B9`0gooo0?ooo`3ookl0
M0000P0000002@1d_ol0oooo0?ooo`3oool0oono07@000000000001809cOo`020?ooo`050;md0000
000000000018W03Oool00P3oool01@3OW4P00000000000000000M;oo0080oooo00D0omnL04P00000
0000000007Boo`020?ooo`050?oo_`1d000000000000B02Lgol01P3oool01@3OW4P0000000000000
07@0_ooo0080oooo00D0omnL04P000000000001809cOo`030?ooo`070?noM000000000000018W03O
ool0oooo0;md0002000000030018W03Oool0oooo0080oooo00D0omnL04P000000000000004RLg`0U
0?ooo`030?oo_`1d0000000000T0000000T004RL0=ooo`3oool0oooo0?oOW018000000000000B02L
gol00`3oool0203o_g@0000000000000B9`0gooo0?ooo`3ookl0M0000P000000201d_ol0oooo0?oo
o`3ogi`0B0000000000004P0W=oo0`3oool01`3o_g@0000000000000B9`0gooo0?ooo`3OW4P00P00
00000`0004P0W=oo0?ooo`020?ooo`050?oOW018000000000000B02Lgol00`3oool0203o_g@00000
00000000B9`0gooo0?ooo`3ogi`0B0000P0000001P1d_ol0oooo0?ooo`3oool0omnL04P000800000
00@0M;oo0?ooo`3ooml0W4P00P0000001`00M;l0oooo0?ooo`3oool0omnL04P00018W=l00P3oool0
1@3ogi`0B0000000000004P0W=oo00<0oooo00D0okmd00000000000004RL0=ooo`0e0?ooo`030000
003oool0oooo01@0oooo00120?ooo`030000003oool0oooo02D0oooo00l0omnL04P0000000000000
04RLg`3o_g@000000000B02Lgol0oooo0?oOW0180000000007Boo`3OW4P00P0000000`0004P0W=oo
0?ooo`030?ooo`040;md000000000000001d_`80oooo00D0omnL04P000000000001809cOo`090?oo
o`050?noM000000000000000M02oool01@3oool01@3ookl0M000000000000000M;oo00`0oooo00@0
_g@000000000000007Bo0P3oool01@3ogi`0B0000000000004P0W=oo00@0oooo00<0oono07@00000
00002@0000000`0007@0_ooo0?ooo`070?ooo`030?oo_`1d0000000000L0000000<004RL0=ooo`3o
ool01`3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd000000000000001d0;ooo`0U
0?ooo`050?noM000000000000000M02oool0103oool01@2oM000000000000000000007Bo00<0oooo
00H0okmd00000000000007Bo0?oog`2LB0020000000304RLg`3oool0oooo0140oooo00D0oono07@0
00000000000004RLg`080?ooo`070=nLB000000000000000M02oool0oooo0?noM003000000050000
B02Lgol0oooo0?ooo`3OW4P00`0000001@18W=l0oooo0?ooo`3ookl0M0000080000000T0M;oo0?oo
o`3oool0oooo0?oo_`1d000000000000B02Lgol00P3oool0202oM0000000000000000000B9cO0?oo
o`3ooml0W4P00`000000100007@0_ooo0?ooo`3OW4P2000000090000B02Lgol0oooo0?ooo`3ookl0
M0000000000004P0W=oo00L0oooo00P0_g@000000000000004RL0=ooo`3oool0oooO09a800800000
00D004RL0=ooo`3oool0oono07@0000200000004001d_`3oool0oooo0?noM0<0000000D007Bo0?oo
o`3oool0oono07@000030000000304RLg`3oool0oooo00`0oooo00D0okmd000000000000001d0;oo
o`040?ooo`050;md00000000000000000000M;l00P3oool01@3o_g@000000000000007@0_ooo00@0
oooo00D0_g@00000000000000000001d_`020?ooo`050=nLB0000000000000000000M;l0103oool0
1P3ogi`0B00000000000000004RL0=ooo`80oooo00D0_g@0000000000000000007Boo`0A0?ooo`05
0?oo_`1d0000000000000018W=l0203oool01`3OW4P000000000000007@0_ooo0?ooo`3o_g@00`00
00001@0004P0W=oo0?ooo`3oool0gia800<0000000D0B9cO0?ooo`3oool0oono07@0000200000009
07Boo`3oool0oooo0?ooo`3ookl0M0000000000004P0W=oo0080oooo00P0_g@00000000000000000
04RLg`3oool0oooO09a800<0000000@0001d0;ooo`3oool0gia80P0000002@0004P0W=oo0?ooo`3o
ool0oono07@000000000001809cOo`070?ooo`080;md0000000000000018W03Oool0oooo0?oog`2L
B002000000050018W03Oool0oooo0?oo_`1d00000P0000001000M;l0oooo0?ooo`3o_g@300000005
001d_`3oool0oooo0?oo_`1d00000`0000000`18W=l0oooo0?ooo`0S0?ooo`030?oo_`1d00000000
00X0000000D007Bo0?ooo`3oool0oooO09a80002000000050018W03Oool0oooo0?oo_`1d00000P00
00001@00M;l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooO09a8000200000005
0018W03Oool0oooo0?oo_`1d00000P0000001000M;l0oooo0?ooo`3OW4P300000006001d_`3oool0
oooo0?ooo`3ooml0W4P00P0000001@00B9`0gooo0?ooo`3ookl0M0000080000000D007Bo0?ooo`3o
ool0omnL04P00002000000050000B02Lgol0oooo0?ooo`2oM0000`000000101d_ol0oooo0?ooo`3O
W4P30000000407Boo`3oool0oooO09a80080000000@0001d0;ooo`3ooml0W4P00P0000001@00B9`0
gooo0?ooo`3ookl0M0000080000000<007Bo0?ooo`3oool0=03oool00`000000oooo0?ooo`0D0?oo
o`00@P3oool00`000000oooo0?ooo`0U0?ooo`0?0?oOW0180000000000000018W=l0gia800000000
B9`0gooo0?ooo`3ooml0W4P000000018W=l0gia80080000000<0001809cOo`3oool00`3oool01`3o
_g@000000000000007@0_ooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`080?ooo`050?noM000
000000000000M02oool01@3oool01@3ookl0M000000000000000M;oo00`0oooo00L0okmd00000000
0000001d0;ooo`3oool0gia80080000000<004RL0=ooo`3oool00`3oool01@3ookl0M00000000000
0000M;oo00D0oooo00D0_g@000000000000004RL0=ooo`070?ooo`060?oo_`1d000000000000001d
_ol0gia80`0000000`18W=l0oooo0?ooo`080?ooo`050?oo_`1d000000000000001d_ol00`3oool0
1@3o_g@0000000000000B9`0gooo02D0oooo00D0okmd000000000000001d0;ooo`040?ooo`060?oo
g`2LB000000000000000B9`0gooo0`3oool01@2oM00000000000001d_ml0W4P00080000000<0B9cO
0?ooo`3oool04@3oool01@3ooml0W4P000000000000007Bo00P0oooo00L0_g@000000000000004RL
0=ooo`3oool0okmd00X0000000@0001d0;ooo`3oool0_g@01P0000001`00M;l0oooo0?oo_`1d0000
00000000B02Lgol00P3oool00`2oM00000000000000>0000000<0000M02oool0oooo0?ooo`3ookl0
M0000000000004P0W=oo0?ooo`3ookl0M000200000001018W=l0oooo0?ooo`3o_g@8000000060000
B02Lgol0oooo0?ooo`3ookl0M0002P0000000`18W=l0oooo0?ooo`0<0?ooo`050?noM00000000000
0000M02oool0103oool0203ooml0W4P000000000000004RL0=ooo`3oool0okmd0P0000000`0007@0
_ooo0?ooo`030?ooo`080?oog`2LB000000000000000B9`0gooo0?ooo`3OW4P600000004001d_`3o
ool0oooo0;md00T0000000<007Bo0?ooo`3oool0403oool01@3ooml0W4P000000000000007Bo00P0
oooo00L0_g@000000000000004RL0=ooo`3oool0okmd00X0000000@0001d0;ooo`3oool0_g@01P00
00001`00M;l0oooo0?oo_`1d000000000000B02Lgol00P3oool00`2oM00000000000000>0000000<
0000M02oool0oooo0?ooo`3ookl0M0000000000004P0W=oo0?ooo`3ookl0M000200000001018W=l0
oooo0?ooo`3o_g@8000000060000B02Lgol0oooo0?ooo`3ookl0M0002P0000000`18W=l0oooo0?oo
o`0S0?ooo`050?oo_`1d000000000000001d_ol0103oool01P3ooml0W4P0000000000000001809cO
o`80oooo00<0okmd0000000000001P000000100004P0W=oo0?ooo`2oM006000000030018W03Oool0
okmd00P0000000D0001809cOo`3oool0oooo0=nLB00600000003001d_`3oool0okmd00P0000000H0
001809cOo`3oool0oooo0?oOW0180009000000060000M02oool0oooo0?ooo`3ookl0M00020000000
1000M;l0oooo0?ooo`3o_g@8000000030000B02Lgol0oooo03D0oooo00<000000?ooo`3oool0503o
ool00480ooooo`00003o00000?l000004000000F0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0
ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03o
ool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0
ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0oooo
o`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?oo
ool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo
003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?oo
ofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3o
oooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0
ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03o
ool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0
ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooocT0oooo00<0oono07@000000000100000000`00M;l0oooo0?ooo`3o0?ooobD0oooo003o0?oo
ool0oooo>03oool00`3OW4P0000000000006000000030000B02Lgol0oooo0?l0oooo903oool00?l0
ooooo`3ooolg0?ooo`030?oOW0180000000000P0000000<004RL0=ooo`3oool0o`3ooolS0?ooo`00
o`3ooooo0?ooocL0oooo00D0okmd0000000000000000001d_`030?ooo`050=nLB000000000000000
B02Lgol0o`3ooolT0?ooo`00o`3ooooo0?ooocl0oooo00D0oono07@000000000000007Boo`3o0?oo
ob@0oooo003o0?oookh0oooo00H0okmd00000000000000000000B02Lgol80?ooo`030?oOW0180000
00000080000000<0001d0;ooo`3oool01P3oool00`2oM00000000000000200000003001d_`3oool0
oooo00<0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`020?ooo`030?oo_`1d0000
00000080000000<0001809cOo`3oool0103oool01@3OW4P0000000000000B9`0gooo00/0oooo00<0
oono07@0000000002P0000001P1d_ol0oooo0?ooo`3oool0omnL04P000<0000000<0001d0;ooo`3o
ool00`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0oono07@000000000000007Boo`04
0?ooo`030?oog`2LB00000000080000000<0M;oo0?oo_`1d00000P0000001P1d_ol0oooo0?ooo`3o
ool0oooO09a800<0000000L004RL0=ooo`3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@0
00000000000007Boo`3o0?ooo`d0oooo003o0?oookh0oooo00<0_g@00000000000000P0000000`18
W=l0oooo0?ooo`050?ooo`030=nLB0000000000000D0000000<0B9cO0?ooo`3oool00P3oool00`3o
gi`0B00000000005000000030000B02Lgol0oooo0080oooo00<0_g@00000000000000P0000001@00
B9`0gooo0?ooo`3ooml0W4P000L0000000<004RL0=ooo`3oool00P3oool01@3OW4P0000000000000
B9`0gooo00/0oooo00<0oono07@0000000002P000000101d_ol0oooo0?ooo`3OW4P70000000904RL
g`3oool0oooo0?ooo`3ogi`0B0000000000007@0_ooo00<0oooo00D0oono07@000000000000007Bo
o`030?ooo`030?oOW0180000000000@0000000D0B9bL07@000000000000007Boo`030?ooo`030;md
0000000000000080000000L004RL0=ooo`3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@0
00000000000007Boo`3o0?ooo`d0oooo003o0?oookd0oooo00<0oono07@0000000000`0000000`00
B9`0gooo0?ooo`040?ooo`030?noM0000000000000H0000000H0001809cOo`3oool0oooo0?oo_`1d
0008000000050018W03Oool0oooo0?oo_`1d0000100000001000B9`0gooo0?ooo`2oM00900000005
001d_`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0:0?ooo`030?oo_`1d00000000
00X0000000<0M;oo0?ooo`3o_g@0200000002@0004P0W=oo0?ooo`3oool0omnL04P000000000001d
0;ooo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool00`3ooml0W4P00000000900000005
07Boo`3oool0oooo0?oo_`1d0000100000001`00B9`0gooo0?oOW018000000000000B02Lgol00`3o
ool01@3ookl0M000000000000000M;oo0?l0oooo3@3oool00?l0oooo_@3oool0203OW4P000000000
0000B7@0M4P00000000004P0W=oo103oool02@3ooml0W4P0000000000000001d0;ooo`3oool0oooO
09a8000200000004001d_`3oool0oooo0=nLB0<0000000@0M;oo0?ooo`3oool0gia80`000000101d
_ol0oooo0?oo_`1d00020000000607Boo`3oool0oooo0?ooo`3ogi`0B0000P0000001@00B9`0gooo
0?ooo`3oool0_g@000<0000000@0M;oo0?ooo`3oool0gia80P0000000`00B9`0gooo0?ooo`0:0?oo
o`050?oo_`1d000000000000001d_ol02@3oool02@3ooml0W4P0000000000000001d0;ooo`3oool0
oooO09a8000200000008001d_`3oool0oooo0?oOW018000000000000M02oool30?ooo`050?oo_`1d
000000000000001d_ol00P3oool01@3o_g@0000000000000000007Bo0080oooo00<0omnL04P00000
00000P0000001@1d_ol0oooo0?ooo`3ookl0M0000080000000T0M;oo0?ooo`3oool0oooo0?oOW018
000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0?l0oooo3@3oool00?l0oooo
_03oool01P3ooml0W4P0000000000000B9cO0=nLB080000000<0B9cO0?ooo`3oool00P3oool01@3o
gi`0B000000000000000M;oo00P0oooo00D0oooO09a8000000000000001d_`030?ooo`040?oo_`1d
000004RL0=ooo`80oooo00D0oono07@000000000000007Boo`030?ooo`050=nLB000000000000000
M02oool00`3oool01@3ooml0W4P000000000000007Bo0080oooo00D0gia800000000000004RL0=oo
o`0;0?ooo`050?oo_`1d000000000000001d_ol02@3oool01@3ogi`0B000000000000000M;oo00T0
oooo00D0omnL04P000000000001d0;ooo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@2oM000000000000000B9`0gooo00<0oooo00D0okmd000000000000000007Boo`020?ooo`050?oo
_`1d000000000000001d_ol00`3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@0
00000000000007Boo`3o0?ooo`d0oooo003o0?oook`0oooo00H0omnL04P000000000001809cOo`3o
_g@2000000030018W03Oool0oooo0080oooo00D0okmd000000000000001d0;ooo`080?ooo`050?oo
g`2LB000000000000018W=l02@3oool01@3ookl0M000000000000000M;oo00<0oooo00@0_g@00000
0000000007Bo1@3oool01`3OW4P0000000000000B9`0gooo0?ooo`3OW4P00P0000000`00B9`0gooo
0?ooo`0:0?ooo`050?oo_`1d000000000000001d_ol02@3oool01@3o_g@000000000000007@0_ooo
00T0oooo00D0omnL04P000000000001d0;ooo`030?ooo`080?oo_`1d000000000000001d_ol0oooo
0?oog`2LB0020000000304RLg`3oool0oooo0080oooo00D0oono07@000000000000007Boo`020?oo
o`050?oo_`1d000000000000001d_ol00`3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0
oono07@000000000000007Boo`3o0?ooo`d0oooo003o0?oook`0oooo00X0gia8000000000000001d
0;ooo`3ookl0M0000000000004P0W=oo0`3oool00`3o_g@0000000000008000000040000B02Lgol0
oono07@00080000000<0M;oo0?ooo`3oool01`3oool01@3ookl0M000000000000000M;oo0080oooo
00D0oooO09a800000000000004RLg`050?ooo`070?noM000000000000000M02oool0oooo0=nLB002
000000030018W03Oool0oooo00X0oooo00D0oono07@000000000000007Boo`090?ooo`030?noM000
0000000000P0000000P0001809cOo`3oool0omnL04P000000000001809cOo`<0oooo00P0oono07@0
00000000000007Boo`3oool0oooO09a80080000000<0B9cO0?ooo`3oool00P3oool01@3ooml0W4P0
000000000000M;oo0080oooo00D0oono07@000000000000007Boo`030?ooo`050?oOW01800000000
0000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0?l0oooo3@3oool00?l0oooo^`3oool0
1@3ooml0W4P000000000000007Bo0080oooo00@0_g@0000000000000B9cO0`3oool00`3o_g@00000
00000008000000040000M02oool0oooO09a80080000000<0M;oo0?ooo`3oool01`3oool01@3ookl0
M000000000000000M;oo0080oooo00D0oooO09a8000000000000001d_`050?ooo`070=nLB0000000
00000018W03Oool0oooo0=nLB002000000030018W03Oool0oooo00X0oooo00D0oono07@000000000
000007Boo`090?ooo`030?noM0000000000000P0000000P0001d0;ooo`3oool0omnL04P000000000
001809cOo`<0oooo00P0oono07@000000000000007Boo`3oool0oooO09a80080000000<0B9cO0?oo
o`3oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00D0oono07@000000000000007Bo
o`030?ooo`050?oOW018000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0?l0
oooo3@3oool00?l0oooo^`3oool01@3ogi`0B000000000000000M;oo0080oooo00D0okmd00000000
0000001d0;ooo`020?ooo`050?oOW018000000000000B02Lgol00`3oool01`3o_g@0000000000000
B9`0gooo0?oog`2LB0000P0000001`00M;l0oooo0?ooo`3oool0omnL04P00018W=l00`3oool01@3o
okl0M000000000000000M;oo00<0oooo00D0gia8000000000000001d0;ooo`030?ooo`050?oog`2L
B000000000000000M;l00P3oool01@3OW4P000000000000004P0W=oo00/0oooo00D0oono07@00000
0000000007Boo`090?ooo`050?oOW018000000000000B02Lgol00`3oool0203o_g@0000000000000
B9`0gooo0?ooo`3ogi`0B0000P0000001P1d_ol0oooo0?ooo`3oool0omnL04P00080000000@0M;oo
0?ooo`3oool0_g@00P0000000`00B9`0gooo0?ooo`020?ooo`050?oOW018000000000000001d_ol0
0P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P000000000000004RLg`030?oo
o`050?oOW018000000000000001d_ol0o`3oool=0?ooo`00o`3ooonk0?ooo`050=nLB00000000000
0000M02oool00P3oool01@3ookl0M000000000000000M;oo0080oooo00T0oooO09a8000000000000
0018W03Oool0oooo0?oo_`1d00000P0000001000M;l0oooo0?ooo`3OW4P30000000407Boo`3oool0
oooO09a80080000000D0001d0;ooo`3oool0oono07@000020000000607Boo`3oool0oooo0?ooo`3o
gi`0B0000P0000001@00B9`0gooo0?ooo`3oool0_g@000<0000000@0M;oo0?ooo`3oool0gia80`00
00000`00M;l0oooo0?ooo`090?ooo`050?oo_`1d000000000000001d_ol02@3oool02@3ooml0W4P0
00000000000004RL0=ooo`3oool0oono07@0000200000005001d_`3oool0oooo0?oOW01800000P00
00001@0004P0W=oo0?ooo`3oool0_g@000<0000000@0M;oo0?ooo`3oool0okmd0`0000001@00M;l0
oooo0?ooo`3ookl0M00000<0000000D0M;oo0?ooo`3oool0oono07@000020000000607Boo`3oool0
oooo0?ooo`3ogi`0B0000P0000001@0004P0W=oo0?ooo`3oool0_g@00080000000<0001809cOo`3o
ool0o`3oool<0?ooo`00o`3ooonj0?ooo`050?oog`2LB000000000000000M;l0103oool0102oM000
000000000000M;l30?ooo`030?noM0000000000000H0000000H0001809cOo`3oool0oooo0?oo_`1d
000800000003001d_`3oool0_g@000H0000000@007Bo0?ooo`3oool0_g@02@0000001@00M;l0oooo
0?ooo`3oool0gia800H0000000<007Bo0?ooo`3oool01P3oool01@3ookl0M000000000000000M;oo
00X0oooo00<0okmd0000000000001P0000001P0004P0W=oo0?ooo`3oool0omnL04P000T0000000H0
001d0;ooo`3oool0oooo0?oog`2LB00:0000000307Boo`3oool0_g@000H0000000@007Bo0?ooo`3o
gi`0B0002@0000000`0007@0_ooo0?ooo`3o0?ooo``0oooo003o0?oookX0oooo00D0omnL04P00000
0000000004RLg`040?ooo`050=nLB000000000000000M02oool00`3oool00`3OW4P0000000000005
0000000307Boo`3oool0oooo0080oooo00<0omnL04P0000000001@000000100007@0_ooo0?ooo`2o
M00600000005001d_`3oool0oooo0?ooo`2oM0001`0000000`00B9`0gooo0?ooo`020?ooo`040=nL
B0000000000004Q8B0<0000000<0001d0;ooo`3oool01P3oool01@3ookl0M000000000000000M;oo
00/0oooo00<0gia80000000000001@0000002@1d_ol0oooo0?ooo`3oool0omnL04P00000000004Qd
07A800060000000304RLg`3oool0oooo0080oooo00<0omnL04P000000000100000001`00M;l0_g@0
000000000000M;oo0?ooo`2oM0001P0000001`00M;l0oooo0?oOW018000000000000B02LW7@01P00
00000`18W=l0oooo0?ooo`3o0?ooo``0oooo003o0?oookX0oooo00D0gia8000000000000001809cO
o`040?ooo`050?oOW018000000000000001d_ol0103oool00`3ookl0M00000000002000000030018
W03Oool0oooo00H0oooo00<0_g@00000000000000P0000001@18W=l0oooo0?ooo`3oool0_g@000H0
000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B00000000002000000030000B02Lgol0oooo00@0
oooo00D0gia8000000000000B9cO0=nLB002000000030000B02Lgol0oooo00H0oooo00D0oono07@0
00000000000007Boo`0<0?ooo`030?oo_`1d000000000080000000<004RL0=ooo`3oool00`3oool0
1P3ogi`0B00000000000B9`0gooo0?noM0@0000000<0M;oo0?ooo`3oool0103oool00`3ooml0W4P0
000000020000000304RLg`3oool0_g@00080000000<0M;oo0?ooo`2oM0001P0000002@00M;l0oooo
0?oOW018000000000000B02Lgol0oono07@000030000000307Boo`3oool0oooo0?l0oooo3@3oool0
0?l0oooo^@3oool01P3ooml0W4P000000000000004RL0=ooo`@0oooo00D0oooO09a8000000000000
001d_`0L0?ooo`050?oo_`1d000000000000001d_ol08P3oool01@3ookl0M000000000000000M;oo
03D0oooo00D0oono07@000000000000007Boo`030?ooo`050?oOW018000000000000B02Lgol0o`3o
oolE0?ooo`00o`3oooni0?ooo`050?oOW0180000000000000018W=l01P3oool01@3OW4P000000000
000007@0_ooo01/0oooo00D0oono07@000000000000007Boo`0R0?ooo`050?oo_`1d000000000000
001d_ol0=@3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P000000000001809cO
o`3o0?oooaD0oooo003o0?oookT0oooo00D0gia8000000000000001809cOo`060?ooo`050?oOW018
000000000000001d_ol0703oool0103ogi`0B0000000001d_olR0?ooo`050?oo_`1d000000000000
001d_ol0=P3oool0103ogi`0B0000000001d_ol30?ooo`050?oOW018000000000000B02Lgol0o`3o
oolE0?ooo`00o`3ooonh0?ooo`060?oog`2LB000000000000000B9`0gooo1P3oool01@3ooml0W4P0
00000000000007Bo01h0oooo00<0gia807Boo`3oool08@3oool01@3ookl0M000000000000000M;oo
03P0oooo00<0gia807Boo`3oool00P3oool01@3ogi`0B0000000000004P0W=oo0?l0oooo5@3oool0
0?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0oooo
J03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?oo
ool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003B0?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool0P03oool00`3ooml0W4P000000002000000030000M02oool0oooo
00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool0KP3oool01@3ookl0M000000000000000M;oo00H0oooo00<0oooO
09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL
0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo06T0oooo00D0oono
07@000000000000007Boo`060?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3oool01@3o
ool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P00
00000`00B9`0gooo0?ooo`1S0?ooo`030?noM0000000000000P0000000<0001d0;ooo`3oool00P3o
ool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P00
00000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool08`3o
ool00=40oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`1n0?ooo`030?oOW0180000
000000D0000000<0M;oo0?ooo`3oool00P3oool00`3ogi`0B00000000004000000030000B02Lgol0
oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`1]0?ooo`050?oo_`1d0000
00000000001d_ol01@3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0
omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0
001809cOo`3oool0J03oool01@3ookl0M000000000000000M;oo00D0oooo00<0omnL04P000000000
1@0000000`1d_ol0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0
0`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo0680oooo00<0oono07@000000000
200000001P0007@0_ooo0?ooo`3oool0omnL04P000D0000000<0001809cOo`3oool00`3oool00`3o
gi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`00
04P0W=oo0?ooo`0R0?ooo`00d03oool00`3ookl0M00000000006000000030018W03Oool0oooo07`0
oooo00<0oono07@0000000001P0000001P0004P0W=oo0?ooo`3oool0oono07@000L0000000H004RL
0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo06`0oooo00D0oono07@000000000
000007Boo`040?ooo`030?oo_`1d0000000000H0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007
000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`1W0?ooo`050?oo
_`1d000000000000001d_ol0103oool00`3ookl0M00000000006000000060000B02Lgol0oooo0?oo
o`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0
HP3oool00`2oM000000000000007000000050000M02oool0oooo0?oo_`1d00001`0000001P00B9`0
gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000030018
W03Oool0oooo0240oooo003@0?ooo`070?noM000000000000000B02Lgol0oooo0?noM00300000003
07Boo`3oool0oooo07/0oooo00P0gia8000000000000000007Boo`3oool0oono07@00080000000@0
07Bo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?no
M080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1[0?ooo`050?oo_`1d0000
00000000001d_ol0103oool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0
oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P00
0000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo06H0oooo00D0oono07@000000000
000007Boo`040?ooo`080=nLB000000000000000001d_ol0oooo0?oo_`1d000200000004001d_`3o
ool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@20000
00040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0H@3oool01@3ogi`0B00000000000
0000B9cO00P0oooo00L0okmd000000000000001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3o
ool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0
001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0P0?ooo`00d03oool0102oM00000000000
0000M;l30?ooo`040;md00000000000004RLgg`0oooo00D0oooO09a8000000000000001d_`030?oo
o`070?noM000000000000000M02oool0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM000
0P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`18
W=l0oooo0?ooo`1[0?ooo`050?oo_`1d000000000000001d_ol0103oool0102oM000000000000000
M;l30?ooo`040;md00000000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM000
000000000018W=l20?ooo`040;md000000000000001d_`<0oooo00@0_g@0000000000000B9cOJ03o
ool01@3ookl0M000000000000000M;oo00<0oooo00D0oooO09a8000000000000001d_`030?ooo`07
0?noM000000000000000M02oool0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM0000P00
00001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`18W=l0
oooo0?ooo`1R0?ooo`050?noM000000000000000001d_ol01`3oool0102oM000000000000000M;l3
0?ooo`040;md00000000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM0000000
00000018W=l20?ooo`040;md000000000000001d_`<0oooo00@0_g@0000000000000B9cO8P3oool0
0<l0oooo00D0oooO09a800000000000007Boo`030?ooo`050=nLB000000000000018W03Oool0N`3o
ool01@3ookl0M000000000000000M;oo00<0oooo00L0omnL04P000000000001809cOo`3ooml0W4P0
0080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0
M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo06/0oooo00D0oono07@000000000
000007Boo`030?ooo`050?oog`2LB00000000000001d_ol00`3oool01`3OW4P0000000000000B9`0
gooo0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0
W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool0IP3oool01@3o
okl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?oOW018
000000000000B02Lgol0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000
B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?oo
o`1S0?ooo`050=nLB0000000000000000000M;l01@3oool01@3ooml0W4P0000000000000M;oo00<0
oooo00L0gia800000000000004RL0=ooo`3ooml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nL
B002000000040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB00200000003
0018W03Oool0oooo0200oooo003?0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o_g@0
000000000000B9`0gooo08<0oooo00L0omnL04P000000000001809cOo`3ookl0M0000080000000D0
M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000030018W03Oool0oooo06/0oooo00D0oono07@000000000000007Boo`03
0?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@0000000000000B9`0gooo0?oo_`1d
00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P000000
1@1d_ol0oooo0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool0IP3oool01@3ookl0M0000000
00000000M;oo00/0oooo00L0omnL04P000000000001809cOo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030018W03Oool0oooo06@0oooo00H0okmd00000000000000000018W03Oool30?oo
o`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@0000000000000B9`0gooo0?oo_`1d0000
0P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d
_ol0oooo0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool0803oool00<l0oooo00D0oono07@0
00000000000007Boo`030?ooo`050?noM000000000000000M02oool0P`3oool01`3o_g@000000000
000004P0W=oo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;oo
o`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0J`3o
ool01@3ookl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`07
0?noM000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
0000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0
_ooo0?ooo`1V0?ooo`050?oo_`1d000000000000001d_ol02`3oool01`3o_g@000000000000004P0
W=oo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0
M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0I@3oool01P3o
_g@0000000000000000004RL0=ooo`80oooo00D0oono07@000000000000007Boo`030?ooo`070?no
M000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000
100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo
0?ooo`0P0?ooo`00c`3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd000000000000
001d0;ooo`1l0?ooo`080=nLB000000000000018W03Oool0oooo0?oo_`1d0002000000040018W03O
ool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@0
0080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo06/0oooo00D0oono
07@000000000000007Boo`030?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@00000
0000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d
0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0
IP3oool01@3ookl0M000000000000000M;oo00@0oooo00P0gia800000000000004RL0=ooo`3oool0
oono07@00080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080
000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d
0;ooo`3oool0IP3oool01@3o_g@0000000000000000007Bo0080oooo00D0oono07@0000000000000
07Boo`030?ooo`070?noM000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo
0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P0000000`0007@0_ooo0?ooo`0P0?ooo`00c`3oool01@3ookl0M000000000000000M;oo00<0oooo
00D0okmd000000000000001d0;ooo`1l0?ooo`030?noM0000000000000L0000000@0M;oo0?ooo`3o
okl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P00
00001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0J`3oool01@3ookl0M000
000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM00000000000
0000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`1V0?oo
o`050?oo_`1d000000000000001d_ol0103oool00`3o_g@00000000000070000000407Boo`3oool0
oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo06L0oooo00P0okmd0000
00000000000007Boo`3oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM00200000004
0000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0
oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo0200oooo
003?0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o_g@0000000000000B9`0gooo07`0
oooo00<0omnL04P0000000001P0000001@00M;l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030018W03Oool0oooo06L0oooo00H0oono07@0B02Lgol0oooo0?oo_`1d00020000
000607Boo`3oool0oooo0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=oo
o`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool0HP3o
ool01P3ookl0M01809cOo`3oool0oono07@00080000000<0M;oo0?ooo`3oool00P3oool00`3ogi`0
B0000000000600000005001d_`3oool0oooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0
okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00<004RL0=ooo`3oool0J03oool01`2oM000000000000000M;l0oooo0?oo_`1d00000P0000001@1d
_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000<004RL0=ooo`3oool0803oool00<l0oooo00D0oooO09a800000000000007Boo`030?oo
o`050=nLB000000000000018W03Oool0O03oool01@3ooml0W4P00000000004P0B4P000<0000000H0
M;oo0?ooo`3oool0oooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000
B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?oo
o`1W0?ooo`060?oo_`1d000000000018W03Ookl0M0000P0000001P1d_ol0oooo0?ooo`3oool0oooO
09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a800800000
00D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?oo
o`3oool0oooo0=nLB002000000030018W03Oool0oooo0680oooo00H0oono07@00000000004RL0=oo
_`1d00020000000307Boo`3oool0oooo0080oooo00D0oooO09a800000000001804Q8000300000006
07Boo`3oool0oooo0?ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@0
04RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3o
ool0H03oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3o
oml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080
000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo
0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo0200oooo003@0?ooo`040;md00000000
0000001d_`<0oooo00@0_g@000000000000007BoOP3oool0102oM00000000000001d_ol80?ooo`04
0;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000
M;l30?ooo`040;md000000000000001d_fT0oooo00<0oono07@0000000001@0000000`1d_ol0oooo
0?ooo`020?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102o
M000000000000000M;l30?ooo`040;md000000000000001d_`80oooo00@0_g@000000000000007Bo
0`3oool0102oM000000000000000M;mT0?ooo`030?oo_`1d0000000000D0000000<0M;oo0?ooo`3o
ool00`3oool0102oM00000000000001d_ol80?ooo`040;md000000000000001d_`<0oooo00@0_g@0
00000000000007Bo0P3oool0102oM000000000000000M;l30?ooo`040;md000000000000001d_f80
oooo00D0oooO09a800000000000004RLg`030?ooo`070?noM000000000000000M02oool0oooo0;md
000200000005001d_`3oool0oooo0?ooo`2oM0000P0000001000M;l0oooo0?ooo`2oM00200000005
001d_`3oool0oooo0?ooo`2oM0000P0000001000M;l0oooo0?ooo`2oM00200000005001d_`3oool0
oooo0?ooo`2oM0000P0000000`00M;l0oooo0?ooo`0P0?ooo`00d03oool01`3o_g@0000000000000
04P0W=oo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`1l0?ooo`040=nLB00000000000001d_`P0
oooo00L0okmd000000000000001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3oool0okmd0P00
0000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo06P0oooo00<0oooO09a800000000
100000000`1d_ol0oooo0?ooo`020?ooo`070?noM000000000000000B02Lgol0oooo0?noM0030000
000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?oo
o`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0H`3oool00`3ooml0
W4P0000000040000000307Boo`3oool0oooo00<0oooo00@0gia800000000000007Bo203oool01`3o
_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@2000000040000
B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0H@3oool0202oM00000000000000004P0W=oo
0?ooo`3ookl0M0000P0000001000B9`0gooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0
000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0
oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0P0?ooo`00d03o
ool00`3ookl0M00000000006000000030018W03Oool0oooo07d0oooo00<0omnL04P0000000001P00
00001@18W=l0oooo0?ooo`3ookl0M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d00070000
00030018W03Oool0oooo06/0oooo00<0okmd0000000000000P0000000`1d_ol0oooo0?ooo`020?oo
o`030?oo_`1d0000000000H0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018W03O
ool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`1V0?ooo`030?noM000000000000080
000000<0M;oo0?ooo`3oool00`3oool00`3ogi`0B000000000060000000504RLg`3oool0oooo0?oo
_`1d00001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0HP3o
ool00`3ogi`0B000000000070000000504RLg`3oool0oooo0?oo_`1d00001`0000001P00B9`0gooo
0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000030018W03O
ool0oooo0240oooo003A0?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0OP3oool0
0`3ookl0M000000000060000000604RLg`3oool0oooo0?ooo`3ogi`0B0001@0000000`0004P0W=oo
0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0K@3oool01@3ogi`0B000
000000000000M;oo00D0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`03
0?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B0000000000400000003
0000B02Lgol0oooo06P0oooo00D0omnL04P000000000000007Boo`050?ooo`030?oo_`1d00000000
00H0000000H0B9cO0?ooo`3oool0oooo0?oOW0180005000000030000B02Lgol0oooo00<0oooo00<0
omnL04P000000000100000000`0004P0W=oo0?ooo`1T0?ooo`030=nLB0000000000000D0000000<0
07Bo0?ooo`3oool00P3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0
omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0
001809cOo`3oool08P3oool00=80oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`1o
0?ooo`030?oog`2LB000000000H0000000<0B9cO0?ooo`3oool00P3oool00`3ooml0W4P000000002
000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`1_
0?ooo`040=nLB0000000000007Boo`H0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?oo
o`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P00000
0002000000030018W03Oool0oooo06X0oooo00@0gia8000000000000M;oo1@3oool00`3ooml0W4P0
000000060000000304RLg`3oool0oooo0080oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0IP3oool00`3ookl0M000
000000030000000307Boo`3oool0oooo00@0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo02<0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0oooo
o`3ooomX0?ooo`00aP3ooooo00000?l00000Q`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K
0?ooo`8000006P3oool00<H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool2000001X0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01P0oooo002a0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`00/03oool00`3ogi`0B00000000004000000030000B02L
gol0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00:l0oooo00<0oono07@0000000001P000000
0`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002_0?ooo`070?noM00000000000
0000B02Lgol0oooo0?noM0030000000307Boo`3oool0oooo00X0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603o
ool00:l0oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=l<0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo002^0?ooo`050?oog`2LB00000000000001d_ol00`3oool01@3OW4P00000
00000000B9`0gooo00/0oooo1@00003o07moOol0OgmoO@1oOgl5000001X0oooo002^0?ooo`050?oo
_`1d000000000000001d_ol00`3oool01@3o_g@0000000000000B9`0gooo00/0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool00:h0oooo00D0oono07@000000000000007Boo`030?ooo`050?noM00000000000
0000M02oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00[P3oool01@3ookl0M000000000000000
M;oo00<0oooo00D0okmd000000000000001d0;ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002^
0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o_g@000000000000007@0_ooo00/0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00:h0oooo00D0oono07@000000000000007Boo`030?ooo`050?no
M000000000000018W03Oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00[P3oool01@3ooml0W4P0
000000000000M;oo00<0oooo00D0gia800000000000004RL0=ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo002_0?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo303oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00[`3oool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`00
00000`1d_ol0oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002_0?ooo`030?oo_`1d0000
000000H0000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00/03oool00`3o
gi`0B00000000004000000030000B02Lgol0oooo00`0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00;40
oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0=0?ooo`<00000303oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00000J0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240ooooo`3<
I/co0<aVc4D0c6K<3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0240ooooo`3<I/co0<aVc4D0c6K<3P3oool00`000000oooo0?ooo`0H
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool3000000`0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`<000006P3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool06P3oool3000001X0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L
0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`03
0000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00
000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00UP3o
ool00`3ooml0W4P000000002000000030000M02oool0oooo00D0oooo00<0oooO09a8000000000P00
00000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool03P3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02T0oooo0P3oIVIX0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool009D0oooo00<0omnL04P0000000001@000000
0`1d_ol0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0Z0?ooo`80ofIVI`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo002D0?ooo`030?oo_`1d0000000000H0000000H0001809cOo`3oool0oooo0?oo_`1d
0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0:P3oool20?mVIVL0oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`00U03oool0203OW4P00000000000000000M;oo0?oo
o`3ookl0M0000P0000001000M;l0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<00000
00@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Z0?ooo`80ofIVI`3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002C0?ooo`050?oog`2LB00000000000
0000M;l00`3oool01`3o_g@000000000000007@0_ooo0?ooo`2oM0000P0000001@00M;l0oooo0?oo
o`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P0000001@00M;l0oooo0?ooo`3oool0_g@0
0080000000<0B9cO0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
02X0oooo0P3oIVIW0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool009<0
oooo00D0oono07@000000000000007Boo`030?ooo`070?oOW018000000000000B02Lgol0oooO09a8
00020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB00200000005
07Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000=`1oOgl20?mV
I_l0Ogmoo`1oOgm407moO`D000006P3oool009/0oooo00L0omnL04P000000000001809cOo`3ookl0
M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0[0?ooo`80ofIVIP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`03
0000003oool0oooo01P0oooo002K0?ooo`070?noM000000000000000B02Lgol0oono07@000020000
000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3o
ool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0:`3oool20?mVIVH0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00U03oool0203OW4P0000000000000B9`0gooo0?ooo`3ookl0M0000P0000001000
B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0:`3oool20?mVIVH0oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`00U03oool00`3o_g@00000000000070000000407Bo
o`3oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0[0?ooo`80ofIVIP3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0L0?ooo`030000003oool0oooo01P0oooo002D0?ooo`030?oOW0180000000000H0000000D007Bo
0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0:`3oool20?mVIVH0oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00U03oool01@3ooml0W4P00000000004P0B4P0
00<0000000H0M;oo0?ooo`3oool0oooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P0
0P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00
B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0;03oool20?mV
IVD0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00U@3oool0102oM000
00000000001d_ol80?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3o
ool0102oM000000000000000M;l30?ooo`040;md000000000000001d_`d0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0/0?ooo`80ofIVI@3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`03
0000003oool0oooo01P0oooo002E0?ooo`040=nLB00000000000001d_`P0oooo00L0okmd00000000
0000001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?oo
o`3o_g@30000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0/0?ooo`80ofIVI@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
002E0?ooo`030?oOW0180000000000H0000000D0B9cO0?ooo`3oool0oono07@00007000000060018
W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0;03oool20?mVIVD0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`00
0000oooo0?ooo`0H0?ooo`00U@3oool00`3ookl0M000000000060000000604RLg`3oool0oooo0?oo
o`3ogi`0B0001@0000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<00018
09cOo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02`0oooo0P3oIVIU
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool009D0oooo00<0oooO09a8
000000001P0000000`18W=l0oooo0?ooo`020?ooo`030?oog`2LB00000000080000000<004RL0=oo
o`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo0`00000<0?oo
o`0307moO`3oool0oooo02`0oooo0P3oIVIU0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00000J0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02d0oooo0P3oIVIT0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0]0?ooo`80ofIVI03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0;@3o
ool20?mVIV@0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02d0oooo0P3oIVIT0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0]0?ooo`80ofIVI03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0;P3oool20?mVIV<0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo02h0oooo0P3oIVIS0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0^0?ooo`80ofIVH`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0;P3oool20?mVIV<0oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo02h0oooo0P3oIVIS0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo02l0oooo0P3oIVIR0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01X0oooo0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo02l0oooo0P3oIVIR0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0
TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0
603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0_0?ooo`80ofIVHP3o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0;`3oool20?mVIV80oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
02l0oooo0P3oIVIR0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0_0?ooo`80ofIVHP3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0<03oool20?mVIV40oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0300oooo0P3o
IVIQ0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0`0?ooo`80ofIVH@3oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L
0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0<03oool20?mVIV40oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?oo
o`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3oool0<03oool20?mVIV40oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool06P3oool3000001X0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
<@3oool20?mVIV00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0340oooo0P3oIVIP0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0a0?ooo`80ofIVH03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<@3oool20?mV
IV00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0340oooo0P3oIVIP0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0b0?ooo`80ofIVG`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<P3oool20?mVIUl0oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0380oooo0P3oIVIO0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0b0?oo
o`80ofIVG`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<P3oool20?mVIUl0oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3oool0
<P3oool20?mVIUl0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool3000001X0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<`3oool20?mVIUh0oooo00<0Ogmo0?ooo`3oool0TP3o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703o
ool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo03<0oooo0P3oIVIN0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0c0?ooo`80ofIVGP3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0<`3oool20?mVIUh0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000
oooo0?ooo`0H0?ooo`00R`3oool01@3ookl0M000000000000000M;oo00H0oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3o
ool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0c0?ooo`80ofIVGP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`03
0000003oool0oooo01P0oooo002;0?ooo`050?oo_`1d000000000000001d_ol01@3oool00`3ogi`0
B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03@0oooo0P3oIVIM0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool008/0oooo00D0oono07@000000000000007Boo`040?ooo`03
0?oo_`1d0000000000H0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018W03Oool0
oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0=03oool20?mVIUd0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00R`3oool01@3ookl0M000000000000000M;oo00@0oooo00L0okmd000000000000
001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o
_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=03oool20?mVIUd0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00R`3oool01@3ookl0M000
000000000000M;oo00@0oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=l2
0?ooo`040;md000000000000001d_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM0000000
00000000M;l30?ooo`040;md00000000000004RLg`d0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0d0?ooo`80ofIVG@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo002;0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ooml0W4P0000000000000
M;oo00<0oooo00L0gia800000000000004RL0=ooo`3ooml0W4P00080000000D0M;oo0?ooo`3oool0
oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002
000000030018W03Oool0oooo00/0oooo1@00001107moO`80ofIVo`1oOgoo07moOcX0Ogmo1@00000J
0?ooo`00R`3oool01@3ookl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Bo
o`030?ooo`070?noM000000000000018W03Oool0oono07@000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=@3o
ool20?mVIU`0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00R`3oool0
1@3ookl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?no
M000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000
100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=@3oool20?mVIU`0oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?ooo`3oool0603oool008/0oooo00D0
oono07@000000000000007Boo`030?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@0
00000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0
001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03D0oooo0P3oIVIL0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo00X0oooo0`1Vc6H?0?ooo`030000003oool0oooo01P0oooo002;0?ooo`050?oo
_`1d000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd0000
00000000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000
M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0e0?ooo`80ofIVG03oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000oooo0?ooo`0H0?ooo`00Q`3oool01P3ookl0
M01809cOo`3oool0oono07@00080000000H0M;oo0?ooo`3oool0oooo0?oo_`1d00020000000507Bo
o`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo
0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
=@3oool20?mVIU`0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?ooo`3oool0
603oool008L0oooo00H0oono07@00000000004RL0=oo_`1d00020000000607Boo`3oool0oooo0?oo
o`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P0
0P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d
_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo03D0oooo0P3oIVIL0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H?
0?ooo`030000003oool0oooo01P0oooo00270?ooo`030?oo_`1d0000000000D0000000<0M;oo0?oo
o`3oool00P3oool0102oM000000000000000M;l30?ooo`040;md000000000000001d_`80oooo00@0
_g@000000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`040;md000000000000001d
_`<0oooo00@0_g@000000000000007Bo3@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo03H0oooo0P3oIVIK0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H?0?ooo`030000003oool0
oooo01P0oooo00280?ooo`030?oog`2LB000000000@0000000<0M;oo0?ooo`3oool00P3oool01`3o
_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@2000000040000
B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@3
0000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0f
0?ooo`80ofIVF`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000oooo0?ooo`0H
0?ooo`00RP3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0080oooo00<0oono07@0
000000001P0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo
0?oo_`1d0007000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0f0?ooo`80ofIVF`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000
oooo0?ooo`0H0?ooo`00R`3oool01@3ogi`0B000000000000000M;oo00D0oooo00<0omnL04P00000
0000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3o
ool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0f0?ooo`80ofIVF`3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0
I/aV3`3oool00`000000oooo0?ooo`0H0?ooo`00S03oool0103OW4P000000000001d_ol60?ooo`03
0?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P00000000200000003
0018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`<0
0000303oool00`1oOgl0oooo0?ooo`0f0?ooo`80ofIVF`3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0
I/aV3@3oool3000001X0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
=`3oool20?mVIUX0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?ooo`3oool0
603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0g0?ooo`80ofIV4P3o
ool00`3oIVH0oooo0?ooo`150?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H?0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=`3oool2
0?mVIQ80oooo00<0ofIV0?ooo`3oool0A@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool0
0`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
03L0oooo0P3oIVHB0?ooo`030?mVIP3oool0oooo04D0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<
IPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0g0?ooo`80ofIV4@3oool30?mVITH0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0
oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0h0?ooo`80ofIV403oool30?mVITH0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0h0?ooo`80ofIV403oool30?mVITH0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<0
00000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0h
0?ooo`80ofIV403oool40?mVITD0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<00000
0?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0h0?oo
o`80ofIV403oool40?mVITD0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?oo
o`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0h0?ooo`80
ofIV403oool50?mVIT@0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?ooo`3o
ool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo03P0oooo0P3oIVH@0?ooo`80ofIV
00<0oooo0?mVIP3oIVH0A03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3@3oool3000001X0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>@3oool20?mVIPl0oooo0P3o
IVH00`3oool0ofIV0?mVIP140?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool00`3o
ool306K<IX`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3o
ool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo03T0oooo0P3oIVH?0?ooo`80ofIV00@0oooo0?mVIP3oIVH0ofIV@`3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool02P3oool306K<IPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0i0?ooo`80ofIV3`3oool20?mVIP80oooo0P3oIVI3
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool00`3oool306K<IX`0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000oooo0?ooo`0H
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03T0oooo0P3oIVH?0?oo
o`80ofIV0P3oool20?mVIT<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?oo
o`<0I/aVS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H?0?oo
o`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0>@3oool20?mVIPl0oooo0P3oIVH20?ooo`<0ofIV@P3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool02P3oool306K<IPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0j0?ooo`80ofIV3P3oool20?mVIP<0oooo0P3oIVI20?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool00`3oool306K<IX`0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03X0oooo0P3oIVH>0?ooo`80ofIV0`3o
ool30?mVIT40oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?ooo`<0I/aVS03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H?0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>P3oool2
0?mVIPh0oooo0P3oIVH40?ooo`80ofIV@@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool3
06K<IPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0j0?ooo`80ofIV3P3oool20?mVIP@0oooo0P3oIVI10?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool00`3oool306K<IX`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0:0?ooo`<0I/aV3`3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool3000000`0
oooo00<0Ogmo0?ooo`3oool0>P3oool20?mVIPh0oooo0P3oIVH40?ooo`<0ofIV@03oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool02P3oool406K<IP`0oooo0`00000J0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo03/0oooo0P3oIVH=0?ooo`80ofIV1@3oool20?mVIT00oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?ooo`<0I/aVS03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?ooo`030000003oool0oooo01P0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>`3oool20?mVIPd0oooo0P3o
IVH50?ooo`80ofIV@03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo00<0oooo0`1V
c6J<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406K<IPh0oooo00<0
00000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0k
0?ooo`80ofIV2P3oool00`1Vc6H0oooo0?ooo`020?mVIPD0oooo0`3oIVHo0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool00`3oool306K<IX`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03/0oooo0P3oIVH:0?ooo`0306K<IP3oool0oooo
0080ofIV1P3oool20?mVISl0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?oo
o`<0I/aVS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?oo
o`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0>`3oool20?mVIPX0oooo00<0I/aV0?ooo`3oool00P3oIVH60?ooo`<0ofIV?P3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool02P3oool406K<IPh0oooo00<000000?ooo`3oool0603oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0k0?ooo`80ofIV2P3oool00`1Vc6H0oooo
0?ooo`020?mVIPL0oooo0P3oIVHn0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0
0`3oool306K<IX`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV
3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo03`0oooo0P3oIVH90?ooo`0306K<IP3oool0oooo0080ofIV1`3oool20?mVISh0oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?ooo`<0I/aVS03oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?ooo`030000003oool0oooo01P0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?03oool20?mVIPT0oooo0P1Vc6H0
0`3oool0ofIV0?mVIP070?ooo`<0ofIV?@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo00<0oooo0`1Vc6J<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool4
06K<IPh0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0Z0?ooo`0306K<IP3oool0oooo00l0oooo0P3oIVH90?ooo`80I/aV00<0oooo0?mV
IP3oIVH0203oool20?mVISd0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?oo
o`<0I/aVS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?oo
o`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0:@3oool406K<IPl0oooo0P3oIVH90?ooo`80I/aV00<0oooo0?mVIP3oIVH0203oool20?mVISd0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`030?ooo`@0I/aVR`3oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?ooo`030000003oool0oooo01P0
oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`0Y0?ooo`H0I/aV3@3oool20?mVIPT0oooo
0P1Vc6H00`3oool0ofIV0?mVIP080?ooo`<0ofIV?03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
2P3oool406K<IP`0oooo0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo02T0oooo0P1Vc6H00`3oool0I/aV06K<IP0306K<IP`0oooo0P3oIVH80?ooo`<0I/aV00<0
ofIV06K<IP3oool0203oool20?mVIS`0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`030?ooo`@0I/aVR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101V
c6H>0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0:@3oool206K<IP<0oooo1P1Vc6H90?ooo`80ofIV203oool606K<IPP0oooo0`3oIVHk
0?ooo`0407moO`3oool0oooo06K<IY40oooo00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?oo
o`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02P0oooo0`1Vc6H5
0?ooo`H0I/aV1`3oool20?mVIPP0oooo201Vc6H70?ooo`80ofIV>`3oool0101oOgl0oooo06K<IP1V
c6JA0?ooo`0307moO`3oool0oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool02P3oool406K<IPh0oooo00<000000?ooo`3oool0603oool00<H0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0X0?ooo`80I/aV2@3oool506K<IPD0oooo0P3oIVH8
0?ooo`T0I/aV1P3oool20?mVIS/0oooo00<0Ogmo0?ooo`1Vc6H00P1Vc6J@0?ooo`0307moO`3oool0
oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool4
06K<IPh0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0R0?ooo`80I/aV103oool206K<IP/0oooo1@1Vc6H30?ooo`80ofIV203oool506K<
IP80oooo101Vc6H40?ooo`<0ofIV>P3oool00`1oOgl0oooo06K<IP0206K<IY00oooo00<0Ogmo0?oo
o`3oool00`3oool406K<IX/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?oo
o`@0I/aV3P3oool00`000000oooo0?ooo`0H0?ooo`00R`3oool01@3ookl0M000000000000000M;oo
00H0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`050?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
00h0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`80I/aV0`3oool306K<
IPd0oooo1@1Vc6H20?ooo`80ofIV1`3oool506K<IP<0oooo101Vc6H40?ooo`80ofIV>P3oool00`1o
Ogl0oooo06K<IP0306K<IXl0oooo00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H0?oo
o`00R`3oool01@3ookl0M000000000000000M;oo00D0oooo00<0omnL04P0000000001@0000000`1d
_ol0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3o
gi`0B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0R0?ooo`80I/aV0`3oool206K<IQ00oooo1@1Vc6H20?mVIPL0oooo1@1Vc6H50?oo
o`@0I/aV0P3oool20?mVISX0oooo00H0Ogmo0?ooo`1Vc6H0I/aV0?ooo`1Vc6J?0?ooo`0307moO`3o
ool0oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3o
ool406K<IPh0oooo00<000000?ooo`3oool0603oool008/0oooo00D0oono07@000000000000007Bo
o`040?ooo`030?oo_`1d0000000000H0000000H0001809cOo`3oool0oooo0?oo_`1d000700000006
0018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool206K<IP<0oooo0P1Vc6HB0?ooo`D0I/aV1`3oool5
06K<IPH0oooo101Vc6H0103oool0ofIV0?mVIP3oIVHi0?ooo`0507moO`3oool0I/aV06K<IP3oool0
0P1Vc6J>0?ooo`0307moO`3oool0oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool02P3oool406K<IPh0oooo00<000000?ooo`3oool0603oool008/0oooo00D0
oono07@000000000000007Boo`040?ooo`080=nLB000000000000000001d_ol0oooo0?oo_`1d0002
00000004001d_`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo
0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P1Vc6H30?ooo`80I/aV503oool606K<
IP@0oooo1@1Vc6H80?ooo`<0I/aV00<0oooo0?mVIP3oIVH0>@3oool0101oOgl0oooo06K<IP1Vc6H2
0?ooo`0306K<IP3oool0oooo08`0oooo00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H
0?ooo`00R`3oool01@3ookl0M000000000000000M;oo00<0oooo00D0oooO09a8000000000000001d
_`030?ooo`070?noM000000000000000M02oool0oooo0;md000200000005001d_`3oool0oooo0?oo
o`2oM0000P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P00
00000`18W=l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3o
ool206K<IP80oooo0`1Vc6HE0?ooo`030?mVIP1Vc6H0I/aV00@0I/aV0P3oool406K<IP030?mVIP3o
ool0oooo00L0oooo101Vc6H20?mVISP0oooo00@0Ogmo0?ooo`1Vc6H0I/aV0P3oool206K<IXd0oooo
00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H0?ooo`00R`3oool01@3ookl0M0000000
00000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?oOW018000000000000
B02Lgol0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oo
g`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D0
0000;`1oOgl206K<IP80Ogmo0P1Vc6HF07moO`80ofIV0P1oOgl706K<IP0307moO`1Vc6H0ofIV00X0
Ogmo101Vc6H00`3oIVH0Ogmo07moO`0h07moO`80I/aV0`1oOgl00`1Vc6H0Ogmo07moO`2A07moO`@0
I/aVo`1oOgl_07moO`@0I/aV2P1oOgl5000001X0oooo002;0?ooo`050?oo_`1d000000000000001d
_ol02`3oool01`3ogi`0B0000000000004P0W=oo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080
000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280
oooo0`1Vc6H00`3oool0I/aV06K<IP0G0?ooo`80ofIV0`3oool506K<IP030?ooo`1Vc6H0ofIV00`0
oooo101Vc6Hg0?ooo`0407moO`3oool0I/aV06K<IP<0oooo0P1Vc6J<0?ooo`0307moO`3oool0oooo
00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406K<
IPh0oooo00<000000?ooo`3oool0603oool008/0oooo00D0oono07@000000000000007Boo`0;0?oo
o`070?noM000000000000000B02Lgol0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
07@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08`3oool506K<
IQL0oooo0P3oIVH50?ooo`<0I/aV00<0oooo06K<IP3oIVH03@3oool406K<ISH0oooo00@0Ogmo0?oo
o`1Vc6H0I/aV103oool206K<IX/0oooo00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H
0?ooo`00R`3oool01@3ookl0M000000000000000M;oo00@0oooo00P0gia800000000000004RL0=oo
o`3oool0oono07@00080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0
okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02<0oooo
101Vc6HH0?ooo`80ofIV1`3oool0101Vc6H0oooo06K<IP3oIVH>0?ooo`040?mVIP1Vc6H0I/aV06K<
ISD0oooo00@0Ogmo0?ooo`1Vc6H0I/aV1@3oool00`1Vc6H0oooo0?ooo`290?ooo`0307moO`3oool0
oooo00<0oooo101Vc6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool4
06K<IPh0oooo00<000000?ooo`3oool0603oool008/0oooo00D0oono07@000000000000007Boo`04
0?ooo`030?noM0000000000000L0000000@0M;oo0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
02<0oooo101Vc6HH0?ooo`80ofIV2@3oool20?mVIPh0oooo0P3oIVH406K<IS<0oooo00@0Ogmo0?oo
o`1Vc6H0I/aV1@3oool206K<IXX0oooo00<0Ogmo0?ooo`3oool00`3oool406K<IX/0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0H
0?ooo`00Q`3oool01P3ookl0M01809cOo`3oool0oono07@00080000000<0M;oo0?ooo`3oool00P3o
ool00`3ogi`0B0000000000600000005001d_`3oool0oooo0?oo_`1d00000P0000001@1d_ol0oooo
0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0
okmd0080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo02@0oooo0`1Vc6HH0?ooo`80ofIV2@3oool20?mVIPh0oooo0`3oIVH406K<IS80oooo00@0Ogmo
0?ooo`1Vc6H0I/aV1P3oool00`1Vc6H0oooo0?ooo`280?ooo`0307moO`3oool0oooo00<0oooo101V
c6J;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406K<IPh0oooo00<0
00000?ooo`3oool0603oool008L0oooo00H0oono07@00000000004RL0=oo_`1d00020000000307Bo
o`3oool0oooo0080oooo00D0oooO09a800000000001804Q800030000000607Boo`3oool0oooo0?oo
o`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P0
0P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0`1Vc6HI0?ooo`80ofIV203oool20?mVIPl0
oooo0P3oIVH20?ooo`@0I/aV<03oool0101oOgl0oooo06K<IP1Vc6H60?ooo`80I/aVR@3oool00`1o
Ogl0oooo0?ooo`030?ooo`@0I/aVR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
00X0oooo101Vc6H>0?ooo`030000003oool0oooo01P0oooo00270?ooo`030?oo_`1d0000000000D0
000000<0M;oo0?ooo`3oool00`3oool0102oM00000000000001d_ol80?ooo`040;md000000000000
001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000M;l30?ooo`040;md
000000000000001d_`d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0U0?ooo`03
06K<IP3oool0oooo01P0oooo0P3oIVH80?ooo`80ofIV3`3oool30?mVIP80oooo101Vc6H_0?ooo`04
07moO`3oool0I/aV06K<IPL0oooo00<0I/aV0?ooo`3oool0Q`3oool00`1oOgl0oooo0?ooo`030?oo
o`D0I/aVRP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101Vc6H>0?oo
o`030000003oool0oooo01P0oooo00280?ooo`030?oog`2LB000000000@0000000<0M;oo0?ooo`3o
ool00`3oool0103OW4P0000000000000M;l80?ooo`070?noM000000000000000B02Lgol0oooo0?no
M0030000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool09@3oool00`1Vc6H0
oooo0?ooo`0H0?ooo`80ofIV203oool20?mVIQ00oooo0P3oIVH40?ooo`@0I/aV3`3ooolB06K<IP`0
oooo00@0Ogmo0?ooo`1Vc6H0I/aV1`3oool206K<IXP0oooo00<0Ogmo0?ooo`3oool00`3oool206K<
IP030?ooo`1Vc6H0I/aV0080I/aVR03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
00X0oooo0P1Vc6H00`3oool0I/aV06K<IP0=0?ooo`030000003oool0oooo01P0oooo002:0?ooo`03
0?noM000000000000080000000<0M;oo0?ooo`3oool00`3oool00`3ogi`0B0000000000600000005
04RLg`3oool0oooo0?oo_`1d00001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<0
04RL0=ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0400oooo0P3o
IVH80?ooo`80ofIV403oool20?mVIPD0oooo9P1Vc6H:0?ooo`0407moO`3oool0I/aV06K<IPP0oooo
00<0I/aV0?ooo`3oool07@3oool00`1Vc6H0oooo0?ooo`1V0?ooo`0307moO`3oool0oooo00<0oooo
0P1Vc6H20?ooo`@0I/aVQ`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo
0P1Vc6H00`3oool0I/aV06K<IP0=0?ooo`030000003oool0oooo01P0oooo002;0?ooo`050?oOW018
000000000000001d_ol01@3oool00`3ookl0M000000000060000000604RLg`3oool0oooo0?ooo`3o
gi`0B0001@0000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cO
o`3oool03@3oool3000000`0oooo00<0Ogmo0?ooo`3oool0@03oool20?mVIPP0oooo0P3oIVH@0?oo
o`<0ofIV1P3oool@06K<IQ40oooo1@1Vc6H80?ooo`0407moO`3oool0I/aV06K<IPP0oooo0P1Vc6HG
0?ooo`/0I/aVI@3oool00`1oOgl0oooo0?ooo`030?ooo`80I/aV103oool406K<IXD0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`80I/aV3P3oool3000001X0oooo002<0?oo
o`040=nLB0000000000007Boo`D0oooo00<0oooO09a8000000001P0000000`18W=l0oooo0?ooo`02
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002
000000030018W03Oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`11
0?ooo`80ofIV1`3oool20?mVIQ40oooo0P3oIVHY0?ooo`D0I/aV1P3oool0101oOgl0oooo06K<IP1V
c6H90?ooo`80I/aV3`3ooolE06K<IV80oooo00@0Ogmo0?ooo`3oool0oooo0`1Vc6H60?ooo`H0I/aV
PP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0P1Vc6H@0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@@3o
ool20?mVIPL0oooo0P3oIVHA0?ooo`80ofIV:`3oool406K<IPD0oooo00@0Ogmo0?ooo`1Vc6H0I/aV
2P3oool00`1Vc6H0oooo0?ooo`060?ooo`h0I/aV2P3oool706K<IUl0oooo00<0Ogmo06K<IP1Vc6H0
101Vc6H80?ooo`L0I/aVO`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00L0oooo
101Vc6H20?mVIPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`110?ooo`80ofIV1`3oool20?mVIQ40oooo0`3oIVH/0?ooo`@0I/aV0`3o
ool0101oOgl0oooo06K<IP1Vc6H:0?oooa00I/aV503oool706K<IU/0oooo1P1Vc6H>0?ooo`H0I/aV
O03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00@0oooo1P1Vc6H30?mVIPl0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`110?ooo`80ofIV1`3oool20?mVIQ80oooo0P3oIVH]0?ooo`D0I/aV00<0oooo07moO`3oool00P1V
c6H;0?ooo`P0I/aV7P3oool706K<IRL0oooo2P1Vc6HU0?ooo`D0I/aV503oool706K<IWP0oooo00<0
Ogmo0?ooo`3oool0T`3oool0101oOgl0oooo0?ooo`3oool606K<IP<0oooo0`3oIVH?0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@@3o
ool20?mVIPL0oooo0P3oIVHB0?ooo`<0ofIV8`3oool00`3oIVH0oooo0?ooo`080?ooo`D0I/aV00<0
oooo06K<IP1Vc6H0=03oool706K<IQl0oooo501Vc6HM0?ooo`H0I/aV00<0Ogmo0?ooo`3oool05P3o
ool706K<IWD0oooo00<0Ogmo0?ooo`3oool01@3oool<06K<IX80oooo00<0Ogmo06K<IP1Vc6H0101V
c6H60?ooo`<0ofIV3`3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0440oooo0P3oIVH70?ooo`80ofIV4`3oool20?mVIR40oooo103oIVH;
0?ooo`H0I/aV=`3oool706K<IQL0oooo2P1Vc6H:0?ooo`X0I/aV5P3oool606K<IP80oooo00<0Ogmo
0?ooo`3oool06P3oool606K<IW80oooo00<0Ogmo06K<IP1Vc6H05@1Vc6Il0?ooo`H0I/aV2@3oool3
0?mVIPl0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`120?ooo`80ofIV1P3oool20?mVIQ<0oooo0P3oIVHP0?ooo`H0ofIV303oool306K<
IS/0oooo1`1Vc6H?0?ooo`X0I/aV503oool:06K<IPl0oooo1@1Vc6H50?ooo`0307moO`3oool0oooo
00@0oooo00<0ofIV0?ooo`3oool05P3oool706K<IVP0oooo3P1Vc6H<0?ooo`P0I/aV:@3oool@06K<
IS`0oooo1P1Vc6H<0?ooo`@0ofIV3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0480oooo0P3oIVH60?ooo`80ofIV4`3oool30?mVIQd0
oooo103oIVH20?ooo`80ofIV303oool00`1oOgl0oooo06K<IP0n0?ooo`L0I/aV1`3oool:06K<IQh0
oooo2P1Vc6H70?ooo`H0I/aV1`3oool00`1oOgl0oooo0?ooo`040?ooo`030?mVIP3oool0oooo01T0
oooo1`1Vc6HB0?oooeX0I/aV5`3oool906K<IQh0oooo801Vc6H_0?ooo`H0I/aV0P3oool00`1oOgl0
oooo0?ooo`0:0?ooo`@0ofIV3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo0480oooo0P3oIVH60?ooo`80ofIV503oool20?mVIQ/0oooo
1@3oIVH40?ooo`80ofIV2`3oool00`1oOgl0oooo0?ooo`110?oooa00I/aV:03oool@06K<IPT0oooo
00<0Ogmo0?ooo`3oool0103oool00`3oIVH0oooo0?ooo`0M0?ooofP0I/aV1P3oool00`1oOgl0oooo
0?ooo`0I0?ooo`T0I/aV503oool<06K<IQ00oooo501Vc6HR0?ooo`H0I/aV1@3oool00`1oOgl0oooo
0?ooo`0:0?ooo`@0ofIV3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo0480oooo0P3oIVH60?ooo`80ofIV503oool20?mVIQX0oooo103o
IVH60?ooo`<0ofIV2P3oool00`1oOgl0oooo0?ooo`140?ooo`P0I/aV<P3oool806K<IP`0oooo00<0
Ogmo0?ooo`3oool0103oool00`3oIVH0oooo0?ooo`0P0?oooa80I/aVF@3oool00`1oOgl0oooo0?oo
o`0N0?ooo`P0I/aV2P3oool<06K<IR00oooo;`1Vc6H80?ooo`0307moO`3oool0oooo00X0oooo103o
IVH>0?ooo`030000003oool0oooo01P0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`12
0?ooo`80ofIV1P3oool20?mVIQ@0oooo0`3oIVHG0?ooo`@0ofIV2@3oool30?mVIPT0oooo00@0Ogmo
0?ooo`3oool0ofIVPP3oool00`1Vc6H0oooo0?ooo`0<0?ooo`0307moO`3oool0oooo00<0oooo0`3o
IVJ<0?ooo`0307moO`3oool0oooo0280oooo501Vc6H`0?ooob80I/aV2`3oool00`1oOgl0oooo0?oo
o`0:0?ooo`@0ofIV303oool3000001X0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool09@3oool00`1VI_l0oooo0?ooo`0K0?ooo`80ofIV1@3oool20?mVIQD0oooo0P3oIVHE
0?ooo`D0ofIV2`3oool30?mVIPP0oooo00@0Ogmo0?ooo`3oool0ofIVT@3oool00`1oOgl0oooo0?oo
o`030?ooo`<0ofIVS03oool00`1oOgl0oooo0?ooo`0V0?ooo`X0I/aVH`3oool0101oOgl0oooo0?oo
o`3oool:0?mVIP80oooo0P3oIVH=0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool306IVoa`0oooo0P3oIVH50?ooo`80ofIV5@3o
ool30?mVIQ<0oooo103oIVH>0?ooo`80ofIV203oool00`1oOgl0oooo0?mVIP020?mVIY00oooo00<0
Ogmo0?ooo`3oool00`3oool30?mVIX`0oooo00<0Ogmo0?ooo`3oool0SP3ooolB0?mVIQ80oooo00<0
00000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T
0?ooo`@0IVKo6`3oool20?mVIPD0oooo0P3oIVHF0?ooo`80ofIV4@3oool40?mVIQ40oooo0P3oIVH7
0?ooo`0307moO`3oool0ofIV0080ofIVT03oool00`1oOgl0oooo0?ooo`030?ooo`<0ofIVM03ooolD
0?mVIP@0oooo00<0Ogmo0?ooo`3oool0Q03ooolC0?mVIQ/0oooo00<000000?ooo`3oool0603oool0
01T0oooo00D0omnL04P000000000001809cOo`020?ooo`050?noM000000000000000001d_ol00P3o
ool01@3ogi`0B0000000000004P0W=oo0080oooo00D0oono07@000000000000007Boo`0:0?ooo`03
0?oo_`1d0000000000X0000000<0M;oo0?ooo`3oool00`3oool00`3ogi`0B0000000000300000003
0000B02Lgol0oooo00D0oooo00D0okmd000000000000001d0;ooo`0>0?ooo`030?noM00000000000
00@0000000<0M;oo0?ooo`3oool0B`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
02@0oooo1@1VI_lJ0?ooo`80ofIV1@3oool20?mVIQH0oooo0P3oIVH?0?ooo`D0ofIV4P3oool30?mV
IPH0oooo00<0Ogmo0?ooo`3oIVH00P3oIVJ@0?ooo`0307moO`3oool0oooo00<0oooo103oIVH30?oo
ob00ofIVAP3ooolX0?mVIV<0oooo:03oIVH50?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool001T0oooo00D0omnL04P000000000001809cOo`020?ooo`050;md000000000000
00000018W=l00P3oool01@3ogi`0B0000000000004P0W=oo0080oooo00D0oono07@0000000000000
07Boo`0:0?ooo`030?oo_`1d0000000000X0000000H0M;oo0?ooo`3oool0oooo0?oo_`1d00080000
00030000M02oool0oooo00<0oooo00D0okmd000000000000001d0;ooo`0<0?ooo`030?oo_`1d0000
000000L0000000<0001809cOo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo02@0oooo0P1VI_l0103oool0IVKo06IVo`1VI_lI0?ooo`80ofIV1@3oool20?mVIQH0oooo0`3o
IVH=0?ooo`@0ofIV5@3oool30?mVIPD0oooo00<0Ogmo0?ooo`3oIVH00`3oIVJ?0?ooo`0307moO`3o
ool0oooo00<0oooo103oIVH00`3oool0ofIV0?mVIP0Z0?mVIS80oooo503oIVHD0?oooa<0ofIV?03o
ooll0?mVIPl0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`006@3oool0
203ogi`0B000000000000000M;oo0?ooo`3ooml0W4P00`0000001000B9`0gooo0?ooo`3o_g@20000
00060000B02Lgol0oooo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?ooo`030?oo_`1d
0000000000X0000000D0M;oo0?ooo`3oool0omnL04P0000:000000030000B02Lgol0oooo0080oooo
00D0okmd000000000000001d0;ooo`0;0?ooo`030?oog`2LB000000000T0000000<0001d0;ooo`3o
ool0B@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l20?ooo`<0
IVKo6@3oool20?mVIP@0oooo0P3oIVHG0?ooo`80ofIV2`3oool40?mVIQP0oooo0`3oIVH40?ooo`03
07moO`3oool0ofIV00<0ofIV2@3ooolU0?mVIV40oooo00<0Ogmo0?ooo`3oool00`3oool80?mVIQl0
oooo503oIVHI0?oooaT0ofIV8P3oool00`1oOgl0oooo0?ooo`030?ooof<0ofIV;@3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo000I0?ooo`080?oOW018000000000000001d
_ol0oooo0?oo_`1d0003000000040000M02oool0oooo0?noM080000000H0001809cOo`3oool0oooo
0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@000000000000007Boo`0:0?oo
o`030?oog`2LB00000000080000000H0001d0;ooo`3oool0oooo0?oog`2LB003000000050018W03O
ool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0:0?ooo`060=nLB0000000000000000000
B9`0gooo0`3oool01@2oM0000000000000000000B9cO04X0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0T0?ooo`80IVKo0`3oool306IVoaP0oooo0P3oIVH40?ooo`80ofIV5`3oool2
0?mVIPT0oooo1@3oIVHJ0?ooo`<0ofIV0`3oool00`1oOgl0oooo0?mVIP0h0?mVIUX0oooo00<0Ogmo
0?ooo`3oool00`3oool60?mVIR/0oooo<P3oIVH/0?ooo`0307moO`3oool0oooo00`0oooo?03oIVI;
0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool001T0oooo00l0omnL04P0
00000000000007Boo`3oool0omnL04P000000000M7Ad0000000004P0W=oo0?ooo`3o_g@00P000000
1P0004P0W=oo0?ooo`3oool0oono07@00080000000<0M;oo0?ooo`3oool0203oool01@3ookl0M000
000000000000M;oo00X0oooo00D0okmd0000000000000000001d_`060?ooo`050;md000000000000
0000001d_ol00P3oool01@3o_g@000000000000007@0_ooo00X0oooo00H0oooO09a8000000000000
0018W03Oool50?ooo`050;md0000000000000018W03Oool0B@3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo02@0oooo0P1VI_l40?ooo`80IVKo603oool20?mVIP@0oooo0P3oIVHG0?oo
o`<0ofIV1`3oool40?mVIQd0oooo0P3oIVH30?ooo`0507moO`3oool0ofIV0?mVIP3oool02P3oIVHU
0?ooo`l0ofIVDP3oool00`1oOgl0oooo0?ooo`030?ooo`80ofIV00<0oooo0?mVIP3oool0=P3ooolI
0?mVIS/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo000I0?ooo`0?0?oOW018000000000000001d_ol0oooo0=nLB0000000001809cO_`1d
0000000004RLg`3oool0okmd0080000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Bo
o`3oool0oooo00P0oooo00D0oono07@000000000000007Boo`0:0?ooo`050;md0000000000000000
M02oool01P3oool01@3ookl0M00000000000000007Bo0080oooo00D0okmd000000000000001d0;oo
o`0:0?ooo`050?oo_`1d000000000000001d_ol01P3oool01@3OW4P0000000000000B9`0gooo04T0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo103oool206IVoaP0
oooo0P3oIVH40?ooo`80ofIV603oool20?mVIPD0oooo103oIVHP0?ooo`80ofIV0P3oool0101oOgl0
oooo0?mVIP3oIVHg0?ooof40ofIVSP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01`0oooo00<000000?ooo`3oool0603oool001T0oooo00l0omnL04P000000000000007Boo`3oool0
_g@000000000B9`0gooO09a80000000007Bo0?ooo`3o_g@00P0000001P0004P0W=oo0?ooo`3oool0
oono07@00080000000<0M;oo0?ooo`3oool0203oool01@3ookl0M000000000000000M;oo00T0oooo
00D0oooO09a8000000000000001d_`080?ooo`070;md0000000000000018W03Oool0oooo0?noM009
000000030018W03Oool0oooo00`0oooo00D0okmd0000000000000000001d_`1:0?ooo`<00000303o
ool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo103oool306IVoaL0oooo0P3oIVH40?ooo`80ofIV603o
ool30?mVIP80oooo1@3oIVHQ0?ooo`<0ofIV00<0oooo07moO`3oool00P3oIVHo0?oooeP0ofIVS`3o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00000J0?ooo`006@3oool0
3`3ogi`0B000000000000000B9cO0?oog`2LB0000000001d_`3oool0_g@000000000B9`0gooo0=nL
B002000000060000B02Lgol0oooo0?ooo`3ookl0M0002@0000001P00B9`0gooo0?ooo`3oool0oono
07@00080000000<0M;oo0?ooo`3oool01`3oool01@3ookl0M000000000000000B9cO00P0oooo00L0
gia8000000000000001d0;ooo`3oool0okmd00/0000000<0M;oo0?ooo`3oool01`3oool00`2oM000
0000000000040000000307Boo`3oool0oooo04P0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0T0?ooo`80IVKo1@3oool206IVoaL0oooo0P3oIVH40?ooo`80ofIV6@3oool20?mVIP03
0?ooo`3oIVH0ofIV0080ofIV903oool30?mVIP0407moO`3oool0ofIV0?mVIY40oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool001T0oooo00l0omnL04P000000000000004RLg`3ookl0M0000000001d_ol0oooo
0?noM0000000001d0;ooo`3OW4P00P0000001P0004P0W=oo0?ooo`3oool0oono07@000T0000000H0
04RL0=ooo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00L0oooo00D0oono07@00000
0000000004RLg`080?ooo`070=nLB000000000000000M02oool0oooo0?noM00;000000030000B02L
gol0oooo00<0oooo00<0oooO09a8000000001`0000000`18W=l0oooo0?ooo`190?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`D0oooo0P1VI_lH0?ooo`80ofIV0`3o
ool20?mVIQT0oooo1@3oIVHW0?ooo`<0ofIV00<0oooo0?mVIP3oIVH0T@3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`006@3oool03`3ogi`0B000000000000000B9cO0?noM0000000001809cOo`3oool0omnL
04P000000000M;oo0=nLB002000000060000B02Lgol0oooo0?ooo`3ookl0M0002@0000001P00B9`0
gooo0?ooo`3oool0oono07@00080000000<0M;oo0?ooo`3oool01`3oool01@3ookl0M00000000000
0000B9cO00P0oooo00L0gia8000000000000001d0;ooo`3oool0okmd0080000000<0001d0;ooo`3o
ool00`3oool01@2oM000000000000000000007Bo00<0oooo00<0okmd0000000000001P0000000`00
04P0W=oo0?ooo`1;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IV
o`D0oooo0`1VI_lG0?ooo`80ofIV0`3oool20?mVIQT0oooo103oIVHY0?ooo`80ofIV00<0oooo0?mV
IP3oIVH0T@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0703oool00`000000oooo0?ooo`0H0?ooo`006@3oool03`3ogi`0B000000000000000B9cO
0=nLB000000004RL0=ooo`3oool0oooO09a800000000B9cO0=nLB002000000060000B02Lgol0oooo
0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?ooo`050?oo_`1d000000000000001d_ol0
2@3oool01@3ooml0W4P000000000000007Bo00P0oooo00L0_g@000000000000004RL0=ooo`3oool0
okmd0080000000<0001d0;ooo`3oool00`3oool02@3ooml0W4P000000000000004RL0=ooo`3oool0
oono07@00005000000030000B02Lgol0oooo04h0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0T0?ooo`80IVKo1P3oool206IVoaL0oooo0P3oIVH30?ooo`80ofIV6P3oool00`3oIVH0
oooo0?ooo`0Z0?ooo`@0ofIVT@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`006@3oool0203ogi`0B000
000000000000B9cO0;md0000000007Bo0`3oool0102oM0000000001d_`3OW4P2000000060000B02L
gol0oooo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?ooo`050?oo_`1d000000000000
001d_ol02P3oool01@2oM00000000000000007@0_ooo00H0oooo00D0oono07@0000000000000001d
_`020?ooo`050?noM000000000000000M02oool01@3oool01`2oM00000000000000007@0_ooo0?oo
o`3o_g@00`0000000`00M;l0oooo0?ooo`1A0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0903oool206IVo`H0oooo0P1VI_lG0?ooo`80ofIV0`3oool20?mVITL0oooo103oIVJA0?oo
o`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?oo
o`030000003oool0oooo01P0oooo000I0?ooo`080?oOW0180000000000000000M7@0M0000000001d
_ol30?ooo`040?noM0000000001d07Ad0080000000H0001809cOo`3oool0oooo0?oo_`1d00020000
000307Boo`3oool0oooo00P0oooo00D0oono07@000000000000007Boo`0:0?ooo`050?noM0000000
000000000000M;l01P3oool01@2oM0000000000000000000M;oo0080oooo00D0okmd000000000000
001d0;ooo`040?ooo`080?oog`2LB000000000000000B9`0gooo0?ooo`3OW4P2000000030018W03O
ool0oooo00<0oooo00D0okmd000000000000001809cOo`1:0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0903oool206IVo`H0oooo0P1VI_lG0?ooo`80ofIV0`3oool20?mVITL0oooo
00<0Ogmo0?mVIP3oIVH0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`006@3oool0203ogi`0B0000000
0000000004Q804P0000004P0W=oo0`3oool0103ogi`0B0000000B018B002000000060000B02Lgol0
oooo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?ooo`050?oo_`1d000000000000001d
_ol02P3oool00`3ooml0W4P000000002000000060018W03Oool0oooo0?ooo`3ooml0W4P00`000000
1@00B9`0gooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool00`3oool01@2oM00000000000
0000000007Bo0080oooo00D0okmd000000000000000007Boo`030?ooo`060?oo_`1d000000000000
000007@0_oooBP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l6
0?ooo`<0IVKo5`3oool20?mVIP80oooo0P3oIVI70?ooo`0307moO`3oool0ofIV0980oooo00<0Ogmo
0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool001T0oooo00<0omnL04P0000000000`0000000`00B9`0gooo0?ooo`020?oo
o`030?oog`2LB000000000<0000000H0001809cOo`3oool0oooo0?oo_`1d000:000000050018W03O
ool0oooo0?oo_`1d00000P0000000`1d_ol0oooo0?ooo`090?ooo`030?oOW0180000000000T00000
00<0001809cOo`3oool00P3oool00`3o_g@000000000000:0000000507Boo`3oool0oooo0?oo_`1d
00002P0000000`18W=l0oooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0903oool206IVo`L0oooo0P1VI_lG0?ooo`80ofIV0P3oool20?mVITL0oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`3ogi`0B0000000000300000003001d
_`3oool0oooo00<0oooo00<0_g@00000000000000P0000001P0004P0W=oo0?ooo`3oool0oono07@0
00X0000000D004RL0=ooo`3oool0oono07@000020000000307Boo`3oool0oooo00X0oooo00<0oono
07@0000000001`0000000`0007@0_ooo0?ooo`030?ooo`030?noM0000000000000T0000000<0B9cO
0?ooo`3oool00P3oool00`3ogi`0B0000000000700000003001d_`3oool0oooo04X0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo1`3oool206IVoaL0oooo0P3oIVH2
0?ooo`80ofIVA`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo000I0?oo
o`030?oOW0180000000000<0000000<0M;oo0?ooo`3oool00`3oool00`3o_g@00000000000020000
00060000B02Lgol0oooo0?ooo`3ookl0M0002P0000001@00B9`0gooo0?ooo`3ookl0M00000800000
00<0M;oo0?ooo`3oool0303oool00`3ogi`0B00000000003000000030000B02Lgol0oooo00D0oooo
00<0okmd0000000000001`0000000`0004P0W=oo0?ooo`060?ooo`030=nLB0000000000000<00000
00<0001d0;ooo`3oool0C03oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo
0P1VI_l70?ooo`<0IVKo5P3oool20?mVIP80oooo0P3oIVI70?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo02@0oooo0P1V
I_l80?ooo`80IVKo5P3oool20?mVIP80oooo0P3oIVI70?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00
000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l8
0?ooo`80IVKo5`3oool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
02@0oooo0P1VI_l80?ooo`<0IVKo5P3oool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo02@0oooo0P1VI_l90?ooo`80IVKo5P3oool20?mVIP030?ooo`3oIVH0ofIV04L0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l90?ooo`80IVKo5P3oool20?mVIP030?oo
o`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l90?ooo`<0IVKo5@3o
ool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00QP3oool00`3o_g@0000000000008000000030000M02oool0oooo0080oooo00<0oooO
09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL
0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo2P3oool206IVoaD0oooo0P3oIVH0
0`3oool0ofIV0?mVIP170?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
08H0oooo00<0oono07@000000000200000001P0007@0_ooo0?ooo`3oool0omnL04P000D0000000<0
001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0
omnL04P000000000100000000`0004P0W=oo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0903oool206IVo`X0oooo0P1VI_lE0?ooo`80ofIV00<0oooo0?mVIP3oIVH0A`3o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00270?ooo`030;md00000000
000000L0000000D0001d0;ooo`3oool0oono07@00007000000060018W03Oool0oooo0?ooo`3ookl0
M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l:0?ooo`<0IVKo503oool2
0?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H
0?ooo`00Q`3oool01@3ogi`0B000000000000000B9cO00P0oooo00L0okmd000000000000001809cO
o`3oool0okmd00<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000
000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?oo
o`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`/0oooo0P1V
I_lD0?ooo`80ofIV00<0oooo0?mVIP3oIVH0A`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003o
ool0oooo01P0oooo00280?ooo`050?noM000000000000000001d_ol01`3oool0102oM00000000000
0000M;l30?ooo`040;md00000000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102o
M000000000000018W=l20?ooo`040;md000000000000001d_`<0oooo00@0_g@0000000000000B9cO
3@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l;0?ooo`80IVKo
503oool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00R@3oool01@3OW4P0000000000000000007Bo00D0oooo00D0oooO09a800000000
000007Boo`030?ooo`070=nLB000000000000018W03Oool0oooO09a800020000000507Boo`3oool0
oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3O
W4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000<@1oOgl206IVo`/0Ogmo0P1VI_lD07moO`80
ofIV00<0Ogmo0?mVIP3oIVH0o`1oOgoo07moOb@0Ogmo1@00000J0?ooo`00RP3oool01P3o_g@00000
00000000000004RL0=ooo`<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM0000000
00000018W03Oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0
gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`/0oooo0`1VI_lC
0?ooo`80ofIV00<0oooo0?mVIP3oIVH0A`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo002;0?ooo`060?noM0000000000000000000B9`0gooo0P3oool01@3ookl0M0000000
00000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0T0?ooo`80IVKo303oool206IVoa<0oooo0P3oIVH00`3oool0ofIV0?mVIP170?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool008`0oooo00D0okmd0000000000000000
001d_`020?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@000000000000007@0_ooo
0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M000
0P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l<0?ooo`80IVKo4`3oool20?mVIP03
0?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00
S@3oool0203o_g@00000000000000000M;oo0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080
000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d
0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_l<
0?ooo`<0IVKo4P3oool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00SP3oool01`2oM000000000000000M;l0oooo0?oo_`1d00000P00
00001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0
oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo02@0oooo0P1VI_l=0?ooo`80IVKo4P3oool20?mVIP030?ooo`3oIVH0ofIV04L0oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00QP3oool01@3ookl0M00000000000
0000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ooml0W4P00080000000D0M;oo0?ooo`3o
ool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nL
B002000000040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB00200000003
0018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80
IVKo3@3oool206IVoa80oooo0P3oIVH00`3oool0ofIV0?mVIP170?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool008H0oooo00D0oooO09a800000000000004RLg`030?ooo`07
0?noM000000000000000M02oool0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM0000P00
00001000M;l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000001000M;l0
oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`00M;l0oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`d0oooo0`1VI_lA
0?ooo`80ofIV00<0oooo0?mVIP3oIVH0A`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo00270?ooo`080;md0000000000000000B02Lgol0oooo0?oo_`1d0002000000040018
W03Oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2
000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo
0?ooo`3o_g@30000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0T0?ooo`80IVKo3P3oool206IVoa40oooo0P3oIVH00`3oool0ofIV0?mVIP170?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool008L0oooo00<0omnL04P000000000
1`0000001@18W=l0oooo0?ooo`3ookl0M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007
000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`h0oooo0P1VI_lA0?ooo`80ofIV
00<0oooo0?mVIP3oIVH0A`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
00280?ooo`030=nLB0000000000000D0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B0000000
0004000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?oo
o`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool3000000`0oooo00<0
Ogmo0?ooo`3oool0903oool206IVo`h0oooo0`1VI_l@0?ooo`@0ofIVB03oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0J0?ooo`<000006P3oool008T0oooo00<0oono07@0000000000`0000000`1d_ol0oooo0?ooo`04
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002
000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`l0oooo0P1VI_l@
0?ooo`@0ofIVB03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`l0oooo0P1VI_l@0?oo
o`80ofIVBP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool206IVo`l0oooo0`1VI_mK0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo403oool206IVoe/0oooo00<0Ogmo0?ooo`3oool0
TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo02@0oooo0P1VI_l@0?ooo`80IVKoF`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool2
06IVoa00oooo0P1VI_mK0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo403oool306IV
oeX0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_lA0?ooo`80IVKoFP3oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0903oool206IVoa40oooo0P1VI_mJ0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0T0?ooo`80IVKo4@3oool306IVoeT0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3oool0903oool206IVoa80oooo0P1VI_mI
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01X0oooo0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo02@0oooo0P1VI_lB0?ooo`80IVKoF@3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?oo
o`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0903oool206IVoa80oooo0`1VI_mH0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T0?ooo`80IVKo
4`3oool206IVoeP0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo0P1VI_lC0?ooo`80IVKoF03o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool08`3oool206IVoa@0oooo0`1VI_mG0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0S0?ooo`80IVKo5@3oool206IVoeL0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`00
0000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02<0
oooo0P1VI_lE0?ooo`80IVKoE`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08`3oool206IVoaD0oooo
0`1VI_mF0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo5P3oool206IVoeH0oooo00<0
Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lF0?ooo`80IVKoEP3oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L
0?ooo`030000003oool0oooo01P0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`0R0?oo
o`<0IVKo5P3oool206IVoeH0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool3000001X0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IVoaH0oooo0`1VI_mE0?ooo`03
07moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo5`3oool206IVoeD0oooo00<0Ogmo0?ooo`3oool0
TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo0280oooo0`1VI_lG0?ooo`80IVKoE@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool3
06IVoaL0oooo0`1VI_mD0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo603oool206IV
oe@0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lH0?ooo`80IVKoE03oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool08P3oool306IVoaP0oooo0`1VI_mC0?ooo`0307moO`3oool0oooo0980oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0R0?ooo`<0IVKo6@3oool206IVoe<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lI
0?ooo`80IVKoD`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?oo
o`<00000303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo6@3oool306IVoe80oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool06P3oool3000001X0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool08P3oool306IVoaX0oooo0P1VI_mB0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo
6P3oool206IVoe80oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lJ0?ooo`<0IVKoD@3o
ool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IVoa/0oooo0P1VI_mA0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0R0?ooo`<0IVKo6`3oool206IVoe40oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`00
0000oooo0?ooo`0H0?ooo`00QP3oool00`3o_g@0000000000008000000030000M02oool0oooo0080
oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`050?ooo`030?oog`2LB00000000080
000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo6`3oool206IVoe40
oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00260?ooo`030?oo
_`1d0000000000P0000000H0001d0;ooo`3oool0oooo0?oOW01800060000000307Boo`3oool0oooo
0080oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW01800000000
00@0000000<0001809cOo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
0280oooo0`1VI_lK0?ooo`<0IVKoD03oool00`1oOgl0oooo06IVo`0206IVoi00oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool008L0oooo00<0_g@00000000000001`0000001@0007@0_ooo0?ooo`3ookl0M000
00L0000000H0001809cOo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0
M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool08P3oool306IVoa`0oooo0P1VI_m@0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0
oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000
oooo0?ooo`0H0?ooo`00Q`3oool01@3ogi`0B000000000000000B9cO00P0oooo00P0gia800000000
0000000007Boo`3oool0oono07@00080000000@007Bo0?ooo`3oool0okmd0P000000100004P0W=oo
0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000
0`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool3
06IVoa`0oooo0P1VI_m@0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H
0?ooo`00R03oool01@3o_g@00000000000000000M;oo00H0oooo00D0oooO09a8000000000000001d
_`030?ooo`070?noM000000000000000M02oool0oooo0;md000200000005001d_`3oool0oooo0?oo
o`2oM0000P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P00
00000`18W=l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3o
ool306IVoa`0oooo0`1VI_m?0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00R@3oool01@3OW4P0000000000000000007Bo00D0oooo00D0oono07@0000000000000
07Boo`030?ooo`070?oOW018000000000000B02Lgol0oooO09a800020000000507Boo`3oool0oooo
0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P0
0P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000;`1oOgl306IVoad0Ogmo0P1VI_mA07moO`<0IVKo
o`1oOgoG07moO`D000006P3oool008X0oooo00H0okmd00000000000000000018W03Oool;0?ooo`07
0?oOW018000000000000B02Lgol0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0
gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IVoad0
oooo0P1VI_m?0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00
R`3oool01P3o_g@0000000000000000004RL0=ooo`X0oooo00L0okmd000000000000001809cOo`3o
okl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo7@3oool306IVodh0oooo00<0Ogmo0?oo
o`1VI_l00P1VI_n@0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002<0?ooo`050?noM000000000000000
0000M;l00`3oool0203OW4P0000000000000B9`0gooo0?ooo`3ookl0M0000P0000001000B9`0gooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IVoah0oooo0P1VI_m>0?ooo`0307moO`3o
ool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00S@3oool01@3o_g@0000000000000
0000M;oo0080oooo00<0okmd0000000000001`000000101d_ol0oooo0?oo_`1d00020000000507Bo
o`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo
0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool08P3oool306IVoah0oooo0P1VI_m>0?ooo`0307moO`3oool0IVKo0080IVKoT03oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool0
0`000000oooo0?ooo`0H0?ooo`00SP3oool0102oM000000000000000M;l20?ooo`030?oOW0180000
000000H0000000D007Bo0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IV
oah0oooo0`1VI_m=0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?oo
o`00QP3oool01@3ookl0M000000000000000M;oo00<0oooo00/0okmd000000000000001d0;ooo`3o
ool0oooO09a800000000001804Q800030000000607Boo`3oool0oooo0?ooo`3ooml0W4P00P000000
1@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo
0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo0280oooo0`1VI_lO0?ooo`80IVKoC@3oool00`1oOgl0oooo06IVo`0206IVoi00
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool008H0oooo00D0oooO09a800000000000004RLg`030?ooo`05
0?noM000000000000000M02oool00P3oool0102oM00000000000001d_ol80?ooo`040;md00000000
0000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000M;l30?ooo`04
0;md000000000000001d_`d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?oo
o`<0IVKo7`3oool206IVodd0oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo
01P0oooo00270?ooo`080;md0000000000000000B02Lgol0oooo0?oo_`1d0002000000050018W03O
ool0oooo0?ooo`3OW4P00P0000000`00M;l0oooo0?ooo`060?ooo`070?noM000000000000000B02L
gol0oooo0?noM0030000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`00
00000`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3o
ool306IVoal0oooo0`1VI_m<0?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00Q`3oool00`3ogi`0B000000000070000000604RLg`3oool0oooo0?ooo`3ogi`0B000
1`0000001@18W=l0oooo0?ooo`3ookl0M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007
000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R
0?ooo`<0IVKo803oool206IVod`0oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo00280?ooo`030=nLB0000000000000D0000000<007Bo0?ooo`3oool00P3oool00`3o
okl0M000000000060000000604RLg`3oool0oooo0?ooo`3ogi`0B0001@0000000`0004P0W=oo0?oo
o`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lP0?ooo`80IVKoC03oool00`1oOgl0oooo06IV
o`0206IVoi00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool008T0oooo00<0oono07@0000000000`000000
0`1d_ol0oooo0?ooo`030?ooo`030?oog`2LB000000000H0000000<0B9cO0?ooo`3oool00P3oool0
0`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P000000
0`00B9`0gooo0?ooo`0>0?ooo`<00000303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo803oool2
06IVod`0oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`<000006P3oool00<H0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo803oool306IVo`80oooo00<0IVKo0?oo
o`3oool0AP3oool00`1oOgl0oooo06IVo`0206IVoi00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo8@3oool206IVo`80
oooo00<0IVKo0?ooo`3oool0AP3oool00`1oOgl0oooo06IVo`0206IVoi00oooo00<0Ogmo0?ooo`3o
ool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo
8@3oool206IVo`80oooo00<0IVKo0?ooo`3oool0AP3oool00`1oOgl0oooo06IVo`0206IVoi00oooo
00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0R0?ooo`<0IVKo8@3oool506IVodP0oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3o
ool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003o
ool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool3
06IVob80oooo1@1VI_m70?ooo`0307moO`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lR0?oo
o`D0IVKoA`3oool00`1oOgl0oooo06IVo`0206IVoi00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0IVKo8P3oool506IVodL0
oooo00<0Ogmo0?ooo`1VI_l00P1VI_n@0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IVob80oooo1@1VI_m70?ooo`0307mo
O`3oool0IVKo0080IVKoT03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lR0?ooo`D0IVKoA`3oool00`1oOgl0oooo06IV
o`0206IVoi00oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0
oooo0280oooo0`1VI_lR0?ooo`80IVKo00<0oooo06IVo`1VI_l0A`3oool00`1oOgl0oooo06IVo`03
06IVohl0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01X0oooo0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
0280oooo0`1VI_lR0?ooo`80IVKo00<0oooo06IVo`1VI_l0A`3oool00`1oOgl0oooo06IVo`0306IV
ohl0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0R0?ooo`<0IVKo8P3oool00`1VI_l0oooo0?ooo`0206IVodL0oooo00<0Ogmo0?ooo`1V
I_l00`1VI_n?0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool08P3oool306IVob80oooo00<0IVKo0?ooo`3oool00P1VI_m70?ooo`0307mo
O`3oool0IVKo00<0IVKoS`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lR0?ooo`0306IVo`3oool0oooo0080IVKo6P3o
ool00`1VI_l0oooo0?ooo`0Z0?ooo`0307moO`3oool0IVKo00<0IVKoS`3oool00`1oOgl0oooo0?oo
o`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1VI_lU
0?ooo`80IVKo603oool506IVobX0oooo00<0Ogmo0?ooo`1VI_l00`1VI_n?0?ooo`0307moO`3oool0
oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306IV
obD0oooo0P1VI_lE0?ooo`T0IVKo:@3oool00`1oOgl0oooo06IVo`0306IVohl0oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?oo
o`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`80
IVKo9P3oool206IVoa<0oooo1P1VI_l30?ooo`@0IVKo9`3oool00`1oOgl0oooo06IVo`0306IVohl0
oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`1:0?ooo`80IVKo403oool606IVo`L0oooo101VI_lV0?ooo`0307moO`3oool0IVKo00<0IVKo
S`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo04X0oooo0P1VI_l>0?ooo`H0IVKo2`3oool406IVob@0oooo00<0Ogmo0?ooo`1VI_l00`1V
I_n?0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0BP3oool206IVo`/0oooo1P1VI_l?0?ooo`@0IVKo8`3oool00`1oOgl0oooo06IVo`03
06IVohl0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo
04X0oooo0P1VI_l90?ooo`H0IVKo4`3oool406IVob40oooo00@0Ogmo06IVo`1VI_l0oooo0P1VI_n?
0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0J
0?ooo`<000006P3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1:0?oo
o`80IVKo1P3oool606IVoaL0oooo1@1VI_lN0?ooo`@0IVKo00<0oooo06IVo`1VI_l0S`3oool00`1o
Ogl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`1:0?ooo`80IVKo103oool606IVoa/0oooo101VI_lL0?ooo`@0IVKo0P3oool206IVohl0
oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0BP3oool206IVo`030?ooo`1VI_l0IVKo00@0IVKo803oool406IVoaT0oooo
0`1VI_l0101oOgl0oooo0?ooo`3oool206IVohl0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0BP3oool706IVob<0oooo
101VI_lF0?ooo`@0IVKo00<0oooo07moO`3oool00P3oool206IVohl0oooo00<0Ogmo0?ooo`3oool0
0`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0BP3o
ool406IVobP0oooo101VI_lC0?ooo`@0IVKo0P3oool0101oOgl0oooo0?ooo`3oool206IVohl0oooo
00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0B`3oool00`1VI_l0oooo0?ooo`0Y0?ooo`D0IVKo403oool306IVo`@0oooo00@0
Ogmo0?ooo`3oool0oooo0P1VI_n?0?ooo`0307moO`3oool0oooo00<0oooo0`1VI_n<0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo07T0oooo101VI_l>0?ooo`<0IVKo1@3o
ool0101oOgl0oooo0?ooo`3oool206IVohl0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0N`3oool406IVo`X0oooo101V
I_l60?ooo`0407moO`3oool0oooo0?ooo`80IVKoS`3oool00`1oOgl0oooo0?ooo`030?ooo`<0IVKo
S03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0
603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1l0?ooo`@0IVKo203o
ool406IVo`L0oooo00@0Ogmo0?ooo`3oool0oooo0P1VI_n?0?ooo`0307moO`3oool0oooo00<0oooo
0`1VI_n<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo
0?ooo`0H0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3oool0OP3oool406IVo`D0oooo0`1V
I_l90?ooo`0407moO`3oool0oooo0?ooo`80IVKoS`3oool00`1oOgl0oooo0?ooo`030?ooo`<0IVKo
S03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo0`00000J0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo07l0oooo101VI_l20?ooo`@0IVKo2P3o
ool0101oOgl0oooo0?ooo`3oool206IVohl0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0P@3oool706IVo`/0oooo00@0
Ogmo0?ooo`3oool0oooo0P1VI_lV0?ooo`0306IVo`3oool0oooo06H0oooo00<0Ogmo0?ooo`3oool0
0`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0PP3o
ool406IVo`d0oooo00@0Ogmo0?ooo`3oool0oooo0P1VI_lV0?ooo`80IVKoI`3oool00`1oOgl0oooo
0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo
00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`240?ooo`0306IVo`3oool0oooo00`0oooo00@0Ogmo0?ooo`3oool0oooo0P1VI_lU0?ooo`@0IVKo
IP3oool00`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0407moO`3oool0oooo0?ooo`80IVKo9@3oool00`1VI_l0oooo
06IVo`0206IVofD0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00290?ooo`030?oo_`1d
000000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2L
B00000000080000000<004RL0=ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool00P3oool206IVob<0oooo0P1VI_l20?ooo`@0IVKoH`3o
ool00`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool008P0oooo00<0okmd0000000000001@000000
0`1d_ol0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`020?ooo`80IVKo8`3oool00`1VI_l0oooo0?ooo`020?ooo`@0IVKoHP3oool0
0`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool008L0oooo00<0omnL04P0000000001P0000001P00
04P0W=oo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d000700000006
0018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`020?ooo`80IVKo8`3oool0
0`1VI_l0oooo0?ooo`040?ooo`<0IVKoH@3oool00`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool0
08L0oooo00P0_g@0000000000000001809cOo`3oool0omnL04P00080000000@007Bo0?ooo`3oool0
okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@00018
09cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0
000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool00P3oool206IVob80oooo0P1VI_l70?ooo`<0IVKoH03oool00`1oOgl0
oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool008H0oooo00D0oono07@000000000000004RLg`030?ooo`07
0=nLB000000000000018W03Oool0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM0000P00
00001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000001018W=l0
oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`18W=l0oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`02
0?ooo`80IVKo8P3oool00`1VI_l0oooo0?ooo`070?ooo`<0IVKoG`3oool00`1oOgl0oooo0?ooo`03
0?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool008H0oooo00D0omnL04P000000000000007Boo`030?ooo`070?noM0000000
00000000M02oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0
gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2L
B0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000
Y@1oOgl206IVob40Ogmo0P1VI_l:07moO`<0IVKoI01oOgl306IVool0Ogmo?P1oOgl5000001X0oooo
002>0?ooo`070=nLB000000000000018W03Oool0oono07@000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0
gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`030?ooo`80IVKo803oool00`1VI_l0oooo0?ooo`0:0?ooo`@0IVKoG03oool00`1oOgl0
oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0
oooo00<000000?ooo`3oool0603oool008d0oooo00P0omnL04P000000000000004RLg`3oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00<0oooo0P1VI_lO0?ooo`80IVKo3@3oool4
06IVoe/0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo002:0?ooo`030?oog`2LB0000000
00<0000000D004RL0=ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
0000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0
_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`03
0?ooo`80IVKo7`3oool00`1VI_l0oooo0?ooo`0>0?ooo`<0IVKoFP3oool00`1oOgl0oooo0?ooo`03
0?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<00000
0?ooo`3oool0603oool008/0oooo00D0_g@000000000000004RL0=ooo`030?ooo`050?oo_`1d0000
00000000001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0
oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool00`3oool206IVoah0oooo0P1VI_lA0?ooo`<0IVKoF@3o
ool00`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool008/0oooo00H0gia800000000000000000000
B02Lgol20?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@0000000000000B9`0gooo
0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M000
0P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool00`3oool206IVoah0
oooo00<0IVKo0?ooo`3oool04@3oool306IVoeP0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoh`0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo002=0?ooo`080;md0000000000000000M02oool0oooo0?oog`2LB0020000000507Boo`3oool0
oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3O
W4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P000000
0`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`030?ooo`80IVKo7P3oool00`1VI_l0oooo0?ooo`0B0?ooo`<0IVKoE`3oool0
0`1oOgl0oooo0?ooo`030?ooo`<0IVKoS03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01`0oooo00<000000?ooo`3oool0603oool008H0oooo00D0oooO09a800000000000007Boo`02
0?ooo`050?oo_`1d000000000000B02Lgol00P3oool0102oM000000000000000M;l30?ooo`040;md
000000000000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l2
0?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo3@3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0103oool206IVoa`0oooo
0P1VI_lE0?ooo`<0IVKoEP3oool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool008L0oooo00L0
gia8000000000000001d0;ooo`3oool0okmd0080000000D0001809cOo`3oool0oooo0?noM0020000
00040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?oo
o`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d
_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`040?ooo`80IVKo703oool00`1VI_l0oooo0?ooo`0E0?ooo`@0IVKoE03oool00`1o
Ogl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01`0oooo00<000000?ooo`3oool0603oool008L0oooo00<0omnL04P0000000001P0000001P00B9`0
gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018
W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`040?ooo`80IVKo6`3oool206IV
oaP0oooo101VI_mC0?ooo`0307moO`3oool0oooo00<0oooo101VI_n;0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00R03oool00`3OW4P0
000000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0
B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00@0oooo0P1VI_lK0?ooo`0306IVo`3oool0oooo01T0
oooo0`1VI_mB0?ooo`0307moO`3oool0oooo00<0oooo101VI_n;0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00R@3oool00`3ookl0M000
00000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo00h0oooo0`00000<0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool0103oool206IVoaX0oooo0P1VI_lL0?ooo`<0IVKoD@3oool00`1oOgl0oooo
0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo
0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0103oool206IVoaX0oooo00<0IVKo0?ooo`3oool0703oool306IVoe00oooo00<0
Ogmo0?ooo`3oool00`3oool406IVoh/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`050?ooo`80IVKo603oool206IVoal0oooo0`1VI_m?
0?ooo`0307moO`3oool0oooo00<0oooo101VI_n;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool01@3oool206IVoaP0oooo00<0IVKo0?oo
o`3oool07`3oool406IVodd0oooo00<0Ogmo0?ooo`3oool00`3oool406IVoh/0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`050?ooo`80
IVKo603oool00`1VI_l0oooo0?ooo`0P0?ooo`@0IVKoC03oool00`1oOgl0oooo0?ooo`030?ooo`@0
IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3o
ool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo00D0oooo0P1VI_lG0?ooo`80IVKo903oool306IVod/0oooo00<0Ogmo0?ooo`3oool0
0`3oool406IVoh/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`050?ooo`80IVKo5`3oool00`1VI_l0oooo0?ooo`0T0?ooo`<0IVKoBP3o
ool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00D0oooo0P1VI_lF0?ooo`80IVKo9`3oool5
06IVodL0oooo00<0Ogmo0?ooo`3oool00`3oool406IVoh/0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`050?ooo`80IVKo5P3oool00`1V
I_l0oooo0?ooo`0W0?ooo`H0IVKoA@3oool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01`0oooo00<000000?ooo`3oool0603oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00H0
oooo0P1VI_lD0?ooo`80IVKo;03oool606IVod80oooo00<0Ogmo0?ooo`3oool00`3oool406IVoh/0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00H0oooo
0P1VI_lD0?ooo`0306IVo`3oool0oooo02d0oooo1`1VI_lo0?ooo`0307moO`3oool0oooo00<0oooo
101VI_n;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool3000001X0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`060?ooo`80IVKo4`3oool206IVoc80oooo1`1VI_ll0?ooo`0307moO`3oool0oooo00<0oooo101V
I_n;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool01P3oool206IVoa<0oooo00<0IVKo0?ooo`3oool0=03oool606IVocX0oooo00<0Ogmo
0?ooo`3oool00`3oool406IVoh/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:
0?ooo`<0IVKo3`3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool01P3oool206IVoa80oooo0P1VI_li0?oo
o`H0IVKo=`3oool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo00X0oooo0`1VI_l?0?ooo`030000003oool0oooo01P0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`060?ooo`80
IVKo4P3oool00`1VI_l0oooo0?ooo`0j0?ooo`L0IVKo=03oool00`1oOgl0oooo0?ooo`030?ooo`@0
IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l?0?ooo`03
0000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`070?ooo`80IVKo4@3oool00`1VI_l0oooo0?ooo`0m0?ooo`L0IVKo
<@3oool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo00X0oooo0`1VI_l?0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`070?ooo`80IVKo403o
ool206IVod80oooo1P1VI_l_0?ooo`0307moO`3oool0oooo00<0oooo101VI_n;0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool306IVo`l0oooo00<000000?ooo`3oool0603o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo00L0oooo0P1VI_l@0?ooo`0306IVo`3oool0oooo04@0oooo1P1VI_l/0?ooo`0307moO`3oool0
oooo00<0oooo101VI_n;0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool3
06IVo`l0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00L0oooo0P1VI_l?0?ooo`80IVKoB03oool906IV
obL0oooo00<0Ogmo0?ooo`3oool00`3oool406IVoh/0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0:0?ooo`<0IVKo3`3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool01`3oool206IVo`l0
oooo00<0IVKo0?ooo`3oool0BP3oool<06IVob40oooo00<0Ogmo0?ooo`3oool00`3oool406IVoh/0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0IVKo3`3oool00`000000
oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool01`3oool206IVo`h0oooo0P1VI_mB0?ooo``0IVKo6`3oool00`1oOgl0oooo
0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo
0`1VI_l?0?ooo`030000003oool0oooo01P0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo00P0oooo0P1VI_l=0?ooo`0306IVo`3oool0oooo05L0oooo301V
I_lE0?ooo`0307moO`3oool0oooo00<0oooo101VI_n;0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool02P3oool306IVo`d0oooo0`00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0203oool206IVo``0oooo0P1VI_mO
0?ooo``0IVKo3`3oool00`1oOgl0oooo0?ooo`030?ooo`@0IVKoR`3oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l?0?ooo`030000003oool0oooo01P0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`080?oo
o`80IVKo303oool00`1VI_l0oooo0?ooo`1T0?ooo`X0IVKo2`3oool00`1oOgl0oooo0?ooo`030?oo
o`D0IVKoRP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l?0?oo
o`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`080?ooo`80IVKo303oool00`1VI_l0oooo0?ooo`1Z0?ooo`L0
IVKo203oool00`1oOgl0oooo0?ooo`030?ooo`80IVKo00@0oooo06IVo`1VI_l0IVKoR@3oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l?0?ooo`030000003oool0oooo
01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`080?ooo`80IVKo2`3oool206IVofl0oooo1`1VI_l50?ooo`0307moO`3oool0oooo00<0
oooo0P1VI_l20?ooo`@0IVKoQ`3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0
oooo0`1VI_l?0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`080?ooo`80IVKo2`3oool00`1VI_l0oooo
0?ooo`1a0?ooo`L0IVKo0P3oool00`1oOgl0oooo0?ooo`030?ooo`80IVKo0`3oool406IVohH0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0IVKo3`3oool00`000000oooo
0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool0203oool206IVo`X0oooo0P1VI_mf0?ooo`L0IVKo1@3oool206IVo`D0oooo0`1V
I_n50?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406IVo`h0oooo00<0
00000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo00T0oooo0P1VI_l90?ooo`0306IVo`3oool0oooo07P0oooo1`1VI_l2
0?ooo`80IVKo1P3oool706IVoh00oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:
0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02@3oool206IVo`P0oooo0P1VI_mm0?oo
o`P0IVKo1`3oool<06IVogX0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?oo
o`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02@3oool206IVo`P0oooo00<0IVKo0?ooo`3o
ool0O03oool00`1oOgl0oooo0?ooo`0406IVo`h0oooo301VI_md0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool02P3oool406IVo`h0oooo00<000000?ooo`3oool0603oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00T0oooo
0P1VI_l70?ooo`80IVKoOP3oool00`1oOgl0oooo0?ooo`030?ooo`0306IVo`3oool0oooo0180oooo
301VI_m^0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406IVo`h0oooo
00<000000?ooo`3oool0603oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool02@3oool206IVo`L0oooo00<0IVKo0?ooo`3oool0O@3oool00`1oOgl0oooo0?oo
o`0N0?ooo``0IVKoJ03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo101V
I_l<0?ooo`<000006P3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo00T0oooo0P1VI_l70?ooo`0306IVo`3oool0oooo07d0oooo00<0Ogmo
0?ooo`3oool0903ooolT06IVodX0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:
0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool206IVo`D0oooo0P1VI_mo0?oo
o`0307moO`3oool0oooo02X0oooo@@1VI_lW0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool02P3oool406IVo`h0oooo00<000000?ooo`3oool0603oool00<H0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00X0oooo0P1VI_l50?ooo`03
06IVo`3oool0oooo07h0oooo00<0Ogmo0?ooo`3oool0B03ooolW06IVob<0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
2P3oool206IVo`@0oooo0P1VI_n00?ooo`0307moO`3oool0oooo06/0oooo201VI_lO0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool406IVo`h0oooo00<000000?ooo`3oool0
603oool008T0oooo00<0oono07@0000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2L
B00000000080000000<0001d0;ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`80IVKo103o
ool00`1VI_l0oooo0?ooo`1o0?ooo`0307moO`3oool0oooo06l0oooo2@1VI_lJ0?ooo`0307moO`3o
ool0oooo00D0oooo2`1VI_n30?ooo`0307moO`3oool0oooo00X0oooo101VI_l>0?ooo`030000003o
ool0oooo01P0oooo00280?ooo`030?noM0000000000000D0000000<0M;oo0?ooo`3oool00P3oool0
0`3ogi`0B000000000050000000307Boo`3oool0oooo0080oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool02P3oool2
06IVo`<0oooo0P1VI_n10?ooo`0307moO`3oool0oooo07<0oooo2@1VI_lF0?ooo`0307moO`1VI_l0
IVKo01@0IVKoO`3oool00`1oOgl0oooo0?ooo`0:0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H
0?ooo`00Q`3oool00`3ogi`0B00000000006000000060000B02Lgol0oooo0?ooo`3ookl0M0001`00
00001P0004P0W=oo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007
000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo00X0oooo0P1VI_l30?ooo`0306IVo`3oool0oooo0800oooo00<0Ogmo
0?ooo`3oool0N03oool806IVo``0oooo3P1VI_l;0?ooo`P0IVKoN`3oool00`1oOgl0oooo0?ooo`0:
0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00Q`3oool0202oM00000000000000004P0
W=oo0?ooo`3ogi`0B0000P0000001000M;l0oooo0?ooo`3OW4P30000000407Boo`3oool0oono07@0
0080000000@007Bo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3o
ool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0;0?ooo`80
IVKo00<0oooo06IVo`1VI_l0PP3oool00`1oOgl0oooo0?ooo`1l0?oooaL0IVKo5P3oool706IVogP0
oooo00<0Ogmo0?ooo`3oool02P3oool406IVo`h0oooo00<000000?ooo`3oool0603oool008H0oooo
00D0oono07@000000000000004RLg`030?ooo`070=nLB000000000000018W03Oool0oooO09a80002
00000005001d_`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?ooo`2oM00200000005001d
_`3oool0oooo0?ooo`2oM0000P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo
0?ooo`2oM0000P0000000`18W=l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0;0?ooo`80IVKo00<0oooo06IVo`3oool0PP3oool0
0`1oOgl0oooo0?ooo`200?ooo``0IVKo1P3oool00`1oOgl0oooo0?ooo`0H0?ooo`L0IVKoM03oool0
0`1oOgl0oooo0?ooo`0:0?ooo`@0IVKo3P3oool00`000000oooo0?ooo`0H0?ooo`00QP3oool01@3o
gi`0B000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M00000800000
00/0M;oo0?ooo`3oool0oooo0?oOW018000000000000B02Lgol0oooO09a800020000000507Boo`3o
ool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?oo
o`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000[P1oOgl206IVo`0307moO`1VI_l0Ogmo
0?l0Ogmo=P1oOgl806IVogd0Ogmo0P1VI_l00`1oOgl0IVKo06IVo`0907moO`D000006P3oool008h0
oooo00D0gia800000000000004RL0=ooo`080?ooo`070?oOW018000000000000B02Lgol0oono07@0
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0;0?ooo`@0IVKoP`3oool00`1o
Ogl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo01l0oooo201VI_le0?oooa80IVKo9@3oool00`1o
Ogl0oooo0?ooo`0:0?ooo`80IVKo403oool00`000000oooo0?ooo`0H0?ooo`00S@3oool01@3ogi`0
B000000000000000B9cO00T0oooo00L0okmd000000000000001809cOo`3ookl0M0000080000000D0
M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00/0oooo0`1VI_n40?ooo`0307moO`3oool0oooo
0980oooo00<0Ogmo0?ooo`3oool08`3oool706IVobP0oooo8`1VI_lN0?ooo`0307moO`3oool0oooo
00X0oooo0P1VI_l@0?ooo`030000003oool0oooo01P0oooo002:0?ooo`030?oog`2LB000000000<0
000000D004RL0=ooo`3oool0oooo0=nLB002000000050018W03Oool0oooo0?oo_`1d00000P000000
1000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0;0?oo
o`<0IVKoQ03oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo02L0oooo=@1VI_lB0?oo
o`l0IVKo5P3oool00`1oOgl0oooo0?ooo`0:0?ooo`80IVKo403oool00`000000oooo0?ooo`0H0?oo
o`00R`3oool01@2oM000000000000000B9`0gooo00@0oooo00<0okmd0000000000001`000000101d
_ol0oooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0;0?ooo`80
IVKoQ@3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo02X0oooo:01VI_lS0?ooo`l0
IVKo3`3oool00`1oOgl0oooo0?ooo`0:0?ooo`80IVKo403oool00`000000oooo0?ooo`0H0?ooo`00
R`3oool01P3OW4P00000000000000000001809cOo`<0oooo00<0omnL04P0000000001P0000001@00
M;l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03O
ool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo00`0
oooo00<0IVKo0?ooo`3oool0P`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo07d0
oooo5@1VI_l00`3oool0Ogmo0?ooo`0;0?ooo`80IVKo403oool00`000000oooo0?ooo`0H0?ooo`00
S@3oool01@2oM00000000000000007@0_ooo0080oooo00D0oooO09a800000000001804Q800030000
000607Boo`3oool0oooo0?ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia800800000
00@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo08@0oooo7P1VI_l@0?oo
o`030000003oool0oooo01P0oooo00260?ooo`050?oog`2LB00000000000001d_ol00P3oool01@3o
okl0M0000000000004P0W=oo00<0oooo00@0_g@0000000000000M;oo203oool0102oM00000000000
0000M;l30?ooo`040;md000000000000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102o
M000000000000000M;l=0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0TP3oool?
06IVoa40oooo00<000000?ooo`3oool0603oool008L0oooo00L0gia8000000000000001d0;ooo`3o
ool0okmd0080000000<0001809cOo`3oool00P3oool0103OW4P0000000000000M;l80?ooo`070?no
M000000000000000B02Lgol0oooo0?noM0030000000407Boo`3oool0oooo0?noM080000000@00018
09cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0:0?ooo`0306IVo`3oool0oooo00l0oooo00<0
00000?ooo`3oool0603oool008L0oooo00<0omnL04P0000000001P0000000`00B9`0gooo0?ooo`02
0?ooo`030?oOW0180000000000H0000000D0B9cO0?ooo`3oool0oono07@00007000000060018W03O
ool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307moO`3oool0oooo0980
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo00280?ooo`030=nLB0000000000000@0000000<0001809cOo`3oool00`3oool00`3ookl0M000
000000060000000604RLg`3oool0oooo0?ooo`3ogi`0B0001@0000000`0004P0W=oo0?ooo`030?oo
o`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0703oool00`000000oooo0?ooo`0H0?oo
o`00R@3oool00`3ookl0M00000000002000000030018W03Oool0oooo00@0oooo00<0oooO09a80000
00001P0000000`18W=l0oooo0?ooo`020?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3o
ool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo0`00000<0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0TP3oool00`1oOgl0oooo0?ooo`2B0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool3000001X0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`2B0?ooo`0307mo
O`3oool0oooo0980oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00360?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00360?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo0P00000J0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`8000006P3oool00<H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool2000001X0oooo00360?ooool00000o`000027000001X0oooo
003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?oo
ofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3o
oooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0
ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03o
ool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0
ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?ooool0oooo
o`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo003o0?oo
ool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?ooofP0oooo
003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3ooooo0?oo
ofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00o`3ooooo0?ooool0ooooJ03oool00?l0ooooo`3o
oooo0?ooofP0oooo003o0?ooool0ooooo`3ooomX0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 868.188}, {589.938, 0}} -> {-1.05194, -0.784208, \
0.00365197, 0.00365197}, {{21.25, 842.688}, {521.625, 13.9375}} -> {-715.235, \
-1538.87, 5.01964, 14.109}, {{66.4375, 846.813}, {575.875, 534.813}} -> \
{-0.513066, -0.908215, 0.00930525, 0.0862084}, {{95.5, 256.688}, {572.688, \
555.25}} -> {-20.2772, -2.98564, 0.172664, 0.172664}, {{282.5, 443.688}, \
{572.688, 555.25}} -> {-41.8026, -2.98564, 0.172664, 0.172664}, {{469.5, \
630.625}, {572.688, 555.25}} -> {-63.328, -2.98564, 0.172664, 0.172664}, \
{{656.5, 817.688}, {572.688, 555.25}} -> {-84.8534, -2.98564, 0.172664, \
0.172664}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Dot Product Mac OS X ", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68061 
%%ImageSize: 850 578.522 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497631 0.473821 0.371571 0.473821 [
[ 0 0 0 0 ]
[ 1 .68061 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0787334 0.971452 0.664409 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000463897 0.0147151 0.000543831 [
[.02381 -0.0125 -6.4375 -18 ]
[.02381 -0.0125 6.4375 0 ]
[.25576 -0.0125 -15.3125 -18 ]
[.25576 -0.0125 15.3125 0 ]
[.48771 -0.0125 -19.75 -18 ]
[.48771 -0.0125 19.75 0 ]
[.71966 -0.0125 -19.75 -18 ]
[.71966 -0.0125 19.75 0 ]
[.9516 -0.0125 -19.75 -18 ]
[.9516 -0.0125 19.75 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -55.625 -36 ]
[.5 -0.0125 55.625 -18 ]
[-0.0125 .01472 -12.875 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .12348 -30.625 -9 ]
[-0.0125 .12348 0 9 ]
[-0.0125 .23225 -30.625 -9 ]
[-0.0125 .23225 0 9 ]
[-0.0125 .34101 -30.625 -9 ]
[-0.0125 .34101 0 9 ]
[-0.0125 .44978 -30.625 -9 ]
[-0.0125 .44978 0 9 ]
[-0.0125 .55855 -39.5 -9 ]
[-0.0125 .55855 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -110 -9 ]
[-0.01875 .30902 -39.5 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.25576 0 m
.25576 .61803 L
s
.48771 0 m
.48771 .61803 L
s
.71966 0 m
.71966 .61803 L
s
.9516 0 m
.9516 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .12348 m
1 .12348 L
s
0 .23225 m
1 .23225 L
s
0 .34101 m
1 .34101 L
s
0 .44978 m
1 .44978 L
s
0 .55855 m
1 .55855 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.4375 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25576 0 m
.25576 .00625 L
s
gsave
.25576 -0.0125 -76.3125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.48771 0 m
.48771 .00625 L
s
gsave
.48771 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.71966 0 m
.71966 .00625 L
s
gsave
.71966 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.9516 0 m
.9516 .00625 L
s
gsave
.9516 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.125 Mabswid
.0702 0 m
.0702 .00375 L
s
.11659 0 m
.11659 .00375 L
s
.16298 0 m
.16298 .00375 L
s
.20937 0 m
.20937 .00375 L
s
.30215 0 m
.30215 .00375 L
s
.34854 0 m
.34854 .00375 L
s
.39493 0 m
.39493 .00375 L
s
.44132 0 m
.44132 .00375 L
s
.5341 0 m
.5341 .00375 L
s
.58049 0 m
.58049 .00375 L
s
.62688 0 m
.62688 .00375 L
s
.67327 0 m
.67327 .00375 L
s
.76605 0 m
.76605 .00375 L
s
.81243 0 m
.81243 .00375 L
s
.85882 0 m
.85882 .00375 L
s
.90521 0 m
.90521 .00375 L
s
.99799 0 m
.99799 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -116.625 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vector) show
117.062 17.000 moveto
(Length) show
170.250 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -73.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12348 m
.00625 .12348 L
s
gsave
-0.0125 .12348 -91.625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .23225 m
.00625 .23225 L
s
gsave
-0.0125 .23225 -91.625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .34101 m
.00625 .34101 L
s
gsave
-0.0125 .34101 -91.625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
0 .44978 m
.00625 .44978 L
s
gsave
-0.0125 .44978 -91.625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
0 .55855 m
.00625 .55855 L
s
gsave
-0.0125 .55855 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04191 m
.00375 .04191 L
s
0 .0691 m
.00375 .0691 L
s
0 .09629 m
.00375 .09629 L
s
0 .15067 m
.00375 .15067 L
s
0 .17786 m
.00375 .17786 L
s
0 .20506 m
.00375 .20506 L
s
0 .25944 m
.00375 .25944 L
s
0 .28663 m
.00375 .28663 L
s
0 .31382 m
.00375 .31382 L
s
0 .36821 m
.00375 .36821 L
s
0 .3954 m
.00375 .3954 L
s
0 .42259 m
.00375 .42259 L
s
0 .47697 m
.00375 .47697 L
s
0 .50416 m
.00375 .50416 L
s
0 .53135 m
.00375 .53135 L
s
0 .58574 m
.00375 .58574 L
s
0 .61293 m
.00375 .61293 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -171 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MFLOPS) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25576 .61178 m
.25576 .61803 L
s
.48771 .61178 m
.48771 .61803 L
s
.71966 .61178 m
.71966 .61803 L
s
.9516 .61178 m
.9516 .61803 L
s
.125 Mabswid
.0702 .61428 m
.0702 .61803 L
s
.11659 .61428 m
.11659 .61803 L
s
.16298 .61428 m
.16298 .61803 L
s
.20937 .61428 m
.20937 .61803 L
s
.30215 .61428 m
.30215 .61803 L
s
.34854 .61428 m
.34854 .61803 L
s
.39493 .61428 m
.39493 .61803 L
s
.44132 .61428 m
.44132 .61803 L
s
.5341 .61428 m
.5341 .61803 L
s
.58049 .61428 m
.58049 .61803 L
s
.62688 .61428 m
.62688 .61803 L
s
.67327 .61428 m
.67327 .61803 L
s
.76605 .61428 m
.76605 .61803 L
s
.81243 .61428 m
.81243 .61803 L
s
.85882 .61428 m
.85882 .61803 L
s
.90521 .61428 m
.90521 .61803 L
s
.99799 .61428 m
.99799 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12348 m
1 .12348 L
s
.99375 .23225 m
1 .23225 L
s
.99375 .34101 m
1 .34101 L
s
.99375 .44978 m
1 .44978 L
s
.99375 .55855 m
1 .55855 L
s
.125 Mabswid
.99625 .04191 m
1 .04191 L
s
.99625 .0691 m
1 .0691 L
s
.99625 .09629 m
1 .09629 L
s
.99625 .15067 m
1 .15067 L
s
.99625 .17786 m
1 .17786 L
s
.99625 .20506 m
1 .20506 L
s
.99625 .25944 m
1 .25944 L
s
.99625 .28663 m
1 .28663 L
s
.99625 .31382 m
1 .31382 L
s
.99625 .36821 m
1 .36821 L
s
.99625 .3954 m
1 .3954 L
s
.99625 .42259 m
1 .42259 L
s
.99625 .47697 m
1 .47697 L
s
.99625 .50416 m
1 .50416 L
s
.99625 .53135 m
1 .53135 L
s
.99625 .58574 m
1 .58574 L
s
.99625 .61293 m
1 .61293 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .4 .4 r
.004 w
.08087 .35373 m
.08319 .36827 L
.08551 .36199 L
.09339 .37382 L
.13978 .43958 L
.14025 .43809 L
.14257 .45709 L
.14489 .44766 L
.18617 .49713 L
.23256 .52039 L
.25901 .53971 L
.26132 .55539 L
.26364 .55151 L
.27895 .54695 L
.32534 .54811 L
.37173 .55455 L
.41812 .57603 L
.46451 .56979 L
.49652 .57885 L
.49884 .5789 L
.50116 .58721 L
.5109 .58965 L
.55729 .58513 L
.60368 .58886 L
.65007 .59145 L
.69646 .5934 L
.74285 .59499 L
.78924 .59706 L
.83563 .60233 L
.88202 .60332 L
.92841 .59997 L
.97155 .59584 L
.97387 .59215 L
.97619 .59856 L
s
.4 .4 1 r
.08087 .05281 m
.08319 .05193 L
.08551 .05211 L
.09339 .05063 L
.13978 .04701 L
.14025 .04701 L
.14257 .04698 L
.14489 .04698 L
.18617 .04585 L
.23256 .04482 L
.25901 .04449 L
.26132 .04457 L
.26364 .04448 L
.27895 .04409 L
.32534 .04355 L
.37173 .04314 L
.41812 .04296 L
.46451 .04284 L
.49652 .04285 L
.49884 .04283 L
.50116 .04286 L
.5109 .0428 L
.55729 .04279 L
.60368 .04279 L
.65007 .04279 L
.69646 .04278 L
.74285 .04277 L
.78924 .04276 L
.83563 .04274 L
.88202 .0427 L
.92841 .04269 L
.97155 .04263 L
.97387 .04278 L
.97619 .04261 L
s
.4 .8 .4 r
.08087 .08355 m
.08319 .08142 L
.08551 .08384 L
.09339 .07899 L
.13978 .06621 L
.14025 .06664 L
.14257 .06567 L
.14489 .06561 L
.18617 .06718 L
.23256 .06155 L
.25901 .06044 L
.26132 .05977 L
.26364 .06026 L
.27895 .05874 L
.32534 .05684 L
.37173 .05558 L
.41812 .05512 L
.46451 .055 L
.49652 .0551 L
.49884 .05514 L
.50116 .05508 L
.5109 .05503 L
.55729 .05512 L
.60368 .05512 L
.65007 .05522 L
.69646 .05526 L
.74285 .05527 L
.78924 .05531 L
.83563 .05524 L
.88202 .05513 L
.92841 .05499 L
.97155 .05471 L
.97387 .05526 L
.97619 .05461 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
1 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
0 g
.001 w
[ ] 0 setdash
.07593 .01621 m
.97619 .01621 L
.97619 .06359 L
.07593 .06359 L
.07593 .01621 L
s
% Start of sub-graphic
p
0.0759299 0.0162051 0.97619 0.0635872 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0271739 0.271739 0.00223015 0.0223015 [
[ 0 0 0 0 ]
[ 1 .05263 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .05263 L
0 .05263 L
closepath
clip
newpath
% Start of sub-graphic
p
0.048913 0.00401427 0.320652 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .4 .4 r
.2244 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.18478 .0281 -88.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vecLib) show
113.562 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.36413 0.00401427 0.63587 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .4 1 r
.2244 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.5 .0281 -101.562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Reference) show
140.125 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.679348 0.00401427 0.951087 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .8 .4 r
.2244 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.81522 .0281 -80.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
85.188 17.000 moveto
(.1) show
98.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .68061 L
0 .68061 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{583.25, 396.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=Z0002Db000`400?l00000o`00003oo`3ooooo
0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00
o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]
0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0oooo
o`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?oo
ool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo
00120?ooool00000o`00003o000001H000005@3oool00480oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool00480oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool00480oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000
003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool00480oooo00<0
00000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool0
0`000000oooo0?ooo`260?oooa80ofIVi@3ooolC06IVonD0oooo4`1Vc6J70?ooo`030000003oool0
oooo01<0oooo00120?ooo`030000003oool0oooo08H0oooo4P3oIVKU0?oooa<0IVKoi@3ooolC06K<
IXL0oooo00<000000?ooo`3oool04`3oool00480oooo00<000000?ooo`3oool0QP3ooolB0?mVI^D0
oooo4`1VI_oU0?oooa<0I/aVQ`3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`000000oooo
0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000003o
ool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool00480oooo00<00000
0?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3oool00`00
0000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo00120?ooo`03
0000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool00480oooo
00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?ooo`00@P3o
ool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0oooo0012
0?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool04`3oool0
0480oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?ooo`0C0?oo
o`00@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0oooo01<0
oooo00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?ooo`3oool0
4`3oool00480oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000oooo0?oo
o`0C0?ooo`00@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000003oool0
oooo01<0oooo00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<000000?oo
o`3oool04`3oool00480oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo4P3oool00`000000
oooo0?ooo`0C0?ooo`00@P3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3ooolB0?ooo`030000
003oool0oooo01<0oooo00120?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?oooa80oooo00<0
00000?ooo`3oool04`3oool00480oooo00<000000?ooo`3oool0K03oool01@3ogi`0B00000000000
04P0W=oo00L0oooo00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`060?ooo`030;md0000
000000000080000000<007Bo0?ooo`3oool00P3oool00`3ookl0M0000000000:0000000707Boo`3o
ool0oono07@000000000001809cOo`020?ooo`060?noM00000000000001d_`3oool0_g@00`000000
0`00B9`0gooo0?ooo`2K0?ooo`050?oo_`1d000000000000001d_ol01P3oool01@2oM00000000000
00000000B9cO00<0oooo00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`030?ooo`050?oo
_`1d000000000000001d_ol01@3oool00`3ogi`0B00000000002000000030000M02oool0oooo00<0
oooo00D0gia800000000000004RL0=ooo`060?ooo`030?oOW018000000000080000000<0001d0;oo
o`3oool00`3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0oono07@000000000000007Bo
o`050?ooo`030;md0000000000000080000000<007Bo0?ooo`3oool0103oool00`3ogi`0B0000000
0002000000030000M02oool0oooo0:d0oooo00D0oooO09a800000000000004RLg`030?ooo`070?oo
_`1d000000000000B02Lgol0oooo0?noM00:000000090000M02oool0oooo0?ooo`3ookl0M0000000
000004P0W=oo00H0oooo00D0oono07@000000000000007Boo`1i0?ooo`030000003oool0oooo01<0
oooo00120?ooo`030000003oool0oooo06`0oooo00D0gia8000000000000000004RLg`060?ooo`03
0=nLB0000000000000D0000000<0B9cO0?ooo`3oool00P3oool00`3ogi`0B0000000000500000006
0000B02Lgol0oooo0?ooo`3ookl0M0002`0000001`1d_ol0oooo0?oo_`1d000000000000B02Lgol0
0P3oool01@3o_g@0000000000000M7@0M00000D0000000<0001809cOo`3oool0VP3oool01@3ookl0
M000000000000000M;oo00D0oooo00H0omnL04P00000000000000000M02oool20?ooo`030=nLB000
0000000000D0000000H0B9cO0?ooo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo0080
oooo00<0gia80000000000001@0000001@18W=l0oooo0?ooo`3oool0gia80080000000<004RL0=oo
o`3oool0103oool00`3OW4P00000000000050000000904RLg`3oool0oooo0?ooo`3ogi`0B0000000
000007@0_ooo00<0oooo00D0oono07@000000000000007Boo`030?ooo`030?oOW0180000000000D0
000000<0001809cOo`3oool00P3oool00`3OW4P00000000000050000000304RLg`3oool0oooo0:/0
oooo00D0oooO09a800000000000004RLg`030?ooo`080?oo_`1d000000000000B02Lgol0oooo0?oo
_`1d0009000000090000M02oool0oooo0?ooo`3ookl0M0000000000004P0W=oo00H0oooo00D0oono
07@000000000000007Boo`1i0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000003oool0
oooo06/0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`030?ooo`030?noM0000000
000000H0000000H0001809cOo`3oool0oooo0?oo_`1d0008000000050018W03Oool0oooo0?oo_`1d
00002`0000001`1d_ol0oooo0?oo_`1d000000000000B02Lgol00P3oool00`3o_g@0000000000008
000000030000M02oool0oooo09T0oooo00D0oono07@000000000000007Boo`040?ooo`030?oog`2L
B00000000080000000@0M;oo0?ooo`3oool0okmd200000001P0004P0W=oo0?ooo`3oool0oono07@0
0080000000D0M;oo0?ooo`3oool0oooo0?noM008000000050000B02Lgol0oooo0?ooo`3OW4P00P00
00000`00B9`0gooo0?ooo`030?ooo`030?noM0000000000000H0000000T0001809cOo`3oool0oooo
0?oOW018000000000000M02oool00`3oool01@3ookl0M000000000000000M;oo0080oooo00<0oono
07@0000000001`0000001000B9`0gooo0?ooo`3o_g@8000000030000B02Lgol0oooo0:/0oooo00D0
oooO09a800000000000004RLg`030?ooo`050?oo_`1d000000000000B02Lgol00P3oool00`2oM000
000000000007000000090000M02oool0oooo0?ooo`3ookl0M0000000000004P0W=oo00H0oooo00D0
oono07@000000000000007Boo`1i0?ooo`030000003oool0oooo01<0oooo00120?ooo`030000003o
ool0oooo06/0oooo00<0okmd0000000000000P0000000`0004P0W=oo0?ooo`020?ooo`090?oog`2L
B00000000000000007@0_ooo0?ooo`3ooml0W4P00080000000@007Bo0?ooo`3oool0gia80`000000
101d_ol0oooo0?ooo`3OW4P30000000407Boo`3oool0oono07@00080000000<0M;oo0?ooo`3oool0
203oool01@3ookl0M0000000000004P0W=oo0080oooo00H0okmd00000000000000000000B02Lgol2
0?ooo`050=nLB0000000000000000018W=l0VP3oool01@3ookl0M000000000000000M;oo00@0oooo
00D0gia80000000000000000001d_`020?ooo`090?oog`2LB00000000000000007@0_ooo0?ooo`3o
oml0W4P00080000000D007Bo0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?oog`2L
B0000P0000001@0007@0_ooo0?ooo`3ooml0W4P00080000000@007Bo0?ooo`3oool0gia80P000000
0`00B9`0gooo0?ooo`020?ooo`090?oog`2LB00000000000000007@0_ooo0?ooo`3ooml0W4P00080
000000P007Bo0?ooo`3oool0omnL04P000000000001d0;ooo`<0oooo00D0oono07@0000000000000
07Boo`020?ooo`050=nLB000000000000000001d_ol00P3oool01`3OW4P00000000000000000M;oo
0?oog`2LB0000P0000001@0007@0_ooo0?ooo`3ooml0W4P00080000000<007Bo0?ooo`3oool0Y03o
ool00`3OW4P00000000000090000000304RLg`3oool0oooo00H0oooo00D0omnL04P0000000000000
04RLg`0D0?ooo`050?oo_`1d000000000000001d_ol0N@3oool00`000000oooo0?ooo`0C0?ooo`00
@P3oool00`000000oooo0?ooo`1[0?ooo`040;md00000000000004Q8B080000000H007Bo0?ooo`3o
ool0oooo0?oOW01800020000000307Boo`3oool0oooo00H0oooo00D0oooO09a8000000000000001d
_`030?ooo`040?oo_`1d000004RL0=ooo`80oooo00D0oono07@000000000000007Boo`0:0?ooo`05
0?oo_`1d000000000000B02Lgol00P3oool01@3o_g@00000000000000000M;oo00@0oooo00D0_g@0
00000000000004RL0=ooo`2I0?ooo`050?oo_`1d000000000000001d_ol00`3oool01P3ogi`0B000
000000000000001d0;ooo`80oooo00D0omnL04P000000000000007Boo`090?ooo`050?oo_`1d0000
00000000001d_ol00P3oool01@3ogi`0B000000000000000M;oo00T0oooo00D0gia8000000000000
04RL0=ooo`030?ooo`050?oOW018000000000000001d_ol02@3oool01@3ogi`0B0000000000007@0
_ooo00<0oooo00P0oono07@000000000000007Boo`3oool0oooO09a80080000000/007Bo0?ooo`3o
ool0oooo0?oo_`1d000004RL0=ooo`3oool0omnL04P000020000000307Boo`3oool0oooo0:/0oooo
00<0gia80000000000002@0000000`18W=l0oooo0?ooo`070?ooo`050?noM000000000000000001d
_ol04`3oool01@3ookl0M000000000000000M;oo07T0oooo00<000000?ooo`3oool04`3oool00480
oooo00<000000?ooo`3oool0JP3oool02@3ookl0M0000000000007@0_mnL04P000000000001d0;oo
o`020?ooo`050?noM000000000000000M02oool0203oool01@3ooml0W4P0000000000000B9cO00T0
oooo00D0oono07@000000000000007Boo`0:0?ooo`050?oo_`1d000000000000B02Lgol00P3oool0
1@3o_g@000000000000007@0_ooo00@0oooo00D0okmd00000000000004RL0=ooo`2I0?ooo`050?oo
_`1d000000000000001d_ol00P3oool00`3ooml0W4P0000000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000000`0007@0_ooo0?ooo`080?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@3o_g@000000000000007@0_ooo00T0oooo00D0gia800000000000004RL0=ooo`030?ooo`050?no
M000000000000000M02oool02@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00P0oono07@0
00000000000007Boo`3oool0oooO09a80080000000<0B9cO0?ooo`3oool01P3oool01@3o_g@00000
0000000007@0_ooo0:d0oooo00<0gia80000000000002@0000000`18W=l0oooo0?ooo`080?ooo`05
0=nLB0000000000000000000M;l04P3oool01@3ookl0M000000000000000M;oo07T0oooo00<00000
0?ooo`3oool04`3oool00480oooo00<000000?ooo`3oool0JP3oool01P3OW4P0000000000000B9`0
gooO09a80080000000@0M;oo0?ooo`3oool0okmd2P000000100004P0W=oo0?oo_`1d000200000003
07Boo`3oool0oooo00L0oooo00D0oono07@000000000000007Boo`0:0?ooo`050?oo_`1d00000000
0000B02Lgol00P3oool01@3o_g@0000000000000B9`0gooo00@0oooo00D0okmd000000000000001d
0;ooo`2I0?ooo`080?oo_`1d000000000000001d_ol0oooo0?oog`2LB0030000000304RLg`3oool0
oooo0080oooo00<0okmd000000000000200000001@0004P0W=oo0?ooo`3ookl0M0000080000000@0
M;oo0?ooo`3oool0okmd2P000000100004P0W=oo0?ooo`3OW4P2000000030018W03Oool0oooo0080
oooo00<0okmd00000000000020000000200004P0W=oo0?ooo`3ogi`0B0000000000004P0W=oo0`3o
ool0203ookl0M000000000000000M;oo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`060?oo
o`030?noM0000000000000P0000000<0001809cOo`3oool0Y03oool0103ogi`0B00000000000M;l2
0?ooo`050?oog`2LB000000000000018W=l03@3oool01P3o_g@0000000000000000004RL0=oooa00
oooo00D0oono07@000000000000007Boo`1i0?ooo`030000003oool0oooo01<0oooo00120?ooo`03
0000003oool0oooo06T0oooo00L0oooO09a800000000000007Boo`3oool0gia80080000000@007Bo
0?ooo`3oool0okmd2P000000100007@0_ooo0?oog`2LB0020000000307Boo`3oool0oooo00L0oooo
00D0oono07@000000000000007Boo`0:0?ooo`050?oo_`1d000000000000B02Lgol00P3oool01@3o
_g@000000000000007@0_ooo00@0oooo00D0gia8000000000000001d0;ooo`2I0?ooo`030?oo_`1d
0000000000L0000000<0M;oo0?ooo`3oool00`3oool00`3o_g@0000000000008000000050000M02o
ool0oooo0?oo_`1d00000P000000101d_ol0oooo0?ooo`3o_g@:000000040000M02oool0oooo0=nL
B080000000<004RL0=ooo`3oool00P3oool00`3o_g@0000000000008000000080000M02oool0oooo
0?oOW018000000000000B02Lgol30?ooo`080?oo_`1d000000000000001d_ol0oooo0?oog`2LB002
0000000307Boo`3oool0oooo00H0oooo00<0okmd000000000000200000000`0007@0_ooo0?ooo`2U
0?ooo`070=nLB0000000000007Boo`3oool0oooO09a800020000000304RLg`3oool0oooo00`0oooo
00H0okmd00000000000000000018W03Oool?0?ooo`050?oo_`1d000000000000001d_ol0N@3oool0
0`000000oooo0?ooo`0C0?ooo`00@P3oool00`000000oooo0?ooo`1Y0?ooo`0A0?oOW01800000000
0000M02oool0oooo0?oOW018000000000000M02oool0oooo0?oOW018000000000000B02Lgol00`3o
ool01`3o_g@0000000000000B9`0gooo0?oog`2LB0000P0000001`00M;l0oooo0?ooo`3oool0omnL
04P00018W=l00`3oool01@3ookl0M000000000000000M;oo00X0oooo00D0oono07@0000000000018
09cOo`020?ooo`050?noM000000000000000B02Lgol0103oool01@2oM000000000000000B9`0gooo
09T0oooo00<0oono07@0000000002@0000002@00B9`0gooo0?ooo`3oool0omnL04P0000000000018
09cOo`030?ooo`080?noM000000000000018W03Oool0oooo0?oo_`1d00020000000807Boo`3oool0
oooo0?oOW018000000000000B02Lgol30?ooo`070?noM000000000000018W03Oool0oooo0=nLB002
000000030000B02Lgol0oooo0080oooo00D0omnL04P000000000001809cOo`030?ooo`080?noM000
000000000018W03Oool0oooo0?oOW01800020000000607Boo`3oool0oooo0?ooo`3ogi`0B0000P00
0000101d_ol0oooo0?oog`2LB00200000007001d_`3oool0oooo0?ooo`3ogi`0B00004RLg`020?oo
o`050?oOW018000000000000B02Lgol00`3oool01@3o_g@0000000000000B9`0gooo0:H0oooo00L0
oono07@000000000001d0;ooo`3ooml0W4P00080000000<0B9cO0?ooo`3oool03@3oool01@3o_g@0
000000000000000007Bo00l0oooo00D0oono07@000000000000007Boo`1i0?ooo`030000003oool0
oooo01<0oooo00120?ooo`030000003oool0oooo06T0oooo00@0gia800000000000007Bo0P3oool0
203ooml0W4P0000000000000B9cO0?ooo`3ooml0W4P00P0000001@00B9`0gooo0?ooo`3ookl0M000
0080000000@007Bo0?ooo`3oool0gia80`000000101d_ol0oooo0?oog`2LB002000000050000M02o
ool0oooo0?oo_`1d00000P0000000`1d_ol0oooo0?ooo`080?ooo`050?oo_`1d000000000000B02L
gol00P3oool01P3o_g@00000000000000000001809cOo`80oooo00D0gia8000000000000000004RL
g`2J0?ooo`030?oo_`1d0000000000X0000000D007Bo0?ooo`3oool0oooO09a80002000000050018
W03Oool0oooo0?oo_`1d00000P0000001@00M;l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooO09a80002000000050018W03Oool0oooo0?oo_`1d00000P0000001000M;l0oooo0?oo
o`3OW4P300000006001d_`3oool0oooo0?ooo`3ooml0W4P00P0000001@00B9`0gooo0?ooo`3ookl0
M0000080000000D007Bo0?ooo`3oool0omnL04P00002000000050000B02Lgol0oooo0?ooo`2oM000
0`000000101d_ol0oooo0?ooo`3OW4P30000000407Boo`3oool0oooO09a80080000000@0001d0;oo
o`3ooml0W4P00P0000001@00B9`0gooo0?ooo`3ookl0M0000080000000<007Bo0?ooo`3oool0YP3o
ool01P3o_g@0000000000000M;l0oooO09a80080000000<0B9cO0?ooo`3oool03P3oool01@3o_g@0
0000000000000000M;oo00h0oooo00D0oono07@000000000000007Boo`1i0?ooo`030000003oool0
oooo01<0oooo00120?ooo`030000003oool0oooo06P0oooo00D0oono07@000000000000007Boo`03
0?ooo`070=nLB000000000000018W03Oool0oooo0?noM008000000060000B02Lgol0oooo0?ooo`3o
okl0M000200000001@00M;l0oooo0?ooo`3ookl0M0000080000000<0M;oo0?ooo`3oool0203oool0
1@3ookl0M0000000000004P0W=oo0080oooo00<0okmd000000000000200000000`0007@0_ooo0?oo
o`2I0?ooo`050?oo_`1d000000000000001d_ol0103oool01P3ooml0W4P0000000000000001809cO
o`80oooo00<0okmd0000000000001P000000100004P0W=oo0?ooo`2oM006000000030018W03Oool0
okmd00P0000000D0001809cOo`3oool0oooo0=nLB00600000003001d_`3oool0okmd00P0000000H0
001809cOo`3oool0oooo0?oOW0180009000000060000M02oool0oooo0?ooo`3ookl0M00020000000
1000M;l0oooo0?ooo`3o_g@8000000030000B02Lgol0oooo0:P0oooo00D0_g@0000000000000M;oO
09a800020000000304RLg`3oool0oooo00l0oooo00@0_g@000000000000007Bo2P3oool01P3ookl0
M01809cOo`3oool0oono07@00080000000<0M;oo0?ooo`3oool0M`3oool00`000000oooo0?ooo`0C
0?ooo`00@P3ooooo00000?l00000o`00000F000001D0oooo003o0?ooool0ooooo`3ooom]0?ooo`00
o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]
0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0oooo
o`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?oo
ool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo
003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?oo
ofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3o
oooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0
ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3o
ool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0
ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo
0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00
o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]
0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0oooo
o`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?oo
ool0oooo>`3oool00`3ookl0M0000000000400000003001d_`3oool0oooo0?l0oooo:03oool00?l0
ooooo`3ooolj0?ooo`030=nLB0000000000000H0000000<0001809cOo`3oool0o`3ooolW0?ooo`00
o`3ooooo0?ooocT0oooo00<0omnL04P000000000200000000`00B9`0gooo0?ooo`3o0?ooobH0oooo
003o0?ooool0oooo>@3oool01@3o_g@0000000000000000007Bo00<0oooo00D0gia8000000000000
001809cOo`3o0?ooobL0oooo003o0?ooool0oooo@@3oool01@3ookl0M000000000000000M;oo0?l0
oooo9`3oool00?l0oooo`03oool01P3o_g@00000000000000000001809cOo`P0oooo00<0omnL04P0
000000000P0000000`0007@0_ooo0?ooo`060?ooo`030;md0000000000000080000000<007Bo0?oo
o`3oool00`3oool00`3ooml0W4P000000002000000030018W03Oool0oooo0080oooo00<0oono07@0
000000000P0000000`0004P0W=oo0?ooo`040?ooo`050=nLB000000000000018W03Oool02`3oool0
0`3ookl0M0000000000:0000000607Boo`3oool0oooo0?ooo`3ogi`0B0000`0000000`0007@0_ooo
0?ooo`030?ooo`050?oOW018000000000000M02oool00`3oool01@3ookl0M000000000000000M;oo
00@0oooo00<0oooO09a8000000000P0000000`1d_ol0oono07@000020000000607Boo`3oool0oooo
0?ooo`3ooml0W4P00`0000001`00B9`0gooo0?oOW018000000000000B02Lgol00`3oool01@3ookl0
M000000000000000M;oo0?l0oooo403oool00?l0oooo`03oool00`2oM00000000000000200000003
04RLg`3oool0oooo00D0oooo00<0gia80000000000001@0000000`18W=l0oooo0?ooo`020?ooo`03
0?oOW0180000000000D0000000<0001809cOo`3oool00P3oool00`2oM00000000000000200000005
0018W03Oool0oooo0?oog`2LB0001`0000000`00B9`0gooo0?ooo`020?ooo`050=nLB00000000000
0018W03Oool02`3oool00`3ookl0M0000000000:0000000407Boo`3oool0oooo0=nLB0L0000000T0
B9cO0?ooo`3oool0oooo0?oOW018000000000000M02oool00`3oool01@3ookl0M000000000000000
M;oo00<0oooo00<0omnL04P000000000100000001@18W9`0M000000000000000M;oo00<0oooo00<0
_g@00000000000000P0000001`00B9`0gooo0?oOW018000000000000B02Lgol00`3oool01@3ookl0
M000000000000000M;oo0?l0oooo403oool00?l0oooo_`3oool00`3ookl0M0000000000300000003
0018W03Oool0oooo00@0oooo00<0okmd0000000000001P0000001P0004P0W=oo0?ooo`3oool0oono
07@000P0000000D004RL0=ooo`3oool0oono07@00004000000040018W03Oool0oooo0;md00T00000
00D007Bo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo00X0oooo00<0oono07@00000
00002P0000000`1d_ol0oooo0?noM008000000090000B02Lgol0oooo0?ooo`3ogi`0B00000000000
07@0_ooo00<0oooo00D0oono07@000000000000007Boo`020?ooo`030?oog`2LB000000000T00000
00D0M;oo0?ooo`3oool0oono07@00004000000070018W03Oool0omnL04P000000000001809cOo`03
0?ooo`050?oo_`1d000000000000001d_ol0o`3oool@0?ooo`00o`3ooono0?ooo`080=nLB0000000
00000018M01dB00000000000B02Lgol40?ooo`090?oog`2LB00000000000000007@0_ooo0?ooo`3o
oml0W4P00080000000@007Bo0?ooo`3oool0gia80`000000101d_ol0oooo0?ooo`3OW4P300000004
07Boo`3oool0oono07@00080000000H0M;oo0?ooo`3oool0oooo0?oOW0180002000000050018W03O
ool0oooo0?ooo`2oM0000`000000101d_ol0oooo0?ooo`3OW4P2000000030018W03Oool0oooo00X0
oooo00D0oono07@000000000000007Boo`090?ooo`090?oog`2LB00000000000000007@0_ooo0?oo
o`3ooml0W4P00080000000P007Bo0?ooo`3oool0omnL04P000000000001d0;ooo`<0oooo00D0oono
07@000000000000007Boo`020?ooo`050?noM0000000000000000000M;l00P3oool00`3ogi`0B000
000000020000000507Boo`3oool0oooo0?oo_`1d00000P0000002@1d_ol0oooo0?ooo`3oool0omnL
04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool@0?ooo`00o`3o
oonn0?ooo`060?oog`2LB000000000000018W=l0gia80P0000000`18W=l0oooo0?ooo`020?ooo`05
0?oOW018000000000000001d_ol0203oool01@3ooml0W4P000000000000007Bo00<0oooo00@0oono
07@00000B9`0gooo0P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0gia8000000000000
001d0;ooo`030?ooo`050?oog`2LB000000000000000M;l00P3oool01@3OW4P0000000000000B9`0
gooo00/0oooo00D0oono07@000000000000007Boo`090?ooo`050?oOW018000000000000001d_ol0
2@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00D0oono07@000000000000007Boo`020?oo
o`050;md0000000000000018W03Oool00`3oool01@3o_g@00000000000000000M;oo0080oooo00D0
oono07@000000000000007Boo`030?ooo`050?oOW018000000000000B02Lgol00`3oool01@3ookl0
M000000000000000M;oo0?l0oooo403oool00?l0oooo_P3oool01P3ogi`0B0000000000004P0W=oo
0?noM080000000<004RL0=ooo`3oool00P3oool01@3o_g@000000000000007@0_ooo00P0oooo00D0
oooO09a800000000000004RLg`090?ooo`050?oo_`1d000000000000001d_ol00`3oool0102oM000
000000000000M;l50?ooo`070=nLB000000000000018W03Oool0oooo0=nLB002000000030018W03O
ool0oooo00X0oooo00D0oono07@000000000000007Boo`090?ooo`050?noM000000000000000M02o
ool02@3oool01@3ogi`0B0000000000007@0_ooo00<0oooo00P0oono07@000000000000007Boo`3o
ool0oooO09a80080000000<0B9cO0?ooo`3oool00P3oool01@3ookl0M000000000000000M;oo0080
oooo00D0oono07@000000000000007Boo`030?ooo`050?oOW018000000000000B02Lgol00`3oool0
1@3ookl0M000000000000000M;oo0?l0oooo403oool00?l0oooo_P3oool02P3OW4P0000000000000
07@0_ooo0?oo_`1d000000000000B02Lgol30?ooo`030?noM0000000000000P0000000@0001809cO
o`3ookl0M0000P0000000`1d_ol0oooo0?ooo`070?ooo`050?oo_`1d000000000000001d_ol00P3o
ool01@3ooml0W4P0000000000000B9cO00D0oooo00L0okmd000000000000001d0;ooo`3oool0gia8
0080000000<004RL0=ooo`3oool02P3oool01@3ookl0M000000000000000M;oo00T0oooo00<0okmd
00000000000020000000200004P0W=oo0?ooo`3ogi`0B0000000000004P0W=oo0`3oool0203ookl0
M000000000000000M;oo0?ooo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`020?ooo`050?oog`2L
B00000000000001d_ol00P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P00000
0000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool@0?ooo`00o`3ooonm0?oo
o`050?oog`2LB000000000000000M;l00P3oool0102oM000000000000018W=l30?ooo`030?noM000
0000000000P0000000@0001d0;ooo`3ooml0W4P00P0000000`1d_ol0oooo0?ooo`070?ooo`050?oo
_`1d000000000000001d_ol00P3oool01@3ooml0W4P000000000000007Bo00D0oooo00L0gia80000
0000000004RL0=ooo`3oool0gia80080000000<004RL0=ooo`3oool02P3oool01@3ookl0M0000000
00000000M;oo00T0oooo00<0okmd00000000000020000000200007@0_ooo0?ooo`3ogi`0B0000000
000004P0W=oo0`3oool0203ookl0M000000000000000M;oo0?ooo`3ooml0W4P00P0000000`18W=l0
oooo0?ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3oool01@3ookl0M000000000000000
M;oo00<0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol0
o`3oool@0?ooo`00o`3ooonm0?ooo`050?oOW018000000000000001d_ol00P3oool01@3o_g@00000
0000000007@0_ooo0080oooo00D0omnL04P000000000001809cOo`030?ooo`070?noM00000000000
0018W03Oool0oooO09a8000200000007001d_`3oool0oooo0?ooo`3ogi`0B00004RLg`030?ooo`05
0?oo_`1d000000000000001d_ol00`3oool01@3OW4P000000000000007@0_ooo00<0oooo00D0oooO
09a8000000000000001d_`020?ooo`050=nLB000000000000000B02Lgol02`3oool01@3ookl0M000
000000000000M;oo00T0oooo00D0omnL04P000000000001809cOo`030?ooo`080?noM00000000000
0018W03Oool0oooo0?oOW01800020000000607Boo`3oool0oooo0?ooo`3ogi`0B0000P000000101d
_ol0oooo0?ooo`2oM002000000030018W03Oool0oooo0080oooo00D0omnL04P000000000000007Bo
o`020?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ogi`0B000000000000000B9cO00<0
oooo00D0omnL04P000000000000007Boo`3o0?oooa00oooo003o0?oookd0oooo00D0gia800000000
0000001d0;ooo`020?ooo`050?oo_`1d000000000000001d_ol00P3oool02@3ooml0W4P000000000
000004RL0=ooo`3oool0oono07@0000200000004001d_`3oool0oooo0=nLB0<0000000@0M;oo0?oo
o`3ooml0W4P00P0000001@0007@0_ooo0?ooo`3ookl0M0000080000000H0M;oo0?ooo`3oool0oooo
0?oOW0180002000000050018W03Oool0oooo0?ooo`2oM0000`000000101d_ol0oooo0?ooo`3OW4P3
00000003001d_`3oool0oooo00T0oooo00D0oono07@000000000000007Boo`090?ooo`090?oog`2L
B000000000000000B9`0gooo0?ooo`3ookl0M0000080000000D007Bo0?ooo`3oool0omnL04P00002
000000050000B02Lgol0oooo0?ooo`2oM0000`000000101d_ol0oooo0?ooo`3o_g@300000005001d
_`3oool0oooo0?oo_`1d00000`0000001@1d_ol0oooo0?ooo`3ookl0M0000080000000H0M;oo0?oo
o`3oool0oooo0?oOW0180002000000050000B02Lgol0oooo0?ooo`2oM0000P0000000`0004P0W=oo
0?ooo`3o0?ooo`l0oooo003o0?oook`0oooo00D0oooO09a8000000000000001d_`040?ooo`040;md
000000000000001d_`<0oooo00<0okmd0000000000001P0000001P0004P0W=oo0?ooo`3oool0oono
07@000P0000000<007Bo0?ooo`2oM0001P0000001000M;l0oooo0?ooo`2oM00900000005001d_`3o
ool0oooo0?ooo`3OW4P01P0000000`00M;l0oooo0?ooo`060?ooo`050?oo_`1d000000000000001d
_ol02P3oool00`3o_g@0000000000006000000060000B02Lgol0oooo0?ooo`3ogi`0B0002@000000
1P0007@0_ooo0?ooo`3oool0oooO09a800X0000000<0M;oo0?ooo`2oM0001P0000001000M;l0oooo
0?oOW0180009000000030000M02oool0oooo0?l0oooo3`3oool00?l0oooo_03oool01@3ogi`0B000
000000000000B9cO00@0oooo00D0gia8000000000000001d0;ooo`030?ooo`030=nLB00000000000
00D0000000<0M;oo0?ooo`3oool00P3oool00`3ogi`0B00000000005000000040000M02oool0oooo
0;md00H0000000D007Bo0?ooo`3oool0oooo0;md0007000000030018W03Oool0oooo0080oooo00@0
gia8000000000000B4Q80`0000000`0007@0_ooo0?ooo`060?ooo`050?oo_`1d000000000000001d
_ol02`3oool00`3OW4P00000000000050000000907Boo`3oool0oooo0?ooo`3ogi`0B00000000000
B7@0M4P000H0000000<0B9cO0?ooo`3oool00P3oool00`3ogi`0B0000000000400000007001d_`2o
M00000000000001d_ol0oooo0;md000600000007001d_`3oool0omnL04P000000000001809bLM006
0000000304RLg`3oool0oooo0?l0oooo3`3oool00?l0oooo_03oool01@3OW4P000000000000004P0
W=oo00@0oooo00D0omnL04P000000000000007Boo`040?ooo`030?oo_`1d000000000080000000<0
04RL0=ooo`3oool01P3oool00`2oM0000000000000020000000504RLg`3oool0oooo0?ooo`2oM000
1P0000000`00M;l0oooo0?ooo`020?ooo`030?oOW018000000000080000000<0001809cOo`3oool0
103oool01@3OW4P0000000000018W=l0gia80080000000<0001809cOo`3oool01P3oool01@3ookl0
M000000000000000M;oo00`0oooo00<0oono07@0000000000P0000000`00B9`0gooo0?ooo`030?oo
o`060?oOW018000000000018W03Oool0okmd100000000`1d_ol0oooo0?ooo`040?ooo`030?oog`2L
B00000000080000000<0B9cO0?ooo`2oM0000P0000000`1d_ol0oooo0;md000600000009001d_`3o
ool0omnL04P000000000001809cOo`3ookl0M00000<0000000<0M;oo0?ooo`3oool0o`3oool@0?oo
o`00o`3ooonk0?ooo`060?oog`2LB000000000000000B9`0gooo103oool01@3ooml0W4P000000000
000007Bo01`0oooo00D0oono07@000000000000007Boo`0R0?ooo`050?oo_`1d000000000000001d
_ol0=@3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P000000000001809cOo`3o
0?oooaP0oooo003o0?oook/0oooo00D0omnL04P000000000000004RLg`060?ooo`050=nLB0000000
00000000M02oool06`3oool01@3ookl0M000000000000000M;oo0280oooo00D0oono07@000000000
000007Boo`0e0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ogi`0B0000000000004P0
W=oo0?l0oooo603oool00?l0oooo^`3oool01@3OW4P000000000000004P0W=oo00H0oooo00D0omnL
04P000000000000007Boo`0L0?ooo`040?oOW0180000000007Boob80oooo00D0oono07@000000000
000007Boo`0f0?ooo`040?oOW0180000000007Boo`<0oooo00D0omnL04P000000000001809cOo`3o
0?oooaP0oooo003o0?oookX0oooo00H0oooO09a80000000000000018W03Oool60?ooo`050?oog`2L
B000000000000000M;l07P3oool00`3OW4P0M;oo0?ooo`0Q0?ooo`050?oo_`1d000000000000001d
_ol0>03oool00`3OW4P0M;oo0?ooo`020?ooo`050?oOW018000000000000B02Lgol0o`3ooolH0?oo
o`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3o
oom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0
ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o
0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00=80oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`210?ooo`030?oog`2LB00000000080000000<0001d0;ooo`3o
ool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`1`0?ooo`050?oo_`1d000000000000001d_ol01P3oool00`3o
oml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00
B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0JP3oool01@3o
okl0M000000000000000M;oo00H0oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`05
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002
000000030018W03Oool0oooo06D0oooo00<0okmd000000000000200000000`0007@0_ooo0?ooo`02
0?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002
000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0R
0?ooo`00d@3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo07l0oooo00<0omnL04P0
000000001@0000000`1d_ol0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cO
o`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo06l0oooo00D0oono07@0
00000000000007Boo`050?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`1Y0?ooo`050?oo_`1d000000000000001d_ol01@3oool00`3ogi`0B0000000
00050000000307Boo`3oool0oooo0080oooo00<0omnL04P000000000100000000`0004P0W=oo0?oo
o`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0I03oool00`3ookl0M0000000
0008000000060000M02oool0oooo0?ooo`3ogi`0B0001@0000000`0004P0W=oo0?ooo`030?ooo`03
0?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B0000000000400000003
0000B02Lgol0oooo0240oooo003@0?ooo`030?oo_`1d0000000000H0000000<004RL0=ooo`3oool0
O@3oool00`3ookl0M00000000006000000060000B02Lgol0oooo0?ooo`3ookl0M0001`0000001P00
B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0KP3oool01@3ookl0M0000000
00000000M;oo00@0oooo00<0oono07@0000000001P0000001P00B9`0gooo0?ooo`3oool0oono07@0
00L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo06P0oooo00D0
oono07@000000000000007Boo`040?ooo`030?oo_`1d0000000000H0000000H0001809cOo`3oool0
oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?oo
o`1T0?ooo`030;md00000000000000L0000000D0001d0;ooo`3oool0oono07@00007000000060018
W03Oool0oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<0
04RL0=ooo`3oool0803oool00=00oooo00L0okmd000000000000001809cOo`3oool0okmd00<00000
00<0M;oo0?ooo`3oool0O03oool0203OW4P00000000000000000M;oo0?ooo`3ookl0M0000P000000
1000M;l0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0
okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo06d0oooo00D0oono07@0
00000000000007Boo`040?ooo`070?noM000000000000000B02Lgol0oooo0?noM0030000000407Bo
o`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2
000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0I`3oool01@3ookl0M0000000
00000000M;oo00@0oooo00P0gia8000000000000000007Boo`3oool0oono07@00080000000@007Bo
0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080
000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1S0?ooo`050?oOW01800000000
00000018W=l0203oool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo
0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000
100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo01l0oooo003@0?ooo`040;md00000000
0000001d_`<0oooo00@0_g@0000000000000B9cOO@3oool01@3ooml0W4P000000000000007Bo00<0
oooo00L0okmd000000000000001d0;ooo`3oool0_g@00080000000D007Bo0?ooo`3oool0oooo0;md
00020000000404RLg`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md000200000003
04RLg`3oool0oooo06d0oooo00D0oono07@000000000000007Boo`040?ooo`040;md000000000000
001d_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md
00000000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=mY
0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ooml0W4P000000000000007Bo00<0oooo
00L0okmd000000000000001d0;ooo`3oool0_g@00080000000D007Bo0?ooo`3oool0oooo0;md0002
0000000404RLg`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md00020000000304RL
g`3oool0oooo06@0oooo00D0okmd000000000000000007Boo`070?ooo`040;md000000000000001d
_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md0000
0000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=lQ0?oo
o`00c`3oool01@3ooml0W4P0000000000000M;oo00<0oooo00D0gia800000000000004RL0=ooo`1l
0?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3ogi`0B0000000000004P0W=oo0?oog`2L
B0000P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P000000
1@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool0K@3oool01@3ookl0M0000000
00000000M;oo00<0oooo00D0oooO09a800000000000007Boo`030?ooo`070=nLB000000000000018
W03Oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oo
g`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`1W0?ooo`05
0?oo_`1d000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0omnL
04P000000000001809cOo`3ooml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB00200000004
0018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0
oooo06D0oooo00D0gia80000000000000000001d_`050?ooo`050?oog`2LB00000000000001d_ol0
0`3oool01`3OW4P0000000000000B9`0gooo0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3oool0
gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia800800000
00<004RL0=ooo`3oool07`3oool00<l0oooo00D0oono07@000000000000007Boo`030?ooo`050?no
M000000000000018W03Oool0Q03oool01`3ogi`0B0000000000004P0W=oo0?oo_`1d00000P000000
1@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo
0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool0K@3oool01@3ookl0M000000000000000M;oo
00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000000000000018W03Oool0oono
07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000
000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`1W0?ooo`050?oo_`1d0000
00000000001d_ol02`3oool01`3ogi`0B0000000000004P0W=oo0?oo_`1d00000P0000001@1d_ol0
oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000<004RL0=ooo`3oool0IP3oool01P3o_g@0000000000000000004RL0=ooo`<0
oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000000000000018W03Oool0oono07@0
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0O0?ooo`00c`3oool01@3ookl0
M000000000000000M;oo00<0oooo00D0okmd000000000000001d0;ooo`240?ooo`070?noM0000000
00000000B02Lgol0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0
_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`1]
0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo
00L0okmd000000000000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002
000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000
M02oool0oooo06L0oooo00D0oono07@000000000000007Boo`0;0?ooo`070?noM000000000000000
B02Lgol0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`1W0?ooo`06
0?noM0000000000000000000B9`0gooo0P3oool01@3ookl0M000000000000000M;oo00<0oooo00L0
okmd000000000000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM0020000
00040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02o
ool0oooo01l0oooo003?0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o_g@000000000
000007@0_ooo07d0oooo00P0gia800000000000004RL0=ooo`3oool0oono07@00080000000@004RL
0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0
M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0K@3oool01@3o
okl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000
000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000
07@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?oo
o`1W0?ooo`050?oo_`1d000000000000001d_ol0103oool0203OW4P0000000000000B9`0gooo0?oo
o`3ookl0M0000P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
07@0_ooo0?ooo`1X0?ooo`050?noM0000000000000000000M;l00P3oool01@3ookl0M00000000000
0000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?no
M002000000030000M02oool0oooo01l0oooo003?0?ooo`050?oo_`1d000000000000001d_ol00`3o
ool01@3o_g@000000000000007@0_ooo07d0oooo00<0okmd0000000000001`000000101d_ol0oooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`1]0?ooo`050?oo_`1d
000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd00000000
0000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02o
ool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo06L0
oooo00D0oono07@000000000000007Boo`040?ooo`030?noM0000000000000L0000000@0M;oo0?oo
o`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M000
0P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool0J@3oool0203o_g@0
0000000000000000M;oo0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;oo
o`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool07`3o
ool00<l0oooo00D0oono07@000000000000007Boo`030?ooo`050?noM000000000000018W03Oool0
O@3oool00`3ogi`0B0000000000600000005001d_`3oool0oooo0?oo_`1d00000P0000001@1d_ol0
oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000<004RL0=ooo`3oool0J@3oool01P3ookl0M01809cOo`3oool0oono07@00080
000000H0M;oo0?ooo`3oool0oooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0
gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`1S
0?ooo`060?oo_`1d04P0W=oo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`020?ooo`030?oO
W0180000000000H0000000D007Bo0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00000`00B9`0gooo0?ooo`1Z0?ooo`070;md000000000000001d_`3oool0oono07@0000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0
oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o
_g@00P0000000`00B9`0gooo0?ooo`0O0?ooo`00c`3oool01@3ooml0W4P0000000000000M;oo00<0
oooo00D0gia800000000000004RL0=ooo`1m0?ooo`050?oog`2LB00000000000B018B0000`000000
1P1d_ol0oooo0?ooo`3oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB00200000004
0018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0
oooo06T0oooo00H0oono07@00000000004RL0=oo_`1d00020000000607Boo`3oool0oooo0?ooo`3o
oml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P00
00001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0
oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool0H`3oool01P3ookl0M00000000000B9`0
gono07@00080000000<0M;oo0?ooo`3oool00P3oool01@3ooml0W4P00000000004P0B4P000<00000
00H0M;oo0?ooo`3oool0oooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P000000
1000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo
0?ooo`1R0?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@000000000000007@0_ooo
0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P0
0P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d
_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool07`3oool00=00oooo00@0_g@00000
0000000007Bo0`3oool0102oM000000000000000M;mo0?ooo`040;md00000000000007Boo`P0oooo
00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`040;md000000000000
001d_`<0oooo00@0_g@000000000000007BoJ`3oool00`3ookl0M000000000050000000307Boo`3o
ool0oooo0080oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`04
0;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000
M;l30?ooo`040;md000000000000001d_fD0oooo00<0oono07@0000000001@0000000`1d_ol0oooo
0?ooo`030?ooo`040;md00000000000007Boo`P0oooo00@0_g@000000000000007Bo0`3oool0102o
M000000000000000M;l20?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo
I03oool01@3ooml0W4P0000000000000B9cO00<0oooo00L0okmd000000000000001d0;ooo`3oool0
_g@00080000000D007Bo0?ooo`3oool0oooo0;md000200000004001d_`3oool0oooo0;md00800000
00D007Bo0?ooo`3oool0oooo0;md000200000004001d_`3oool0oooo0;md0080000000D007Bo0?oo
o`3oool0oooo0;md000200000003001d_`3oool0oooo01l0oooo003@0?ooo`070?noM00000000000
0000B02Lgol0oooo0?noM0030000000307Boo`3oool0oooo07d0oooo00@0gia800000000000007Bo
203oool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@2
000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0JP3oool00`3ooml0W4P00000
00040000000307Boo`3oool0oooo0080oooo00L0okmd000000000000001809cOo`3oool0okmd00<0
000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0
oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1T0?ooo`030?oo
g`2LB000000000@0000000<0M;oo0?ooo`3oool00`3oool0103OW4P0000000000000M;l80?ooo`07
0?noM000000000000000B02Lgol0oooo0?noM0030000000407Boo`3oool0oooo0?noM080000000@0
001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1S0?ooo`080;md0000000000000000B02L
gol0oooo0?oo_`1d0002000000040018W03Oool0oooo0?noM080000000@0001809cOo`3oool0okmd
0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?oo
o`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo01l0oooo003@
0?ooo`030?oo_`1d0000000000H0000000<004RL0=ooo`3oool0OP3oool00`3ogi`0B00000000006
0000000504RLg`3oool0oooo0?oo_`1d00001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0
000000<004RL0=ooo`3oool0K@3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0080
oooo00<0oono07@0000000001P0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL
0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo06L0oooo00<0okmd000000000000
0P0000000`1d_ol0oooo0?ooo`030?ooo`030?oOW0180000000000H0000000D0B9cO0?ooo`3oool0
oono07@00007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`1T
0?ooo`030?oOW0180000000000L0000000D0B9cO0?ooo`3oool0oono07@00007000000060018W03O
ool0oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL
0=ooo`3oool0803oool00=40oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`1o0?oo
o`030?oo_`1d0000000000H0000000H0B9cO0?ooo`3oool0oooo0?oOW0180005000000030000B02L
gol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`1_0?ooo`050?oOW018
000000000000001d_ol01@3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo
00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@00000
00<0001809cOo`3oool0J@3oool01@3ogi`0B000000000000000M;oo00D0oooo00<0oono07@00000
00001P0000001P18W=l0oooo0?ooo`3oool0omnL04P000D0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo06H0oooo00<0gia80000000000001@000000
0`00M;l0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`0Q0?ooo`00dP3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
0800oooo00<0oooO09a8000000001P0000000`18W=l0oooo0?ooo`020?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
0740oooo00@0gia8000000000000M;oo1P3oool00`3ooml0W4P000000002000000030018W03Oool0
oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB000
00000080000000<004RL0=ooo`3oool0J`3oool0103OW4P000000000001d_ol50?ooo`030?oog`2L
B000000000H0000000<0B9cO0?ooo`3oool00P3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`1X0?ooo`030?oo_`1d
0000000000<0000000<0M;oo0?ooo`3oool0103oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2L
B00000000080000000<004RL0=ooo`3oool08P3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?oo
ool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo
003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?oo
ofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3o
oooo0?ooofd0oooo00360?ooool00000o`00002=000001T0oooo00360?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01`0oooo0P00000I0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`8000006@3oool00<H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00;00oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?oo
o`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo002_0?ooo`030?oOW0180000000000@0000000<00018
09cOo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00[P3oool00`3ookl0M000000000060000
00030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00:h0oooo00L0okmd00000000
0000001809cOo`3oool0okmd00<0000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G
0?ooo`00[P3oool0102oM000000000000000M;l30?ooo`040;md00000000000004RLg`d0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00:d0oooo00D0oooO09a800000000000007Boo`030?ooo`050=nLB000
000000000018W03Oool0303oool500000?l0Ogmoo`1oOgn307moO`D000006@3oool00:d0oooo00D0
oono07@000000000000007Boo`030?ooo`050?noM000000000000018W03Oool0303oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00[@3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd00000000
0000001d0;ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002]0?ooo`050?oo_`1d000000000000
001d_ol00`3oool01@3o_g@000000000000007@0_ooo00`0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0:d0oooo00D0oono07@000000000000007Boo`030?ooo`050?noM000000000000000M02oool0303o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0G0?ooo`00[@3oool01@3ookl0M000000000000000M;oo00<0oooo00D0
okmd00000000000004RL0=ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002]0?ooo`050?oog`2L
B00000000000001d_ol00`3oool01@3OW4P0000000000000B9`0gooo00`0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool00:h0oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l=0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo002^0?ooo`070?noM000000000000000B02Lgol0oooo0?noM003
0000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00:h0oooo00<0oono07@0
000000001P0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002_0?ooo`03
0?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
/03oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo0`00000<
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool4000001T0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`0<0?oo
ool0IVKoa`1VI_l?0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0I`3ooooo06IVool0IVKo101VI_l?0?ooo`030000003oool0oooo01L0
oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?`3ooomT06IVohP0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0e0?oooc80IVKo;@3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0:`3ooolD06IVoeD0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo02D0oooo401VI_mO0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`X0
IVKoJ@3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0=0?ooo`0306K<IP3oool0oooo00d0oooo00<000000?ooo`3o
ool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`@0IVKo
K`3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
Q03ooolQ06K<IPh0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo02X0ooooo`1Vc6JY06K<IPl0oooo00<0
00000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo00`0ooooo`1Vc6JW06K<IPl0oooo00<0Ogmo0?ooo`3oool0303oool0
0`1Vc6H0oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`020?ooobP0I/aVJP3oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08D0
oooo7P1Vc6J80?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0OP3ooolK06K<IY80oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1f0?ooo`l0I/aV3`3oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0K`3oool?06K<IQH0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04H0oooo<01Vc6HN0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`120?ooobd0I/aV9@3oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`0n0?ooo`P0I/aV
CP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`@000006@3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`0j0?ooo`P0I/aVDP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=`3oool7
06K<IUH0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03<0oooo1`1Vc6IJ0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0_0?ooo`P0I/aVG@3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0
oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0:`3oool806K<IV40oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo02T0oooo1P1Vc6IU0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0T
0?ooo`0306K<IP3oool0oooo00D0I/aVJ03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool806K<
IVX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo1`1Vc6I/0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0
oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0R0?ooo`0406K<IP3oool0oooo06K<IVh0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3o
ool3000000`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`@000006@3o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0
oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool009<0oooo00<0okmd000000000000200000000`0007@0
_ooo0?ooo`020?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0
W4P000000002000000030018W03Oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool009<0oooo
00<0oono07@000000000200000001P0007@0_ooo0?ooo`3oool0omnL04P000D0000000<0001809cO
o`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool009@0oooo00<0_g@00000000000001`0000001@0007@0_ooo0?ooo`3ookl0M000
00L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool009@0oooo00D0omnL04P000000000000004RLg`080?ooo`070?noM000
000000000000B02Lgol0oooo0?noM0030000000407Boo`3oool0oooo0?noM080000000@0001809cO
o`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002E0?oo
o`050?noM000000000000000001d_ol01`3oool0102oM000000000000000M;l30?ooo`040;md0000
0000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=l=0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo002F0?ooo`050=nLB0000000000000000000M;l01@3oool01@3o
oml0W4P0000000000000M;oo00<0oooo00L0gia800000000000004RL0=ooo`3ooml0W4P000800000
00D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo00/0oooo1@00003o07moOol0
OgmoP`1oOgl5000001T0oooo002G0?ooo`060?noM0000000000000000000B9`0gooo0`3oool01@3o
okl0M000000000000000M;oo00<0oooo00L0okmd00000000000004RL0=ooo`3ookl0M00000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool009P0oooo00H0okmd00000000000000000018W03Oool20?ooo`050?oo_`1d00000000
0000001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo
0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
V@3oool01@3o_g@0000000000000000007Bo0080oooo00D0oono07@000000000000007Boo`030?oo
o`070?noM000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002J0?ooo`080?noM000
000000000000001d_ol0oooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000
100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002K0?ooo`070;md000000000000001d_`3oool0
oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo002C0?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o_g@000000000
000007@0_ooo0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=oo
o`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0G0?ooo`00T`3oool01@3ooml0W4P0000000000000B9cO00<0oooo00L0
okmd000000000000001d0;ooo`3oool0_g@00080000000D007Bo0?ooo`3oool0oooo0;md00020000
0004001d_`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md000200000003001d_`3o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool009@0oooo00P0_g@0000000000000001809cO
o`3oool0oono07@00080000000@004RL0=ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@3
0000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002D0?ooo`030?oOW0180000000000L0000000D0
B9cO0?ooo`3oool0oono07@00007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00
B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002E0?ooo`030=nLB0000000000000D0
000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0
oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0
oooo002F0?ooo`030?oo_`1d0000000000<0000000<0M;oo0?ooo`3oool0103oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M
0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01X0oooo1000000I0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo
0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`@000006@3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<00000
0?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?oo
o`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0
oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool06P3oool4000001T0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002I0?ooo`050?oo
g`2LB000000000000018W=l01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0
oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0
oooo002I0?ooo`050?oog`2LB000000000000018W=l0103oool00`3ogi`0B0000000000400000003
0000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo002I0?ooo`050?oog`2LB000000000000018W=l00`3oool00`3ookl0
M00000000006000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M
0?ooo`030000003oool0oooo01L0oooo002C0?ooo`030=nLB0000000000000T0000000<0B9cO0?oo
o`3o_g@00P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0
001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
002C0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`2oM0000P0000001@00M;l0oooo0?oo
o`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P0000001@00M;l0oooo0?ooo`3oool0_g@0
0080000000<0B9cO0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00T`3oool00`3OW4P0
0000000000090000000304RLg`3ooml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB0020000
00040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03O
ool0oooo00/0oooo1@00003o07moOol0OgmoP`1oOgl5000001T0oooo002C0?ooo`040?oOW0180000
0000001d_`80oooo00D0oooO09a800000000000004RLg`020?ooo`050?oo_`1d000000000000001d
_ol00`3oool01`3o_g@0000000000000B9`0gooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3o
ool0okmd0080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00U03oool0
1`3OW4P000000000001d_ol0oooo0?oog`2LB0000P0000001@18W=l0oooo0?ooo`3ookl0M0000080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo
0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool009@0oooo00L0oono07@000000000001d0;ooo`3ooml0W4P00080000000D0B9cO0?ooo`3oool0
oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo002E0?ooo`060?noM00000000000001d_`3ooml0W4P00P0000001@18W=l0oooo
0?ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool009H0oooo00D0_g@0000000000000M;oO09a800020000000504RLg`3o
ool0oooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3o
okl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<004RL0=ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0G0?ooo`00UP3oool01@3ookl0M00000000000B7@0M4P00080000000D0B9cO
0?ooo`3oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo
0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo002G0?ooo`030?noM0000000000000<0000000D0B9cO0?ooo`3o
ool0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM0000P0000001000M;l0oooo0?ooo`2o
M00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`00M;l0oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo002H0?ooo`030;md0000000000000080000000D0B9cO0?ooo`3oool0oooo
0?noM002000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P0000001000
04P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
09P0oooo00<0oono07@0000000000P0000001P18W=l0oooo0?ooo`3oool0oono07@000L0000000H0
04RL0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool009T0oooo00D0okmd000000000000000004RLg`040?ooo`030?oOW0180000000000@0
000000<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0
oooo00<000000?ooo`3oool05`3oool009X0oooo00@0_g@0000000000000B9cO1@3oool00`3ooml0
W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0
gooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo00360?ooo`<00000303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01X0oooo1000000I0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo
0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool0
0`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0J0?ooo`@000006@3oool00<H0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0
oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool001T0oooo00D0omnL04P0
00000000001809cOo`020?ooo`050?noM000000000000000001d_ol00P3oool01@3ogi`0B0000000
000004P0W=oo0080oooo00D0oono07@000000000000007Boo`0:0?ooo`030?oo_`1d0000000000X0
000000<0M;oo0?ooo`3oool00`3oool00`3ogi`0B00000000003000000030000B02Lgol0oooo00D0
oooo00D0okmd000000000000001d0;ooo`0>0?ooo`030?noM0000000000000@0000000<0M;oo0?oo
o`3oool0B`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`006@3oool01@3ogi`0B0000000000004P0W=oo
0080oooo00D0_g@0000000000000000004RLg`020?ooo`050?oOW018000000000000B02Lgol00P3o
ool01@3ookl0M000000000000000M;oo00X0oooo00<0oono07@0000000002P0000001P1d_ol0oooo
0?ooo`3oool0oono07@000P0000000<0001d0;ooo`3oool00`3oool01@3o_g@000000000000007@0
_ooo00`0oooo00<0oono07@0000000001`0000000`0004P0W=oo0?ooo`1:0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo000I0?ooo`080?oOW018000000000000001d_ol0oooo0?oog`2LB003000000040018
W03Oool0oooo0?noM080000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0
oooo00P0oooo00<0oono07@0000000002P0000001@1d_ol0oooo0?ooo`3ogi`0B00000X0000000<0
001809cOo`3oool00P3oool01@3o_g@000000000000007@0_ooo00/0oooo00<0oooO09a800000000
2@0000000`0007@0_ooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo000I0?ooo`080?oOW018
000000000000001d_ol0oooo0?oo_`1d0003000000040000M02oool0oooo0?noM080000000H00018
09cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@000000000
000007Boo`0:0?ooo`030?oog`2LB00000000080000000H0001d0;ooo`3oool0oooo0?oog`2LB003
000000050018W03Oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0:0?ooo`060=nLB000
0000000000000000B9`0gooo0`3oool01@2oM0000000000000000000B9cO04X0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool001T0oooo00l0omnL04P000000000000007Boo`3oool0omnL04P000000000M7Ad
0000000004P0W=oo0?ooo`3o_g@00P0000001P0004P0W=oo0?ooo`3oool0oono07@00080000000<0
M;oo0?ooo`3oool0203oool01@3ookl0M000000000000000M;oo00X0oooo00D0okmd000000000000
0000001d_`060?ooo`050;md0000000000000000001d_ol00P3oool01@3o_g@000000000000007@0
_ooo00X0oooo00H0oooO09a80000000000000018W03Oool50?ooo`050;md0000000000000018W03O
ool0B@3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`006@3oool03`3ogi`0B000000000000000M;oo0?oo
o`3OW4P000000000B02Lgkl0M00000000018W=l0oooo0?noM002000000060000B02Lgol0oooo0?oo
o`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?ooo`050?oo_`1d000000000000001d_ol02P3o
ool01@2oM00000000000000007@0_ooo00H0oooo00D0oono07@0000000000000001d_`020?ooo`05
0?noM000000000000000M02oool02P3oool01@3ookl0M000000000000000M;oo00H0oooo00D0gia8
00000000000004RL0=ooo`190?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo000I0?ooo`0?0?oOW0180000
00000000001d_ol0oooo0;md0000000004RL0=oog`2LB0000000001d_`3oool0okmd0080000000H0
001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@00000
0000000007Boo`090?ooo`050?oog`2LB000000000000000M;l0203oool01`2oM000000000000000
B9`0gooo0?ooo`3o_g@02@0000000`00B9`0gooo0?ooo`0<0?ooo`050?noM0000000000000000000
M;l0BP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`006@3oool03`3ogi`0B000000000000000B9cO0?oo
g`2LB0000000001d_`3oool0_g@000000000B9`0gooo0=nLB002000000060000B02Lgol0oooo0?oo
o`3ookl0M0002@0000001P00B9`0gooo0?ooo`3oool0oono07@00080000000<0M;oo0?ooo`3oool0
1`3oool01@3ookl0M000000000000000B9cO00P0oooo00L0gia8000000000000001d0;ooo`3oool0
okmd00/0000000<0M;oo0?ooo`3oool01`3oool00`2oM0000000000000040000000307Boo`3oool0
oooo04P0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool001T0oooo00l0omnL04P000000000000004RLg`3o
okl0M0000000001d_ol0oooo0?noM0000000001d0;ooo`3OW4P00P0000001P0004P0W=oo0?ooo`3o
ool0oono07@000T0000000H004RL0=ooo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo
00L0oooo00D0oono07@000000000000004RLg`080?ooo`070=nLB000000000000000M02oool0oooo
0?noM00;000000030000B02Lgol0oooo00<0oooo00<0oooO09a8000000001`0000000`18W=l0oooo
0?ooo`190?ooo`<00000303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo
1000000I0?ooo`006@3oool03`3ogi`0B000000000000000B9cO0?noM0000000001809cOo`3oool0
omnL04P000000000M;oo0=nLB002000000060000B02Lgol0oooo0?ooo`3ookl0M0002@0000001P00
B9`0gooo0?ooo`3oool0oono07@00080000000<0M;oo0?ooo`3oool01`3oool01@3ookl0M0000000
00000000B9cO00P0oooo00L0gia8000000000000001d0;ooo`3oool0okmd0080000000<0001d0;oo
o`3oool00`3oool01@2oM000000000000000000007Bo00<0oooo00<0okmd0000000000001P000000
0`0004P0W=oo0?ooo`1;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo000I0?ooo`0?0?oOW01800000000
00000018W=l0gia800000000B9`0gooo0?ooo`3ooml0W4P000000018W=l0gia80080000000H00018
09cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@000000000
000007Boo`090?ooo`050?oog`2LB000000000000000M;l0203oool01`2oM000000000000000B9`0
gooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`030?ooo`090?oog`2LB000000000000000B9`0
gooo0?ooo`3ookl0M00000D0000000<0001809cOo`3oool0CP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?oo
o`006@3oool0203ogi`0B000000000000000B9cO0;md0000000007Bo0`3oool0102oM0000000001d
_`3OW4P2000000060000B02Lgol0oooo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`080?oo
o`050?oo_`1d000000000000001d_ol02P3oool01@2oM00000000000000007@0_ooo00H0oooo00D0
oono07@0000000000000001d_`020?ooo`050?noM000000000000000M02oool01@3oool01`2oM000
00000000000007@0_ooo0?ooo`3o_g@00`0000000`00M;l0oooo0?ooo`1A0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo000I0?ooo`080?oOW0180000000000000000M7@0M0000000001d_ol30?ooo`040?no
M0000000001d07Ad0080000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0
oooo00P0oooo00D0oono07@000000000000007Boo`0:0?ooo`050?noM0000000000000000000M;l0
1P3oool01@2oM0000000000000000000M;oo0080oooo00D0okmd000000000000001d0;ooo`040?oo
o`080?oog`2LB000000000000000B9`0gooo0?ooo`3OW4P2000000030018W03Oool0oooo00<0oooo
00D0okmd000000000000001809cOo`1:0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo000I0?ooo`080?oO
W0180000000000000000B4P0B0000000B02Lgol30?ooo`040?oOW0180000001804Q80080000000H0
001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@00000
0000000007Boo`0:0?ooo`030?oog`2LB00000000080000000H004RL0=ooo`3oool0oooo0?oog`2L
B003000000050018W03Oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`030?ooo`050;md
00000000000000000000M;l00P3oool01@3o_g@00000000000000000M;oo00<0oooo00H0oono07@0
0000000000000000M02ooom:0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030?oOW0180000
000000<0000000<004RL0=ooo`3oool00P3oool00`3ooml0W4P000000003000000060000B02Lgol0
oooo0?ooo`3ookl0M0002P0000001@00B9`0gooo0?ooo`3ookl0M0000080000000<0M;oo0?ooo`3o
ool02@3oool00`3ogi`0B00000000009000000030000B02Lgol0oooo0080oooo00<0okmd00000000
00002P0000001@1d_ol0oooo0?ooo`3ookl0M00000X0000000<0B9cO0?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`006@3oool00`3ogi`0B0000000000300000003001d_`3oool0oooo00<0
oooo00<0_g@00000000000000P0000001P0004P0W=oo0?ooo`3oool0oono07@000X0000000D004RL
0=ooo`3oool0oono07@000020000000307Boo`3oool0oooo00X0oooo00<0oono07@0000000001`00
00000`0007@0_ooo0?ooo`030?ooo`030?noM0000000000000T0000000<0B9cO0?ooo`3oool00P3o
ool00`3ogi`0B0000000000700000003001d_`3oool0oooo04X0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool001T0oooo00<0omnL04P0000000000`0000000`1d_ol0oooo0?ooo`030?ooo`030?noM0000000
00000080000000H0001809cOo`3oool0oooo0?oo_`1d000:000000050018W03Oool0oooo0?oo_`1d
00000P0000000`1d_ol0oooo0?ooo`0<0?ooo`030?oOW0180000000000<0000000<0001809cOo`3o
ool01@3oool00`3o_g@0000000000007000000030000B02Lgol0oooo00H0oooo00<0gia800000000
00000`0000000`0007@0_ooo0?ooo`1<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002G0?ooo`060=nLB000000000000000
000004P0W=oo1P3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO
09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002E0?oo
o`030?oo_`1d0000000000D0000000<007Bo0?ooo`3oool00P3oool00`3ogi`0B000000000040000
00030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo002D0?ooo`030?oog`2LB000000000L0000000D0B9cO0?ooo`3o
ool0oono07@00007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo002D0?ooo`080?noM0000000000000000018W=l0oooo
0?oog`2LB002000000040018W03Oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000
101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00U03oool01@2oM000000000000000B9`0gooo0080oooo
00L0omnL04P000000000001809cOo`3oool0_g@00080000000D007Bo0?ooo`3oool0oooo0;md0002
0000000404RLg`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md00020000000304RL
g`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool009<0oooo00D0oooO09a8000000000000
001d_`030?ooo`070?oOW018000000000000B02Lgol0oooO09a800020000000507Boo`3oool0oooo
0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P0
0P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000o`1oOgoo07moOh<0Ogmo1@00000I0?ooo`00T`3o
ool01@3ookl0M00000000000000007Bo00<0oooo00L0omnL04P000000000001809cOo`3ookl0M000
0080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0
M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool009<0oooo00<0oono07@0000000000P000000101d_ol0oooo0?oog`2LB002000000040000
M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool009<0oooo00<0oono07@000000000200000001018W=l0oooo0?oo_`1d
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo002C0?ooo`030?oo_`1d0000000000L0000000D004RL0=ooo`3oool0oono07@000020000
000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3o
ool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
002C0?ooo`060?oo_`1d000000000000001d_ol0gia80`0000001P18W=l0oooo0?ooo`3oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool009<0oooo00D0oooO09a800000000000004RLg`080?ooo`050?oog`2LB00000000000
001d_ol00`3oool01`3OW4P0000000000000B9`0gooo0?oog`2LB0000P0000001@1d_ol0oooo0?oo
o`3oool0gia80080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00U03o
ool01@2oM000000000000000B9`0gooo0080oooo00L0gia800000000000004RL0=ooo`3oool0_g@0
0080000000D007Bo0?ooo`3oool0oooo0;md000200000004001d_`3oool0oooo0;md0080000000D0
07Bo0?ooo`3oool0oooo0;md000200000003001d_`3oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0R0?ooo`030?mVIP3oool0oooo06l0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00U03oool0203o_g@00000000000000000B9cO0?ooo`3o
okl0M0000P0000001000M;l0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0
M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`<0ofIVL03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002E0?ooo`030;md00000000000000D00000
00H0001809cOo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`00
00000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3o
ool20?mVIW00oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00U@3oool0
0`3ooml0W4P0000000050000000304RLg`3oool0oooo0080oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P3oIVI`0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool009L0oooo00<0okmd0000000000000P0000000`1d
_ol0oooo0?ooo`040?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3o
oml0W4P000000002000000030018W03Oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`0R0?ooo`80ofIVL03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool40?mVIVh0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo02<0oooo0`3oIVI^0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0S0?ooo`@0ofIVK@3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08`3oool50?mVIV`0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo02<0oooo0`3oIVH00`3oool0ofIV0?mVIP1[0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo0`00000<0?ooo`0307moO`3oool0oooo02<0
oooo0`3oIVH20?ooo`030?mVIP3oool0oooo06T0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool4000001T0
oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0903oool0103oIVH0oooo
0?ooo`3oool20?mVIVX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo00<0ofIV0?ooo`3oool0
0P3oool20?mVIVT0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo00<0ofIV0?ooo`3oool00`3o
ool20?mVIVP0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02@0oooo00<0ofIV0?ooo`3oool0103oool0
0`3oIVH0oooo0?ooo`1V0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0[0?ooo`80ofIVI`3oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0;03oool20?mVIVH0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo02d0oooo
00<0ofIV0?ooo`3oool0I03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0;@3oool20?mVIVD0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo02h0oooo0P3oIVIT0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<00000
0?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0_0?oo
o`80ofIVH`3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<03oool00`3oIVH0oooo0?ooo`1Q0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0`0?ooo`80ofIVHP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0<@3o
ool20?mVIV40oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0380oooo00<0ofIV0?ooo`3oool0G`3oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0<P3oool20?mVIV00oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03<0
oooo0P3oIVIO0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0d0?ooo`030?mVIP3oool0oooo05d0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo
00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool3000000`0oooo00<0
Ogmo0?ooo`3oool0=03oool20?mVIUh0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool4000001T0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=@3oool20?mVIUd0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo03H0oooo0P3oIVIL0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0g0?ooo`03
0?mVIP3oool0oooo05X0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03L0oooo0P3oIVIK0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`0h0?ooo`80ofIVFP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>@3oool0
0`3oIVH0oooo0?ooo`1H0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0i0?ooo`80ofIVF@3oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0>P3oool20?mVIUP0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03/0oooo
00<0ofIV0?ooo`3oool0EP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo
00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>`3oool20?mVIUL0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0
Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo03`0oooo0P3oIVIF0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<00000
0?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0m0?oo
o`030?mVIP3oool0oooo05@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03d0oooo0P3oIVIE0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0n0?ooo`80ofIVE03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?`3o
ool20?mVIU<0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0400oooo00<0ofIV0?ooo`3oool0D@3oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0@03oool20?mVIU80oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool3000000`0oooo00<0Ogmo0?ooo`3oool0@@3oool20?mVIU40
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool06P3oool4000001T0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0@P3oool00`3oIVH0oooo0?ooo`1?0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`120?ooo`80ofIVD03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@`3oool20?mVITl0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo04@0oooo00<0ofIV0?ooo`3oool0C@3oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0A03oool20?mVITh0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04D0oooo0P3oIVI=0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`160?ooo`80ofIVC03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A`3oool0
0`3oIVH0oooo0?ooo`1:0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`170?ooo`80ofIVB`3oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0B03oool20?mVITX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04P0oooo
0`3oIVI90?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool009H0oooo00<0
omnL04P0000000000P0000000`0004P0W=oo0?ooo`050?ooo`030?oog`2LB00000000080000000<0
04RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`190?ooo`80ofIVB@3oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo002E0?ooo`030;md00000000000000D0000000<007Bo
0?ooo`3oool00P3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL
04P000000000100000000`0004P0W=oo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0B@3oool20?mVITT0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D
0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G
0?ooo`00U03oool00`3OW4P00000000000070000000504RLg`3oool0oooo0?oo_`1d00001`000000
1P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo04T0oooo0P3oIVI90?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool009<0oooo00T0oono07@00000000000000000M02oool0oooo0?oo
_`1d00000P0000001000B9`0gooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0
M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`190?ooo`80ofIV00<0oooo0?mVIP3o
ool0AP3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002C0?ooo`050?oo
_`1d000000000000001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?ooo`2oM0000P000000
1@00M;l0oooo0?ooo`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P0000001@00M;l0oooo
0?ooo`3oool0_g@00080000000<0B9cO0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo04T0oooo1@3oIVI60?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool009<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000000000000000
M02oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oo
g`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`D0
0000EP1oOgl60?mVI_l0Ogmoo`1oOglW07moO`D000006@3oool009@0oooo00P0_g@0000000000000
04RL0=ooo`3oool0oono07@00080000000@007Bo0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
04T0oooo1`3oIVI40?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool009@0
oooo00<0oono07@0000000001P0000001@00B9`0gooo0?ooo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`190?ooo`@0ofIV00<0oooo0?mVIP3oIVH0A03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo002F0?ooo`030?noM0000000000000<0000000H0M;oo0?ooo`3oool0oooo
0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0B@3oool30?mVIP<0oooo0P3oIVI30?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool009D0oooo00<0gia80000000000001@000000
1@18W=l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000
M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`190?ooo`<0ofIV0`3oool30?mV
IT80oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00U03oool01`3o_g@0
00000000000004P0W=oo0?ooo`3o_g@00P0000001@0004P0W=oo0?ooo`3ookl0M0000080000000D0
M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`190?ooo`<0ofIV103oool30?mVIT40oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00U03oool0102oM000000000000000M;l30?ooo`070;md000000000000
04RLg`3oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo
0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0BP3oool00`3oIVH0oooo0?ooo`040?oo
o`<0ofIV@03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002D0?ooo`04
0;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000
M;l30?ooo`040;md000000000000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102oM000
000000000000M;l=0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0BP3oool00`3o
IVH0oooo0?ooo`050?ooo`<0ofIV?`3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo002D0?ooo`080=nLB000000000000000B02Lgol0oooo0?oOW01800020000000404RLg`3o
ool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@20000
00040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo04X0oooo00<0ofIV0?ooo`3oool01P3oool20?mVISl0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00U03oool00`3ogi`0B000000000060000
00060000B02Lgol0oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0
000000<004RL0=ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo05@0
oooo0P3oIVHn0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool009D0oooo
00<0gia80000000000001@0000000`18W=l0oooo0?ooo`020?ooo`030?oOW0180000000000@00000
00<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1D0?ooo`<0ofIV?@3oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002F0?ooo`030?oOW018000000000080000000<0
001d0;ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0
oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0E@3oool30?mVIS`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo05H0oooo0`3oIVHk
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`1G0?ooo`<0ofIV>P3oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0F03oool20?mVISX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo05T0oooo0P3oIVHi0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`1I0?ooo`<0ofIV>03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0FP3oool3
0?mVISL0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0
oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool30000
00`0oooo00<0Ogmo0?ooo`3oool0F`3oool30?mVISH0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool06P3oool40000
01T0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0G03oool30?mVISD0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo05d0oooo0`3oIVHd0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`1N0?ooo`80ofIV=03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0G`3oool20?mVIS<0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo05l0oooo0`3oIVHb0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1P0?ooo`<0
ofIV<@3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0H@3oool30?mVIS00oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo0680oooo0`3oIVH_0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1S0?ooo`80ofIV;`3oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0I03oool20?mVIRh0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo06@0
oooo0`3oIVH]0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1U0?ooo`<0ofIV;03oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0IP3oool40?mVIRX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo06L0oooo1@3oIVHX
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`1Y0?ooo`D0ofIV9P3oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0J`3oool50?mVIR@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00
aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo06d0oooo1@3oIVHR0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo0`00000<0?ooo`0307moO`3o
ool0oooo06l0oooo1@3oIVHP0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo1000000I0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0740oooo1@3oIVHN0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`1c0?ooo`D0ofIV703oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0M@3oool50?mVIQX0
oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo07L0oooo1@3oIVHH0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`1i0?ooo`D0ofIV5P3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo0036
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0N`3oool50?mVIQ@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo07d0oooo1@3oIVHB0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?oo
o`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`1o0?ooo`D0
ofIV403oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3o
ool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0P@3oool50?mVIPh0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo08<0oooo103oIVH=0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3o
ool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`250?ooo`@0ofIV2`3oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool0
0`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0QP3oool40?mVIPX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08P0
oooo0`3oIVH90?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`290?ooo`@0ofIV1`3oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0RP3oool40?mVIPH0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08`0oooo0`3oIVH5
0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C
0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo0`00000<0?oo
o`0307moO`3oool0oooo08d0oooo0`3oIVH40?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01X0oooo1000000I0?oo
o`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08h0oooo103oIVH20?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`03
07moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2?0?ooo`@0ofIV00<0oooo07moO`3oool0U@3oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo
0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0940oooo0`3o
IVH00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3o
ool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0TP3oool40?mVIYD0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2C0?ooo`@0ofIVU03oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0
oooo00<0Ogmo0?mVIP3oIVH0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00@0Ogmo0?ooo`3oIVH0ofIVT`3oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo
00@0Ogmo0?ooo`3oIVH0ofIVT`3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00@0Ogmo0?ooo`3oIVH0ofIVT`3oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000
oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo
00@0Ogmo0?ooo`3oIVH0ofIV203ooolQ0?mVIVX0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0407moO`3oool0ofIV0?mVIPD0
oooo;03oIVIR0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`090?mVIR40oooo3`3oIVIK0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d_ol01P3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool03`3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool01P3oIVH/0?ooo`l0ofIV
D`3oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool0
7@3oool00`000000oooo0?ooo`0G0?ooo`00RP3oool01@3ookl0M000000000000000M;oo00D0oooo
00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@00000
00<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00h0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo00<0ofIV
=P3oool?0?mVIT`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307mo
O`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool008X0oooo00D0oono07@0000000000000
07Boo`040?ooo`030?oo_`1d0000000000H0000000H004RL0=ooo`3oool0oooo0?oo_`1d00070000
00060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`030?mVISh0oooo2P3o
IVI90?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d_ol0103o
ool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@20000
00040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?oo
o`3o_g@30000000307Boo`3oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2D0?ooo`0307moO`3oool0oooo00<0ofIVA@3oool50?mVITL0oooo00<0Ogmo0?ooo`3oool0
U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool008X0oooo00D0oono07@000000000000007Boo`040?ooo`040;md000000000000001d_`<0
oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md00000000
000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=l>0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool01@1oOgl0oooo0?ooo`3oool0ofIV
04P0oooo1P3oIVI40?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000
001d_ol00`3oool01@3ooml0W4P0000000000000M;oo00<0oooo00L0gia800000000000004RL0=oo
o`3ooml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a8
0080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo00`0oooo1@00002U
07moO`030?mVIP1oOgl0Ogmo04P0Ogmo1P3oIVKo07moOh`0Ogmo1@00000I0?ooo`00RP3oool01@3o
okl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000
000000000018W03Oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000
B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?oo
o`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool01@1oOgl0oooo0?oo
o`3oool0ofIV04d0oooo1@3oIVI00?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d
000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd00000000
0000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02o
ool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo0540
oooo1@3oIVHn0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0
oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d
_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3o
okl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo05<0oooo1@3oIVHl0?oo
o`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o
okl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M00000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000030000M02oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo05D0oooo1P3oIVHi0?ooo`0307moO`3oool0
oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo00260?ooo`060?oo_`1d04P0W=oo0?ooo`3ookl0M0000P0000001P1d_ol0oooo0?oo
o`3oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono
07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo05L0oooo1P3oIVHg0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo00260?ooo`060?oo_`1d000000000018W03Ookl0M0000P0000001P1d
_ol0oooo0?ooo`3oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018
W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO
09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo05X0oooo1@3o
IVHe0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?oo
o`0M0?ooo`030000003oool0oooo01L0oooo00260?ooo`030?oo_`1d0000000000D0000000<0M;oo
0?ooo`3oool00P3oool0102oM000000000000000M;l30?ooo`040;md000000000000001d_`80oooo
00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`040;md000000000000
001d_`<0oooo00@0_g@000000000000007Bo3P3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0G03oool50?mVIQd0oooo2`3oIVH;0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003o
ool0oooo01L0oooo00270?ooo`030?oog`2LB000000000@0000000<0M;oo0?ooo`3oool00P3oool0
1`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@200000004
0000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o
_g@30000000307Boo`3oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo05h0oooo1P3oIVHB0?oooaH0ofIV203oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00R@3oool00`3o_g@00000000000020000000307Boo`3oool0oooo0080oooo00<0oono
07@0000000001P0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0
oooo0?oo_`1d0007000000030018W03Oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo0600oooo1P3oIVH90?ooo`l0ofIV2`3oool70?mV
IP@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool008X0oooo00D0omnL04P000000000000007Boo`050?oo
o`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B000000000040000
00030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`0>0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`1S0?oo
oa<0ofIV5P3oool70?mVIP030?ooo`1oOgl0oooo09D0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1o
Ogl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo002;0?ooo`040=nLB0000000000007Bo
o`H0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
00l0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
06D0oooo2P3oIVHQ0?ooo`L0ofIVU03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09<0oooo1`3oIVJA0?ooo`0307moO`3oool0oooo09<0
oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`060?mVIXh0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000
003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03o
ool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo00<0oooo0`3oIVJ>0?ooo`0307moO`3o
ool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`040?ooo`80ofIVSP3oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0103oool30?mV
IXd0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo
01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo00D0oooo0P3oIVHI0?oooa@0ofIVH03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
0`00000<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo
0?ooo`050?ooo`80ofIV3`3ooolX0?mVIUH0oooo00<0Ogmo0?ooo`3oool0T`3oool00`1oOgl0oooo
0?ooo`0J0?ooo`@000006@3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool01@3ooolK0?mVIQ@0oooo503o
IVI<0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3oool07@3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`060?oooa00ofIV:03ooolX0?mVIRh0oooo00<0Ogmo
0?ooo`3oool0T`3oool00`1oOgl0oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00360?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?oo
o`0307moO`3oool0oooo04P0oooo;P3oIVHN0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?oo
o`3oool0303oool00`3oIVH0oooo0?ooo`0>0?ooo`030000003oool0oooo01L0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo06H0oooo7`3oIVH?0?ooo`0307moO`3oool0oooo09<0oooo00<0Ogmo0?ooo`3o
ool02`3oool30?mVIPl0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0
MP3oool]0?mVIXL0oooo00<0Ogmo0?ooo`3oool02P3oool40?mVIPl0oooo00<000000?ooo`3oool0
5`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0Q@3oooll0?mVIVT0oooo00@0Ogmo0?ooo`3oool0oooo
3@3oIVH?0?ooo`030000003oool0oooo01L0oooo00360?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0
Ogmo0?ooo`3oool0303ooolX0?mVIUX0oooo4P3oIVH20?ooo`80ofIV3`3oool00`000000oooo0?oo
o`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo
0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo02X0oooo503oIVI6
0?oooa<0ofIV2`3oool30?mVIPh0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?oo
o`3oool0U03oool00`1oOgl0oooo0?ooo`0d0?oooa@0ofIV;@3ooolI0?mVIPD0oooo00<0Ogmo0?oo
o`3oool03@3oool00`3oIVH0oooo0?ooo`0=0?ooo`030000003oool0oooo01L0oooo00360?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`03
07moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0?P3ooom60?mVIPl0oooo00<0Ogmo0?ooo`3o
ool07@3oool00`000000oooo0?ooo`0G0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2D0?ooo`0307mo
O`3oool0oooo04P0oooo;@3oIVHN0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3o
ool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3o
ool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool0
0`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool0
0<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo
09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo
01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0
oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00<H0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2D0?ooo`0307moO`3oool0oooo09@0oooo
00<0Ogmo0?ooo`3oool0U03oool00`1oOgl0oooo0?ooo`2C0?ooo`0307moO`3oool0oooo01d0oooo
00<000000?ooo`3oool05`3oool00<H0oooo0`00000<0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool06P3oool4000001T0oooo00360?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo0P00000I
0?ooo`00aP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0L0?ooo`8000006@3oool00<H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0703oool2000001T0oooo00360?ooool00000o`00002=000001T0oooo003o0?ooool0ooooo`3o
oom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0
ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o
0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0
oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo
0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0oooo
o`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool0
0?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0oooo
K@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3ooooo0?oo
ool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?ooo`00o`3o
oooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3ooom]0?oo
o`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0ooooo`3o
oom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o0?ooool0
ooooo`3ooom]0?ooo`00o`3ooooo0?ooool0ooooK@3oool00?l0ooooo`3ooooo0?ooofd0oooo003o
0?ooool0ooooo`3ooom]0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 873.875}, {594.313, 0}} -> {-1.05107, -0.784208, \
0.00362547, 0.00362547}, {{21.125, 848.563}, {525.5, 14.125}} -> {-708.965, \
-464.618, 4.97416, 4.24304}, {{66.625, 852.688}, {580.125, 538.75}} -> \
{-0.411931, -0.909459, 0.00702242, 0.0855666}, {{105.063, 318.625}, {576.938, \
559.438}} -> {-24.211, -2.98574, 0.17143, 0.17143}, {{352.813, 566.438}, \
{576.938, 559.438}} -> {-52.5291, -2.98574, 0.17143, 0.17143}, {{600.625, \
814.188}, {576.938, 559.438}} -> {-80.8472, -2.98574, 0.17143, 0.17143}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["\<\
Dot Product Linux IA64 (Itanium 900MHz) \[Dash] Note multiprocessor speedup\
\>", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68061 
%%ImageSize: 850 578.522 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497631 0.473821 0.371571 0.473821 [
[ 0 0 0 0 ]
[ 1 .68061 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0787334 0.971452 0.664409 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000463897 0.0147151 5.93423e-05 [
[.02381 -0.0125 -6.4375 -18 ]
[.02381 -0.0125 6.4375 0 ]
[.25576 -0.0125 -15.3125 -18 ]
[.25576 -0.0125 15.3125 0 ]
[.48771 -0.0125 -19.75 -18 ]
[.48771 -0.0125 19.75 0 ]
[.71966 -0.0125 -19.75 -18 ]
[.71966 -0.0125 19.75 0 ]
[.9516 -0.0125 -19.75 -18 ]
[.9516 -0.0125 19.75 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -55.625 -36 ]
[.5 -0.0125 55.625 -18 ]
[-0.0125 .01472 -12.875 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .1334 -39.5 -9 ]
[-0.0125 .1334 0 9 ]
[-0.0125 .25208 -39.5 -9 ]
[-0.0125 .25208 0 9 ]
[-0.0125 .37077 -39.5 -9 ]
[-0.0125 .37077 0 9 ]
[-0.0125 .48945 -39.5 -9 ]
[-0.0125 .48945 0 9 ]
[-0.0125 .60814 -48.375 -9 ]
[-0.0125 .60814 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -118.875 -9 ]
[-0.01875 .30902 -48.375 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.25576 0 m
.25576 .61803 L
s
.48771 0 m
.48771 .61803 L
s
.71966 0 m
.71966 .61803 L
s
.9516 0 m
.9516 .61803 L
s
0 .01472 m
1 .01472 L
s
0 .1334 m
1 .1334 L
s
0 .25208 m
1 .25208 L
s
0 .37077 m
1 .37077 L
s
0 .48945 m
1 .48945 L
s
0 .60814 m
1 .60814 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.4375 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25576 0 m
.25576 .00625 L
s
gsave
.25576 -0.0125 -76.3125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.48771 0 m
.48771 .00625 L
s
gsave
.48771 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.71966 0 m
.71966 .00625 L
s
gsave
.71966 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.9516 0 m
.9516 .00625 L
s
gsave
.9516 -0.0125 -80.75 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.125 Mabswid
.0702 0 m
.0702 .00375 L
s
.11659 0 m
.11659 .00375 L
s
.16298 0 m
.16298 .00375 L
s
.20937 0 m
.20937 .00375 L
s
.30215 0 m
.30215 .00375 L
s
.34854 0 m
.34854 .00375 L
s
.39493 0 m
.39493 .00375 L
s
.44132 0 m
.44132 .00375 L
s
.5341 0 m
.5341 .00375 L
s
.58049 0 m
.58049 .00375 L
s
.62688 0 m
.62688 .00375 L
s
.67327 0 m
.67327 .00375 L
s
.76605 0 m
.76605 .00375 L
s
.81243 0 m
.81243 .00375 L
s
.85882 0 m
.85882 .00375 L
s
.90521 0 m
.90521 .00375 L
s
.99799 0 m
.99799 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -116.625 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vector) show
117.062 17.000 moveto
(Length) show
170.250 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -73.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1334 m
.00625 .1334 L
s
gsave
-0.0125 .1334 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
0 .25208 m
.00625 .25208 L
s
gsave
-0.0125 .25208 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
0 .37077 m
.00625 .37077 L
s
gsave
-0.0125 .37077 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
0 .48945 m
.00625 .48945 L
s
gsave
-0.0125 .48945 -100.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
0 .60814 m
.00625 .60814 L
s
gsave
-0.0125 .60814 -109.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04439 m
.00375 .04439 L
s
0 .07406 m
.00375 .07406 L
s
0 .10373 m
.00375 .10373 L
s
0 .16307 m
.00375 .16307 L
s
0 .19274 m
.00375 .19274 L
s
0 .22241 m
.00375 .22241 L
s
0 .28176 m
.00375 .28176 L
s
0 .31143 m
.00375 .31143 L
s
0 .3411 m
.00375 .3411 L
s
0 .40044 m
.00375 .40044 L
s
0 .43011 m
.00375 .43011 L
s
0 .45978 m
.00375 .45978 L
s
0 .51912 m
.00375 .51912 L
s
0 .5488 m
.00375 .5488 L
s
0 .57847 m
.00375 .57847 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -179.875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MFLOPS) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.25576 .61178 m
.25576 .61803 L
s
.48771 .61178 m
.48771 .61803 L
s
.71966 .61178 m
.71966 .61803 L
s
.9516 .61178 m
.9516 .61803 L
s
.125 Mabswid
.0702 .61428 m
.0702 .61803 L
s
.11659 .61428 m
.11659 .61803 L
s
.16298 .61428 m
.16298 .61803 L
s
.20937 .61428 m
.20937 .61803 L
s
.30215 .61428 m
.30215 .61803 L
s
.34854 .61428 m
.34854 .61803 L
s
.39493 .61428 m
.39493 .61803 L
s
.44132 .61428 m
.44132 .61803 L
s
.5341 .61428 m
.5341 .61803 L
s
.58049 .61428 m
.58049 .61803 L
s
.62688 .61428 m
.62688 .61803 L
s
.67327 .61428 m
.67327 .61803 L
s
.76605 .61428 m
.76605 .61803 L
s
.81243 .61428 m
.81243 .61803 L
s
.85882 .61428 m
.85882 .61803 L
s
.90521 .61428 m
.90521 .61803 L
s
.99799 .61428 m
.99799 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1334 m
1 .1334 L
s
.99375 .25208 m
1 .25208 L
s
.99375 .37077 m
1 .37077 L
s
.99375 .48945 m
1 .48945 L
s
.99375 .60814 m
1 .60814 L
s
.125 Mabswid
.99625 .04439 m
1 .04439 L
s
.99625 .07406 m
1 .07406 L
s
.99625 .10373 m
1 .10373 L
s
.99625 .16307 m
1 .16307 L
s
.99625 .19274 m
1 .19274 L
s
.99625 .22241 m
1 .22241 L
s
.99625 .28176 m
1 .28176 L
s
.99625 .31143 m
1 .31143 L
s
.99625 .3411 m
1 .3411 L
s
.99625 .40044 m
1 .40044 L
s
.99625 .43011 m
1 .43011 L
s
.99625 .45978 m
1 .45978 L
s
.99625 .51912 m
1 .51912 L
s
.99625 .5488 m
1 .5488 L
s
.99625 .57847 m
1 .57847 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .4 .4 r
.004 w
.08087 .2115 m
.08319 .31861 L
.08551 .29571 L
.09339 .26415 L
.13978 .39451 L
.14025 .38078 L
.14257 .44397 L
.14489 .33884 L
.18617 .453 L
.23256 .43741 L
.25901 .46724 L
.26132 .50901 L
.26364 .49457 L
.27895 .49615 L
.32534 .52041 L
.37173 .4851 L
.41812 .56351 L
.46451 .57193 L
.49652 .55502 L
.49884 .58959 L
.50116 .56189 L
.5109 .54362 L
.55729 .59964 L
.60368 .58946 L
.65007 .58755 L
.69646 .59364 L
.74285 .58185 L
.78924 .59612 L
.83563 .59835 L
.88202 .60212 L
.92841 .60332 L
.97155 .55057 L
.97387 .59663 L
.97619 .53301 L
s
.4 .4 1 r
.08087 .16327 m
.08319 .2471 L
.08551 .21592 L
.09339 .23186 L
.13978 .26791 L
.14025 .26071 L
.14257 .29355 L
.14489 .26404 L
.18617 .28579 L
.23256 .30312 L
.25901 .29755 L
.26132 .32841 L
.26364 .29937 L
.27895 .2995 L
.32534 .31272 L
.37173 .32545 L
.41812 .327 L
.46451 .32763 L
.49652 .32235 L
.49884 .34342 L
.50116 .30897 L
.5109 .31924 L
.55729 .33285 L
.60368 .33333 L
.65007 .33589 L
.69646 .3369 L
.74285 .33798 L
.78924 .34065 L
.83563 .34417 L
.88202 .34244 L
.92841 .34712 L
.97155 .32733 L
.97387 .35224 L
.97619 .31962 L
s
.4 .8 .4 r
.08087 .13994 m
.08319 .16521 L
.08551 .14304 L
.09339 .15246 L
.13978 .1594 L
.14025 .15707 L
.14257 .17865 L
.14489 .15877 L
.18617 .16551 L
.23256 .17158 L
.25901 .16849 L
.26132 .18288 L
.26364 .16334 L
.27895 .16907 L
.32534 .17365 L
.37173 .17748 L
.41812 .17875 L
.46451 .18064 L
.49652 .17566 L
.49884 .18848 L
.50116 .17217 L
.5109 .17699 L
.55729 .18184 L
.60368 .18366 L
.65007 .18337 L
.69646 .18452 L
.74285 .18209 L
.78924 .18458 L
.83563 .18478 L
.88202 .18432 L
.92841 .18617 L
.97155 .17779 L
.97387 .1907 L
.97619 .17527 L
s
.8 .4 .8 r
.08087 .0275 m
.08319 .02797 L
.08551 .02761 L
.09339 .02764 L
.13978 .02742 L
.14025 .02742 L
.14257 .02698 L
.14489 .02744 L
.18617 .02546 L
.23256 .02299 L
.25901 .0221 L
.26132 .02266 L
.26364 .02212 L
.27895 .02186 L
.32534 .02184 L
.37173 .02181 L
.41812 .02186 L
.46451 .02185 L
.49652 .02185 L
.49884 .02202 L
.50116 .02185 L
.5109 .02187 L
.55729 .02187 L
.60368 .02188 L
.65007 .02189 L
.69646 .0219 L
.74285 .0219 L
.78924 .02191 L
.83563 .02191 L
.88202 .02191 L
.92841 .02192 L
.97155 .02191 L
.97387 .02208 L
.97619 .02191 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
1 g
.07593 .01621 m
.07593 .06359 L
.97619 .06359 L
.97619 .01621 L
F
0 g
.001 w
[ ] 0 setdash
.07593 .01621 m
.97619 .01621 L
.97619 .06359 L
.07593 .06359 L
.07593 .01621 L
s
% Start of sub-graphic
p
0.0759299 0.0162051 0.97619 0.0635872 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0206612 0.206612 0.00223015 0.0223015 [
[ 0 0 0 0 ]
[ 1 .05263 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .05263 L
0 .05263 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0371901 0.00401427 0.243802 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .4 .4 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.1405 .0281 -100.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
76.312 17.000 moveto
(Threads) show
138.375 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.27686 0.00401427 0.483471 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .4 1 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38017 .0281 -100.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
76.312 17.000 moveto
(Threads) show
138.375 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.516529 0.00401427 0.72314 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 .8 .4 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.61983 .0281 -96.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
76.312 17.000 moveto
(Thread) show
129.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.756198 0.00401427 0.96281 0.0263158 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.8 .4 .8 r
.2992 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.8595 .0281 -80.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
85.188 17.000 moveto
(.1) show
98.500 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .68061 L
0 .68061 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{575.875, 391.875},
  ImageMargins->{{2.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=O0002Bb000`400?l00000o`00003oo`3ooooo
0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00
o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR
0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0oooo
o`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?oo
ool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo
00110?ooool00000o`00003o000000`000005@3oool00440oooo00<000000?ooo`3oool0o`3ooooo
0?ooool0oooo203oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?oo
ool0ooooo`3oool80?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?ooo`P0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0
o`3ooooo0?ooool0oooo203oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?oo
o`3o0?ooool0ooooo`3oool80?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooo`P0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo203oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000
oooo0?ooo`3o0?ooool0ooooo`3oool80?ooo`030000003oool0oooo01<0oooo00110?ooo`030000
003oool0oooo0680oooo4P3oIVJX0?oooa80IVKoZ03ooolB06K<IZP0oooo4P3<I/aS0?ooo`030000
003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0680oooo4P3oIVJX0?oooa80IVKoZ03o
oolB06K<IZP0oooo4P3<I/aS0?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0
oooo0680oooo4P3oIVJX0?oooa80IVKoZ03ooolB06K<IZP0oooo4P3<I/aS0?ooo`030000003oool0
oooo01<0oooo00110?ooo`030000003oool0oooo0680oooo4P3oIVJX0?oooa80IVKoZ03ooolB06K<
IZP0oooo4P3<I/aS0?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0680
oooo4P3oIVJX0?oooa80IVKoZ03ooolB06K<IZP0oooo4P3<I/aS0?ooo`030000003oool0oooo01<0
oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`P0oooo00<000000?ooo`3oool0
4`3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo203oool00`000000oooo0?oo
o`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool80?ooo`030000003oool0
oooo01<0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`P0oooo00<000000?oo
o`3oool04`3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo203oool00`000000
oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool80?ooo`030000
003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`P0oooo00<0
00000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo203oool0
0`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3oool80?oo
o`030000003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooooo0?ooo`P0
oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo
203oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0ooooo`3o
ool80?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0?l0ooooo`3ooooo
0?ooo`P0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0o`3ooooo0?oo
ool0oooo203oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooool0
ooooo`3oool80?ooo`030000003oool0oooo01<0oooo00110?ooo`030000003oool0oooo0?l0oooo
o`3ooooo0?ooo`P0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0>03o
ool01@3ooml0W4P0000000000000B9cO00l0oooo00D0okmd000000000000001d0;ooo`050?ooo`05
0?oOW018000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia8
00000000000004RL0=ooo`060?ooo`030?oOW018000000000080000000<0001d0;ooo`3oool0103o
ool01`3OW4P00000000000000000001d0;ooo`3o_g@00P0000000`00B9`0gooo0?ooo`030?ooo`07
0;md00000000000000000000B9`0gooo0;md00020000000304RLg`3oool0oooo0080oooo00<0_g@0
0000000000000`0000000`1d_ol0oooo0?ooo`1:0?ooo`030?noM0000000000000P0000000<0001d
0;ooo`3oool0303oool01@3o_g@000000000000007@0_ooo00D0oooo00D0omnL04P0000000000018
09cOo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool01@3OW4P0000000000000B9`0gooo
00H0oooo00<0omnL04P0000000000P0000000`0007@0_ooo0?ooo`040?ooo`070=nLB00000000000
0000000007@0_ooo0?noM002000000030018W03Oool0oooo00<0oooo00L0_g@00000000000000000
0018W03Oool0_g@00080000000<0B9cO0?ooo`3oool00P3oool00`2oM00000000000000300000003
07Boo`3oool0oooo05D0oooo00D0oono07@000000000000007Boo`0@0?ooo`050?noM00000000000
0000M02oool01@3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@0000000000000
07Boo`020?ooo`050=nLB000000000000018W03Oool01P3oool00`3ogi`0B0000000000200000003
0000M02oool0oooo00@0oooo00L0gia800000000000000000000M02oool0okmd0080000000<004RL
0=ooo`3oool00`3oool01`2oM000000000000000000004RL0=ooo`2oM0000P0000000`18W=l0oooo
0?ooo`1c0?ooo`050?oog`2LB000000000000018W=l00`3oool01`3ookl0M0000000000004P0W=oo
0?ooo`3o_g@02P000000200007@0_ooo0?ooo`3ookl0M0000000000004P0W=oo1P3oool01@3ookl0
M000000000000000M;oo05D0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3o
ool0>03oool01@3ooml0W4P0000000000000B9cO00l0oooo00D0okmd000000000000001d0;ooo`05
0?ooo`050?oOW018000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo
00D0gia800000000000004RL0=ooo`050?ooo`030=nLB0000000000000D0000000D0B9cO0?ooo`3o
ool0oooo0;md00090000000604RLg`3oool0oooo0?ooo`3ookl0M0001@0000001@0004P0B4P00000
00000000B9cO0080oooo00<0omnL04P0000000001P0000000`00B9`0gooo0?ooo`190?ooo`030?oo
_`1d0000000000P0000000<0001d0;ooo`3oool0303oool01@3o_g@000000000000007@0_ooo00D0
oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@3OW4P0000000000000B9`0gooo00D0oooo00<0gia80000000000001@0000001@18W=l0oooo0?oo
o`3oool0_g@000T0000000H0B9cO0?ooo`3oool0oooo0?oo_`1d0005000000050000B018B0000000
00000018W=l00P3oool00`3ogi`0B00000000006000000030018W03Oool0oooo05@0oooo00D0oono
07@000000000000007Boo`0@0?ooo`050?noM000000000000000M02oool01@3oool01@3ogi`0B000
0000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`020?ooo`050=nLB00000000000
0018W03Oool01@3oool00`3OW4P00000000000050000000504RLg`3oool0oooo0?ooo`2oM0002@00
00001P18W=l0oooo0?ooo`3oool0oono07@000D0000000D0001804Q800000000000004RLg`1e0?oo
o`050?oog`2LB000000000000018W=l00`3oool0203ookl0M0000000000004P0W=oo0?ooo`3ookl0
M0002@000000200007@0_ooo0?ooo`3ookl0M0000000000004P0W=oo1P3oool01@3ookl0M0000000
00000000M;oo05D0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0>03o
ool01@3ooml0W4P0000000000000B9cO00l0oooo00D0okmd000000000000001d0;ooo`050?ooo`05
0?oOW018000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia8
00000000000004RL0=ooo`040?ooo`030?noM0000000000000H0000000D0001809cOo`3oool0omnL
04P000020000000404RLg`3oool0oono07@000<0000000D0M;oo0?ooo`3oool0oooO09a8000:0000
000404RLg`3oool0oono07@000T0000000<0B9cO0?ooo`3oool0B@3oool00`2oM000000000000007
000000030000M02oool0oooo00`0oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oOW018
000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia800000000
000004RL0=ooo`040?ooo`030?noM0000000000000H0000000D0001809cOo`3oool0omnL04P00002
0000000404RLg`3oool0oono07@000<0000000D0M;oo0?ooo`3oool0oooO09a8000:0000000404RL
g`3oool0oono07@000T0000000<0B9cO0?ooo`3oool0D`3oool01@3ookl0M000000000000000M;oo
0100oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oOW018000000000000B02Lgol00`3o
ool01@3ookl0M000000000000000M;oo0080oooo00D0gia800000000000004RL0=ooo`040?ooo`03
0?noM0000000000000H0000000D0001809cOo`3oool0omnL04P000020000000404RLg`3oool0oono
07@000<0000000D0M;oo0?ooo`3oool0oooO09a8000:0000000304RLg`3oool0oooo07<0oooo00D0
oooO09a800000000000004RLg`030?ooo`050?oo_`1d000000000000B02Lgol00P3oool00`2oM000
000000000007000000080000M02oool0oooo0?oo_`1d000000000000B02Lgol60?ooo`050?oo_`1d
000000000000001d_ol0E@3oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000oooo0?oo
o`0b0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`3oool02`3oool01@3o_g@000000000
000007@0_ooo00D0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000
001d_ol00P3oool01@3OW4P0000000000000B9`0gooo00<0oooo00T0oooO09a80000000000000000
M02oool0oooo0?oog`2LB0000P0000000`00M;l0oooo0?noM002000000060000M02oool0oooo0?oo
o`3ogi`0B0000P000000101d_ol0oooo0?ooo`3o_g@300000005001d_`3oool0oooo0?oo_`1d0000
0`0000000`18W=l0oooo0?noM0030000000504RLg`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0
gooo0?ooo`190?ooo`050?oOW0180000000000000018W=l0503oool01@3o_g@000000000000007@0
_ooo00D0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol0
0P3oool01@3OW4P0000000000000B9`0gooo00<0oooo00T0oooO09a80000000000000000M02oool0
oooo0?oog`2LB0000P0000000`00M;l0oooo0?noM002000000060000M02oool0oooo0?ooo`3ogi`0
B0000P000000101d_ol0oooo0?ooo`3o_g@300000005001d_`3oool0oooo0?oo_`1d00000`000000
0`18W=l0oooo0?noM0030000000504RLg`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?oo
o`1C0?ooo`050?oo_`1d000000000000001d_ol0403oool01@3o_g@000000000000007@0_ooo00D0
oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool0
1@3OW4P0000000000000B9`0gooo00<0oooo00T0oooO09a80000000000000000M02oool0oooo0?oo
g`2LB0000P0000000`00M;l0oooo0?noM002000000060000M02oool0oooo0?ooo`3ogi`0B0000P00
0000101d_ol0oooo0?ooo`3o_g@300000005001d_`3oool0oooo0?oo_`1d00000`0000000`18W=l0
oooo0?ooo`1]0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`3oool01P3oool01@3ogi`0
B000000000000000B9cO01<0oooo00D0oono07@000000000000007Boo`1E0?ooo`030000003oool0
oooo01<0oooo00110?ooo`030000003oool0oooo0380oooo00<0gia80000000000002@0000000`18
W=l0oooo0?ooo`0;0?ooo`050?noM000000000000000M02oool01@3oool01@3ogi`0B00000000000
04P0W=oo00<0oooo00D0oono07@000000000000007Boo`020?ooo`050=nLB000000000000018W03O
ool00`3oool01@3ogi`0B000000000000000M;oo00P0oooo00D0omnL04P000000000000007Boo`02
0?ooo`050?oo_`1d000000000000001d_ol00P3oool01@2oM000000000000000B9`0gooo00<0oooo
00D0omnL04P000000000000004RLg`080?ooo`060;md00000000000000000000B9`0goooB`3oool0
1@3o_g@00000000000000000M;oo01<0oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oO
W018000000000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia80000
0000000004RL0=ooo`030?ooo`050?oOW018000000000000001d_ol0203oool01@3ogi`0B0000000
00000000M;oo0080oooo00D0oono07@000000000000007Boo`020?ooo`050;md0000000000000018
W03Oool00`3oool01@3ogi`0B000000000000000B9cO00P0oooo00H0_g@000000000000000000018
W03OoomD0?ooo`050?oo_`1d000000000000001d_ol0403oool01@3o_g@000000000000007@0_ooo
00D0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol00P3o
ool01@3OW4P0000000000000B9`0gooo00<0oooo00D0omnL04P000000000000007Boo`080?ooo`05
0?oOW018000000000000001d_ol00P3oool01@3ookl0M000000000000000M;oo0080oooo00D0_g@0
00000000000004RL0=ooo`030?ooo`050?oOW0180000000000000018W=l0K`3oool00`3OW4P00000
000000090000000304RLg`3oool0oooo00L0oooo00D0okmd000000000000000007Boo`0B0?ooo`05
0?oo_`1d000000000000001d_ol0E@3oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000
oooo0?ooo`0b0?ooo`030=nLB0000000000000T0000000<0B9cO0?ooo`3oool02`3oool01@3o_g@0
00000000000007@0_ooo00D0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d0000
00000000001d_ol00P3oool01@3OW4P0000000000000B9`0gooo00<0oooo00D0okmd000000000000
001d0;ooo`080?ooo`030?oog`2LB000000000<0000000<007Bo0?oo_`1d00000P000000101d_ol0
oooo0?oog`2LB00200000003001d_`3oool0oooo0080oooo00D0oooO09a800000000000004RLg`04
0?ooo`030=nLB0000000000000D0000000<007Bo0?ooo`3oool0B`3oool01@3OW4P0000000000000
000007Bo0180oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oOW018000000000000B02L
gol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia800000000000004RL0=ooo`03
0?ooo`050?noM000000000000000M02oool0203oool00`3ooml0W4P00000000300000003001d_`3o
okl0M0000080000000@0M;oo0?ooo`3ooml0W4P00P0000000`00M;l0oooo0?ooo`020?ooo`050?oo
g`2LB000000000000018W=l0103oool00`3OW4P000000000000500000003001d_`3oool0oooo05<0
oooo00D0oono07@000000000000007Boo`0@0?ooo`050?noM000000000000000M02oool01@3oool0
1@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`020?ooo`050=nL
B000000000000018W03Oool00`3oool01@3o_g@000000000000007@0_ooo00P0oooo00<0oooO09a8
000000000`0000000`00M;l0oono07@000020000000407Boo`3oool0oooO09a80080000000<007Bo
0?ooo`3oool00P3oool01@3ooml0W4P0000000000000B9cO06l0oooo00<0gia80000000000002@00
00000`18W=l0oooo0?ooo`080?ooo`050=nLB0000000000000000000M;l04@3oool01@3ookl0M000
000000000000M;oo05D0oooo00<000000?ooo`3oool04`3oool00440oooo00<000000?ooo`3oool0
<P3oool0103ogi`0B00000000000M;l20?ooo`050?oog`2LB000000000000018W=l03`3oool01@3o
_g@000000000000007@0_ooo00D0oooo00D0omnL04P000000000001809cOo`030?ooo`050?oo_`1d
000000000000001d_ol00P3oool01@3OW4P0000000000000B9`0gooo00<0oooo00<0okmd00000000
0000200000001@0004P0W=oo0?ooo`3ooml0W4P000P0000000@0M;oo0?ooo`3ooml0W4P00P000000
0`18W=l0oooo0?ooo`020?ooo`050?oog`2LB000000000000018W=l00P3oool00`3ogi`0B0000000
0006000000030000M02oool0oooo04d0oooo00H0okmd00000000000000000018W03Oool@0?ooo`05
0?noM000000000000000M02oool01@3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono
07@000000000000007Boo`020?ooo`050=nLB000000000000018W03Oool00`3oool00`3o_g@00000
00000008000000050000B02Lgol0oooo0?oog`2LB00020000000101d_ol0oooo0?oog`2LB0020000
000304RLg`3oool0oooo0080oooo00D0oooO09a800000000000004RLg`020?ooo`030?oOW0180000
000000H0000000<0001d0;ooo`3oool0E03oool01@3ookl0M000000000000000M;oo0100oooo00D0
okmd000000000000001d0;ooo`050?ooo`050?oOW018000000000000B02Lgol00`3oool01@3ookl0
M000000000000000M;oo0080oooo00D0gia800000000000004RL0=ooo`030?ooo`030?noM0000000
000000P0000000D0001809cOo`3oool0oooO09a800080000000407Boo`3oool0oooO09a800800000
00<0B9cO0?ooo`3oool00P3oool01@3ooml0W4P0000000000000B9cO06l0oooo00@0omnL04P00000
000007Bo0P3oool01@3ooml0W4P0000000000000B9cO00d0oooo00H0okmd00000000000000000018
W03Oool?0?ooo`050?oo_`1d000000000000001d_ol0E@3oool00`000000oooo0?ooo`0C0?ooo`00
@@3oool00`000000oooo0?ooo`0c0?ooo`070=nLB0000000000007Boo`3oool0oooO09a800020000
000304RLg`3oool0oooo00d0oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oOW0180000
00000000B02Lgol00`3oool01@3ookl0M000000000000000M;oo0080oooo00D0gia8000000000000
04RL0=ooo`030?ooo`030?noM0000000000000P0000000<0001d0;ooo`3oool00`3oool00`3ooml0
W4P0000000040000000407Boo`3oool0oooO09a80080000000<0B9cO0?ooo`3oool00P3oool0203o
oml0W4P0000000000000B9cO0?ooo`3ooml0W4P01`0000000`1d_ol0oooo0?ooo`1?0?ooo`060?no
M0000000000000000000B9`0gooo3`3oool01@3o_g@000000000000007@0_ooo00D0oooo00D0omnL
04P000000000001809cOo`030?ooo`050?oo_`1d000000000000001d_ol00P3oool01@3OW4P00000
00000000B9`0gooo00<0oooo00<0okmd000000000000200000000`0007@0_ooo0?ooo`030?ooo`03
0?oog`2LB000000000@0000000@0M;oo0?ooo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`020?oo
o`080?oog`2LB000000000000018W=l0oooo0?oog`2LB0070000000307Boo`3oool0oooo05D0oooo
00D0oono07@000000000000007Boo`0@0?ooo`050?noM000000000000000M02oool01@3oool01@3o
gi`0B0000000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`020?ooo`050=nLB000
000000000018W03Oool00`3oool00`3o_g@0000000000008000000030000M02oool0oooo00<0oooo
00<0oooO09a80000000010000000101d_ol0oooo0?oog`2LB0020000000304RLg`3oool0oooo0080
oooo00D0oooO09a800000000000004RLg`1`0?ooo`070=nLB0000000000007Boo`3oool0oooO09a8
00020000000304RLg`3oool0oooo00`0oooo00H0okmd00000000000000000018W03Oool>0?ooo`05
0?oo_`1d000000000000001d_ol0E@3oool00`000000oooo0?ooo`0C0?ooo`00@@3oool00`000000
oooo0?ooo`0c0?ooo`070?oo_`1d000000000000M02oool0oooO09a800020000000304RLg`3oool0
oooo00d0oooo00D0okmd000000000000001d0;ooo`050?ooo`050?oOW0180000000000000018W=l0
0`3oool01@3ogi`0B000000000000000M;oo0080oooo00D0gia8000000000000001809cOo`030?oo
o`050?oOW018000000000000B02Lgol00`3oool01@3o_g@0000000000000B9`0gooo00L0oooo00D0
oono07@000000000000007Boo`020?ooo`050;md0000000000000018W03Oool00`3oool0203ogi`0
B000000000000000B9cO0?ooo`3ookl0M0000`0000000`18W=l0oooo0?ooo`1D0?ooo`050?noM000
0000000000000000M;l03`3oool01@3o_g@000000000000007@0_ooo00D0oooo00D0omnL04P00000
0000000004RLg`030?ooo`050?oOW018000000000000001d_ol00P3oool01@3OW4P0000000000000
04P0W=oo00<0oooo00D0omnL04P000000000001809cOo`030?ooo`050?noM000000000000018W03O
ool01`3oool01@3ookl0M000000000000000M;oo0080oooo00D0_g@000000000000004RL0=ooo`03
0?ooo`080?oOW0180000000000000018W=l0oooo0?oo_`1d00030000000304RLg`3oool0oooo05T0
oooo00D0oono07@000000000000007Boo`0@0?ooo`050?noM000000000000000M02oool01@3oool0
1@3ogi`0B000000000000000B9cO00<0oooo00D0omnL04P000000000000007Boo`020?ooo`050=nL
B000000000000000B02Lgol00`3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0okmd0000
0000000004RL0=ooo`070?ooo`050?oo_`1d000000000000001d_ol00P3oool01@2oM00000000000
0000B9`0gooo00<0oooo00D0omnL04P000000000000004RLg`1`0?ooo`070?oo_`1d000000000000
M02oool0oooO09a800020000000304RLg`3oool0oooo00d0oooo00D0okmd0000000000000000001d
_`0>0?ooo`050?oo_`1d000000000000001d_ol0E@3oool00`000000oooo0?ooo`0C0?ooo`00@@3o
ool00`000000oooo0?ooo`0d0?ooo`060?noM00000000000001d_`3ooml0W4P00P0000000`18W=l0
oooo0?ooo`0=0?ooo`050?noM000000000000000M02oool01@3oool01P3ogi`0B000000000000000
001809cOo`80oooo00D0_g@0000000000000001809cOo`020?ooo`050=nLB0000000000000000000
M;l00`3oool02@3ooml0W4P000000000000004RL0=ooo`3oool0oono07@0000200000004001d_`3o
ool0oooo0;md0080000000D0M;oo0?ooo`3oool0omnL04P000020000000407Boo`3oool0oooo0?no
M0<0000000D007Bo0?ooo`3oool0oono07@000030000000704RLg`3oool0oono07@000000000001d
0;ooo`020?ooo`050?noM0000000000000000018W=l0D@3oool01@3o_g@00000000000000000M;oo
00h0oooo00D0okmd000000000000001d0;ooo`050?ooo`060?oOW018000000000000000004P0W=oo
0P3oool01@2oM00000000000000004P0W=oo0080oooo00D0gia80000000000000000001d_`030?oo
o`090?oog`2LB000000000000000B9`0gooo0?ooo`3ookl0M0000080000000@007Bo0?ooo`3oool0
_g@00P0000001@1d_ol0oooo0?ooo`3ogi`0B0000080000000@0M;oo0?ooo`3oool0okmd0`000000
1@00M;l0oooo0?ooo`3ookl0M00000<0000000L0B9cO0?ooo`3ookl0M0000000000007@0_ooo0080
oooo00D0okmd000000000000000004RLg`1E0?ooo`050?oo_`1d000000000000001d_ol0403oool0
1@3o_g@000000000000007@0_ooo00D0oooo00H0omnL04P00000000000000000B02Lgol20?ooo`05
0;md0000000000000000B02Lgol00P3oool01@3OW4P0000000000000000007Bo00<0oooo00T0oooO
09a80000000000000018W03Oool0oooo0?oo_`1d00000P0000001000M;l0oooo0?ooo`2oM0020000
000507Boo`3oool0oooo0?oOW01800000P000000101d_ol0oooo0?ooo`3o_g@300000005001d_`3o
ool0oooo0?oo_`1d00000`0000000`18W=l0oooo0?ooo`1_0?ooo`060?noM00000000000001d_`3o
oml0W4P00P0000000`18W=l0oooo0?ooo`0>0?ooo`050?noM000000000000000001d_ol03@3oool0
1@3ookl0M000000000000000M;oo05D0oooo00<000000?ooo`3oool04`3oool00440oooo00<00000
0?ooo`3oool0=@3oool01@2oM00000000000001d_ml0W4P00080000000<0B9cO0?ooo`3oool03@3o
ool01@3o_g@000000000000007@0_ooo00D0oooo00<0omnL04P000000000200000001@0007@0_ooo
0?ooo`3oool0gia800H0000000<007Bo0?ooo`3o_g@0200000001@0004P0W=oo0?ooo`3oool0okmd
0080000000@004RL0=ooo`3oool0gia80P0000001P0004P0W=oo0?ooo`3oool0oono07@000X00000
00@0B9cO0?ooo`3ooml0W4P0200000000`0004P0W=oo0?ooo`1A0?ooo`040;md000000000000001d
_`h0oooo00D0okmd000000000000001d0;ooo`050?ooo`030?oOW0180000000000P0000000D0001d
0;ooo`3oool0oooo0=nLB00600000003001d_`3oool0okmd00P0000000D0001809cOo`3oool0oooo
0?noM002000000040018W03Oool0oooo0=nLB080000000H0001809cOo`3oool0oooo0?oo_`1d000:
0000000404RLg`3oool0oooO09a800P0000000<0001809cOo`3oool0D03oool01P3ookl0M01809cO
o`3oool0oono07@00080000000<0M;oo0?ooo`3oool03P3oool01@3o_g@000000000000007@0_ooo
00D0oooo00<0omnL04P000000000200000001@0007@0_ooo0?ooo`3oool0gia800H0000000<007Bo
0?ooo`3o_g@0200000001@0004P0W=oo0?ooo`3oool0okmd0080000000@004RL0=ooo`3oool0gia8
0P0000001P0004P0W=oo0?ooo`3oool0oono07@000X0000000<0B9cO0?ooo`3oool0L03oool01@2o
M00000000000001d_ml0W4P00080000000<0B9cO0?ooo`3oool03`3oool0102oM000000000000000
M;l90?ooo`060?oo_`1d04P0W=oo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo00110?ooool00000o`00003o000000`000005@3oool00?l0ooooo`3o
oooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0
ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3o
ool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0
ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo
0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00
o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR
0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0oooo
o`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?oo
ool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo
003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?oo
of80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3o
oooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0
ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3o
ool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0
ooooHP3oool00?l0ooooo`3oooll0?ooo`030?oo_`1d0000000000@0000000<007Bo0?ooo`3oool0
o`3ooolL0?ooo`00o`3ooooo0?oooc/0oooo00<0gia80000000000001P0000000`0004P0W=oo0?oo
o`3o0?oooa/0oooo003o0?ooool0oooo>P3oool00`3ogi`0B00000000008000000030018W03Oool0
oooo0?l0oooo6P3oool00?l0ooooo`3ooolj0?ooo`050?noM0000000000000000000M;l00`3oool0
1@3OW4P000000000000004P0W=oo0?l0oooo6`3oool00?l0ooooo`3ooom20?ooo`050?oo_`1d0000
00000000001d_ol0o`3ooolK0?ooo`00o`3oooo10?ooo`060?noM000000000000000000004P0W=oo
203oool00`3ogi`0B00000000002000000030000M02oool0oooo00H0oooo00<0_g@0000000000000
0P0000000`00M;l0oooo0?ooo`030?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool0
0P3oool00`3ookl0M00000000002000000030000B02Lgol0oooo00@0oooo00D0gia8000000000000
04RL0=ooo`0;0?ooo`030?oo_`1d0000000000X0000000H0M;oo0?ooo`3oool0oooo0?oOW0180003
000000030000M02oool0oooo00<0oooo00D0omnL04P000000000001d0;ooo`030?ooo`050?oo_`1d
000000000000001d_ol0103oool00`3ooml0W4P0000000020000000307Boo`3ookl0M00000800000
00H0M;oo0?ooo`3oool0oooo0?oog`2LB003000000070018W03Oool0omnL04P000000000001809cO
o`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool40?ooo`00o`3oooo10?ooo`030;md0000
000000000080000000<0B9cO0?ooo`3oool01@3oool00`3OW4P00000000000050000000304RLg`3o
ool0oooo0080oooo00<0omnL04P0000000001@0000000`0004P0W=oo0?ooo`020?ooo`030;md0000
000000000080000000D004RL0=ooo`3oool0oooO09a80007000000030018W03Oool0oooo0080oooo
00D0gia800000000000004RL0=ooo`0;0?ooo`030?oo_`1d0000000000X0000000@0M;oo0?ooo`3o
ool0gia81`0000002@18W=l0oooo0?ooo`3oool0omnL04P000000000001d0;ooo`030?ooo`050?oo
_`1d000000000000001d_ol00`3oool00`3ogi`0B000000000040000000504RLW01d000000000000
001d_ol00`3oool00`2oM000000000000002000000070018W03Oool0omnL04P000000000001809cO
o`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool40?ooo`00o`3oooo00?ooo`030?oo_`1d
0000000000<0000000<004RL0=ooo`3oool0103oool00`3o_g@0000000000006000000060000B02L
gol0oooo0?ooo`3ookl0M000200000001@00B9`0gooo0?ooo`3ookl0M00000@0000000@004RL0=oo
o`3oool0_g@02@0000001@00M;l0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02P3o
ool00`3ookl0M0000000000:0000000307Boo`3oool0okmd00P0000000T0001809cOo`3oool0oooo
0?oOW018000000000000M02oool00`3oool01@3ookl0M000000000000000M;oo0080oooo00<0oooO
09a8000000002@0000001@1d_ol0oooo0?ooo`3ookl0M00000@0000000L004RL0=ooo`3ogi`0B000
0000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`3o0?ooo`@0oooo003o0?oool00
oooo00P0gia800000000000004Qd07A800000000001809cOo`@0oooo00T0oooO09a8000000000000
0000M02oool0oooo0?oog`2LB0000P0000001000M;l0oooo0?ooo`3OW4P30000000407Boo`3oool0
oooo0=nLB0<0000000@0M;oo0?ooo`3ookl0M0000P0000001P1d_ol0oooo0?ooo`3oool0omnL04P0
0080000000D004RL0=ooo`3oool0oooo0;md00030000000407Boo`3oool0oooo0=nLB080000000<0
04RL0=ooo`3oool02P3oool01@3ookl0M000000000000000M;oo00T0oooo00T0oooO09a800000000
00000000M02oool0oooo0?oog`2LB0000P0000002000M;l0oooo0?ooo`3ogi`0B0000000000007@0
_ooo0`3oool01@3ookl0M000000000000000M;oo0080oooo00D0okmd0000000000000000001d_`02
0?ooo`030?oOW018000000000080000000D0M;oo0?ooo`3oool0oono07@000020000000907Boo`3o
ool0oooo0?ooo`3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`3o
0?ooo`@0oooo003o0?oookl0oooo00H0oooO09a800000000000004RLg`3OW4P20000000304RLg`3o
ool0oooo0080oooo00D0omnL04P000000000000007Boo`080?ooo`050?oog`2LB000000000000000
M;l00`3oool0103ookl0M0000018W03Oool20?ooo`050?oo_`1d000000000000001d_ol00`3oool0
1@3OW4P000000000000007@0_ooo00<0oooo00D0oooO09a8000000000000001d_`020?ooo`050=nL
B000000000000018W03Oool02`3oool01@3ookl0M000000000000000M;oo00T0oooo00D0omnL04P0
00000000000007Boo`090?ooo`050?oOW018000000000000M02oool00`3oool01@3ookl0M0000000
00000000M;oo0080oooo00D0_g@000000000000004RL0=ooo`030?ooo`050?noM000000000000000
001d_ol00P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P000000000001809cO
o`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool40?ooo`00o`3ooono0?ooo`060?oOW018
000000000000B02Lgol0okmd0P0000000`00B9`0gooo0?ooo`020?ooo`050?noM000000000000000
M02oool0203oool01@3ooml0W4P0000000000000B9cO00T0oooo00D0oono07@000000000000007Bo
o`030?ooo`040;md000000000000001d_`D0oooo00L0gia800000000000004RL0=ooo`3oool0gia8
0080000000<004RL0=ooo`3oool02P3oool01@3ookl0M000000000000000M;oo00T0oooo00D0okmd
000000000000001d0;ooo`090?ooo`050?oOW018000000000000M02oool00`3oool0203ookl0M000
000000000000M;oo0?ooo`3ooml0W4P00P0000000`18W=l0oooo0?ooo`020?ooo`050?oo_`1d0000
00000000001d_ol00P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0omnL04P000000000
001809cOo`030?ooo`050?oo_`1d000000000000001d_ol0o`3oool40?ooo`00o`3ooono0?ooo`0:
0=nLB000000000000000M02oool0oono07@000000000001809cOo`<0oooo00<0okmd000000000000
20000000100004P0W=oo0?oo_`1d00020000000307Boo`3oool0oooo00L0oooo00D0oono07@00000
0000000007Boo`020?ooo`050?oog`2LB000000000000018W=l01@3oool01`3o_g@0000000000000
07@0_ooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0:0?ooo`050?oo_`1d000000000000001d
_ol02@3oool00`3o_g@0000000000008000000080000B02Lgol0oooo0?oOW018000000000000B02L
gol30?ooo`080?oo_`1d000000000000001d_ol0oooo0?oog`2LB0020000000304RLg`3oool0oooo
0080oooo00D0oooO09a800000000000007Boo`020?ooo`050?oo_`1d000000000000001d_ol00`3o
ool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@000000000000007Boo`3o0?ooo`@0
oooo003o0?oookh0oooo00D0oooO09a8000000000000001d_`020?ooo`040;md00000000000004RL
g`<0oooo00<0okmd00000000000020000000100007@0_ooo0?oog`2LB0020000000307Boo`3oool0
oooo00L0oooo00D0oono07@000000000000007Boo`020?ooo`050?oog`2LB000000000000000M;l0
1@3oool01`3OW4P0000000000000B9`0gooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0:0?oo
o`050?oo_`1d000000000000001d_ol02@3oool00`3o_g@0000000000008000000080000M02oool0
oooo0?oOW018000000000000B02Lgol30?ooo`080?oo_`1d000000000000001d_ol0oooo0?oog`2L
B0020000000304RLg`3oool0oooo0080oooo00D0oono07@000000000000007Boo`020?ooo`050?oo
_`1d000000000000001d_ol00`3oool01@3ogi`0B0000000000004P0W=oo00<0oooo00D0oono07@0
00000000000007Boo`3o0?ooo`@0oooo003o0?oookh0oooo00D0omnL04P000000000000007Boo`02
0?ooo`050?noM000000000000000M02oool00P3oool01@3ogi`0B0000000000004P0W=oo00<0oooo
00L0okmd00000000000004RL0=ooo`3ooml0W4P00080000000L007Bo0?ooo`3oool0oooo0?oOW018
0000B9cO00<0oooo00D0oono07@000000000000007Boo`030?ooo`050=nLB000000000000000M02o
ool00`3oool01@3ooml0W4P000000000000007Bo0080oooo00D0gia8000000000000001809cOo`0;
0?ooo`050?oo_`1d000000000000001d_ol02@3oool01@3ogi`0B0000000000004P0W=oo00<0oooo
00P0okmd00000000000004RL0=ooo`3oool0omnL04P00080000000H0M;oo0?ooo`3oool0oooo0?oO
W01800020000000407Boo`3oool0oooo0;md0080000000<004RL0=ooo`3oool00P3oool01@3ogi`0
B000000000000000M;oo0080oooo00D0oono07@000000000000007Boo`030?ooo`050?oOW0180000
000000000018W=l00`3oool01@3ogi`0B000000000000000M;oo0?l0oooo103oool00?l0oooo_P3o
ool01@3OW4P000000000000007@0_ooo0080oooo00D0oono07@000000000000007Boo`020?ooo`09
0?oog`2LB000000000000000B9`0gooo0?ooo`3ookl0M0000080000000@007Bo0?ooo`3oool0gia8
0`000000101d_ol0oooo0?oog`2LB002000000050000M02oool0oooo0?oo_`1d00000P0000001P1d
_ol0oooo0?ooo`3oool0omnL04P00080000000D004RL0=ooo`3oool0oooo0;md00030000000407Bo
o`3oool0oooo0=nLB0<0000000<007Bo0?ooo`3oool02@3oool01@3ookl0M000000000000000M;oo
00T0oooo00T0oooO09a80000000000000018W03Oool0oooo0?oo_`1d00000P0000001@00M;l0oooo
0?ooo`3ogi`0B0000080000000D0001809cOo`3oool0oooo0;md00030000000407Boo`3oool0oooo
0?noM0<0000000D007Bo0?ooo`3oool0oono07@000030000000507Boo`3oool0oooo0?oo_`1d0000
0P0000001P1d_ol0oooo0?ooo`3oool0omnL04P00080000000D0001809cOo`3oool0oooo0;md0002
000000030000B02Lgol0oooo0?l0oooo0`3oool00?l0oooo_@3oool01@3ooml0W4P0000000000000
07Bo00@0oooo00@0_g@000000000000007Bo0`3oool00`3o_g@0000000000006000000060000B02L
gol0oooo0?ooo`3ookl0M000200000000`00M;l0oooo0;md000600000004001d_`3oool0oooo0;md
00T0000000D007Bo0?ooo`3oool0oooo0=nLB00600000003001d_`3oool0oooo00H0oooo00D0oono
07@000000000000007Boo`0:0?ooo`030?noM0000000000000H0000000H0001809cOo`3oool0oooo
0?oOW0180009000000060000M02oool0oooo0?ooo`3ooml0W4P02P0000000`1d_ol0oooo0;md0006
00000004001d_`3oool0omnL04P000T0000000<0001d0;ooo`3oool0o`3oool30?ooo`00o`3ooonm
0?ooo`050?oOW0180000000000000018W=l0103oool01@3OW4P000000000000007@0_ooo00<0oooo
00<0gia80000000000001@0000000`1d_ol0oooo0?ooo`020?ooo`030?oOW0180000000000D00000
00@0001d0;ooo`3oool0_g@01P0000001@00M;l0oooo0?ooo`3oool0_g@000L0000000<004RL0=oo
o`3oool00P3oool0103OW4P0000000000018B4P3000000030000M02oool0oooo00H0oooo00D0oono
07@000000000000007Boo`0;0?ooo`030=nLB0000000000000D0000000T0M;oo0?ooo`3oool0oooo
0?oOW018000000000018M01dB0001P0000000`18W=l0oooo0?ooo`020?ooo`030?oOW01800000000
00@0000000L007Bo0;md00000000000007Boo`3oool0_g@000H0000000L007Bo0?ooo`3ogi`0B000
0000000004P0W9ad00H0000000<0B9cO0?ooo`3oool0o`3oool30?ooo`00o`3ooonm0?ooo`050=nL
B000000000000000B02Lgol0103oool01@3ogi`0B000000000000000M;oo00@0oooo00<0oono07@0
000000000P0000000`00B9`0gooo0?ooo`060?ooo`030;md0000000000000080000000D0B9cO0?oo
o`3oool0oooo0;md000600000003001d_`3oool0oooo0080oooo00<0omnL04P0000000000P000000
0`0004P0W=oo0?ooo`040?ooo`050=nLB0000000000004RLg`3OW4P00P0000000`0004P0W=oo0?oo
o`060?ooo`050?oo_`1d000000000000001d_ol0303oool00`3ookl0M00000000002000000030018
W03Oool0oooo00<0oooo00H0omnL04P00000000004RL0=ooo`3o_g@40000000307Boo`3oool0oooo
00@0oooo00<0oooO09a8000000000P0000000`18W=l0oooo0;md00020000000307Boo`3oool0_g@0
00H0000000T007Bo0?ooo`3ogi`0B0000000000004P0W=oo0?oo_`1d00000`0000000`1d_ol0oooo
0?ooo`3o0?ooo`@0oooo003o0?oook`0oooo00H0oooO09a80000000000000018W03Oool40?ooo`05
0?oog`2LB000000000000000M;l0703oool01@3ookl0M000000000000000M;oo0280oooo00D0oono
07@000000000000007Boo`0e0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ogi`0B000
0000000004P0W=oo0?l0oooo303oool00?l0oooo_03oool01@3ogi`0B000000000000000B9cO00H0
oooo00D0gia8000000000000001d0;ooo`0K0?ooo`050?oo_`1d000000000000001d_ol08P3oool0
1@3ookl0M000000000000000M;oo03D0oooo00D0oono07@000000000000007Boo`030?ooo`050?oO
W018000000000000B02Lgol0o`3oool<0?ooo`00o`3ooonl0?ooo`050=nLB000000000000000B02L
gol01P3oool01@3ogi`0B000000000000000M;oo01`0oooo00@0omnL04P000000000M;oo8P3oool0
1@3ookl0M000000000000000M;oo03H0oooo00@0omnL04P000000000M;oo0`3oool01@3ogi`0B000
0000000004P0W=oo0?l0oooo303oool00?l0oooo^`3oool01P3ooml0W4P000000000000004RL0=oo
o`H0oooo00D0oooO09a8000000000000001d_`0N0?ooo`030=nLB01d_ol0oooo0240oooo00D0oono
07@000000000000007Boo`0h0?ooo`030=nLB01d_ol0oooo0080oooo00D0omnL04P0000000000018
09cOo`3o0?ooo``0oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool0
0?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0oooo
HP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?oo
ool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00gP3o
ool00`3ooml0W4P000000002000000030018W03Oool0oooo07`0oooo00<0oooO09a8000000000P00
00000`0007@0_ooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3o
ool00`3ooml0W4P000000002000000030018W03Oool0oooo06X0oooo00D0oono07@0000000000000
07Boo`060?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P0
00000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo
0?ooo`1U0?ooo`050?oo_`1d000000000000001d_ol01P3oool00`3ooml0W4P00000000200000003
0000M02oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`03
0?oog`2LB00000000080000000<004RL0=ooo`3oool0G`3oool00`3o_g@000000000000800000003
0000M02oool0oooo0080oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`03
0?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P00000000200000003
0018W03Oool0oooo0240oooo003M0?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0
NP3oool00`3ogi`0B000000000050000000307Boo`3oool0oooo0080oooo00<0omnL04P000000000
100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0
J@3oool01@3ookl0M000000000000000M;oo00D0oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0
B00000000004000000030000B02Lgol0oooo06@0oooo00D0oono07@000000000000007Boo`050?oo
o`030?oOW0180000000000D0000000<0M;oo0?ooo`3oool00P3oool00`3ogi`0B000000000040000
00030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`1N0?oo
o`030?oo_`1d0000000000P0000000H0001d0;ooo`3oool0oooo0?oOW0180005000000030000B02L
gol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW018
0000000000@0000000<0001809cOo`3oool0803oool00=`0oooo00<0oono07@0000000001P000000
0`00B9`0gooo0?ooo`1h0?ooo`030?oo_`1d0000000000H0000000H0001809cOo`3oool0oooo0?oo
_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`1X0?oo
o`050?oo_`1d000000000000001d_ol0103oool00`3ookl0M00000000006000000060018W03Oool0
oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=oo
o`3oool0H`3oool01@3ookl0M000000000000000M;oo00@0oooo00<0oono07@0000000001P000000
1P0004P0W=oo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d00070000
00030018W03Oool0oooo05h0oooo00<0_g@00000000000001`0000001@0007@0_ooo0?ooo`3ookl0
M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3o
okl0M0001`0000000`00B9`0gooo0?ooo`0O0?ooo`00g03oool01`3o_g@000000000000004P0W=oo
0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`1g0?ooo`080=nLB000000000000000001d_ol0oooo
0?oo_`1d000200000004001d_`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000
101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0
I`3oool01@3ookl0M000000000000000M;oo00@0oooo00L0okmd000000000000001809cOo`3oool0
okmd00<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Bo
o`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1R0?oo
o`050?oo_`1d000000000000001d_ol0103oool0203OW4P00000000000000000M;oo0?ooo`3ookl0
M0000P0000001000M;l0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo
0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo05d0oooo
00D0omnL04P000000000000004RLg`080?ooo`070?noM000000000000000B02Lgol0oooo0?noM003
0000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo
0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool07P3oool00=`0
oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=mh0?ooo`050?oog`2LB000
000000000000M;l00`3oool01`3o_g@000000000000007@0_ooo0?ooo`2oM0000P0000001@00M;l0
oooo0?ooo`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P0000001@00M;l0oooo0?ooo`3o
ool0_g@00080000000<0B9cO0?ooo`3oool0I`3oool01@3ookl0M000000000000000M;oo00@0oooo
00@0_g@000000000000007Bo0`3oool0102oM000000000000018W=l20?ooo`040;md000000000000
001d_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md
00000000000004RLgf@0oooo00D0oono07@000000000000007Boo`030?ooo`050?oog`2LB0000000
00000000M;l00`3oool01`3o_g@000000000000007@0_ooo0?ooo`2oM0000P0000001@00M;l0oooo
0?ooo`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P0000001@00M;l0oooo0?ooo`3oool0
_g@00080000000<0B9cO0?ooo`3oool0GP3oool01@3o_g@00000000000000000M;oo00L0oooo00@0
_g@000000000000007Bo0`3oool0102oM000000000000018W=l20?ooo`040;md000000000000001d
_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md0000
0000000004RLgb00oooo003K0?ooo`050?oog`2LB00000000000001d_ol00`3oool01@3OW4P00000
00000000B9`0gooo07L0oooo00D0oono07@000000000000007Boo`030?ooo`070?oOW01800000000
0000B02Lgol0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo
0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`1W0?oo
o`050?oo_`1d000000000000001d_ol00`3oool01@3ooml0W4P0000000000000M;oo00<0oooo00L0
gia800000000000004RL0=ooo`3ooml0W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB0020000
00040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03O
ool0oooo0680oooo00D0oono07@000000000000007Boo`030?ooo`050?oo_`1d000000000000001d
_ol00`3oool01`3ogi`0B0000000000004P0W=oo0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3o
ool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080
000000<004RL0=ooo`3oool0G`3oool01@3OW4P0000000000000000007Bo00D0oooo00D0oooO09a8
00000000000007Boo`030?ooo`070=nLB000000000000018W03Oool0oooO09a800020000000507Bo
o`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo
0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0N0?ooo`00f`3oool01@3ookl0M000000000000000
M;oo00<0oooo00D0okmd00000000000004RL0=ooo`1o0?ooo`070?oOW018000000000000B02Lgol0
oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d0002
0000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`1W0?ooo`050?oo_`1d
000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd00000000
000004RL0=ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03O
ool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo0680
oooo00D0oono07@000000000000007Boo`0;0?ooo`070?oOW018000000000000B02Lgol0oono07@0
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`1P0?ooo`060?noM00000000000
00000000B9`0gooo0`3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000
04RL0=ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0
oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo01h0oooo
003K0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3o_g@000000000000007@0_ooo07l0
oooo00L0okmd000000000000001809cOo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?no
M002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM00200000003
0000M02oool0oooo06L0oooo00D0oono07@000000000000007Boo`030?ooo`050?oo_`1d00000000
0000001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo
0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0
okmd0080000000<0001d0;ooo`3oool0HP3oool01@3ookl0M000000000000000M;oo00/0oooo00L0
okmd000000000000001809cOo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM0020000
00040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02o
ool0oooo0640oooo00H0okmd00000000000000000018W03Oool20?ooo`050?oo_`1d000000000000
001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000<0001d0;ooo`3oool07P3oool00=/0oooo00D0oono07@000000000000007Boo`030?oo
o`050?noM000000000000000M02oool0N03oool0203OW4P0000000000000B9`0gooo0?ooo`3ookl0
M0000P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000
100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo
0?ooo`1W0?ooo`050?oo_`1d000000000000001d_ol00`3oool01@3ookl0M000000000000000M;oo
00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM0020000
00030000M02oool0oooo0680oooo00D0oono07@000000000000007Boo`040?ooo`080=nLB0000000
00000018W03Oool0oooo0?oo_`1d0002000000040018W03Oool0oono07@00080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030000M02oool0oooo0680oooo00D0okmd0000000000000000001d_`020?ooo`05
0?oo_`1d000000000000001d_ol00`3oool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P00
00001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0
oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool07P3oool00=/0oooo00D0oono07@00000
0000000007Boo`030?ooo`050?noM000000000000000M02oool0N03oool00`3o_g@0000000000007
0000000407Boo`3oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000
M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo
06L0oooo00D0oono07@000000000000007Boo`030?ooo`050?oo_`1d000000000000001d_ol00`3o
ool01`3o_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0
001d0;ooo`3oool0HP3oool01@3ookl0M000000000000000M;oo00@0oooo00<0okmd000000000000
1`000000101d_ol0oooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000
07@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?oo
o`1S0?ooo`080?noM000000000000000001d_ol0oooo0?oo_`1d00020000000507Boo`3oool0oooo
0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
07@0_ooo0?ooo`0N0?ooo`00f`3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd0000
0000000004RL0=ooo`1h0?ooo`030?oOW0180000000000H0000000D007Bo0?ooo`3oool0oono07@0
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`1S0?ooo`060?oo_`1d04P0W=oo
0?ooo`3ookl0M0000P0000001P1d_ol0oooo0?ooo`3oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?no
M002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM00200000003
0018W03Oool0oooo05h0oooo00H0oono07@0B02Lgol0oooo0?oo_`1d00020000000307Boo`3oool0
oooo0080oooo00<0omnL04P0000000001P0000001@00M;l0oooo0?ooo`3ookl0M0000080000000D0
M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000030018W03Oool0oooo06@0oooo00L0_g@000000000000007Bo0?ooo`3o
okl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo
0?ooo`3oool0oooo0?noM002000000030018W03Oool0oooo01h0oooo003K0?ooo`050?oog`2LB000
00000000001d_ol00`3oool01@3OW4P0000000000000B9`0gooo07P0oooo00D0oooO09a800000000
001804Q800030000000607Boo`3oool0oooo0?ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3o
ool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080
000000<004RL0=ooo`3oool0H`3oool01P3ookl0M00000000000B9`0gono07@00080000000H0M;oo
0?ooo`3oool0oooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0
gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2L
B0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`1N0?ooo`060?oo
_`1d000000000018W03Ookl0M0000P0000000`1d_ol0oooo0?ooo`020?ooo`050?oog`2LB0000000
0000B018B0000`0000001P1d_ol0oooo0?ooo`3oool0oooO09a80080000000D0M;oo0?ooo`3oool0
oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?ooo`3oool0oooo0=nLB002
000000030018W03Oool0oooo05`0oooo00D0oono07@000000000000007Boo`030?ooo`070?noM000
000000000000M02oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000
B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oo
g`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0N0?ooo`00
g03oool0102oM000000000000000M;l30?ooo`040;md000000000000001d_gX0oooo00@0_g@00000
00000000M;oo203oool0102oM000000000000000M;l30?ooo`040;md000000000000001d_`80oooo
00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;mU0?ooo`030?oo_`1d00000000
00D0000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l30?ooo`040;md00000000
0000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`04
0;md000000000000001d_`<0oooo00@0_g@000000000000007BoH03oool00`3ookl0M00000000005
0000000307Boo`3oool0oooo00<0oooo00@0_g@0000000000000M;oo203oool0102oM00000000000
0000M;l30?ooo`040;md000000000000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102o
M000000000000000M;mN0?ooo`050?oog`2LB000000000000018W=l00`3oool01`3o_g@000000000
000007@0_ooo0?ooo`2oM0000P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@007Bo0?oo
o`3oool0_g@00P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@007Bo0?ooo`3oool0_g@0
0P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000<007Bo0?ooo`3oool07P3oool00=`0oooo
00L0okmd000000000000001809cOo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0N03oool0103O
W4P0000000000000M;l80?ooo`070?noM000000000000000B02Lgol0oooo0?noM0030000000407Bo
o`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`1T0?oo
o`030?oog`2LB000000000@0000000<0M;oo0?ooo`3oool00P3oool01`3o_g@000000000000004P0
W=oo0?ooo`3o_g@00`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0
000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0
oooo05l0oooo00<0oooO09a800000000100000000`1d_ol0oooo0?ooo`030?ooo`040=nLB0000000
0000001d_`P0oooo00L0okmd000000000000001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3o
ool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000307Boo`3oool0oooo05d0oooo00P0_g@0
000000000000001809cOo`3oool0oono07@00080000000@004RL0=ooo`3oool0okmd0P0000001000
04P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd
0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?oo
o`3oool07P3oool00=`0oooo00<0oono07@0000000001P0000000`00B9`0gooo0?ooo`1i0?ooo`03
0?oOW0180000000000H0000000D0B9cO0?ooo`3oool0oono07@00007000000060018W03Oool0oooo
0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`1W0?ooo`030?noM000000000000080000000<0
M;oo0?ooo`3oool00P3oool00`3ookl0M00000000006000000060018W03Oool0oooo0?ooo`3ookl0
M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0HP3oool0
0`3o_g@00000000000020000000307Boo`3oool0oooo00<0oooo00<0omnL04P0000000001P000000
1@18W=l0oooo0?ooo`3ookl0M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d000700000003
0018W03Oool0oooo05h0oooo00<0omnL04P0000000001`0000001@18W=l0oooo0?ooo`3ookl0M000
00L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0
M0001`0000000`00B9`0gooo0?ooo`0O0?ooo`00g@3oool00`3ogi`0B00000000004000000030000
B02Lgol0oooo07X0oooo00<0oono07@0000000001P0000001P18W=l0oooo0?ooo`3oool0omnL04P0
00D0000000<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo
06T0oooo00D0omnL04P000000000000007Boo`050?ooo`030?oOW0180000000000@0000000<00018
09cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL
04P000000000100000000`0004P0W=oo0?ooo`1T0?ooo`050?oOW018000000000000001d_ol01@3o
ool00`3ookl0M000000000060000000604RLg`3oool0oooo0?ooo`3ogi`0B0001@0000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0H03oool00`3OW4P0
00000000000500000003001d_`3oool0oooo0080oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0
B00000000004000000030000B02Lgol0oooo0200oooo003N0?ooo`030?oog`2LB000000000800000
00<004RL0=ooo`3oool0N`3oool00`3ooml0W4P0000000060000000304RLg`3oool0oooo0080oooo
00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB000000000800000
00<004RL0=ooo`3oool0J`3oool0103OW4P000000000001d_ol60?ooo`030?oog`2LB00000000080
000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0
oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`1V0?ooo`040=nLB0000000000007Bo
o`D0oooo00<0oooO09a8000000001P0000000`18W=l0oooo0?ooo`020?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
0680oooo00<0oono07@0000000000`0000000`1d_ol0oooo0?ooo`040?ooo`030?oog`2LB0000000
0080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo
00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0Q0?ooo`00o`3ooooo0?ooool0
ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo
0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00
o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR
0?ooo`00o`3ooooo0?ooool0ooooHP3oool00=80ooooo`00003o000007H000006@3oool00=80oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool06P3oool2000001T0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo0P00
000I0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00_@3oool00`3ooml0W4P0000000020000
00030018W03Oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00;`0oooo00<0omnL04P00000
0000100000000`0004P0W=oo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002k0?ooo`030?oo
_`1d0000000000H0000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00^`3o
ool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0:0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo002k0?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000
0000B9cO303oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?oo
o`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00^P3oool01@3ooml0W4P0000000000000M;oo
00<0oooo00D0gia800000000000004RL0=ooo`0;0?ooo`D00000o`1oOgoo07moOf`0Ogmo1@00000I
0?ooo`00^P3oool01@3ookl0M000000000000000M;oo00<0oooo00D0okmd00000000000004RL0=oo
o`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo002j0?ooo`050?oo_`1d000000000000001d_ol00`3o
ool01@3o_g@000000000000007@0_ooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00;X0oooo00D0
oono07@000000000000007Boo`030?ooo`050?noM000000000000000M02oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0303oool00`3<I/`0
oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo002j0?ooo`050?oo_`1d000000000000001d
_ol00`3oool01@3o_g@000000000000007@0_ooo00/0oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo0080ooooo`3<I/c10<aVc0d0oooo00<000000?oo
o`3oool05`3oool00;X0oooo00D0oono07@000000000000007Boo`030?ooo`050?noM00000000000
0018W03Oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0780ooooo`3<I/cR
0<aVc0h0oooo00<000000?ooo`3oool05`3oool00;X0oooo00D0oooO09a800000000000007Boo`03
0?ooo`050=nLB000000000000018W03Oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo06<0oooo<@3<I/b<0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`0;0?ooo`030<aVc03oool0oooo00d0oooo00<000000?ooo`3oool05`3o
ool00;/0oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l<0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0B@3ooolY0<aVc1d0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00^`3oool01`3o_g@000000000000004P0W=oo0?ooo`3o
_g@00`0000000`1d_ol0oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0803ooom30<aVc2`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
^`3oool00`3ookl0M00000000006000000030018W03Oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0P0?ooobT0c6K<AP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo002l0?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00_@3oool00`3ooml0W4P000000002000000030018W03Oool0
oooo00d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0
oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1o
Ogl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0
oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<0
00000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?oo
o`3oool05`3oool00=80oooo1000000;0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool06@3oool3000001T0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003o
ool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0
oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?oo
o`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0
oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K
0?ooo`030000003oool0oooo01L0oooo003B0?ooo`@000002`3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo01T0oooo0`00000I0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?oo
o`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0
oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0
oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo
0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0
Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool4000000/0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0I0?ooo`<000006@3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?oo
o`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool0
5`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool0
0=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo
00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3o
ool05`3oool00980oooo00<0okmd000000000000200000000`0007@0_ooo0?ooo`020?ooo`030?oo
g`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018
W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo002B0?ooo`030?oo_`1d0000000000P0000000H0001d0;ooo`3oool0oooo
0?oOW0180005000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0
W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00T`3oool00`2oM000000000000007000000050000M02oool0oooo0?oo_`1d
00001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo
_`1d0007000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009<0oooo00D0
omnL04P000000000000004RLg`080?ooo`070?noM000000000000000B02Lgol0oooo0?noM0030000
000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?oo
o`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00U03oool01@3o_g@00000000000000000M;oo00L0oooo00@0_g@000000000
000007Bo0`3oool0102oM000000000000018W=l20?ooo`040;md000000000000001d_`<0oooo00@0
_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?ooo`040;md00000000000004RL
g`d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool009D0oooo00D0gia80000000000000000001d_`050?oo
o`050?oog`2LB00000000000001d_ol00`3oool01`3OW4P0000000000000B9`0gooo0?oog`2LB000
0P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d
_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3oool500000?l0Ogmoo`1oOgm/
07moO`D000006@3oool009H0oooo00H0okmd00000000000000000018W03Oool30?ooo`050?oo_`1d
000000000000001d_ol00`3oool01`3o_g@0000000000000B9`0gooo0?oo_`1d00000P0000001@1d
_ol0oooo0?ooo`3oool0okmd0080000000@004RL0=ooo`3ookl0M0000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000<004RL0=ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00U`3o
ool01P3o_g@0000000000000000004RL0=ooo`80oooo00D0oono07@000000000000007Boo`030?oo
o`070?noM000000000000000M02oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
07@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002H0?ooo`050?noM000000000000000
0000M;l00P3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;oo
o`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@0
0080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool009T0oooo00P0okmd000000000000000007Boo`3oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0P0?ooo`80I/aVK@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
002J0?ooo`070;md000000000000001d_`3oool0oono07@000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0
gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool206K<IP03
0?ooo`1Vc6H0oooo06T0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
TP3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ooml0
W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a800800000
00D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?oo
o`3oool0oooo0=nLB002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0Q0?ooo`D0I/aVJ@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo002B0?ooo`050?oog`2LB000000000000018W=l00`3oool01`3o_g@0000000000000
07@0_ooo0?ooo`2oM0000P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@007Bo0?ooo`3o
ool0_g@00P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@007Bo0?ooo`3oool0_g@00P00
00001@00M;l0oooo0?ooo`3oool0_g@00080000000<007Bo0?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo1P1Vc6IX0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo
00<000000?ooo`3oool05`3oool009<0oooo00P0_g@0000000000000001809cOo`3oool0oono07@0
0080000000@004RL0=ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3o
ool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@20000
00040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0240oooo1P1Vc6IX0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool009<0oooo00<0omnL04P0000000001`0000001@18W=l0oooo0?ooo`3ookl0
M00000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3o
okl0M0001`0000000`00B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool08@3oool406K<IP030?ooo`1Vc6H0I/aV06L0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00U03oool00`3OW4P000000000000500000003001d_`3oool0oooo0080
oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0
000000<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`@0I/aV00@0oooo06K<IP1V
c6H0I/aVIP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002E0?ooo`03
0?oo_`1d0000000000<0000000<0M;oo0?ooo`3oool0103oool00`3ooml0W4P00000000200000003
0018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`03
0?oog`2LB00000000080000000<004RL0=ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo0240oooo101Vc6H20?ooo`<0I/aVI@3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
8@3oool406K<IP<0oooo1`1Vc6IP0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool0
5`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0I/aV103o
ool<06K<IUX0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`1Vc6H:0?ooo``0I/aVE03oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool08P3oool306K<IQ00oooo301Vc6I>0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0R0?ooo`<0I/aV5P3ooolE06K<ISl0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo
0`1Vc6HL0?oooaD0I/aV>@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool306K<IR40oooo101V
c6H60?ooo`d0I/aV<P3oool00`1oOgl0oooo0?ooo`020?ooo`0306K<IP3oool0oooo08T0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<0
00000?ooo`3oool05`3oool00=80oooo1000000;0?ooo`0307moO`3oool0oooo0200oooo0P1VI_l3
06K<IR40oooo101Vc6H<0?ooo`d0I/aV;03oool0101oOgl0oooo0?ooo`3oool406K<IXT0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01T0oooo0`00
000I0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo00<0IVKo
06K<IP1Vc6H08P3oool406K<IQ<0oooo3P1Vc6HT0?ooo`0407moO`3oool0oooo0?ooo`H0I/aVQ`3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo0240oooo0P1VI_lS0?ooo`@0I/aV6@3oool?06K<IQd0oooo00@0Ogmo0?ooo`1Vc6H0oooo0P1V
c6H00`3oool0I/aV06K<IP0406K<IX@0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80IVKo8`3oool406K<IR40oooo3P1Vc6H@
0?ooo`T0I/aV00<0oooo06K<IP1Vc6H00`3oool606K<IX80oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool0
0=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80IVKo903oool306K<
IRP0oooo8`1Vc6H60?ooo``0I/aVN@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_lT0?ooo`<0I/aV;`3oool@06K<IPH0
oooo00<0Ogmo0?ooo`1Vc6H00`1Vc6H80?oooa@0I/aVK`3oool00`1oOgl0oooo0?ooo`060?ooo`03
06K<IP3oool0oooo08D0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
8@3oool206IVob@0oooo0`1Vc6I50?ooo`0307moO`3oool0I/aV0080I/aV4`3ooolC06K<IVH0oooo
00<0Ogmo0?ooo`3oool01@3oool406K<IXD0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool08@3oool206IVob@0oooo0`1Vc6I50?ooo`0307moO`3oool0I/aV0080I/aV7@3o
oolH06K<IUL0oooo00<0Ogmo0?ooo`3oool00`3oool00`1Vc6H0oooo06K<IP0506K<IX<0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool206IVob@0oooo0`1Vc6I5
0?ooo`0307moO`3oool0I/aV0080I/aV9P3ooolM06K<ITT0oooo1`1Vc6H0103oool0I/aV06K<IP3o
ool506K<IX40oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`090?ooo`0306K<IP3o
ool0oooo0080I/aV3@3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo0240oooo0P1VI_lT0?ooo`<0I/aVA@3oool00`1oOgl0oooo06K<IP02
06K<ISD0oooo:`1Vc6HU0?oooa40I/aV0`3oool<06K<IWP0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`040?ooo`T0I/aV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_lT0?ooo`80I/aVAP3oool00`1o
Ogl0oooo06K<IP0206K<IT<0ooooB@1Vc6H00`1oOgl0oooo0?ooo`030?ooo`@0I/aV1@3ooolD06K<
IVh0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo06K<IP0=06K<IPh0oooo00<000000?oo
o`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80
IVKo9@3oool00`1Vc6H0oooo0?ooo`140?ooo`0307moO`3oool0I/aV0080I/aVH03ooolU06K<IPL0
oooo00<0Ogmo0?ooo`3oool00`3oool306K<IQ00oooo4`1Vc6IU0?ooo`0307moO`3oool0oooo08/0
oooo2`1Vc6H50?ooo`@0I/aV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_lU0?ooo`0306K<IP3oool0oooo04@0oooo
00@0Ogmo0?ooo`1Vc6H0I/aVS@3oool00`1oOgl0oooo0?ooo`030?ooo`<0I/aV6P3ooolV06K<ISX0
oooo>P1Vc6IM0?ooo`/0I/aV2P3oool406K<IPh0oooo00<000000?ooo`3oool05`3oool00=80oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80IVKo9@3oool00`1Vc6H0oooo
0?ooo`140?ooo`0407moO`3oool0oooo06K<IXd0oooo00<0Ogmo0?ooo`3oool00`3oool306K<IR<0
ooool`1Vc6H40?ooo`0307moO`3oool0oooo00T0oooo101Vc6H>0?ooo`030000003oool0oooo01L0
oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool206IVobD0oooo
00<0I/aV0?ooo`3oool0A03oool0101oOgl0oooo0?ooo`1Vc6J=0?ooo`0307moO`3oool0oooo00<0
oooo0`1Vc6I00?ooocX0I/aV3P3oool00`1oOgl0oooo0?ooo`0Y0?oooed0I/aV2@3oool00`1oOgl0
oooo0?ooo`0:0?ooo`<0I/aV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_lU0?ooo`0306K<IP3oool0oooo04@0oooo
00@0Ogmo0?ooo`3oool0I/aVS@3oool00`1oOgl0oooo0?ooo`030?ooo`<0I/aVR03oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00X0oooo0`1Vc6H>0?ooo`030000003oool0oooo01L0
oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool206IVobD0oooo
00<0I/aV0?ooo`3oool0A03oool0101oOgl0oooo0?ooo`1Vc6J=0?ooo`0307moO`3oool0oooo00<0
oooo0P1Vc6J90?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool02P3oool306K<IPh0
oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0Q0?ooo`80IVKoK03oool0101oOgl0oooo0?ooo`1Vc6J=0?ooo`0307moO`3oool0oooo00@0
oooo00<0I/aV0?ooo`3oool0Q`3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00X0
oooo0P1Vc6H?0?ooo`030000003oool0oooo01L0oooo003B0?ooo`@000002`3oool00`1oOgl0oooo
0?ooo`0Q0?ooo`80IVKoK03oool0101oOgl0oooo0?ooo`1Vc6J=0?ooo`0307moO`3oool0oooo00@0
oooo00<0I/aV0?ooo`3oool0Q`3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00/0
oooo00<0I/aV0?ooo`3oool02`3oool3000001T0oooo003B0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool08@3oool206IVof`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`040?ooo`0306K<IP3oool0oooo08L0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0;0?ooo`0306K<IP3oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00=80oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80IVKoK03oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo00@0oooo00<0I/aV0?ooo`3oool0Q`3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo00/0oooo00<0I/aV0?ooo`3oool03@3oool00`000000oooo0?oo
o`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_m/
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo00/0oooo00<0I/aV0?ooo`3oool03@3oool00`000000oooo0?ooo`0G
0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_m/0?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80IVKoK03oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
8@3oool206IVof`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3o
ool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P1VI_m/0?ooo`0307moO`3o
ool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0Q0?ooo`80IVKoK03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool206IV
of/0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P1VI_m[0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0
oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0R0?ooo`80IVKoJ`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool00`3oIVH0IVKo06IV
o`1[0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`030?mVIP1VI_l0IVKo06/0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo0240oooo00@0ofIV06IVo`1VI_l0IVKoJP3oool00`1oOgl0oooo0?ooo`2>
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K
0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?oo
o`3oool08@3oool0103oIVH0IVKo06IVo`1VI_mZ0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?oo
o`030?mVIP1VI_l0IVKo0080IVKoJ@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool00`3oIVH0
IVKo06IVo`0206IVofT0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo00<0ofIV06IVo`1VI_l0
0`1VI_mX0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo1000
000;0?ooo`0307moO`3oool0oooo0240oooo00H0ofIV06IVo`1VI_l0IVKo0?ooo`1VI_mX0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01T0oooo0`00000I0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo0240oooo00D0ofIV06IVo`1VI_l0IVKo0?ooo`0206IVofL0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo0240oooo00@0ofIV06IVo`1VI_l0IVKo0P3oool00`1VI_l0oooo0?ooo`1U0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0Q0?ooo`040?mVIP1VI_l0IVKo06IVo`80oooo0P1VI_mV0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`0Q0?ooo`040?mVIP1VI_l0IVKo06IVo`<0oooo00<0IVKo0?ooo`3o
ool0I03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l30?ooo`80
IVKoI@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l40?ooo`80
IVKoI03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l40?ooo`@0
IVKoHP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l50?ooo`@0
IVKoH@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l70?ooo`<0
IVKoH03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l80?ooo`<0
IVKoG`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l90?ooo`@0
IVKoG@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l:0?ooo`@0
IVKoG03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool0103oIVH0IVKo06IVo`1VI_l<0?ooo`<0
IVKoF`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002H0?ooo`050?oo
g`2LB000000000000018W=l01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0
oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080
000000<004RL0=ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240
oooo00@0ofIV06IVo`1VI_l0IVKo3@3oool306IVoeX0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00V03oool01@3ooml0W4P0000000000000B9cO00@0oooo00<0omnL04P0
00000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cO
o`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`040?mVIP1VI_l0IVKo06IVo`h0oooo101VI_mH
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009P0oooo00D0oooO09a8
00000000000004RLg`030?ooo`030?oo_`1d0000000000H0000000H004RL0=ooo`3oool0oooo0?oo
_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00B9`0gooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool00`3oIVH0IVKo06IVo`0@0?oo
o`@0IVKoE`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`03
0=nLB0000000000000T0000000<0B9cO0?ooo`3o_g@00P000000100004P0W=oo0?ooo`3o_g@30000
000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?oo
o`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P3oIVHC0?ooo`<0IVKoEP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0
oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`030=nLB0000000000000T00000
00<0B9cO0?ooo`2oM0000P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@0B9cO0?ooo`3o
ool0_g@00P0000001@00M;l0oooo0?ooo`3oool0_g@00080000000@0B9cO0?ooo`3oool0_g@00P00
00001@00M;l0oooo0?ooo`3oool0_g@00080000000<0B9cO0?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo0240oooo0P3oIVHD0?ooo`<0IVKoE@3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`030=nLB0000000000000T0000000<0
B9cO0?oog`2LB0000P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0
W4P00P0000001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P000000
1@1d_ol0oooo0?ooo`3oool0gia80080000000<004RL0=ooo`3oool02`3oool5000002h0Ogmo0P3o
IVHE07moO`@0IVKoo`1oOgoo07moOb<0Ogmo1@00000I0?ooo`00TP3oool0103ogi`0B00000000000
M;l20?ooo`050?oog`2LB000000000000018W=l00P3oool01@3ookl0M000000000000000M;oo00<0
oooo00L0okmd00000000000004RL0=ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?no
M002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM00200000003
0018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80
ofIV5P3oool406IVoe80oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
T`3oool01`3OW4P000000000001d_ol0oooo0?oog`2LB0000P0000001@18W=l0oooo0?ooo`3ookl0
M0000080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@000800000
00D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0Q0?ooo`80ofIV603oool306IVoe40oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`00T`3oool01`3ookl0M0000000000007@0_ooo0?oog`2LB0000P00
00001@18W=l0oooo0?ooo`3ookl0M0000080000000D0M;oo0?ooo`3oool0oooo0?noM00200000004
0000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0
oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM002000000030000M02oool0oooo00/0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80ofIV6@3oool306IVoe00oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00U03oool01P3o_g@000000000
0000M;l0oooO09a80080000000D0B9cO0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo
0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@0
0P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00
07@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool20?mV
IPH0oooo00<0ofIV0?ooo`3oool04@3oool406IVodh0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00U@3oool01@2oM00000000000001d_ml0W4P00080000000D0B9cO0?oo
o`3oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000
000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool08@3oool20?mVIPH0oooo00<0ofIV0?ooo`3oool04P3oool4
06IVodd0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00U@3oool01@3o
okl0M00000000000B7@0M4P00080000000D0B9cO0?ooo`3oool0oooO09a800020000000507Boo`3o
ool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?oo
o`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P00
00000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08@3o
ool20?mVIPH0oooo00<0ofIV0?ooo`3oool0503oool306IVo`80oooo0`1VI_l00`3oool0IVKo0?oo
o`140?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009H0oooo00<0okmd
0000000000000`0000001@18W=l0oooo0?ooo`3oool0_g@00080000000D007Bo0?ooo`3oool0oooo
0;md000200000004001d_`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md00020000
0004001d_`3oool0oooo0;md0080000000D007Bo0?ooo`3oool0oooo0;md000200000003001d_`3o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0Q0?ooo`80ofIV1@3o
ool30?mVIQH0oooo0`1VI_l00`3oool0IVKo06IVo`0506IVod<0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00U`3oool00`2oM0000000000000020000000504RLg`3oool0
oooo0?ooo`3o_g@00P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080
000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0
oooo0?noM0<0000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo0280oooo0P3oIVH40?ooo`<0ofIV5`3oool<06IVod40oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00U`3oool00`3ookl0M000000000020000000604RLg`3oool0
oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=oo
o`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`0R0?ooo`80ofIV103oool30?mVIQP0oooo1`1VI_l00`3oool0IVKo06IV
o`0306IVocl0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00V03oool0
1@3o_g@00000000000000000B9cO00@0oooo00<0omnL04P000000000100000000`0004P0W=oo0?oo
o`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B0000000
0004000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0R0?ooo`80ofIV103oool40?mVIQT0oooo1@1VI_l30?ooo`@0IVKo?P3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo002I0?ooo`040;md00000000000004RLg`D0oooo00<0
oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<0
04RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`80ofIV0`3oool50?mVIQX0oooo101V
I_l50?ooo`@0IVKo?03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool20?mVIP<0oooo0P3oIVH0
0`3oool0ofIV0?mVIP0J0?ooo`@0IVKo1P3oool506IVocX0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
0280oooo0P3oIVH30?ooo`80ofIV00@0oooo0?mVIP3oIVH0ofIV6@3oool406IVo`P0oooo1@1VI_lh
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`80ofIV0`3oool20?mVIP80oooo0P3oIVHI0?oo
o`@0IVKo2P3oool506IVocH0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P3oIVH20?ooo`<0
ofIV0P3oool30?mVIQP0oooo101VI_l<0?ooo`D0IVKo=03oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
8P3oool20?mVIP80oooo0P3oIVH40?ooo`80ofIV6@3oool306IVo`h0oooo1@1VI_lb0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`0R0?ooo`80ofIV0P3oool20?mVIP@0oooo0P3oIVHI0?ooo`<0IVKo403o
ool406IVoc40oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool4
000000/0oooo00<0Ogmo0?ooo`3oool08P3oool20?mVIP80oooo0P3oIVH40?ooo`<0ofIV603oool3
06IVoa80oooo101VI_l_0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01T0oooo0`00000I0?ooo`00dP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P3oIVH0103oool0ofIV0?mVIP3oIVH5
0?ooo`80ofIV603oool306IVoa<0oooo1@1VI_l]0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?oo
o`80ofIV00<0oooo0?mVIP3oIVH01P3oool20?mVIQP0oooo0`1VI_lE0?ooo`D0IVKo:`3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool08P3oool20?mVIP030?ooo`3oIVH0ofIV00H0oooo0`3oIVHG0?ooo`<0
IVKo5`3oool606IVobP0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P3oIVH00`3oool0ofIV
0?mVIP070?ooo`80ofIV5`3oool306IVoaT0oooo1P1VI_lV0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo
00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0R0?ooo`D0ofIV1`3oool20?mVIQL0oooo0`1VI_lL0?ooo`H0IVKo8`3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool08P3oool40?mVIPP0oooo0`3oIVHF0?ooo`<0IVKo7P3oool706IVob00oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo0280oooo103oIVH90?ooo`80ofIV5P3oool306IVob40oooo1P1VI_lN0?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`@0ofIV2@3oool20?mVIQH0oooo0P1VI_lU0?ooo`H0
IVKo6`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool40?mVIPT0oooo0`3oIVHn0?ooo`H0IVKo
6@3oool00`1oOgl0oooo06IVo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool30?mVIP/0oooo0P3oIVI10?ooo`H0IVKo503o
ool506IVohh0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool0
0`1oOgl0oooo0?ooo`0R0?ooo`<0ofIV2`3oool20?mVIT<0oooo1`1VI_l=0?oooaP0IVKoO`3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`00603oool01@3ogi`0B0000000000004P0W=oo0080oooo00D0okmd
000000000000000007Boo`020?ooo`050?oOW018000000000000B02Lgol00P3oool01@3ookl0M000
000000000000M;oo00X0oooo00<0oono07@0000000002P0000000`1d_ol0oooo0?ooo`030?ooo`03
0?oOW0180000000000<0000000<0001809cOo`3oool01@3oool01@3o_g@000000000000007@0_ooo
00h0oooo00<0okmd000000000000100000000`1d_ol0oooo0?ooo`1H0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool08P3oool30?mVIP/0oooo0`3oIVI50?ooo`H0IVKo1`3oool806IV
o`80oooo00<0Ogmo0?ooo`1VI_l04P1VI_ml0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo000H0?ooo`05
0?oOW018000000000000B02Lgol00P3oool01@2oM0000000000000000000B9cO0080oooo00D0omnL
04P000000000001809cOo`020?ooo`050?oo_`1d000000000000001d_ol02P3oool00`3ookl0M000
0000000:0000000607Boo`3oool0oooo0?ooo`3ookl0M000200000000`0007@0_ooo0?ooo`030?oo
o`050?noM000000000000000M02oool0303oool00`3ookl0M00000000007000000030000B02Lgol0
oooo05L0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0ofIV303oool2
0?mVITP0oooo3P1VI_l60?ooo`0307moO`3oool0IVKo00<0IVKo303oool606IVogT0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool001P0oooo00P0omnL04P000000000000007Boo`3oool0oooO09a800<00000
00@004RL0=ooo`3oool0okmd0P0000001P0004P0W=oo0?ooo`3oool0oono07@00080000000<0M;oo
0?ooo`3oool0203oool00`3ookl0M0000000000:0000000507Boo`3oool0oooo0?oOW01800002P00
00000`0004P0W=oo0?ooo`020?ooo`050?noM000000000000000M02oool02`3oool00`3ooml0W4P0
00000009000000030000M02oool0oooo05H0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0R0?ooo`<0ofIV303oool30?mVITT0oooo201VI_l:0?ooo`0307moO`3oool0IVKo00<0IVKo
3`3oool606IVogH0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool001P0oooo00P0omnL04P0000000000000
07Boo`3oool0oono07@000<0000000@0001d0;ooo`3oool0okmd0P0000001P0004P0W=oo0?ooo`3o
ool0oono07@00080000000<0M;oo0?ooo`3oool0203oool01@3ookl0M000000000000000M;oo00X0
oooo00<0oooO09a8000000000P0000001P0007@0_ooo0?ooo`3oool0oooO09a800<0000000D004RL
0=ooo`3oool0oooo0?noM002000000030000M02oool0oooo00X0oooo00H0gia80000000000000000
0018W03Oool30?ooo`050;md00000000000000000018W=l0E`3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo0280oooo0`3oIVH=0?ooo`80ofIVF`3oool00`1oOgl0oooo06IVo`0306IV
oa80oooo1`1VI_mb0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo000H0?ooo`0?0?oOW018000000000000
001d_ol0oooo0?oOW0180000000007AdM0000000001809cOo`3oool0okmd0080000000H0001809cO
o`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono07@0000000000000
07Boo`0:0?ooo`050?noM0000000000000000000M;l01P3oool01@2oM0000000000000000000M;oo
0080oooo00D0okmd000000000000001d0;ooo`0:0?ooo`060?oog`2LB000000000000000B9`0gooo
1@3oool01@2oM000000000000000B9`0gooo05H0oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0R0?ooo`<0ofIV3@3oool20?mVIU/0oooo00<0Ogmo0?ooo`1VI_l00`1VI_lE0?ooo`L0
IVKoK`3oool00`1oOgl0oooo0?ooo`060?ooo`0306IVo`3oool0oooo08D0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo000H0?ooo`0?0?oO
W018000000000000001d_ol0oooo0=nLB0000000001809cO_`1d0000000004RLg`3oool0okmd0080
000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0oooo00D0oono
07@000000000000007Boo`0:0?ooo`050;md0000000000000000M02oool01P3oool01@3ookl0M000
00000000000007Bo0080oooo00D0okmd000000000000001d0;ooo`0:0?ooo`050?oo_`1d00000000
0000001d_ol01P3oool01@3OW4P0000000000000B9`0gooo05H0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`0R0?ooo`<0ofIV3@3oool30?mVIUX0oooo00<0Ogmo0?ooo`1VI_l00`1V
I_lI0?ooo`H0IVKoK03oool00`1oOgl0oooo0?ooo`050?ooo`<0IVKoQP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool001P0oooo00l0omnL
04P000000000000007Boo`3oool0_g@000000000B9`0gooO09a80000000007Bo0?ooo`3o_g@00P00
00001P0004P0W=oo0?ooo`3oool0oono07@00080000000<0M;oo0?ooo`3oool0203oool01@3ookl0
M000000000000000M;oo00T0oooo00D0oooO09a8000000000000001d_`080?ooo`070;md00000000
00000018W03Oool0oooo0?noM009000000030018W03Oool0oooo00`0oooo00D0okmd000000000000
0000001d_`1G0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool08P3oool30?mVIPh0
oooo0P3oIVIJ0?ooo`0307moO`3oool0IVKo00<0IVKo703oool606IVofT0oooo00<0Ogmo0?ooo`3o
ool01@3oool406IVohD0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo000H0?ooo`0?0?oOW0180000000000000018W=l0oooO09a800000000
07Bo0?ooo`2oM00000000018W03Oool0gia80080000000H0001809cOo`3oool0oooo0?oo_`1d0009
000000060018W03Oool0oooo0?ooo`3ookl0M0000P0000000`1d_ol0oooo0?ooo`070?ooo`050?oo
_`1d0000000000000018W=l0203oool01`3OW4P000000000000007@0_ooo0?ooo`3o_g@02`000000
0`1d_ol0oooo0?ooo`070?ooo`030;md00000000000000@0000000<0M;oo0?ooo`3oool0E@3oool4
000000/0oooo00<0Ogmo0?ooo`3oool08P3oool30?mVIPh0oooo0P3oIVIJ0?ooo`0307moO`3oool0
IVKo00<0IVKo7`3oool606IVofH0oooo00<0Ogmo0?ooo`3oool01@3oool506IVoh@0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0I0?ooo`<000006@3oool001P0oooo00l0omnL04P0
00000000000004RLg`3ookl0M0000000001d_ol0oooo0?noM0000000001d0;ooo`3OW4P00P000000
1P0004P0W=oo0?ooo`3oool0oono07@000T0000000H004RL0=ooo`3oool0oooo0?oo_`1d00020000
000307Boo`3oool0oooo00L0oooo00D0oono07@000000000000004RLg`080?ooo`070=nLB0000000
00000000M02oool0oooo0?noM00;000000030000B02Lgol0oooo00<0oooo00<0oooO09a800000000
1`0000000`18W=l0oooo0?ooo`1F0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
8P3oool30?mVIPh0oooo0`3oIVII0?ooo`0307moO`3oool0IVKo00<0IVKo8P3oool706IVof80oooo
00<0Ogmo0?ooo`3oool01@3oool206IVo`030?ooo`1VI_l0IVKo08@0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo000H0?ooo`0?0?oOW018
0000000000000018W=l0okmd0000000004P0W=oo0?ooo`3ogi`0B0000000001d_ol0gia800800000
00H0001809cOo`3oool0oooo0?oo_`1d0009000000060018W03Oool0oooo0?ooo`3ookl0M0000P00
00000`1d_ol0oooo0?ooo`070?ooo`050?oo_`1d0000000000000018W=l0203oool01`3OW4P00000
0000000007@0_ooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`030?ooo`050;md000000000000
00000000M;l00`3oool00`3o_g@0000000000006000000030000B02Lgol0oooo05P0oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0R0?ooo`<0ofIV3`3oool20?mVIUT0oooo00<0Ogmo
0?ooo`1VI_l00P1VI_lV0?ooo`P0IVKoGP3oool00`1oOgl0oooo0?ooo`050?ooo`80IVKo0P3oool2
06IVoh<0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo000H0?ooo`0?0?oOW0180000000000000018W=l0gia800000000B9`0gooo0?ooo`3o
oml0W4P000000018W=l0gia80080000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Bo
o`3oool0oooo00P0oooo00D0oono07@000000000000007Boo`090?ooo`050?oog`2LB00000000000
0000M;l0203oool01`2oM000000000000000B9`0gooo0?ooo`3o_g@00P0000000`0007@0_ooo0?oo
o`030?ooo`090?oog`2LB000000000000000B9`0gooo0?ooo`3ookl0M00000D0000000<0001809cO
o`3oool0F`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0`3oIVH?0?oo
o`80ofIVF@3oool00`1oOgl0oooo06IVo`0206IVobX0oooo1`1VI_mK0?ooo`0307moO`3oool0oooo
00D0oooo0P1VI_l20?ooo`<0IVKoPP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool001P0oooo00P0omnL04P000000000000004RLg`2oM000
0000001d_`<0oooo00@0_g@000000000M;l0gia80P0000001P0004P0W=oo0?ooo`3oool0oono07@0
0080000000<0M;oo0?ooo`3oool0203oool01@3ookl0M000000000000000M;oo00X0oooo00D0_g@0
000000000000001d0;ooo`060?ooo`050?oo_`1d0000000000000000M;l00P3oool01@3o_g@00000
0000000007@0_ooo00D0oooo00L0_g@0000000000000001d0;ooo`3oool0okmd00<0000000<007Bo
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0280oooo0P3oIVH@
0?ooo`<0ofIVF03oool00`1oOgl0oooo06IVo`0206IVobh0oooo1`1VI_mG0?ooo`0307moO`3oool0
oooo00D0oooo0P1VI_l30?ooo`<0IVKoP@3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0
oooo01/0oooo00<000000?ooo`3oool05`3oool001P0oooo00P0omnL04P0000000000000001dM01d
0000000007Boo`<0oooo00@0okmd0000000007@0M7@00P0000001P0004P0W=oo0?ooo`3oool0oono
07@00080000000<0M;oo0?ooo`3oool0203oool01@3ookl0M000000000000000M;oo00X0oooo00D0
okmd0000000000000000001d_`060?ooo`050;md0000000000000000001d_ol00P3oool01@3o_g@0
00000000000007@0_ooo00@0oooo00P0oooO09a80000000000000018W03Oool0oooo0=nLB0800000
00<004RL0=ooo`3oool00`3oool01@3o_g@000000000000004P0W=oo05L0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`0e0?ooo`80ofIVF03oool00`1oOgl0oooo06IVo`0206IVoc40
oooo201VI_mC0?ooo`0307moO`3oool0oooo00D0oooo0P1VI_l40?ooo`D0IVKoOP3oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00`0oooo0P1VI_l=0?ooo`030000003oool0oooo01L0
oooo000H0?ooo`080?oOW0180000000000000000B4P0B0000000B02Lgol30?ooo`040?oOW0180000
001804Q80080000000H0001809cOo`3oool0oooo0?oo_`1d00020000000307Boo`3oool0oooo00P0
oooo00D0oono07@000000000000007Boo`0:0?ooo`030?oog`2LB00000000080000000H004RL0=oo
o`3oool0oooo0?oog`2LB003000000050018W03Oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo
0?ooo`030?ooo`050;md00000000000000000000M;l00P3oool01@3o_g@00000000000000000M;oo
00<0oooo00H0oono07@00000000000000000M02ooomG0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0=@3oool20?mVIUP0oooo00<0Ogmo0?ooo`1VI_l00P1VI_le0?ooo`L0IVKoD03o
ool00`1oOgl0oooo0?ooo`030?ooo`0406IVo`3oool0IVKo06IVo`D0oooo201VI_mj0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool02`3oool206IVo`h0oooo00<000000?ooo`3oool0
5`3oool001P0oooo00<0omnL04P0000000000`0000000`00B9`0gooo0?ooo`020?ooo`030?oog`2L
B000000000<0000000H0001809cOo`3oool0oooo0?oo_`1d000:000000050018W03Oool0oooo0?oo
_`1d00000P0000000`1d_ol0oooo0?ooo`090?ooo`030?oOW0180000000000T0000000<0001809cO
o`3oool00P3oool00`3o_g@000000000000:0000000507Boo`3oool0oooo0?oo_`1d00002P000000
0`18W=l0oooo0?ooo`1F0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=@3oool3
0?mVIUL0oooo00<0Ogmo0?ooo`1VI_l00P1VI_li0?ooo`L0IVKoC03oool706IVo`030?ooo`1VI_l0
IVKo00T0oooo1`1VI_mg0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool02`3oool2
06IVo`h0oooo00<000000?ooo`3oool05`3oool001P0oooo00<0omnL04P0000000000`0000000`00
M;l0oooo0?ooo`030?ooo`030;md0000000000000080000000H0001809cOo`3oool0oooo0?oo_`1d
000:000000050018W03Oool0oooo0?oo_`1d00000P0000000`1d_ol0oooo0?ooo`0:0?ooo`030?oo
_`1d0000000000L0000000<0001d0;ooo`3oool00`3oool00`3o_g@00000000000090000000304RL
g`3oool0oooo0080oooo00<0omnL04P0000000001`0000000`00M;l0oooo0?ooo`1G0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=P3oool20?mVIUL0oooo00<0Ogmo0?ooo`1VI_l0
0P1VI_ll0?ooo`L0IVKo@P3ooolA06IVo`d0oooo1`1VI_mc0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool02`3oool206IVo`h0oooo00<000000?ooo`3oool05`3oool001P0oooo00<0
omnL04P0000000000`0000000`1d_ol0oooo0?ooo`030?ooo`030?noM000000000000080000000H0
001809cOo`3oool0oooo0?oo_`1d000:000000050018W03Oool0oooo0?oo_`1d00000P0000000`1d
_ol0oooo0?ooo`0<0?ooo`030?oOW0180000000000<0000000<0001809cOo`3oool01@3oool00`3o
_g@0000000000007000000030000B02Lgol0oooo00H0oooo00<0gia80000000000000`0000000`00
07@0_ooo0?ooo`1I0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0=P3oool20?mV
IUL0oooo00<0Ogmo0?ooo`1VI_l00P1VI_m00?ooob00IVKo7P3oool>06IVo`0307moO`3oool0oooo
00<0oooo0`1VI_lA0?ooo`P0IVKoK`3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
00T0oooo00@0IVKo0?ooo`1VI_l0IVKo3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03H0oooo0`3oIVIF0?ooo`0307moO`3oool0IVKo
0080IVKo@`3ooom206IVo`L0oooo00<0Ogmo0?ooo`3oool00`3oool306IVoaD0oooo1`1VI_m/0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool01`3oool306IVo`030?ooo`1VI_l0IVKo
00h0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`0g0?ooo`80ofIVEP3oool0101oOgl0oooo06IVo`1VI_mQ0?oooah0IVKo3P3oool00`1o
Ogl0oooo0?ooo`030?ooo`<0IVKo6@3oool706IVofP0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`040?ooo`T0IVKo3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000
oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03L0oooo0`3oIVIE0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool00`3oool306IVoa`0oooo1`1VI_mU0?ooo`0307moO`3oool0oooo08l0
oooo00<0Ogmo0?ooo`3oool00P3oool606IVo`030?ooo`1VI_l0IVKo0080IVKo3P3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo03P0oooo
0P3oIVIE0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool00`3oool306IVob00oooo
801VI_m80?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool01@1VI_l40?ooo`@0IVKo
3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo03P0oooo0P3oIVH?0?ooo`030?mVIP3oool0oooo04<0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`030?ooo`<0IVKo8`3ooolj06IVob/0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0IVKo06IVo`0306IVo`H0oooo101VI_l>0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>03oool30?mVIPh0oooo00<0ofIV
0?ooo`3oool0@`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo00<0oooo0`1VI_m0
0?ooocX0IVKo3P3oool00`1oOgl0oooo0?ooo`2=0?ooo`H0IVKo203oool406IVo`h0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0i0?oo
o`80ofIV3P3oool00`3oIVH0oooo0?ooo`130?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool00`3oool306IVoed0oooo>P1VI_mo0?ooo`H0IVKo2P3oool406IVo`h0oooo00<000000?oo
o`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0i0?ooo`80
ofIV3@3oool30?mVIT@0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`030?ooo`<0
IVKoNP3ooolj06IVof00oooo1@1VI_l00`3oool0Ogmo0?ooo`0:0?ooo`@0IVKo3P3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool4000000/0oooo00<0Ogmo0?ooo`3oool0>@3oool30?mVIP`0oooo
0`3oIVI40?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool00`3oool306IVohP0oooo
00<0Ogmo0?ooo`3oool0303oool/06IVodl0oooo1@1VI_l30?ooo`0307moO`3oool0oooo00X0oooo
0`1VI_l<0?ooo`<000006@3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?oo
o`0j0?ooo`80ofIV303oool30?mVIT@0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`030?ooo`<0IVKoR03oool00`1oOgl0oooo0?ooo`0Y0?oood@0IVKo5`3oool606IVo`D0oooo00<0
Ogmo0?ooo`3oool02P3oool306IVo`h0oooo00<000000?ooo`3oool05`3oool00=80oooo00<00000
0?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0j0?ooo`80ofIV303oool40?mVIT<0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`030?ooo`80IVKoR@3oool00`1oOgl0oooo0?ooo`0h
0?ooocl0IVKo2`3oool606IVo`L0oooo00<0Ogmo0?ooo`3oool02P3oool306IVo`h0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0j0?oo
o`<0ofIV2`3oool40?mVIT<0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo06d0oooo601VI_l:0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l>0?oo
o`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0>`3oool20?mVIP/0oooo103oIVI30?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`1g0?ooo``0IVKo303oool00`1oOgl0oooo0?ooo`0:0?ooo`<0
IVKo3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo03/0oooo0P3oIVH;0?ooo`D0ofIV@P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0P03oool00`1VI_l0oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo00X0oooo0`1VI_l>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0>`3oool30?mVIPX0oooo0P3oIVH00`3oool0ofIV0?mV
IP120?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo00X0oooo0`1VI_l>0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?03oool20?mVIPX0oooo0P3oIVH0
103oool0ofIV0?mVIP3oIVI10?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00X0oooo0P1VI_l?0?ooo`030000003o
ool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?03oool2
0?mVIPX0oooo0P3oIVH20?ooo`80ofIV@@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?03oool30?mV
IPT0oooo0P3oIVH20?ooo`80ofIV@@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?@3oool20?mVIPT0
oooo0P3oIVH20?ooo`<0ofIV@03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0
oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?@3oool30?mVIPP0oooo
0P3oIVH30?ooo`80ofIV@03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?P3oool20?mVIPP0oooo0P3o
IVH30?ooo`80ofIV@03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?P3oool20?mVIPP0oooo0P3oIVH3
0?ooo`<0ofIV?`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002F0?oo
o`060=nLB000000000000000000004P0W=oo1P3oool00`3ooml0W4P000000002000000030018W03O
ool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2L
B00000000080000000<004RL0=ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo03h0oooo0`3oIVH70?ooo`80ofIV103oool20?mVISl0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00U03oool00`3ookl0M0000000000500000003001d_`3oool0
oooo0080oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000
000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0
oooo00d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`0o0?ooo`80ofIV1`3oool2
0?mVIP@0oooo0P3oIVHo0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool0
09<0oooo00<0oooO09a8000000001`0000001@18W=l0oooo0?ooo`3ookl0M00000L0000000H004RL
0=ooo`3oool0oooo0?oo_`1d0007000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000000`00
B9`0gooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0?`3oool20?mV
IPL0oooo0P3oIVH40?ooo`<0ofIV?P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo002C0?ooo`080?noM0000000000000000018W=l0oooo0?oog`2LB002000000040018W03O
ool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@20000
00040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?oo
o`3o_g@30000000307Boo`3oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`0o0?ooo`<0ofIV1P3oool20?mVIPD0oooo0P3oIVHn0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo
00<000000?ooo`3oool05`3oool009<0oooo00D0_g@000000000000004RL0=ooo`020?ooo`070?oO
W018000000000000B02Lgol0oooo0;md000200000005001d_`3oool0oooo0?ooo`2oM0000P000000
1018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000001018W=l0oooo
0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P0000000`18W=l0oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@03oool20?mVIPH0oooo0P3oIVH50?oo
o`<0ofIV?@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`05
0?oog`2LB000000000000000M;l00`3oool01`3ogi`0B0000000000004P0W=oo0?oog`2LB0000P00
00001@1d_ol0oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0
oooo0?ooo`3oool0gia80080000000@004RL0=ooo`3ooml0W4P00P0000001@1d_ol0oooo0?ooo`3o
ool0gia80080000000<004RL0=ooo`3oool02`3oool5000004d0Ogmo0P3oIVH607moO`80ofIV1P1o
Ogl20?mVI_l0Ogmoo`1oOgl=07moO`D000006@3oool00980oooo00D0oono07@0000000000000001d
_`030?ooo`070?oOW018000000000000B02Lgol0oono07@000020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0
gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@03oool30?mVIPD0
oooo0P3oIVH60?ooo`80ofIV?@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0
oooo002B0?ooo`030?oo_`1d000000000080000000@0M;oo0?ooo`3ooml0W4P00P000000100007@0
_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0@@3oool20?mVIPD0oooo0P3oIVH60?ooo`<0ofIV?03oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`030?oo_`1d0000000000P0
000000@0B9cO0?ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d
0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0
M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0440oooo0P3oIVH50?ooo`80ofIV1`3oool20?mV
IS`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00TP3oool00`3ookl0
M00000000007000000050018W03Oool0oooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0
okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0440oooo0`3oIVH40?oo
o`80ofIV1`3oool20?mVIS`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00TP3oool01P3ookl0M000000000000000M;oo0=nLB0<0000000H0B9cO0?ooo`3oool0oooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000
000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3o
ool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0@P3oool20?mVIP@0oooo0P3oIVH70?ooo`<0ofIV>`3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`050?oog`2LB000000000000018W=l0
203oool01@3ooml0W4P0000000000000M;oo00<0oooo00L0gia800000000000004RL0=ooo`3ooml0
W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a800800000
00D0M;oo0?ooo`3oool0oooo0=nLB002000000030018W03Oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`120?ooo`80ofIV103oool20?mVIPP0oooo0P3oIVHk0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009<0oooo00D0_g@0000000000000
04RL0=ooo`020?ooo`070=nLB000000000000018W03Oool0oooo0;md000200000005001d_`3oool0
oooo0?ooo`2oM0000P0000001000M;l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2o
M0000P0000001000M;l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM0000P000000
0`00M;l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0@P3oool8
0?mVIPP0oooo0P3oIVHk0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool0
09<0oooo00P0okmd000000000000000004RLg`3oool0oono07@00080000000@007Bo0?ooo`3oool0
okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@00018
09cOo`3oool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0
000000<0M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04<0
oooo1`3oIVH80?ooo`<0ofIV>P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0
oooo002D0?ooo`030;md00000000000000D0000000H0001809cOo`3oool0oooo0?oo_`1d00070000
00060018W03Oool0oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0
000000<004RL0=ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04<0
oooo1`3oIVH90?ooo`80ofIV>P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0
oooo002D0?ooo`030?oog`2LB000000000D0000000<0B9cO0?ooo`3oool00P3oool00`3ogi`0B000
00000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P000000000100000000`0004P0W=oo
0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo04@0oooo1P3oIVH90?ooo`<0ofIV>@3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002F0?ooo`030?noM000000000000080000000<0
M;oo0?ooo`3oool0103oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0
oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<0
04RL0=ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04@0oooo1P3o
IVH:0?ooo`80ofIV>@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A03oool60?mVIPX0oooo0P3oIVHi
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`150?ooo`D0ofIV2P3oool30?mVISP0oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?oo
o`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo04D0oooo1@3oIVH;0?ooo`80ofIV>03oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
A@3oool50?mVIP/0oooo0P3oIVHh0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool0
5`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`160?ooo`@0ofIV2`3o
ool30?mVISL0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04H0oooo103oIVH<0?ooo`80ofIV=`3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0AP3oool40?mVIP`0oooo0P3oIVHg0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool00=80oooo1000000;0?ooo`0307moO`3oool0oooo04H0
oooo103oIVH<0?ooo`<0ofIV=P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0I0?ooo`<000006@3oool00=80oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`160?ooo`@0ofIV3@3oool20?mVISH0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo04H0oooo103oIVH=0?ooo`80ofIV=P3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo
0?ooo`3oool0AP3oool40?mVIPd0oooo0`3oIVHe0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<00000
0?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`160?oo
o`@0ofIV3P3oool20?mVISD0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04H0oooo103oIVH>0?ooo`<0
ofIV=03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0AP3oool40?mVIPl0oooo0P3oIVHd0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`160?ooo`@0ofIV3`3oool20?mVIS@0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo04L0oooo0`3oIVH?0?ooo`<0ofIV<`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A`3oool30?mV
IQ00oooo0P3oIVHc0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80
oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`170?ooo`<0ofIV403oool20?mVIS<0
oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0
oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo0`3oIVH@0?ooo`<0ofIV<P3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0A`3oool30?mVIQ40oooo0P3oIVHb0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<0
00000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`17
0?ooo`<0ofIV4@3oool20?mVIS80oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>
0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G
0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo0`3oIVHA0?oo
o`<0ofIV<@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A`3oool30?mVIQ80oooo0P3oIVHa0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`170?ooo`<0ofIV4P3oool30?mVIS00oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo04L0oooo0`3oIVHC0?ooo`80ofIV<03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003o
ool0oooo01L0oooo003B0?ooo`@000002`3oool00`1oOgl0oooo0?ooo`170?ooo`<0ofIV4`3oool2
0?mVIS00oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo08l0oooo00<0Ogmo0?ooo`3oool06@3oool3000001T0oooo003B0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0A`3oool30?mVIQ<0oooo0`3oIVH_0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`170?ooo`<0ofIV503oool20?mVIRl0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo
0`3oIVHD0?ooo`80ofIV;`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo
003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A`3oool30?mVIQ@0oooo0`3o
IVHO0?ooo`030?mVIP3oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?oo
o`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo0`3oIVHE
0?ooo`80ofIV703oool50?mVIPd0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>
0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G
0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo0`3oIVHE0?oo
o`80ofIV6@3oool90?mVIP`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo04L0oooo0`3oIVHE0?ooo`<0
ofIV5@3oool70?mVIP<0oooo0`3oIVH;0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3o
ool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`170?ooo`<0ofIV
5P3oool20?mVIQ80oooo1`3oIVH70?ooo`<0ofIV2P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0A`3o
ool20?mVIQL0oooo0`3oIVH>0?ooo`L0ofIV2`3oool20?mVIPX0oooo00<0Ogmo0?ooo`3oool0SP3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo0640oooo0P3oIVH<0?ooo`H0ofIV3`3oool20?mVIPT0oooo00<0Ogmo0?ooo`3oool0SP3oool0
0`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
0640oooo0P3oIVH90?ooo`H0ofIV4P3oool30?mVIPP0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0640
oooo0`3oIVH50?ooo`L0ofIV5@3oool30?mVIPL0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0680oooo
0P3oIVH20?ooo`L0ofIV6@3oool30?mVIPH0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo
0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo0680oooo203o
IVHM0?ooo`<0ofIV1@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0HP3oool50?mVIR40oooo0`3oIVH4
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`1S0?ooo`030?mVIP3oool0oooo02<0oooo0`3oIVH30?oo
o`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2:0?ooo`<0ofIV0P3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
R`3oool30?mVIP030?ooo`1oOgl0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo1000
000;0?ooo`0307moO`3oool0oooo08`0oooo0P3oIVH00`3oool0Ogmo0?ooo`2?0?ooo`0307moO`3o
ool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0I0?ooo`<000006@3o
ool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2=0?ooo`80ofIV00<0Ogmo
0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo08d0oooo0`3oIVJ@0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?oo
o`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0SP3oool30?mVIXl0oooo00<0Ogmo0?ooo`3o
ool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3o
ool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`<0ofIV
SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?mVIP3oIVH0SP3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0
oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3o
ool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVS@3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00U@3oool00`3ogi`0B00000000002000000030000B02Lgol0
oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB000
00000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018W03Oool0
oooo00h0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0407moO`3oool0
ofIV0?mVIXd0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool009@0oooo00<0_g@00000000000001@000000
0`00M;l0oooo0?ooo`020?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool0
0`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P00000000010000000
0`0004P0W=oo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool0
101oOgl0oooo0?mVIP3oIVJ=0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002C0?ooo`030=nLB0000000
000000L0000000D0B9cO0?ooo`3oool0oono07@00007000000060018W03Oool0oooo0?ooo`3ookl0
M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000<004RL0=ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?ooo`3oIVH0ofIVA03o
ool00`3oIVH0oooo0?ooo`160?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002B0?ooo`090?oo_`1d0000
00000000000007@0_ooo0?ooo`3ookl0M0000080000000@004RL0=ooo`3oool0okmd0P0000001000
04P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd
0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00@0Ogmo0?oo
o`3oIVH0ofIV@`3oool20?mVITP0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00980oooo00D0oono07@0
00000000000007Boo`030?ooo`070?noM000000000000000M02oool0oooo0;md000200000005001d
_`3oool0oooo0?ooo`2oM0000P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo
0?ooo`2oM0000P0000001018W=l0oooo0?ooo`2oM00200000005001d_`3oool0oooo0?ooo`2oM000
0P0000000`18W=l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
S`3oool0101oOgl0oooo0?mVIP3oIVI10?ooo`D0ofIVA`3oool00`1oOgl0oooo0?ooo`2>0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00
TP3oool01@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ooml0
W4P00080000000D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a800800000
00D0M;oo0?ooo`3oool0oooo0=nLB002000000040018W03Oool0oooO09a80080000000D0M;oo0?oo
o`3oool0oooo0=nLB002000000030018W03Oool0oooo00/0oooo1@00002N07moO`80ofIV@01oOgl4
0?mVIP0307moO`3oIVH0Ogmo0?l0OgmoQ01oOgl5000001T0oooo002C0?ooo`080;md000000000000
0018W03Oool0oooo0?oo_`1d000200000004001d_`3oool0oono07@00080000000D0M;oo0?ooo`3o
ool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?no
M002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM00200000003
0018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`04
07moO`3oool0ofIV0?mVISl0oooo0`3oIVH30?ooo`80ofIVAP3oool00`1oOgl0oooo0?ooo`2>0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?oo
o`00T`3oool00`3ookl0M00000000006000000050018W03Oool0oooo0?oo_`1d00000P0000001@1d
_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?oo
o`3oool0okmd0080000000@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd
0080000000<0001d0;ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
08l0oooo00@0Ogmo0?ooo`3oIVH0ofIV?@3oool40?mVIPD0oooo0P3oIVI50?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo002E0?ooo`030?noM0000000000000<0000000H0M;oo0?ooo`3oool0oooo0?oo_`1d
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d000200000005
07Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0
oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0S`3oool0101oOgl0oooo0?mVIP3oIVHl0?ooo`@0ofIV1`3oool00`3oIVH0oooo
0?ooo`130?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002D0?ooo`030=nLB0000000000000D0000000D0
B9cO0?ooo`3oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0
_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d
00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?mVIP0;0?mVIS40oooo
0`3oIVH90?ooo`80ofIVA03oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00T`3oool01`3o_g@000000000
000004P0W=oo0?ooo`3o_g@00P0000001@0004P0W=oo0?ooo`3ookl0M0000080000000D0M;oo0?oo
o`3oool0oooo0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo
0?noM002000000040018W03Oool0oono07@00080000000D0M;oo0?ooo`3oool0oooo0?noM0020000
00030018W03Oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?oo
o`0307moO`3oool0ofIV00h0ofIV;03oool40?mVIP/0oooo00<0ofIV0?ooo`3oool0@P3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00T`3oool0102oM000000000000000M;l30?ooo`070;md000000000000
04RLg`3oool0oooO09a800020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo
0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB002
0000000507Boo`3oool0oooo0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003o
ool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?mVIP030?mVIPP0oooo1@3o
IVHY0?ooo`@0ofIV303oool20?mVIT<0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?oo
o`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009<0oooo00@0_g@0
00000000000007Bo0`3oool0102oM000000000000000M;l20?ooo`040;md000000000000001d_`<0
oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000M;l30?ooo`040;md00000000
0000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102oM000000000000000M;l=0?ooo`03
0000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?mVIP030?mVIPX0
oooo1@3oIVHV0?ooo`<0ofIV3`3oool20?mVIT80oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool009<0oooo
00P0gia8000000000000001809cOo`3oool0omnL04P00080000000@0B9cO0?ooo`3oool0okmd0P00
0000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@0001809cOo`3o
ool0okmd0`000000101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0
M;oo0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0
Ogmo0?ooo`3oIVH00`3oIVH<0?ooo`D0ofIV8P3oool40?mVIQ40oooo00<0ofIV0?ooo`3oool0@03o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00T`3oool00`3ogi`0B00000000006000000060000B02Lgol0
oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=oo
o`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0ofIV0080ofIV3`3oool50?mVIQl0oooo103o
IVHB0?ooo`80ofIV@@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0
Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00U03oool00`3OW4P0000000000005
0000000304RLg`3oool0oooo0080oooo00<0omnL04P000000000100000000`0004P0W=oo0?ooo`03
0?ooo`030?oOW0180000000000@0000000<0001809cOo`3oool00`3oool00`3ogi`0B00000000004
000000030000B02Lgol0oooo00d0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0ofIV0080ofIV4@3oool50?mVIQ`0oooo0`3oIVHE0?ooo`030?mVIP3oool0
oooo03l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0
oooo01/0oooo00<000000?ooo`3oool05`3oool009D0oooo00<0omnL04P0000000000P0000000`00
07@0_ooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3o
oml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00
B9`0gooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?mVIP020?mVIQ<0oooo1@3oIVHI0?ooo`<0ofIV5P3oool20?mVIT00oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?oo
o`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0ofIV0080ofIV5@3oool40?mVIQH0oooo103oIVHH0?ooo`80ofIV?`3oool00`1oOgl0
oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000
oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo
00<0Ogmo0?ooo`3oIVH00P3oIVHG0?ooo`@0ofIV4`3oool40?mVIQX0oooo00<0ofIV0?ooo`3oool0
?@3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo08l0oooo00@0Ogmo0?ooo`3oool0ofIV6@3oool50?mVIQ00oooo0`3oIVHL0?ooo`80ofIV
?P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3o
ool0oooo08l0oooo00@0Ogmo0?ooo`3oool0ofIV6`3oool50?mVIP`0oooo103oIVHN0?ooo`030?mV
IP3oool0oooo03`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0407moO`3oool0oooo0?mVIQd0oooo1@3oIVH90?ooo`@0ofIV
7`3oool20?mVISd0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0407moO`3oool0oooo0?mVIQl0oooo1@3oIVH60?ooo`<0ofIV
8P3oool20?mVIS`0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0407moO`3oool0oooo0?mVIR40oooo1@3oIVH20?ooo`@0ofIV
903oool00`3oIVH0oooo0?ooo`0j0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`@000002`3o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo02@0oooo203oIVHU0?ooo`80ofIV>`3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06@3o
ool3000001T0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`0V0?ooo`@0ofIV:03oool00`3oIVH0oooo0?ooo`0i0?ooo`0307moO`3oool0
oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`0X0?ooo`030?mVIP3oool0oooo02L0oooo0P3oIVHj0?ooo`0307moO`3oool0oooo
08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo
01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0
oooo0?ooo`1C0?ooo`030?mVIP3oool0oooo03P0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00=80oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo05<0oooo
0P3oIVHi0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1D0?ooo`80ofIV>03oool00`1oOgl0oooo0?oo
o`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?oo
o`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool0E@3oool00`3oIVH0oooo0?ooo`0f0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo003B0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1E0?oo
o`80ofIV=`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?oo
o`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0EP3oool00`3oIVH0oooo0?ooo`0e0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K0?ooo`03
0000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0
S`3oool00`1oOgl0oooo0?ooo`1F0?ooo`80ofIV=P3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool02`3oool20?mVIPh0oooo00<000000?ooo`3oool0
5`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo05L0oooo0P3oIVHe0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`0;0?ooo`80ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool0
0`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0F03oool0
0`3oIVH0oooo0?ooo`0c0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool0
0`1oOgl0oooo0?ooo`0;0?ooo`80ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0F03oool20?mV
IS@0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
00/0oooo0P3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0
oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1I0?ooo`030?mVIP3oool0oooo0380
oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00/0
oooo0P3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1I0?ooo`80ofIV<`3oool00`1oOgl0oooo
0?ooo`0<0?ooo`030?mVIP3oool0oooo07l0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`0;0?ooo`80ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?oo
o`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0FP3oool20?mVIS80oooo00<0
Ogmo0?ooo`3oool0303oool20?mVIX00oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?oo
o`0;0?ooo`80ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0F`3oool00`3oIVH0oooo0?ooo`0`
0?ooo`0307moO`3oool0oooo00/0oooo103oIVIo0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo
0?ooo`3oool02`3oool20?mVIPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?oo
o`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo05/0oooo0P3oIVHa0?oo
o`0307moO`3oool0oooo00/0oooo00@0ofIV0?ooo`3oIVH0ofIVO`3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0oooo00/0oooo0P3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?oo
o`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1L0?oo
o`030?mVIP3oool0oooo02l0oooo00<0Ogmo0?ooo`3oool02P3oool20?mVIP80oooo0P3oIVIn0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool02`3oool20?mVIPh0oooo00<000000?oo
o`3oool05`3oool00=80oooo1000000;0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3o
ool0G03oool20?mVIS00oooo00<0Ogmo0?ooo`3oool02P3oool0103oIVH0oooo0?ooo`3oool30?mV
IWd0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`090?ooo`040?mVIP3oool0ofIV
0?mVIP`0oooo0`00000I0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool0G@3oool20?mVIRl0oooo00<0Ogmo0?ooo`3oool02@3oool20?mV
IP@0oooo0`3oIVIl0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0203oool20?mV
IP030?ooo`3oIVH0ofIV00h0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo05h0oooo00<0ofIV0?ooo`3o
ool0;@3oool00`1oOgl0oooo0?ooo`090?ooo`030?mVIP3oool0oooo00@0oooo0`3oIVIk0?ooo`03
07moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool01`3oool60?mVIPh0oooo00<000000?ooo`3o
ool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307mo
O`3oool0oooo05h0oooo0P3oIVH^0?ooo`0307moO`3oool0oooo00<0oooo00<0ofIV0?ooo`3oool0
0P3oool20?mVIPL0oooo0P3oIVIk0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
1`3oool60?mVIPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303o
ool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo05l0oooo00<0ofIV0?ooo`3oool0;03o
ool0101oOgl0oooo0?ooo`3oool30?mVIP@0oooo00<0ofIV0?ooo`3oool01`3oool20?mVIWX0oooo
00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`060?ooo`80ofIV00<0oooo0?mVIP3oIVH0
0P3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`1O0?ooo`80ofIV;@3oool00`1oOgl0oooo0?mV
IP050?mVIP80oooo0P3oIVH90?ooo`<0ofIVN@3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3o
ool0oooo00D0oooo0`3oIVH00`3oool0ofIV0?mVIP020?mVIPh0oooo00<000000?ooo`3oool05`3o
ool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0
oooo0600oooo0P3oIVH/0?ooo`D0ofIV00<0oooo0?mVIP3oIVH00P3oool00`3oIVH0oooo0?ooo`09
0?ooo`<0ofIVN03oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo00@0oooo0`3oIVH2
0?ooo`@0ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?oo
o`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0H@3oool00`3oIVH0oooo0?ooo`0X0?oo
o`D0ofIV0`3oool20?mVIP030?ooo`3oIVH0ofIV00`0oooo0`3oIVIg0?ooo`0307moO`3oool0oooo
08l0oooo00<0Ogmo0?ooo`3oool00`3oool30?mVIP<0oooo103oIVH>0?ooo`030000003oool0oooo
01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0
oooo0?ooo`1Q0?ooo`80ofIV9`3oool50?mVIPD0oooo0P3oIVH00`3oool0ofIV0?ooo`0=0?ooo`80
ofIVM`3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo0080oooo0`3oIVH40?ooo`@0
ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307mo
O`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0HP3oool60?mVIR00oooo1@3oIVH00`3oool0Ogmo
0?ooo`040?ooo`@0ofIV3`3oool20?mVIWH0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo
0?ooo`020?ooo`80ofIV1@3oool40?mVIPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<0
00000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo0680oooo303o
IVHH0?ooo`D0ofIV0`3oool00`1oOgl0oooo0?ooo`030?ooo`@0ofIV3`3oool30?mVIWD0oooo00<0
Ogmo0?ooo`3oool0S`3oool0101oOgl0oooo0?ooo`3oool20?mVIPH0oooo103oIVH>0?ooo`030000
003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`1X0?ooo``0ofIV403oool50?mVIPD0oooo00<0Ogmo0?ooo`3oool00`3o
ool40?mVIQ00oooo0`3oIVId0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool00`3o
IVH60?ooo`@0ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<
0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0KP3oool<0?mVIPP0oooo1@3oIVH7
0?ooo`0307moO`3oool0oooo00<0oooo103oIVHA0?ooo`<0ofIVL`3oool00`1oOgl0oooo0?ooo`2?
0?ooo`0307moO`3oool0ofIV0080ofIV1`3oool40?mVIPh0oooo00<000000?ooo`3oool05`3oool0
0=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo
07@0oooo4@3oIVH90?ooo`0307moO`3oool0oooo00<0oooo103oIVHB0?ooo`80ofIVL`3oool00`1o
Ogl0oooo0?ooo`2?0?ooo`0407moO`3oIVH0ofIV0?mVIPP0oooo103oIVH>0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`1j0?ooo`T0ofIV2`3oool00`1oOgl0oooo0?ooo`030?ooo`@0ofIV4`3oool20?mV
IW80oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0ofIV0?mVIP090?ooo`@0ofIV3P3oool00`00
0000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0
oooo00<0Ogmo0?ooo`3oool0P03oool00`3oIVH0oooo0?ooo`0;0?ooo`0307moO`3oool0oooo00<0
oooo103oIVHC0?ooo`<0ofIVL@3oool00`1oOgl0oooo0?ooo`2?0?ooo`80ofIV2P3oool40?mVIPh0
oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo
0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool00`3oool40?mVIQ@0oooo
0`3oIVI`0?ooo`0307moO`3oool0oooo08h0oooo0`3oIVH;0?ooo`<0ofIV3P3oool00`000000oooo
0?ooo`0G0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0
Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`030?ooo`<0ofIV5P3oool30?mVIVl0oooo00<0
Ogmo0?ooo`3oool0S@3oool30?mVIP`0oooo0`3oIVH>0?ooo`030000003oool0oooo01L0oooo003B
0?ooo`@000002`3oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo
0?ooo`3oool00`3oool30?mVIQL0oooo0`3oIVI^0?ooo`0307moO`3oool0oooo08`0oooo0`3oIVH0
0`1oOgl0oooo0?ooo`0:0?ooo`<0ofIV303oool3000001T0oooo003B0?ooo`030000003oool0oooo
00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo
00<0oooo0`3oIVHH0?ooo`80ofIVKP3oool00`1oOgl0oooo0?ooo`2;0?ooo`<0ofIV00<0oooo07mo
O`3oool02`3oool30?mVIPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3o
ool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3o
ool00`3oool30?mVIQT0oooo0P3oIVI]0?ooo`0307moO`3oool0oooo00T0oooo1`3oIVIk0?ooo`80
ofIV0P3oool00`1oOgl0oooo0?ooo`0:0?ooo`<0ofIV3P3oool00`000000oooo0?ooo`0G0?ooo`00
dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0
SP3oool00`1oOgl0oooo0?ooo`030?ooo`<0ofIV6@3oool30?mVIV`0oooo00<0Ogmo0?ooo`3oool0
1@3oool>0?mVIWL0oooo0P3oIVH30?ooo`0307moO`3oool0oooo00X0oooo0`3oIVH>0?ooo`030000
003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo00<0oooo0`3oIVHJ0?ooo`<0ofIVJ`3o
ool00`1oOgl0oooo0?ooo`020?ooo`L0ofIV1`3oool60?mVIW<0oooo0`3oIVH30?ooo`0307moO`3o
ool0oooo00X0oooo0`3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo00<0oooo0`3oIVHK0?ooo`<0ofIVJP3oool00`1oOgl0ofIV0?mVIP050?mVIPh0oooo1P3oIVI_
0?ooo`<0ofIV103oool00`1oOgl0oooo0?ooo`0:0?ooo`<0ofIV3P3oool00`000000oooo0?ooo`0G
0?ooo`00dP3oool00`000000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?oo
o`3oool0SP3oool00`1oOgl0oooo0?ooo`030?ooo`<0ofIV703oool20?mVIR80oooo9@3oIVHP0?oo
o`P0ofIV503oool70?mVIVX0oooo0`3oIVH50?ooo`0307moO`3oool0oooo00X0oooo0`3oIVH>0?oo
o`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3o
ool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo00<0oooo0P3oIVHN0?ooo`80
ofIV7@3oool`0?mVIQH0oooo1`3oIVHK0?ooo`L0ofIVI`3oool20?mVIPH0oooo00<0Ogmo0?ooo`3o
ool02P3oool30?mVIPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0
303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0
8`3oool30?mVIQP0oooo203oIVHU0?ooo`h0ofIV2`3oool70?mVIP<0oooo00<0Ogmo0?ooo`3oool0
7@3oool60?mVIV<0oooo0P3oIVH70?ooo`0307moO`3oool0oooo00X0oooo0`3oIVH>0?ooo`030000
003oool0oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3o
ool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo02@0oooo0`3oIVHC0?ooo`P0ofIV<03o
oolF0?mVIPH0oooo00<0Ogmo0?ooo`3oool0803oool60?mVIUl0oooo0`3oIVH70?ooo`0307moO`3o
ool0oooo00X0oooo0`3oIVH>0?ooo`030000003oool0oooo01L0oooo003B0?ooo`030000003oool0
oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0
oooo02D0oooo0`3oIVH>0?ooo`P0ofIV>`3oool;0?mVIPX0oooo00<0Ogmo0?ooo`3oool08`3oool6
0?mVIU/0oooo0`3oIVH80?ooo`0307moO`3oool0oooo00X0oooo0`3oIVH>0?ooo`030000003oool0
oooo01L0oooo003B0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo02H0oooo0P3oIVH:0?ooo`P0ofIVE03oool00`1o
Ogl0oooo0?ooo`0V0?oooa80ofIVB`3oool30?mVIPT0oooo00<0Ogmo0?ooo`3oool02P3oool30?mV
IPh0oooo00<000000?ooo`3oool05`3oool00=80oooo00<000000?ooo`3oool0303oool00`1oOgl0
oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool09`3oool20?mVIPD0
oooo203oIVIH0?ooo`0307moO`3oool0oooo02T0oooo7@3oIVHl0?ooo`<0ofIV2P3oool00`1oOgl0
oooo0?ooo`0:0?ooo`80ofIV3`3oool00`000000oooo0?ooo`0G0?ooo`00dP3oool00`000000oooo
0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo
0?ooo`0W0?ooo`/0ofIVG03oool00`1oOgl0oooo0?ooo`0h0?oooad0ofIV;@3oool20?mVIP/0oooo
00<0Ogmo0?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`00RP3oool01@3ookl0M0000000
00000000M;oo00H0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`050?ooo`030?oo
g`2LB00000000080000000<004RL0=ooo`3oool01@3oool00`3ooml0W4P000000002000000030018
W03Oool0oooo00D0oooo00<0oooO09a8000000000P0000000`00B9`0gooo0?ooo`0>0?ooo`030000
003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307mo
O`3oool0oooo02P0oooo1P3oIVIP0?ooo`0307moO`3oool0oooo04H0oooo7@3oIVHN0?ooo`80ofIV
303oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d
000000000000001d_ol01@3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo
00<0omnL04P000000000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@00000
00<0001809cOo`3oool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00d0oooo
00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`0307moO`3oool0oooo08h0oooo
00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`1E0?ooobh0ofIV303oool00`1oOgl0oooo
0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d_ol0
103oool00`3ookl0M00000000006000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000001P00
B9`0gooo0?ooo`3oool0oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d000700000003
0018W03Oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`1oOgl0oooo0?ooo`2?0?ooo`03
07moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1oOgl0oooo0?ooo`1S0?oooal0
ofIV3@3oool00`1oOgl0oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo
_`1d000000000000001d_ol0103oool01`3o_g@000000000000004P0W=oo0?ooo`3o_g@00`000000
101d_ol0oooo0?ooo`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000@0M;oo0?ooo`3oool0
okmd0P000000100004P0W=oo0?ooo`3o_g@30000000407Boo`3oool0oooo0?noM080000000@00018
09cOo`3oool0okmd0`0000000`1d_ol0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08h0oooo00<0
Ogmo0?ooo`3oool0P03oool00`3oIVH0oooo0?ooo`0<0?ooo`0307moO`3oool0oooo01/0oooo00<0
00000?ooo`3oool05`3oool008X0oooo00D0oono07@000000000000007Boo`040?ooo`040;md0000
00000000001d_`<0oooo00@0_g@0000000000000B9cO0P3oool0102oM000000000000000M;l30?oo
o`040;md00000000000004RLg`80oooo00@0_g@000000000000007Bo0`3oool0102oM00000000000
0018W=l20?ooo`040;md000000000000001d_`<0oooo00@0_g@0000000000000B9cO3@3oool00`00
0000oooo0?ooo`0<0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool0SP3oool00`1o
Ogl0oooo0?ooo`2>0?ooo`0307moO`3oool0oooo08l0oooo00<0Ogmo0?ooo`3oool06`3oool00`00
0000oooo0?ooo`0G0?ooo`00RP3oool01@3ookl0M000000000000000M;oo00<0oooo00D0oooO09a8
00000000000007Boo`030?ooo`070=nLB000000000000018W03Oool0oooO09a800020000000507Bo
o`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo
0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P0
0P0000000`00B9`0gooo0?ooo`0;0?ooo`D00000o`1oOgoo07moOf`0Ogmo1@00000I0?ooo`00RP3o
ool01@3ookl0M000000000000000M;oo00<0oooo00D0oono07@000000000000007Boo`030?ooo`07
0?noM000000000000018W03Oool0oono07@000020000000507Boo`3oool0oooo0?ooo`3o_g@00P00
00001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0
gooo0?oo_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000000`00B9`0gooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`2>
0?ooo`0307moO`3oool0oooo08h0oooo00<0Ogmo0?ooo`3oool0S`3oool00`1oOgl0oooo0?ooo`0K
0?ooo`030000003oool0oooo01L0oooo002:0?ooo`050?oo_`1d000000000000001d_ol00`3oool0
1@3ookl0M000000000000000M;oo00<0oooo00L0okmd000000000000001d0;ooo`3ookl0M0000080
000000D0M;oo0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo
0?ooo`3oool0oooo0?noM002000000040000M02oool0oono07@00080000000D0M;oo0?ooo`3oool0
oooo0?noM002000000030000M02oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool008X0oooo
00D0oono07@000000000000007Boo`030?ooo`050?oo_`1d000000000000001d_ol00`3oool01`3o
_g@000000000000007@0_ooo0?oo_`1d00000P0000001@1d_ol0oooo0?ooo`3oool0okmd00800000
00@0001d0;ooo`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000@0001d0;oo
o`3ookl0M0000P0000001@1d_ol0oooo0?ooo`3oool0okmd0080000000<0001d0;ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`00RP3oool01@3ookl0M000000000000000M;oo00<0oooo00D0
oono07@000000000000007Boo`030?ooo`070?noM000000000000000M02oool0oono07@000020000
000507Boo`3oool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3o
ool0oooo0?ooo`3o_g@00P000000100007@0_ooo0?oo_`1d00020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000000`0007@0_ooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo0P00000I0?oo
o`00QP3oool01P3ookl0M01809cOo`3oool0oono07@00080000000H0M;oo0?ooo`3oool0oooo0?oo
_`1d00020000000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000
000507Boo`3oool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3o
ool0oooo0?ooo`3o_g@00P0000001000B9`0gooo0?oo_`1d00020000000507Boo`3oool0oooo0?oo
o`3o_g@00P0000000`00B9`0gooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo0P00000I0?oo
o`00QP3oool01P3ookl0M00000000000B9`0gono07@00080000000H0M;oo0?ooo`3oool0oooo0?oo
g`2LB0020000000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000
000507Boo`3oool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3o
ool0oooo0?ooo`3OW4P00P0000001000B9`0gooo0?oog`2LB0020000000507Boo`3oool0oooo0?oo
o`3OW4P00P0000000`00B9`0gooo0?ooo`0;0?ooool00000o`00001f000001T0oooo00260?ooo`03
0?oo_`1d0000000000D0000000<0M;oo0?ooo`3oool00P3oool0102oM000000000000000M;l30?oo
o`040;md000000000000001d_`80oooo00@0_g@000000000000007Bo0`3oool0102oM00000000000
0000M;l20?ooo`040;md000000000000001d_`<0oooo00@0_g@000000000000007Bo0P3oool0102o
M000000000000000M;l30?ooo`040;md000000000000001d_ol0ooooo`3ooonL0?ooo`00Q`3oool0
0`3ooml0W4P0000000040000000307Boo`3oool0oooo0080oooo00L0okmd000000000000001809cO
o`3oool0okmd00<0000000@0M;oo0?ooo`3oool0okmd0P000000100004P0W=oo0?ooo`3o_g@30000
000407Boo`3oool0oooo0?noM080000000@0001809cOo`3oool0okmd0`000000101d_ol0oooo0?oo
o`3o_g@2000000040000B02Lgol0oooo0?noM0<0000000<0M;oo0?ooo`3oool0o`3ooooo0?oooiX0
oooo00290?ooo`030?noM000000000000080000000<0M;oo0?ooo`3oool00P3oool00`3ookl0M000
00000006000000060018W03Oool0oooo0?ooo`3ookl0M0001`0000001P00B9`0gooo0?ooo`3oool0
oono07@000L0000000H004RL0=ooo`3oool0oooo0?oo_`1d0007000000030018W03Oool0oooo0?l0
ooooo`3ooonK0?ooo`00RP3oool01@3ogi`0B000000000000000M;oo00D0oooo00<0omnL04P00000
0000100000000`0004P0W=oo0?ooo`030?ooo`030?oOW0180000000000@0000000<0001809cOo`3o
ool00`3oool00`3ogi`0B00000000004000000030000B02Lgol0oooo00<0oooo00<0omnL04P00000
0000100000000`0004P0W=oo0?ooo`3o0?ooool0ooooW03oool008/0oooo00@0gia8000000000000
M;oo1P3oool00`3ooml0W4P000000002000000030018W03Oool0oooo00D0oooo00<0oooO09a80000
00000P0000000`00B9`0gooo0?ooo`050?ooo`030?oog`2LB00000000080000000<004RL0=ooo`3o
ool01@3oool00`3ooml0W4P000000002000000030018W03Oool0oooo0?l0ooooo`3ooonM0?ooo`00
o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR
0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0oooo
o`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?oo
ool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo
003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?oo
of80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3o
oooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0
ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3o
ool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0
ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00o`3ooooo
0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR0?ooo`00
o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0ooooo`3ooomR
0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?ooool0oooo
o`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00?l0ooooo`3ooooo0?ooof80oooo003o0?oo
ool0ooooo`3ooomR0?ooo`00o`3ooooo0?ooool0ooooHP3oool00001\
\>"],
  ImageRangeCache->{{{0, 862.813}, {586.813, 0}} -> {-1.05103, -0.784208, \
0.00367181, 0.00367181}, {{20.8125, 837.875}, {518.875, 13.9375}} -> \
{-776.569, -4387.71, 5.15868, 40.327}, {{65.75, 841.938}, {572.813, 531.938}} -> \
{-0.510019, -0.909495, 0.00935348, 0.0866553}, {{94.5625, 254.938}, {569.625, \
552.375}} -> {-20.2611, -2.99278, 0.173915, 0.173915}, {{280.625, 441}, \
{569.625, 552.375}} -> {-41.8338, -2.99278, 0.173915, 0.173915}, {{466.625, \
627}, {569.625, 552.375}} -> {-63.3992, -2.99278, 0.173915, 0.173915}, \
{{652.688, 813.063}, {569.625, 552.375}} -> {-84.9719, -2.99278, 0.173915, \
0.173915}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Sparse Numerical Linear Algebra", "Section"],

Cell["\<\
A means of dealing with very large matrices that have mostly zero entries\
\>", "BulletText"],

Cell["\<\
These come up in solving ODEs, solving PDEs, solving optimization problems, \
etc. \
\>", "BulletText"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " design, works for arrays of any rank, and is fully integrated with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "BulletText"],

Cell[TextData[{
  "Competitive Situation: On par or better than Matlab and Fortran libraries \
(",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", NAG)."
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell["Here we create a sparse array using patterns. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SparseArray[\ {{i_, \ j_} /; \ 
            Abs[i - j]\  \[LessEqual] \ 1\  \[RuleDelayed] \ 
          Random[]\ }, \ {5, \ 5}]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]13\[InvisibleSpace]">"\),
            SequenceForm[ "<", 13, ">"],
            Editable->False], ",", \({5, 5}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "If you apply ",
  StyleBox["Normal", "MR"],
  " to a ",
  StyleBox["SparseArray", "MR"],
  " object you get the corresponding dense array. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[\ %\ ]\  // MatrixForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.633359842894021`", "0.9277609931918128`", "0", "0", "0"},
            {"0.2903671336881774`", "0.35417264776928975`", 
              "0.7941186012499657`", "0", "0"},
            {"0", "0.5903162123394384`", "0.07655152014108098`", 
              "0.5008835366328445`", "0"},
            {"0", "0", "0.4730991370106786`", "0.7749054696104243`", 
              "0.8202302100141222`"},
            {"0", "0", "0", "0.8234944714636211`", "0.2828693152694498`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[23]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "You can also ",
  StyleBox["Import", "MR"],
  " (and ",
  StyleBox["Export", "MR"],
  ") several sparse array formats such as MatrixMarket and Harwell-Boeing."
}], "MathCaption"],

Cell[BoxData[
    \(\(SetDirectory[\ 
        ToFileName[\ $PresentationDirectory, \ "\<Data\>"]\ ];\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ Import[\ "\<young1c.mtx\>", \ "\<MatrixMarket\>"\ ]\)], "Input",\

  CellLabel->"In[31]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]4089\[InvisibleSpace]">"\),
            SequenceForm[ "<", 4089, ">"],
            Editable->False], ",", \({841, 841}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
Also you may often want to understand the structure of nonzer0 elements in \
your sparse array. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(matrixPlot[\ s\ ];\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0192308 0.00114333 0.0192308 0.00114333 [
[.01923 -0.0125 -4.21875 -10.9375 ]
[.01923 -0.0125 4.21875 0 ]
[.2479 -0.0125 -8.65625 -10.9375 ]
[.2479 -0.0125 8.65625 0 ]
[.47656 -0.0125 -8.65625 -10.9375 ]
[.47656 -0.0125 8.65625 0 ]
[.70523 -0.0125 -8.65625 -10.9375 ]
[.70523 -0.0125 8.65625 0 ]
[.93389 -0.0125 -8.65625 -10.9375 ]
[.93389 -0.0125 8.65625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -8.4375 -5.46875 ]
[-0.0125 .01923 0 5.46875 ]
[-0.0125 .2479 -17.3125 -5.46875 ]
[-0.0125 .2479 0 5.46875 ]
[-0.0125 .47656 -17.3125 -5.46875 ]
[-0.0125 .47656 0 5.46875 ]
[-0.0125 .70523 -17.3125 -5.46875 ]
[-0.0125 .70523 0 5.46875 ]
[-0.0125 .93389 -17.3125 -5.46875 ]
[-0.0125 .93389 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2479 0 m
.2479 .00625 L
s
gsave
.2479 -0.0125 -69.6563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.47656 0 m
.47656 .00625 L
s
gsave
.47656 -0.0125 -69.6563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.70523 0 m
.70523 .00625 L
s
gsave
.70523 -0.0125 -69.6563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.93389 0 m
.93389 .00625 L
s
gsave
.93389 -0.0125 -69.6563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.125 Mabswid
.0764 0 m
.0764 .00375 L
s
.13356 0 m
.13356 .00375 L
s
.19073 0 m
.19073 .00375 L
s
.30506 0 m
.30506 .00375 L
s
.36223 0 m
.36223 .00375 L
s
.4194 0 m
.4194 .00375 L
s
.53373 0 m
.53373 .00375 L
s
.59089 0 m
.59089 .00375 L
s
.64806 0 m
.64806 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.81956 0 m
.81956 .00375 L
s
.87673 0 m
.87673 .00375 L
s
.99106 0 m
.99106 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .2479 m
.00625 .2479 L
s
gsave
-0.0125 .2479 -78.3125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .47656 m
.00625 .47656 L
s
gsave
-0.0125 .47656 -78.3125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .70523 m
.00625 .70523 L
s
gsave
-0.0125 .70523 -78.3125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
0 .93389 m
.00625 .93389 L
s
gsave
-0.0125 .93389 -78.3125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0764 m
.00375 .0764 L
s
0 .13356 m
.00375 .13356 L
s
0 .19073 m
.00375 .19073 L
s
0 .30506 m
.00375 .30506 L
s
0 .36223 m
.00375 .36223 L
s
0 .4194 m
.00375 .4194 L
s
0 .53373 m
.00375 .53373 L
s
0 .59089 m
.00375 .59089 L
s
0 .64806 m
.00375 .64806 L
s
0 .76239 m
.00375 .76239 L
s
0 .81956 m
.00375 .81956 L
s
0 .87673 m
.00375 .87673 L
s
0 .99106 m
.00375 .99106 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.2479 .99375 m
.2479 1 L
s
.47656 .99375 m
.47656 1 L
s
.70523 .99375 m
.70523 1 L
s
.93389 .99375 m
.93389 1 L
s
.125 Mabswid
.0764 .99625 m
.0764 1 L
s
.13356 .99625 m
.13356 1 L
s
.19073 .99625 m
.19073 1 L
s
.30506 .99625 m
.30506 1 L
s
.36223 .99625 m
.36223 1 L
s
.4194 .99625 m
.4194 1 L
s
.53373 .99625 m
.53373 1 L
s
.59089 .99625 m
.59089 1 L
s
.64806 .99625 m
.64806 1 L
s
.76239 .99625 m
.76239 1 L
s
.81956 .99625 m
.81956 1 L
s
.87673 .99625 m
.87673 1 L
s
.99106 .99625 m
.99106 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .2479 m
1 .2479 L
s
.99375 .47656 m
1 .47656 L
s
.99375 .70523 m
1 .70523 L
s
.99375 .93389 m
1 .93389 L
s
.125 Mabswid
.99625 .0764 m
1 .0764 L
s
.99625 .13356 m
1 .13356 L
s
.99625 .19073 m
1 .19073 L
s
.99625 .30506 m
1 .30506 L
s
.99625 .36223 m
1 .36223 L
s
.99625 .4194 m
1 .4194 L
s
.99625 .53373 m
1 .53373 L
s
.99625 .59089 m
1 .59089 L
s
.99625 .64806 m
1 .64806 L
s
.99625 .76239 m
1 .76239 L
s
.99625 .81956 m
1 .81956 L
s
.99625 .87673 m
1 .87673 L
s
.99625 .99106 m
1 .99106 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .01923 m
.01923 .98077 L
.98077 .98077 L
.98077 .01923 L
F
0 g
.94647 .01923 m
.94647 .02037 L
.94761 .02037 L
.94761 .01923 L
F
.97848 .01923 m
.97848 .02037 L
.97963 .02037 L
.97963 .01923 L
F
.97963 .01923 m
.97963 .02037 L
.98077 .02037 L
.98077 .01923 L
F
.94533 .02037 m
.94533 .02152 L
.94647 .02152 L
.94647 .02037 L
F
.97734 .02037 m
.97734 .02152 L
.97848 .02152 L
.97848 .02037 L
F
.97848 .02037 m
.97848 .02152 L
.97963 .02152 L
.97963 .02037 L
F
.97963 .02037 m
.97963 .02152 L
.98077 .02152 L
.98077 .02037 L
F
.94418 .02152 m
.94418 .02266 L
.94533 .02266 L
.94533 .02152 L
F
.9762 .02152 m
.9762 .02266 L
.97734 .02266 L
.97734 .02152 L
F
.97734 .02152 m
.97734 .02266 L
.97848 .02266 L
.97848 .02152 L
F
.97848 .02152 m
.97848 .02266 L
.97963 .02266 L
.97963 .02152 L
F
.94304 .02266 m
.94304 .0238 L
.94418 .0238 L
.94418 .02266 L
F
.97505 .02266 m
.97505 .0238 L
.9762 .0238 L
.9762 .02266 L
F
.9762 .02266 m
.9762 .0238 L
.97734 .0238 L
.97734 .02266 L
F
.97734 .02266 m
.97734 .0238 L
.97848 .0238 L
.97848 .02266 L
F
.9419 .0238 m
.9419 .02495 L
.94304 .02495 L
.94304 .0238 L
F
.97391 .0238 m
.97391 .02495 L
.97505 .02495 L
.97505 .0238 L
F
.97505 .0238 m
.97505 .02495 L
.9762 .02495 L
.9762 .0238 L
F
.9762 .0238 m
.9762 .02495 L
.97734 .02495 L
.97734 .0238 L
F
.94075 .02495 m
.94075 .02609 L
.9419 .02609 L
.9419 .02495 L
F
.97277 .02495 m
.97277 .02609 L
.97391 .02609 L
.97391 .02495 L
F
.97391 .02495 m
.97391 .02609 L
.97505 .02609 L
.97505 .02495 L
F
.97505 .02495 m
.97505 .02609 L
.9762 .02609 L
.9762 .02495 L
F
.93961 .02609 m
.93961 .02723 L
.94075 .02723 L
.94075 .02609 L
F
.97162 .02609 m
.97162 .02723 L
.97277 .02723 L
.97277 .02609 L
F
.97277 .02609 m
.97277 .02723 L
.97391 .02723 L
.97391 .02609 L
F
.97391 .02609 m
.97391 .02723 L
.97505 .02723 L
.97505 .02609 L
F
.93847 .02723 m
.93847 .02838 L
.93961 .02838 L
.93961 .02723 L
F
.97048 .02723 m
.97048 .02838 L
.97162 .02838 L
.97162 .02723 L
F
.97162 .02723 m
.97162 .02838 L
.97277 .02838 L
.97277 .02723 L
F
.97277 .02723 m
.97277 .02838 L
.97391 .02838 L
.97391 .02723 L
F
.93732 .02838 m
.93732 .02952 L
.93847 .02952 L
.93847 .02838 L
F
.96934 .02838 m
.96934 .02952 L
.97048 .02952 L
.97048 .02838 L
F
.97048 .02838 m
.97048 .02952 L
.97162 .02952 L
.97162 .02838 L
F
.97162 .02838 m
.97162 .02952 L
.97277 .02952 L
.97277 .02838 L
F
.93618 .02952 m
.93618 .03066 L
.93732 .03066 L
.93732 .02952 L
F
.96819 .02952 m
.96819 .03066 L
.96934 .03066 L
.96934 .02952 L
F
.96934 .02952 m
.96934 .03066 L
.97048 .03066 L
.97048 .02952 L
F
.97048 .02952 m
.97048 .03066 L
.97162 .03066 L
.97162 .02952 L
F
.93504 .03066 m
.93504 .03181 L
.93618 .03181 L
.93618 .03066 L
F
.96705 .03066 m
.96705 .03181 L
.96819 .03181 L
.96819 .03066 L
F
.96819 .03066 m
.96819 .03181 L
.96934 .03181 L
.96934 .03066 L
F
.96934 .03066 m
.96934 .03181 L
.97048 .03181 L
.97048 .03066 L
F
.93389 .03181 m
.93389 .03295 L
.93504 .03295 L
.93504 .03181 L
F
.96591 .03181 m
.96591 .03295 L
.96705 .03295 L
.96705 .03181 L
F
.96705 .03181 m
.96705 .03295 L
.96819 .03295 L
.96819 .03181 L
F
.96819 .03181 m
.96819 .03295 L
.96934 .03295 L
.96934 .03181 L
F
.93275 .03295 m
.93275 .03409 L
.93389 .03409 L
.93389 .03295 L
F
.96476 .03295 m
.96476 .03409 L
.96591 .03409 L
.96591 .03295 L
F
.96591 .03295 m
.96591 .03409 L
.96705 .03409 L
.96705 .03295 L
F
.96705 .03295 m
.96705 .03409 L
.96819 .03409 L
.96819 .03295 L
F
.93161 .03409 m
.93161 .03524 L
.93275 .03524 L
.93275 .03409 L
F
.96362 .03409 m
.96362 .03524 L
.96476 .03524 L
.96476 .03409 L
F
.96476 .03409 m
.96476 .03524 L
.96591 .03524 L
.96591 .03409 L
F
.96591 .03409 m
.96591 .03524 L
.96705 .03524 L
.96705 .03409 L
F
.93046 .03524 m
.93046 .03638 L
.93161 .03638 L
.93161 .03524 L
F
.96248 .03524 m
.96248 .03638 L
.96362 .03638 L
.96362 .03524 L
F
.96362 .03524 m
.96362 .03638 L
.96476 .03638 L
.96476 .03524 L
F
.96476 .03524 m
.96476 .03638 L
.96591 .03638 L
.96591 .03524 L
F
.92932 .03638 m
.92932 .03752 L
.93046 .03752 L
.93046 .03638 L
F
.96133 .03638 m
.96133 .03752 L
.96248 .03752 L
.96248 .03638 L
F
.96248 .03638 m
.96248 .03752 L
.96362 .03752 L
.96362 .03638 L
F
.96362 .03638 m
.96362 .03752 L
.96476 .03752 L
.96476 .03638 L
F
.92818 .03752 m
.92818 .03867 L
.92932 .03867 L
.92932 .03752 L
F
.96019 .03752 m
.96019 .03867 L
.96133 .03867 L
.96133 .03752 L
F
.96133 .03752 m
.96133 .03867 L
.96248 .03867 L
.96248 .03752 L
F
.96248 .03752 m
.96248 .03867 L
.96362 .03867 L
.96362 .03752 L
F
.92703 .03867 m
.92703 .03981 L
.92818 .03981 L
.92818 .03867 L
F
.95905 .03867 m
.95905 .03981 L
.96019 .03981 L
.96019 .03867 L
F
.96019 .03867 m
.96019 .03981 L
.96133 .03981 L
.96133 .03867 L
F
.96133 .03867 m
.96133 .03981 L
.96248 .03981 L
.96248 .03867 L
F
.92589 .03981 m
.92589 .04095 L
.92703 .04095 L
.92703 .03981 L
F
.9579 .03981 m
.9579 .04095 L
.95905 .04095 L
.95905 .03981 L
F
.95905 .03981 m
.95905 .04095 L
.96019 .04095 L
.96019 .03981 L
F
.96019 .03981 m
.96019 .04095 L
.96133 .04095 L
.96133 .03981 L
F
.92475 .04095 m
.92475 .0421 L
.92589 .0421 L
.92589 .04095 L
F
.95676 .04095 m
.95676 .0421 L
.9579 .0421 L
.9579 .04095 L
F
.9579 .04095 m
.9579 .0421 L
.95905 .0421 L
.95905 .04095 L
F
.95905 .04095 m
.95905 .0421 L
.96019 .0421 L
.96019 .04095 L
F
.9236 .0421 m
.9236 .04324 L
.92475 .04324 L
.92475 .0421 L
F
.95562 .0421 m
.95562 .04324 L
.95676 .04324 L
.95676 .0421 L
F
.95676 .0421 m
.95676 .04324 L
.9579 .04324 L
.9579 .0421 L
F
.9579 .0421 m
.9579 .04324 L
.95905 .04324 L
.95905 .0421 L
F
.92246 .04324 m
.92246 .04438 L
.9236 .04438 L
.9236 .04324 L
F
.95447 .04324 m
.95447 .04438 L
.95562 .04438 L
.95562 .04324 L
F
.95562 .04324 m
.95562 .04438 L
.95676 .04438 L
.95676 .04324 L
F
.95676 .04324 m
.95676 .04438 L
.9579 .04438 L
.9579 .04324 L
F
.92132 .04438 m
.92132 .04553 L
.92246 .04553 L
.92246 .04438 L
F
.95333 .04438 m
.95333 .04553 L
.95447 .04553 L
.95447 .04438 L
F
.95447 .04438 m
.95447 .04553 L
.95562 .04553 L
.95562 .04438 L
F
.95562 .04438 m
.95562 .04553 L
.95676 .04553 L
.95676 .04438 L
F
.92017 .04553 m
.92017 .04667 L
.92132 .04667 L
.92132 .04553 L
F
.95219 .04553 m
.95219 .04667 L
.95333 .04667 L
.95333 .04553 L
F
.95333 .04553 m
.95333 .04667 L
.95447 .04667 L
.95447 .04553 L
F
.95447 .04553 m
.95447 .04667 L
.95562 .04667 L
.95562 .04553 L
F
.91903 .04667 m
.91903 .04781 L
.92017 .04781 L
.92017 .04667 L
F
.95104 .04667 m
.95104 .04781 L
.95219 .04781 L
.95219 .04667 L
F
.95219 .04667 m
.95219 .04781 L
.95333 .04781 L
.95333 .04667 L
F
.95333 .04667 m
.95333 .04781 L
.95447 .04781 L
.95447 .04667 L
F
.91789 .04781 m
.91789 .04896 L
.91903 .04896 L
.91903 .04781 L
F
.9499 .04781 m
.9499 .04896 L
.95104 .04896 L
.95104 .04781 L
F
.95104 .04781 m
.95104 .04896 L
.95219 .04896 L
.95219 .04781 L
F
.95219 .04781 m
.95219 .04896 L
.95333 .04896 L
.95333 .04781 L
F
.91674 .04896 m
.91674 .0501 L
.91789 .0501 L
.91789 .04896 L
F
.94876 .04896 m
.94876 .0501 L
.9499 .0501 L
.9499 .04896 L
F
.9499 .04896 m
.9499 .0501 L
.95104 .0501 L
.95104 .04896 L
F
.95104 .04896 m
.95104 .0501 L
.95219 .0501 L
.95219 .04896 L
F
.9156 .0501 m
.9156 .05124 L
.91674 .05124 L
.91674 .0501 L
F
.94761 .0501 m
.94761 .05124 L
.94876 .05124 L
.94876 .0501 L
F
.94876 .0501 m
.94876 .05124 L
.9499 .05124 L
.9499 .0501 L
F
.9499 .0501 m
.9499 .05124 L
.95104 .05124 L
.95104 .0501 L
F
.91446 .05124 m
.91446 .05239 L
.9156 .05239 L
.9156 .05124 L
F
.94761 .05124 m
.94761 .05239 L
.94876 .05239 L
.94876 .05124 L
F
.94876 .05124 m
.94876 .05239 L
.9499 .05239 L
.9499 .05124 L
F
.91331 .05239 m
.91331 .05353 L
.91446 .05353 L
.91446 .05239 L
F
.94533 .05239 m
.94533 .05353 L
.94647 .05353 L
.94647 .05239 L
F
.94647 .05239 m
.94647 .05353 L
.94761 .05353 L
.94761 .05239 L
F
.97963 .05239 m
.97963 .05353 L
.98077 .05353 L
.98077 .05239 L
F
.91217 .05353 m
.91217 .05467 L
.91331 .05467 L
.91331 .05353 L
F
.94418 .05353 m
.94418 .05467 L
.94533 .05467 L
.94533 .05353 L
F
.94533 .05353 m
.94533 .05467 L
.94647 .05467 L
.94647 .05353 L
F
.94647 .05353 m
.94647 .05467 L
.94761 .05467 L
.94761 .05353 L
F
.97848 .05353 m
.97848 .05467 L
.97963 .05467 L
.97963 .05353 L
F
.91103 .05467 m
.91103 .05582 L
.91217 .05582 L
.91217 .05467 L
F
.94304 .05467 m
.94304 .05582 L
.94418 .05582 L
.94418 .05467 L
F
.94418 .05467 m
.94418 .05582 L
.94533 .05582 L
.94533 .05467 L
F
.94533 .05467 m
.94533 .05582 L
.94647 .05582 L
.94647 .05467 L
F
.97734 .05467 m
.97734 .05582 L
.97848 .05582 L
.97848 .05467 L
F
.90988 .05582 m
.90988 .05696 L
.91103 .05696 L
.91103 .05582 L
F
.9419 .05582 m
.9419 .05696 L
.94304 .05696 L
.94304 .05582 L
F
.94304 .05582 m
.94304 .05696 L
.94418 .05696 L
.94418 .05582 L
F
.94418 .05582 m
.94418 .05696 L
.94533 .05696 L
.94533 .05582 L
F
.9762 .05582 m
.9762 .05696 L
.97734 .05696 L
.97734 .05582 L
F
.90874 .05696 m
.90874 .0581 L
.90988 .0581 L
.90988 .05696 L
F
.94075 .05696 m
.94075 .0581 L
.9419 .0581 L
.9419 .05696 L
F
.9419 .05696 m
.9419 .0581 L
.94304 .0581 L
.94304 .05696 L
F
.94304 .05696 m
.94304 .0581 L
.94418 .0581 L
.94418 .05696 L
F
.97505 .05696 m
.97505 .0581 L
.9762 .0581 L
.9762 .05696 L
F
.9076 .0581 m
.9076 .05925 L
.90874 .05925 L
.90874 .0581 L
F
.93961 .0581 m
.93961 .05925 L
.94075 .05925 L
.94075 .0581 L
F
.94075 .0581 m
.94075 .05925 L
.9419 .05925 L
.9419 .0581 L
F
.9419 .0581 m
.9419 .05925 L
.94304 .05925 L
.94304 .0581 L
F
.97391 .0581 m
.97391 .05925 L
.97505 .05925 L
.97505 .0581 L
F
.90645 .05925 m
.90645 .06039 L
.9076 .06039 L
.9076 .05925 L
F
.93847 .05925 m
.93847 .06039 L
.93961 .06039 L
.93961 .05925 L
F
.93961 .05925 m
.93961 .06039 L
.94075 .06039 L
.94075 .05925 L
F
.94075 .05925 m
.94075 .06039 L
.9419 .06039 L
.9419 .05925 L
F
.97277 .05925 m
.97277 .06039 L
.97391 .06039 L
.97391 .05925 L
F
.90531 .06039 m
.90531 .06153 L
.90645 .06153 L
.90645 .06039 L
F
.93732 .06039 m
.93732 .06153 L
.93847 .06153 L
.93847 .06039 L
F
.93847 .06039 m
.93847 .06153 L
.93961 .06153 L
.93961 .06039 L
F
.93961 .06039 m
.93961 .06153 L
.94075 .06153 L
.94075 .06039 L
F
.97162 .06039 m
.97162 .06153 L
.97277 .06153 L
.97277 .06039 L
F
.90417 .06153 m
.90417 .06268 L
.90531 .06268 L
.90531 .06153 L
F
.93618 .06153 m
.93618 .06268 L
.93732 .06268 L
.93732 .06153 L
F
.93732 .06153 m
.93732 .06268 L
.93847 .06268 L
.93847 .06153 L
F
.93847 .06153 m
.93847 .06268 L
.93961 .06268 L
.93961 .06153 L
F
.97048 .06153 m
.97048 .06268 L
.97162 .06268 L
.97162 .06153 L
F
.90302 .06268 m
.90302 .06382 L
.90417 .06382 L
.90417 .06268 L
F
.93504 .06268 m
.93504 .06382 L
.93618 .06382 L
.93618 .06268 L
F
.93618 .06268 m
.93618 .06382 L
.93732 .06382 L
.93732 .06268 L
F
.93732 .06268 m
.93732 .06382 L
.93847 .06382 L
.93847 .06268 L
F
.96934 .06268 m
.96934 .06382 L
.97048 .06382 L
.97048 .06268 L
F
.90188 .06382 m
.90188 .06496 L
.90302 .06496 L
.90302 .06382 L
F
.93389 .06382 m
.93389 .06496 L
.93504 .06496 L
.93504 .06382 L
F
.93504 .06382 m
.93504 .06496 L
.93618 .06496 L
.93618 .06382 L
F
.93618 .06382 m
.93618 .06496 L
.93732 .06496 L
.93732 .06382 L
F
.96819 .06382 m
.96819 .06496 L
.96934 .06496 L
.96934 .06382 L
F
.90074 .06496 m
.90074 .06611 L
.90188 .06611 L
.90188 .06496 L
F
.93275 .06496 m
.93275 .06611 L
.93389 .06611 L
.93389 .06496 L
F
.93389 .06496 m
.93389 .06611 L
.93504 .06611 L
.93504 .06496 L
F
.93504 .06496 m
.93504 .06611 L
.93618 .06611 L
.93618 .06496 L
F
.96705 .06496 m
.96705 .06611 L
.96819 .06611 L
.96819 .06496 L
F
.89959 .06611 m
.89959 .06725 L
.90074 .06725 L
.90074 .06611 L
F
.93161 .06611 m
.93161 .06725 L
.93275 .06725 L
.93275 .06611 L
F
.93275 .06611 m
.93275 .06725 L
.93389 .06725 L
.93389 .06611 L
F
.93389 .06611 m
.93389 .06725 L
.93504 .06725 L
.93504 .06611 L
F
.96591 .06611 m
.96591 .06725 L
.96705 .06725 L
.96705 .06611 L
F
.89845 .06725 m
.89845 .06839 L
.89959 .06839 L
.89959 .06725 L
F
.93046 .06725 m
.93046 .06839 L
.93161 .06839 L
.93161 .06725 L
F
.93161 .06725 m
.93161 .06839 L
.93275 .06839 L
.93275 .06725 L
F
.93275 .06725 m
.93275 .06839 L
.93389 .06839 L
.93389 .06725 L
F
.96476 .06725 m
.96476 .06839 L
.96591 .06839 L
.96591 .06725 L
F
.89731 .06839 m
.89731 .06954 L
.89845 .06954 L
.89845 .06839 L
F
.92932 .06839 m
.92932 .06954 L
.93046 .06954 L
.93046 .06839 L
F
.93046 .06839 m
.93046 .06954 L
.93161 .06954 L
.93161 .06839 L
F
.93161 .06839 m
.93161 .06954 L
.93275 .06954 L
.93275 .06839 L
F
.96362 .06839 m
.96362 .06954 L
.96476 .06954 L
.96476 .06839 L
F
.89616 .06954 m
.89616 .07068 L
.89731 .07068 L
.89731 .06954 L
F
.92818 .06954 m
.92818 .07068 L
.92932 .07068 L
.92932 .06954 L
F
.92932 .06954 m
.92932 .07068 L
.93046 .07068 L
.93046 .06954 L
F
.93046 .06954 m
.93046 .07068 L
.93161 .07068 L
.93161 .06954 L
F
.96248 .06954 m
.96248 .07068 L
.96362 .07068 L
.96362 .06954 L
F
.89502 .07068 m
.89502 .07182 L
.89616 .07182 L
.89616 .07068 L
F
.92703 .07068 m
.92703 .07182 L
.92818 .07182 L
.92818 .07068 L
F
.92818 .07068 m
.92818 .07182 L
.92932 .07182 L
.92932 .07068 L
F
.92932 .07068 m
.92932 .07182 L
.93046 .07182 L
.93046 .07068 L
F
.96133 .07068 m
.96133 .07182 L
.96248 .07182 L
.96248 .07068 L
F
.89388 .07182 m
.89388 .07297 L
.89502 .07297 L
.89502 .07182 L
F
.92589 .07182 m
.92589 .07297 L
.92703 .07297 L
.92703 .07182 L
F
.92703 .07182 m
.92703 .07297 L
.92818 .07297 L
.92818 .07182 L
F
.92818 .07182 m
.92818 .07297 L
.92932 .07297 L
.92932 .07182 L
F
.96019 .07182 m
.96019 .07297 L
.96133 .07297 L
.96133 .07182 L
F
.89273 .07297 m
.89273 .07411 L
.89388 .07411 L
.89388 .07297 L
F
.92475 .07297 m
.92475 .07411 L
.92589 .07411 L
.92589 .07297 L
F
.92589 .07297 m
.92589 .07411 L
.92703 .07411 L
.92703 .07297 L
F
.92703 .07297 m
.92703 .07411 L
.92818 .07411 L
.92818 .07297 L
F
.95905 .07297 m
.95905 .07411 L
.96019 .07411 L
.96019 .07297 L
F
.89159 .07411 m
.89159 .07525 L
.89273 .07525 L
.89273 .07411 L
F
.9236 .07411 m
.9236 .07525 L
.92475 .07525 L
.92475 .07411 L
F
.92475 .07411 m
.92475 .07525 L
.92589 .07525 L
.92589 .07411 L
F
.92589 .07411 m
.92589 .07525 L
.92703 .07525 L
.92703 .07411 L
F
.9579 .07411 m
.9579 .07525 L
.95905 .07525 L
.95905 .07411 L
F
.89045 .07525 m
.89045 .0764 L
.89159 .0764 L
.89159 .07525 L
F
.92246 .07525 m
.92246 .0764 L
.9236 .0764 L
.9236 .07525 L
F
.9236 .07525 m
.9236 .0764 L
.92475 .0764 L
.92475 .07525 L
F
.92475 .07525 m
.92475 .0764 L
.92589 .0764 L
.92589 .07525 L
F
.95676 .07525 m
.95676 .0764 L
.9579 .0764 L
.9579 .07525 L
F
.8893 .0764 m
.8893 .07754 L
.89045 .07754 L
.89045 .0764 L
F
.92132 .0764 m
.92132 .07754 L
.92246 .07754 L
.92246 .0764 L
F
.92246 .0764 m
.92246 .07754 L
.9236 .07754 L
.9236 .0764 L
F
.9236 .0764 m
.9236 .07754 L
.92475 .07754 L
.92475 .0764 L
F
.95562 .0764 m
.95562 .07754 L
.95676 .07754 L
.95676 .0764 L
F
.88816 .07754 m
.88816 .07868 L
.8893 .07868 L
.8893 .07754 L
F
.92017 .07754 m
.92017 .07868 L
.92132 .07868 L
.92132 .07754 L
F
.92132 .07754 m
.92132 .07868 L
.92246 .07868 L
.92246 .07754 L
F
.92246 .07754 m
.92246 .07868 L
.9236 .07868 L
.9236 .07754 L
F
.95447 .07754 m
.95447 .07868 L
.95562 .07868 L
.95562 .07754 L
F
.88702 .07868 m
.88702 .07983 L
.88816 .07983 L
.88816 .07868 L
F
.91903 .07868 m
.91903 .07983 L
.92017 .07983 L
.92017 .07868 L
F
.92017 .07868 m
.92017 .07983 L
.92132 .07983 L
.92132 .07868 L
F
.92132 .07868 m
.92132 .07983 L
.92246 .07983 L
.92246 .07868 L
F
.95333 .07868 m
.95333 .07983 L
.95447 .07983 L
.95447 .07868 L
F
.88587 .07983 m
.88587 .08097 L
.88702 .08097 L
.88702 .07983 L
F
.91789 .07983 m
.91789 .08097 L
.91903 .08097 L
.91903 .07983 L
F
.91903 .07983 m
.91903 .08097 L
.92017 .08097 L
.92017 .07983 L
F
.92017 .07983 m
.92017 .08097 L
.92132 .08097 L
.92132 .07983 L
F
.95219 .07983 m
.95219 .08097 L
.95333 .08097 L
.95333 .07983 L
F
.88473 .08097 m
.88473 .08211 L
.88587 .08211 L
.88587 .08097 L
F
.91674 .08097 m
.91674 .08211 L
.91789 .08211 L
.91789 .08097 L
F
.91789 .08097 m
.91789 .08211 L
.91903 .08211 L
.91903 .08097 L
F
.91903 .08097 m
.91903 .08211 L
.92017 .08211 L
.92017 .08097 L
F
.95104 .08097 m
.95104 .08211 L
.95219 .08211 L
.95219 .08097 L
F
.88359 .08211 m
.88359 .08326 L
.88473 .08326 L
.88473 .08211 L
F
.9156 .08211 m
.9156 .08326 L
.91674 .08326 L
.91674 .08211 L
F
.91674 .08211 m
.91674 .08326 L
.91789 .08326 L
.91789 .08211 L
F
.91789 .08211 m
.91789 .08326 L
.91903 .08326 L
.91903 .08211 L
F
.9499 .08211 m
.9499 .08326 L
.95104 .08326 L
.95104 .08211 L
F
.88244 .08326 m
.88244 .0844 L
.88359 .0844 L
.88359 .08326 L
F
.91446 .08326 m
.91446 .0844 L
.9156 .0844 L
.9156 .08326 L
F
.9156 .08326 m
.9156 .0844 L
.91674 .0844 L
.91674 .08326 L
F
.91674 .08326 m
.91674 .0844 L
.91789 .0844 L
.91789 .08326 L
F
.94876 .08326 m
.94876 .0844 L
.9499 .0844 L
.9499 .08326 L
F
.8813 .0844 m
.8813 .08554 L
.88244 .08554 L
.88244 .0844 L
F
.91446 .0844 m
.91446 .08554 L
.9156 .08554 L
.9156 .0844 L
F
.9156 .0844 m
.9156 .08554 L
.91674 .08554 L
.91674 .0844 L
F
.94761 .0844 m
.94761 .08554 L
.94876 .08554 L
.94876 .0844 L
F
.88016 .08554 m
.88016 .08669 L
.8813 .08669 L
.8813 .08554 L
F
.91217 .08554 m
.91217 .08669 L
.91331 .08669 L
.91331 .08554 L
F
.91331 .08554 m
.91331 .08669 L
.91446 .08669 L
.91446 .08554 L
F
.94647 .08554 m
.94647 .08669 L
.94761 .08669 L
.94761 .08554 L
F
.87901 .08669 m
.87901 .08783 L
.88016 .08783 L
.88016 .08669 L
F
.91103 .08669 m
.91103 .08783 L
.91217 .08783 L
.91217 .08669 L
F
.91217 .08669 m
.91217 .08783 L
.91331 .08783 L
.91331 .08669 L
F
.91331 .08669 m
.91331 .08783 L
.91446 .08783 L
.91446 .08669 L
F
.94533 .08669 m
.94533 .08783 L
.94647 .08783 L
.94647 .08669 L
F
.87787 .08783 m
.87787 .08897 L
.87901 .08897 L
.87901 .08783 L
F
.90988 .08783 m
.90988 .08897 L
.91103 .08897 L
.91103 .08783 L
F
.91103 .08783 m
.91103 .08897 L
.91217 .08897 L
.91217 .08783 L
F
.91217 .08783 m
.91217 .08897 L
.91331 .08897 L
.91331 .08783 L
F
.94418 .08783 m
.94418 .08897 L
.94533 .08897 L
.94533 .08783 L
F
.87673 .08897 m
.87673 .09012 L
.87787 .09012 L
.87787 .08897 L
F
.90874 .08897 m
.90874 .09012 L
.90988 .09012 L
.90988 .08897 L
F
.90988 .08897 m
.90988 .09012 L
.91103 .09012 L
.91103 .08897 L
F
.91103 .08897 m
.91103 .09012 L
.91217 .09012 L
.91217 .08897 L
F
.94304 .08897 m
.94304 .09012 L
.94418 .09012 L
.94418 .08897 L
F
.87558 .09012 m
.87558 .09126 L
.87673 .09126 L
.87673 .09012 L
F
.9076 .09012 m
.9076 .09126 L
.90874 .09126 L
.90874 .09012 L
F
.90874 .09012 m
.90874 .09126 L
.90988 .09126 L
.90988 .09012 L
F
.90988 .09012 m
.90988 .09126 L
.91103 .09126 L
.91103 .09012 L
F
.9419 .09012 m
.9419 .09126 L
.94304 .09126 L
.94304 .09012 L
F
.87444 .09126 m
.87444 .0924 L
.87558 .0924 L
.87558 .09126 L
F
.90645 .09126 m
.90645 .0924 L
.9076 .0924 L
.9076 .09126 L
F
.9076 .09126 m
.9076 .0924 L
.90874 .0924 L
.90874 .09126 L
F
.90874 .09126 m
.90874 .0924 L
.90988 .0924 L
.90988 .09126 L
F
.94075 .09126 m
.94075 .0924 L
.9419 .0924 L
.9419 .09126 L
F
.8733 .0924 m
.8733 .09355 L
.87444 .09355 L
.87444 .0924 L
F
.90531 .0924 m
.90531 .09355 L
.90645 .09355 L
.90645 .0924 L
F
.90645 .0924 m
.90645 .09355 L
.9076 .09355 L
.9076 .0924 L
F
.9076 .0924 m
.9076 .09355 L
.90874 .09355 L
.90874 .0924 L
F
.93961 .0924 m
.93961 .09355 L
.94075 .09355 L
.94075 .0924 L
F
.87215 .09355 m
.87215 .09469 L
.8733 .09469 L
.8733 .09355 L
F
.90417 .09355 m
.90417 .09469 L
.90531 .09469 L
.90531 .09355 L
F
.90531 .09355 m
.90531 .09469 L
.90645 .09469 L
.90645 .09355 L
F
.90645 .09355 m
.90645 .09469 L
.9076 .09469 L
.9076 .09355 L
F
.93847 .09355 m
.93847 .09469 L
.93961 .09469 L
.93961 .09355 L
F
.87101 .09469 m
.87101 .09583 L
.87215 .09583 L
.87215 .09469 L
F
.90302 .09469 m
.90302 .09583 L
.90417 .09583 L
.90417 .09469 L
F
.90417 .09469 m
.90417 .09583 L
.90531 .09583 L
.90531 .09469 L
F
.90531 .09469 m
.90531 .09583 L
.90645 .09583 L
.90645 .09469 L
F
.93732 .09469 m
.93732 .09583 L
.93847 .09583 L
.93847 .09469 L
F
.86987 .09583 m
.86987 .09698 L
.87101 .09698 L
.87101 .09583 L
F
.90188 .09583 m
.90188 .09698 L
.90302 .09698 L
.90302 .09583 L
F
.90302 .09583 m
.90302 .09698 L
.90417 .09698 L
.90417 .09583 L
F
.90417 .09583 m
.90417 .09698 L
.90531 .09698 L
.90531 .09583 L
F
.93618 .09583 m
.93618 .09698 L
.93732 .09698 L
.93732 .09583 L
F
.86872 .09698 m
.86872 .09812 L
.86987 .09812 L
.86987 .09698 L
F
.90074 .09698 m
.90074 .09812 L
.90188 .09812 L
.90188 .09698 L
F
.90188 .09698 m
.90188 .09812 L
.90302 .09812 L
.90302 .09698 L
F
.90302 .09698 m
.90302 .09812 L
.90417 .09812 L
.90417 .09698 L
F
.93504 .09698 m
.93504 .09812 L
.93618 .09812 L
.93618 .09698 L
F
.86758 .09812 m
.86758 .09926 L
.86872 .09926 L
.86872 .09812 L
F
.89959 .09812 m
.89959 .09926 L
.90074 .09926 L
.90074 .09812 L
F
.90074 .09812 m
.90074 .09926 L
.90188 .09926 L
.90188 .09812 L
F
.90188 .09812 m
.90188 .09926 L
.90302 .09926 L
.90302 .09812 L
F
.93389 .09812 m
.93389 .09926 L
.93504 .09926 L
.93504 .09812 L
F
.86644 .09926 m
.86644 .10041 L
.86758 .10041 L
.86758 .09926 L
F
.89845 .09926 m
.89845 .10041 L
.89959 .10041 L
.89959 .09926 L
F
.89959 .09926 m
.89959 .10041 L
.90074 .10041 L
.90074 .09926 L
F
.90074 .09926 m
.90074 .10041 L
.90188 .10041 L
.90188 .09926 L
F
.93275 .09926 m
.93275 .10041 L
.93389 .10041 L
.93389 .09926 L
F
.86529 .10041 m
.86529 .10155 L
.86644 .10155 L
.86644 .10041 L
F
.89731 .10041 m
.89731 .10155 L
.89845 .10155 L
.89845 .10041 L
F
.89845 .10041 m
.89845 .10155 L
.89959 .10155 L
.89959 .10041 L
F
.89959 .10041 m
.89959 .10155 L
.90074 .10155 L
.90074 .10041 L
F
.93161 .10041 m
.93161 .10155 L
.93275 .10155 L
.93275 .10041 L
F
.86415 .10155 m
.86415 .10269 L
.86529 .10269 L
.86529 .10155 L
F
.89616 .10155 m
.89616 .10269 L
.89731 .10269 L
.89731 .10155 L
F
.89731 .10155 m
.89731 .10269 L
.89845 .10269 L
.89845 .10155 L
F
.89845 .10155 m
.89845 .10269 L
.89959 .10269 L
.89959 .10155 L
F
.93046 .10155 m
.93046 .10269 L
.93161 .10269 L
.93161 .10155 L
F
.86301 .10269 m
.86301 .10384 L
.86415 .10384 L
.86415 .10269 L
F
.89502 .10269 m
.89502 .10384 L
.89616 .10384 L
.89616 .10269 L
F
.89616 .10269 m
.89616 .10384 L
.89731 .10384 L
.89731 .10269 L
F
.89731 .10269 m
.89731 .10384 L
.89845 .10384 L
.89845 .10269 L
F
.92932 .10269 m
.92932 .10384 L
.93046 .10384 L
.93046 .10269 L
F
.86186 .10384 m
.86186 .10498 L
.86301 .10498 L
.86301 .10384 L
F
.89388 .10384 m
.89388 .10498 L
.89502 .10498 L
.89502 .10384 L
F
.89502 .10384 m
.89502 .10498 L
.89616 .10498 L
.89616 .10384 L
F
.89616 .10384 m
.89616 .10498 L
.89731 .10498 L
.89731 .10384 L
F
.92818 .10384 m
.92818 .10498 L
.92932 .10498 L
.92932 .10384 L
F
.86072 .10498 m
.86072 .10612 L
.86186 .10612 L
.86186 .10498 L
F
.89273 .10498 m
.89273 .10612 L
.89388 .10612 L
.89388 .10498 L
F
.89388 .10498 m
.89388 .10612 L
.89502 .10612 L
.89502 .10498 L
F
.89502 .10498 m
.89502 .10612 L
.89616 .10612 L
.89616 .10498 L
F
.92703 .10498 m
.92703 .10612 L
.92818 .10612 L
.92818 .10498 L
F
.85958 .10612 m
.85958 .10727 L
.86072 .10727 L
.86072 .10612 L
F
.89159 .10612 m
.89159 .10727 L
.89273 .10727 L
.89273 .10612 L
F
.89273 .10612 m
.89273 .10727 L
.89388 .10727 L
.89388 .10612 L
F
.89388 .10612 m
.89388 .10727 L
.89502 .10727 L
.89502 .10612 L
F
.92589 .10612 m
.92589 .10727 L
.92703 .10727 L
.92703 .10612 L
F
.85843 .10727 m
.85843 .10841 L
.85958 .10841 L
.85958 .10727 L
F
.89045 .10727 m
.89045 .10841 L
.89159 .10841 L
.89159 .10727 L
F
.89159 .10727 m
.89159 .10841 L
.89273 .10841 L
.89273 .10727 L
F
.89273 .10727 m
.89273 .10841 L
.89388 .10841 L
.89388 .10727 L
F
.92475 .10727 m
.92475 .10841 L
.92589 .10841 L
.92589 .10727 L
F
.85729 .10841 m
.85729 .10955 L
.85843 .10955 L
.85843 .10841 L
F
.8893 .10841 m
.8893 .10955 L
.89045 .10955 L
.89045 .10841 L
F
.89045 .10841 m
.89045 .10955 L
.89159 .10955 L
.89159 .10841 L
F
.89159 .10841 m
.89159 .10955 L
.89273 .10955 L
.89273 .10841 L
F
.9236 .10841 m
.9236 .10955 L
.92475 .10955 L
.92475 .10841 L
F
.85615 .10955 m
.85615 .1107 L
.85729 .1107 L
.85729 .10955 L
F
.88816 .10955 m
.88816 .1107 L
.8893 .1107 L
.8893 .10955 L
F
.8893 .10955 m
.8893 .1107 L
.89045 .1107 L
.89045 .10955 L
F
.89045 .10955 m
.89045 .1107 L
.89159 .1107 L
.89159 .10955 L
F
.92246 .10955 m
.92246 .1107 L
.9236 .1107 L
.9236 .10955 L
F
.855 .1107 m
.855 .11184 L
.85615 .11184 L
.85615 .1107 L
F
.88702 .1107 m
.88702 .11184 L
.88816 .11184 L
.88816 .1107 L
F
.88816 .1107 m
.88816 .11184 L
.8893 .11184 L
.8893 .1107 L
F
.8893 .1107 m
.8893 .11184 L
.89045 .11184 L
.89045 .1107 L
F
.92132 .1107 m
.92132 .11184 L
.92246 .11184 L
.92246 .1107 L
F
.85386 .11184 m
.85386 .11298 L
.855 .11298 L
.855 .11184 L
F
.88587 .11184 m
.88587 .11298 L
.88702 .11298 L
.88702 .11184 L
F
.88702 .11184 m
.88702 .11298 L
.88816 .11298 L
.88816 .11184 L
F
.88816 .11184 m
.88816 .11298 L
.8893 .11298 L
.8893 .11184 L
F
.92017 .11184 m
.92017 .11298 L
.92132 .11298 L
.92132 .11184 L
F
.85272 .11298 m
.85272 .11413 L
.85386 .11413 L
.85386 .11298 L
F
.88473 .11298 m
.88473 .11413 L
.88587 .11413 L
.88587 .11298 L
F
.88587 .11298 m
.88587 .11413 L
.88702 .11413 L
.88702 .11298 L
F
.88702 .11298 m
.88702 .11413 L
.88816 .11413 L
.88816 .11298 L
F
.91903 .11298 m
.91903 .11413 L
.92017 .11413 L
.92017 .11298 L
F
.85157 .11413 m
.85157 .11527 L
.85272 .11527 L
.85272 .11413 L
F
.88359 .11413 m
.88359 .11527 L
.88473 .11527 L
.88473 .11413 L
F
.88473 .11413 m
.88473 .11527 L
.88587 .11527 L
.88587 .11413 L
F
.88587 .11413 m
.88587 .11527 L
.88702 .11527 L
.88702 .11413 L
F
.91789 .11413 m
.91789 .11527 L
.91903 .11527 L
.91903 .11413 L
F
.85043 .11527 m
.85043 .11641 L
.85157 .11641 L
.85157 .11527 L
F
.88244 .11527 m
.88244 .11641 L
.88359 .11641 L
.88359 .11527 L
F
.88359 .11527 m
.88359 .11641 L
.88473 .11641 L
.88473 .11527 L
F
.88473 .11527 m
.88473 .11641 L
.88587 .11641 L
.88587 .11527 L
F
.91674 .11527 m
.91674 .11641 L
.91789 .11641 L
.91789 .11527 L
F
.84929 .11641 m
.84929 .11756 L
.85043 .11756 L
.85043 .11641 L
F
.8813 .11641 m
.8813 .11756 L
.88244 .11756 L
.88244 .11641 L
F
.88244 .11641 m
.88244 .11756 L
.88359 .11756 L
.88359 .11641 L
F
.88359 .11641 m
.88359 .11756 L
.88473 .11756 L
.88473 .11641 L
F
.9156 .11641 m
.9156 .11756 L
.91674 .11756 L
.91674 .11641 L
F
.84814 .11756 m
.84814 .1187 L
.84929 .1187 L
.84929 .11756 L
F
.8813 .11756 m
.8813 .1187 L
.88244 .1187 L
.88244 .11756 L
F
.88244 .11756 m
.88244 .1187 L
.88359 .1187 L
.88359 .11756 L
F
.91446 .11756 m
.91446 .1187 L
.9156 .1187 L
.9156 .11756 L
F
.847 .1187 m
.847 .11984 L
.84814 .11984 L
.84814 .1187 L
F
.87901 .1187 m
.87901 .11984 L
.88016 .11984 L
.88016 .1187 L
F
.88016 .1187 m
.88016 .11984 L
.8813 .11984 L
.8813 .1187 L
F
.91331 .1187 m
.91331 .11984 L
.91446 .11984 L
.91446 .1187 L
F
.84586 .11984 m
.84586 .12099 L
.847 .12099 L
.847 .11984 L
F
.87787 .11984 m
.87787 .12099 L
.87901 .12099 L
.87901 .11984 L
F
.87901 .11984 m
.87901 .12099 L
.88016 .12099 L
.88016 .11984 L
F
.88016 .11984 m
.88016 .12099 L
.8813 .12099 L
.8813 .11984 L
F
.91217 .11984 m
.91217 .12099 L
.91331 .12099 L
.91331 .11984 L
F
.84471 .12099 m
.84471 .12213 L
.84586 .12213 L
.84586 .12099 L
F
.87673 .12099 m
.87673 .12213 L
.87787 .12213 L
.87787 .12099 L
F
.87787 .12099 m
.87787 .12213 L
.87901 .12213 L
.87901 .12099 L
F
.87901 .12099 m
.87901 .12213 L
.88016 .12213 L
.88016 .12099 L
F
.91103 .12099 m
.91103 .12213 L
.91217 .12213 L
.91217 .12099 L
F
.84357 .12213 m
.84357 .12327 L
.84471 .12327 L
.84471 .12213 L
F
.87558 .12213 m
.87558 .12327 L
.87673 .12327 L
.87673 .12213 L
F
.87673 .12213 m
.87673 .12327 L
.87787 .12327 L
.87787 .12213 L
F
.87787 .12213 m
.87787 .12327 L
.87901 .12327 L
.87901 .12213 L
F
.90988 .12213 m
.90988 .12327 L
.91103 .12327 L
.91103 .12213 L
F
.84243 .12327 m
.84243 .12442 L
.84357 .12442 L
.84357 .12327 L
F
.87444 .12327 m
.87444 .12442 L
.87558 .12442 L
.87558 .12327 L
F
.87558 .12327 m
.87558 .12442 L
.87673 .12442 L
.87673 .12327 L
F
.87673 .12327 m
.87673 .12442 L
.87787 .12442 L
.87787 .12327 L
F
.90874 .12327 m
.90874 .12442 L
.90988 .12442 L
.90988 .12327 L
F
.84128 .12442 m
.84128 .12556 L
.84243 .12556 L
.84243 .12442 L
F
.8733 .12442 m
.8733 .12556 L
.87444 .12556 L
.87444 .12442 L
F
.87444 .12442 m
.87444 .12556 L
.87558 .12556 L
.87558 .12442 L
F
.87558 .12442 m
.87558 .12556 L
.87673 .12556 L
.87673 .12442 L
F
.9076 .12442 m
.9076 .12556 L
.90874 .12556 L
.90874 .12442 L
F
.84014 .12556 m
.84014 .1267 L
.84128 .1267 L
.84128 .12556 L
F
.87215 .12556 m
.87215 .1267 L
.8733 .1267 L
.8733 .12556 L
F
.8733 .12556 m
.8733 .1267 L
.87444 .1267 L
.87444 .12556 L
F
.87444 .12556 m
.87444 .1267 L
.87558 .1267 L
.87558 .12556 L
F
.90645 .12556 m
.90645 .1267 L
.9076 .1267 L
.9076 .12556 L
F
.839 .1267 m
.839 .12785 L
.84014 .12785 L
.84014 .1267 L
F
.87101 .1267 m
.87101 .12785 L
.87215 .12785 L
.87215 .1267 L
F
.87215 .1267 m
.87215 .12785 L
.8733 .12785 L
.8733 .1267 L
F
.8733 .1267 m
.8733 .12785 L
.87444 .12785 L
.87444 .1267 L
F
.90531 .1267 m
.90531 .12785 L
.90645 .12785 L
.90645 .1267 L
F
.83785 .12785 m
.83785 .12899 L
.839 .12899 L
.839 .12785 L
F
.86987 .12785 m
.86987 .12899 L
.87101 .12899 L
.87101 .12785 L
F
.87101 .12785 m
.87101 .12899 L
.87215 .12899 L
.87215 .12785 L
F
.87215 .12785 m
.87215 .12899 L
.8733 .12899 L
.8733 .12785 L
F
.90417 .12785 m
.90417 .12899 L
.90531 .12899 L
.90531 .12785 L
F
.83671 .12899 m
.83671 .13013 L
.83785 .13013 L
.83785 .12899 L
F
.86872 .12899 m
.86872 .13013 L
.86987 .13013 L
.86987 .12899 L
F
.86987 .12899 m
.86987 .13013 L
.87101 .13013 L
.87101 .12899 L
F
.87101 .12899 m
.87101 .13013 L
.87215 .13013 L
.87215 .12899 L
F
.90302 .12899 m
.90302 .13013 L
.90417 .13013 L
.90417 .12899 L
F
.83557 .13013 m
.83557 .13128 L
.83671 .13128 L
.83671 .13013 L
F
.86758 .13013 m
.86758 .13128 L
.86872 .13128 L
.86872 .13013 L
F
.86872 .13013 m
.86872 .13128 L
.86987 .13128 L
.86987 .13013 L
F
.86987 .13013 m
.86987 .13128 L
.87101 .13128 L
.87101 .13013 L
F
.90188 .13013 m
.90188 .13128 L
.90302 .13128 L
.90302 .13013 L
F
.83442 .13128 m
.83442 .13242 L
.83557 .13242 L
.83557 .13128 L
F
.86644 .13128 m
.86644 .13242 L
.86758 .13242 L
.86758 .13128 L
F
.86758 .13128 m
.86758 .13242 L
.86872 .13242 L
.86872 .13128 L
F
.86872 .13128 m
.86872 .13242 L
.86987 .13242 L
.86987 .13128 L
F
.90074 .13128 m
.90074 .13242 L
.90188 .13242 L
.90188 .13128 L
F
.83328 .13242 m
.83328 .13356 L
.83442 .13356 L
.83442 .13242 L
F
.86529 .13242 m
.86529 .13356 L
.86644 .13356 L
.86644 .13242 L
F
.86644 .13242 m
.86644 .13356 L
.86758 .13356 L
.86758 .13242 L
F
.86758 .13242 m
.86758 .13356 L
.86872 .13356 L
.86872 .13242 L
F
.89959 .13242 m
.89959 .13356 L
.90074 .13356 L
.90074 .13242 L
F
.83214 .13356 m
.83214 .13471 L
.83328 .13471 L
.83328 .13356 L
F
.86415 .13356 m
.86415 .13471 L
.86529 .13471 L
.86529 .13356 L
F
.86529 .13356 m
.86529 .13471 L
.86644 .13471 L
.86644 .13356 L
F
.86644 .13356 m
.86644 .13471 L
.86758 .13471 L
.86758 .13356 L
F
.89845 .13356 m
.89845 .13471 L
.89959 .13471 L
.89959 .13356 L
F
.83099 .13471 m
.83099 .13585 L
.83214 .13585 L
.83214 .13471 L
F
.86301 .13471 m
.86301 .13585 L
.86415 .13585 L
.86415 .13471 L
F
.86415 .13471 m
.86415 .13585 L
.86529 .13585 L
.86529 .13471 L
F
.86529 .13471 m
.86529 .13585 L
.86644 .13585 L
.86644 .13471 L
F
.89731 .13471 m
.89731 .13585 L
.89845 .13585 L
.89845 .13471 L
F
.82985 .13585 m
.82985 .13699 L
.83099 .13699 L
.83099 .13585 L
F
.86186 .13585 m
.86186 .13699 L
.86301 .13699 L
.86301 .13585 L
F
.86301 .13585 m
.86301 .13699 L
.86415 .13699 L
.86415 .13585 L
F
.86415 .13585 m
.86415 .13699 L
.86529 .13699 L
.86529 .13585 L
F
.89616 .13585 m
.89616 .13699 L
.89731 .13699 L
.89731 .13585 L
F
.82871 .13699 m
.82871 .13814 L
.82985 .13814 L
.82985 .13699 L
F
.86072 .13699 m
.86072 .13814 L
.86186 .13814 L
.86186 .13699 L
F
.86186 .13699 m
.86186 .13814 L
.86301 .13814 L
.86301 .13699 L
F
.86301 .13699 m
.86301 .13814 L
.86415 .13814 L
.86415 .13699 L
F
.89502 .13699 m
.89502 .13814 L
.89616 .13814 L
.89616 .13699 L
F
.82756 .13814 m
.82756 .13928 L
.82871 .13928 L
.82871 .13814 L
F
.85958 .13814 m
.85958 .13928 L
.86072 .13928 L
.86072 .13814 L
F
.86072 .13814 m
.86072 .13928 L
.86186 .13928 L
.86186 .13814 L
F
.86186 .13814 m
.86186 .13928 L
.86301 .13928 L
.86301 .13814 L
F
.89388 .13814 m
.89388 .13928 L
.89502 .13928 L
.89502 .13814 L
F
.82642 .13928 m
.82642 .14042 L
.82756 .14042 L
.82756 .13928 L
F
.85843 .13928 m
.85843 .14042 L
.85958 .14042 L
.85958 .13928 L
F
.85958 .13928 m
.85958 .14042 L
.86072 .14042 L
.86072 .13928 L
F
.86072 .13928 m
.86072 .14042 L
.86186 .14042 L
.86186 .13928 L
F
.89273 .13928 m
.89273 .14042 L
.89388 .14042 L
.89388 .13928 L
F
.82528 .14042 m
.82528 .14157 L
.82642 .14157 L
.82642 .14042 L
F
.85729 .14042 m
.85729 .14157 L
.85843 .14157 L
.85843 .14042 L
F
.85843 .14042 m
.85843 .14157 L
.85958 .14157 L
.85958 .14042 L
F
.85958 .14042 m
.85958 .14157 L
.86072 .14157 L
.86072 .14042 L
F
.89159 .14042 m
.89159 .14157 L
.89273 .14157 L
.89273 .14042 L
F
.82413 .14157 m
.82413 .14271 L
.82528 .14271 L
.82528 .14157 L
F
.85615 .14157 m
.85615 .14271 L
.85729 .14271 L
.85729 .14157 L
F
.85729 .14157 m
.85729 .14271 L
.85843 .14271 L
.85843 .14157 L
F
.85843 .14157 m
.85843 .14271 L
.85958 .14271 L
.85958 .14157 L
F
.89045 .14157 m
.89045 .14271 L
.89159 .14271 L
.89159 .14157 L
F
.82299 .14271 m
.82299 .14385 L
.82413 .14385 L
.82413 .14271 L
F
.855 .14271 m
.855 .14385 L
.85615 .14385 L
.85615 .14271 L
F
.85615 .14271 m
.85615 .14385 L
.85729 .14385 L
.85729 .14271 L
F
.85729 .14271 m
.85729 .14385 L
.85843 .14385 L
.85843 .14271 L
F
.8893 .14271 m
.8893 .14385 L
.89045 .14385 L
.89045 .14271 L
F
.82185 .14385 m
.82185 .145 L
.82299 .145 L
.82299 .14385 L
F
.85386 .14385 m
.85386 .145 L
.855 .145 L
.855 .14385 L
F
.855 .14385 m
.855 .145 L
.85615 .145 L
.85615 .14385 L
F
.85615 .14385 m
.85615 .145 L
.85729 .145 L
.85729 .14385 L
F
.88816 .14385 m
.88816 .145 L
.8893 .145 L
.8893 .14385 L
F
.8207 .145 m
.8207 .14614 L
.82185 .14614 L
.82185 .145 L
F
.85272 .145 m
.85272 .14614 L
.85386 .14614 L
.85386 .145 L
F
.85386 .145 m
.85386 .14614 L
.855 .14614 L
.855 .145 L
F
.855 .145 m
.855 .14614 L
.85615 .14614 L
.85615 .145 L
F
.88702 .145 m
.88702 .14614 L
.88816 .14614 L
.88816 .145 L
F
.81956 .14614 m
.81956 .14728 L
.8207 .14728 L
.8207 .14614 L
F
.85157 .14614 m
.85157 .14728 L
.85272 .14728 L
.85272 .14614 L
F
.85272 .14614 m
.85272 .14728 L
.85386 .14728 L
.85386 .14614 L
F
.85386 .14614 m
.85386 .14728 L
.855 .14728 L
.855 .14614 L
F
.88587 .14614 m
.88587 .14728 L
.88702 .14728 L
.88702 .14614 L
F
.81842 .14728 m
.81842 .14843 L
.81956 .14843 L
.81956 .14728 L
F
.85043 .14728 m
.85043 .14843 L
.85157 .14843 L
.85157 .14728 L
F
.85157 .14728 m
.85157 .14843 L
.85272 .14843 L
.85272 .14728 L
F
.85272 .14728 m
.85272 .14843 L
.85386 .14843 L
.85386 .14728 L
F
.88473 .14728 m
.88473 .14843 L
.88587 .14843 L
.88587 .14728 L
F
.81727 .14843 m
.81727 .14957 L
.81842 .14957 L
.81842 .14843 L
F
.84929 .14843 m
.84929 .14957 L
.85043 .14957 L
.85043 .14843 L
F
.85043 .14843 m
.85043 .14957 L
.85157 .14957 L
.85157 .14843 L
F
.85157 .14843 m
.85157 .14957 L
.85272 .14957 L
.85272 .14843 L
F
.88359 .14843 m
.88359 .14957 L
.88473 .14957 L
.88473 .14843 L
F
.81613 .14957 m
.81613 .15071 L
.81727 .15071 L
.81727 .14957 L
F
.84814 .14957 m
.84814 .15071 L
.84929 .15071 L
.84929 .14957 L
F
.84929 .14957 m
.84929 .15071 L
.85043 .15071 L
.85043 .14957 L
F
.85043 .14957 m
.85043 .15071 L
.85157 .15071 L
.85157 .14957 L
F
.88244 .14957 m
.88244 .15071 L
.88359 .15071 L
.88359 .14957 L
F
.81499 .15071 m
.81499 .15186 L
.81613 .15186 L
.81613 .15071 L
F
.84814 .15071 m
.84814 .15186 L
.84929 .15186 L
.84929 .15071 L
F
.84929 .15071 m
.84929 .15186 L
.85043 .15186 L
.85043 .15071 L
F
.8813 .15071 m
.8813 .15186 L
.88244 .15186 L
.88244 .15071 L
F
.81384 .15186 m
.81384 .153 L
.81499 .153 L
.81499 .15186 L
F
.84586 .15186 m
.84586 .153 L
.847 .153 L
.847 .15186 L
F
.847 .15186 m
.847 .153 L
.84814 .153 L
.84814 .15186 L
F
.88016 .15186 m
.88016 .153 L
.8813 .153 L
.8813 .15186 L
F
.8127 .153 m
.8127 .15414 L
.81384 .15414 L
.81384 .153 L
F
.84471 .153 m
.84471 .15414 L
.84586 .15414 L
.84586 .153 L
F
.84586 .153 m
.84586 .15414 L
.847 .15414 L
.847 .153 L
F
.847 .153 m
.847 .15414 L
.84814 .15414 L
.84814 .153 L
F
.87901 .153 m
.87901 .15414 L
.88016 .15414 L
.88016 .153 L
F
.81156 .15414 m
.81156 .15529 L
.8127 .15529 L
.8127 .15414 L
F
.84357 .15414 m
.84357 .15529 L
.84471 .15529 L
.84471 .15414 L
F
.84471 .15414 m
.84471 .15529 L
.84586 .15529 L
.84586 .15414 L
F
.84586 .15414 m
.84586 .15529 L
.847 .15529 L
.847 .15414 L
F
.87787 .15414 m
.87787 .15529 L
.87901 .15529 L
.87901 .15414 L
F
.81041 .15529 m
.81041 .15643 L
.81156 .15643 L
.81156 .15529 L
F
.84243 .15529 m
.84243 .15643 L
.84357 .15643 L
.84357 .15529 L
F
.84357 .15529 m
.84357 .15643 L
.84471 .15643 L
.84471 .15529 L
F
.84471 .15529 m
.84471 .15643 L
.84586 .15643 L
.84586 .15529 L
F
.87673 .15529 m
.87673 .15643 L
.87787 .15643 L
.87787 .15529 L
F
.80927 .15643 m
.80927 .15757 L
.81041 .15757 L
.81041 .15643 L
F
.84128 .15643 m
.84128 .15757 L
.84243 .15757 L
.84243 .15643 L
F
.84243 .15643 m
.84243 .15757 L
.84357 .15757 L
.84357 .15643 L
F
.84357 .15643 m
.84357 .15757 L
.84471 .15757 L
.84471 .15643 L
F
.87558 .15643 m
.87558 .15757 L
.87673 .15757 L
.87673 .15643 L
F
.80813 .15757 m
.80813 .15872 L
.80927 .15872 L
.80927 .15757 L
F
.84014 .15757 m
.84014 .15872 L
.84128 .15872 L
.84128 .15757 L
F
.84128 .15757 m
.84128 .15872 L
.84243 .15872 L
.84243 .15757 L
F
.84243 .15757 m
.84243 .15872 L
.84357 .15872 L
.84357 .15757 L
F
.87444 .15757 m
.87444 .15872 L
.87558 .15872 L
.87558 .15757 L
F
.80698 .15872 m
.80698 .15986 L
.80813 .15986 L
.80813 .15872 L
F
.839 .15872 m
.839 .15986 L
.84014 .15986 L
.84014 .15872 L
F
.84014 .15872 m
.84014 .15986 L
.84128 .15986 L
.84128 .15872 L
F
.84128 .15872 m
.84128 .15986 L
.84243 .15986 L
.84243 .15872 L
F
.8733 .15872 m
.8733 .15986 L
.87444 .15986 L
.87444 .15872 L
F
.80584 .15986 m
.80584 .161 L
.80698 .161 L
.80698 .15986 L
F
.83785 .15986 m
.83785 .161 L
.839 .161 L
.839 .15986 L
F
.839 .15986 m
.839 .161 L
.84014 .161 L
.84014 .15986 L
F
.84014 .15986 m
.84014 .161 L
.84128 .161 L
.84128 .15986 L
F
.87215 .15986 m
.87215 .161 L
.8733 .161 L
.8733 .15986 L
F
.8047 .161 m
.8047 .16215 L
.80584 .16215 L
.80584 .161 L
F
.83671 .161 m
.83671 .16215 L
.83785 .16215 L
.83785 .161 L
F
.83785 .161 m
.83785 .16215 L
.839 .16215 L
.839 .161 L
F
.839 .161 m
.839 .16215 L
.84014 .16215 L
.84014 .161 L
F
.87101 .161 m
.87101 .16215 L
.87215 .16215 L
.87215 .161 L
F
.80355 .16215 m
.80355 .16329 L
.8047 .16329 L
.8047 .16215 L
F
.83557 .16215 m
.83557 .16329 L
.83671 .16329 L
.83671 .16215 L
F
.83671 .16215 m
.83671 .16329 L
.83785 .16329 L
.83785 .16215 L
F
.83785 .16215 m
.83785 .16329 L
.839 .16329 L
.839 .16215 L
F
.86987 .16215 m
.86987 .16329 L
.87101 .16329 L
.87101 .16215 L
F
.80241 .16329 m
.80241 .16443 L
.80355 .16443 L
.80355 .16329 L
F
.83442 .16329 m
.83442 .16443 L
.83557 .16443 L
.83557 .16329 L
F
.83557 .16329 m
.83557 .16443 L
.83671 .16443 L
.83671 .16329 L
F
.83671 .16329 m
.83671 .16443 L
.83785 .16443 L
.83785 .16329 L
F
.86872 .16329 m
.86872 .16443 L
.86987 .16443 L
.86987 .16329 L
F
.80127 .16443 m
.80127 .16558 L
.80241 .16558 L
.80241 .16443 L
F
.83328 .16443 m
.83328 .16558 L
.83442 .16558 L
.83442 .16443 L
F
.83442 .16443 m
.83442 .16558 L
.83557 .16558 L
.83557 .16443 L
F
.83557 .16443 m
.83557 .16558 L
.83671 .16558 L
.83671 .16443 L
F
.86758 .16443 m
.86758 .16558 L
.86872 .16558 L
.86872 .16443 L
F
.80012 .16558 m
.80012 .16672 L
.80127 .16672 L
.80127 .16558 L
F
.83214 .16558 m
.83214 .16672 L
.83328 .16672 L
.83328 .16558 L
F
.83328 .16558 m
.83328 .16672 L
.83442 .16672 L
.83442 .16558 L
F
.83442 .16558 m
.83442 .16672 L
.83557 .16672 L
.83557 .16558 L
F
.86644 .16558 m
.86644 .16672 L
.86758 .16672 L
.86758 .16558 L
F
.79898 .16672 m
.79898 .16786 L
.80012 .16786 L
.80012 .16672 L
F
.83099 .16672 m
.83099 .16786 L
.83214 .16786 L
.83214 .16672 L
F
.83214 .16672 m
.83214 .16786 L
.83328 .16786 L
.83328 .16672 L
F
.83328 .16672 m
.83328 .16786 L
.83442 .16786 L
.83442 .16672 L
F
.86529 .16672 m
.86529 .16786 L
.86644 .16786 L
.86644 .16672 L
F
.79784 .16786 m
.79784 .16901 L
.79898 .16901 L
.79898 .16786 L
F
.82985 .16786 m
.82985 .16901 L
.83099 .16901 L
.83099 .16786 L
F
.83099 .16786 m
.83099 .16901 L
.83214 .16901 L
.83214 .16786 L
F
.83214 .16786 m
.83214 .16901 L
.83328 .16901 L
.83328 .16786 L
F
.86415 .16786 m
.86415 .16901 L
.86529 .16901 L
.86529 .16786 L
F
.79669 .16901 m
.79669 .17015 L
.79784 .17015 L
.79784 .16901 L
F
.82871 .16901 m
.82871 .17015 L
.82985 .17015 L
.82985 .16901 L
F
.82985 .16901 m
.82985 .17015 L
.83099 .17015 L
.83099 .16901 L
F
.83099 .16901 m
.83099 .17015 L
.83214 .17015 L
.83214 .16901 L
F
.86301 .16901 m
.86301 .17015 L
.86415 .17015 L
.86415 .16901 L
F
.79555 .17015 m
.79555 .17129 L
.79669 .17129 L
.79669 .17015 L
F
.82756 .17015 m
.82756 .17129 L
.82871 .17129 L
.82871 .17015 L
F
.82871 .17015 m
.82871 .17129 L
.82985 .17129 L
.82985 .17015 L
F
.82985 .17015 m
.82985 .17129 L
.83099 .17129 L
.83099 .17015 L
F
.86186 .17015 m
.86186 .17129 L
.86301 .17129 L
.86301 .17015 L
F
.79441 .17129 m
.79441 .17244 L
.79555 .17244 L
.79555 .17129 L
F
.82642 .17129 m
.82642 .17244 L
.82756 .17244 L
.82756 .17129 L
F
.82756 .17129 m
.82756 .17244 L
.82871 .17244 L
.82871 .17129 L
F
.82871 .17129 m
.82871 .17244 L
.82985 .17244 L
.82985 .17129 L
F
.86072 .17129 m
.86072 .17244 L
.86186 .17244 L
.86186 .17129 L
F
.79326 .17244 m
.79326 .17358 L
.79441 .17358 L
.79441 .17244 L
F
.82528 .17244 m
.82528 .17358 L
.82642 .17358 L
.82642 .17244 L
F
.82642 .17244 m
.82642 .17358 L
.82756 .17358 L
.82756 .17244 L
F
.82756 .17244 m
.82756 .17358 L
.82871 .17358 L
.82871 .17244 L
F
.85958 .17244 m
.85958 .17358 L
.86072 .17358 L
.86072 .17244 L
F
.79212 .17358 m
.79212 .17472 L
.79326 .17472 L
.79326 .17358 L
F
.82413 .17358 m
.82413 .17472 L
.82528 .17472 L
.82528 .17358 L
F
.82528 .17358 m
.82528 .17472 L
.82642 .17472 L
.82642 .17358 L
F
.82642 .17358 m
.82642 .17472 L
.82756 .17472 L
.82756 .17358 L
F
.85843 .17358 m
.85843 .17472 L
.85958 .17472 L
.85958 .17358 L
F
.79098 .17472 m
.79098 .17587 L
.79212 .17587 L
.79212 .17472 L
F
.82299 .17472 m
.82299 .17587 L
.82413 .17587 L
.82413 .17472 L
F
.82413 .17472 m
.82413 .17587 L
.82528 .17587 L
.82528 .17472 L
F
.82528 .17472 m
.82528 .17587 L
.82642 .17587 L
.82642 .17472 L
F
.85729 .17472 m
.85729 .17587 L
.85843 .17587 L
.85843 .17472 L
F
.78983 .17587 m
.78983 .17701 L
.79098 .17701 L
.79098 .17587 L
F
.82185 .17587 m
.82185 .17701 L
.82299 .17701 L
.82299 .17587 L
F
.82299 .17587 m
.82299 .17701 L
.82413 .17701 L
.82413 .17587 L
F
.82413 .17587 m
.82413 .17701 L
.82528 .17701 L
.82528 .17587 L
F
.85615 .17587 m
.85615 .17701 L
.85729 .17701 L
.85729 .17587 L
F
.78869 .17701 m
.78869 .17815 L
.78983 .17815 L
.78983 .17701 L
F
.8207 .17701 m
.8207 .17815 L
.82185 .17815 L
.82185 .17701 L
F
.82185 .17701 m
.82185 .17815 L
.82299 .17815 L
.82299 .17701 L
F
.82299 .17701 m
.82299 .17815 L
.82413 .17815 L
.82413 .17701 L
F
.855 .17701 m
.855 .17815 L
.85615 .17815 L
.85615 .17701 L
F
.78755 .17815 m
.78755 .1793 L
.78869 .1793 L
.78869 .17815 L
F
.81956 .17815 m
.81956 .1793 L
.8207 .1793 L
.8207 .17815 L
F
.8207 .17815 m
.8207 .1793 L
.82185 .1793 L
.82185 .17815 L
F
.82185 .17815 m
.82185 .1793 L
.82299 .1793 L
.82299 .17815 L
F
.85386 .17815 m
.85386 .1793 L
.855 .1793 L
.855 .17815 L
F
.7864 .1793 m
.7864 .18044 L
.78755 .18044 L
.78755 .1793 L
F
.81842 .1793 m
.81842 .18044 L
.81956 .18044 L
.81956 .1793 L
F
.81956 .1793 m
.81956 .18044 L
.8207 .18044 L
.8207 .1793 L
F
.8207 .1793 m
.8207 .18044 L
.82185 .18044 L
.82185 .1793 L
F
.85272 .1793 m
.85272 .18044 L
.85386 .18044 L
.85386 .1793 L
F
.78526 .18044 m
.78526 .18158 L
.7864 .18158 L
.7864 .18044 L
F
.81727 .18044 m
.81727 .18158 L
.81842 .18158 L
.81842 .18044 L
F
.81842 .18044 m
.81842 .18158 L
.81956 .18158 L
.81956 .18044 L
F
.81956 .18044 m
.81956 .18158 L
.8207 .18158 L
.8207 .18044 L
F
.85157 .18044 m
.85157 .18158 L
.85272 .18158 L
.85272 .18044 L
F
.78412 .18158 m
.78412 .18273 L
.78526 .18273 L
.78526 .18158 L
F
.81613 .18158 m
.81613 .18273 L
.81727 .18273 L
.81727 .18158 L
F
.81727 .18158 m
.81727 .18273 L
.81842 .18273 L
.81842 .18158 L
F
.81842 .18158 m
.81842 .18273 L
.81956 .18273 L
.81956 .18158 L
F
.85043 .18158 m
.85043 .18273 L
.85157 .18273 L
.85157 .18158 L
F
.78297 .18273 m
.78297 .18387 L
.78412 .18387 L
.78412 .18273 L
F
.81499 .18273 m
.81499 .18387 L
.81613 .18387 L
.81613 .18273 L
F
.81613 .18273 m
.81613 .18387 L
.81727 .18387 L
.81727 .18273 L
F
.81727 .18273 m
.81727 .18387 L
.81842 .18387 L
.81842 .18273 L
F
.84929 .18273 m
.84929 .18387 L
.85043 .18387 L
.85043 .18273 L
F
.78183 .18387 m
.78183 .18501 L
.78297 .18501 L
.78297 .18387 L
F
.81499 .18387 m
.81499 .18501 L
.81613 .18501 L
.81613 .18387 L
F
.81613 .18387 m
.81613 .18501 L
.81727 .18501 L
.81727 .18387 L
F
.84814 .18387 m
.84814 .18501 L
.84929 .18501 L
.84929 .18387 L
F
.78069 .18501 m
.78069 .18616 L
.78183 .18616 L
.78183 .18501 L
F
.8127 .18501 m
.8127 .18616 L
.81384 .18616 L
.81384 .18501 L
F
.81384 .18501 m
.81384 .18616 L
.81499 .18616 L
.81499 .18501 L
F
.847 .18501 m
.847 .18616 L
.84814 .18616 L
.84814 .18501 L
F
.77954 .18616 m
.77954 .1873 L
.78069 .1873 L
.78069 .18616 L
F
.81156 .18616 m
.81156 .1873 L
.8127 .1873 L
.8127 .18616 L
F
.8127 .18616 m
.8127 .1873 L
.81384 .1873 L
.81384 .18616 L
F
.81384 .18616 m
.81384 .1873 L
.81499 .1873 L
.81499 .18616 L
F
.84586 .18616 m
.84586 .1873 L
.847 .1873 L
.847 .18616 L
F
.7784 .1873 m
.7784 .18844 L
.77954 .18844 L
.77954 .1873 L
F
.81041 .1873 m
.81041 .18844 L
.81156 .18844 L
.81156 .1873 L
F
.81156 .1873 m
.81156 .18844 L
.8127 .18844 L
.8127 .1873 L
F
.8127 .1873 m
.8127 .18844 L
.81384 .18844 L
.81384 .1873 L
F
.84471 .1873 m
.84471 .18844 L
.84586 .18844 L
.84586 .1873 L
F
.77726 .18844 m
.77726 .18959 L
.7784 .18959 L
.7784 .18844 L
F
.80927 .18844 m
.80927 .18959 L
.81041 .18959 L
.81041 .18844 L
F
.81041 .18844 m
.81041 .18959 L
.81156 .18959 L
.81156 .18844 L
F
.81156 .18844 m
.81156 .18959 L
.8127 .18959 L
.8127 .18844 L
F
.84357 .18844 m
.84357 .18959 L
.84471 .18959 L
.84471 .18844 L
F
.77611 .18959 m
.77611 .19073 L
.77726 .19073 L
.77726 .18959 L
F
.80813 .18959 m
.80813 .19073 L
.80927 .19073 L
.80927 .18959 L
F
.80927 .18959 m
.80927 .19073 L
.81041 .19073 L
.81041 .18959 L
F
.81041 .18959 m
.81041 .19073 L
.81156 .19073 L
.81156 .18959 L
F
.84243 .18959 m
.84243 .19073 L
.84357 .19073 L
.84357 .18959 L
F
.77497 .19073 m
.77497 .19187 L
.77611 .19187 L
.77611 .19073 L
F
.80698 .19073 m
.80698 .19187 L
.80813 .19187 L
.80813 .19073 L
F
.80813 .19073 m
.80813 .19187 L
.80927 .19187 L
.80927 .19073 L
F
.80927 .19073 m
.80927 .19187 L
.81041 .19187 L
.81041 .19073 L
F
.84128 .19073 m
.84128 .19187 L
.84243 .19187 L
.84243 .19073 L
F
.77383 .19187 m
.77383 .19302 L
.77497 .19302 L
.77497 .19187 L
F
.80584 .19187 m
.80584 .19302 L
.80698 .19302 L
.80698 .19187 L
F
.80698 .19187 m
.80698 .19302 L
.80813 .19302 L
.80813 .19187 L
F
.80813 .19187 m
.80813 .19302 L
.80927 .19302 L
.80927 .19187 L
F
.84014 .19187 m
.84014 .19302 L
.84128 .19302 L
.84128 .19187 L
F
.77268 .19302 m
.77268 .19416 L
.77383 .19416 L
.77383 .19302 L
F
.8047 .19302 m
.8047 .19416 L
.80584 .19416 L
.80584 .19302 L
F
.80584 .19302 m
.80584 .19416 L
.80698 .19416 L
.80698 .19302 L
F
.80698 .19302 m
.80698 .19416 L
.80813 .19416 L
.80813 .19302 L
F
.839 .19302 m
.839 .19416 L
.84014 .19416 L
.84014 .19302 L
F
.77154 .19416 m
.77154 .1953 L
.77268 .1953 L
.77268 .19416 L
F
.80355 .19416 m
.80355 .1953 L
.8047 .1953 L
.8047 .19416 L
F
.8047 .19416 m
.8047 .1953 L
.80584 .1953 L
.80584 .19416 L
F
.80584 .19416 m
.80584 .1953 L
.80698 .1953 L
.80698 .19416 L
F
.83785 .19416 m
.83785 .1953 L
.839 .1953 L
.839 .19416 L
F
.7704 .1953 m
.7704 .19645 L
.77154 .19645 L
.77154 .1953 L
F
.80241 .1953 m
.80241 .19645 L
.80355 .19645 L
.80355 .1953 L
F
.80355 .1953 m
.80355 .19645 L
.8047 .19645 L
.8047 .1953 L
F
.8047 .1953 m
.8047 .19645 L
.80584 .19645 L
.80584 .1953 L
F
.83671 .1953 m
.83671 .19645 L
.83785 .19645 L
.83785 .1953 L
F
.76925 .19645 m
.76925 .19759 L
.7704 .19759 L
.7704 .19645 L
F
.80127 .19645 m
.80127 .19759 L
.80241 .19759 L
.80241 .19645 L
F
.80241 .19645 m
.80241 .19759 L
.80355 .19759 L
.80355 .19645 L
F
.80355 .19645 m
.80355 .19759 L
.8047 .19759 L
.8047 .19645 L
F
.83557 .19645 m
.83557 .19759 L
.83671 .19759 L
.83671 .19645 L
F
.76811 .19759 m
.76811 .19873 L
.76925 .19873 L
.76925 .19759 L
F
.80012 .19759 m
.80012 .19873 L
.80127 .19873 L
.80127 .19759 L
F
.80127 .19759 m
.80127 .19873 L
.80241 .19873 L
.80241 .19759 L
F
.80241 .19759 m
.80241 .19873 L
.80355 .19873 L
.80355 .19759 L
F
.83442 .19759 m
.83442 .19873 L
.83557 .19873 L
.83557 .19759 L
F
.76697 .19873 m
.76697 .19988 L
.76811 .19988 L
.76811 .19873 L
F
.79898 .19873 m
.79898 .19988 L
.80012 .19988 L
.80012 .19873 L
F
.80012 .19873 m
.80012 .19988 L
.80127 .19988 L
.80127 .19873 L
F
.80127 .19873 m
.80127 .19988 L
.80241 .19988 L
.80241 .19873 L
F
.83328 .19873 m
.83328 .19988 L
.83442 .19988 L
.83442 .19873 L
F
.76582 .19988 m
.76582 .20102 L
.76697 .20102 L
.76697 .19988 L
F
.79784 .19988 m
.79784 .20102 L
.79898 .20102 L
.79898 .19988 L
F
.79898 .19988 m
.79898 .20102 L
.80012 .20102 L
.80012 .19988 L
F
.80012 .19988 m
.80012 .20102 L
.80127 .20102 L
.80127 .19988 L
F
.83214 .19988 m
.83214 .20102 L
.83328 .20102 L
.83328 .19988 L
F
.76468 .20102 m
.76468 .20216 L
.76582 .20216 L
.76582 .20102 L
F
.79669 .20102 m
.79669 .20216 L
.79784 .20216 L
.79784 .20102 L
F
.79784 .20102 m
.79784 .20216 L
.79898 .20216 L
.79898 .20102 L
F
.79898 .20102 m
.79898 .20216 L
.80012 .20216 L
.80012 .20102 L
F
.83099 .20102 m
.83099 .20216 L
.83214 .20216 L
.83214 .20102 L
F
.76354 .20216 m
.76354 .20331 L
.76468 .20331 L
.76468 .20216 L
F
.79555 .20216 m
.79555 .20331 L
.79669 .20331 L
.79669 .20216 L
F
.79669 .20216 m
.79669 .20331 L
.79784 .20331 L
.79784 .20216 L
F
.79784 .20216 m
.79784 .20331 L
.79898 .20331 L
.79898 .20216 L
F
.82985 .20216 m
.82985 .20331 L
.83099 .20331 L
.83099 .20216 L
F
.76239 .20331 m
.76239 .20445 L
.76354 .20445 L
.76354 .20331 L
F
.79441 .20331 m
.79441 .20445 L
.79555 .20445 L
.79555 .20331 L
F
.79555 .20331 m
.79555 .20445 L
.79669 .20445 L
.79669 .20331 L
F
.79669 .20331 m
.79669 .20445 L
.79784 .20445 L
.79784 .20331 L
F
.82871 .20331 m
.82871 .20445 L
.82985 .20445 L
.82985 .20331 L
F
.76125 .20445 m
.76125 .20559 L
.76239 .20559 L
.76239 .20445 L
F
.79326 .20445 m
.79326 .20559 L
.79441 .20559 L
.79441 .20445 L
F
.79441 .20445 m
.79441 .20559 L
.79555 .20559 L
.79555 .20445 L
F
.79555 .20445 m
.79555 .20559 L
.79669 .20559 L
.79669 .20445 L
F
.82756 .20445 m
.82756 .20559 L
.82871 .20559 L
.82871 .20445 L
F
.76011 .20559 m
.76011 .20674 L
.76125 .20674 L
.76125 .20559 L
F
.79212 .20559 m
.79212 .20674 L
.79326 .20674 L
.79326 .20559 L
F
.79326 .20559 m
.79326 .20674 L
.79441 .20674 L
.79441 .20559 L
F
.79441 .20559 m
.79441 .20674 L
.79555 .20674 L
.79555 .20559 L
F
.82642 .20559 m
.82642 .20674 L
.82756 .20674 L
.82756 .20559 L
F
.75896 .20674 m
.75896 .20788 L
.76011 .20788 L
.76011 .20674 L
F
.79098 .20674 m
.79098 .20788 L
.79212 .20788 L
.79212 .20674 L
F
.79212 .20674 m
.79212 .20788 L
.79326 .20788 L
.79326 .20674 L
F
.79326 .20674 m
.79326 .20788 L
.79441 .20788 L
.79441 .20674 L
F
.82528 .20674 m
.82528 .20788 L
.82642 .20788 L
.82642 .20674 L
F
.75782 .20788 m
.75782 .20902 L
.75896 .20902 L
.75896 .20788 L
F
.78983 .20788 m
.78983 .20902 L
.79098 .20902 L
.79098 .20788 L
F
.79098 .20788 m
.79098 .20902 L
.79212 .20902 L
.79212 .20788 L
F
.79212 .20788 m
.79212 .20902 L
.79326 .20902 L
.79326 .20788 L
F
.82413 .20788 m
.82413 .20902 L
.82528 .20902 L
.82528 .20788 L
F
.75668 .20902 m
.75668 .21017 L
.75782 .21017 L
.75782 .20902 L
F
.78869 .20902 m
.78869 .21017 L
.78983 .21017 L
.78983 .20902 L
F
.78983 .20902 m
.78983 .21017 L
.79098 .21017 L
.79098 .20902 L
F
.79098 .20902 m
.79098 .21017 L
.79212 .21017 L
.79212 .20902 L
F
.82299 .20902 m
.82299 .21017 L
.82413 .21017 L
.82413 .20902 L
F
.75553 .21017 m
.75553 .21131 L
.75668 .21131 L
.75668 .21017 L
F
.78755 .21017 m
.78755 .21131 L
.78869 .21131 L
.78869 .21017 L
F
.78869 .21017 m
.78869 .21131 L
.78983 .21131 L
.78983 .21017 L
F
.78983 .21017 m
.78983 .21131 L
.79098 .21131 L
.79098 .21017 L
F
.82185 .21017 m
.82185 .21131 L
.82299 .21131 L
.82299 .21017 L
F
.75439 .21131 m
.75439 .21245 L
.75553 .21245 L
.75553 .21131 L
F
.7864 .21131 m
.7864 .21245 L
.78755 .21245 L
.78755 .21131 L
F
.78755 .21131 m
.78755 .21245 L
.78869 .21245 L
.78869 .21131 L
F
.78869 .21131 m
.78869 .21245 L
.78983 .21245 L
.78983 .21131 L
F
.8207 .21131 m
.8207 .21245 L
.82185 .21245 L
.82185 .21131 L
F
.75325 .21245 m
.75325 .2136 L
.75439 .2136 L
.75439 .21245 L
F
.78526 .21245 m
.78526 .2136 L
.7864 .2136 L
.7864 .21245 L
F
.7864 .21245 m
.7864 .2136 L
.78755 .2136 L
.78755 .21245 L
F
.78755 .21245 m
.78755 .2136 L
.78869 .2136 L
.78869 .21245 L
F
.81956 .21245 m
.81956 .2136 L
.8207 .2136 L
.8207 .21245 L
F
.7521 .2136 m
.7521 .21474 L
.75325 .21474 L
.75325 .2136 L
F
.78412 .2136 m
.78412 .21474 L
.78526 .21474 L
.78526 .2136 L
F
.78526 .2136 m
.78526 .21474 L
.7864 .21474 L
.7864 .2136 L
F
.7864 .2136 m
.7864 .21474 L
.78755 .21474 L
.78755 .2136 L
F
.81842 .2136 m
.81842 .21474 L
.81956 .21474 L
.81956 .2136 L
F
.75096 .21474 m
.75096 .21588 L
.7521 .21588 L
.7521 .21474 L
F
.78297 .21474 m
.78297 .21588 L
.78412 .21588 L
.78412 .21474 L
F
.78412 .21474 m
.78412 .21588 L
.78526 .21588 L
.78526 .21474 L
F
.78526 .21474 m
.78526 .21588 L
.7864 .21588 L
.7864 .21474 L
F
.81727 .21474 m
.81727 .21588 L
.81842 .21588 L
.81842 .21474 L
F
.74982 .21588 m
.74982 .21703 L
.75096 .21703 L
.75096 .21588 L
F
.78183 .21588 m
.78183 .21703 L
.78297 .21703 L
.78297 .21588 L
F
.78297 .21588 m
.78297 .21703 L
.78412 .21703 L
.78412 .21588 L
F
.78412 .21588 m
.78412 .21703 L
.78526 .21703 L
.78526 .21588 L
F
.81613 .21588 m
.81613 .21703 L
.81727 .21703 L
.81727 .21588 L
F
.74867 .21703 m
.74867 .21817 L
.74982 .21817 L
.74982 .21703 L
F
.78183 .21703 m
.78183 .21817 L
.78297 .21817 L
.78297 .21703 L
F
.78297 .21703 m
.78297 .21817 L
.78412 .21817 L
.78412 .21703 L
F
.81499 .21703 m
.81499 .21817 L
.81613 .21817 L
.81613 .21703 L
F
.74753 .21817 m
.74753 .21931 L
.74867 .21931 L
.74867 .21817 L
F
.77954 .21817 m
.77954 .21931 L
.78069 .21931 L
.78069 .21817 L
F
.78069 .21817 m
.78069 .21931 L
.78183 .21931 L
.78183 .21817 L
F
.81384 .21817 m
.81384 .21931 L
.81499 .21931 L
.81499 .21817 L
F
.74639 .21931 m
.74639 .22046 L
.74753 .22046 L
.74753 .21931 L
F
.7784 .21931 m
.7784 .22046 L
.77954 .22046 L
.77954 .21931 L
F
.77954 .21931 m
.77954 .22046 L
.78069 .22046 L
.78069 .21931 L
F
.78069 .21931 m
.78069 .22046 L
.78183 .22046 L
.78183 .21931 L
F
.8127 .21931 m
.8127 .22046 L
.81384 .22046 L
.81384 .21931 L
F
.74524 .22046 m
.74524 .2216 L
.74639 .2216 L
.74639 .22046 L
F
.77726 .22046 m
.77726 .2216 L
.7784 .2216 L
.7784 .22046 L
F
.7784 .22046 m
.7784 .2216 L
.77954 .2216 L
.77954 .22046 L
F
.77954 .22046 m
.77954 .2216 L
.78069 .2216 L
.78069 .22046 L
F
.81156 .22046 m
.81156 .2216 L
.8127 .2216 L
.8127 .22046 L
F
.7441 .2216 m
.7441 .22274 L
.74524 .22274 L
.74524 .2216 L
F
.77611 .2216 m
.77611 .22274 L
.77726 .22274 L
.77726 .2216 L
F
.77726 .2216 m
.77726 .22274 L
.7784 .22274 L
.7784 .2216 L
F
.7784 .2216 m
.7784 .22274 L
.77954 .22274 L
.77954 .2216 L
F
.81041 .2216 m
.81041 .22274 L
.81156 .22274 L
.81156 .2216 L
F
.74296 .22274 m
.74296 .22389 L
.7441 .22389 L
.7441 .22274 L
F
.77497 .22274 m
.77497 .22389 L
.77611 .22389 L
.77611 .22274 L
F
.77611 .22274 m
.77611 .22389 L
.77726 .22389 L
.77726 .22274 L
F
.77726 .22274 m
.77726 .22389 L
.7784 .22389 L
.7784 .22274 L
F
.80927 .22274 m
.80927 .22389 L
.81041 .22389 L
.81041 .22274 L
F
.74181 .22389 m
.74181 .22503 L
.74296 .22503 L
.74296 .22389 L
F
.77383 .22389 m
.77383 .22503 L
.77497 .22503 L
.77497 .22389 L
F
.77497 .22389 m
.77497 .22503 L
.77611 .22503 L
.77611 .22389 L
F
.77611 .22389 m
.77611 .22503 L
.77726 .22503 L
.77726 .22389 L
F
.80813 .22389 m
.80813 .22503 L
.80927 .22503 L
.80927 .22389 L
F
.74067 .22503 m
.74067 .22617 L
.74181 .22617 L
.74181 .22503 L
F
.77268 .22503 m
.77268 .22617 L
.77383 .22617 L
.77383 .22503 L
F
.77383 .22503 m
.77383 .22617 L
.77497 .22617 L
.77497 .22503 L
F
.77497 .22503 m
.77497 .22617 L
.77611 .22617 L
.77611 .22503 L
F
.80698 .22503 m
.80698 .22617 L
.80813 .22617 L
.80813 .22503 L
F
.73953 .22617 m
.73953 .22732 L
.74067 .22732 L
.74067 .22617 L
F
.77154 .22617 m
.77154 .22732 L
.77268 .22732 L
.77268 .22617 L
F
.77268 .22617 m
.77268 .22732 L
.77383 .22732 L
.77383 .22617 L
F
.77383 .22617 m
.77383 .22732 L
.77497 .22732 L
.77497 .22617 L
F
.80584 .22617 m
.80584 .22732 L
.80698 .22732 L
.80698 .22617 L
F
.73838 .22732 m
.73838 .22846 L
.73953 .22846 L
.73953 .22732 L
F
.7704 .22732 m
.7704 .22846 L
.77154 .22846 L
.77154 .22732 L
F
.77154 .22732 m
.77154 .22846 L
.77268 .22846 L
.77268 .22732 L
F
.77268 .22732 m
.77268 .22846 L
.77383 .22846 L
.77383 .22732 L
F
.8047 .22732 m
.8047 .22846 L
.80584 .22846 L
.80584 .22732 L
F
.73724 .22846 m
.73724 .2296 L
.73838 .2296 L
.73838 .22846 L
F
.76925 .22846 m
.76925 .2296 L
.7704 .2296 L
.7704 .22846 L
F
.7704 .22846 m
.7704 .2296 L
.77154 .2296 L
.77154 .22846 L
F
.77154 .22846 m
.77154 .2296 L
.77268 .2296 L
.77268 .22846 L
F
.80355 .22846 m
.80355 .2296 L
.8047 .2296 L
.8047 .22846 L
F
.7361 .2296 m
.7361 .23075 L
.73724 .23075 L
.73724 .2296 L
F
.76811 .2296 m
.76811 .23075 L
.76925 .23075 L
.76925 .2296 L
F
.76925 .2296 m
.76925 .23075 L
.7704 .23075 L
.7704 .2296 L
F
.7704 .2296 m
.7704 .23075 L
.77154 .23075 L
.77154 .2296 L
F
.80241 .2296 m
.80241 .23075 L
.80355 .23075 L
.80355 .2296 L
F
.73495 .23075 m
.73495 .23189 L
.7361 .23189 L
.7361 .23075 L
F
.76697 .23075 m
.76697 .23189 L
.76811 .23189 L
.76811 .23075 L
F
.76811 .23075 m
.76811 .23189 L
.76925 .23189 L
.76925 .23075 L
F
.76925 .23075 m
.76925 .23189 L
.7704 .23189 L
.7704 .23075 L
F
.80127 .23075 m
.80127 .23189 L
.80241 .23189 L
.80241 .23075 L
F
.73381 .23189 m
.73381 .23303 L
.73495 .23303 L
.73495 .23189 L
F
.76582 .23189 m
.76582 .23303 L
.76697 .23303 L
.76697 .23189 L
F
.76697 .23189 m
.76697 .23303 L
.76811 .23303 L
.76811 .23189 L
F
.76811 .23189 m
.76811 .23303 L
.76925 .23303 L
.76925 .23189 L
F
.80012 .23189 m
.80012 .23303 L
.80127 .23303 L
.80127 .23189 L
F
.73267 .23303 m
.73267 .23418 L
.73381 .23418 L
.73381 .23303 L
F
.76468 .23303 m
.76468 .23418 L
.76582 .23418 L
.76582 .23303 L
F
.76582 .23303 m
.76582 .23418 L
.76697 .23418 L
.76697 .23303 L
F
.76697 .23303 m
.76697 .23418 L
.76811 .23418 L
.76811 .23303 L
F
.79898 .23303 m
.79898 .23418 L
.80012 .23418 L
.80012 .23303 L
F
.73152 .23418 m
.73152 .23532 L
.73267 .23532 L
.73267 .23418 L
F
.76354 .23418 m
.76354 .23532 L
.76468 .23532 L
.76468 .23418 L
F
.76468 .23418 m
.76468 .23532 L
.76582 .23532 L
.76582 .23418 L
F
.76582 .23418 m
.76582 .23532 L
.76697 .23532 L
.76697 .23418 L
F
.79784 .23418 m
.79784 .23532 L
.79898 .23532 L
.79898 .23418 L
F
.73038 .23532 m
.73038 .23646 L
.73152 .23646 L
.73152 .23532 L
F
.76239 .23532 m
.76239 .23646 L
.76354 .23646 L
.76354 .23532 L
F
.76354 .23532 m
.76354 .23646 L
.76468 .23646 L
.76468 .23532 L
F
.76468 .23532 m
.76468 .23646 L
.76582 .23646 L
.76582 .23532 L
F
.79669 .23532 m
.79669 .23646 L
.79784 .23646 L
.79784 .23532 L
F
.72924 .23646 m
.72924 .23761 L
.73038 .23761 L
.73038 .23646 L
F
.76125 .23646 m
.76125 .23761 L
.76239 .23761 L
.76239 .23646 L
F
.76239 .23646 m
.76239 .23761 L
.76354 .23761 L
.76354 .23646 L
F
.76354 .23646 m
.76354 .23761 L
.76468 .23761 L
.76468 .23646 L
F
.79555 .23646 m
.79555 .23761 L
.79669 .23761 L
.79669 .23646 L
F
.72809 .23761 m
.72809 .23875 L
.72924 .23875 L
.72924 .23761 L
F
.76011 .23761 m
.76011 .23875 L
.76125 .23875 L
.76125 .23761 L
F
.76125 .23761 m
.76125 .23875 L
.76239 .23875 L
.76239 .23761 L
F
.76239 .23761 m
.76239 .23875 L
.76354 .23875 L
.76354 .23761 L
F
.79441 .23761 m
.79441 .23875 L
.79555 .23875 L
.79555 .23761 L
F
.72695 .23875 m
.72695 .23989 L
.72809 .23989 L
.72809 .23875 L
F
.75896 .23875 m
.75896 .23989 L
.76011 .23989 L
.76011 .23875 L
F
.76011 .23875 m
.76011 .23989 L
.76125 .23989 L
.76125 .23875 L
F
.76125 .23875 m
.76125 .23989 L
.76239 .23989 L
.76239 .23875 L
F
.79326 .23875 m
.79326 .23989 L
.79441 .23989 L
.79441 .23875 L
F
.72581 .23989 m
.72581 .24104 L
.72695 .24104 L
.72695 .23989 L
F
.75782 .23989 m
.75782 .24104 L
.75896 .24104 L
.75896 .23989 L
F
.75896 .23989 m
.75896 .24104 L
.76011 .24104 L
.76011 .23989 L
F
.76011 .23989 m
.76011 .24104 L
.76125 .24104 L
.76125 .23989 L
F
.79212 .23989 m
.79212 .24104 L
.79326 .24104 L
.79326 .23989 L
F
.72466 .24104 m
.72466 .24218 L
.72581 .24218 L
.72581 .24104 L
F
.75668 .24104 m
.75668 .24218 L
.75782 .24218 L
.75782 .24104 L
F
.75782 .24104 m
.75782 .24218 L
.75896 .24218 L
.75896 .24104 L
F
.75896 .24104 m
.75896 .24218 L
.76011 .24218 L
.76011 .24104 L
F
.79098 .24104 m
.79098 .24218 L
.79212 .24218 L
.79212 .24104 L
F
.72352 .24218 m
.72352 .24332 L
.72466 .24332 L
.72466 .24218 L
F
.75553 .24218 m
.75553 .24332 L
.75668 .24332 L
.75668 .24218 L
F
.75668 .24218 m
.75668 .24332 L
.75782 .24332 L
.75782 .24218 L
F
.75782 .24218 m
.75782 .24332 L
.75896 .24332 L
.75896 .24218 L
F
.78983 .24218 m
.78983 .24332 L
.79098 .24332 L
.79098 .24218 L
F
.72238 .24332 m
.72238 .24447 L
.72352 .24447 L
.72352 .24332 L
F
.75439 .24332 m
.75439 .24447 L
.75553 .24447 L
.75553 .24332 L
F
.75553 .24332 m
.75553 .24447 L
.75668 .24447 L
.75668 .24332 L
F
.75668 .24332 m
.75668 .24447 L
.75782 .24447 L
.75782 .24332 L
F
.78869 .24332 m
.78869 .24447 L
.78983 .24447 L
.78983 .24332 L
F
.72123 .24447 m
.72123 .24561 L
.72238 .24561 L
.72238 .24447 L
F
.75325 .24447 m
.75325 .24561 L
.75439 .24561 L
.75439 .24447 L
F
.75439 .24447 m
.75439 .24561 L
.75553 .24561 L
.75553 .24447 L
F
.75553 .24447 m
.75553 .24561 L
.75668 .24561 L
.75668 .24447 L
F
.78755 .24447 m
.78755 .24561 L
.78869 .24561 L
.78869 .24447 L
F
.72009 .24561 m
.72009 .24675 L
.72123 .24675 L
.72123 .24561 L
F
.7521 .24561 m
.7521 .24675 L
.75325 .24675 L
.75325 .24561 L
F
.75325 .24561 m
.75325 .24675 L
.75439 .24675 L
.75439 .24561 L
F
.75439 .24561 m
.75439 .24675 L
.75553 .24675 L
.75553 .24561 L
F
.7864 .24561 m
.7864 .24675 L
.78755 .24675 L
.78755 .24561 L
F
.71895 .24675 m
.71895 .2479 L
.72009 .2479 L
.72009 .24675 L
F
.75096 .24675 m
.75096 .2479 L
.7521 .2479 L
.7521 .24675 L
F
.7521 .24675 m
.7521 .2479 L
.75325 .2479 L
.75325 .24675 L
F
.75325 .24675 m
.75325 .2479 L
.75439 .2479 L
.75439 .24675 L
F
.78526 .24675 m
.78526 .2479 L
.7864 .2479 L
.7864 .24675 L
F
.7178 .2479 m
.7178 .24904 L
.71895 .24904 L
.71895 .2479 L
F
.74982 .2479 m
.74982 .24904 L
.75096 .24904 L
.75096 .2479 L
F
.75096 .2479 m
.75096 .24904 L
.7521 .24904 L
.7521 .2479 L
F
.7521 .2479 m
.7521 .24904 L
.75325 .24904 L
.75325 .2479 L
F
.78412 .2479 m
.78412 .24904 L
.78526 .24904 L
.78526 .2479 L
F
.71666 .24904 m
.71666 .25018 L
.7178 .25018 L
.7178 .24904 L
F
.74867 .24904 m
.74867 .25018 L
.74982 .25018 L
.74982 .24904 L
F
.74982 .24904 m
.74982 .25018 L
.75096 .25018 L
.75096 .24904 L
F
.75096 .24904 m
.75096 .25018 L
.7521 .25018 L
.7521 .24904 L
F
.78297 .24904 m
.78297 .25018 L
.78412 .25018 L
.78412 .24904 L
F
.71552 .25018 m
.71552 .25133 L
.71666 .25133 L
.71666 .25018 L
F
.74867 .25018 m
.74867 .25133 L
.74982 .25133 L
.74982 .25018 L
F
.74982 .25018 m
.74982 .25133 L
.75096 .25133 L
.75096 .25018 L
F
.78183 .25018 m
.78183 .25133 L
.78297 .25133 L
.78297 .25018 L
F
.71437 .25133 m
.71437 .25247 L
.71552 .25247 L
.71552 .25133 L
F
.74639 .25133 m
.74639 .25247 L
.74753 .25247 L
.74753 .25133 L
F
.74753 .25133 m
.74753 .25247 L
.74867 .25247 L
.74867 .25133 L
F
.78069 .25133 m
.78069 .25247 L
.78183 .25247 L
.78183 .25133 L
F
.71323 .25247 m
.71323 .25361 L
.71437 .25361 L
.71437 .25247 L
F
.74524 .25247 m
.74524 .25361 L
.74639 .25361 L
.74639 .25247 L
F
.74639 .25247 m
.74639 .25361 L
.74753 .25361 L
.74753 .25247 L
F
.74753 .25247 m
.74753 .25361 L
.74867 .25361 L
.74867 .25247 L
F
.77954 .25247 m
.77954 .25361 L
.78069 .25361 L
.78069 .25247 L
F
.71209 .25361 m
.71209 .25476 L
.71323 .25476 L
.71323 .25361 L
F
.7441 .25361 m
.7441 .25476 L
.74524 .25476 L
.74524 .25361 L
F
.74524 .25361 m
.74524 .25476 L
.74639 .25476 L
.74639 .25361 L
F
.74639 .25361 m
.74639 .25476 L
.74753 .25476 L
.74753 .25361 L
F
.7784 .25361 m
.7784 .25476 L
.77954 .25476 L
.77954 .25361 L
F
.71094 .25476 m
.71094 .2559 L
.71209 .2559 L
.71209 .25476 L
F
.74296 .25476 m
.74296 .2559 L
.7441 .2559 L
.7441 .25476 L
F
.7441 .25476 m
.7441 .2559 L
.74524 .2559 L
.74524 .25476 L
F
.74524 .25476 m
.74524 .2559 L
.74639 .2559 L
.74639 .25476 L
F
.77726 .25476 m
.77726 .2559 L
.7784 .2559 L
.7784 .25476 L
F
.7098 .2559 m
.7098 .25704 L
.71094 .25704 L
.71094 .2559 L
F
.74181 .2559 m
.74181 .25704 L
.74296 .25704 L
.74296 .2559 L
F
.74296 .2559 m
.74296 .25704 L
.7441 .25704 L
.7441 .2559 L
F
.7441 .2559 m
.7441 .25704 L
.74524 .25704 L
.74524 .2559 L
F
.77611 .2559 m
.77611 .25704 L
.77726 .25704 L
.77726 .2559 L
F
.70866 .25704 m
.70866 .25819 L
.7098 .25819 L
.7098 .25704 L
F
.74067 .25704 m
.74067 .25819 L
.74181 .25819 L
.74181 .25704 L
F
.74181 .25704 m
.74181 .25819 L
.74296 .25819 L
.74296 .25704 L
F
.74296 .25704 m
.74296 .25819 L
.7441 .25819 L
.7441 .25704 L
F
.77497 .25704 m
.77497 .25819 L
.77611 .25819 L
.77611 .25704 L
F
.70751 .25819 m
.70751 .25933 L
.70866 .25933 L
.70866 .25819 L
F
.73953 .25819 m
.73953 .25933 L
.74067 .25933 L
.74067 .25819 L
F
.74067 .25819 m
.74067 .25933 L
.74181 .25933 L
.74181 .25819 L
F
.74181 .25819 m
.74181 .25933 L
.74296 .25933 L
.74296 .25819 L
F
.77383 .25819 m
.77383 .25933 L
.77497 .25933 L
.77497 .25819 L
F
.70637 .25933 m
.70637 .26047 L
.70751 .26047 L
.70751 .25933 L
F
.73838 .25933 m
.73838 .26047 L
.73953 .26047 L
.73953 .25933 L
F
.73953 .25933 m
.73953 .26047 L
.74067 .26047 L
.74067 .25933 L
F
.74067 .25933 m
.74067 .26047 L
.74181 .26047 L
.74181 .25933 L
F
.77268 .25933 m
.77268 .26047 L
.77383 .26047 L
.77383 .25933 L
F
.70523 .26047 m
.70523 .26162 L
.70637 .26162 L
.70637 .26047 L
F
.73724 .26047 m
.73724 .26162 L
.73838 .26162 L
.73838 .26047 L
F
.73838 .26047 m
.73838 .26162 L
.73953 .26162 L
.73953 .26047 L
F
.73953 .26047 m
.73953 .26162 L
.74067 .26162 L
.74067 .26047 L
F
.77154 .26047 m
.77154 .26162 L
.77268 .26162 L
.77268 .26047 L
F
.70408 .26162 m
.70408 .26276 L
.70523 .26276 L
.70523 .26162 L
F
.7361 .26162 m
.7361 .26276 L
.73724 .26276 L
.73724 .26162 L
F
.73724 .26162 m
.73724 .26276 L
.73838 .26276 L
.73838 .26162 L
F
.73838 .26162 m
.73838 .26276 L
.73953 .26276 L
.73953 .26162 L
F
.7704 .26162 m
.7704 .26276 L
.77154 .26276 L
.77154 .26162 L
F
.70294 .26276 m
.70294 .2639 L
.70408 .2639 L
.70408 .26276 L
F
.73495 .26276 m
.73495 .2639 L
.7361 .2639 L
.7361 .26276 L
F
.7361 .26276 m
.7361 .2639 L
.73724 .2639 L
.73724 .26276 L
F
.73724 .26276 m
.73724 .2639 L
.73838 .2639 L
.73838 .26276 L
F
.76925 .26276 m
.76925 .2639 L
.7704 .2639 L
.7704 .26276 L
F
.7018 .2639 m
.7018 .26505 L
.70294 .26505 L
.70294 .2639 L
F
.73381 .2639 m
.73381 .26505 L
.73495 .26505 L
.73495 .2639 L
F
.73495 .2639 m
.73495 .26505 L
.7361 .26505 L
.7361 .2639 L
F
.7361 .2639 m
.7361 .26505 L
.73724 .26505 L
.73724 .2639 L
F
.76811 .2639 m
.76811 .26505 L
.76925 .26505 L
.76925 .2639 L
F
.70065 .26505 m
.70065 .26619 L
.7018 .26619 L
.7018 .26505 L
F
.73267 .26505 m
.73267 .26619 L
.73381 .26619 L
.73381 .26505 L
F
.73381 .26505 m
.73381 .26619 L
.73495 .26619 L
.73495 .26505 L
F
.73495 .26505 m
.73495 .26619 L
.7361 .26619 L
.7361 .26505 L
F
.76697 .26505 m
.76697 .26619 L
.76811 .26619 L
.76811 .26505 L
F
.69951 .26619 m
.69951 .26733 L
.70065 .26733 L
.70065 .26619 L
F
.73152 .26619 m
.73152 .26733 L
.73267 .26733 L
.73267 .26619 L
F
.73267 .26619 m
.73267 .26733 L
.73381 .26733 L
.73381 .26619 L
F
.73381 .26619 m
.73381 .26733 L
.73495 .26733 L
.73495 .26619 L
F
.76582 .26619 m
.76582 .26733 L
.76697 .26733 L
.76697 .26619 L
F
.69837 .26733 m
.69837 .26848 L
.69951 .26848 L
.69951 .26733 L
F
.73038 .26733 m
.73038 .26848 L
.73152 .26848 L
.73152 .26733 L
F
.73152 .26733 m
.73152 .26848 L
.73267 .26848 L
.73267 .26733 L
F
.73267 .26733 m
.73267 .26848 L
.73381 .26848 L
.73381 .26733 L
F
.76468 .26733 m
.76468 .26848 L
.76582 .26848 L
.76582 .26733 L
F
.69722 .26848 m
.69722 .26962 L
.69837 .26962 L
.69837 .26848 L
F
.72924 .26848 m
.72924 .26962 L
.73038 .26962 L
.73038 .26848 L
F
.73038 .26848 m
.73038 .26962 L
.73152 .26962 L
.73152 .26848 L
F
.73152 .26848 m
.73152 .26962 L
.73267 .26962 L
.73267 .26848 L
F
.76354 .26848 m
.76354 .26962 L
.76468 .26962 L
.76468 .26848 L
F
.69608 .26962 m
.69608 .27076 L
.69722 .27076 L
.69722 .26962 L
F
.72809 .26962 m
.72809 .27076 L
.72924 .27076 L
.72924 .26962 L
F
.72924 .26962 m
.72924 .27076 L
.73038 .27076 L
.73038 .26962 L
F
.73038 .26962 m
.73038 .27076 L
.73152 .27076 L
.73152 .26962 L
F
.76239 .26962 m
.76239 .27076 L
.76354 .27076 L
.76354 .26962 L
F
.69494 .27076 m
.69494 .27191 L
.69608 .27191 L
.69608 .27076 L
F
.72695 .27076 m
.72695 .27191 L
.72809 .27191 L
.72809 .27076 L
F
.72809 .27076 m
.72809 .27191 L
.72924 .27191 L
.72924 .27076 L
F
.72924 .27076 m
.72924 .27191 L
.73038 .27191 L
.73038 .27076 L
F
.76125 .27076 m
.76125 .27191 L
.76239 .27191 L
.76239 .27076 L
F
.69379 .27191 m
.69379 .27305 L
.69494 .27305 L
.69494 .27191 L
F
.72581 .27191 m
.72581 .27305 L
.72695 .27305 L
.72695 .27191 L
F
.72695 .27191 m
.72695 .27305 L
.72809 .27305 L
.72809 .27191 L
F
.72809 .27191 m
.72809 .27305 L
.72924 .27305 L
.72924 .27191 L
F
.76011 .27191 m
.76011 .27305 L
.76125 .27305 L
.76125 .27191 L
F
.69265 .27305 m
.69265 .27419 L
.69379 .27419 L
.69379 .27305 L
F
.72466 .27305 m
.72466 .27419 L
.72581 .27419 L
.72581 .27305 L
F
.72581 .27305 m
.72581 .27419 L
.72695 .27419 L
.72695 .27305 L
F
.72695 .27305 m
.72695 .27419 L
.72809 .27419 L
.72809 .27305 L
F
.75896 .27305 m
.75896 .27419 L
.76011 .27419 L
.76011 .27305 L
F
.69151 .27419 m
.69151 .27534 L
.69265 .27534 L
.69265 .27419 L
F
.72352 .27419 m
.72352 .27534 L
.72466 .27534 L
.72466 .27419 L
F
.72466 .27419 m
.72466 .27534 L
.72581 .27534 L
.72581 .27419 L
F
.72581 .27419 m
.72581 .27534 L
.72695 .27534 L
.72695 .27419 L
F
.75782 .27419 m
.75782 .27534 L
.75896 .27534 L
.75896 .27419 L
F
.69036 .27534 m
.69036 .27648 L
.69151 .27648 L
.69151 .27534 L
F
.72238 .27534 m
.72238 .27648 L
.72352 .27648 L
.72352 .27534 L
F
.72352 .27534 m
.72352 .27648 L
.72466 .27648 L
.72466 .27534 L
F
.72466 .27534 m
.72466 .27648 L
.72581 .27648 L
.72581 .27534 L
F
.75668 .27534 m
.75668 .27648 L
.75782 .27648 L
.75782 .27534 L
F
.68922 .27648 m
.68922 .27762 L
.69036 .27762 L
.69036 .27648 L
F
.72123 .27648 m
.72123 .27762 L
.72238 .27762 L
.72238 .27648 L
F
.72238 .27648 m
.72238 .27762 L
.72352 .27762 L
.72352 .27648 L
F
.72352 .27648 m
.72352 .27762 L
.72466 .27762 L
.72466 .27648 L
F
.75553 .27648 m
.75553 .27762 L
.75668 .27762 L
.75668 .27648 L
F
.68808 .27762 m
.68808 .27877 L
.68922 .27877 L
.68922 .27762 L
F
.72009 .27762 m
.72009 .27877 L
.72123 .27877 L
.72123 .27762 L
F
.72123 .27762 m
.72123 .27877 L
.72238 .27877 L
.72238 .27762 L
F
.72238 .27762 m
.72238 .27877 L
.72352 .27877 L
.72352 .27762 L
F
.75439 .27762 m
.75439 .27877 L
.75553 .27877 L
.75553 .27762 L
F
.68693 .27877 m
.68693 .27991 L
.68808 .27991 L
.68808 .27877 L
F
.71895 .27877 m
.71895 .27991 L
.72009 .27991 L
.72009 .27877 L
F
.72009 .27877 m
.72009 .27991 L
.72123 .27991 L
.72123 .27877 L
F
.72123 .27877 m
.72123 .27991 L
.72238 .27991 L
.72238 .27877 L
F
.75325 .27877 m
.75325 .27991 L
.75439 .27991 L
.75439 .27877 L
F
.68579 .27991 m
.68579 .28105 L
.68693 .28105 L
.68693 .27991 L
F
.7178 .27991 m
.7178 .28105 L
.71895 .28105 L
.71895 .27991 L
F
.71895 .27991 m
.71895 .28105 L
.72009 .28105 L
.72009 .27991 L
F
.72009 .27991 m
.72009 .28105 L
.72123 .28105 L
.72123 .27991 L
F
.7521 .27991 m
.7521 .28105 L
.75325 .28105 L
.75325 .27991 L
F
.68465 .28105 m
.68465 .2822 L
.68579 .2822 L
.68579 .28105 L
F
.71666 .28105 m
.71666 .2822 L
.7178 .2822 L
.7178 .28105 L
F
.7178 .28105 m
.7178 .2822 L
.71895 .2822 L
.71895 .28105 L
F
.71895 .28105 m
.71895 .2822 L
.72009 .2822 L
.72009 .28105 L
F
.75096 .28105 m
.75096 .2822 L
.7521 .2822 L
.7521 .28105 L
F
.6835 .2822 m
.6835 .28334 L
.68465 .28334 L
.68465 .2822 L
F
.71552 .2822 m
.71552 .28334 L
.71666 .28334 L
.71666 .2822 L
F
.71666 .2822 m
.71666 .28334 L
.7178 .28334 L
.7178 .2822 L
F
.7178 .2822 m
.7178 .28334 L
.71895 .28334 L
.71895 .2822 L
F
.74982 .2822 m
.74982 .28334 L
.75096 .28334 L
.75096 .2822 L
F
.68236 .28334 m
.68236 .28448 L
.6835 .28448 L
.6835 .28334 L
F
.71552 .28334 m
.71552 .28448 L
.71666 .28448 L
.71666 .28334 L
F
.71666 .28334 m
.71666 .28448 L
.7178 .28448 L
.7178 .28334 L
F
.74867 .28334 m
.74867 .28448 L
.74982 .28448 L
.74982 .28334 L
F
.68122 .28448 m
.68122 .28563 L
.68236 .28563 L
.68236 .28448 L
F
.71323 .28448 m
.71323 .28563 L
.71437 .28563 L
.71437 .28448 L
F
.71437 .28448 m
.71437 .28563 L
.71552 .28563 L
.71552 .28448 L
F
.74753 .28448 m
.74753 .28563 L
.74867 .28563 L
.74867 .28448 L
F
.68007 .28563 m
.68007 .28677 L
.68122 .28677 L
.68122 .28563 L
F
.71209 .28563 m
.71209 .28677 L
.71323 .28677 L
.71323 .28563 L
F
.71323 .28563 m
.71323 .28677 L
.71437 .28677 L
.71437 .28563 L
F
.71437 .28563 m
.71437 .28677 L
.71552 .28677 L
.71552 .28563 L
F
.74639 .28563 m
.74639 .28677 L
.74753 .28677 L
.74753 .28563 L
F
.67893 .28677 m
.67893 .28791 L
.68007 .28791 L
.68007 .28677 L
F
.71094 .28677 m
.71094 .28791 L
.71209 .28791 L
.71209 .28677 L
F
.71209 .28677 m
.71209 .28791 L
.71323 .28791 L
.71323 .28677 L
F
.71323 .28677 m
.71323 .28791 L
.71437 .28791 L
.71437 .28677 L
F
.74524 .28677 m
.74524 .28791 L
.74639 .28791 L
.74639 .28677 L
F
.67779 .28791 m
.67779 .28906 L
.67893 .28906 L
.67893 .28791 L
F
.7098 .28791 m
.7098 .28906 L
.71094 .28906 L
.71094 .28791 L
F
.71094 .28791 m
.71094 .28906 L
.71209 .28906 L
.71209 .28791 L
F
.71209 .28791 m
.71209 .28906 L
.71323 .28906 L
.71323 .28791 L
F
.7441 .28791 m
.7441 .28906 L
.74524 .28906 L
.74524 .28791 L
F
.67664 .28906 m
.67664 .2902 L
.67779 .2902 L
.67779 .28906 L
F
.70866 .28906 m
.70866 .2902 L
.7098 .2902 L
.7098 .28906 L
F
.7098 .28906 m
.7098 .2902 L
.71094 .2902 L
.71094 .28906 L
F
.71094 .28906 m
.71094 .2902 L
.71209 .2902 L
.71209 .28906 L
F
.74296 .28906 m
.74296 .2902 L
.7441 .2902 L
.7441 .28906 L
F
.6755 .2902 m
.6755 .29134 L
.67664 .29134 L
.67664 .2902 L
F
.70751 .2902 m
.70751 .29134 L
.70866 .29134 L
.70866 .2902 L
F
.70866 .2902 m
.70866 .29134 L
.7098 .29134 L
.7098 .2902 L
F
.7098 .2902 m
.7098 .29134 L
.71094 .29134 L
.71094 .2902 L
F
.74181 .2902 m
.74181 .29134 L
.74296 .29134 L
.74296 .2902 L
F
.67436 .29134 m
.67436 .29249 L
.6755 .29249 L
.6755 .29134 L
F
.70637 .29134 m
.70637 .29249 L
.70751 .29249 L
.70751 .29134 L
F
.70751 .29134 m
.70751 .29249 L
.70866 .29249 L
.70866 .29134 L
F
.70866 .29134 m
.70866 .29249 L
.7098 .29249 L
.7098 .29134 L
F
.74067 .29134 m
.74067 .29249 L
.74181 .29249 L
.74181 .29134 L
F
.67321 .29249 m
.67321 .29363 L
.67436 .29363 L
.67436 .29249 L
F
.70523 .29249 m
.70523 .29363 L
.70637 .29363 L
.70637 .29249 L
F
.70637 .29249 m
.70637 .29363 L
.70751 .29363 L
.70751 .29249 L
F
.70751 .29249 m
.70751 .29363 L
.70866 .29363 L
.70866 .29249 L
F
.73953 .29249 m
.73953 .29363 L
.74067 .29363 L
.74067 .29249 L
F
.67207 .29363 m
.67207 .29477 L
.67321 .29477 L
.67321 .29363 L
F
.70408 .29363 m
.70408 .29477 L
.70523 .29477 L
.70523 .29363 L
F
.70523 .29363 m
.70523 .29477 L
.70637 .29477 L
.70637 .29363 L
F
.70637 .29363 m
.70637 .29477 L
.70751 .29477 L
.70751 .29363 L
F
.73838 .29363 m
.73838 .29477 L
.73953 .29477 L
.73953 .29363 L
F
.67093 .29477 m
.67093 .29592 L
.67207 .29592 L
.67207 .29477 L
F
.70294 .29477 m
.70294 .29592 L
.70408 .29592 L
.70408 .29477 L
F
.70408 .29477 m
.70408 .29592 L
.70523 .29592 L
.70523 .29477 L
F
.70523 .29477 m
.70523 .29592 L
.70637 .29592 L
.70637 .29477 L
F
.73724 .29477 m
.73724 .29592 L
.73838 .29592 L
.73838 .29477 L
F
.66978 .29592 m
.66978 .29706 L
.67093 .29706 L
.67093 .29592 L
F
.7018 .29592 m
.7018 .29706 L
.70294 .29706 L
.70294 .29592 L
F
.70294 .29592 m
.70294 .29706 L
.70408 .29706 L
.70408 .29592 L
F
.70408 .29592 m
.70408 .29706 L
.70523 .29706 L
.70523 .29592 L
F
.7361 .29592 m
.7361 .29706 L
.73724 .29706 L
.73724 .29592 L
F
.66864 .29706 m
.66864 .2982 L
.66978 .2982 L
.66978 .29706 L
F
.70065 .29706 m
.70065 .2982 L
.7018 .2982 L
.7018 .29706 L
F
.7018 .29706 m
.7018 .2982 L
.70294 .2982 L
.70294 .29706 L
F
.70294 .29706 m
.70294 .2982 L
.70408 .2982 L
.70408 .29706 L
F
.73495 .29706 m
.73495 .2982 L
.7361 .2982 L
.7361 .29706 L
F
.6675 .2982 m
.6675 .29935 L
.66864 .29935 L
.66864 .2982 L
F
.69951 .2982 m
.69951 .29935 L
.70065 .29935 L
.70065 .2982 L
F
.70065 .2982 m
.70065 .29935 L
.7018 .29935 L
.7018 .2982 L
F
.7018 .2982 m
.7018 .29935 L
.70294 .29935 L
.70294 .2982 L
F
.73381 .2982 m
.73381 .29935 L
.73495 .29935 L
.73495 .2982 L
F
.66635 .29935 m
.66635 .30049 L
.6675 .30049 L
.6675 .29935 L
F
.69837 .29935 m
.69837 .30049 L
.69951 .30049 L
.69951 .29935 L
F
.69951 .29935 m
.69951 .30049 L
.70065 .30049 L
.70065 .29935 L
F
.70065 .29935 m
.70065 .30049 L
.7018 .30049 L
.7018 .29935 L
F
.73267 .29935 m
.73267 .30049 L
.73381 .30049 L
.73381 .29935 L
F
.66521 .30049 m
.66521 .30163 L
.66635 .30163 L
.66635 .30049 L
F
.69722 .30049 m
.69722 .30163 L
.69837 .30163 L
.69837 .30049 L
F
.69837 .30049 m
.69837 .30163 L
.69951 .30163 L
.69951 .30049 L
F
.69951 .30049 m
.69951 .30163 L
.70065 .30163 L
.70065 .30049 L
F
.73152 .30049 m
.73152 .30163 L
.73267 .30163 L
.73267 .30049 L
F
.66407 .30163 m
.66407 .30278 L
.66521 .30278 L
.66521 .30163 L
F
.69608 .30163 m
.69608 .30278 L
.69722 .30278 L
.69722 .30163 L
F
.69722 .30163 m
.69722 .30278 L
.69837 .30278 L
.69837 .30163 L
F
.69837 .30163 m
.69837 .30278 L
.69951 .30278 L
.69951 .30163 L
F
.73038 .30163 m
.73038 .30278 L
.73152 .30278 L
.73152 .30163 L
F
.66292 .30278 m
.66292 .30392 L
.66407 .30392 L
.66407 .30278 L
F
.69494 .30278 m
.69494 .30392 L
.69608 .30392 L
.69608 .30278 L
F
.69608 .30278 m
.69608 .30392 L
.69722 .30392 L
.69722 .30278 L
F
.69722 .30278 m
.69722 .30392 L
.69837 .30392 L
.69837 .30278 L
F
.72924 .30278 m
.72924 .30392 L
.73038 .30392 L
.73038 .30278 L
F
.66178 .30392 m
.66178 .30506 L
.66292 .30506 L
.66292 .30392 L
F
.69379 .30392 m
.69379 .30506 L
.69494 .30506 L
.69494 .30392 L
F
.69494 .30392 m
.69494 .30506 L
.69608 .30506 L
.69608 .30392 L
F
.69608 .30392 m
.69608 .30506 L
.69722 .30506 L
.69722 .30392 L
F
.72809 .30392 m
.72809 .30506 L
.72924 .30506 L
.72924 .30392 L
F
.66064 .30506 m
.66064 .30621 L
.66178 .30621 L
.66178 .30506 L
F
.69265 .30506 m
.69265 .30621 L
.69379 .30621 L
.69379 .30506 L
F
.69379 .30506 m
.69379 .30621 L
.69494 .30621 L
.69494 .30506 L
F
.69494 .30506 m
.69494 .30621 L
.69608 .30621 L
.69608 .30506 L
F
.72695 .30506 m
.72695 .30621 L
.72809 .30621 L
.72809 .30506 L
F
.65949 .30621 m
.65949 .30735 L
.66064 .30735 L
.66064 .30621 L
F
.69151 .30621 m
.69151 .30735 L
.69265 .30735 L
.69265 .30621 L
F
.69265 .30621 m
.69265 .30735 L
.69379 .30735 L
.69379 .30621 L
F
.69379 .30621 m
.69379 .30735 L
.69494 .30735 L
.69494 .30621 L
F
.72581 .30621 m
.72581 .30735 L
.72695 .30735 L
.72695 .30621 L
F
.65835 .30735 m
.65835 .30849 L
.65949 .30849 L
.65949 .30735 L
F
.69036 .30735 m
.69036 .30849 L
.69151 .30849 L
.69151 .30735 L
F
.69151 .30735 m
.69151 .30849 L
.69265 .30849 L
.69265 .30735 L
F
.69265 .30735 m
.69265 .30849 L
.69379 .30849 L
.69379 .30735 L
F
.72466 .30735 m
.72466 .30849 L
.72581 .30849 L
.72581 .30735 L
F
.65721 .30849 m
.65721 .30964 L
.65835 .30964 L
.65835 .30849 L
F
.68922 .30849 m
.68922 .30964 L
.69036 .30964 L
.69036 .30849 L
F
.69036 .30849 m
.69036 .30964 L
.69151 .30964 L
.69151 .30849 L
F
.69151 .30849 m
.69151 .30964 L
.69265 .30964 L
.69265 .30849 L
F
.72352 .30849 m
.72352 .30964 L
.72466 .30964 L
.72466 .30849 L
F
.65606 .30964 m
.65606 .31078 L
.65721 .31078 L
.65721 .30964 L
F
.68808 .30964 m
.68808 .31078 L
.68922 .31078 L
.68922 .30964 L
F
.68922 .30964 m
.68922 .31078 L
.69036 .31078 L
.69036 .30964 L
F
.69036 .30964 m
.69036 .31078 L
.69151 .31078 L
.69151 .30964 L
F
.72238 .30964 m
.72238 .31078 L
.72352 .31078 L
.72352 .30964 L
F
.65492 .31078 m
.65492 .31192 L
.65606 .31192 L
.65606 .31078 L
F
.68693 .31078 m
.68693 .31192 L
.68808 .31192 L
.68808 .31078 L
F
.68808 .31078 m
.68808 .31192 L
.68922 .31192 L
.68922 .31078 L
F
.68922 .31078 m
.68922 .31192 L
.69036 .31192 L
.69036 .31078 L
F
.72123 .31078 m
.72123 .31192 L
.72238 .31192 L
.72238 .31078 L
F
.65378 .31192 m
.65378 .31307 L
.65492 .31307 L
.65492 .31192 L
F
.68579 .31192 m
.68579 .31307 L
.68693 .31307 L
.68693 .31192 L
F
.68693 .31192 m
.68693 .31307 L
.68808 .31307 L
.68808 .31192 L
F
.68808 .31192 m
.68808 .31307 L
.68922 .31307 L
.68922 .31192 L
F
.72009 .31192 m
.72009 .31307 L
.72123 .31307 L
.72123 .31192 L
F
.65263 .31307 m
.65263 .31421 L
.65378 .31421 L
.65378 .31307 L
F
.68465 .31307 m
.68465 .31421 L
.68579 .31421 L
.68579 .31307 L
F
.68579 .31307 m
.68579 .31421 L
.68693 .31421 L
.68693 .31307 L
F
.68693 .31307 m
.68693 .31421 L
.68808 .31421 L
.68808 .31307 L
F
.71895 .31307 m
.71895 .31421 L
.72009 .31421 L
.72009 .31307 L
F
.65149 .31421 m
.65149 .31535 L
.65263 .31535 L
.65263 .31421 L
F
.6835 .31421 m
.6835 .31535 L
.68465 .31535 L
.68465 .31421 L
F
.68465 .31421 m
.68465 .31535 L
.68579 .31535 L
.68579 .31421 L
F
.68579 .31421 m
.68579 .31535 L
.68693 .31535 L
.68693 .31421 L
F
.7178 .31421 m
.7178 .31535 L
.71895 .31535 L
.71895 .31421 L
F
.65035 .31535 m
.65035 .3165 L
.65149 .3165 L
.65149 .31535 L
F
.68236 .31535 m
.68236 .3165 L
.6835 .3165 L
.6835 .31535 L
F
.6835 .31535 m
.6835 .3165 L
.68465 .3165 L
.68465 .31535 L
F
.68465 .31535 m
.68465 .3165 L
.68579 .3165 L
.68579 .31535 L
F
.71666 .31535 m
.71666 .3165 L
.7178 .3165 L
.7178 .31535 L
F
.6492 .3165 m
.6492 .31764 L
.65035 .31764 L
.65035 .3165 L
F
.68236 .3165 m
.68236 .31764 L
.6835 .31764 L
.6835 .3165 L
F
.6835 .3165 m
.6835 .31764 L
.68465 .31764 L
.68465 .3165 L
F
.71552 .3165 m
.71552 .31764 L
.71666 .31764 L
.71666 .3165 L
F
.64806 .31764 m
.64806 .31878 L
.6492 .31878 L
.6492 .31764 L
F
.68007 .31764 m
.68007 .31878 L
.68122 .31878 L
.68122 .31764 L
F
.68122 .31764 m
.68122 .31878 L
.68236 .31878 L
.68236 .31764 L
F
.71437 .31764 m
.71437 .31878 L
.71552 .31878 L
.71552 .31764 L
F
.64692 .31878 m
.64692 .31993 L
.64806 .31993 L
.64806 .31878 L
F
.67893 .31878 m
.67893 .31993 L
.68007 .31993 L
.68007 .31878 L
F
.68007 .31878 m
.68007 .31993 L
.68122 .31993 L
.68122 .31878 L
F
.68122 .31878 m
.68122 .31993 L
.68236 .31993 L
.68236 .31878 L
F
.71323 .31878 m
.71323 .31993 L
.71437 .31993 L
.71437 .31878 L
F
.64577 .31993 m
.64577 .32107 L
.64692 .32107 L
.64692 .31993 L
F
.67779 .31993 m
.67779 .32107 L
.67893 .32107 L
.67893 .31993 L
F
.67893 .31993 m
.67893 .32107 L
.68007 .32107 L
.68007 .31993 L
F
.68007 .31993 m
.68007 .32107 L
.68122 .32107 L
.68122 .31993 L
F
.71209 .31993 m
.71209 .32107 L
.71323 .32107 L
.71323 .31993 L
F
.64463 .32107 m
.64463 .32221 L
.64577 .32221 L
.64577 .32107 L
F
.67664 .32107 m
.67664 .32221 L
.67779 .32221 L
.67779 .32107 L
F
.67779 .32107 m
.67779 .32221 L
.67893 .32221 L
.67893 .32107 L
F
.67893 .32107 m
.67893 .32221 L
.68007 .32221 L
.68007 .32107 L
F
.71094 .32107 m
.71094 .32221 L
.71209 .32221 L
.71209 .32107 L
F
.64349 .32221 m
.64349 .32336 L
.64463 .32336 L
.64463 .32221 L
F
.6755 .32221 m
.6755 .32336 L
.67664 .32336 L
.67664 .32221 L
F
.67664 .32221 m
.67664 .32336 L
.67779 .32336 L
.67779 .32221 L
F
.67779 .32221 m
.67779 .32336 L
.67893 .32336 L
.67893 .32221 L
F
.7098 .32221 m
.7098 .32336 L
.71094 .32336 L
.71094 .32221 L
F
.64234 .32336 m
.64234 .3245 L
.64349 .3245 L
.64349 .32336 L
F
.67436 .32336 m
.67436 .3245 L
.6755 .3245 L
.6755 .32336 L
F
.6755 .32336 m
.6755 .3245 L
.67664 .3245 L
.67664 .32336 L
F
.67664 .32336 m
.67664 .3245 L
.67779 .3245 L
.67779 .32336 L
F
.70866 .32336 m
.70866 .3245 L
.7098 .3245 L
.7098 .32336 L
F
.6412 .3245 m
.6412 .32564 L
.64234 .32564 L
.64234 .3245 L
F
.67321 .3245 m
.67321 .32564 L
.67436 .32564 L
.67436 .3245 L
F
.67436 .3245 m
.67436 .32564 L
.6755 .32564 L
.6755 .3245 L
F
.6755 .3245 m
.6755 .32564 L
.67664 .32564 L
.67664 .3245 L
F
.70751 .3245 m
.70751 .32564 L
.70866 .32564 L
.70866 .3245 L
F
.64006 .32564 m
.64006 .32679 L
.6412 .32679 L
.6412 .32564 L
F
.67207 .32564 m
.67207 .32679 L
.67321 .32679 L
.67321 .32564 L
F
.67321 .32564 m
.67321 .32679 L
.67436 .32679 L
.67436 .32564 L
F
.67436 .32564 m
.67436 .32679 L
.6755 .32679 L
.6755 .32564 L
F
.70637 .32564 m
.70637 .32679 L
.70751 .32679 L
.70751 .32564 L
F
.63891 .32679 m
.63891 .32793 L
.64006 .32793 L
.64006 .32679 L
F
.67093 .32679 m
.67093 .32793 L
.67207 .32793 L
.67207 .32679 L
F
.67207 .32679 m
.67207 .32793 L
.67321 .32793 L
.67321 .32679 L
F
.67321 .32679 m
.67321 .32793 L
.67436 .32793 L
.67436 .32679 L
F
.70523 .32679 m
.70523 .32793 L
.70637 .32793 L
.70637 .32679 L
F
.63777 .32793 m
.63777 .32907 L
.63891 .32907 L
.63891 .32793 L
F
.66978 .32793 m
.66978 .32907 L
.67093 .32907 L
.67093 .32793 L
F
.67093 .32793 m
.67093 .32907 L
.67207 .32907 L
.67207 .32793 L
F
.67207 .32793 m
.67207 .32907 L
.67321 .32907 L
.67321 .32793 L
F
.70408 .32793 m
.70408 .32907 L
.70523 .32907 L
.70523 .32793 L
F
.63663 .32907 m
.63663 .33022 L
.63777 .33022 L
.63777 .32907 L
F
.66864 .32907 m
.66864 .33022 L
.66978 .33022 L
.66978 .32907 L
F
.66978 .32907 m
.66978 .33022 L
.67093 .33022 L
.67093 .32907 L
F
.67093 .32907 m
.67093 .33022 L
.67207 .33022 L
.67207 .32907 L
F
.70294 .32907 m
.70294 .33022 L
.70408 .33022 L
.70408 .32907 L
F
.63548 .33022 m
.63548 .33136 L
.63663 .33136 L
.63663 .33022 L
F
.6675 .33022 m
.6675 .33136 L
.66864 .33136 L
.66864 .33022 L
F
.66864 .33022 m
.66864 .33136 L
.66978 .33136 L
.66978 .33022 L
F
.66978 .33022 m
.66978 .33136 L
.67093 .33136 L
.67093 .33022 L
F
.7018 .33022 m
.7018 .33136 L
.70294 .33136 L
.70294 .33022 L
F
.63434 .33136 m
.63434 .3325 L
.63548 .3325 L
.63548 .33136 L
F
.66635 .33136 m
.66635 .3325 L
.6675 .3325 L
.6675 .33136 L
F
.6675 .33136 m
.6675 .3325 L
.66864 .3325 L
.66864 .33136 L
F
.66864 .33136 m
.66864 .3325 L
.66978 .3325 L
.66978 .33136 L
F
.70065 .33136 m
.70065 .3325 L
.7018 .3325 L
.7018 .33136 L
F
.6332 .3325 m
.6332 .33365 L
.63434 .33365 L
.63434 .3325 L
F
.66521 .3325 m
.66521 .33365 L
.66635 .33365 L
.66635 .3325 L
F
.66635 .3325 m
.66635 .33365 L
.6675 .33365 L
.6675 .3325 L
F
.6675 .3325 m
.6675 .33365 L
.66864 .33365 L
.66864 .3325 L
F
.69951 .3325 m
.69951 .33365 L
.70065 .33365 L
.70065 .3325 L
F
.63205 .33365 m
.63205 .33479 L
.6332 .33479 L
.6332 .33365 L
F
.66407 .33365 m
.66407 .33479 L
.66521 .33479 L
.66521 .33365 L
F
.66521 .33365 m
.66521 .33479 L
.66635 .33479 L
.66635 .33365 L
F
.66635 .33365 m
.66635 .33479 L
.6675 .33479 L
.6675 .33365 L
F
.69837 .33365 m
.69837 .33479 L
.69951 .33479 L
.69951 .33365 L
F
.63091 .33479 m
.63091 .33593 L
.63205 .33593 L
.63205 .33479 L
F
.66292 .33479 m
.66292 .33593 L
.66407 .33593 L
.66407 .33479 L
F
.66407 .33479 m
.66407 .33593 L
.66521 .33593 L
.66521 .33479 L
F
.66521 .33479 m
.66521 .33593 L
.66635 .33593 L
.66635 .33479 L
F
.69722 .33479 m
.69722 .33593 L
.69837 .33593 L
.69837 .33479 L
F
.62977 .33593 m
.62977 .33708 L
.63091 .33708 L
.63091 .33593 L
F
.66178 .33593 m
.66178 .33708 L
.66292 .33708 L
.66292 .33593 L
F
.66292 .33593 m
.66292 .33708 L
.66407 .33708 L
.66407 .33593 L
F
.66407 .33593 m
.66407 .33708 L
.66521 .33708 L
.66521 .33593 L
F
.69608 .33593 m
.69608 .33708 L
.69722 .33708 L
.69722 .33593 L
F
.62862 .33708 m
.62862 .33822 L
.62977 .33822 L
.62977 .33708 L
F
.66064 .33708 m
.66064 .33822 L
.66178 .33822 L
.66178 .33708 L
F
.66178 .33708 m
.66178 .33822 L
.66292 .33822 L
.66292 .33708 L
F
.66292 .33708 m
.66292 .33822 L
.66407 .33822 L
.66407 .33708 L
F
.69494 .33708 m
.69494 .33822 L
.69608 .33822 L
.69608 .33708 L
F
.62748 .33822 m
.62748 .33936 L
.62862 .33936 L
.62862 .33822 L
F
.65949 .33822 m
.65949 .33936 L
.66064 .33936 L
.66064 .33822 L
F
.66064 .33822 m
.66064 .33936 L
.66178 .33936 L
.66178 .33822 L
F
.66178 .33822 m
.66178 .33936 L
.66292 .33936 L
.66292 .33822 L
F
.69379 .33822 m
.69379 .33936 L
.69494 .33936 L
.69494 .33822 L
F
.62634 .33936 m
.62634 .34051 L
.62748 .34051 L
.62748 .33936 L
F
.65835 .33936 m
.65835 .34051 L
.65949 .34051 L
.65949 .33936 L
F
.65949 .33936 m
.65949 .34051 L
.66064 .34051 L
.66064 .33936 L
F
.66064 .33936 m
.66064 .34051 L
.66178 .34051 L
.66178 .33936 L
F
.69265 .33936 m
.69265 .34051 L
.69379 .34051 L
.69379 .33936 L
F
.62519 .34051 m
.62519 .34165 L
.62634 .34165 L
.62634 .34051 L
F
.65721 .34051 m
.65721 .34165 L
.65835 .34165 L
.65835 .34051 L
F
.65835 .34051 m
.65835 .34165 L
.65949 .34165 L
.65949 .34051 L
F
.65949 .34051 m
.65949 .34165 L
.66064 .34165 L
.66064 .34051 L
F
.69151 .34051 m
.69151 .34165 L
.69265 .34165 L
.69265 .34051 L
F
.62405 .34165 m
.62405 .34279 L
.62519 .34279 L
.62519 .34165 L
F
.65606 .34165 m
.65606 .34279 L
.65721 .34279 L
.65721 .34165 L
F
.65721 .34165 m
.65721 .34279 L
.65835 .34279 L
.65835 .34165 L
F
.65835 .34165 m
.65835 .34279 L
.65949 .34279 L
.65949 .34165 L
F
.69036 .34165 m
.69036 .34279 L
.69151 .34279 L
.69151 .34165 L
F
.62291 .34279 m
.62291 .34394 L
.62405 .34394 L
.62405 .34279 L
F
.65492 .34279 m
.65492 .34394 L
.65606 .34394 L
.65606 .34279 L
F
.65606 .34279 m
.65606 .34394 L
.65721 .34394 L
.65721 .34279 L
F
.65721 .34279 m
.65721 .34394 L
.65835 .34394 L
.65835 .34279 L
F
.68922 .34279 m
.68922 .34394 L
.69036 .34394 L
.69036 .34279 L
F
.62176 .34394 m
.62176 .34508 L
.62291 .34508 L
.62291 .34394 L
F
.65378 .34394 m
.65378 .34508 L
.65492 .34508 L
.65492 .34394 L
F
.65492 .34394 m
.65492 .34508 L
.65606 .34508 L
.65606 .34394 L
F
.65606 .34394 m
.65606 .34508 L
.65721 .34508 L
.65721 .34394 L
F
.68808 .34394 m
.68808 .34508 L
.68922 .34508 L
.68922 .34394 L
F
.62062 .34508 m
.62062 .34622 L
.62176 .34622 L
.62176 .34508 L
F
.65263 .34508 m
.65263 .34622 L
.65378 .34622 L
.65378 .34508 L
F
.65378 .34508 m
.65378 .34622 L
.65492 .34622 L
.65492 .34508 L
F
.65492 .34508 m
.65492 .34622 L
.65606 .34622 L
.65606 .34508 L
F
.68693 .34508 m
.68693 .34622 L
.68808 .34622 L
.68808 .34508 L
F
.61948 .34622 m
.61948 .34737 L
.62062 .34737 L
.62062 .34622 L
F
.65149 .34622 m
.65149 .34737 L
.65263 .34737 L
.65263 .34622 L
F
.65263 .34622 m
.65263 .34737 L
.65378 .34737 L
.65378 .34622 L
F
.65378 .34622 m
.65378 .34737 L
.65492 .34737 L
.65492 .34622 L
F
.68579 .34622 m
.68579 .34737 L
.68693 .34737 L
.68693 .34622 L
F
.61833 .34737 m
.61833 .34851 L
.61948 .34851 L
.61948 .34737 L
F
.65035 .34737 m
.65035 .34851 L
.65149 .34851 L
.65149 .34737 L
F
.65149 .34737 m
.65149 .34851 L
.65263 .34851 L
.65263 .34737 L
F
.65263 .34737 m
.65263 .34851 L
.65378 .34851 L
.65378 .34737 L
F
.68465 .34737 m
.68465 .34851 L
.68579 .34851 L
.68579 .34737 L
F
.61719 .34851 m
.61719 .34965 L
.61833 .34965 L
.61833 .34851 L
F
.6492 .34851 m
.6492 .34965 L
.65035 .34965 L
.65035 .34851 L
F
.65035 .34851 m
.65035 .34965 L
.65149 .34965 L
.65149 .34851 L
F
.65149 .34851 m
.65149 .34965 L
.65263 .34965 L
.65263 .34851 L
F
.6835 .34851 m
.6835 .34965 L
.68465 .34965 L
.68465 .34851 L
F
.61605 .34965 m
.61605 .3508 L
.61719 .3508 L
.61719 .34965 L
F
.6492 .34965 m
.6492 .3508 L
.65035 .3508 L
.65035 .34965 L
F
.65035 .34965 m
.65035 .3508 L
.65149 .3508 L
.65149 .34965 L
F
.68236 .34965 m
.68236 .3508 L
.6835 .3508 L
.6835 .34965 L
F
.6149 .3508 m
.6149 .35194 L
.61605 .35194 L
.61605 .3508 L
F
.64692 .3508 m
.64692 .35194 L
.64806 .35194 L
.64806 .3508 L
F
.64806 .3508 m
.64806 .35194 L
.6492 .35194 L
.6492 .3508 L
F
.68122 .3508 m
.68122 .35194 L
.68236 .35194 L
.68236 .3508 L
F
.61376 .35194 m
.61376 .35308 L
.6149 .35308 L
.6149 .35194 L
F
.64577 .35194 m
.64577 .35308 L
.64692 .35308 L
.64692 .35194 L
F
.64692 .35194 m
.64692 .35308 L
.64806 .35308 L
.64806 .35194 L
F
.64806 .35194 m
.64806 .35308 L
.6492 .35308 L
.6492 .35194 L
F
.68007 .35194 m
.68007 .35308 L
.68122 .35308 L
.68122 .35194 L
F
.61262 .35308 m
.61262 .35423 L
.61376 .35423 L
.61376 .35308 L
F
.64463 .35308 m
.64463 .35423 L
.64577 .35423 L
.64577 .35308 L
F
.64577 .35308 m
.64577 .35423 L
.64692 .35423 L
.64692 .35308 L
F
.64692 .35308 m
.64692 .35423 L
.64806 .35423 L
.64806 .35308 L
F
.67893 .35308 m
.67893 .35423 L
.68007 .35423 L
.68007 .35308 L
F
.61147 .35423 m
.61147 .35537 L
.61262 .35537 L
.61262 .35423 L
F
.64349 .35423 m
.64349 .35537 L
.64463 .35537 L
.64463 .35423 L
F
.64463 .35423 m
.64463 .35537 L
.64577 .35537 L
.64577 .35423 L
F
.64577 .35423 m
.64577 .35537 L
.64692 .35537 L
.64692 .35423 L
F
.67779 .35423 m
.67779 .35537 L
.67893 .35537 L
.67893 .35423 L
F
.61033 .35537 m
.61033 .35651 L
.61147 .35651 L
.61147 .35537 L
F
.64234 .35537 m
.64234 .35651 L
.64349 .35651 L
.64349 .35537 L
F
.64349 .35537 m
.64349 .35651 L
.64463 .35651 L
.64463 .35537 L
F
.64463 .35537 m
.64463 .35651 L
.64577 .35651 L
.64577 .35537 L
F
.67664 .35537 m
.67664 .35651 L
.67779 .35651 L
.67779 .35537 L
F
.60919 .35651 m
.60919 .35766 L
.61033 .35766 L
.61033 .35651 L
F
.6412 .35651 m
.6412 .35766 L
.64234 .35766 L
.64234 .35651 L
F
.64234 .35651 m
.64234 .35766 L
.64349 .35766 L
.64349 .35651 L
F
.64349 .35651 m
.64349 .35766 L
.64463 .35766 L
.64463 .35651 L
F
.6755 .35651 m
.6755 .35766 L
.67664 .35766 L
.67664 .35651 L
F
.60804 .35766 m
.60804 .3588 L
.60919 .3588 L
.60919 .35766 L
F
.64006 .35766 m
.64006 .3588 L
.6412 .3588 L
.6412 .35766 L
F
.6412 .35766 m
.6412 .3588 L
.64234 .3588 L
.64234 .35766 L
F
.64234 .35766 m
.64234 .3588 L
.64349 .3588 L
.64349 .35766 L
F
.67436 .35766 m
.67436 .3588 L
.6755 .3588 L
.6755 .35766 L
F
.6069 .3588 m
.6069 .35994 L
.60804 .35994 L
.60804 .3588 L
F
.63891 .3588 m
.63891 .35994 L
.64006 .35994 L
.64006 .3588 L
F
.64006 .3588 m
.64006 .35994 L
.6412 .35994 L
.6412 .3588 L
F
.6412 .3588 m
.6412 .35994 L
.64234 .35994 L
.64234 .3588 L
F
.67321 .3588 m
.67321 .35994 L
.67436 .35994 L
.67436 .3588 L
F
.60576 .35994 m
.60576 .36109 L
.6069 .36109 L
.6069 .35994 L
F
.63777 .35994 m
.63777 .36109 L
.63891 .36109 L
.63891 .35994 L
F
.63891 .35994 m
.63891 .36109 L
.64006 .36109 L
.64006 .35994 L
F
.64006 .35994 m
.64006 .36109 L
.6412 .36109 L
.6412 .35994 L
F
.67207 .35994 m
.67207 .36109 L
.67321 .36109 L
.67321 .35994 L
F
.60461 .36109 m
.60461 .36223 L
.60576 .36223 L
.60576 .36109 L
F
.63663 .36109 m
.63663 .36223 L
.63777 .36223 L
.63777 .36109 L
F
.63777 .36109 m
.63777 .36223 L
.63891 .36223 L
.63891 .36109 L
F
.63891 .36109 m
.63891 .36223 L
.64006 .36223 L
.64006 .36109 L
F
.67093 .36109 m
.67093 .36223 L
.67207 .36223 L
.67207 .36109 L
F
.60347 .36223 m
.60347 .36337 L
.60461 .36337 L
.60461 .36223 L
F
.63548 .36223 m
.63548 .36337 L
.63663 .36337 L
.63663 .36223 L
F
.63663 .36223 m
.63663 .36337 L
.63777 .36337 L
.63777 .36223 L
F
.63777 .36223 m
.63777 .36337 L
.63891 .36337 L
.63891 .36223 L
F
.66978 .36223 m
.66978 .36337 L
.67093 .36337 L
.67093 .36223 L
F
.60233 .36337 m
.60233 .36452 L
.60347 .36452 L
.60347 .36337 L
F
.63434 .36337 m
.63434 .36452 L
.63548 .36452 L
.63548 .36337 L
F
.63548 .36337 m
.63548 .36452 L
.63663 .36452 L
.63663 .36337 L
F
.63663 .36337 m
.63663 .36452 L
.63777 .36452 L
.63777 .36337 L
F
.66864 .36337 m
.66864 .36452 L
.66978 .36452 L
.66978 .36337 L
F
.60118 .36452 m
.60118 .36566 L
.60233 .36566 L
.60233 .36452 L
F
.6332 .36452 m
.6332 .36566 L
.63434 .36566 L
.63434 .36452 L
F
.63434 .36452 m
.63434 .36566 L
.63548 .36566 L
.63548 .36452 L
F
.63548 .36452 m
.63548 .36566 L
.63663 .36566 L
.63663 .36452 L
F
.6675 .36452 m
.6675 .36566 L
.66864 .36566 L
.66864 .36452 L
F
.60004 .36566 m
.60004 .3668 L
.60118 .3668 L
.60118 .36566 L
F
.63205 .36566 m
.63205 .3668 L
.6332 .3668 L
.6332 .36566 L
F
.6332 .36566 m
.6332 .3668 L
.63434 .3668 L
.63434 .36566 L
F
.63434 .36566 m
.63434 .3668 L
.63548 .3668 L
.63548 .36566 L
F
.66635 .36566 m
.66635 .3668 L
.6675 .3668 L
.6675 .36566 L
F
.5989 .3668 m
.5989 .36795 L
.60004 .36795 L
.60004 .3668 L
F
.63091 .3668 m
.63091 .36795 L
.63205 .36795 L
.63205 .3668 L
F
.63205 .3668 m
.63205 .36795 L
.6332 .36795 L
.6332 .3668 L
F
.6332 .3668 m
.6332 .36795 L
.63434 .36795 L
.63434 .3668 L
F
.66521 .3668 m
.66521 .36795 L
.66635 .36795 L
.66635 .3668 L
F
.59775 .36795 m
.59775 .36909 L
.5989 .36909 L
.5989 .36795 L
F
.62977 .36795 m
.62977 .36909 L
.63091 .36909 L
.63091 .36795 L
F
.63091 .36795 m
.63091 .36909 L
.63205 .36909 L
.63205 .36795 L
F
.63205 .36795 m
.63205 .36909 L
.6332 .36909 L
.6332 .36795 L
F
.66407 .36795 m
.66407 .36909 L
.66521 .36909 L
.66521 .36795 L
F
.59661 .36909 m
.59661 .37023 L
.59775 .37023 L
.59775 .36909 L
F
.62862 .36909 m
.62862 .37023 L
.62977 .37023 L
.62977 .36909 L
F
.62977 .36909 m
.62977 .37023 L
.63091 .37023 L
.63091 .36909 L
F
.63091 .36909 m
.63091 .37023 L
.63205 .37023 L
.63205 .36909 L
F
.66292 .36909 m
.66292 .37023 L
.66407 .37023 L
.66407 .36909 L
F
.59547 .37023 m
.59547 .37138 L
.59661 .37138 L
.59661 .37023 L
F
.62748 .37023 m
.62748 .37138 L
.62862 .37138 L
.62862 .37023 L
F
.62862 .37023 m
.62862 .37138 L
.62977 .37138 L
.62977 .37023 L
F
.62977 .37023 m
.62977 .37138 L
.63091 .37138 L
.63091 .37023 L
F
.66178 .37023 m
.66178 .37138 L
.66292 .37138 L
.66292 .37023 L
F
.59432 .37138 m
.59432 .37252 L
.59547 .37252 L
.59547 .37138 L
F
.62634 .37138 m
.62634 .37252 L
.62748 .37252 L
.62748 .37138 L
F
.62748 .37138 m
.62748 .37252 L
.62862 .37252 L
.62862 .37138 L
F
.62862 .37138 m
.62862 .37252 L
.62977 .37252 L
.62977 .37138 L
F
.66064 .37138 m
.66064 .37252 L
.66178 .37252 L
.66178 .37138 L
F
.59318 .37252 m
.59318 .37366 L
.59432 .37366 L
.59432 .37252 L
F
.62519 .37252 m
.62519 .37366 L
.62634 .37366 L
.62634 .37252 L
F
.62634 .37252 m
.62634 .37366 L
.62748 .37366 L
.62748 .37252 L
F
.62748 .37252 m
.62748 .37366 L
.62862 .37366 L
.62862 .37252 L
F
.65949 .37252 m
.65949 .37366 L
.66064 .37366 L
.66064 .37252 L
F
.59204 .37366 m
.59204 .37481 L
.59318 .37481 L
.59318 .37366 L
F
.62405 .37366 m
.62405 .37481 L
.62519 .37481 L
.62519 .37366 L
F
.62519 .37366 m
.62519 .37481 L
.62634 .37481 L
.62634 .37366 L
F
.62634 .37366 m
.62634 .37481 L
.62748 .37481 L
.62748 .37366 L
F
.65835 .37366 m
.65835 .37481 L
.65949 .37481 L
.65949 .37366 L
F
.59089 .37481 m
.59089 .37595 L
.59204 .37595 L
.59204 .37481 L
F
.62291 .37481 m
.62291 .37595 L
.62405 .37595 L
.62405 .37481 L
F
.62405 .37481 m
.62405 .37595 L
.62519 .37595 L
.62519 .37481 L
F
.62519 .37481 m
.62519 .37595 L
.62634 .37595 L
.62634 .37481 L
F
.65721 .37481 m
.65721 .37595 L
.65835 .37595 L
.65835 .37481 L
F
.58975 .37595 m
.58975 .37709 L
.59089 .37709 L
.59089 .37595 L
F
.62176 .37595 m
.62176 .37709 L
.62291 .37709 L
.62291 .37595 L
F
.62291 .37595 m
.62291 .37709 L
.62405 .37709 L
.62405 .37595 L
F
.62405 .37595 m
.62405 .37709 L
.62519 .37709 L
.62519 .37595 L
F
.65606 .37595 m
.65606 .37709 L
.65721 .37709 L
.65721 .37595 L
F
.58861 .37709 m
.58861 .37824 L
.58975 .37824 L
.58975 .37709 L
F
.62062 .37709 m
.62062 .37824 L
.62176 .37824 L
.62176 .37709 L
F
.62176 .37709 m
.62176 .37824 L
.62291 .37824 L
.62291 .37709 L
F
.62291 .37709 m
.62291 .37824 L
.62405 .37824 L
.62405 .37709 L
F
.65492 .37709 m
.65492 .37824 L
.65606 .37824 L
.65606 .37709 L
F
.58746 .37824 m
.58746 .37938 L
.58861 .37938 L
.58861 .37824 L
F
.61948 .37824 m
.61948 .37938 L
.62062 .37938 L
.62062 .37824 L
F
.62062 .37824 m
.62062 .37938 L
.62176 .37938 L
.62176 .37824 L
F
.62176 .37824 m
.62176 .37938 L
.62291 .37938 L
.62291 .37824 L
F
.65378 .37824 m
.65378 .37938 L
.65492 .37938 L
.65492 .37824 L
F
.58632 .37938 m
.58632 .38052 L
.58746 .38052 L
.58746 .37938 L
F
.61833 .37938 m
.61833 .38052 L
.61948 .38052 L
.61948 .37938 L
F
.61948 .37938 m
.61948 .38052 L
.62062 .38052 L
.62062 .37938 L
F
.62062 .37938 m
.62062 .38052 L
.62176 .38052 L
.62176 .37938 L
F
.65263 .37938 m
.65263 .38052 L
.65378 .38052 L
.65378 .37938 L
F
.58518 .38052 m
.58518 .38167 L
.58632 .38167 L
.58632 .38052 L
F
.61719 .38052 m
.61719 .38167 L
.61833 .38167 L
.61833 .38052 L
F
.61833 .38052 m
.61833 .38167 L
.61948 .38167 L
.61948 .38052 L
F
.61948 .38052 m
.61948 .38167 L
.62062 .38167 L
.62062 .38052 L
F
.65149 .38052 m
.65149 .38167 L
.65263 .38167 L
.65263 .38052 L
F
.58403 .38167 m
.58403 .38281 L
.58518 .38281 L
.58518 .38167 L
F
.61605 .38167 m
.61605 .38281 L
.61719 .38281 L
.61719 .38167 L
F
.61719 .38167 m
.61719 .38281 L
.61833 .38281 L
.61833 .38167 L
F
.61833 .38167 m
.61833 .38281 L
.61948 .38281 L
.61948 .38167 L
F
.65035 .38167 m
.65035 .38281 L
.65149 .38281 L
.65149 .38167 L
F
.58289 .38281 m
.58289 .38395 L
.58403 .38395 L
.58403 .38281 L
F
.61605 .38281 m
.61605 .38395 L
.61719 .38395 L
.61719 .38281 L
F
.61719 .38281 m
.61719 .38395 L
.61833 .38395 L
.61833 .38281 L
F
.6492 .38281 m
.6492 .38395 L
.65035 .38395 L
.65035 .38281 L
F
.58175 .38395 m
.58175 .3851 L
.58289 .3851 L
.58289 .38395 L
F
.61376 .38395 m
.61376 .3851 L
.6149 .3851 L
.6149 .38395 L
F
.6149 .38395 m
.6149 .3851 L
.61605 .3851 L
.61605 .38395 L
F
.64806 .38395 m
.64806 .3851 L
.6492 .3851 L
.6492 .38395 L
F
.5806 .3851 m
.5806 .38624 L
.58175 .38624 L
.58175 .3851 L
F
.61262 .3851 m
.61262 .38624 L
.61376 .38624 L
.61376 .3851 L
F
.61376 .3851 m
.61376 .38624 L
.6149 .38624 L
.6149 .3851 L
F
.6149 .3851 m
.6149 .38624 L
.61605 .38624 L
.61605 .3851 L
F
.64692 .3851 m
.64692 .38624 L
.64806 .38624 L
.64806 .3851 L
F
.57946 .38624 m
.57946 .38738 L
.5806 .38738 L
.5806 .38624 L
F
.61147 .38624 m
.61147 .38738 L
.61262 .38738 L
.61262 .38624 L
F
.61262 .38624 m
.61262 .38738 L
.61376 .38738 L
.61376 .38624 L
F
.61376 .38624 m
.61376 .38738 L
.6149 .38738 L
.6149 .38624 L
F
.64577 .38624 m
.64577 .38738 L
.64692 .38738 L
.64692 .38624 L
F
.57832 .38738 m
.57832 .38853 L
.57946 .38853 L
.57946 .38738 L
F
.61033 .38738 m
.61033 .38853 L
.61147 .38853 L
.61147 .38738 L
F
.61147 .38738 m
.61147 .38853 L
.61262 .38853 L
.61262 .38738 L
F
.61262 .38738 m
.61262 .38853 L
.61376 .38853 L
.61376 .38738 L
F
.64463 .38738 m
.64463 .38853 L
.64577 .38853 L
.64577 .38738 L
F
.57717 .38853 m
.57717 .38967 L
.57832 .38967 L
.57832 .38853 L
F
.60919 .38853 m
.60919 .38967 L
.61033 .38967 L
.61033 .38853 L
F
.61033 .38853 m
.61033 .38967 L
.61147 .38967 L
.61147 .38853 L
F
.61147 .38853 m
.61147 .38967 L
.61262 .38967 L
.61262 .38853 L
F
.64349 .38853 m
.64349 .38967 L
.64463 .38967 L
.64463 .38853 L
F
.57603 .38967 m
.57603 .39081 L
.57717 .39081 L
.57717 .38967 L
F
.60804 .38967 m
.60804 .39081 L
.60919 .39081 L
.60919 .38967 L
F
.60919 .38967 m
.60919 .39081 L
.61033 .39081 L
.61033 .38967 L
F
.61033 .38967 m
.61033 .39081 L
.61147 .39081 L
.61147 .38967 L
F
.64234 .38967 m
.64234 .39081 L
.64349 .39081 L
.64349 .38967 L
F
.57489 .39081 m
.57489 .39196 L
.57603 .39196 L
.57603 .39081 L
F
.6069 .39081 m
.6069 .39196 L
.60804 .39196 L
.60804 .39081 L
F
.60804 .39081 m
.60804 .39196 L
.60919 .39196 L
.60919 .39081 L
F
.60919 .39081 m
.60919 .39196 L
.61033 .39196 L
.61033 .39081 L
F
.6412 .39081 m
.6412 .39196 L
.64234 .39196 L
.64234 .39081 L
F
.57374 .39196 m
.57374 .3931 L
.57489 .3931 L
.57489 .39196 L
F
.60576 .39196 m
.60576 .3931 L
.6069 .3931 L
.6069 .39196 L
F
.6069 .39196 m
.6069 .3931 L
.60804 .3931 L
.60804 .39196 L
F
.60804 .39196 m
.60804 .3931 L
.60919 .3931 L
.60919 .39196 L
F
.64006 .39196 m
.64006 .3931 L
.6412 .3931 L
.6412 .39196 L
F
.5726 .3931 m
.5726 .39424 L
.57374 .39424 L
.57374 .3931 L
F
.60461 .3931 m
.60461 .39424 L
.60576 .39424 L
.60576 .3931 L
F
.60576 .3931 m
.60576 .39424 L
.6069 .39424 L
.6069 .3931 L
F
.6069 .3931 m
.6069 .39424 L
.60804 .39424 L
.60804 .3931 L
F
.63891 .3931 m
.63891 .39424 L
.64006 .39424 L
.64006 .3931 L
F
.57146 .39424 m
.57146 .39539 L
.5726 .39539 L
.5726 .39424 L
F
.60347 .39424 m
.60347 .39539 L
.60461 .39539 L
.60461 .39424 L
F
.60461 .39424 m
.60461 .39539 L
.60576 .39539 L
.60576 .39424 L
F
.60576 .39424 m
.60576 .39539 L
.6069 .39539 L
.6069 .39424 L
F
.63777 .39424 m
.63777 .39539 L
.63891 .39539 L
.63891 .39424 L
F
.57031 .39539 m
.57031 .39653 L
.57146 .39653 L
.57146 .39539 L
F
.60233 .39539 m
.60233 .39653 L
.60347 .39653 L
.60347 .39539 L
F
.60347 .39539 m
.60347 .39653 L
.60461 .39653 L
.60461 .39539 L
F
.60461 .39539 m
.60461 .39653 L
.60576 .39653 L
.60576 .39539 L
F
.63663 .39539 m
.63663 .39653 L
.63777 .39653 L
.63777 .39539 L
F
.56917 .39653 m
.56917 .39767 L
.57031 .39767 L
.57031 .39653 L
F
.60118 .39653 m
.60118 .39767 L
.60233 .39767 L
.60233 .39653 L
F
.60233 .39653 m
.60233 .39767 L
.60347 .39767 L
.60347 .39653 L
F
.60347 .39653 m
.60347 .39767 L
.60461 .39767 L
.60461 .39653 L
F
.63548 .39653 m
.63548 .39767 L
.63663 .39767 L
.63663 .39653 L
F
.56803 .39767 m
.56803 .39882 L
.56917 .39882 L
.56917 .39767 L
F
.60004 .39767 m
.60004 .39882 L
.60118 .39882 L
.60118 .39767 L
F
.60118 .39767 m
.60118 .39882 L
.60233 .39882 L
.60233 .39767 L
F
.60233 .39767 m
.60233 .39882 L
.60347 .39882 L
.60347 .39767 L
F
.63434 .39767 m
.63434 .39882 L
.63548 .39882 L
.63548 .39767 L
F
.56688 .39882 m
.56688 .39996 L
.56803 .39996 L
.56803 .39882 L
F
.5989 .39882 m
.5989 .39996 L
.60004 .39996 L
.60004 .39882 L
F
.60004 .39882 m
.60004 .39996 L
.60118 .39996 L
.60118 .39882 L
F
.60118 .39882 m
.60118 .39996 L
.60233 .39996 L
.60233 .39882 L
F
.6332 .39882 m
.6332 .39996 L
.63434 .39996 L
.63434 .39882 L
F
.56574 .39996 m
.56574 .4011 L
.56688 .4011 L
.56688 .39996 L
F
.59775 .39996 m
.59775 .4011 L
.5989 .4011 L
.5989 .39996 L
F
.5989 .39996 m
.5989 .4011 L
.60004 .4011 L
.60004 .39996 L
F
.60004 .39996 m
.60004 .4011 L
.60118 .4011 L
.60118 .39996 L
F
.63205 .39996 m
.63205 .4011 L
.6332 .4011 L
.6332 .39996 L
F
.5646 .4011 m
.5646 .40225 L
.56574 .40225 L
.56574 .4011 L
F
.59661 .4011 m
.59661 .40225 L
.59775 .40225 L
.59775 .4011 L
F
.59775 .4011 m
.59775 .40225 L
.5989 .40225 L
.5989 .4011 L
F
.5989 .4011 m
.5989 .40225 L
.60004 .40225 L
.60004 .4011 L
F
.63091 .4011 m
.63091 .40225 L
.63205 .40225 L
.63205 .4011 L
F
.56345 .40225 m
.56345 .40339 L
.5646 .40339 L
.5646 .40225 L
F
.59547 .40225 m
.59547 .40339 L
.59661 .40339 L
.59661 .40225 L
F
.59661 .40225 m
.59661 .40339 L
.59775 .40339 L
.59775 .40225 L
F
.59775 .40225 m
.59775 .40339 L
.5989 .40339 L
.5989 .40225 L
F
.62977 .40225 m
.62977 .40339 L
.63091 .40339 L
.63091 .40225 L
F
.56231 .40339 m
.56231 .40453 L
.56345 .40453 L
.56345 .40339 L
F
.59432 .40339 m
.59432 .40453 L
.59547 .40453 L
.59547 .40339 L
F
.59547 .40339 m
.59547 .40453 L
.59661 .40453 L
.59661 .40339 L
F
.59661 .40339 m
.59661 .40453 L
.59775 .40453 L
.59775 .40339 L
F
.62862 .40339 m
.62862 .40453 L
.62977 .40453 L
.62977 .40339 L
F
.56117 .40453 m
.56117 .40568 L
.56231 .40568 L
.56231 .40453 L
F
.59318 .40453 m
.59318 .40568 L
.59432 .40568 L
.59432 .40453 L
F
.59432 .40453 m
.59432 .40568 L
.59547 .40568 L
.59547 .40453 L
F
.59547 .40453 m
.59547 .40568 L
.59661 .40568 L
.59661 .40453 L
F
.62748 .40453 m
.62748 .40568 L
.62862 .40568 L
.62862 .40453 L
F
.56002 .40568 m
.56002 .40682 L
.56117 .40682 L
.56117 .40568 L
F
.59204 .40568 m
.59204 .40682 L
.59318 .40682 L
.59318 .40568 L
F
.59318 .40568 m
.59318 .40682 L
.59432 .40682 L
.59432 .40568 L
F
.59432 .40568 m
.59432 .40682 L
.59547 .40682 L
.59547 .40568 L
F
.62634 .40568 m
.62634 .40682 L
.62748 .40682 L
.62748 .40568 L
F
.55888 .40682 m
.55888 .40796 L
.56002 .40796 L
.56002 .40682 L
F
.59089 .40682 m
.59089 .40796 L
.59204 .40796 L
.59204 .40682 L
F
.59204 .40682 m
.59204 .40796 L
.59318 .40796 L
.59318 .40682 L
F
.59318 .40682 m
.59318 .40796 L
.59432 .40796 L
.59432 .40682 L
F
.62519 .40682 m
.62519 .40796 L
.62634 .40796 L
.62634 .40682 L
F
.55774 .40796 m
.55774 .40911 L
.55888 .40911 L
.55888 .40796 L
F
.58975 .40796 m
.58975 .40911 L
.59089 .40911 L
.59089 .40796 L
F
.59089 .40796 m
.59089 .40911 L
.59204 .40911 L
.59204 .40796 L
F
.59204 .40796 m
.59204 .40911 L
.59318 .40911 L
.59318 .40796 L
F
.62405 .40796 m
.62405 .40911 L
.62519 .40911 L
.62519 .40796 L
F
.55659 .40911 m
.55659 .41025 L
.55774 .41025 L
.55774 .40911 L
F
.58861 .40911 m
.58861 .41025 L
.58975 .41025 L
.58975 .40911 L
F
.58975 .40911 m
.58975 .41025 L
.59089 .41025 L
.59089 .40911 L
F
.59089 .40911 m
.59089 .41025 L
.59204 .41025 L
.59204 .40911 L
F
.62291 .40911 m
.62291 .41025 L
.62405 .41025 L
.62405 .40911 L
F
.55545 .41025 m
.55545 .41139 L
.55659 .41139 L
.55659 .41025 L
F
.58746 .41025 m
.58746 .41139 L
.58861 .41139 L
.58861 .41025 L
F
.58861 .41025 m
.58861 .41139 L
.58975 .41139 L
.58975 .41025 L
F
.58975 .41025 m
.58975 .41139 L
.59089 .41139 L
.59089 .41025 L
F
.62176 .41025 m
.62176 .41139 L
.62291 .41139 L
.62291 .41025 L
F
.55431 .41139 m
.55431 .41254 L
.55545 .41254 L
.55545 .41139 L
F
.58632 .41139 m
.58632 .41254 L
.58746 .41254 L
.58746 .41139 L
F
.58746 .41139 m
.58746 .41254 L
.58861 .41254 L
.58861 .41139 L
F
.58861 .41139 m
.58861 .41254 L
.58975 .41254 L
.58975 .41139 L
F
.62062 .41139 m
.62062 .41254 L
.62176 .41254 L
.62176 .41139 L
F
.55316 .41254 m
.55316 .41368 L
.55431 .41368 L
.55431 .41254 L
F
.58518 .41254 m
.58518 .41368 L
.58632 .41368 L
.58632 .41254 L
F
.58632 .41254 m
.58632 .41368 L
.58746 .41368 L
.58746 .41254 L
F
.58746 .41254 m
.58746 .41368 L
.58861 .41368 L
.58861 .41254 L
F
.61948 .41254 m
.61948 .41368 L
.62062 .41368 L
.62062 .41254 L
F
.55202 .41368 m
.55202 .41482 L
.55316 .41482 L
.55316 .41368 L
F
.58403 .41368 m
.58403 .41482 L
.58518 .41482 L
.58518 .41368 L
F
.58518 .41368 m
.58518 .41482 L
.58632 .41482 L
.58632 .41368 L
F
.58632 .41368 m
.58632 .41482 L
.58746 .41482 L
.58746 .41368 L
F
.61833 .41368 m
.61833 .41482 L
.61948 .41482 L
.61948 .41368 L
F
.55088 .41482 m
.55088 .41597 L
.55202 .41597 L
.55202 .41482 L
F
.58289 .41482 m
.58289 .41597 L
.58403 .41597 L
.58403 .41482 L
F
.58403 .41482 m
.58403 .41597 L
.58518 .41597 L
.58518 .41482 L
F
.58518 .41482 m
.58518 .41597 L
.58632 .41597 L
.58632 .41482 L
F
.61719 .41482 m
.61719 .41597 L
.61833 .41597 L
.61833 .41482 L
F
.54973 .41597 m
.54973 .41711 L
.55088 .41711 L
.55088 .41597 L
F
.58289 .41597 m
.58289 .41711 L
.58403 .41711 L
.58403 .41597 L
F
.58403 .41597 m
.58403 .41711 L
.58518 .41711 L
.58518 .41597 L
F
.61605 .41597 m
.61605 .41711 L
.61719 .41711 L
.61719 .41597 L
F
.54859 .41711 m
.54859 .41825 L
.54973 .41825 L
.54973 .41711 L
F
.5806 .41711 m
.5806 .41825 L
.58175 .41825 L
.58175 .41711 L
F
.58175 .41711 m
.58175 .41825 L
.58289 .41825 L
.58289 .41711 L
F
.6149 .41711 m
.6149 .41825 L
.61605 .41825 L
.61605 .41711 L
F
.54745 .41825 m
.54745 .4194 L
.54859 .4194 L
.54859 .41825 L
F
.57946 .41825 m
.57946 .4194 L
.5806 .4194 L
.5806 .41825 L
F
.5806 .41825 m
.5806 .4194 L
.58175 .4194 L
.58175 .41825 L
F
.58175 .41825 m
.58175 .4194 L
.58289 .4194 L
.58289 .41825 L
F
.61376 .41825 m
.61376 .4194 L
.6149 .4194 L
.6149 .41825 L
F
.5463 .4194 m
.5463 .42054 L
.54745 .42054 L
.54745 .4194 L
F
.57832 .4194 m
.57832 .42054 L
.57946 .42054 L
.57946 .4194 L
F
.57946 .4194 m
.57946 .42054 L
.5806 .42054 L
.5806 .4194 L
F
.5806 .4194 m
.5806 .42054 L
.58175 .42054 L
.58175 .4194 L
F
.61262 .4194 m
.61262 .42054 L
.61376 .42054 L
.61376 .4194 L
F
.54516 .42054 m
.54516 .42168 L
.5463 .42168 L
.5463 .42054 L
F
.57717 .42054 m
.57717 .42168 L
.57832 .42168 L
.57832 .42054 L
F
.57832 .42054 m
.57832 .42168 L
.57946 .42168 L
.57946 .42054 L
F
.57946 .42054 m
.57946 .42168 L
.5806 .42168 L
.5806 .42054 L
F
.61147 .42054 m
.61147 .42168 L
.61262 .42168 L
.61262 .42054 L
F
.54402 .42168 m
.54402 .42283 L
.54516 .42283 L
.54516 .42168 L
F
.57603 .42168 m
.57603 .42283 L
.57717 .42283 L
.57717 .42168 L
F
.57717 .42168 m
.57717 .42283 L
.57832 .42283 L
.57832 .42168 L
F
.57832 .42168 m
.57832 .42283 L
.57946 .42283 L
.57946 .42168 L
F
.61033 .42168 m
.61033 .42283 L
.61147 .42283 L
.61147 .42168 L
F
.54287 .42283 m
.54287 .42397 L
.54402 .42397 L
.54402 .42283 L
F
.57489 .42283 m
.57489 .42397 L
.57603 .42397 L
.57603 .42283 L
F
.57603 .42283 m
.57603 .42397 L
.57717 .42397 L
.57717 .42283 L
F
.57717 .42283 m
.57717 .42397 L
.57832 .42397 L
.57832 .42283 L
F
.60919 .42283 m
.60919 .42397 L
.61033 .42397 L
.61033 .42283 L
F
.54173 .42397 m
.54173 .42511 L
.54287 .42511 L
.54287 .42397 L
F
.57374 .42397 m
.57374 .42511 L
.57489 .42511 L
.57489 .42397 L
F
.57489 .42397 m
.57489 .42511 L
.57603 .42511 L
.57603 .42397 L
F
.57603 .42397 m
.57603 .42511 L
.57717 .42511 L
.57717 .42397 L
F
.60804 .42397 m
.60804 .42511 L
.60919 .42511 L
.60919 .42397 L
F
.54059 .42511 m
.54059 .42626 L
.54173 .42626 L
.54173 .42511 L
F
.5726 .42511 m
.5726 .42626 L
.57374 .42626 L
.57374 .42511 L
F
.57374 .42511 m
.57374 .42626 L
.57489 .42626 L
.57489 .42511 L
F
.57489 .42511 m
.57489 .42626 L
.57603 .42626 L
.57603 .42511 L
F
.6069 .42511 m
.6069 .42626 L
.60804 .42626 L
.60804 .42511 L
F
.53944 .42626 m
.53944 .4274 L
.54059 .4274 L
.54059 .42626 L
F
.57146 .42626 m
.57146 .4274 L
.5726 .4274 L
.5726 .42626 L
F
.5726 .42626 m
.5726 .4274 L
.57374 .4274 L
.57374 .42626 L
F
.57374 .42626 m
.57374 .4274 L
.57489 .4274 L
.57489 .42626 L
F
.60576 .42626 m
.60576 .4274 L
.6069 .4274 L
.6069 .42626 L
F
.5383 .4274 m
.5383 .42854 L
.53944 .42854 L
.53944 .4274 L
F
.57031 .4274 m
.57031 .42854 L
.57146 .42854 L
.57146 .4274 L
F
.57146 .4274 m
.57146 .42854 L
.5726 .42854 L
.5726 .4274 L
F
.5726 .4274 m
.5726 .42854 L
.57374 .42854 L
.57374 .4274 L
F
.60461 .4274 m
.60461 .42854 L
.60576 .42854 L
.60576 .4274 L
F
.53716 .42854 m
.53716 .42969 L
.5383 .42969 L
.5383 .42854 L
F
.56917 .42854 m
.56917 .42969 L
.57031 .42969 L
.57031 .42854 L
F
.57031 .42854 m
.57031 .42969 L
.57146 .42969 L
.57146 .42854 L
F
.57146 .42854 m
.57146 .42969 L
.5726 .42969 L
.5726 .42854 L
F
.60347 .42854 m
.60347 .42969 L
.60461 .42969 L
.60461 .42854 L
F
.53601 .42969 m
.53601 .43083 L
.53716 .43083 L
.53716 .42969 L
F
.56803 .42969 m
.56803 .43083 L
.56917 .43083 L
.56917 .42969 L
F
.56917 .42969 m
.56917 .43083 L
.57031 .43083 L
.57031 .42969 L
F
.57031 .42969 m
.57031 .43083 L
.57146 .43083 L
.57146 .42969 L
F
.60233 .42969 m
.60233 .43083 L
.60347 .43083 L
.60347 .42969 L
F
.53487 .43083 m
.53487 .43197 L
.53601 .43197 L
.53601 .43083 L
F
.56688 .43083 m
.56688 .43197 L
.56803 .43197 L
.56803 .43083 L
F
.56803 .43083 m
.56803 .43197 L
.56917 .43197 L
.56917 .43083 L
F
.56917 .43083 m
.56917 .43197 L
.57031 .43197 L
.57031 .43083 L
F
.60118 .43083 m
.60118 .43197 L
.60233 .43197 L
.60233 .43083 L
F
.53373 .43197 m
.53373 .43312 L
.53487 .43312 L
.53487 .43197 L
F
.56574 .43197 m
.56574 .43312 L
.56688 .43312 L
.56688 .43197 L
F
.56688 .43197 m
.56688 .43312 L
.56803 .43312 L
.56803 .43197 L
F
.56803 .43197 m
.56803 .43312 L
.56917 .43312 L
.56917 .43197 L
F
.60004 .43197 m
.60004 .43312 L
.60118 .43312 L
.60118 .43197 L
F
.53258 .43312 m
.53258 .43426 L
.53373 .43426 L
.53373 .43312 L
F
.5646 .43312 m
.5646 .43426 L
.56574 .43426 L
.56574 .43312 L
F
.56574 .43312 m
.56574 .43426 L
.56688 .43426 L
.56688 .43312 L
F
.56688 .43312 m
.56688 .43426 L
.56803 .43426 L
.56803 .43312 L
F
.5989 .43312 m
.5989 .43426 L
.60004 .43426 L
.60004 .43312 L
F
.53144 .43426 m
.53144 .4354 L
.53258 .4354 L
.53258 .43426 L
F
.56345 .43426 m
.56345 .4354 L
.5646 .4354 L
.5646 .43426 L
F
.5646 .43426 m
.5646 .4354 L
.56574 .4354 L
.56574 .43426 L
F
.56574 .43426 m
.56574 .4354 L
.56688 .4354 L
.56688 .43426 L
F
.59775 .43426 m
.59775 .4354 L
.5989 .4354 L
.5989 .43426 L
F
.5303 .4354 m
.5303 .43655 L
.53144 .43655 L
.53144 .4354 L
F
.56231 .4354 m
.56231 .43655 L
.56345 .43655 L
.56345 .4354 L
F
.56345 .4354 m
.56345 .43655 L
.5646 .43655 L
.5646 .4354 L
F
.5646 .4354 m
.5646 .43655 L
.56574 .43655 L
.56574 .4354 L
F
.59661 .4354 m
.59661 .43655 L
.59775 .43655 L
.59775 .4354 L
F
.52915 .43655 m
.52915 .43769 L
.5303 .43769 L
.5303 .43655 L
F
.56117 .43655 m
.56117 .43769 L
.56231 .43769 L
.56231 .43655 L
F
.56231 .43655 m
.56231 .43769 L
.56345 .43769 L
.56345 .43655 L
F
.56345 .43655 m
.56345 .43769 L
.5646 .43769 L
.5646 .43655 L
F
.59547 .43655 m
.59547 .43769 L
.59661 .43769 L
.59661 .43655 L
F
.52801 .43769 m
.52801 .43883 L
.52915 .43883 L
.52915 .43769 L
F
.56002 .43769 m
.56002 .43883 L
.56117 .43883 L
.56117 .43769 L
F
.56117 .43769 m
.56117 .43883 L
.56231 .43883 L
.56231 .43769 L
F
.56231 .43769 m
.56231 .43883 L
.56345 .43883 L
.56345 .43769 L
F
.59432 .43769 m
.59432 .43883 L
.59547 .43883 L
.59547 .43769 L
F
.52687 .43883 m
.52687 .43998 L
.52801 .43998 L
.52801 .43883 L
F
.55888 .43883 m
.55888 .43998 L
.56002 .43998 L
.56002 .43883 L
F
.56002 .43883 m
.56002 .43998 L
.56117 .43998 L
.56117 .43883 L
F
.56117 .43883 m
.56117 .43998 L
.56231 .43998 L
.56231 .43883 L
F
.59318 .43883 m
.59318 .43998 L
.59432 .43998 L
.59432 .43883 L
F
.52572 .43998 m
.52572 .44112 L
.52687 .44112 L
.52687 .43998 L
F
.55774 .43998 m
.55774 .44112 L
.55888 .44112 L
.55888 .43998 L
F
.55888 .43998 m
.55888 .44112 L
.56002 .44112 L
.56002 .43998 L
F
.56002 .43998 m
.56002 .44112 L
.56117 .44112 L
.56117 .43998 L
F
.59204 .43998 m
.59204 .44112 L
.59318 .44112 L
.59318 .43998 L
F
.52458 .44112 m
.52458 .44226 L
.52572 .44226 L
.52572 .44112 L
F
.55659 .44112 m
.55659 .44226 L
.55774 .44226 L
.55774 .44112 L
F
.55774 .44112 m
.55774 .44226 L
.55888 .44226 L
.55888 .44112 L
F
.55888 .44112 m
.55888 .44226 L
.56002 .44226 L
.56002 .44112 L
F
.59089 .44112 m
.59089 .44226 L
.59204 .44226 L
.59204 .44112 L
F
.52344 .44226 m
.52344 .44341 L
.52458 .44341 L
.52458 .44226 L
F
.55545 .44226 m
.55545 .44341 L
.55659 .44341 L
.55659 .44226 L
F
.55659 .44226 m
.55659 .44341 L
.55774 .44341 L
.55774 .44226 L
F
.55774 .44226 m
.55774 .44341 L
.55888 .44341 L
.55888 .44226 L
F
.58975 .44226 m
.58975 .44341 L
.59089 .44341 L
.59089 .44226 L
F
.52229 .44341 m
.52229 .44455 L
.52344 .44455 L
.52344 .44341 L
F
.55431 .44341 m
.55431 .44455 L
.55545 .44455 L
.55545 .44341 L
F
.55545 .44341 m
.55545 .44455 L
.55659 .44455 L
.55659 .44341 L
F
.55659 .44341 m
.55659 .44455 L
.55774 .44455 L
.55774 .44341 L
F
.58861 .44341 m
.58861 .44455 L
.58975 .44455 L
.58975 .44341 L
F
.52115 .44455 m
.52115 .44569 L
.52229 .44569 L
.52229 .44455 L
F
.55316 .44455 m
.55316 .44569 L
.55431 .44569 L
.55431 .44455 L
F
.55431 .44455 m
.55431 .44569 L
.55545 .44569 L
.55545 .44455 L
F
.55545 .44455 m
.55545 .44569 L
.55659 .44569 L
.55659 .44455 L
F
.58746 .44455 m
.58746 .44569 L
.58861 .44569 L
.58861 .44455 L
F
.52001 .44569 m
.52001 .44684 L
.52115 .44684 L
.52115 .44569 L
F
.55202 .44569 m
.55202 .44684 L
.55316 .44684 L
.55316 .44569 L
F
.55316 .44569 m
.55316 .44684 L
.55431 .44684 L
.55431 .44569 L
F
.55431 .44569 m
.55431 .44684 L
.55545 .44684 L
.55545 .44569 L
F
.58632 .44569 m
.58632 .44684 L
.58746 .44684 L
.58746 .44569 L
F
.51886 .44684 m
.51886 .44798 L
.52001 .44798 L
.52001 .44684 L
F
.55088 .44684 m
.55088 .44798 L
.55202 .44798 L
.55202 .44684 L
F
.55202 .44684 m
.55202 .44798 L
.55316 .44798 L
.55316 .44684 L
F
.55316 .44684 m
.55316 .44798 L
.55431 .44798 L
.55431 .44684 L
F
.58518 .44684 m
.58518 .44798 L
.58632 .44798 L
.58632 .44684 L
F
.51772 .44798 m
.51772 .44912 L
.51886 .44912 L
.51886 .44798 L
F
.54973 .44798 m
.54973 .44912 L
.55088 .44912 L
.55088 .44798 L
F
.55088 .44798 m
.55088 .44912 L
.55202 .44912 L
.55202 .44798 L
F
.55202 .44798 m
.55202 .44912 L
.55316 .44912 L
.55316 .44798 L
F
.58403 .44798 m
.58403 .44912 L
.58518 .44912 L
.58518 .44798 L
F
.51658 .44912 m
.51658 .45027 L
.51772 .45027 L
.51772 .44912 L
F
.54973 .44912 m
.54973 .45027 L
.55088 .45027 L
.55088 .44912 L
F
.55088 .44912 m
.55088 .45027 L
.55202 .45027 L
.55202 .44912 L
F
.58289 .44912 m
.58289 .45027 L
.58403 .45027 L
.58403 .44912 L
F
.51543 .45027 m
.51543 .45141 L
.51658 .45141 L
.51658 .45027 L
F
.54745 .45027 m
.54745 .45141 L
.54859 .45141 L
.54859 .45027 L
F
.54859 .45027 m
.54859 .45141 L
.54973 .45141 L
.54973 .45027 L
F
.58175 .45027 m
.58175 .45141 L
.58289 .45141 L
.58289 .45027 L
F
.51429 .45141 m
.51429 .45255 L
.51543 .45255 L
.51543 .45141 L
F
.5463 .45141 m
.5463 .45255 L
.54745 .45255 L
.54745 .45141 L
F
.54745 .45141 m
.54745 .45255 L
.54859 .45255 L
.54859 .45141 L
F
.54859 .45141 m
.54859 .45255 L
.54973 .45255 L
.54973 .45141 L
F
.5806 .45141 m
.5806 .45255 L
.58175 .45255 L
.58175 .45141 L
F
.51315 .45255 m
.51315 .4537 L
.51429 .4537 L
.51429 .45255 L
F
.54516 .45255 m
.54516 .4537 L
.5463 .4537 L
.5463 .45255 L
F
.5463 .45255 m
.5463 .4537 L
.54745 .4537 L
.54745 .45255 L
F
.54745 .45255 m
.54745 .4537 L
.54859 .4537 L
.54859 .45255 L
F
.57946 .45255 m
.57946 .4537 L
.5806 .4537 L
.5806 .45255 L
F
.512 .4537 m
.512 .45484 L
.51315 .45484 L
.51315 .4537 L
F
.54402 .4537 m
.54402 .45484 L
.54516 .45484 L
.54516 .4537 L
F
.54516 .4537 m
.54516 .45484 L
.5463 .45484 L
.5463 .4537 L
F
.5463 .4537 m
.5463 .45484 L
.54745 .45484 L
.54745 .4537 L
F
.57832 .4537 m
.57832 .45484 L
.57946 .45484 L
.57946 .4537 L
F
.51086 .45484 m
.51086 .45598 L
.512 .45598 L
.512 .45484 L
F
.54287 .45484 m
.54287 .45598 L
.54402 .45598 L
.54402 .45484 L
F
.54402 .45484 m
.54402 .45598 L
.54516 .45598 L
.54516 .45484 L
F
.54516 .45484 m
.54516 .45598 L
.5463 .45598 L
.5463 .45484 L
F
.57717 .45484 m
.57717 .45598 L
.57832 .45598 L
.57832 .45484 L
F
.50972 .45598 m
.50972 .45713 L
.51086 .45713 L
.51086 .45598 L
F
.54173 .45598 m
.54173 .45713 L
.54287 .45713 L
.54287 .45598 L
F
.54287 .45598 m
.54287 .45713 L
.54402 .45713 L
.54402 .45598 L
F
.54402 .45598 m
.54402 .45713 L
.54516 .45713 L
.54516 .45598 L
F
.57603 .45598 m
.57603 .45713 L
.57717 .45713 L
.57717 .45598 L
F
.50857 .45713 m
.50857 .45827 L
.50972 .45827 L
.50972 .45713 L
F
.54059 .45713 m
.54059 .45827 L
.54173 .45827 L
.54173 .45713 L
F
.54173 .45713 m
.54173 .45827 L
.54287 .45827 L
.54287 .45713 L
F
.54287 .45713 m
.54287 .45827 L
.54402 .45827 L
.54402 .45713 L
F
.57489 .45713 m
.57489 .45827 L
.57603 .45827 L
.57603 .45713 L
F
.50743 .45827 m
.50743 .45941 L
.50857 .45941 L
.50857 .45827 L
F
.53944 .45827 m
.53944 .45941 L
.54059 .45941 L
.54059 .45827 L
F
.54059 .45827 m
.54059 .45941 L
.54173 .45941 L
.54173 .45827 L
F
.54173 .45827 m
.54173 .45941 L
.54287 .45941 L
.54287 .45827 L
F
.57374 .45827 m
.57374 .45941 L
.57489 .45941 L
.57489 .45827 L
F
.50629 .45941 m
.50629 .46056 L
.50743 .46056 L
.50743 .45941 L
F
.5383 .45941 m
.5383 .46056 L
.53944 .46056 L
.53944 .45941 L
F
.53944 .45941 m
.53944 .46056 L
.54059 .46056 L
.54059 .45941 L
F
.54059 .45941 m
.54059 .46056 L
.54173 .46056 L
.54173 .45941 L
F
.5726 .45941 m
.5726 .46056 L
.57374 .46056 L
.57374 .45941 L
F
.50514 .46056 m
.50514 .4617 L
.50629 .4617 L
.50629 .46056 L
F
.53716 .46056 m
.53716 .4617 L
.5383 .4617 L
.5383 .46056 L
F
.5383 .46056 m
.5383 .4617 L
.53944 .4617 L
.53944 .46056 L
F
.53944 .46056 m
.53944 .4617 L
.54059 .4617 L
.54059 .46056 L
F
.57146 .46056 m
.57146 .4617 L
.5726 .4617 L
.5726 .46056 L
F
.504 .4617 m
.504 .46284 L
.50514 .46284 L
.50514 .4617 L
F
.53601 .4617 m
.53601 .46284 L
.53716 .46284 L
.53716 .4617 L
F
.53716 .4617 m
.53716 .46284 L
.5383 .46284 L
.5383 .4617 L
F
.5383 .4617 m
.5383 .46284 L
.53944 .46284 L
.53944 .4617 L
F
.57031 .4617 m
.57031 .46284 L
.57146 .46284 L
.57146 .4617 L
F
.50286 .46284 m
.50286 .46399 L
.504 .46399 L
.504 .46284 L
F
.53487 .46284 m
.53487 .46399 L
.53601 .46399 L
.53601 .46284 L
F
.53601 .46284 m
.53601 .46399 L
.53716 .46399 L
.53716 .46284 L
F
.53716 .46284 m
.53716 .46399 L
.5383 .46399 L
.5383 .46284 L
F
.56917 .46284 m
.56917 .46399 L
.57031 .46399 L
.57031 .46284 L
F
.50171 .46399 m
.50171 .46513 L
.50286 .46513 L
.50286 .46399 L
F
.53373 .46399 m
.53373 .46513 L
.53487 .46513 L
.53487 .46399 L
F
.53487 .46399 m
.53487 .46513 L
.53601 .46513 L
.53601 .46399 L
F
.53601 .46399 m
.53601 .46513 L
.53716 .46513 L
.53716 .46399 L
F
.56803 .46399 m
.56803 .46513 L
.56917 .46513 L
.56917 .46399 L
F
.50057 .46513 m
.50057 .46627 L
.50171 .46627 L
.50171 .46513 L
F
.53258 .46513 m
.53258 .46627 L
.53373 .46627 L
.53373 .46513 L
F
.53373 .46513 m
.53373 .46627 L
.53487 .46627 L
.53487 .46513 L
F
.53487 .46513 m
.53487 .46627 L
.53601 .46627 L
.53601 .46513 L
F
.56688 .46513 m
.56688 .46627 L
.56803 .46627 L
.56803 .46513 L
F
.49943 .46627 m
.49943 .46742 L
.50057 .46742 L
.50057 .46627 L
F
.53144 .46627 m
.53144 .46742 L
.53258 .46742 L
.53258 .46627 L
F
.53258 .46627 m
.53258 .46742 L
.53373 .46742 L
.53373 .46627 L
F
.53373 .46627 m
.53373 .46742 L
.53487 .46742 L
.53487 .46627 L
F
.56574 .46627 m
.56574 .46742 L
.56688 .46742 L
.56688 .46627 L
F
.49829 .46742 m
.49829 .46856 L
.49943 .46856 L
.49943 .46742 L
F
.5303 .46742 m
.5303 .46856 L
.53144 .46856 L
.53144 .46742 L
F
.53144 .46742 m
.53144 .46856 L
.53258 .46856 L
.53258 .46742 L
F
.53258 .46742 m
.53258 .46856 L
.53373 .46856 L
.53373 .46742 L
F
.5646 .46742 m
.5646 .46856 L
.56574 .46856 L
.56574 .46742 L
F
.49714 .46856 m
.49714 .4697 L
.49829 .4697 L
.49829 .46856 L
F
.52915 .46856 m
.52915 .4697 L
.5303 .4697 L
.5303 .46856 L
F
.5303 .46856 m
.5303 .4697 L
.53144 .4697 L
.53144 .46856 L
F
.53144 .46856 m
.53144 .4697 L
.53258 .4697 L
.53258 .46856 L
F
.56345 .46856 m
.56345 .4697 L
.5646 .4697 L
.5646 .46856 L
F
.496 .4697 m
.496 .47085 L
.49714 .47085 L
.49714 .4697 L
F
.52801 .4697 m
.52801 .47085 L
.52915 .47085 L
.52915 .4697 L
F
.52915 .4697 m
.52915 .47085 L
.5303 .47085 L
.5303 .4697 L
F
.5303 .4697 m
.5303 .47085 L
.53144 .47085 L
.53144 .4697 L
F
.56231 .4697 m
.56231 .47085 L
.56345 .47085 L
.56345 .4697 L
F
.49486 .47085 m
.49486 .47199 L
.496 .47199 L
.496 .47085 L
F
.52687 .47085 m
.52687 .47199 L
.52801 .47199 L
.52801 .47085 L
F
.52801 .47085 m
.52801 .47199 L
.52915 .47199 L
.52915 .47085 L
F
.52915 .47085 m
.52915 .47199 L
.5303 .47199 L
.5303 .47085 L
F
.56117 .47085 m
.56117 .47199 L
.56231 .47199 L
.56231 .47085 L
F
.49371 .47199 m
.49371 .47313 L
.49486 .47313 L
.49486 .47199 L
F
.52572 .47199 m
.52572 .47313 L
.52687 .47313 L
.52687 .47199 L
F
.52687 .47199 m
.52687 .47313 L
.52801 .47313 L
.52801 .47199 L
F
.52801 .47199 m
.52801 .47313 L
.52915 .47313 L
.52915 .47199 L
F
.56002 .47199 m
.56002 .47313 L
.56117 .47313 L
.56117 .47199 L
F
.49257 .47313 m
.49257 .47428 L
.49371 .47428 L
.49371 .47313 L
F
.52458 .47313 m
.52458 .47428 L
.52572 .47428 L
.52572 .47313 L
F
.52572 .47313 m
.52572 .47428 L
.52687 .47428 L
.52687 .47313 L
F
.52687 .47313 m
.52687 .47428 L
.52801 .47428 L
.52801 .47313 L
F
.55888 .47313 m
.55888 .47428 L
.56002 .47428 L
.56002 .47313 L
F
.49143 .47428 m
.49143 .47542 L
.49257 .47542 L
.49257 .47428 L
F
.52344 .47428 m
.52344 .47542 L
.52458 .47542 L
.52458 .47428 L
F
.52458 .47428 m
.52458 .47542 L
.52572 .47542 L
.52572 .47428 L
F
.52572 .47428 m
.52572 .47542 L
.52687 .47542 L
.52687 .47428 L
F
.55774 .47428 m
.55774 .47542 L
.55888 .47542 L
.55888 .47428 L
F
.49028 .47542 m
.49028 .47656 L
.49143 .47656 L
.49143 .47542 L
F
.52229 .47542 m
.52229 .47656 L
.52344 .47656 L
.52344 .47542 L
F
.52344 .47542 m
.52344 .47656 L
.52458 .47656 L
.52458 .47542 L
F
.52458 .47542 m
.52458 .47656 L
.52572 .47656 L
.52572 .47542 L
F
.55659 .47542 m
.55659 .47656 L
.55774 .47656 L
.55774 .47542 L
F
.48914 .47656 m
.48914 .47771 L
.49028 .47771 L
.49028 .47656 L
F
.52115 .47656 m
.52115 .47771 L
.52229 .47771 L
.52229 .47656 L
F
.52229 .47656 m
.52229 .47771 L
.52344 .47771 L
.52344 .47656 L
F
.52344 .47656 m
.52344 .47771 L
.52458 .47771 L
.52458 .47656 L
F
.55545 .47656 m
.55545 .47771 L
.55659 .47771 L
.55659 .47656 L
F
.488 .47771 m
.488 .47885 L
.48914 .47885 L
.48914 .47771 L
F
.52001 .47771 m
.52001 .47885 L
.52115 .47885 L
.52115 .47771 L
F
.52115 .47771 m
.52115 .47885 L
.52229 .47885 L
.52229 .47771 L
F
.52229 .47771 m
.52229 .47885 L
.52344 .47885 L
.52344 .47771 L
F
.55431 .47771 m
.55431 .47885 L
.55545 .47885 L
.55545 .47771 L
F
.48685 .47885 m
.48685 .47999 L
.488 .47999 L
.488 .47885 L
F
.51886 .47885 m
.51886 .47999 L
.52001 .47999 L
.52001 .47885 L
F
.52001 .47885 m
.52001 .47999 L
.52115 .47999 L
.52115 .47885 L
F
.52115 .47885 m
.52115 .47999 L
.52229 .47999 L
.52229 .47885 L
F
.55316 .47885 m
.55316 .47999 L
.55431 .47999 L
.55431 .47885 L
F
.48571 .47999 m
.48571 .48114 L
.48685 .48114 L
.48685 .47999 L
F
.51772 .47999 m
.51772 .48114 L
.51886 .48114 L
.51886 .47999 L
F
.51886 .47999 m
.51886 .48114 L
.52001 .48114 L
.52001 .47999 L
F
.52001 .47999 m
.52001 .48114 L
.52115 .48114 L
.52115 .47999 L
F
.55202 .47999 m
.55202 .48114 L
.55316 .48114 L
.55316 .47999 L
F
.48457 .48114 m
.48457 .48228 L
.48571 .48228 L
.48571 .48114 L
F
.51658 .48114 m
.51658 .48228 L
.51772 .48228 L
.51772 .48114 L
F
.51772 .48114 m
.51772 .48228 L
.51886 .48228 L
.51886 .48114 L
F
.51886 .48114 m
.51886 .48228 L
.52001 .48228 L
.52001 .48114 L
F
.55088 .48114 m
.55088 .48228 L
.55202 .48228 L
.55202 .48114 L
F
.48342 .48228 m
.48342 .48342 L
.48457 .48342 L
.48457 .48228 L
F
.51658 .48228 m
.51658 .48342 L
.51772 .48342 L
.51772 .48228 L
F
.51772 .48228 m
.51772 .48342 L
.51886 .48342 L
.51886 .48228 L
F
.54973 .48228 m
.54973 .48342 L
.55088 .48342 L
.55088 .48228 L
F
.48228 .48342 m
.48228 .48457 L
.48342 .48457 L
.48342 .48342 L
F
.51429 .48342 m
.51429 .48457 L
.51543 .48457 L
.51543 .48342 L
F
.51543 .48342 m
.51543 .48457 L
.51658 .48457 L
.51658 .48342 L
F
.54859 .48342 m
.54859 .48457 L
.54973 .48457 L
.54973 .48342 L
F
.48114 .48457 m
.48114 .48571 L
.48228 .48571 L
.48228 .48457 L
F
.51315 .48457 m
.51315 .48571 L
.51429 .48571 L
.51429 .48457 L
F
.51429 .48457 m
.51429 .48571 L
.51543 .48571 L
.51543 .48457 L
F
.51543 .48457 m
.51543 .48571 L
.51658 .48571 L
.51658 .48457 L
F
.54745 .48457 m
.54745 .48571 L
.54859 .48571 L
.54859 .48457 L
F
.47999 .48571 m
.47999 .48685 L
.48114 .48685 L
.48114 .48571 L
F
.512 .48571 m
.512 .48685 L
.51315 .48685 L
.51315 .48571 L
F
.51315 .48571 m
.51315 .48685 L
.51429 .48685 L
.51429 .48571 L
F
.51429 .48571 m
.51429 .48685 L
.51543 .48685 L
.51543 .48571 L
F
.5463 .48571 m
.5463 .48685 L
.54745 .48685 L
.54745 .48571 L
F
.47885 .48685 m
.47885 .488 L
.47999 .488 L
.47999 .48685 L
F
.51086 .48685 m
.51086 .488 L
.512 .488 L
.512 .48685 L
F
.512 .48685 m
.512 .488 L
.51315 .488 L
.51315 .48685 L
F
.51315 .48685 m
.51315 .488 L
.51429 .488 L
.51429 .48685 L
F
.54516 .48685 m
.54516 .488 L
.5463 .488 L
.5463 .48685 L
F
.47771 .488 m
.47771 .48914 L
.47885 .48914 L
.47885 .488 L
F
.50972 .488 m
.50972 .48914 L
.51086 .48914 L
.51086 .488 L
F
.51086 .488 m
.51086 .48914 L
.512 .48914 L
.512 .488 L
F
.512 .488 m
.512 .48914 L
.51315 .48914 L
.51315 .488 L
F
.54402 .488 m
.54402 .48914 L
.54516 .48914 L
.54516 .488 L
F
.47656 .48914 m
.47656 .49028 L
.47771 .49028 L
.47771 .48914 L
F
.50857 .48914 m
.50857 .49028 L
.50972 .49028 L
.50972 .48914 L
F
.50972 .48914 m
.50972 .49028 L
.51086 .49028 L
.51086 .48914 L
F
.51086 .48914 m
.51086 .49028 L
.512 .49028 L
.512 .48914 L
F
.54287 .48914 m
.54287 .49028 L
.54402 .49028 L
.54402 .48914 L
F
.47542 .49028 m
.47542 .49143 L
.47656 .49143 L
.47656 .49028 L
F
.50743 .49028 m
.50743 .49143 L
.50857 .49143 L
.50857 .49028 L
F
.50857 .49028 m
.50857 .49143 L
.50972 .49143 L
.50972 .49028 L
F
.50972 .49028 m
.50972 .49143 L
.51086 .49143 L
.51086 .49028 L
F
.54173 .49028 m
.54173 .49143 L
.54287 .49143 L
.54287 .49028 L
F
.47428 .49143 m
.47428 .49257 L
.47542 .49257 L
.47542 .49143 L
F
.50629 .49143 m
.50629 .49257 L
.50743 .49257 L
.50743 .49143 L
F
.50743 .49143 m
.50743 .49257 L
.50857 .49257 L
.50857 .49143 L
F
.50857 .49143 m
.50857 .49257 L
.50972 .49257 L
.50972 .49143 L
F
.54059 .49143 m
.54059 .49257 L
.54173 .49257 L
.54173 .49143 L
F
.47313 .49257 m
.47313 .49371 L
.47428 .49371 L
.47428 .49257 L
F
.50514 .49257 m
.50514 .49371 L
.50629 .49371 L
.50629 .49257 L
F
.50629 .49257 m
.50629 .49371 L
.50743 .49371 L
.50743 .49257 L
F
.50743 .49257 m
.50743 .49371 L
.50857 .49371 L
.50857 .49257 L
F
.53944 .49257 m
.53944 .49371 L
.54059 .49371 L
.54059 .49257 L
F
.47199 .49371 m
.47199 .49486 L
.47313 .49486 L
.47313 .49371 L
F
.504 .49371 m
.504 .49486 L
.50514 .49486 L
.50514 .49371 L
F
.50514 .49371 m
.50514 .49486 L
.50629 .49486 L
.50629 .49371 L
F
.50629 .49371 m
.50629 .49486 L
.50743 .49486 L
.50743 .49371 L
F
.5383 .49371 m
.5383 .49486 L
.53944 .49486 L
.53944 .49371 L
F
.47085 .49486 m
.47085 .496 L
.47199 .496 L
.47199 .49486 L
F
.50286 .49486 m
.50286 .496 L
.504 .496 L
.504 .49486 L
F
.504 .49486 m
.504 .496 L
.50514 .496 L
.50514 .49486 L
F
.50514 .49486 m
.50514 .496 L
.50629 .496 L
.50629 .49486 L
F
.53716 .49486 m
.53716 .496 L
.5383 .496 L
.5383 .49486 L
F
.4697 .496 m
.4697 .49714 L
.47085 .49714 L
.47085 .496 L
F
.50171 .496 m
.50171 .49714 L
.50286 .49714 L
.50286 .496 L
F
.50286 .496 m
.50286 .49714 L
.504 .49714 L
.504 .496 L
F
.504 .496 m
.504 .49714 L
.50514 .49714 L
.50514 .496 L
F
.53601 .496 m
.53601 .49714 L
.53716 .49714 L
.53716 .496 L
F
.46856 .49714 m
.46856 .49829 L
.4697 .49829 L
.4697 .49714 L
F
.50057 .49714 m
.50057 .49829 L
.50171 .49829 L
.50171 .49714 L
F
.50171 .49714 m
.50171 .49829 L
.50286 .49829 L
.50286 .49714 L
F
.50286 .49714 m
.50286 .49829 L
.504 .49829 L
.504 .49714 L
F
.53487 .49714 m
.53487 .49829 L
.53601 .49829 L
.53601 .49714 L
F
.46742 .49829 m
.46742 .49943 L
.46856 .49943 L
.46856 .49829 L
F
.49943 .49829 m
.49943 .49943 L
.50057 .49943 L
.50057 .49829 L
F
.50057 .49829 m
.50057 .49943 L
.50171 .49943 L
.50171 .49829 L
F
.50171 .49829 m
.50171 .49943 L
.50286 .49943 L
.50286 .49829 L
F
.53373 .49829 m
.53373 .49943 L
.53487 .49943 L
.53487 .49829 L
F
.46627 .49943 m
.46627 .50057 L
.46742 .50057 L
.46742 .49943 L
F
.49829 .49943 m
.49829 .50057 L
.49943 .50057 L
.49943 .49943 L
F
.49943 .49943 m
.49943 .50057 L
.50057 .50057 L
.50057 .49943 L
F
.50057 .49943 m
.50057 .50057 L
.50171 .50057 L
.50171 .49943 L
F
.53258 .49943 m
.53258 .50057 L
.53373 .50057 L
.53373 .49943 L
F
.46513 .50057 m
.46513 .50171 L
.46627 .50171 L
.46627 .50057 L
F
.49714 .50057 m
.49714 .50171 L
.49829 .50171 L
.49829 .50057 L
F
.49829 .50057 m
.49829 .50171 L
.49943 .50171 L
.49943 .50057 L
F
.49943 .50057 m
.49943 .50171 L
.50057 .50171 L
.50057 .50057 L
F
.53144 .50057 m
.53144 .50171 L
.53258 .50171 L
.53258 .50057 L
F
.46399 .50171 m
.46399 .50286 L
.46513 .50286 L
.46513 .50171 L
F
.496 .50171 m
.496 .50286 L
.49714 .50286 L
.49714 .50171 L
F
.49714 .50171 m
.49714 .50286 L
.49829 .50286 L
.49829 .50171 L
F
.49829 .50171 m
.49829 .50286 L
.49943 .50286 L
.49943 .50171 L
F
.5303 .50171 m
.5303 .50286 L
.53144 .50286 L
.53144 .50171 L
F
.46284 .50286 m
.46284 .504 L
.46399 .504 L
.46399 .50286 L
F
.49486 .50286 m
.49486 .504 L
.496 .504 L
.496 .50286 L
F
.496 .50286 m
.496 .504 L
.49714 .504 L
.49714 .50286 L
F
.49714 .50286 m
.49714 .504 L
.49829 .504 L
.49829 .50286 L
F
.52915 .50286 m
.52915 .504 L
.5303 .504 L
.5303 .50286 L
F
.4617 .504 m
.4617 .50514 L
.46284 .50514 L
.46284 .504 L
F
.49371 .504 m
.49371 .50514 L
.49486 .50514 L
.49486 .504 L
F
.49486 .504 m
.49486 .50514 L
.496 .50514 L
.496 .504 L
F
.496 .504 m
.496 .50514 L
.49714 .50514 L
.49714 .504 L
F
.52801 .504 m
.52801 .50514 L
.52915 .50514 L
.52915 .504 L
F
.46056 .50514 m
.46056 .50629 L
.4617 .50629 L
.4617 .50514 L
F
.49257 .50514 m
.49257 .50629 L
.49371 .50629 L
.49371 .50514 L
F
.49371 .50514 m
.49371 .50629 L
.49486 .50629 L
.49486 .50514 L
F
.49486 .50514 m
.49486 .50629 L
.496 .50629 L
.496 .50514 L
F
.52687 .50514 m
.52687 .50629 L
.52801 .50629 L
.52801 .50514 L
F
.45941 .50629 m
.45941 .50743 L
.46056 .50743 L
.46056 .50629 L
F
.49143 .50629 m
.49143 .50743 L
.49257 .50743 L
.49257 .50629 L
F
.49257 .50629 m
.49257 .50743 L
.49371 .50743 L
.49371 .50629 L
F
.49371 .50629 m
.49371 .50743 L
.49486 .50743 L
.49486 .50629 L
F
.52572 .50629 m
.52572 .50743 L
.52687 .50743 L
.52687 .50629 L
F
.45827 .50743 m
.45827 .50857 L
.45941 .50857 L
.45941 .50743 L
F
.49028 .50743 m
.49028 .50857 L
.49143 .50857 L
.49143 .50743 L
F
.49143 .50743 m
.49143 .50857 L
.49257 .50857 L
.49257 .50743 L
F
.49257 .50743 m
.49257 .50857 L
.49371 .50857 L
.49371 .50743 L
F
.52458 .50743 m
.52458 .50857 L
.52572 .50857 L
.52572 .50743 L
F
.45713 .50857 m
.45713 .50972 L
.45827 .50972 L
.45827 .50857 L
F
.48914 .50857 m
.48914 .50972 L
.49028 .50972 L
.49028 .50857 L
F
.49028 .50857 m
.49028 .50972 L
.49143 .50972 L
.49143 .50857 L
F
.49143 .50857 m
.49143 .50972 L
.49257 .50972 L
.49257 .50857 L
F
.52344 .50857 m
.52344 .50972 L
.52458 .50972 L
.52458 .50857 L
F
.45598 .50972 m
.45598 .51086 L
.45713 .51086 L
.45713 .50972 L
F
.488 .50972 m
.488 .51086 L
.48914 .51086 L
.48914 .50972 L
F
.48914 .50972 m
.48914 .51086 L
.49028 .51086 L
.49028 .50972 L
F
.49028 .50972 m
.49028 .51086 L
.49143 .51086 L
.49143 .50972 L
F
.52229 .50972 m
.52229 .51086 L
.52344 .51086 L
.52344 .50972 L
F
.45484 .51086 m
.45484 .512 L
.45598 .512 L
.45598 .51086 L
F
.48685 .51086 m
.48685 .512 L
.488 .512 L
.488 .51086 L
F
.488 .51086 m
.488 .512 L
.48914 .512 L
.48914 .51086 L
F
.48914 .51086 m
.48914 .512 L
.49028 .512 L
.49028 .51086 L
F
.52115 .51086 m
.52115 .512 L
.52229 .512 L
.52229 .51086 L
F
.4537 .512 m
.4537 .51315 L
.45484 .51315 L
.45484 .512 L
F
.48571 .512 m
.48571 .51315 L
.48685 .51315 L
.48685 .512 L
F
.48685 .512 m
.48685 .51315 L
.488 .51315 L
.488 .512 L
F
.488 .512 m
.488 .51315 L
.48914 .51315 L
.48914 .512 L
F
.52001 .512 m
.52001 .51315 L
.52115 .51315 L
.52115 .512 L
F
.45255 .51315 m
.45255 .51429 L
.4537 .51429 L
.4537 .51315 L
F
.48457 .51315 m
.48457 .51429 L
.48571 .51429 L
.48571 .51315 L
F
.48571 .51315 m
.48571 .51429 L
.48685 .51429 L
.48685 .51315 L
F
.48685 .51315 m
.48685 .51429 L
.488 .51429 L
.488 .51315 L
F
.51886 .51315 m
.51886 .51429 L
.52001 .51429 L
.52001 .51315 L
F
.45141 .51429 m
.45141 .51543 L
.45255 .51543 L
.45255 .51429 L
F
.48342 .51429 m
.48342 .51543 L
.48457 .51543 L
.48457 .51429 L
F
.48457 .51429 m
.48457 .51543 L
.48571 .51543 L
.48571 .51429 L
F
.48571 .51429 m
.48571 .51543 L
.48685 .51543 L
.48685 .51429 L
F
.51772 .51429 m
.51772 .51543 L
.51886 .51543 L
.51886 .51429 L
F
.45027 .51543 m
.45027 .51658 L
.45141 .51658 L
.45141 .51543 L
F
.48342 .51543 m
.48342 .51658 L
.48457 .51658 L
.48457 .51543 L
F
.48457 .51543 m
.48457 .51658 L
.48571 .51658 L
.48571 .51543 L
F
.51658 .51543 m
.51658 .51658 L
.51772 .51658 L
.51772 .51543 L
F
.44912 .51658 m
.44912 .51772 L
.45027 .51772 L
.45027 .51658 L
F
.48114 .51658 m
.48114 .51772 L
.48228 .51772 L
.48228 .51658 L
F
.48228 .51658 m
.48228 .51772 L
.48342 .51772 L
.48342 .51658 L
F
.51543 .51658 m
.51543 .51772 L
.51658 .51772 L
.51658 .51658 L
F
.44798 .51772 m
.44798 .51886 L
.44912 .51886 L
.44912 .51772 L
F
.47999 .51772 m
.47999 .51886 L
.48114 .51886 L
.48114 .51772 L
F
.48114 .51772 m
.48114 .51886 L
.48228 .51886 L
.48228 .51772 L
F
.48228 .51772 m
.48228 .51886 L
.48342 .51886 L
.48342 .51772 L
F
.51429 .51772 m
.51429 .51886 L
.51543 .51886 L
.51543 .51772 L
F
.44684 .51886 m
.44684 .52001 L
.44798 .52001 L
.44798 .51886 L
F
.47885 .51886 m
.47885 .52001 L
.47999 .52001 L
.47999 .51886 L
F
.47999 .51886 m
.47999 .52001 L
.48114 .52001 L
.48114 .51886 L
F
.48114 .51886 m
.48114 .52001 L
.48228 .52001 L
.48228 .51886 L
F
.51315 .51886 m
.51315 .52001 L
.51429 .52001 L
.51429 .51886 L
F
.44569 .52001 m
.44569 .52115 L
.44684 .52115 L
.44684 .52001 L
F
.47771 .52001 m
.47771 .52115 L
.47885 .52115 L
.47885 .52001 L
F
.47885 .52001 m
.47885 .52115 L
.47999 .52115 L
.47999 .52001 L
F
.47999 .52001 m
.47999 .52115 L
.48114 .52115 L
.48114 .52001 L
F
.512 .52001 m
.512 .52115 L
.51315 .52115 L
.51315 .52001 L
F
.44455 .52115 m
.44455 .52229 L
.44569 .52229 L
.44569 .52115 L
F
.47656 .52115 m
.47656 .52229 L
.47771 .52229 L
.47771 .52115 L
F
.47771 .52115 m
.47771 .52229 L
.47885 .52229 L
.47885 .52115 L
F
.47885 .52115 m
.47885 .52229 L
.47999 .52229 L
.47999 .52115 L
F
.51086 .52115 m
.51086 .52229 L
.512 .52229 L
.512 .52115 L
F
.44341 .52229 m
.44341 .52344 L
.44455 .52344 L
.44455 .52229 L
F
.47542 .52229 m
.47542 .52344 L
.47656 .52344 L
.47656 .52229 L
F
.47656 .52229 m
.47656 .52344 L
.47771 .52344 L
.47771 .52229 L
F
.47771 .52229 m
.47771 .52344 L
.47885 .52344 L
.47885 .52229 L
F
.50972 .52229 m
.50972 .52344 L
.51086 .52344 L
.51086 .52229 L
F
.44226 .52344 m
.44226 .52458 L
.44341 .52458 L
.44341 .52344 L
F
.47428 .52344 m
.47428 .52458 L
.47542 .52458 L
.47542 .52344 L
F
.47542 .52344 m
.47542 .52458 L
.47656 .52458 L
.47656 .52344 L
F
.47656 .52344 m
.47656 .52458 L
.47771 .52458 L
.47771 .52344 L
F
.50857 .52344 m
.50857 .52458 L
.50972 .52458 L
.50972 .52344 L
F
.44112 .52458 m
.44112 .52572 L
.44226 .52572 L
.44226 .52458 L
F
.47313 .52458 m
.47313 .52572 L
.47428 .52572 L
.47428 .52458 L
F
.47428 .52458 m
.47428 .52572 L
.47542 .52572 L
.47542 .52458 L
F
.47542 .52458 m
.47542 .52572 L
.47656 .52572 L
.47656 .52458 L
F
.50743 .52458 m
.50743 .52572 L
.50857 .52572 L
.50857 .52458 L
F
.43998 .52572 m
.43998 .52687 L
.44112 .52687 L
.44112 .52572 L
F
.47199 .52572 m
.47199 .52687 L
.47313 .52687 L
.47313 .52572 L
F
.47313 .52572 m
.47313 .52687 L
.47428 .52687 L
.47428 .52572 L
F
.47428 .52572 m
.47428 .52687 L
.47542 .52687 L
.47542 .52572 L
F
.50629 .52572 m
.50629 .52687 L
.50743 .52687 L
.50743 .52572 L
F
.43883 .52687 m
.43883 .52801 L
.43998 .52801 L
.43998 .52687 L
F
.47085 .52687 m
.47085 .52801 L
.47199 .52801 L
.47199 .52687 L
F
.47199 .52687 m
.47199 .52801 L
.47313 .52801 L
.47313 .52687 L
F
.47313 .52687 m
.47313 .52801 L
.47428 .52801 L
.47428 .52687 L
F
.50514 .52687 m
.50514 .52801 L
.50629 .52801 L
.50629 .52687 L
F
.43769 .52801 m
.43769 .52915 L
.43883 .52915 L
.43883 .52801 L
F
.4697 .52801 m
.4697 .52915 L
.47085 .52915 L
.47085 .52801 L
F
.47085 .52801 m
.47085 .52915 L
.47199 .52915 L
.47199 .52801 L
F
.47199 .52801 m
.47199 .52915 L
.47313 .52915 L
.47313 .52801 L
F
.504 .52801 m
.504 .52915 L
.50514 .52915 L
.50514 .52801 L
F
.43655 .52915 m
.43655 .5303 L
.43769 .5303 L
.43769 .52915 L
F
.46856 .52915 m
.46856 .5303 L
.4697 .5303 L
.4697 .52915 L
F
.4697 .52915 m
.4697 .5303 L
.47085 .5303 L
.47085 .52915 L
F
.47085 .52915 m
.47085 .5303 L
.47199 .5303 L
.47199 .52915 L
F
.50286 .52915 m
.50286 .5303 L
.504 .5303 L
.504 .52915 L
F
.4354 .5303 m
.4354 .53144 L
.43655 .53144 L
.43655 .5303 L
F
.46742 .5303 m
.46742 .53144 L
.46856 .53144 L
.46856 .5303 L
F
.46856 .5303 m
.46856 .53144 L
.4697 .53144 L
.4697 .5303 L
F
.4697 .5303 m
.4697 .53144 L
.47085 .53144 L
.47085 .5303 L
F
.50171 .5303 m
.50171 .53144 L
.50286 .53144 L
.50286 .5303 L
F
.43426 .53144 m
.43426 .53258 L
.4354 .53258 L
.4354 .53144 L
F
.46627 .53144 m
.46627 .53258 L
.46742 .53258 L
.46742 .53144 L
F
.46742 .53144 m
.46742 .53258 L
.46856 .53258 L
.46856 .53144 L
F
.46856 .53144 m
.46856 .53258 L
.4697 .53258 L
.4697 .53144 L
F
.50057 .53144 m
.50057 .53258 L
.50171 .53258 L
.50171 .53144 L
F
.43312 .53258 m
.43312 .53373 L
.43426 .53373 L
.43426 .53258 L
F
.46513 .53258 m
.46513 .53373 L
.46627 .53373 L
.46627 .53258 L
F
.46627 .53258 m
.46627 .53373 L
.46742 .53373 L
.46742 .53258 L
F
.46742 .53258 m
.46742 .53373 L
.46856 .53373 L
.46856 .53258 L
F
.49943 .53258 m
.49943 .53373 L
.50057 .53373 L
.50057 .53258 L
F
.43197 .53373 m
.43197 .53487 L
.43312 .53487 L
.43312 .53373 L
F
.46399 .53373 m
.46399 .53487 L
.46513 .53487 L
.46513 .53373 L
F
.46513 .53373 m
.46513 .53487 L
.46627 .53487 L
.46627 .53373 L
F
.46627 .53373 m
.46627 .53487 L
.46742 .53487 L
.46742 .53373 L
F
.49829 .53373 m
.49829 .53487 L
.49943 .53487 L
.49943 .53373 L
F
.43083 .53487 m
.43083 .53601 L
.43197 .53601 L
.43197 .53487 L
F
.46284 .53487 m
.46284 .53601 L
.46399 .53601 L
.46399 .53487 L
F
.46399 .53487 m
.46399 .53601 L
.46513 .53601 L
.46513 .53487 L
F
.46513 .53487 m
.46513 .53601 L
.46627 .53601 L
.46627 .53487 L
F
.49714 .53487 m
.49714 .53601 L
.49829 .53601 L
.49829 .53487 L
F
.42969 .53601 m
.42969 .53716 L
.43083 .53716 L
.43083 .53601 L
F
.4617 .53601 m
.4617 .53716 L
.46284 .53716 L
.46284 .53601 L
F
.46284 .53601 m
.46284 .53716 L
.46399 .53716 L
.46399 .53601 L
F
.46399 .53601 m
.46399 .53716 L
.46513 .53716 L
.46513 .53601 L
F
.496 .53601 m
.496 .53716 L
.49714 .53716 L
.49714 .53601 L
F
.42854 .53716 m
.42854 .5383 L
.42969 .5383 L
.42969 .53716 L
F
.46056 .53716 m
.46056 .5383 L
.4617 .5383 L
.4617 .53716 L
F
.4617 .53716 m
.4617 .5383 L
.46284 .5383 L
.46284 .53716 L
F
.46284 .53716 m
.46284 .5383 L
.46399 .5383 L
.46399 .53716 L
F
.49486 .53716 m
.49486 .5383 L
.496 .5383 L
.496 .53716 L
F
.4274 .5383 m
.4274 .53944 L
.42854 .53944 L
.42854 .5383 L
F
.45941 .5383 m
.45941 .53944 L
.46056 .53944 L
.46056 .5383 L
F
.46056 .5383 m
.46056 .53944 L
.4617 .53944 L
.4617 .5383 L
F
.4617 .5383 m
.4617 .53944 L
.46284 .53944 L
.46284 .5383 L
F
.49371 .5383 m
.49371 .53944 L
.49486 .53944 L
.49486 .5383 L
F
.42626 .53944 m
.42626 .54059 L
.4274 .54059 L
.4274 .53944 L
F
.45827 .53944 m
.45827 .54059 L
.45941 .54059 L
.45941 .53944 L
F
.45941 .53944 m
.45941 .54059 L
.46056 .54059 L
.46056 .53944 L
F
.46056 .53944 m
.46056 .54059 L
.4617 .54059 L
.4617 .53944 L
F
.49257 .53944 m
.49257 .54059 L
.49371 .54059 L
.49371 .53944 L
F
.42511 .54059 m
.42511 .54173 L
.42626 .54173 L
.42626 .54059 L
F
.45713 .54059 m
.45713 .54173 L
.45827 .54173 L
.45827 .54059 L
F
.45827 .54059 m
.45827 .54173 L
.45941 .54173 L
.45941 .54059 L
F
.45941 .54059 m
.45941 .54173 L
.46056 .54173 L
.46056 .54059 L
F
.49143 .54059 m
.49143 .54173 L
.49257 .54173 L
.49257 .54059 L
F
.42397 .54173 m
.42397 .54287 L
.42511 .54287 L
.42511 .54173 L
F
.45598 .54173 m
.45598 .54287 L
.45713 .54287 L
.45713 .54173 L
F
.45713 .54173 m
.45713 .54287 L
.45827 .54287 L
.45827 .54173 L
F
.45827 .54173 m
.45827 .54287 L
.45941 .54287 L
.45941 .54173 L
F
.49028 .54173 m
.49028 .54287 L
.49143 .54287 L
.49143 .54173 L
F
.42283 .54287 m
.42283 .54402 L
.42397 .54402 L
.42397 .54287 L
F
.45484 .54287 m
.45484 .54402 L
.45598 .54402 L
.45598 .54287 L
F
.45598 .54287 m
.45598 .54402 L
.45713 .54402 L
.45713 .54287 L
F
.45713 .54287 m
.45713 .54402 L
.45827 .54402 L
.45827 .54287 L
F
.48914 .54287 m
.48914 .54402 L
.49028 .54402 L
.49028 .54287 L
F
.42168 .54402 m
.42168 .54516 L
.42283 .54516 L
.42283 .54402 L
F
.4537 .54402 m
.4537 .54516 L
.45484 .54516 L
.45484 .54402 L
F
.45484 .54402 m
.45484 .54516 L
.45598 .54516 L
.45598 .54402 L
F
.45598 .54402 m
.45598 .54516 L
.45713 .54516 L
.45713 .54402 L
F
.488 .54402 m
.488 .54516 L
.48914 .54516 L
.48914 .54402 L
F
.42054 .54516 m
.42054 .5463 L
.42168 .5463 L
.42168 .54516 L
F
.45255 .54516 m
.45255 .5463 L
.4537 .5463 L
.4537 .54516 L
F
.4537 .54516 m
.4537 .5463 L
.45484 .5463 L
.45484 .54516 L
F
.45484 .54516 m
.45484 .5463 L
.45598 .5463 L
.45598 .54516 L
F
.48685 .54516 m
.48685 .5463 L
.488 .5463 L
.488 .54516 L
F
.4194 .5463 m
.4194 .54745 L
.42054 .54745 L
.42054 .5463 L
F
.45141 .5463 m
.45141 .54745 L
.45255 .54745 L
.45255 .5463 L
F
.45255 .5463 m
.45255 .54745 L
.4537 .54745 L
.4537 .5463 L
F
.4537 .5463 m
.4537 .54745 L
.45484 .54745 L
.45484 .5463 L
F
.48571 .5463 m
.48571 .54745 L
.48685 .54745 L
.48685 .5463 L
F
.41825 .54745 m
.41825 .54859 L
.4194 .54859 L
.4194 .54745 L
F
.45027 .54745 m
.45027 .54859 L
.45141 .54859 L
.45141 .54745 L
F
.45141 .54745 m
.45141 .54859 L
.45255 .54859 L
.45255 .54745 L
F
.45255 .54745 m
.45255 .54859 L
.4537 .54859 L
.4537 .54745 L
F
.48457 .54745 m
.48457 .54859 L
.48571 .54859 L
.48571 .54745 L
F
.41711 .54859 m
.41711 .54973 L
.41825 .54973 L
.41825 .54859 L
F
.45027 .54859 m
.45027 .54973 L
.45141 .54973 L
.45141 .54859 L
F
.45141 .54859 m
.45141 .54973 L
.45255 .54973 L
.45255 .54859 L
F
.48342 .54859 m
.48342 .54973 L
.48457 .54973 L
.48457 .54859 L
F
.41597 .54973 m
.41597 .55088 L
.41711 .55088 L
.41711 .54973 L
F
.44798 .54973 m
.44798 .55088 L
.44912 .55088 L
.44912 .54973 L
F
.44912 .54973 m
.44912 .55088 L
.45027 .55088 L
.45027 .54973 L
F
.48228 .54973 m
.48228 .55088 L
.48342 .55088 L
.48342 .54973 L
F
.41482 .55088 m
.41482 .55202 L
.41597 .55202 L
.41597 .55088 L
F
.44684 .55088 m
.44684 .55202 L
.44798 .55202 L
.44798 .55088 L
F
.44798 .55088 m
.44798 .55202 L
.44912 .55202 L
.44912 .55088 L
F
.44912 .55088 m
.44912 .55202 L
.45027 .55202 L
.45027 .55088 L
F
.48114 .55088 m
.48114 .55202 L
.48228 .55202 L
.48228 .55088 L
F
.41368 .55202 m
.41368 .55316 L
.41482 .55316 L
.41482 .55202 L
F
.44569 .55202 m
.44569 .55316 L
.44684 .55316 L
.44684 .55202 L
F
.44684 .55202 m
.44684 .55316 L
.44798 .55316 L
.44798 .55202 L
F
.44798 .55202 m
.44798 .55316 L
.44912 .55316 L
.44912 .55202 L
F
.47999 .55202 m
.47999 .55316 L
.48114 .55316 L
.48114 .55202 L
F
.41254 .55316 m
.41254 .55431 L
.41368 .55431 L
.41368 .55316 L
F
.44455 .55316 m
.44455 .55431 L
.44569 .55431 L
.44569 .55316 L
F
.44569 .55316 m
.44569 .55431 L
.44684 .55431 L
.44684 .55316 L
F
.44684 .55316 m
.44684 .55431 L
.44798 .55431 L
.44798 .55316 L
F
.47885 .55316 m
.47885 .55431 L
.47999 .55431 L
.47999 .55316 L
F
.41139 .55431 m
.41139 .55545 L
.41254 .55545 L
.41254 .55431 L
F
.44341 .55431 m
.44341 .55545 L
.44455 .55545 L
.44455 .55431 L
F
.44455 .55431 m
.44455 .55545 L
.44569 .55545 L
.44569 .55431 L
F
.44569 .55431 m
.44569 .55545 L
.44684 .55545 L
.44684 .55431 L
F
.47771 .55431 m
.47771 .55545 L
.47885 .55545 L
.47885 .55431 L
F
.41025 .55545 m
.41025 .55659 L
.41139 .55659 L
.41139 .55545 L
F
.44226 .55545 m
.44226 .55659 L
.44341 .55659 L
.44341 .55545 L
F
.44341 .55545 m
.44341 .55659 L
.44455 .55659 L
.44455 .55545 L
F
.44455 .55545 m
.44455 .55659 L
.44569 .55659 L
.44569 .55545 L
F
.47656 .55545 m
.47656 .55659 L
.47771 .55659 L
.47771 .55545 L
F
.40911 .55659 m
.40911 .55774 L
.41025 .55774 L
.41025 .55659 L
F
.44112 .55659 m
.44112 .55774 L
.44226 .55774 L
.44226 .55659 L
F
.44226 .55659 m
.44226 .55774 L
.44341 .55774 L
.44341 .55659 L
F
.44341 .55659 m
.44341 .55774 L
.44455 .55774 L
.44455 .55659 L
F
.47542 .55659 m
.47542 .55774 L
.47656 .55774 L
.47656 .55659 L
F
.40796 .55774 m
.40796 .55888 L
.40911 .55888 L
.40911 .55774 L
F
.43998 .55774 m
.43998 .55888 L
.44112 .55888 L
.44112 .55774 L
F
.44112 .55774 m
.44112 .55888 L
.44226 .55888 L
.44226 .55774 L
F
.44226 .55774 m
.44226 .55888 L
.44341 .55888 L
.44341 .55774 L
F
.47428 .55774 m
.47428 .55888 L
.47542 .55888 L
.47542 .55774 L
F
.40682 .55888 m
.40682 .56002 L
.40796 .56002 L
.40796 .55888 L
F
.43883 .55888 m
.43883 .56002 L
.43998 .56002 L
.43998 .55888 L
F
.43998 .55888 m
.43998 .56002 L
.44112 .56002 L
.44112 .55888 L
F
.44112 .55888 m
.44112 .56002 L
.44226 .56002 L
.44226 .55888 L
F
.47313 .55888 m
.47313 .56002 L
.47428 .56002 L
.47428 .55888 L
F
.40568 .56002 m
.40568 .56117 L
.40682 .56117 L
.40682 .56002 L
F
.43769 .56002 m
.43769 .56117 L
.43883 .56117 L
.43883 .56002 L
F
.43883 .56002 m
.43883 .56117 L
.43998 .56117 L
.43998 .56002 L
F
.43998 .56002 m
.43998 .56117 L
.44112 .56117 L
.44112 .56002 L
F
.47199 .56002 m
.47199 .56117 L
.47313 .56117 L
.47313 .56002 L
F
.40453 .56117 m
.40453 .56231 L
.40568 .56231 L
.40568 .56117 L
F
.43655 .56117 m
.43655 .56231 L
.43769 .56231 L
.43769 .56117 L
F
.43769 .56117 m
.43769 .56231 L
.43883 .56231 L
.43883 .56117 L
F
.43883 .56117 m
.43883 .56231 L
.43998 .56231 L
.43998 .56117 L
F
.47085 .56117 m
.47085 .56231 L
.47199 .56231 L
.47199 .56117 L
F
.40339 .56231 m
.40339 .56345 L
.40453 .56345 L
.40453 .56231 L
F
.4354 .56231 m
.4354 .56345 L
.43655 .56345 L
.43655 .56231 L
F
.43655 .56231 m
.43655 .56345 L
.43769 .56345 L
.43769 .56231 L
F
.43769 .56231 m
.43769 .56345 L
.43883 .56345 L
.43883 .56231 L
F
.4697 .56231 m
.4697 .56345 L
.47085 .56345 L
.47085 .56231 L
F
.40225 .56345 m
.40225 .5646 L
.40339 .5646 L
.40339 .56345 L
F
.43426 .56345 m
.43426 .5646 L
.4354 .5646 L
.4354 .56345 L
F
.4354 .56345 m
.4354 .5646 L
.43655 .5646 L
.43655 .56345 L
F
.43655 .56345 m
.43655 .5646 L
.43769 .5646 L
.43769 .56345 L
F
.46856 .56345 m
.46856 .5646 L
.4697 .5646 L
.4697 .56345 L
F
.4011 .5646 m
.4011 .56574 L
.40225 .56574 L
.40225 .5646 L
F
.43312 .5646 m
.43312 .56574 L
.43426 .56574 L
.43426 .5646 L
F
.43426 .5646 m
.43426 .56574 L
.4354 .56574 L
.4354 .5646 L
F
.4354 .5646 m
.4354 .56574 L
.43655 .56574 L
.43655 .5646 L
F
.46742 .5646 m
.46742 .56574 L
.46856 .56574 L
.46856 .5646 L
F
.39996 .56574 m
.39996 .56688 L
.4011 .56688 L
.4011 .56574 L
F
.43197 .56574 m
.43197 .56688 L
.43312 .56688 L
.43312 .56574 L
F
.43312 .56574 m
.43312 .56688 L
.43426 .56688 L
.43426 .56574 L
F
.43426 .56574 m
.43426 .56688 L
.4354 .56688 L
.4354 .56574 L
F
.46627 .56574 m
.46627 .56688 L
.46742 .56688 L
.46742 .56574 L
F
.39882 .56688 m
.39882 .56803 L
.39996 .56803 L
.39996 .56688 L
F
.43083 .56688 m
.43083 .56803 L
.43197 .56803 L
.43197 .56688 L
F
.43197 .56688 m
.43197 .56803 L
.43312 .56803 L
.43312 .56688 L
F
.43312 .56688 m
.43312 .56803 L
.43426 .56803 L
.43426 .56688 L
F
.46513 .56688 m
.46513 .56803 L
.46627 .56803 L
.46627 .56688 L
F
.39767 .56803 m
.39767 .56917 L
.39882 .56917 L
.39882 .56803 L
F
.42969 .56803 m
.42969 .56917 L
.43083 .56917 L
.43083 .56803 L
F
.43083 .56803 m
.43083 .56917 L
.43197 .56917 L
.43197 .56803 L
F
.43197 .56803 m
.43197 .56917 L
.43312 .56917 L
.43312 .56803 L
F
.46399 .56803 m
.46399 .56917 L
.46513 .56917 L
.46513 .56803 L
F
.39653 .56917 m
.39653 .57031 L
.39767 .57031 L
.39767 .56917 L
F
.42854 .56917 m
.42854 .57031 L
.42969 .57031 L
.42969 .56917 L
F
.42969 .56917 m
.42969 .57031 L
.43083 .57031 L
.43083 .56917 L
F
.43083 .56917 m
.43083 .57031 L
.43197 .57031 L
.43197 .56917 L
F
.46284 .56917 m
.46284 .57031 L
.46399 .57031 L
.46399 .56917 L
F
.39539 .57031 m
.39539 .57146 L
.39653 .57146 L
.39653 .57031 L
F
.4274 .57031 m
.4274 .57146 L
.42854 .57146 L
.42854 .57031 L
F
.42854 .57031 m
.42854 .57146 L
.42969 .57146 L
.42969 .57031 L
F
.42969 .57031 m
.42969 .57146 L
.43083 .57146 L
.43083 .57031 L
F
.4617 .57031 m
.4617 .57146 L
.46284 .57146 L
.46284 .57031 L
F
.39424 .57146 m
.39424 .5726 L
.39539 .5726 L
.39539 .57146 L
F
.42626 .57146 m
.42626 .5726 L
.4274 .5726 L
.4274 .57146 L
F
.4274 .57146 m
.4274 .5726 L
.42854 .5726 L
.42854 .57146 L
F
.42854 .57146 m
.42854 .5726 L
.42969 .5726 L
.42969 .57146 L
F
.46056 .57146 m
.46056 .5726 L
.4617 .5726 L
.4617 .57146 L
F
.3931 .5726 m
.3931 .57374 L
.39424 .57374 L
.39424 .5726 L
F
.42511 .5726 m
.42511 .57374 L
.42626 .57374 L
.42626 .5726 L
F
.42626 .5726 m
.42626 .57374 L
.4274 .57374 L
.4274 .5726 L
F
.4274 .5726 m
.4274 .57374 L
.42854 .57374 L
.42854 .5726 L
F
.45941 .5726 m
.45941 .57374 L
.46056 .57374 L
.46056 .5726 L
F
.39196 .57374 m
.39196 .57489 L
.3931 .57489 L
.3931 .57374 L
F
.42397 .57374 m
.42397 .57489 L
.42511 .57489 L
.42511 .57374 L
F
.42511 .57374 m
.42511 .57489 L
.42626 .57489 L
.42626 .57374 L
F
.42626 .57374 m
.42626 .57489 L
.4274 .57489 L
.4274 .57374 L
F
.45827 .57374 m
.45827 .57489 L
.45941 .57489 L
.45941 .57374 L
F
.39081 .57489 m
.39081 .57603 L
.39196 .57603 L
.39196 .57489 L
F
.42283 .57489 m
.42283 .57603 L
.42397 .57603 L
.42397 .57489 L
F
.42397 .57489 m
.42397 .57603 L
.42511 .57603 L
.42511 .57489 L
F
.42511 .57489 m
.42511 .57603 L
.42626 .57603 L
.42626 .57489 L
F
.45713 .57489 m
.45713 .57603 L
.45827 .57603 L
.45827 .57489 L
F
.38967 .57603 m
.38967 .57717 L
.39081 .57717 L
.39081 .57603 L
F
.42168 .57603 m
.42168 .57717 L
.42283 .57717 L
.42283 .57603 L
F
.42283 .57603 m
.42283 .57717 L
.42397 .57717 L
.42397 .57603 L
F
.42397 .57603 m
.42397 .57717 L
.42511 .57717 L
.42511 .57603 L
F
.45598 .57603 m
.45598 .57717 L
.45713 .57717 L
.45713 .57603 L
F
.38853 .57717 m
.38853 .57832 L
.38967 .57832 L
.38967 .57717 L
F
.42054 .57717 m
.42054 .57832 L
.42168 .57832 L
.42168 .57717 L
F
.42168 .57717 m
.42168 .57832 L
.42283 .57832 L
.42283 .57717 L
F
.42283 .57717 m
.42283 .57832 L
.42397 .57832 L
.42397 .57717 L
F
.45484 .57717 m
.45484 .57832 L
.45598 .57832 L
.45598 .57717 L
F
.38738 .57832 m
.38738 .57946 L
.38853 .57946 L
.38853 .57832 L
F
.4194 .57832 m
.4194 .57946 L
.42054 .57946 L
.42054 .57832 L
F
.42054 .57832 m
.42054 .57946 L
.42168 .57946 L
.42168 .57832 L
F
.42168 .57832 m
.42168 .57946 L
.42283 .57946 L
.42283 .57832 L
F
.4537 .57832 m
.4537 .57946 L
.45484 .57946 L
.45484 .57832 L
F
.38624 .57946 m
.38624 .5806 L
.38738 .5806 L
.38738 .57946 L
F
.41825 .57946 m
.41825 .5806 L
.4194 .5806 L
.4194 .57946 L
F
.4194 .57946 m
.4194 .5806 L
.42054 .5806 L
.42054 .57946 L
F
.42054 .57946 m
.42054 .5806 L
.42168 .5806 L
.42168 .57946 L
F
.45255 .57946 m
.45255 .5806 L
.4537 .5806 L
.4537 .57946 L
F
.3851 .5806 m
.3851 .58175 L
.38624 .58175 L
.38624 .5806 L
F
.41711 .5806 m
.41711 .58175 L
.41825 .58175 L
.41825 .5806 L
F
.41825 .5806 m
.41825 .58175 L
.4194 .58175 L
.4194 .5806 L
F
.4194 .5806 m
.4194 .58175 L
.42054 .58175 L
.42054 .5806 L
F
.45141 .5806 m
.45141 .58175 L
.45255 .58175 L
.45255 .5806 L
F
.38395 .58175 m
.38395 .58289 L
.3851 .58289 L
.3851 .58175 L
F
.41711 .58175 m
.41711 .58289 L
.41825 .58289 L
.41825 .58175 L
F
.41825 .58175 m
.41825 .58289 L
.4194 .58289 L
.4194 .58175 L
F
.45027 .58175 m
.45027 .58289 L
.45141 .58289 L
.45141 .58175 L
F
.38281 .58289 m
.38281 .58403 L
.38395 .58403 L
.38395 .58289 L
F
.41482 .58289 m
.41482 .58403 L
.41597 .58403 L
.41597 .58289 L
F
.41597 .58289 m
.41597 .58403 L
.41711 .58403 L
.41711 .58289 L
F
.44912 .58289 m
.44912 .58403 L
.45027 .58403 L
.45027 .58289 L
F
.38167 .58403 m
.38167 .58518 L
.38281 .58518 L
.38281 .58403 L
F
.41368 .58403 m
.41368 .58518 L
.41482 .58518 L
.41482 .58403 L
F
.41482 .58403 m
.41482 .58518 L
.41597 .58518 L
.41597 .58403 L
F
.41597 .58403 m
.41597 .58518 L
.41711 .58518 L
.41711 .58403 L
F
.44798 .58403 m
.44798 .58518 L
.44912 .58518 L
.44912 .58403 L
F
.38052 .58518 m
.38052 .58632 L
.38167 .58632 L
.38167 .58518 L
F
.41254 .58518 m
.41254 .58632 L
.41368 .58632 L
.41368 .58518 L
F
.41368 .58518 m
.41368 .58632 L
.41482 .58632 L
.41482 .58518 L
F
.41482 .58518 m
.41482 .58632 L
.41597 .58632 L
.41597 .58518 L
F
.44684 .58518 m
.44684 .58632 L
.44798 .58632 L
.44798 .58518 L
F
.37938 .58632 m
.37938 .58746 L
.38052 .58746 L
.38052 .58632 L
F
.41139 .58632 m
.41139 .58746 L
.41254 .58746 L
.41254 .58632 L
F
.41254 .58632 m
.41254 .58746 L
.41368 .58746 L
.41368 .58632 L
F
.41368 .58632 m
.41368 .58746 L
.41482 .58746 L
.41482 .58632 L
F
.44569 .58632 m
.44569 .58746 L
.44684 .58746 L
.44684 .58632 L
F
.37824 .58746 m
.37824 .58861 L
.37938 .58861 L
.37938 .58746 L
F
.41025 .58746 m
.41025 .58861 L
.41139 .58861 L
.41139 .58746 L
F
.41139 .58746 m
.41139 .58861 L
.41254 .58861 L
.41254 .58746 L
F
.41254 .58746 m
.41254 .58861 L
.41368 .58861 L
.41368 .58746 L
F
.44455 .58746 m
.44455 .58861 L
.44569 .58861 L
.44569 .58746 L
F
.37709 .58861 m
.37709 .58975 L
.37824 .58975 L
.37824 .58861 L
F
.40911 .58861 m
.40911 .58975 L
.41025 .58975 L
.41025 .58861 L
F
.41025 .58861 m
.41025 .58975 L
.41139 .58975 L
.41139 .58861 L
F
.41139 .58861 m
.41139 .58975 L
.41254 .58975 L
.41254 .58861 L
F
.44341 .58861 m
.44341 .58975 L
.44455 .58975 L
.44455 .58861 L
F
.37595 .58975 m
.37595 .59089 L
.37709 .59089 L
.37709 .58975 L
F
.40796 .58975 m
.40796 .59089 L
.40911 .59089 L
.40911 .58975 L
F
.40911 .58975 m
.40911 .59089 L
.41025 .59089 L
.41025 .58975 L
F
.41025 .58975 m
.41025 .59089 L
.41139 .59089 L
.41139 .58975 L
F
.44226 .58975 m
.44226 .59089 L
.44341 .59089 L
.44341 .58975 L
F
.37481 .59089 m
.37481 .59204 L
.37595 .59204 L
.37595 .59089 L
F
.40682 .59089 m
.40682 .59204 L
.40796 .59204 L
.40796 .59089 L
F
.40796 .59089 m
.40796 .59204 L
.40911 .59204 L
.40911 .59089 L
F
.40911 .59089 m
.40911 .59204 L
.41025 .59204 L
.41025 .59089 L
F
.44112 .59089 m
.44112 .59204 L
.44226 .59204 L
.44226 .59089 L
F
.37366 .59204 m
.37366 .59318 L
.37481 .59318 L
.37481 .59204 L
F
.40568 .59204 m
.40568 .59318 L
.40682 .59318 L
.40682 .59204 L
F
.40682 .59204 m
.40682 .59318 L
.40796 .59318 L
.40796 .59204 L
F
.40796 .59204 m
.40796 .59318 L
.40911 .59318 L
.40911 .59204 L
F
.43998 .59204 m
.43998 .59318 L
.44112 .59318 L
.44112 .59204 L
F
.37252 .59318 m
.37252 .59432 L
.37366 .59432 L
.37366 .59318 L
F
.40453 .59318 m
.40453 .59432 L
.40568 .59432 L
.40568 .59318 L
F
.40568 .59318 m
.40568 .59432 L
.40682 .59432 L
.40682 .59318 L
F
.40682 .59318 m
.40682 .59432 L
.40796 .59432 L
.40796 .59318 L
F
.43883 .59318 m
.43883 .59432 L
.43998 .59432 L
.43998 .59318 L
F
.37138 .59432 m
.37138 .59547 L
.37252 .59547 L
.37252 .59432 L
F
.40339 .59432 m
.40339 .59547 L
.40453 .59547 L
.40453 .59432 L
F
.40453 .59432 m
.40453 .59547 L
.40568 .59547 L
.40568 .59432 L
F
.40568 .59432 m
.40568 .59547 L
.40682 .59547 L
.40682 .59432 L
F
.43769 .59432 m
.43769 .59547 L
.43883 .59547 L
.43883 .59432 L
F
.37023 .59547 m
.37023 .59661 L
.37138 .59661 L
.37138 .59547 L
F
.40225 .59547 m
.40225 .59661 L
.40339 .59661 L
.40339 .59547 L
F
.40339 .59547 m
.40339 .59661 L
.40453 .59661 L
.40453 .59547 L
F
.40453 .59547 m
.40453 .59661 L
.40568 .59661 L
.40568 .59547 L
F
.43655 .59547 m
.43655 .59661 L
.43769 .59661 L
.43769 .59547 L
F
.36909 .59661 m
.36909 .59775 L
.37023 .59775 L
.37023 .59661 L
F
.4011 .59661 m
.4011 .59775 L
.40225 .59775 L
.40225 .59661 L
F
.40225 .59661 m
.40225 .59775 L
.40339 .59775 L
.40339 .59661 L
F
.40339 .59661 m
.40339 .59775 L
.40453 .59775 L
.40453 .59661 L
F
.4354 .59661 m
.4354 .59775 L
.43655 .59775 L
.43655 .59661 L
F
.36795 .59775 m
.36795 .5989 L
.36909 .5989 L
.36909 .59775 L
F
.39996 .59775 m
.39996 .5989 L
.4011 .5989 L
.4011 .59775 L
F
.4011 .59775 m
.4011 .5989 L
.40225 .5989 L
.40225 .59775 L
F
.40225 .59775 m
.40225 .5989 L
.40339 .5989 L
.40339 .59775 L
F
.43426 .59775 m
.43426 .5989 L
.4354 .5989 L
.4354 .59775 L
F
.3668 .5989 m
.3668 .60004 L
.36795 .60004 L
.36795 .5989 L
F
.39882 .5989 m
.39882 .60004 L
.39996 .60004 L
.39996 .5989 L
F
.39996 .5989 m
.39996 .60004 L
.4011 .60004 L
.4011 .5989 L
F
.4011 .5989 m
.4011 .60004 L
.40225 .60004 L
.40225 .5989 L
F
.43312 .5989 m
.43312 .60004 L
.43426 .60004 L
.43426 .5989 L
F
.36566 .60004 m
.36566 .60118 L
.3668 .60118 L
.3668 .60004 L
F
.39767 .60004 m
.39767 .60118 L
.39882 .60118 L
.39882 .60004 L
F
.39882 .60004 m
.39882 .60118 L
.39996 .60118 L
.39996 .60004 L
F
.39996 .60004 m
.39996 .60118 L
.4011 .60118 L
.4011 .60004 L
F
.43197 .60004 m
.43197 .60118 L
.43312 .60118 L
.43312 .60004 L
F
.36452 .60118 m
.36452 .60233 L
.36566 .60233 L
.36566 .60118 L
F
.39653 .60118 m
.39653 .60233 L
.39767 .60233 L
.39767 .60118 L
F
.39767 .60118 m
.39767 .60233 L
.39882 .60233 L
.39882 .60118 L
F
.39882 .60118 m
.39882 .60233 L
.39996 .60233 L
.39996 .60118 L
F
.43083 .60118 m
.43083 .60233 L
.43197 .60233 L
.43197 .60118 L
F
.36337 .60233 m
.36337 .60347 L
.36452 .60347 L
.36452 .60233 L
F
.39539 .60233 m
.39539 .60347 L
.39653 .60347 L
.39653 .60233 L
F
.39653 .60233 m
.39653 .60347 L
.39767 .60347 L
.39767 .60233 L
F
.39767 .60233 m
.39767 .60347 L
.39882 .60347 L
.39882 .60233 L
F
.42969 .60233 m
.42969 .60347 L
.43083 .60347 L
.43083 .60233 L
F
.36223 .60347 m
.36223 .60461 L
.36337 .60461 L
.36337 .60347 L
F
.39424 .60347 m
.39424 .60461 L
.39539 .60461 L
.39539 .60347 L
F
.39539 .60347 m
.39539 .60461 L
.39653 .60461 L
.39653 .60347 L
F
.39653 .60347 m
.39653 .60461 L
.39767 .60461 L
.39767 .60347 L
F
.42854 .60347 m
.42854 .60461 L
.42969 .60461 L
.42969 .60347 L
F
.36109 .60461 m
.36109 .60576 L
.36223 .60576 L
.36223 .60461 L
F
.3931 .60461 m
.3931 .60576 L
.39424 .60576 L
.39424 .60461 L
F
.39424 .60461 m
.39424 .60576 L
.39539 .60576 L
.39539 .60461 L
F
.39539 .60461 m
.39539 .60576 L
.39653 .60576 L
.39653 .60461 L
F
.4274 .60461 m
.4274 .60576 L
.42854 .60576 L
.42854 .60461 L
F
.35994 .60576 m
.35994 .6069 L
.36109 .6069 L
.36109 .60576 L
F
.39196 .60576 m
.39196 .6069 L
.3931 .6069 L
.3931 .60576 L
F
.3931 .60576 m
.3931 .6069 L
.39424 .6069 L
.39424 .60576 L
F
.39424 .60576 m
.39424 .6069 L
.39539 .6069 L
.39539 .60576 L
F
.42626 .60576 m
.42626 .6069 L
.4274 .6069 L
.4274 .60576 L
F
.3588 .6069 m
.3588 .60804 L
.35994 .60804 L
.35994 .6069 L
F
.39081 .6069 m
.39081 .60804 L
.39196 .60804 L
.39196 .6069 L
F
.39196 .6069 m
.39196 .60804 L
.3931 .60804 L
.3931 .6069 L
F
.3931 .6069 m
.3931 .60804 L
.39424 .60804 L
.39424 .6069 L
F
.42511 .6069 m
.42511 .60804 L
.42626 .60804 L
.42626 .6069 L
F
.35766 .60804 m
.35766 .60919 L
.3588 .60919 L
.3588 .60804 L
F
.38967 .60804 m
.38967 .60919 L
.39081 .60919 L
.39081 .60804 L
F
.39081 .60804 m
.39081 .60919 L
.39196 .60919 L
.39196 .60804 L
F
.39196 .60804 m
.39196 .60919 L
.3931 .60919 L
.3931 .60804 L
F
.42397 .60804 m
.42397 .60919 L
.42511 .60919 L
.42511 .60804 L
F
.35651 .60919 m
.35651 .61033 L
.35766 .61033 L
.35766 .60919 L
F
.38853 .60919 m
.38853 .61033 L
.38967 .61033 L
.38967 .60919 L
F
.38967 .60919 m
.38967 .61033 L
.39081 .61033 L
.39081 .60919 L
F
.39081 .60919 m
.39081 .61033 L
.39196 .61033 L
.39196 .60919 L
F
.42283 .60919 m
.42283 .61033 L
.42397 .61033 L
.42397 .60919 L
F
.35537 .61033 m
.35537 .61147 L
.35651 .61147 L
.35651 .61033 L
F
.38738 .61033 m
.38738 .61147 L
.38853 .61147 L
.38853 .61033 L
F
.38853 .61033 m
.38853 .61147 L
.38967 .61147 L
.38967 .61033 L
F
.38967 .61033 m
.38967 .61147 L
.39081 .61147 L
.39081 .61033 L
F
.42168 .61033 m
.42168 .61147 L
.42283 .61147 L
.42283 .61033 L
F
.35423 .61147 m
.35423 .61262 L
.35537 .61262 L
.35537 .61147 L
F
.38624 .61147 m
.38624 .61262 L
.38738 .61262 L
.38738 .61147 L
F
.38738 .61147 m
.38738 .61262 L
.38853 .61262 L
.38853 .61147 L
F
.38853 .61147 m
.38853 .61262 L
.38967 .61262 L
.38967 .61147 L
F
.42054 .61147 m
.42054 .61262 L
.42168 .61262 L
.42168 .61147 L
F
.35308 .61262 m
.35308 .61376 L
.35423 .61376 L
.35423 .61262 L
F
.3851 .61262 m
.3851 .61376 L
.38624 .61376 L
.38624 .61262 L
F
.38624 .61262 m
.38624 .61376 L
.38738 .61376 L
.38738 .61262 L
F
.38738 .61262 m
.38738 .61376 L
.38853 .61376 L
.38853 .61262 L
F
.4194 .61262 m
.4194 .61376 L
.42054 .61376 L
.42054 .61262 L
F
.35194 .61376 m
.35194 .6149 L
.35308 .6149 L
.35308 .61376 L
F
.38395 .61376 m
.38395 .6149 L
.3851 .6149 L
.3851 .61376 L
F
.3851 .61376 m
.3851 .6149 L
.38624 .6149 L
.38624 .61376 L
F
.38624 .61376 m
.38624 .6149 L
.38738 .6149 L
.38738 .61376 L
F
.41825 .61376 m
.41825 .6149 L
.4194 .6149 L
.4194 .61376 L
F
.3508 .6149 m
.3508 .61605 L
.35194 .61605 L
.35194 .6149 L
F
.38395 .6149 m
.38395 .61605 L
.3851 .61605 L
.3851 .6149 L
F
.3851 .6149 m
.3851 .61605 L
.38624 .61605 L
.38624 .6149 L
F
.41711 .6149 m
.41711 .61605 L
.41825 .61605 L
.41825 .6149 L
F
.34965 .61605 m
.34965 .61719 L
.3508 .61719 L
.3508 .61605 L
F
.38167 .61605 m
.38167 .61719 L
.38281 .61719 L
.38281 .61605 L
F
.38281 .61605 m
.38281 .61719 L
.38395 .61719 L
.38395 .61605 L
F
.41597 .61605 m
.41597 .61719 L
.41711 .61719 L
.41711 .61605 L
F
.34851 .61719 m
.34851 .61833 L
.34965 .61833 L
.34965 .61719 L
F
.38052 .61719 m
.38052 .61833 L
.38167 .61833 L
.38167 .61719 L
F
.38167 .61719 m
.38167 .61833 L
.38281 .61833 L
.38281 .61719 L
F
.38281 .61719 m
.38281 .61833 L
.38395 .61833 L
.38395 .61719 L
F
.41482 .61719 m
.41482 .61833 L
.41597 .61833 L
.41597 .61719 L
F
.34737 .61833 m
.34737 .61948 L
.34851 .61948 L
.34851 .61833 L
F
.37938 .61833 m
.37938 .61948 L
.38052 .61948 L
.38052 .61833 L
F
.38052 .61833 m
.38052 .61948 L
.38167 .61948 L
.38167 .61833 L
F
.38167 .61833 m
.38167 .61948 L
.38281 .61948 L
.38281 .61833 L
F
.41368 .61833 m
.41368 .61948 L
.41482 .61948 L
.41482 .61833 L
F
.34622 .61948 m
.34622 .62062 L
.34737 .62062 L
.34737 .61948 L
F
.37824 .61948 m
.37824 .62062 L
.37938 .62062 L
.37938 .61948 L
F
.37938 .61948 m
.37938 .62062 L
.38052 .62062 L
.38052 .61948 L
F
.38052 .61948 m
.38052 .62062 L
.38167 .62062 L
.38167 .61948 L
F
.41254 .61948 m
.41254 .62062 L
.41368 .62062 L
.41368 .61948 L
F
.34508 .62062 m
.34508 .62176 L
.34622 .62176 L
.34622 .62062 L
F
.37709 .62062 m
.37709 .62176 L
.37824 .62176 L
.37824 .62062 L
F
.37824 .62062 m
.37824 .62176 L
.37938 .62176 L
.37938 .62062 L
F
.37938 .62062 m
.37938 .62176 L
.38052 .62176 L
.38052 .62062 L
F
.41139 .62062 m
.41139 .62176 L
.41254 .62176 L
.41254 .62062 L
F
.34394 .62176 m
.34394 .62291 L
.34508 .62291 L
.34508 .62176 L
F
.37595 .62176 m
.37595 .62291 L
.37709 .62291 L
.37709 .62176 L
F
.37709 .62176 m
.37709 .62291 L
.37824 .62291 L
.37824 .62176 L
F
.37824 .62176 m
.37824 .62291 L
.37938 .62291 L
.37938 .62176 L
F
.41025 .62176 m
.41025 .62291 L
.41139 .62291 L
.41139 .62176 L
F
.34279 .62291 m
.34279 .62405 L
.34394 .62405 L
.34394 .62291 L
F
.37481 .62291 m
.37481 .62405 L
.37595 .62405 L
.37595 .62291 L
F
.37595 .62291 m
.37595 .62405 L
.37709 .62405 L
.37709 .62291 L
F
.37709 .62291 m
.37709 .62405 L
.37824 .62405 L
.37824 .62291 L
F
.40911 .62291 m
.40911 .62405 L
.41025 .62405 L
.41025 .62291 L
F
.34165 .62405 m
.34165 .62519 L
.34279 .62519 L
.34279 .62405 L
F
.37366 .62405 m
.37366 .62519 L
.37481 .62519 L
.37481 .62405 L
F
.37481 .62405 m
.37481 .62519 L
.37595 .62519 L
.37595 .62405 L
F
.37595 .62405 m
.37595 .62519 L
.37709 .62519 L
.37709 .62405 L
F
.40796 .62405 m
.40796 .62519 L
.40911 .62519 L
.40911 .62405 L
F
.34051 .62519 m
.34051 .62634 L
.34165 .62634 L
.34165 .62519 L
F
.37252 .62519 m
.37252 .62634 L
.37366 .62634 L
.37366 .62519 L
F
.37366 .62519 m
.37366 .62634 L
.37481 .62634 L
.37481 .62519 L
F
.37481 .62519 m
.37481 .62634 L
.37595 .62634 L
.37595 .62519 L
F
.40682 .62519 m
.40682 .62634 L
.40796 .62634 L
.40796 .62519 L
F
.33936 .62634 m
.33936 .62748 L
.34051 .62748 L
.34051 .62634 L
F
.37138 .62634 m
.37138 .62748 L
.37252 .62748 L
.37252 .62634 L
F
.37252 .62634 m
.37252 .62748 L
.37366 .62748 L
.37366 .62634 L
F
.37366 .62634 m
.37366 .62748 L
.37481 .62748 L
.37481 .62634 L
F
.40568 .62634 m
.40568 .62748 L
.40682 .62748 L
.40682 .62634 L
F
.33822 .62748 m
.33822 .62862 L
.33936 .62862 L
.33936 .62748 L
F
.37023 .62748 m
.37023 .62862 L
.37138 .62862 L
.37138 .62748 L
F
.37138 .62748 m
.37138 .62862 L
.37252 .62862 L
.37252 .62748 L
F
.37252 .62748 m
.37252 .62862 L
.37366 .62862 L
.37366 .62748 L
F
.40453 .62748 m
.40453 .62862 L
.40568 .62862 L
.40568 .62748 L
F
.33708 .62862 m
.33708 .62977 L
.33822 .62977 L
.33822 .62862 L
F
.36909 .62862 m
.36909 .62977 L
.37023 .62977 L
.37023 .62862 L
F
.37023 .62862 m
.37023 .62977 L
.37138 .62977 L
.37138 .62862 L
F
.37138 .62862 m
.37138 .62977 L
.37252 .62977 L
.37252 .62862 L
F
.40339 .62862 m
.40339 .62977 L
.40453 .62977 L
.40453 .62862 L
F
.33593 .62977 m
.33593 .63091 L
.33708 .63091 L
.33708 .62977 L
F
.36795 .62977 m
.36795 .63091 L
.36909 .63091 L
.36909 .62977 L
F
.36909 .62977 m
.36909 .63091 L
.37023 .63091 L
.37023 .62977 L
F
.37023 .62977 m
.37023 .63091 L
.37138 .63091 L
.37138 .62977 L
F
.40225 .62977 m
.40225 .63091 L
.40339 .63091 L
.40339 .62977 L
F
.33479 .63091 m
.33479 .63205 L
.33593 .63205 L
.33593 .63091 L
F
.3668 .63091 m
.3668 .63205 L
.36795 .63205 L
.36795 .63091 L
F
.36795 .63091 m
.36795 .63205 L
.36909 .63205 L
.36909 .63091 L
F
.36909 .63091 m
.36909 .63205 L
.37023 .63205 L
.37023 .63091 L
F
.4011 .63091 m
.4011 .63205 L
.40225 .63205 L
.40225 .63091 L
F
.33365 .63205 m
.33365 .6332 L
.33479 .6332 L
.33479 .63205 L
F
.36566 .63205 m
.36566 .6332 L
.3668 .6332 L
.3668 .63205 L
F
.3668 .63205 m
.3668 .6332 L
.36795 .6332 L
.36795 .63205 L
F
.36795 .63205 m
.36795 .6332 L
.36909 .6332 L
.36909 .63205 L
F
.39996 .63205 m
.39996 .6332 L
.4011 .6332 L
.4011 .63205 L
F
.3325 .6332 m
.3325 .63434 L
.33365 .63434 L
.33365 .6332 L
F
.36452 .6332 m
.36452 .63434 L
.36566 .63434 L
.36566 .6332 L
F
.36566 .6332 m
.36566 .63434 L
.3668 .63434 L
.3668 .6332 L
F
.3668 .6332 m
.3668 .63434 L
.36795 .63434 L
.36795 .6332 L
F
.39882 .6332 m
.39882 .63434 L
.39996 .63434 L
.39996 .6332 L
F
.33136 .63434 m
.33136 .63548 L
.3325 .63548 L
.3325 .63434 L
F
.36337 .63434 m
.36337 .63548 L
.36452 .63548 L
.36452 .63434 L
F
.36452 .63434 m
.36452 .63548 L
.36566 .63548 L
.36566 .63434 L
F
.36566 .63434 m
.36566 .63548 L
.3668 .63548 L
.3668 .63434 L
F
.39767 .63434 m
.39767 .63548 L
.39882 .63548 L
.39882 .63434 L
F
.33022 .63548 m
.33022 .63663 L
.33136 .63663 L
.33136 .63548 L
F
.36223 .63548 m
.36223 .63663 L
.36337 .63663 L
.36337 .63548 L
F
.36337 .63548 m
.36337 .63663 L
.36452 .63663 L
.36452 .63548 L
F
.36452 .63548 m
.36452 .63663 L
.36566 .63663 L
.36566 .63548 L
F
.39653 .63548 m
.39653 .63663 L
.39767 .63663 L
.39767 .63548 L
F
.32907 .63663 m
.32907 .63777 L
.33022 .63777 L
.33022 .63663 L
F
.36109 .63663 m
.36109 .63777 L
.36223 .63777 L
.36223 .63663 L
F
.36223 .63663 m
.36223 .63777 L
.36337 .63777 L
.36337 .63663 L
F
.36337 .63663 m
.36337 .63777 L
.36452 .63777 L
.36452 .63663 L
F
.39539 .63663 m
.39539 .63777 L
.39653 .63777 L
.39653 .63663 L
F
.32793 .63777 m
.32793 .63891 L
.32907 .63891 L
.32907 .63777 L
F
.35994 .63777 m
.35994 .63891 L
.36109 .63891 L
.36109 .63777 L
F
.36109 .63777 m
.36109 .63891 L
.36223 .63891 L
.36223 .63777 L
F
.36223 .63777 m
.36223 .63891 L
.36337 .63891 L
.36337 .63777 L
F
.39424 .63777 m
.39424 .63891 L
.39539 .63891 L
.39539 .63777 L
F
.32679 .63891 m
.32679 .64006 L
.32793 .64006 L
.32793 .63891 L
F
.3588 .63891 m
.3588 .64006 L
.35994 .64006 L
.35994 .63891 L
F
.35994 .63891 m
.35994 .64006 L
.36109 .64006 L
.36109 .63891 L
F
.36109 .63891 m
.36109 .64006 L
.36223 .64006 L
.36223 .63891 L
F
.3931 .63891 m
.3931 .64006 L
.39424 .64006 L
.39424 .63891 L
F
.32564 .64006 m
.32564 .6412 L
.32679 .6412 L
.32679 .64006 L
F
.35766 .64006 m
.35766 .6412 L
.3588 .6412 L
.3588 .64006 L
F
.3588 .64006 m
.3588 .6412 L
.35994 .6412 L
.35994 .64006 L
F
.35994 .64006 m
.35994 .6412 L
.36109 .6412 L
.36109 .64006 L
F
.39196 .64006 m
.39196 .6412 L
.3931 .6412 L
.3931 .64006 L
F
.3245 .6412 m
.3245 .64234 L
.32564 .64234 L
.32564 .6412 L
F
.35651 .6412 m
.35651 .64234 L
.35766 .64234 L
.35766 .6412 L
F
.35766 .6412 m
.35766 .64234 L
.3588 .64234 L
.3588 .6412 L
F
.3588 .6412 m
.3588 .64234 L
.35994 .64234 L
.35994 .6412 L
F
.39081 .6412 m
.39081 .64234 L
.39196 .64234 L
.39196 .6412 L
F
.32336 .64234 m
.32336 .64349 L
.3245 .64349 L
.3245 .64234 L
F
.35537 .64234 m
.35537 .64349 L
.35651 .64349 L
.35651 .64234 L
F
.35651 .64234 m
.35651 .64349 L
.35766 .64349 L
.35766 .64234 L
F
.35766 .64234 m
.35766 .64349 L
.3588 .64349 L
.3588 .64234 L
F
.38967 .64234 m
.38967 .64349 L
.39081 .64349 L
.39081 .64234 L
F
.32221 .64349 m
.32221 .64463 L
.32336 .64463 L
.32336 .64349 L
F
.35423 .64349 m
.35423 .64463 L
.35537 .64463 L
.35537 .64349 L
F
.35537 .64349 m
.35537 .64463 L
.35651 .64463 L
.35651 .64349 L
F
.35651 .64349 m
.35651 .64463 L
.35766 .64463 L
.35766 .64349 L
F
.38853 .64349 m
.38853 .64463 L
.38967 .64463 L
.38967 .64349 L
F
.32107 .64463 m
.32107 .64577 L
.32221 .64577 L
.32221 .64463 L
F
.35308 .64463 m
.35308 .64577 L
.35423 .64577 L
.35423 .64463 L
F
.35423 .64463 m
.35423 .64577 L
.35537 .64577 L
.35537 .64463 L
F
.35537 .64463 m
.35537 .64577 L
.35651 .64577 L
.35651 .64463 L
F
.38738 .64463 m
.38738 .64577 L
.38853 .64577 L
.38853 .64463 L
F
.31993 .64577 m
.31993 .64692 L
.32107 .64692 L
.32107 .64577 L
F
.35194 .64577 m
.35194 .64692 L
.35308 .64692 L
.35308 .64577 L
F
.35308 .64577 m
.35308 .64692 L
.35423 .64692 L
.35423 .64577 L
F
.35423 .64577 m
.35423 .64692 L
.35537 .64692 L
.35537 .64577 L
F
.38624 .64577 m
.38624 .64692 L
.38738 .64692 L
.38738 .64577 L
F
.31878 .64692 m
.31878 .64806 L
.31993 .64806 L
.31993 .64692 L
F
.3508 .64692 m
.3508 .64806 L
.35194 .64806 L
.35194 .64692 L
F
.35194 .64692 m
.35194 .64806 L
.35308 .64806 L
.35308 .64692 L
F
.35308 .64692 m
.35308 .64806 L
.35423 .64806 L
.35423 .64692 L
F
.3851 .64692 m
.3851 .64806 L
.38624 .64806 L
.38624 .64692 L
F
.31764 .64806 m
.31764 .6492 L
.31878 .6492 L
.31878 .64806 L
F
.3508 .64806 m
.3508 .6492 L
.35194 .6492 L
.35194 .64806 L
F
.35194 .64806 m
.35194 .6492 L
.35308 .6492 L
.35308 .64806 L
F
.38395 .64806 m
.38395 .6492 L
.3851 .6492 L
.3851 .64806 L
F
.3165 .6492 m
.3165 .65035 L
.31764 .65035 L
.31764 .6492 L
F
.34851 .6492 m
.34851 .65035 L
.34965 .65035 L
.34965 .6492 L
F
.34965 .6492 m
.34965 .65035 L
.3508 .65035 L
.3508 .6492 L
F
.38281 .6492 m
.38281 .65035 L
.38395 .65035 L
.38395 .6492 L
F
.31535 .65035 m
.31535 .65149 L
.3165 .65149 L
.3165 .65035 L
F
.34737 .65035 m
.34737 .65149 L
.34851 .65149 L
.34851 .65035 L
F
.34851 .65035 m
.34851 .65149 L
.34965 .65149 L
.34965 .65035 L
F
.34965 .65035 m
.34965 .65149 L
.3508 .65149 L
.3508 .65035 L
F
.38167 .65035 m
.38167 .65149 L
.38281 .65149 L
.38281 .65035 L
F
.31421 .65149 m
.31421 .65263 L
.31535 .65263 L
.31535 .65149 L
F
.34622 .65149 m
.34622 .65263 L
.34737 .65263 L
.34737 .65149 L
F
.34737 .65149 m
.34737 .65263 L
.34851 .65263 L
.34851 .65149 L
F
.34851 .65149 m
.34851 .65263 L
.34965 .65263 L
.34965 .65149 L
F
.38052 .65149 m
.38052 .65263 L
.38167 .65263 L
.38167 .65149 L
F
.31307 .65263 m
.31307 .65378 L
.31421 .65378 L
.31421 .65263 L
F
.34508 .65263 m
.34508 .65378 L
.34622 .65378 L
.34622 .65263 L
F
.34622 .65263 m
.34622 .65378 L
.34737 .65378 L
.34737 .65263 L
F
.34737 .65263 m
.34737 .65378 L
.34851 .65378 L
.34851 .65263 L
F
.37938 .65263 m
.37938 .65378 L
.38052 .65378 L
.38052 .65263 L
F
.31192 .65378 m
.31192 .65492 L
.31307 .65492 L
.31307 .65378 L
F
.34394 .65378 m
.34394 .65492 L
.34508 .65492 L
.34508 .65378 L
F
.34508 .65378 m
.34508 .65492 L
.34622 .65492 L
.34622 .65378 L
F
.34622 .65378 m
.34622 .65492 L
.34737 .65492 L
.34737 .65378 L
F
.37824 .65378 m
.37824 .65492 L
.37938 .65492 L
.37938 .65378 L
F
.31078 .65492 m
.31078 .65606 L
.31192 .65606 L
.31192 .65492 L
F
.34279 .65492 m
.34279 .65606 L
.34394 .65606 L
.34394 .65492 L
F
.34394 .65492 m
.34394 .65606 L
.34508 .65606 L
.34508 .65492 L
F
.34508 .65492 m
.34508 .65606 L
.34622 .65606 L
.34622 .65492 L
F
.37709 .65492 m
.37709 .65606 L
.37824 .65606 L
.37824 .65492 L
F
.30964 .65606 m
.30964 .65721 L
.31078 .65721 L
.31078 .65606 L
F
.34165 .65606 m
.34165 .65721 L
.34279 .65721 L
.34279 .65606 L
F
.34279 .65606 m
.34279 .65721 L
.34394 .65721 L
.34394 .65606 L
F
.34394 .65606 m
.34394 .65721 L
.34508 .65721 L
.34508 .65606 L
F
.37595 .65606 m
.37595 .65721 L
.37709 .65721 L
.37709 .65606 L
F
.30849 .65721 m
.30849 .65835 L
.30964 .65835 L
.30964 .65721 L
F
.34051 .65721 m
.34051 .65835 L
.34165 .65835 L
.34165 .65721 L
F
.34165 .65721 m
.34165 .65835 L
.34279 .65835 L
.34279 .65721 L
F
.34279 .65721 m
.34279 .65835 L
.34394 .65835 L
.34394 .65721 L
F
.37481 .65721 m
.37481 .65835 L
.37595 .65835 L
.37595 .65721 L
F
.30735 .65835 m
.30735 .65949 L
.30849 .65949 L
.30849 .65835 L
F
.33936 .65835 m
.33936 .65949 L
.34051 .65949 L
.34051 .65835 L
F
.34051 .65835 m
.34051 .65949 L
.34165 .65949 L
.34165 .65835 L
F
.34165 .65835 m
.34165 .65949 L
.34279 .65949 L
.34279 .65835 L
F
.37366 .65835 m
.37366 .65949 L
.37481 .65949 L
.37481 .65835 L
F
.30621 .65949 m
.30621 .66064 L
.30735 .66064 L
.30735 .65949 L
F
.33822 .65949 m
.33822 .66064 L
.33936 .66064 L
.33936 .65949 L
F
.33936 .65949 m
.33936 .66064 L
.34051 .66064 L
.34051 .65949 L
F
.34051 .65949 m
.34051 .66064 L
.34165 .66064 L
.34165 .65949 L
F
.37252 .65949 m
.37252 .66064 L
.37366 .66064 L
.37366 .65949 L
F
.30506 .66064 m
.30506 .66178 L
.30621 .66178 L
.30621 .66064 L
F
.33708 .66064 m
.33708 .66178 L
.33822 .66178 L
.33822 .66064 L
F
.33822 .66064 m
.33822 .66178 L
.33936 .66178 L
.33936 .66064 L
F
.33936 .66064 m
.33936 .66178 L
.34051 .66178 L
.34051 .66064 L
F
.37138 .66064 m
.37138 .66178 L
.37252 .66178 L
.37252 .66064 L
F
.30392 .66178 m
.30392 .66292 L
.30506 .66292 L
.30506 .66178 L
F
.33593 .66178 m
.33593 .66292 L
.33708 .66292 L
.33708 .66178 L
F
.33708 .66178 m
.33708 .66292 L
.33822 .66292 L
.33822 .66178 L
F
.33822 .66178 m
.33822 .66292 L
.33936 .66292 L
.33936 .66178 L
F
.37023 .66178 m
.37023 .66292 L
.37138 .66292 L
.37138 .66178 L
F
.30278 .66292 m
.30278 .66407 L
.30392 .66407 L
.30392 .66292 L
F
.33479 .66292 m
.33479 .66407 L
.33593 .66407 L
.33593 .66292 L
F
.33593 .66292 m
.33593 .66407 L
.33708 .66407 L
.33708 .66292 L
F
.33708 .66292 m
.33708 .66407 L
.33822 .66407 L
.33822 .66292 L
F
.36909 .66292 m
.36909 .66407 L
.37023 .66407 L
.37023 .66292 L
F
.30163 .66407 m
.30163 .66521 L
.30278 .66521 L
.30278 .66407 L
F
.33365 .66407 m
.33365 .66521 L
.33479 .66521 L
.33479 .66407 L
F
.33479 .66407 m
.33479 .66521 L
.33593 .66521 L
.33593 .66407 L
F
.33593 .66407 m
.33593 .66521 L
.33708 .66521 L
.33708 .66407 L
F
.36795 .66407 m
.36795 .66521 L
.36909 .66521 L
.36909 .66407 L
F
.30049 .66521 m
.30049 .66635 L
.30163 .66635 L
.30163 .66521 L
F
.3325 .66521 m
.3325 .66635 L
.33365 .66635 L
.33365 .66521 L
F
.33365 .66521 m
.33365 .66635 L
.33479 .66635 L
.33479 .66521 L
F
.33479 .66521 m
.33479 .66635 L
.33593 .66635 L
.33593 .66521 L
F
.3668 .66521 m
.3668 .66635 L
.36795 .66635 L
.36795 .66521 L
F
.29935 .66635 m
.29935 .6675 L
.30049 .6675 L
.30049 .66635 L
F
.33136 .66635 m
.33136 .6675 L
.3325 .6675 L
.3325 .66635 L
F
.3325 .66635 m
.3325 .6675 L
.33365 .6675 L
.33365 .66635 L
F
.33365 .66635 m
.33365 .6675 L
.33479 .6675 L
.33479 .66635 L
F
.36566 .66635 m
.36566 .6675 L
.3668 .6675 L
.3668 .66635 L
F
.2982 .6675 m
.2982 .66864 L
.29935 .66864 L
.29935 .6675 L
F
.33022 .6675 m
.33022 .66864 L
.33136 .66864 L
.33136 .6675 L
F
.33136 .6675 m
.33136 .66864 L
.3325 .66864 L
.3325 .6675 L
F
.3325 .6675 m
.3325 .66864 L
.33365 .66864 L
.33365 .6675 L
F
.36452 .6675 m
.36452 .66864 L
.36566 .66864 L
.36566 .6675 L
F
.29706 .66864 m
.29706 .66978 L
.2982 .66978 L
.2982 .66864 L
F
.32907 .66864 m
.32907 .66978 L
.33022 .66978 L
.33022 .66864 L
F
.33022 .66864 m
.33022 .66978 L
.33136 .66978 L
.33136 .66864 L
F
.33136 .66864 m
.33136 .66978 L
.3325 .66978 L
.3325 .66864 L
F
.36337 .66864 m
.36337 .66978 L
.36452 .66978 L
.36452 .66864 L
F
.29592 .66978 m
.29592 .67093 L
.29706 .67093 L
.29706 .66978 L
F
.32793 .66978 m
.32793 .67093 L
.32907 .67093 L
.32907 .66978 L
F
.32907 .66978 m
.32907 .67093 L
.33022 .67093 L
.33022 .66978 L
F
.33022 .66978 m
.33022 .67093 L
.33136 .67093 L
.33136 .66978 L
F
.36223 .66978 m
.36223 .67093 L
.36337 .67093 L
.36337 .66978 L
F
.29477 .67093 m
.29477 .67207 L
.29592 .67207 L
.29592 .67093 L
F
.32679 .67093 m
.32679 .67207 L
.32793 .67207 L
.32793 .67093 L
F
.32793 .67093 m
.32793 .67207 L
.32907 .67207 L
.32907 .67093 L
F
.32907 .67093 m
.32907 .67207 L
.33022 .67207 L
.33022 .67093 L
F
.36109 .67093 m
.36109 .67207 L
.36223 .67207 L
.36223 .67093 L
F
.29363 .67207 m
.29363 .67321 L
.29477 .67321 L
.29477 .67207 L
F
.32564 .67207 m
.32564 .67321 L
.32679 .67321 L
.32679 .67207 L
F
.32679 .67207 m
.32679 .67321 L
.32793 .67321 L
.32793 .67207 L
F
.32793 .67207 m
.32793 .67321 L
.32907 .67321 L
.32907 .67207 L
F
.35994 .67207 m
.35994 .67321 L
.36109 .67321 L
.36109 .67207 L
F
.29249 .67321 m
.29249 .67436 L
.29363 .67436 L
.29363 .67321 L
F
.3245 .67321 m
.3245 .67436 L
.32564 .67436 L
.32564 .67321 L
F
.32564 .67321 m
.32564 .67436 L
.32679 .67436 L
.32679 .67321 L
F
.32679 .67321 m
.32679 .67436 L
.32793 .67436 L
.32793 .67321 L
F
.3588 .67321 m
.3588 .67436 L
.35994 .67436 L
.35994 .67321 L
F
.29134 .67436 m
.29134 .6755 L
.29249 .6755 L
.29249 .67436 L
F
.32336 .67436 m
.32336 .6755 L
.3245 .6755 L
.3245 .67436 L
F
.3245 .67436 m
.3245 .6755 L
.32564 .6755 L
.32564 .67436 L
F
.32564 .67436 m
.32564 .6755 L
.32679 .6755 L
.32679 .67436 L
F
.35766 .67436 m
.35766 .6755 L
.3588 .6755 L
.3588 .67436 L
F
.2902 .6755 m
.2902 .67664 L
.29134 .67664 L
.29134 .6755 L
F
.32221 .6755 m
.32221 .67664 L
.32336 .67664 L
.32336 .6755 L
F
.32336 .6755 m
.32336 .67664 L
.3245 .67664 L
.3245 .6755 L
F
.3245 .6755 m
.3245 .67664 L
.32564 .67664 L
.32564 .6755 L
F
.35651 .6755 m
.35651 .67664 L
.35766 .67664 L
.35766 .6755 L
F
.28906 .67664 m
.28906 .67779 L
.2902 .67779 L
.2902 .67664 L
F
.32107 .67664 m
.32107 .67779 L
.32221 .67779 L
.32221 .67664 L
F
.32221 .67664 m
.32221 .67779 L
.32336 .67779 L
.32336 .67664 L
F
.32336 .67664 m
.32336 .67779 L
.3245 .67779 L
.3245 .67664 L
F
.35537 .67664 m
.35537 .67779 L
.35651 .67779 L
.35651 .67664 L
F
.28791 .67779 m
.28791 .67893 L
.28906 .67893 L
.28906 .67779 L
F
.31993 .67779 m
.31993 .67893 L
.32107 .67893 L
.32107 .67779 L
F
.32107 .67779 m
.32107 .67893 L
.32221 .67893 L
.32221 .67779 L
F
.32221 .67779 m
.32221 .67893 L
.32336 .67893 L
.32336 .67779 L
F
.35423 .67779 m
.35423 .67893 L
.35537 .67893 L
.35537 .67779 L
F
.28677 .67893 m
.28677 .68007 L
.28791 .68007 L
.28791 .67893 L
F
.31878 .67893 m
.31878 .68007 L
.31993 .68007 L
.31993 .67893 L
F
.31993 .67893 m
.31993 .68007 L
.32107 .68007 L
.32107 .67893 L
F
.32107 .67893 m
.32107 .68007 L
.32221 .68007 L
.32221 .67893 L
F
.35308 .67893 m
.35308 .68007 L
.35423 .68007 L
.35423 .67893 L
F
.28563 .68007 m
.28563 .68122 L
.28677 .68122 L
.28677 .68007 L
F
.31764 .68007 m
.31764 .68122 L
.31878 .68122 L
.31878 .68007 L
F
.31878 .68007 m
.31878 .68122 L
.31993 .68122 L
.31993 .68007 L
F
.31993 .68007 m
.31993 .68122 L
.32107 .68122 L
.32107 .68007 L
F
.35194 .68007 m
.35194 .68122 L
.35308 .68122 L
.35308 .68007 L
F
.28448 .68122 m
.28448 .68236 L
.28563 .68236 L
.28563 .68122 L
F
.31764 .68122 m
.31764 .68236 L
.31878 .68236 L
.31878 .68122 L
F
.31878 .68122 m
.31878 .68236 L
.31993 .68236 L
.31993 .68122 L
F
.3508 .68122 m
.3508 .68236 L
.35194 .68236 L
.35194 .68122 L
F
.28334 .68236 m
.28334 .6835 L
.28448 .6835 L
.28448 .68236 L
F
.31535 .68236 m
.31535 .6835 L
.3165 .6835 L
.3165 .68236 L
F
.3165 .68236 m
.3165 .6835 L
.31764 .6835 L
.31764 .68236 L
F
.34965 .68236 m
.34965 .6835 L
.3508 .6835 L
.3508 .68236 L
F
.2822 .6835 m
.2822 .68465 L
.28334 .68465 L
.28334 .6835 L
F
.31421 .6835 m
.31421 .68465 L
.31535 .68465 L
.31535 .6835 L
F
.31535 .6835 m
.31535 .68465 L
.3165 .68465 L
.3165 .6835 L
F
.3165 .6835 m
.3165 .68465 L
.31764 .68465 L
.31764 .6835 L
F
.34851 .6835 m
.34851 .68465 L
.34965 .68465 L
.34965 .6835 L
F
.28105 .68465 m
.28105 .68579 L
.2822 .68579 L
.2822 .68465 L
F
.31307 .68465 m
.31307 .68579 L
.31421 .68579 L
.31421 .68465 L
F
.31421 .68465 m
.31421 .68579 L
.31535 .68579 L
.31535 .68465 L
F
.31535 .68465 m
.31535 .68579 L
.3165 .68579 L
.3165 .68465 L
F
.34737 .68465 m
.34737 .68579 L
.34851 .68579 L
.34851 .68465 L
F
.27991 .68579 m
.27991 .68693 L
.28105 .68693 L
.28105 .68579 L
F
.31192 .68579 m
.31192 .68693 L
.31307 .68693 L
.31307 .68579 L
F
.31307 .68579 m
.31307 .68693 L
.31421 .68693 L
.31421 .68579 L
F
.31421 .68579 m
.31421 .68693 L
.31535 .68693 L
.31535 .68579 L
F
.34622 .68579 m
.34622 .68693 L
.34737 .68693 L
.34737 .68579 L
F
.27877 .68693 m
.27877 .68808 L
.27991 .68808 L
.27991 .68693 L
F
.31078 .68693 m
.31078 .68808 L
.31192 .68808 L
.31192 .68693 L
F
.31192 .68693 m
.31192 .68808 L
.31307 .68808 L
.31307 .68693 L
F
.31307 .68693 m
.31307 .68808 L
.31421 .68808 L
.31421 .68693 L
F
.34508 .68693 m
.34508 .68808 L
.34622 .68808 L
.34622 .68693 L
F
.27762 .68808 m
.27762 .68922 L
.27877 .68922 L
.27877 .68808 L
F
.30964 .68808 m
.30964 .68922 L
.31078 .68922 L
.31078 .68808 L
F
.31078 .68808 m
.31078 .68922 L
.31192 .68922 L
.31192 .68808 L
F
.31192 .68808 m
.31192 .68922 L
.31307 .68922 L
.31307 .68808 L
F
.34394 .68808 m
.34394 .68922 L
.34508 .68922 L
.34508 .68808 L
F
.27648 .68922 m
.27648 .69036 L
.27762 .69036 L
.27762 .68922 L
F
.30849 .68922 m
.30849 .69036 L
.30964 .69036 L
.30964 .68922 L
F
.30964 .68922 m
.30964 .69036 L
.31078 .69036 L
.31078 .68922 L
F
.31078 .68922 m
.31078 .69036 L
.31192 .69036 L
.31192 .68922 L
F
.34279 .68922 m
.34279 .69036 L
.34394 .69036 L
.34394 .68922 L
F
.27534 .69036 m
.27534 .69151 L
.27648 .69151 L
.27648 .69036 L
F
.30735 .69036 m
.30735 .69151 L
.30849 .69151 L
.30849 .69036 L
F
.30849 .69036 m
.30849 .69151 L
.30964 .69151 L
.30964 .69036 L
F
.30964 .69036 m
.30964 .69151 L
.31078 .69151 L
.31078 .69036 L
F
.34165 .69036 m
.34165 .69151 L
.34279 .69151 L
.34279 .69036 L
F
.27419 .69151 m
.27419 .69265 L
.27534 .69265 L
.27534 .69151 L
F
.30621 .69151 m
.30621 .69265 L
.30735 .69265 L
.30735 .69151 L
F
.30735 .69151 m
.30735 .69265 L
.30849 .69265 L
.30849 .69151 L
F
.30849 .69151 m
.30849 .69265 L
.30964 .69265 L
.30964 .69151 L
F
.34051 .69151 m
.34051 .69265 L
.34165 .69265 L
.34165 .69151 L
F
.27305 .69265 m
.27305 .69379 L
.27419 .69379 L
.27419 .69265 L
F
.30506 .69265 m
.30506 .69379 L
.30621 .69379 L
.30621 .69265 L
F
.30621 .69265 m
.30621 .69379 L
.30735 .69379 L
.30735 .69265 L
F
.30735 .69265 m
.30735 .69379 L
.30849 .69379 L
.30849 .69265 L
F
.33936 .69265 m
.33936 .69379 L
.34051 .69379 L
.34051 .69265 L
F
.27191 .69379 m
.27191 .69494 L
.27305 .69494 L
.27305 .69379 L
F
.30392 .69379 m
.30392 .69494 L
.30506 .69494 L
.30506 .69379 L
F
.30506 .69379 m
.30506 .69494 L
.30621 .69494 L
.30621 .69379 L
F
.30621 .69379 m
.30621 .69494 L
.30735 .69494 L
.30735 .69379 L
F
.33822 .69379 m
.33822 .69494 L
.33936 .69494 L
.33936 .69379 L
F
.27076 .69494 m
.27076 .69608 L
.27191 .69608 L
.27191 .69494 L
F
.30278 .69494 m
.30278 .69608 L
.30392 .69608 L
.30392 .69494 L
F
.30392 .69494 m
.30392 .69608 L
.30506 .69608 L
.30506 .69494 L
F
.30506 .69494 m
.30506 .69608 L
.30621 .69608 L
.30621 .69494 L
F
.33708 .69494 m
.33708 .69608 L
.33822 .69608 L
.33822 .69494 L
F
.26962 .69608 m
.26962 .69722 L
.27076 .69722 L
.27076 .69608 L
F
.30163 .69608 m
.30163 .69722 L
.30278 .69722 L
.30278 .69608 L
F
.30278 .69608 m
.30278 .69722 L
.30392 .69722 L
.30392 .69608 L
F
.30392 .69608 m
.30392 .69722 L
.30506 .69722 L
.30506 .69608 L
F
.33593 .69608 m
.33593 .69722 L
.33708 .69722 L
.33708 .69608 L
F
.26848 .69722 m
.26848 .69837 L
.26962 .69837 L
.26962 .69722 L
F
.30049 .69722 m
.30049 .69837 L
.30163 .69837 L
.30163 .69722 L
F
.30163 .69722 m
.30163 .69837 L
.30278 .69837 L
.30278 .69722 L
F
.30278 .69722 m
.30278 .69837 L
.30392 .69837 L
.30392 .69722 L
F
.33479 .69722 m
.33479 .69837 L
.33593 .69837 L
.33593 .69722 L
F
.26733 .69837 m
.26733 .69951 L
.26848 .69951 L
.26848 .69837 L
F
.29935 .69837 m
.29935 .69951 L
.30049 .69951 L
.30049 .69837 L
F
.30049 .69837 m
.30049 .69951 L
.30163 .69951 L
.30163 .69837 L
F
.30163 .69837 m
.30163 .69951 L
.30278 .69951 L
.30278 .69837 L
F
.33365 .69837 m
.33365 .69951 L
.33479 .69951 L
.33479 .69837 L
F
.26619 .69951 m
.26619 .70065 L
.26733 .70065 L
.26733 .69951 L
F
.2982 .69951 m
.2982 .70065 L
.29935 .70065 L
.29935 .69951 L
F
.29935 .69951 m
.29935 .70065 L
.30049 .70065 L
.30049 .69951 L
F
.30049 .69951 m
.30049 .70065 L
.30163 .70065 L
.30163 .69951 L
F
.3325 .69951 m
.3325 .70065 L
.33365 .70065 L
.33365 .69951 L
F
.26505 .70065 m
.26505 .7018 L
.26619 .7018 L
.26619 .70065 L
F
.29706 .70065 m
.29706 .7018 L
.2982 .7018 L
.2982 .70065 L
F
.2982 .70065 m
.2982 .7018 L
.29935 .7018 L
.29935 .70065 L
F
.29935 .70065 m
.29935 .7018 L
.30049 .7018 L
.30049 .70065 L
F
.33136 .70065 m
.33136 .7018 L
.3325 .7018 L
.3325 .70065 L
F
.2639 .7018 m
.2639 .70294 L
.26505 .70294 L
.26505 .7018 L
F
.29592 .7018 m
.29592 .70294 L
.29706 .70294 L
.29706 .7018 L
F
.29706 .7018 m
.29706 .70294 L
.2982 .70294 L
.2982 .7018 L
F
.2982 .7018 m
.2982 .70294 L
.29935 .70294 L
.29935 .7018 L
F
.33022 .7018 m
.33022 .70294 L
.33136 .70294 L
.33136 .7018 L
F
.26276 .70294 m
.26276 .70408 L
.2639 .70408 L
.2639 .70294 L
F
.29477 .70294 m
.29477 .70408 L
.29592 .70408 L
.29592 .70294 L
F
.29592 .70294 m
.29592 .70408 L
.29706 .70408 L
.29706 .70294 L
F
.29706 .70294 m
.29706 .70408 L
.2982 .70408 L
.2982 .70294 L
F
.32907 .70294 m
.32907 .70408 L
.33022 .70408 L
.33022 .70294 L
F
.26162 .70408 m
.26162 .70523 L
.26276 .70523 L
.26276 .70408 L
F
.29363 .70408 m
.29363 .70523 L
.29477 .70523 L
.29477 .70408 L
F
.29477 .70408 m
.29477 .70523 L
.29592 .70523 L
.29592 .70408 L
F
.29592 .70408 m
.29592 .70523 L
.29706 .70523 L
.29706 .70408 L
F
.32793 .70408 m
.32793 .70523 L
.32907 .70523 L
.32907 .70408 L
F
.26047 .70523 m
.26047 .70637 L
.26162 .70637 L
.26162 .70523 L
F
.29249 .70523 m
.29249 .70637 L
.29363 .70637 L
.29363 .70523 L
F
.29363 .70523 m
.29363 .70637 L
.29477 .70637 L
.29477 .70523 L
F
.29477 .70523 m
.29477 .70637 L
.29592 .70637 L
.29592 .70523 L
F
.32679 .70523 m
.32679 .70637 L
.32793 .70637 L
.32793 .70523 L
F
.25933 .70637 m
.25933 .70751 L
.26047 .70751 L
.26047 .70637 L
F
.29134 .70637 m
.29134 .70751 L
.29249 .70751 L
.29249 .70637 L
F
.29249 .70637 m
.29249 .70751 L
.29363 .70751 L
.29363 .70637 L
F
.29363 .70637 m
.29363 .70751 L
.29477 .70751 L
.29477 .70637 L
F
.32564 .70637 m
.32564 .70751 L
.32679 .70751 L
.32679 .70637 L
F
.25819 .70751 m
.25819 .70866 L
.25933 .70866 L
.25933 .70751 L
F
.2902 .70751 m
.2902 .70866 L
.29134 .70866 L
.29134 .70751 L
F
.29134 .70751 m
.29134 .70866 L
.29249 .70866 L
.29249 .70751 L
F
.29249 .70751 m
.29249 .70866 L
.29363 .70866 L
.29363 .70751 L
F
.3245 .70751 m
.3245 .70866 L
.32564 .70866 L
.32564 .70751 L
F
.25704 .70866 m
.25704 .7098 L
.25819 .7098 L
.25819 .70866 L
F
.28906 .70866 m
.28906 .7098 L
.2902 .7098 L
.2902 .70866 L
F
.2902 .70866 m
.2902 .7098 L
.29134 .7098 L
.29134 .70866 L
F
.29134 .70866 m
.29134 .7098 L
.29249 .7098 L
.29249 .70866 L
F
.32336 .70866 m
.32336 .7098 L
.3245 .7098 L
.3245 .70866 L
F
.2559 .7098 m
.2559 .71094 L
.25704 .71094 L
.25704 .7098 L
F
.28791 .7098 m
.28791 .71094 L
.28906 .71094 L
.28906 .7098 L
F
.28906 .7098 m
.28906 .71094 L
.2902 .71094 L
.2902 .7098 L
F
.2902 .7098 m
.2902 .71094 L
.29134 .71094 L
.29134 .7098 L
F
.32221 .7098 m
.32221 .71094 L
.32336 .71094 L
.32336 .7098 L
F
.25476 .71094 m
.25476 .71209 L
.2559 .71209 L
.2559 .71094 L
F
.28677 .71094 m
.28677 .71209 L
.28791 .71209 L
.28791 .71094 L
F
.28791 .71094 m
.28791 .71209 L
.28906 .71209 L
.28906 .71094 L
F
.28906 .71094 m
.28906 .71209 L
.2902 .71209 L
.2902 .71094 L
F
.32107 .71094 m
.32107 .71209 L
.32221 .71209 L
.32221 .71094 L
F
.25361 .71209 m
.25361 .71323 L
.25476 .71323 L
.25476 .71209 L
F
.28563 .71209 m
.28563 .71323 L
.28677 .71323 L
.28677 .71209 L
F
.28677 .71209 m
.28677 .71323 L
.28791 .71323 L
.28791 .71209 L
F
.28791 .71209 m
.28791 .71323 L
.28906 .71323 L
.28906 .71209 L
F
.31993 .71209 m
.31993 .71323 L
.32107 .71323 L
.32107 .71209 L
F
.25247 .71323 m
.25247 .71437 L
.25361 .71437 L
.25361 .71323 L
F
.28448 .71323 m
.28448 .71437 L
.28563 .71437 L
.28563 .71323 L
F
.28563 .71323 m
.28563 .71437 L
.28677 .71437 L
.28677 .71323 L
F
.28677 .71323 m
.28677 .71437 L
.28791 .71437 L
.28791 .71323 L
F
.31878 .71323 m
.31878 .71437 L
.31993 .71437 L
.31993 .71323 L
F
.25133 .71437 m
.25133 .71552 L
.25247 .71552 L
.25247 .71437 L
F
.28448 .71437 m
.28448 .71552 L
.28563 .71552 L
.28563 .71437 L
F
.28563 .71437 m
.28563 .71552 L
.28677 .71552 L
.28677 .71437 L
F
.31764 .71437 m
.31764 .71552 L
.31878 .71552 L
.31878 .71437 L
F
.25018 .71552 m
.25018 .71666 L
.25133 .71666 L
.25133 .71552 L
F
.2822 .71552 m
.2822 .71666 L
.28334 .71666 L
.28334 .71552 L
F
.28334 .71552 m
.28334 .71666 L
.28448 .71666 L
.28448 .71552 L
F
.3165 .71552 m
.3165 .71666 L
.31764 .71666 L
.31764 .71552 L
F
.24904 .71666 m
.24904 .7178 L
.25018 .7178 L
.25018 .71666 L
F
.28105 .71666 m
.28105 .7178 L
.2822 .7178 L
.2822 .71666 L
F
.2822 .71666 m
.2822 .7178 L
.28334 .7178 L
.28334 .71666 L
F
.28334 .71666 m
.28334 .7178 L
.28448 .7178 L
.28448 .71666 L
F
.31535 .71666 m
.31535 .7178 L
.3165 .7178 L
.3165 .71666 L
F
.2479 .7178 m
.2479 .71895 L
.24904 .71895 L
.24904 .7178 L
F
.27991 .7178 m
.27991 .71895 L
.28105 .71895 L
.28105 .7178 L
F
.28105 .7178 m
.28105 .71895 L
.2822 .71895 L
.2822 .7178 L
F
.2822 .7178 m
.2822 .71895 L
.28334 .71895 L
.28334 .7178 L
F
.31421 .7178 m
.31421 .71895 L
.31535 .71895 L
.31535 .7178 L
F
.24675 .71895 m
.24675 .72009 L
.2479 .72009 L
.2479 .71895 L
F
.27877 .71895 m
.27877 .72009 L
.27991 .72009 L
.27991 .71895 L
F
.27991 .71895 m
.27991 .72009 L
.28105 .72009 L
.28105 .71895 L
F
.28105 .71895 m
.28105 .72009 L
.2822 .72009 L
.2822 .71895 L
F
.31307 .71895 m
.31307 .72009 L
.31421 .72009 L
.31421 .71895 L
F
.24561 .72009 m
.24561 .72123 L
.24675 .72123 L
.24675 .72009 L
F
.27762 .72009 m
.27762 .72123 L
.27877 .72123 L
.27877 .72009 L
F
.27877 .72009 m
.27877 .72123 L
.27991 .72123 L
.27991 .72009 L
F
.27991 .72009 m
.27991 .72123 L
.28105 .72123 L
.28105 .72009 L
F
.31192 .72009 m
.31192 .72123 L
.31307 .72123 L
.31307 .72009 L
F
.24447 .72123 m
.24447 .72238 L
.24561 .72238 L
.24561 .72123 L
F
.27648 .72123 m
.27648 .72238 L
.27762 .72238 L
.27762 .72123 L
F
.27762 .72123 m
.27762 .72238 L
.27877 .72238 L
.27877 .72123 L
F
.27877 .72123 m
.27877 .72238 L
.27991 .72238 L
.27991 .72123 L
F
.31078 .72123 m
.31078 .72238 L
.31192 .72238 L
.31192 .72123 L
F
.24332 .72238 m
.24332 .72352 L
.24447 .72352 L
.24447 .72238 L
F
.27534 .72238 m
.27534 .72352 L
.27648 .72352 L
.27648 .72238 L
F
.27648 .72238 m
.27648 .72352 L
.27762 .72352 L
.27762 .72238 L
F
.27762 .72238 m
.27762 .72352 L
.27877 .72352 L
.27877 .72238 L
F
.30964 .72238 m
.30964 .72352 L
.31078 .72352 L
.31078 .72238 L
F
.24218 .72352 m
.24218 .72466 L
.24332 .72466 L
.24332 .72352 L
F
.27419 .72352 m
.27419 .72466 L
.27534 .72466 L
.27534 .72352 L
F
.27534 .72352 m
.27534 .72466 L
.27648 .72466 L
.27648 .72352 L
F
.27648 .72352 m
.27648 .72466 L
.27762 .72466 L
.27762 .72352 L
F
.30849 .72352 m
.30849 .72466 L
.30964 .72466 L
.30964 .72352 L
F
.24104 .72466 m
.24104 .72581 L
.24218 .72581 L
.24218 .72466 L
F
.27305 .72466 m
.27305 .72581 L
.27419 .72581 L
.27419 .72466 L
F
.27419 .72466 m
.27419 .72581 L
.27534 .72581 L
.27534 .72466 L
F
.27534 .72466 m
.27534 .72581 L
.27648 .72581 L
.27648 .72466 L
F
.30735 .72466 m
.30735 .72581 L
.30849 .72581 L
.30849 .72466 L
F
.23989 .72581 m
.23989 .72695 L
.24104 .72695 L
.24104 .72581 L
F
.27191 .72581 m
.27191 .72695 L
.27305 .72695 L
.27305 .72581 L
F
.27305 .72581 m
.27305 .72695 L
.27419 .72695 L
.27419 .72581 L
F
.27419 .72581 m
.27419 .72695 L
.27534 .72695 L
.27534 .72581 L
F
.30621 .72581 m
.30621 .72695 L
.30735 .72695 L
.30735 .72581 L
F
.23875 .72695 m
.23875 .72809 L
.23989 .72809 L
.23989 .72695 L
F
.27076 .72695 m
.27076 .72809 L
.27191 .72809 L
.27191 .72695 L
F
.27191 .72695 m
.27191 .72809 L
.27305 .72809 L
.27305 .72695 L
F
.27305 .72695 m
.27305 .72809 L
.27419 .72809 L
.27419 .72695 L
F
.30506 .72695 m
.30506 .72809 L
.30621 .72809 L
.30621 .72695 L
F
.23761 .72809 m
.23761 .72924 L
.23875 .72924 L
.23875 .72809 L
F
.26962 .72809 m
.26962 .72924 L
.27076 .72924 L
.27076 .72809 L
F
.27076 .72809 m
.27076 .72924 L
.27191 .72924 L
.27191 .72809 L
F
.27191 .72809 m
.27191 .72924 L
.27305 .72924 L
.27305 .72809 L
F
.30392 .72809 m
.30392 .72924 L
.30506 .72924 L
.30506 .72809 L
F
.23646 .72924 m
.23646 .73038 L
.23761 .73038 L
.23761 .72924 L
F
.26848 .72924 m
.26848 .73038 L
.26962 .73038 L
.26962 .72924 L
F
.26962 .72924 m
.26962 .73038 L
.27076 .73038 L
.27076 .72924 L
F
.27076 .72924 m
.27076 .73038 L
.27191 .73038 L
.27191 .72924 L
F
.30278 .72924 m
.30278 .73038 L
.30392 .73038 L
.30392 .72924 L
F
.23532 .73038 m
.23532 .73152 L
.23646 .73152 L
.23646 .73038 L
F
.26733 .73038 m
.26733 .73152 L
.26848 .73152 L
.26848 .73038 L
F
.26848 .73038 m
.26848 .73152 L
.26962 .73152 L
.26962 .73038 L
F
.26962 .73038 m
.26962 .73152 L
.27076 .73152 L
.27076 .73038 L
F
.30163 .73038 m
.30163 .73152 L
.30278 .73152 L
.30278 .73038 L
F
.23418 .73152 m
.23418 .73267 L
.23532 .73267 L
.23532 .73152 L
F
.26619 .73152 m
.26619 .73267 L
.26733 .73267 L
.26733 .73152 L
F
.26733 .73152 m
.26733 .73267 L
.26848 .73267 L
.26848 .73152 L
F
.26848 .73152 m
.26848 .73267 L
.26962 .73267 L
.26962 .73152 L
F
.30049 .73152 m
.30049 .73267 L
.30163 .73267 L
.30163 .73152 L
F
.23303 .73267 m
.23303 .73381 L
.23418 .73381 L
.23418 .73267 L
F
.26505 .73267 m
.26505 .73381 L
.26619 .73381 L
.26619 .73267 L
F
.26619 .73267 m
.26619 .73381 L
.26733 .73381 L
.26733 .73267 L
F
.26733 .73267 m
.26733 .73381 L
.26848 .73381 L
.26848 .73267 L
F
.29935 .73267 m
.29935 .73381 L
.30049 .73381 L
.30049 .73267 L
F
.23189 .73381 m
.23189 .73495 L
.23303 .73495 L
.23303 .73381 L
F
.2639 .73381 m
.2639 .73495 L
.26505 .73495 L
.26505 .73381 L
F
.26505 .73381 m
.26505 .73495 L
.26619 .73495 L
.26619 .73381 L
F
.26619 .73381 m
.26619 .73495 L
.26733 .73495 L
.26733 .73381 L
F
.2982 .73381 m
.2982 .73495 L
.29935 .73495 L
.29935 .73381 L
F
.23075 .73495 m
.23075 .7361 L
.23189 .7361 L
.23189 .73495 L
F
.26276 .73495 m
.26276 .7361 L
.2639 .7361 L
.2639 .73495 L
F
.2639 .73495 m
.2639 .7361 L
.26505 .7361 L
.26505 .73495 L
F
.26505 .73495 m
.26505 .7361 L
.26619 .7361 L
.26619 .73495 L
F
.29706 .73495 m
.29706 .7361 L
.2982 .7361 L
.2982 .73495 L
F
.2296 .7361 m
.2296 .73724 L
.23075 .73724 L
.23075 .7361 L
F
.26162 .7361 m
.26162 .73724 L
.26276 .73724 L
.26276 .7361 L
F
.26276 .7361 m
.26276 .73724 L
.2639 .73724 L
.2639 .7361 L
F
.2639 .7361 m
.2639 .73724 L
.26505 .73724 L
.26505 .7361 L
F
.29592 .7361 m
.29592 .73724 L
.29706 .73724 L
.29706 .7361 L
F
.22846 .73724 m
.22846 .73838 L
.2296 .73838 L
.2296 .73724 L
F
.26047 .73724 m
.26047 .73838 L
.26162 .73838 L
.26162 .73724 L
F
.26162 .73724 m
.26162 .73838 L
.26276 .73838 L
.26276 .73724 L
F
.26276 .73724 m
.26276 .73838 L
.2639 .73838 L
.2639 .73724 L
F
.29477 .73724 m
.29477 .73838 L
.29592 .73838 L
.29592 .73724 L
F
.22732 .73838 m
.22732 .73953 L
.22846 .73953 L
.22846 .73838 L
F
.25933 .73838 m
.25933 .73953 L
.26047 .73953 L
.26047 .73838 L
F
.26047 .73838 m
.26047 .73953 L
.26162 .73953 L
.26162 .73838 L
F
.26162 .73838 m
.26162 .73953 L
.26276 .73953 L
.26276 .73838 L
F
.29363 .73838 m
.29363 .73953 L
.29477 .73953 L
.29477 .73838 L
F
.22617 .73953 m
.22617 .74067 L
.22732 .74067 L
.22732 .73953 L
F
.25819 .73953 m
.25819 .74067 L
.25933 .74067 L
.25933 .73953 L
F
.25933 .73953 m
.25933 .74067 L
.26047 .74067 L
.26047 .73953 L
F
.26047 .73953 m
.26047 .74067 L
.26162 .74067 L
.26162 .73953 L
F
.29249 .73953 m
.29249 .74067 L
.29363 .74067 L
.29363 .73953 L
F
.22503 .74067 m
.22503 .74181 L
.22617 .74181 L
.22617 .74067 L
F
.25704 .74067 m
.25704 .74181 L
.25819 .74181 L
.25819 .74067 L
F
.25819 .74067 m
.25819 .74181 L
.25933 .74181 L
.25933 .74067 L
F
.25933 .74067 m
.25933 .74181 L
.26047 .74181 L
.26047 .74067 L
F
.29134 .74067 m
.29134 .74181 L
.29249 .74181 L
.29249 .74067 L
F
.22389 .74181 m
.22389 .74296 L
.22503 .74296 L
.22503 .74181 L
F
.2559 .74181 m
.2559 .74296 L
.25704 .74296 L
.25704 .74181 L
F
.25704 .74181 m
.25704 .74296 L
.25819 .74296 L
.25819 .74181 L
F
.25819 .74181 m
.25819 .74296 L
.25933 .74296 L
.25933 .74181 L
F
.2902 .74181 m
.2902 .74296 L
.29134 .74296 L
.29134 .74181 L
F
.22274 .74296 m
.22274 .7441 L
.22389 .7441 L
.22389 .74296 L
F
.25476 .74296 m
.25476 .7441 L
.2559 .7441 L
.2559 .74296 L
F
.2559 .74296 m
.2559 .7441 L
.25704 .7441 L
.25704 .74296 L
F
.25704 .74296 m
.25704 .7441 L
.25819 .7441 L
.25819 .74296 L
F
.28906 .74296 m
.28906 .7441 L
.2902 .7441 L
.2902 .74296 L
F
.2216 .7441 m
.2216 .74524 L
.22274 .74524 L
.22274 .7441 L
F
.25361 .7441 m
.25361 .74524 L
.25476 .74524 L
.25476 .7441 L
F
.25476 .7441 m
.25476 .74524 L
.2559 .74524 L
.2559 .7441 L
F
.2559 .7441 m
.2559 .74524 L
.25704 .74524 L
.25704 .7441 L
F
.28791 .7441 m
.28791 .74524 L
.28906 .74524 L
.28906 .7441 L
F
.22046 .74524 m
.22046 .74639 L
.2216 .74639 L
.2216 .74524 L
F
.25247 .74524 m
.25247 .74639 L
.25361 .74639 L
.25361 .74524 L
F
.25361 .74524 m
.25361 .74639 L
.25476 .74639 L
.25476 .74524 L
F
.25476 .74524 m
.25476 .74639 L
.2559 .74639 L
.2559 .74524 L
F
.28677 .74524 m
.28677 .74639 L
.28791 .74639 L
.28791 .74524 L
F
.21931 .74639 m
.21931 .74753 L
.22046 .74753 L
.22046 .74639 L
F
.25133 .74639 m
.25133 .74753 L
.25247 .74753 L
.25247 .74639 L
F
.25247 .74639 m
.25247 .74753 L
.25361 .74753 L
.25361 .74639 L
F
.25361 .74639 m
.25361 .74753 L
.25476 .74753 L
.25476 .74639 L
F
.28563 .74639 m
.28563 .74753 L
.28677 .74753 L
.28677 .74639 L
F
.21817 .74753 m
.21817 .74867 L
.21931 .74867 L
.21931 .74753 L
F
.25133 .74753 m
.25133 .74867 L
.25247 .74867 L
.25247 .74753 L
F
.25247 .74753 m
.25247 .74867 L
.25361 .74867 L
.25361 .74753 L
F
.28448 .74753 m
.28448 .74867 L
.28563 .74867 L
.28563 .74753 L
F
.21703 .74867 m
.21703 .74982 L
.21817 .74982 L
.21817 .74867 L
F
.24904 .74867 m
.24904 .74982 L
.25018 .74982 L
.25018 .74867 L
F
.25018 .74867 m
.25018 .74982 L
.25133 .74982 L
.25133 .74867 L
F
.28334 .74867 m
.28334 .74982 L
.28448 .74982 L
.28448 .74867 L
F
.21588 .74982 m
.21588 .75096 L
.21703 .75096 L
.21703 .74982 L
F
.2479 .74982 m
.2479 .75096 L
.24904 .75096 L
.24904 .74982 L
F
.24904 .74982 m
.24904 .75096 L
.25018 .75096 L
.25018 .74982 L
F
.25018 .74982 m
.25018 .75096 L
.25133 .75096 L
.25133 .74982 L
F
.2822 .74982 m
.2822 .75096 L
.28334 .75096 L
.28334 .74982 L
F
.21474 .75096 m
.21474 .7521 L
.21588 .7521 L
.21588 .75096 L
F
.24675 .75096 m
.24675 .7521 L
.2479 .7521 L
.2479 .75096 L
F
.2479 .75096 m
.2479 .7521 L
.24904 .7521 L
.24904 .75096 L
F
.24904 .75096 m
.24904 .7521 L
.25018 .7521 L
.25018 .75096 L
F
.28105 .75096 m
.28105 .7521 L
.2822 .7521 L
.2822 .75096 L
F
.2136 .7521 m
.2136 .75325 L
.21474 .75325 L
.21474 .7521 L
F
.24561 .7521 m
.24561 .75325 L
.24675 .75325 L
.24675 .7521 L
F
.24675 .7521 m
.24675 .75325 L
.2479 .75325 L
.2479 .7521 L
F
.2479 .7521 m
.2479 .75325 L
.24904 .75325 L
.24904 .7521 L
F
.27991 .7521 m
.27991 .75325 L
.28105 .75325 L
.28105 .7521 L
F
.21245 .75325 m
.21245 .75439 L
.2136 .75439 L
.2136 .75325 L
F
.24447 .75325 m
.24447 .75439 L
.24561 .75439 L
.24561 .75325 L
F
.24561 .75325 m
.24561 .75439 L
.24675 .75439 L
.24675 .75325 L
F
.24675 .75325 m
.24675 .75439 L
.2479 .75439 L
.2479 .75325 L
F
.27877 .75325 m
.27877 .75439 L
.27991 .75439 L
.27991 .75325 L
F
.21131 .75439 m
.21131 .75553 L
.21245 .75553 L
.21245 .75439 L
F
.24332 .75439 m
.24332 .75553 L
.24447 .75553 L
.24447 .75439 L
F
.24447 .75439 m
.24447 .75553 L
.24561 .75553 L
.24561 .75439 L
F
.24561 .75439 m
.24561 .75553 L
.24675 .75553 L
.24675 .75439 L
F
.27762 .75439 m
.27762 .75553 L
.27877 .75553 L
.27877 .75439 L
F
.21017 .75553 m
.21017 .75668 L
.21131 .75668 L
.21131 .75553 L
F
.24218 .75553 m
.24218 .75668 L
.24332 .75668 L
.24332 .75553 L
F
.24332 .75553 m
.24332 .75668 L
.24447 .75668 L
.24447 .75553 L
F
.24447 .75553 m
.24447 .75668 L
.24561 .75668 L
.24561 .75553 L
F
.27648 .75553 m
.27648 .75668 L
.27762 .75668 L
.27762 .75553 L
F
.20902 .75668 m
.20902 .75782 L
.21017 .75782 L
.21017 .75668 L
F
.24104 .75668 m
.24104 .75782 L
.24218 .75782 L
.24218 .75668 L
F
.24218 .75668 m
.24218 .75782 L
.24332 .75782 L
.24332 .75668 L
F
.24332 .75668 m
.24332 .75782 L
.24447 .75782 L
.24447 .75668 L
F
.27534 .75668 m
.27534 .75782 L
.27648 .75782 L
.27648 .75668 L
F
.20788 .75782 m
.20788 .75896 L
.20902 .75896 L
.20902 .75782 L
F
.23989 .75782 m
.23989 .75896 L
.24104 .75896 L
.24104 .75782 L
F
.24104 .75782 m
.24104 .75896 L
.24218 .75896 L
.24218 .75782 L
F
.24218 .75782 m
.24218 .75896 L
.24332 .75896 L
.24332 .75782 L
F
.27419 .75782 m
.27419 .75896 L
.27534 .75896 L
.27534 .75782 L
F
.20674 .75896 m
.20674 .76011 L
.20788 .76011 L
.20788 .75896 L
F
.23875 .75896 m
.23875 .76011 L
.23989 .76011 L
.23989 .75896 L
F
.23989 .75896 m
.23989 .76011 L
.24104 .76011 L
.24104 .75896 L
F
.24104 .75896 m
.24104 .76011 L
.24218 .76011 L
.24218 .75896 L
F
.27305 .75896 m
.27305 .76011 L
.27419 .76011 L
.27419 .75896 L
F
.20559 .76011 m
.20559 .76125 L
.20674 .76125 L
.20674 .76011 L
F
.23761 .76011 m
.23761 .76125 L
.23875 .76125 L
.23875 .76011 L
F
.23875 .76011 m
.23875 .76125 L
.23989 .76125 L
.23989 .76011 L
F
.23989 .76011 m
.23989 .76125 L
.24104 .76125 L
.24104 .76011 L
F
.27191 .76011 m
.27191 .76125 L
.27305 .76125 L
.27305 .76011 L
F
.20445 .76125 m
.20445 .76239 L
.20559 .76239 L
.20559 .76125 L
F
.23646 .76125 m
.23646 .76239 L
.23761 .76239 L
.23761 .76125 L
F
.23761 .76125 m
.23761 .76239 L
.23875 .76239 L
.23875 .76125 L
F
.23875 .76125 m
.23875 .76239 L
.23989 .76239 L
.23989 .76125 L
F
.27076 .76125 m
.27076 .76239 L
.27191 .76239 L
.27191 .76125 L
F
.20331 .76239 m
.20331 .76354 L
.20445 .76354 L
.20445 .76239 L
F
.23532 .76239 m
.23532 .76354 L
.23646 .76354 L
.23646 .76239 L
F
.23646 .76239 m
.23646 .76354 L
.23761 .76354 L
.23761 .76239 L
F
.23761 .76239 m
.23761 .76354 L
.23875 .76354 L
.23875 .76239 L
F
.26962 .76239 m
.26962 .76354 L
.27076 .76354 L
.27076 .76239 L
F
.20216 .76354 m
.20216 .76468 L
.20331 .76468 L
.20331 .76354 L
F
.23418 .76354 m
.23418 .76468 L
.23532 .76468 L
.23532 .76354 L
F
.23532 .76354 m
.23532 .76468 L
.23646 .76468 L
.23646 .76354 L
F
.23646 .76354 m
.23646 .76468 L
.23761 .76468 L
.23761 .76354 L
F
.26848 .76354 m
.26848 .76468 L
.26962 .76468 L
.26962 .76354 L
F
.20102 .76468 m
.20102 .76582 L
.20216 .76582 L
.20216 .76468 L
F
.23303 .76468 m
.23303 .76582 L
.23418 .76582 L
.23418 .76468 L
F
.23418 .76468 m
.23418 .76582 L
.23532 .76582 L
.23532 .76468 L
F
.23532 .76468 m
.23532 .76582 L
.23646 .76582 L
.23646 .76468 L
F
.26733 .76468 m
.26733 .76582 L
.26848 .76582 L
.26848 .76468 L
F
.19988 .76582 m
.19988 .76697 L
.20102 .76697 L
.20102 .76582 L
F
.23189 .76582 m
.23189 .76697 L
.23303 .76697 L
.23303 .76582 L
F
.23303 .76582 m
.23303 .76697 L
.23418 .76697 L
.23418 .76582 L
F
.23418 .76582 m
.23418 .76697 L
.23532 .76697 L
.23532 .76582 L
F
.26619 .76582 m
.26619 .76697 L
.26733 .76697 L
.26733 .76582 L
F
.19873 .76697 m
.19873 .76811 L
.19988 .76811 L
.19988 .76697 L
F
.23075 .76697 m
.23075 .76811 L
.23189 .76811 L
.23189 .76697 L
F
.23189 .76697 m
.23189 .76811 L
.23303 .76811 L
.23303 .76697 L
F
.23303 .76697 m
.23303 .76811 L
.23418 .76811 L
.23418 .76697 L
F
.26505 .76697 m
.26505 .76811 L
.26619 .76811 L
.26619 .76697 L
F
.19759 .76811 m
.19759 .76925 L
.19873 .76925 L
.19873 .76811 L
F
.2296 .76811 m
.2296 .76925 L
.23075 .76925 L
.23075 .76811 L
F
.23075 .76811 m
.23075 .76925 L
.23189 .76925 L
.23189 .76811 L
F
.23189 .76811 m
.23189 .76925 L
.23303 .76925 L
.23303 .76811 L
F
.2639 .76811 m
.2639 .76925 L
.26505 .76925 L
.26505 .76811 L
F
.19645 .76925 m
.19645 .7704 L
.19759 .7704 L
.19759 .76925 L
F
.22846 .76925 m
.22846 .7704 L
.2296 .7704 L
.2296 .76925 L
F
.2296 .76925 m
.2296 .7704 L
.23075 .7704 L
.23075 .76925 L
F
.23075 .76925 m
.23075 .7704 L
.23189 .7704 L
.23189 .76925 L
F
.26276 .76925 m
.26276 .7704 L
.2639 .7704 L
.2639 .76925 L
F
.1953 .7704 m
.1953 .77154 L
.19645 .77154 L
.19645 .7704 L
F
.22732 .7704 m
.22732 .77154 L
.22846 .77154 L
.22846 .7704 L
F
.22846 .7704 m
.22846 .77154 L
.2296 .77154 L
.2296 .7704 L
F
.2296 .7704 m
.2296 .77154 L
.23075 .77154 L
.23075 .7704 L
F
.26162 .7704 m
.26162 .77154 L
.26276 .77154 L
.26276 .7704 L
F
.19416 .77154 m
.19416 .77268 L
.1953 .77268 L
.1953 .77154 L
F
.22617 .77154 m
.22617 .77268 L
.22732 .77268 L
.22732 .77154 L
F
.22732 .77154 m
.22732 .77268 L
.22846 .77268 L
.22846 .77154 L
F
.22846 .77154 m
.22846 .77268 L
.2296 .77268 L
.2296 .77154 L
F
.26047 .77154 m
.26047 .77268 L
.26162 .77268 L
.26162 .77154 L
F
.19302 .77268 m
.19302 .77383 L
.19416 .77383 L
.19416 .77268 L
F
.22503 .77268 m
.22503 .77383 L
.22617 .77383 L
.22617 .77268 L
F
.22617 .77268 m
.22617 .77383 L
.22732 .77383 L
.22732 .77268 L
F
.22732 .77268 m
.22732 .77383 L
.22846 .77383 L
.22846 .77268 L
F
.25933 .77268 m
.25933 .77383 L
.26047 .77383 L
.26047 .77268 L
F
.19187 .77383 m
.19187 .77497 L
.19302 .77497 L
.19302 .77383 L
F
.22389 .77383 m
.22389 .77497 L
.22503 .77497 L
.22503 .77383 L
F
.22503 .77383 m
.22503 .77497 L
.22617 .77497 L
.22617 .77383 L
F
.22617 .77383 m
.22617 .77497 L
.22732 .77497 L
.22732 .77383 L
F
.25819 .77383 m
.25819 .77497 L
.25933 .77497 L
.25933 .77383 L
F
.19073 .77497 m
.19073 .77611 L
.19187 .77611 L
.19187 .77497 L
F
.22274 .77497 m
.22274 .77611 L
.22389 .77611 L
.22389 .77497 L
F
.22389 .77497 m
.22389 .77611 L
.22503 .77611 L
.22503 .77497 L
F
.22503 .77497 m
.22503 .77611 L
.22617 .77611 L
.22617 .77497 L
F
.25704 .77497 m
.25704 .77611 L
.25819 .77611 L
.25819 .77497 L
F
.18959 .77611 m
.18959 .77726 L
.19073 .77726 L
.19073 .77611 L
F
.2216 .77611 m
.2216 .77726 L
.22274 .77726 L
.22274 .77611 L
F
.22274 .77611 m
.22274 .77726 L
.22389 .77726 L
.22389 .77611 L
F
.22389 .77611 m
.22389 .77726 L
.22503 .77726 L
.22503 .77611 L
F
.2559 .77611 m
.2559 .77726 L
.25704 .77726 L
.25704 .77611 L
F
.18844 .77726 m
.18844 .7784 L
.18959 .7784 L
.18959 .77726 L
F
.22046 .77726 m
.22046 .7784 L
.2216 .7784 L
.2216 .77726 L
F
.2216 .77726 m
.2216 .7784 L
.22274 .7784 L
.22274 .77726 L
F
.22274 .77726 m
.22274 .7784 L
.22389 .7784 L
.22389 .77726 L
F
.25476 .77726 m
.25476 .7784 L
.2559 .7784 L
.2559 .77726 L
F
.1873 .7784 m
.1873 .77954 L
.18844 .77954 L
.18844 .7784 L
F
.21931 .7784 m
.21931 .77954 L
.22046 .77954 L
.22046 .7784 L
F
.22046 .7784 m
.22046 .77954 L
.2216 .77954 L
.2216 .7784 L
F
.2216 .7784 m
.2216 .77954 L
.22274 .77954 L
.22274 .7784 L
F
.25361 .7784 m
.25361 .77954 L
.25476 .77954 L
.25476 .7784 L
F
.18616 .77954 m
.18616 .78069 L
.1873 .78069 L
.1873 .77954 L
F
.21817 .77954 m
.21817 .78069 L
.21931 .78069 L
.21931 .77954 L
F
.21931 .77954 m
.21931 .78069 L
.22046 .78069 L
.22046 .77954 L
F
.22046 .77954 m
.22046 .78069 L
.2216 .78069 L
.2216 .77954 L
F
.25247 .77954 m
.25247 .78069 L
.25361 .78069 L
.25361 .77954 L
F
.18501 .78069 m
.18501 .78183 L
.18616 .78183 L
.18616 .78069 L
F
.21817 .78069 m
.21817 .78183 L
.21931 .78183 L
.21931 .78069 L
F
.21931 .78069 m
.21931 .78183 L
.22046 .78183 L
.22046 .78069 L
F
.25133 .78069 m
.25133 .78183 L
.25247 .78183 L
.25247 .78069 L
F
.18387 .78183 m
.18387 .78297 L
.18501 .78297 L
.18501 .78183 L
F
.21588 .78183 m
.21588 .78297 L
.21703 .78297 L
.21703 .78183 L
F
.21703 .78183 m
.21703 .78297 L
.21817 .78297 L
.21817 .78183 L
F
.25018 .78183 m
.25018 .78297 L
.25133 .78297 L
.25133 .78183 L
F
.18273 .78297 m
.18273 .78412 L
.18387 .78412 L
.18387 .78297 L
F
.21474 .78297 m
.21474 .78412 L
.21588 .78412 L
.21588 .78297 L
F
.21588 .78297 m
.21588 .78412 L
.21703 .78412 L
.21703 .78297 L
F
.21703 .78297 m
.21703 .78412 L
.21817 .78412 L
.21817 .78297 L
F
.24904 .78297 m
.24904 .78412 L
.25018 .78412 L
.25018 .78297 L
F
.18158 .78412 m
.18158 .78526 L
.18273 .78526 L
.18273 .78412 L
F
.2136 .78412 m
.2136 .78526 L
.21474 .78526 L
.21474 .78412 L
F
.21474 .78412 m
.21474 .78526 L
.21588 .78526 L
.21588 .78412 L
F
.21588 .78412 m
.21588 .78526 L
.21703 .78526 L
.21703 .78412 L
F
.2479 .78412 m
.2479 .78526 L
.24904 .78526 L
.24904 .78412 L
F
.18044 .78526 m
.18044 .7864 L
.18158 .7864 L
.18158 .78526 L
F
.21245 .78526 m
.21245 .7864 L
.2136 .7864 L
.2136 .78526 L
F
.2136 .78526 m
.2136 .7864 L
.21474 .7864 L
.21474 .78526 L
F
.21474 .78526 m
.21474 .7864 L
.21588 .7864 L
.21588 .78526 L
F
.24675 .78526 m
.24675 .7864 L
.2479 .7864 L
.2479 .78526 L
F
.1793 .7864 m
.1793 .78755 L
.18044 .78755 L
.18044 .7864 L
F
.21131 .7864 m
.21131 .78755 L
.21245 .78755 L
.21245 .7864 L
F
.21245 .7864 m
.21245 .78755 L
.2136 .78755 L
.2136 .7864 L
F
.2136 .7864 m
.2136 .78755 L
.21474 .78755 L
.21474 .7864 L
F
.24561 .7864 m
.24561 .78755 L
.24675 .78755 L
.24675 .7864 L
F
.17815 .78755 m
.17815 .78869 L
.1793 .78869 L
.1793 .78755 L
F
.21017 .78755 m
.21017 .78869 L
.21131 .78869 L
.21131 .78755 L
F
.21131 .78755 m
.21131 .78869 L
.21245 .78869 L
.21245 .78755 L
F
.21245 .78755 m
.21245 .78869 L
.2136 .78869 L
.2136 .78755 L
F
.24447 .78755 m
.24447 .78869 L
.24561 .78869 L
.24561 .78755 L
F
.17701 .78869 m
.17701 .78983 L
.17815 .78983 L
.17815 .78869 L
F
.20902 .78869 m
.20902 .78983 L
.21017 .78983 L
.21017 .78869 L
F
.21017 .78869 m
.21017 .78983 L
.21131 .78983 L
.21131 .78869 L
F
.21131 .78869 m
.21131 .78983 L
.21245 .78983 L
.21245 .78869 L
F
.24332 .78869 m
.24332 .78983 L
.24447 .78983 L
.24447 .78869 L
F
.17587 .78983 m
.17587 .79098 L
.17701 .79098 L
.17701 .78983 L
F
.20788 .78983 m
.20788 .79098 L
.20902 .79098 L
.20902 .78983 L
F
.20902 .78983 m
.20902 .79098 L
.21017 .79098 L
.21017 .78983 L
F
.21017 .78983 m
.21017 .79098 L
.21131 .79098 L
.21131 .78983 L
F
.24218 .78983 m
.24218 .79098 L
.24332 .79098 L
.24332 .78983 L
F
.17472 .79098 m
.17472 .79212 L
.17587 .79212 L
.17587 .79098 L
F
.20674 .79098 m
.20674 .79212 L
.20788 .79212 L
.20788 .79098 L
F
.20788 .79098 m
.20788 .79212 L
.20902 .79212 L
.20902 .79098 L
F
.20902 .79098 m
.20902 .79212 L
.21017 .79212 L
.21017 .79098 L
F
.24104 .79098 m
.24104 .79212 L
.24218 .79212 L
.24218 .79098 L
F
.17358 .79212 m
.17358 .79326 L
.17472 .79326 L
.17472 .79212 L
F
.20559 .79212 m
.20559 .79326 L
.20674 .79326 L
.20674 .79212 L
F
.20674 .79212 m
.20674 .79326 L
.20788 .79326 L
.20788 .79212 L
F
.20788 .79212 m
.20788 .79326 L
.20902 .79326 L
.20902 .79212 L
F
.23989 .79212 m
.23989 .79326 L
.24104 .79326 L
.24104 .79212 L
F
.17244 .79326 m
.17244 .79441 L
.17358 .79441 L
.17358 .79326 L
F
.20445 .79326 m
.20445 .79441 L
.20559 .79441 L
.20559 .79326 L
F
.20559 .79326 m
.20559 .79441 L
.20674 .79441 L
.20674 .79326 L
F
.20674 .79326 m
.20674 .79441 L
.20788 .79441 L
.20788 .79326 L
F
.23875 .79326 m
.23875 .79441 L
.23989 .79441 L
.23989 .79326 L
F
.17129 .79441 m
.17129 .79555 L
.17244 .79555 L
.17244 .79441 L
F
.20331 .79441 m
.20331 .79555 L
.20445 .79555 L
.20445 .79441 L
F
.20445 .79441 m
.20445 .79555 L
.20559 .79555 L
.20559 .79441 L
F
.20559 .79441 m
.20559 .79555 L
.20674 .79555 L
.20674 .79441 L
F
.23761 .79441 m
.23761 .79555 L
.23875 .79555 L
.23875 .79441 L
F
.17015 .79555 m
.17015 .79669 L
.17129 .79669 L
.17129 .79555 L
F
.20216 .79555 m
.20216 .79669 L
.20331 .79669 L
.20331 .79555 L
F
.20331 .79555 m
.20331 .79669 L
.20445 .79669 L
.20445 .79555 L
F
.20445 .79555 m
.20445 .79669 L
.20559 .79669 L
.20559 .79555 L
F
.23646 .79555 m
.23646 .79669 L
.23761 .79669 L
.23761 .79555 L
F
.16901 .79669 m
.16901 .79784 L
.17015 .79784 L
.17015 .79669 L
F
.20102 .79669 m
.20102 .79784 L
.20216 .79784 L
.20216 .79669 L
F
.20216 .79669 m
.20216 .79784 L
.20331 .79784 L
.20331 .79669 L
F
.20331 .79669 m
.20331 .79784 L
.20445 .79784 L
.20445 .79669 L
F
.23532 .79669 m
.23532 .79784 L
.23646 .79784 L
.23646 .79669 L
F
.16786 .79784 m
.16786 .79898 L
.16901 .79898 L
.16901 .79784 L
F
.19988 .79784 m
.19988 .79898 L
.20102 .79898 L
.20102 .79784 L
F
.20102 .79784 m
.20102 .79898 L
.20216 .79898 L
.20216 .79784 L
F
.20216 .79784 m
.20216 .79898 L
.20331 .79898 L
.20331 .79784 L
F
.23418 .79784 m
.23418 .79898 L
.23532 .79898 L
.23532 .79784 L
F
.16672 .79898 m
.16672 .80012 L
.16786 .80012 L
.16786 .79898 L
F
.19873 .79898 m
.19873 .80012 L
.19988 .80012 L
.19988 .79898 L
F
.19988 .79898 m
.19988 .80012 L
.20102 .80012 L
.20102 .79898 L
F
.20102 .79898 m
.20102 .80012 L
.20216 .80012 L
.20216 .79898 L
F
.23303 .79898 m
.23303 .80012 L
.23418 .80012 L
.23418 .79898 L
F
.16558 .80012 m
.16558 .80127 L
.16672 .80127 L
.16672 .80012 L
F
.19759 .80012 m
.19759 .80127 L
.19873 .80127 L
.19873 .80012 L
F
.19873 .80012 m
.19873 .80127 L
.19988 .80127 L
.19988 .80012 L
F
.19988 .80012 m
.19988 .80127 L
.20102 .80127 L
.20102 .80012 L
F
.23189 .80012 m
.23189 .80127 L
.23303 .80127 L
.23303 .80012 L
F
.16443 .80127 m
.16443 .80241 L
.16558 .80241 L
.16558 .80127 L
F
.19645 .80127 m
.19645 .80241 L
.19759 .80241 L
.19759 .80127 L
F
.19759 .80127 m
.19759 .80241 L
.19873 .80241 L
.19873 .80127 L
F
.19873 .80127 m
.19873 .80241 L
.19988 .80241 L
.19988 .80127 L
F
.23075 .80127 m
.23075 .80241 L
.23189 .80241 L
.23189 .80127 L
F
.16329 .80241 m
.16329 .80355 L
.16443 .80355 L
.16443 .80241 L
F
.1953 .80241 m
.1953 .80355 L
.19645 .80355 L
.19645 .80241 L
F
.19645 .80241 m
.19645 .80355 L
.19759 .80355 L
.19759 .80241 L
F
.19759 .80241 m
.19759 .80355 L
.19873 .80355 L
.19873 .80241 L
F
.2296 .80241 m
.2296 .80355 L
.23075 .80355 L
.23075 .80241 L
F
.16215 .80355 m
.16215 .8047 L
.16329 .8047 L
.16329 .80355 L
F
.19416 .80355 m
.19416 .8047 L
.1953 .8047 L
.1953 .80355 L
F
.1953 .80355 m
.1953 .8047 L
.19645 .8047 L
.19645 .80355 L
F
.19645 .80355 m
.19645 .8047 L
.19759 .8047 L
.19759 .80355 L
F
.22846 .80355 m
.22846 .8047 L
.2296 .8047 L
.2296 .80355 L
F
.161 .8047 m
.161 .80584 L
.16215 .80584 L
.16215 .8047 L
F
.19302 .8047 m
.19302 .80584 L
.19416 .80584 L
.19416 .8047 L
F
.19416 .8047 m
.19416 .80584 L
.1953 .80584 L
.1953 .8047 L
F
.1953 .8047 m
.1953 .80584 L
.19645 .80584 L
.19645 .8047 L
F
.22732 .8047 m
.22732 .80584 L
.22846 .80584 L
.22846 .8047 L
F
.15986 .80584 m
.15986 .80698 L
.161 .80698 L
.161 .80584 L
F
.19187 .80584 m
.19187 .80698 L
.19302 .80698 L
.19302 .80584 L
F
.19302 .80584 m
.19302 .80698 L
.19416 .80698 L
.19416 .80584 L
F
.19416 .80584 m
.19416 .80698 L
.1953 .80698 L
.1953 .80584 L
F
.22617 .80584 m
.22617 .80698 L
.22732 .80698 L
.22732 .80584 L
F
.15872 .80698 m
.15872 .80813 L
.15986 .80813 L
.15986 .80698 L
F
.19073 .80698 m
.19073 .80813 L
.19187 .80813 L
.19187 .80698 L
F
.19187 .80698 m
.19187 .80813 L
.19302 .80813 L
.19302 .80698 L
F
.19302 .80698 m
.19302 .80813 L
.19416 .80813 L
.19416 .80698 L
F
.22503 .80698 m
.22503 .80813 L
.22617 .80813 L
.22617 .80698 L
F
.15757 .80813 m
.15757 .80927 L
.15872 .80927 L
.15872 .80813 L
F
.18959 .80813 m
.18959 .80927 L
.19073 .80927 L
.19073 .80813 L
F
.19073 .80813 m
.19073 .80927 L
.19187 .80927 L
.19187 .80813 L
F
.19187 .80813 m
.19187 .80927 L
.19302 .80927 L
.19302 .80813 L
F
.22389 .80813 m
.22389 .80927 L
.22503 .80927 L
.22503 .80813 L
F
.15643 .80927 m
.15643 .81041 L
.15757 .81041 L
.15757 .80927 L
F
.18844 .80927 m
.18844 .81041 L
.18959 .81041 L
.18959 .80927 L
F
.18959 .80927 m
.18959 .81041 L
.19073 .81041 L
.19073 .80927 L
F
.19073 .80927 m
.19073 .81041 L
.19187 .81041 L
.19187 .80927 L
F
.22274 .80927 m
.22274 .81041 L
.22389 .81041 L
.22389 .80927 L
F
.15529 .81041 m
.15529 .81156 L
.15643 .81156 L
.15643 .81041 L
F
.1873 .81041 m
.1873 .81156 L
.18844 .81156 L
.18844 .81041 L
F
.18844 .81041 m
.18844 .81156 L
.18959 .81156 L
.18959 .81041 L
F
.18959 .81041 m
.18959 .81156 L
.19073 .81156 L
.19073 .81041 L
F
.2216 .81041 m
.2216 .81156 L
.22274 .81156 L
.22274 .81041 L
F
.15414 .81156 m
.15414 .8127 L
.15529 .8127 L
.15529 .81156 L
F
.18616 .81156 m
.18616 .8127 L
.1873 .8127 L
.1873 .81156 L
F
.1873 .81156 m
.1873 .8127 L
.18844 .8127 L
.18844 .81156 L
F
.18844 .81156 m
.18844 .8127 L
.18959 .8127 L
.18959 .81156 L
F
.22046 .81156 m
.22046 .8127 L
.2216 .8127 L
.2216 .81156 L
F
.153 .8127 m
.153 .81384 L
.15414 .81384 L
.15414 .8127 L
F
.18501 .8127 m
.18501 .81384 L
.18616 .81384 L
.18616 .8127 L
F
.18616 .8127 m
.18616 .81384 L
.1873 .81384 L
.1873 .8127 L
F
.1873 .8127 m
.1873 .81384 L
.18844 .81384 L
.18844 .8127 L
F
.21931 .8127 m
.21931 .81384 L
.22046 .81384 L
.22046 .8127 L
F
.15186 .81384 m
.15186 .81499 L
.153 .81499 L
.153 .81384 L
F
.18501 .81384 m
.18501 .81499 L
.18616 .81499 L
.18616 .81384 L
F
.18616 .81384 m
.18616 .81499 L
.1873 .81499 L
.1873 .81384 L
F
.21817 .81384 m
.21817 .81499 L
.21931 .81499 L
.21931 .81384 L
F
.15071 .81499 m
.15071 .81613 L
.15186 .81613 L
.15186 .81499 L
F
.18273 .81499 m
.18273 .81613 L
.18387 .81613 L
.18387 .81499 L
F
.18387 .81499 m
.18387 .81613 L
.18501 .81613 L
.18501 .81499 L
F
.21703 .81499 m
.21703 .81613 L
.21817 .81613 L
.21817 .81499 L
F
.14957 .81613 m
.14957 .81727 L
.15071 .81727 L
.15071 .81613 L
F
.18158 .81613 m
.18158 .81727 L
.18273 .81727 L
.18273 .81613 L
F
.18273 .81613 m
.18273 .81727 L
.18387 .81727 L
.18387 .81613 L
F
.18387 .81613 m
.18387 .81727 L
.18501 .81727 L
.18501 .81613 L
F
.21588 .81613 m
.21588 .81727 L
.21703 .81727 L
.21703 .81613 L
F
.14843 .81727 m
.14843 .81842 L
.14957 .81842 L
.14957 .81727 L
F
.18044 .81727 m
.18044 .81842 L
.18158 .81842 L
.18158 .81727 L
F
.18158 .81727 m
.18158 .81842 L
.18273 .81842 L
.18273 .81727 L
F
.18273 .81727 m
.18273 .81842 L
.18387 .81842 L
.18387 .81727 L
F
.21474 .81727 m
.21474 .81842 L
.21588 .81842 L
.21588 .81727 L
F
.14728 .81842 m
.14728 .81956 L
.14843 .81956 L
.14843 .81842 L
F
.1793 .81842 m
.1793 .81956 L
.18044 .81956 L
.18044 .81842 L
F
.18044 .81842 m
.18044 .81956 L
.18158 .81956 L
.18158 .81842 L
F
.18158 .81842 m
.18158 .81956 L
.18273 .81956 L
.18273 .81842 L
F
.2136 .81842 m
.2136 .81956 L
.21474 .81956 L
.21474 .81842 L
F
.14614 .81956 m
.14614 .8207 L
.14728 .8207 L
.14728 .81956 L
F
.17815 .81956 m
.17815 .8207 L
.1793 .8207 L
.1793 .81956 L
F
.1793 .81956 m
.1793 .8207 L
.18044 .8207 L
.18044 .81956 L
F
.18044 .81956 m
.18044 .8207 L
.18158 .8207 L
.18158 .81956 L
F
.21245 .81956 m
.21245 .8207 L
.2136 .8207 L
.2136 .81956 L
F
.145 .8207 m
.145 .82185 L
.14614 .82185 L
.14614 .8207 L
F
.17701 .8207 m
.17701 .82185 L
.17815 .82185 L
.17815 .8207 L
F
.17815 .8207 m
.17815 .82185 L
.1793 .82185 L
.1793 .8207 L
F
.1793 .8207 m
.1793 .82185 L
.18044 .82185 L
.18044 .8207 L
F
.21131 .8207 m
.21131 .82185 L
.21245 .82185 L
.21245 .8207 L
F
.14385 .82185 m
.14385 .82299 L
.145 .82299 L
.145 .82185 L
F
.17587 .82185 m
.17587 .82299 L
.17701 .82299 L
.17701 .82185 L
F
.17701 .82185 m
.17701 .82299 L
.17815 .82299 L
.17815 .82185 L
F
.17815 .82185 m
.17815 .82299 L
.1793 .82299 L
.1793 .82185 L
F
.21017 .82185 m
.21017 .82299 L
.21131 .82299 L
.21131 .82185 L
F
.14271 .82299 m
.14271 .82413 L
.14385 .82413 L
.14385 .82299 L
F
.17472 .82299 m
.17472 .82413 L
.17587 .82413 L
.17587 .82299 L
F
.17587 .82299 m
.17587 .82413 L
.17701 .82413 L
.17701 .82299 L
F
.17701 .82299 m
.17701 .82413 L
.17815 .82413 L
.17815 .82299 L
F
.20902 .82299 m
.20902 .82413 L
.21017 .82413 L
.21017 .82299 L
F
.14157 .82413 m
.14157 .82528 L
.14271 .82528 L
.14271 .82413 L
F
.17358 .82413 m
.17358 .82528 L
.17472 .82528 L
.17472 .82413 L
F
.17472 .82413 m
.17472 .82528 L
.17587 .82528 L
.17587 .82413 L
F
.17587 .82413 m
.17587 .82528 L
.17701 .82528 L
.17701 .82413 L
F
.20788 .82413 m
.20788 .82528 L
.20902 .82528 L
.20902 .82413 L
F
.14042 .82528 m
.14042 .82642 L
.14157 .82642 L
.14157 .82528 L
F
.17244 .82528 m
.17244 .82642 L
.17358 .82642 L
.17358 .82528 L
F
.17358 .82528 m
.17358 .82642 L
.17472 .82642 L
.17472 .82528 L
F
.17472 .82528 m
.17472 .82642 L
.17587 .82642 L
.17587 .82528 L
F
.20674 .82528 m
.20674 .82642 L
.20788 .82642 L
.20788 .82528 L
F
.13928 .82642 m
.13928 .82756 L
.14042 .82756 L
.14042 .82642 L
F
.17129 .82642 m
.17129 .82756 L
.17244 .82756 L
.17244 .82642 L
F
.17244 .82642 m
.17244 .82756 L
.17358 .82756 L
.17358 .82642 L
F
.17358 .82642 m
.17358 .82756 L
.17472 .82756 L
.17472 .82642 L
F
.20559 .82642 m
.20559 .82756 L
.20674 .82756 L
.20674 .82642 L
F
.13814 .82756 m
.13814 .82871 L
.13928 .82871 L
.13928 .82756 L
F
.17015 .82756 m
.17015 .82871 L
.17129 .82871 L
.17129 .82756 L
F
.17129 .82756 m
.17129 .82871 L
.17244 .82871 L
.17244 .82756 L
F
.17244 .82756 m
.17244 .82871 L
.17358 .82871 L
.17358 .82756 L
F
.20445 .82756 m
.20445 .82871 L
.20559 .82871 L
.20559 .82756 L
F
.13699 .82871 m
.13699 .82985 L
.13814 .82985 L
.13814 .82871 L
F
.16901 .82871 m
.16901 .82985 L
.17015 .82985 L
.17015 .82871 L
F
.17015 .82871 m
.17015 .82985 L
.17129 .82985 L
.17129 .82871 L
F
.17129 .82871 m
.17129 .82985 L
.17244 .82985 L
.17244 .82871 L
F
.20331 .82871 m
.20331 .82985 L
.20445 .82985 L
.20445 .82871 L
F
.13585 .82985 m
.13585 .83099 L
.13699 .83099 L
.13699 .82985 L
F
.16786 .82985 m
.16786 .83099 L
.16901 .83099 L
.16901 .82985 L
F
.16901 .82985 m
.16901 .83099 L
.17015 .83099 L
.17015 .82985 L
F
.17015 .82985 m
.17015 .83099 L
.17129 .83099 L
.17129 .82985 L
F
.20216 .82985 m
.20216 .83099 L
.20331 .83099 L
.20331 .82985 L
F
.13471 .83099 m
.13471 .83214 L
.13585 .83214 L
.13585 .83099 L
F
.16672 .83099 m
.16672 .83214 L
.16786 .83214 L
.16786 .83099 L
F
.16786 .83099 m
.16786 .83214 L
.16901 .83214 L
.16901 .83099 L
F
.16901 .83099 m
.16901 .83214 L
.17015 .83214 L
.17015 .83099 L
F
.20102 .83099 m
.20102 .83214 L
.20216 .83214 L
.20216 .83099 L
F
.13356 .83214 m
.13356 .83328 L
.13471 .83328 L
.13471 .83214 L
F
.16558 .83214 m
.16558 .83328 L
.16672 .83328 L
.16672 .83214 L
F
.16672 .83214 m
.16672 .83328 L
.16786 .83328 L
.16786 .83214 L
F
.16786 .83214 m
.16786 .83328 L
.16901 .83328 L
.16901 .83214 L
F
.19988 .83214 m
.19988 .83328 L
.20102 .83328 L
.20102 .83214 L
F
.13242 .83328 m
.13242 .83442 L
.13356 .83442 L
.13356 .83328 L
F
.16443 .83328 m
.16443 .83442 L
.16558 .83442 L
.16558 .83328 L
F
.16558 .83328 m
.16558 .83442 L
.16672 .83442 L
.16672 .83328 L
F
.16672 .83328 m
.16672 .83442 L
.16786 .83442 L
.16786 .83328 L
F
.19873 .83328 m
.19873 .83442 L
.19988 .83442 L
.19988 .83328 L
F
.13128 .83442 m
.13128 .83557 L
.13242 .83557 L
.13242 .83442 L
F
.16329 .83442 m
.16329 .83557 L
.16443 .83557 L
.16443 .83442 L
F
.16443 .83442 m
.16443 .83557 L
.16558 .83557 L
.16558 .83442 L
F
.16558 .83442 m
.16558 .83557 L
.16672 .83557 L
.16672 .83442 L
F
.19759 .83442 m
.19759 .83557 L
.19873 .83557 L
.19873 .83442 L
F
.13013 .83557 m
.13013 .83671 L
.13128 .83671 L
.13128 .83557 L
F
.16215 .83557 m
.16215 .83671 L
.16329 .83671 L
.16329 .83557 L
F
.16329 .83557 m
.16329 .83671 L
.16443 .83671 L
.16443 .83557 L
F
.16443 .83557 m
.16443 .83671 L
.16558 .83671 L
.16558 .83557 L
F
.19645 .83557 m
.19645 .83671 L
.19759 .83671 L
.19759 .83557 L
F
.12899 .83671 m
.12899 .83785 L
.13013 .83785 L
.13013 .83671 L
F
.161 .83671 m
.161 .83785 L
.16215 .83785 L
.16215 .83671 L
F
.16215 .83671 m
.16215 .83785 L
.16329 .83785 L
.16329 .83671 L
F
.16329 .83671 m
.16329 .83785 L
.16443 .83785 L
.16443 .83671 L
F
.1953 .83671 m
.1953 .83785 L
.19645 .83785 L
.19645 .83671 L
F
.12785 .83785 m
.12785 .839 L
.12899 .839 L
.12899 .83785 L
F
.15986 .83785 m
.15986 .839 L
.161 .839 L
.161 .83785 L
F
.161 .83785 m
.161 .839 L
.16215 .839 L
.16215 .83785 L
F
.16215 .83785 m
.16215 .839 L
.16329 .839 L
.16329 .83785 L
F
.19416 .83785 m
.19416 .839 L
.1953 .839 L
.1953 .83785 L
F
.1267 .839 m
.1267 .84014 L
.12785 .84014 L
.12785 .839 L
F
.15872 .839 m
.15872 .84014 L
.15986 .84014 L
.15986 .839 L
F
.15986 .839 m
.15986 .84014 L
.161 .84014 L
.161 .839 L
F
.161 .839 m
.161 .84014 L
.16215 .84014 L
.16215 .839 L
F
.19302 .839 m
.19302 .84014 L
.19416 .84014 L
.19416 .839 L
F
.12556 .84014 m
.12556 .84128 L
.1267 .84128 L
.1267 .84014 L
F
.15757 .84014 m
.15757 .84128 L
.15872 .84128 L
.15872 .84014 L
F
.15872 .84014 m
.15872 .84128 L
.15986 .84128 L
.15986 .84014 L
F
.15986 .84014 m
.15986 .84128 L
.161 .84128 L
.161 .84014 L
F
.19187 .84014 m
.19187 .84128 L
.19302 .84128 L
.19302 .84014 L
F
.12442 .84128 m
.12442 .84243 L
.12556 .84243 L
.12556 .84128 L
F
.15643 .84128 m
.15643 .84243 L
.15757 .84243 L
.15757 .84128 L
F
.15757 .84128 m
.15757 .84243 L
.15872 .84243 L
.15872 .84128 L
F
.15872 .84128 m
.15872 .84243 L
.15986 .84243 L
.15986 .84128 L
F
.19073 .84128 m
.19073 .84243 L
.19187 .84243 L
.19187 .84128 L
F
.12327 .84243 m
.12327 .84357 L
.12442 .84357 L
.12442 .84243 L
F
.15529 .84243 m
.15529 .84357 L
.15643 .84357 L
.15643 .84243 L
F
.15643 .84243 m
.15643 .84357 L
.15757 .84357 L
.15757 .84243 L
F
.15757 .84243 m
.15757 .84357 L
.15872 .84357 L
.15872 .84243 L
F
.18959 .84243 m
.18959 .84357 L
.19073 .84357 L
.19073 .84243 L
F
.12213 .84357 m
.12213 .84471 L
.12327 .84471 L
.12327 .84357 L
F
.15414 .84357 m
.15414 .84471 L
.15529 .84471 L
.15529 .84357 L
F
.15529 .84357 m
.15529 .84471 L
.15643 .84471 L
.15643 .84357 L
F
.15643 .84357 m
.15643 .84471 L
.15757 .84471 L
.15757 .84357 L
F
.18844 .84357 m
.18844 .84471 L
.18959 .84471 L
.18959 .84357 L
F
.12099 .84471 m
.12099 .84586 L
.12213 .84586 L
.12213 .84471 L
F
.153 .84471 m
.153 .84586 L
.15414 .84586 L
.15414 .84471 L
F
.15414 .84471 m
.15414 .84586 L
.15529 .84586 L
.15529 .84471 L
F
.15529 .84471 m
.15529 .84586 L
.15643 .84586 L
.15643 .84471 L
F
.1873 .84471 m
.1873 .84586 L
.18844 .84586 L
.18844 .84471 L
F
.11984 .84586 m
.11984 .847 L
.12099 .847 L
.12099 .84586 L
F
.15186 .84586 m
.15186 .847 L
.153 .847 L
.153 .84586 L
F
.153 .84586 m
.153 .847 L
.15414 .847 L
.15414 .84586 L
F
.15414 .84586 m
.15414 .847 L
.15529 .847 L
.15529 .84586 L
F
.18616 .84586 m
.18616 .847 L
.1873 .847 L
.1873 .84586 L
F
.1187 .847 m
.1187 .84814 L
.11984 .84814 L
.11984 .847 L
F
.15186 .847 m
.15186 .84814 L
.153 .84814 L
.153 .847 L
F
.153 .847 m
.153 .84814 L
.15414 .84814 L
.15414 .847 L
F
.18501 .847 m
.18501 .84814 L
.18616 .84814 L
.18616 .847 L
F
.11756 .84814 m
.11756 .84929 L
.1187 .84929 L
.1187 .84814 L
F
.14957 .84814 m
.14957 .84929 L
.15071 .84929 L
.15071 .84814 L
F
.15071 .84814 m
.15071 .84929 L
.15186 .84929 L
.15186 .84814 L
F
.18387 .84814 m
.18387 .84929 L
.18501 .84929 L
.18501 .84814 L
F
.11641 .84929 m
.11641 .85043 L
.11756 .85043 L
.11756 .84929 L
F
.14843 .84929 m
.14843 .85043 L
.14957 .85043 L
.14957 .84929 L
F
.14957 .84929 m
.14957 .85043 L
.15071 .85043 L
.15071 .84929 L
F
.15071 .84929 m
.15071 .85043 L
.15186 .85043 L
.15186 .84929 L
F
.18273 .84929 m
.18273 .85043 L
.18387 .85043 L
.18387 .84929 L
F
.11527 .85043 m
.11527 .85157 L
.11641 .85157 L
.11641 .85043 L
F
.14728 .85043 m
.14728 .85157 L
.14843 .85157 L
.14843 .85043 L
F
.14843 .85043 m
.14843 .85157 L
.14957 .85157 L
.14957 .85043 L
F
.14957 .85043 m
.14957 .85157 L
.15071 .85157 L
.15071 .85043 L
F
.18158 .85043 m
.18158 .85157 L
.18273 .85157 L
.18273 .85043 L
F
.11413 .85157 m
.11413 .85272 L
.11527 .85272 L
.11527 .85157 L
F
.14614 .85157 m
.14614 .85272 L
.14728 .85272 L
.14728 .85157 L
F
.14728 .85157 m
.14728 .85272 L
.14843 .85272 L
.14843 .85157 L
F
.14843 .85157 m
.14843 .85272 L
.14957 .85272 L
.14957 .85157 L
F
.18044 .85157 m
.18044 .85272 L
.18158 .85272 L
.18158 .85157 L
F
.11298 .85272 m
.11298 .85386 L
.11413 .85386 L
.11413 .85272 L
F
.145 .85272 m
.145 .85386 L
.14614 .85386 L
.14614 .85272 L
F
.14614 .85272 m
.14614 .85386 L
.14728 .85386 L
.14728 .85272 L
F
.14728 .85272 m
.14728 .85386 L
.14843 .85386 L
.14843 .85272 L
F
.1793 .85272 m
.1793 .85386 L
.18044 .85386 L
.18044 .85272 L
F
.11184 .85386 m
.11184 .855 L
.11298 .855 L
.11298 .85386 L
F
.14385 .85386 m
.14385 .855 L
.145 .855 L
.145 .85386 L
F
.145 .85386 m
.145 .855 L
.14614 .855 L
.14614 .85386 L
F
.14614 .85386 m
.14614 .855 L
.14728 .855 L
.14728 .85386 L
F
.17815 .85386 m
.17815 .855 L
.1793 .855 L
.1793 .85386 L
F
.1107 .855 m
.1107 .85615 L
.11184 .85615 L
.11184 .855 L
F
.14271 .855 m
.14271 .85615 L
.14385 .85615 L
.14385 .855 L
F
.14385 .855 m
.14385 .85615 L
.145 .85615 L
.145 .855 L
F
.145 .855 m
.145 .85615 L
.14614 .85615 L
.14614 .855 L
F
.17701 .855 m
.17701 .85615 L
.17815 .85615 L
.17815 .855 L
F
.10955 .85615 m
.10955 .85729 L
.1107 .85729 L
.1107 .85615 L
F
.14157 .85615 m
.14157 .85729 L
.14271 .85729 L
.14271 .85615 L
F
.14271 .85615 m
.14271 .85729 L
.14385 .85729 L
.14385 .85615 L
F
.14385 .85615 m
.14385 .85729 L
.145 .85729 L
.145 .85615 L
F
.17587 .85615 m
.17587 .85729 L
.17701 .85729 L
.17701 .85615 L
F
.10841 .85729 m
.10841 .85843 L
.10955 .85843 L
.10955 .85729 L
F
.14042 .85729 m
.14042 .85843 L
.14157 .85843 L
.14157 .85729 L
F
.14157 .85729 m
.14157 .85843 L
.14271 .85843 L
.14271 .85729 L
F
.14271 .85729 m
.14271 .85843 L
.14385 .85843 L
.14385 .85729 L
F
.17472 .85729 m
.17472 .85843 L
.17587 .85843 L
.17587 .85729 L
F
.10727 .85843 m
.10727 .85958 L
.10841 .85958 L
.10841 .85843 L
F
.13928 .85843 m
.13928 .85958 L
.14042 .85958 L
.14042 .85843 L
F
.14042 .85843 m
.14042 .85958 L
.14157 .85958 L
.14157 .85843 L
F
.14157 .85843 m
.14157 .85958 L
.14271 .85958 L
.14271 .85843 L
F
.17358 .85843 m
.17358 .85958 L
.17472 .85958 L
.17472 .85843 L
F
.10612 .85958 m
.10612 .86072 L
.10727 .86072 L
.10727 .85958 L
F
.13814 .85958 m
.13814 .86072 L
.13928 .86072 L
.13928 .85958 L
F
.13928 .85958 m
.13928 .86072 L
.14042 .86072 L
.14042 .85958 L
F
.14042 .85958 m
.14042 .86072 L
.14157 .86072 L
.14157 .85958 L
F
.17244 .85958 m
.17244 .86072 L
.17358 .86072 L
.17358 .85958 L
F
.10498 .86072 m
.10498 .86186 L
.10612 .86186 L
.10612 .86072 L
F
.13699 .86072 m
.13699 .86186 L
.13814 .86186 L
.13814 .86072 L
F
.13814 .86072 m
.13814 .86186 L
.13928 .86186 L
.13928 .86072 L
F
.13928 .86072 m
.13928 .86186 L
.14042 .86186 L
.14042 .86072 L
F
.17129 .86072 m
.17129 .86186 L
.17244 .86186 L
.17244 .86072 L
F
.10384 .86186 m
.10384 .86301 L
.10498 .86301 L
.10498 .86186 L
F
.13585 .86186 m
.13585 .86301 L
.13699 .86301 L
.13699 .86186 L
F
.13699 .86186 m
.13699 .86301 L
.13814 .86301 L
.13814 .86186 L
F
.13814 .86186 m
.13814 .86301 L
.13928 .86301 L
.13928 .86186 L
F
.17015 .86186 m
.17015 .86301 L
.17129 .86301 L
.17129 .86186 L
F
.10269 .86301 m
.10269 .86415 L
.10384 .86415 L
.10384 .86301 L
F
.13471 .86301 m
.13471 .86415 L
.13585 .86415 L
.13585 .86301 L
F
.13585 .86301 m
.13585 .86415 L
.13699 .86415 L
.13699 .86301 L
F
.13699 .86301 m
.13699 .86415 L
.13814 .86415 L
.13814 .86301 L
F
.16901 .86301 m
.16901 .86415 L
.17015 .86415 L
.17015 .86301 L
F
.10155 .86415 m
.10155 .86529 L
.10269 .86529 L
.10269 .86415 L
F
.13356 .86415 m
.13356 .86529 L
.13471 .86529 L
.13471 .86415 L
F
.13471 .86415 m
.13471 .86529 L
.13585 .86529 L
.13585 .86415 L
F
.13585 .86415 m
.13585 .86529 L
.13699 .86529 L
.13699 .86415 L
F
.16786 .86415 m
.16786 .86529 L
.16901 .86529 L
.16901 .86415 L
F
.10041 .86529 m
.10041 .86644 L
.10155 .86644 L
.10155 .86529 L
F
.13242 .86529 m
.13242 .86644 L
.13356 .86644 L
.13356 .86529 L
F
.13356 .86529 m
.13356 .86644 L
.13471 .86644 L
.13471 .86529 L
F
.13471 .86529 m
.13471 .86644 L
.13585 .86644 L
.13585 .86529 L
F
.16672 .86529 m
.16672 .86644 L
.16786 .86644 L
.16786 .86529 L
F
.09926 .86644 m
.09926 .86758 L
.10041 .86758 L
.10041 .86644 L
F
.13128 .86644 m
.13128 .86758 L
.13242 .86758 L
.13242 .86644 L
F
.13242 .86644 m
.13242 .86758 L
.13356 .86758 L
.13356 .86644 L
F
.13356 .86644 m
.13356 .86758 L
.13471 .86758 L
.13471 .86644 L
F
.16558 .86644 m
.16558 .86758 L
.16672 .86758 L
.16672 .86644 L
F
.09812 .86758 m
.09812 .86872 L
.09926 .86872 L
.09926 .86758 L
F
.13013 .86758 m
.13013 .86872 L
.13128 .86872 L
.13128 .86758 L
F
.13128 .86758 m
.13128 .86872 L
.13242 .86872 L
.13242 .86758 L
F
.13242 .86758 m
.13242 .86872 L
.13356 .86872 L
.13356 .86758 L
F
.16443 .86758 m
.16443 .86872 L
.16558 .86872 L
.16558 .86758 L
F
.09698 .86872 m
.09698 .86987 L
.09812 .86987 L
.09812 .86872 L
F
.12899 .86872 m
.12899 .86987 L
.13013 .86987 L
.13013 .86872 L
F
.13013 .86872 m
.13013 .86987 L
.13128 .86987 L
.13128 .86872 L
F
.13128 .86872 m
.13128 .86987 L
.13242 .86987 L
.13242 .86872 L
F
.16329 .86872 m
.16329 .86987 L
.16443 .86987 L
.16443 .86872 L
F
.09583 .86987 m
.09583 .87101 L
.09698 .87101 L
.09698 .86987 L
F
.12785 .86987 m
.12785 .87101 L
.12899 .87101 L
.12899 .86987 L
F
.12899 .86987 m
.12899 .87101 L
.13013 .87101 L
.13013 .86987 L
F
.13013 .86987 m
.13013 .87101 L
.13128 .87101 L
.13128 .86987 L
F
.16215 .86987 m
.16215 .87101 L
.16329 .87101 L
.16329 .86987 L
F
.09469 .87101 m
.09469 .87215 L
.09583 .87215 L
.09583 .87101 L
F
.1267 .87101 m
.1267 .87215 L
.12785 .87215 L
.12785 .87101 L
F
.12785 .87101 m
.12785 .87215 L
.12899 .87215 L
.12899 .87101 L
F
.12899 .87101 m
.12899 .87215 L
.13013 .87215 L
.13013 .87101 L
F
.161 .87101 m
.161 .87215 L
.16215 .87215 L
.16215 .87101 L
F
.09355 .87215 m
.09355 .8733 L
.09469 .8733 L
.09469 .87215 L
F
.12556 .87215 m
.12556 .8733 L
.1267 .8733 L
.1267 .87215 L
F
.1267 .87215 m
.1267 .8733 L
.12785 .8733 L
.12785 .87215 L
F
.12785 .87215 m
.12785 .8733 L
.12899 .8733 L
.12899 .87215 L
F
.15986 .87215 m
.15986 .8733 L
.161 .8733 L
.161 .87215 L
F
.0924 .8733 m
.0924 .87444 L
.09355 .87444 L
.09355 .8733 L
F
.12442 .8733 m
.12442 .87444 L
.12556 .87444 L
.12556 .8733 L
F
.12556 .8733 m
.12556 .87444 L
.1267 .87444 L
.1267 .8733 L
F
.1267 .8733 m
.1267 .87444 L
.12785 .87444 L
.12785 .8733 L
F
.15872 .8733 m
.15872 .87444 L
.15986 .87444 L
.15986 .8733 L
F
.09126 .87444 m
.09126 .87558 L
.0924 .87558 L
.0924 .87444 L
F
.12327 .87444 m
.12327 .87558 L
.12442 .87558 L
.12442 .87444 L
F
.12442 .87444 m
.12442 .87558 L
.12556 .87558 L
.12556 .87444 L
F
.12556 .87444 m
.12556 .87558 L
.1267 .87558 L
.1267 .87444 L
F
.15757 .87444 m
.15757 .87558 L
.15872 .87558 L
.15872 .87444 L
F
.09012 .87558 m
.09012 .87673 L
.09126 .87673 L
.09126 .87558 L
F
.12213 .87558 m
.12213 .87673 L
.12327 .87673 L
.12327 .87558 L
F
.12327 .87558 m
.12327 .87673 L
.12442 .87673 L
.12442 .87558 L
F
.12442 .87558 m
.12442 .87673 L
.12556 .87673 L
.12556 .87558 L
F
.15643 .87558 m
.15643 .87673 L
.15757 .87673 L
.15757 .87558 L
F
.08897 .87673 m
.08897 .87787 L
.09012 .87787 L
.09012 .87673 L
F
.12099 .87673 m
.12099 .87787 L
.12213 .87787 L
.12213 .87673 L
F
.12213 .87673 m
.12213 .87787 L
.12327 .87787 L
.12327 .87673 L
F
.12327 .87673 m
.12327 .87787 L
.12442 .87787 L
.12442 .87673 L
F
.15529 .87673 m
.15529 .87787 L
.15643 .87787 L
.15643 .87673 L
F
.08783 .87787 m
.08783 .87901 L
.08897 .87901 L
.08897 .87787 L
F
.11984 .87787 m
.11984 .87901 L
.12099 .87901 L
.12099 .87787 L
F
.12099 .87787 m
.12099 .87901 L
.12213 .87901 L
.12213 .87787 L
F
.12213 .87787 m
.12213 .87901 L
.12327 .87901 L
.12327 .87787 L
F
.15414 .87787 m
.15414 .87901 L
.15529 .87901 L
.15529 .87787 L
F
.08669 .87901 m
.08669 .88016 L
.08783 .88016 L
.08783 .87901 L
F
.1187 .87901 m
.1187 .88016 L
.11984 .88016 L
.11984 .87901 L
F
.11984 .87901 m
.11984 .88016 L
.12099 .88016 L
.12099 .87901 L
F
.12099 .87901 m
.12099 .88016 L
.12213 .88016 L
.12213 .87901 L
F
.153 .87901 m
.153 .88016 L
.15414 .88016 L
.15414 .87901 L
F
.08554 .88016 m
.08554 .8813 L
.08669 .8813 L
.08669 .88016 L
F
.1187 .88016 m
.1187 .8813 L
.11984 .8813 L
.11984 .88016 L
F
.11984 .88016 m
.11984 .8813 L
.12099 .8813 L
.12099 .88016 L
F
.15186 .88016 m
.15186 .8813 L
.153 .8813 L
.153 .88016 L
F
.0844 .8813 m
.0844 .88244 L
.08554 .88244 L
.08554 .8813 L
F
.11641 .8813 m
.11641 .88244 L
.11756 .88244 L
.11756 .8813 L
F
.11756 .8813 m
.11756 .88244 L
.1187 .88244 L
.1187 .8813 L
F
.15071 .8813 m
.15071 .88244 L
.15186 .88244 L
.15186 .8813 L
F
.08326 .88244 m
.08326 .88359 L
.0844 .88359 L
.0844 .88244 L
F
.11527 .88244 m
.11527 .88359 L
.11641 .88359 L
.11641 .88244 L
F
.11641 .88244 m
.11641 .88359 L
.11756 .88359 L
.11756 .88244 L
F
.11756 .88244 m
.11756 .88359 L
.1187 .88359 L
.1187 .88244 L
F
.14957 .88244 m
.14957 .88359 L
.15071 .88359 L
.15071 .88244 L
F
.08211 .88359 m
.08211 .88473 L
.08326 .88473 L
.08326 .88359 L
F
.11413 .88359 m
.11413 .88473 L
.11527 .88473 L
.11527 .88359 L
F
.11527 .88359 m
.11527 .88473 L
.11641 .88473 L
.11641 .88359 L
F
.11641 .88359 m
.11641 .88473 L
.11756 .88473 L
.11756 .88359 L
F
.14843 .88359 m
.14843 .88473 L
.14957 .88473 L
.14957 .88359 L
F
.08097 .88473 m
.08097 .88587 L
.08211 .88587 L
.08211 .88473 L
F
.11298 .88473 m
.11298 .88587 L
.11413 .88587 L
.11413 .88473 L
F
.11413 .88473 m
.11413 .88587 L
.11527 .88587 L
.11527 .88473 L
F
.11527 .88473 m
.11527 .88587 L
.11641 .88587 L
.11641 .88473 L
F
.14728 .88473 m
.14728 .88587 L
.14843 .88587 L
.14843 .88473 L
F
.07983 .88587 m
.07983 .88702 L
.08097 .88702 L
.08097 .88587 L
F
.11184 .88587 m
.11184 .88702 L
.11298 .88702 L
.11298 .88587 L
F
.11298 .88587 m
.11298 .88702 L
.11413 .88702 L
.11413 .88587 L
F
.11413 .88587 m
.11413 .88702 L
.11527 .88702 L
.11527 .88587 L
F
.14614 .88587 m
.14614 .88702 L
.14728 .88702 L
.14728 .88587 L
F
.07868 .88702 m
.07868 .88816 L
.07983 .88816 L
.07983 .88702 L
F
.1107 .88702 m
.1107 .88816 L
.11184 .88816 L
.11184 .88702 L
F
.11184 .88702 m
.11184 .88816 L
.11298 .88816 L
.11298 .88702 L
F
.11298 .88702 m
.11298 .88816 L
.11413 .88816 L
.11413 .88702 L
F
.145 .88702 m
.145 .88816 L
.14614 .88816 L
.14614 .88702 L
F
.07754 .88816 m
.07754 .8893 L
.07868 .8893 L
.07868 .88816 L
F
.10955 .88816 m
.10955 .8893 L
.1107 .8893 L
.1107 .88816 L
F
.1107 .88816 m
.1107 .8893 L
.11184 .8893 L
.11184 .88816 L
F
.11184 .88816 m
.11184 .8893 L
.11298 .8893 L
.11298 .88816 L
F
.14385 .88816 m
.14385 .8893 L
.145 .8893 L
.145 .88816 L
F
.0764 .8893 m
.0764 .89045 L
.07754 .89045 L
.07754 .8893 L
F
.10841 .8893 m
.10841 .89045 L
.10955 .89045 L
.10955 .8893 L
F
.10955 .8893 m
.10955 .89045 L
.1107 .89045 L
.1107 .8893 L
F
.1107 .8893 m
.1107 .89045 L
.11184 .89045 L
.11184 .8893 L
F
.14271 .8893 m
.14271 .89045 L
.14385 .89045 L
.14385 .8893 L
F
.07525 .89045 m
.07525 .89159 L
.0764 .89159 L
.0764 .89045 L
F
.10727 .89045 m
.10727 .89159 L
.10841 .89159 L
.10841 .89045 L
F
.10841 .89045 m
.10841 .89159 L
.10955 .89159 L
.10955 .89045 L
F
.10955 .89045 m
.10955 .89159 L
.1107 .89159 L
.1107 .89045 L
F
.14157 .89045 m
.14157 .89159 L
.14271 .89159 L
.14271 .89045 L
F
.07411 .89159 m
.07411 .89273 L
.07525 .89273 L
.07525 .89159 L
F
.10612 .89159 m
.10612 .89273 L
.10727 .89273 L
.10727 .89159 L
F
.10727 .89159 m
.10727 .89273 L
.10841 .89273 L
.10841 .89159 L
F
.10841 .89159 m
.10841 .89273 L
.10955 .89273 L
.10955 .89159 L
F
.14042 .89159 m
.14042 .89273 L
.14157 .89273 L
.14157 .89159 L
F
.07297 .89273 m
.07297 .89388 L
.07411 .89388 L
.07411 .89273 L
F
.10498 .89273 m
.10498 .89388 L
.10612 .89388 L
.10612 .89273 L
F
.10612 .89273 m
.10612 .89388 L
.10727 .89388 L
.10727 .89273 L
F
.10727 .89273 m
.10727 .89388 L
.10841 .89388 L
.10841 .89273 L
F
.13928 .89273 m
.13928 .89388 L
.14042 .89388 L
.14042 .89273 L
F
.07182 .89388 m
.07182 .89502 L
.07297 .89502 L
.07297 .89388 L
F
.10384 .89388 m
.10384 .89502 L
.10498 .89502 L
.10498 .89388 L
F
.10498 .89388 m
.10498 .89502 L
.10612 .89502 L
.10612 .89388 L
F
.10612 .89388 m
.10612 .89502 L
.10727 .89502 L
.10727 .89388 L
F
.13814 .89388 m
.13814 .89502 L
.13928 .89502 L
.13928 .89388 L
F
.07068 .89502 m
.07068 .89616 L
.07182 .89616 L
.07182 .89502 L
F
.10269 .89502 m
.10269 .89616 L
.10384 .89616 L
.10384 .89502 L
F
.10384 .89502 m
.10384 .89616 L
.10498 .89616 L
.10498 .89502 L
F
.10498 .89502 m
.10498 .89616 L
.10612 .89616 L
.10612 .89502 L
F
.13699 .89502 m
.13699 .89616 L
.13814 .89616 L
.13814 .89502 L
F
.06954 .89616 m
.06954 .89731 L
.07068 .89731 L
.07068 .89616 L
F
.10155 .89616 m
.10155 .89731 L
.10269 .89731 L
.10269 .89616 L
F
.10269 .89616 m
.10269 .89731 L
.10384 .89731 L
.10384 .89616 L
F
.10384 .89616 m
.10384 .89731 L
.10498 .89731 L
.10498 .89616 L
F
.13585 .89616 m
.13585 .89731 L
.13699 .89731 L
.13699 .89616 L
F
.06839 .89731 m
.06839 .89845 L
.06954 .89845 L
.06954 .89731 L
F
.10041 .89731 m
.10041 .89845 L
.10155 .89845 L
.10155 .89731 L
F
.10155 .89731 m
.10155 .89845 L
.10269 .89845 L
.10269 .89731 L
F
.10269 .89731 m
.10269 .89845 L
.10384 .89845 L
.10384 .89731 L
F
.13471 .89731 m
.13471 .89845 L
.13585 .89845 L
.13585 .89731 L
F
.06725 .89845 m
.06725 .89959 L
.06839 .89959 L
.06839 .89845 L
F
.09926 .89845 m
.09926 .89959 L
.10041 .89959 L
.10041 .89845 L
F
.10041 .89845 m
.10041 .89959 L
.10155 .89959 L
.10155 .89845 L
F
.10155 .89845 m
.10155 .89959 L
.10269 .89959 L
.10269 .89845 L
F
.13356 .89845 m
.13356 .89959 L
.13471 .89959 L
.13471 .89845 L
F
.06611 .89959 m
.06611 .90074 L
.06725 .90074 L
.06725 .89959 L
F
.09812 .89959 m
.09812 .90074 L
.09926 .90074 L
.09926 .89959 L
F
.09926 .89959 m
.09926 .90074 L
.10041 .90074 L
.10041 .89959 L
F
.10041 .89959 m
.10041 .90074 L
.10155 .90074 L
.10155 .89959 L
F
.13242 .89959 m
.13242 .90074 L
.13356 .90074 L
.13356 .89959 L
F
.06496 .90074 m
.06496 .90188 L
.06611 .90188 L
.06611 .90074 L
F
.09698 .90074 m
.09698 .90188 L
.09812 .90188 L
.09812 .90074 L
F
.09812 .90074 m
.09812 .90188 L
.09926 .90188 L
.09926 .90074 L
F
.09926 .90074 m
.09926 .90188 L
.10041 .90188 L
.10041 .90074 L
F
.13128 .90074 m
.13128 .90188 L
.13242 .90188 L
.13242 .90074 L
F
.06382 .90188 m
.06382 .90302 L
.06496 .90302 L
.06496 .90188 L
F
.09583 .90188 m
.09583 .90302 L
.09698 .90302 L
.09698 .90188 L
F
.09698 .90188 m
.09698 .90302 L
.09812 .90302 L
.09812 .90188 L
F
.09812 .90188 m
.09812 .90302 L
.09926 .90302 L
.09926 .90188 L
F
.13013 .90188 m
.13013 .90302 L
.13128 .90302 L
.13128 .90188 L
F
.06268 .90302 m
.06268 .90417 L
.06382 .90417 L
.06382 .90302 L
F
.09469 .90302 m
.09469 .90417 L
.09583 .90417 L
.09583 .90302 L
F
.09583 .90302 m
.09583 .90417 L
.09698 .90417 L
.09698 .90302 L
F
.09698 .90302 m
.09698 .90417 L
.09812 .90417 L
.09812 .90302 L
F
.12899 .90302 m
.12899 .90417 L
.13013 .90417 L
.13013 .90302 L
F
.06153 .90417 m
.06153 .90531 L
.06268 .90531 L
.06268 .90417 L
F
.09355 .90417 m
.09355 .90531 L
.09469 .90531 L
.09469 .90417 L
F
.09469 .90417 m
.09469 .90531 L
.09583 .90531 L
.09583 .90417 L
F
.09583 .90417 m
.09583 .90531 L
.09698 .90531 L
.09698 .90417 L
F
.12785 .90417 m
.12785 .90531 L
.12899 .90531 L
.12899 .90417 L
F
.06039 .90531 m
.06039 .90645 L
.06153 .90645 L
.06153 .90531 L
F
.0924 .90531 m
.0924 .90645 L
.09355 .90645 L
.09355 .90531 L
F
.09355 .90531 m
.09355 .90645 L
.09469 .90645 L
.09469 .90531 L
F
.09469 .90531 m
.09469 .90645 L
.09583 .90645 L
.09583 .90531 L
F
.1267 .90531 m
.1267 .90645 L
.12785 .90645 L
.12785 .90531 L
F
.05925 .90645 m
.05925 .9076 L
.06039 .9076 L
.06039 .90645 L
F
.09126 .90645 m
.09126 .9076 L
.0924 .9076 L
.0924 .90645 L
F
.0924 .90645 m
.0924 .9076 L
.09355 .9076 L
.09355 .90645 L
F
.09355 .90645 m
.09355 .9076 L
.09469 .9076 L
.09469 .90645 L
F
.12556 .90645 m
.12556 .9076 L
.1267 .9076 L
.1267 .90645 L
F
.0581 .9076 m
.0581 .90874 L
.05925 .90874 L
.05925 .9076 L
F
.09012 .9076 m
.09012 .90874 L
.09126 .90874 L
.09126 .9076 L
F
.09126 .9076 m
.09126 .90874 L
.0924 .90874 L
.0924 .9076 L
F
.0924 .9076 m
.0924 .90874 L
.09355 .90874 L
.09355 .9076 L
F
.12442 .9076 m
.12442 .90874 L
.12556 .90874 L
.12556 .9076 L
F
.05696 .90874 m
.05696 .90988 L
.0581 .90988 L
.0581 .90874 L
F
.08897 .90874 m
.08897 .90988 L
.09012 .90988 L
.09012 .90874 L
F
.09012 .90874 m
.09012 .90988 L
.09126 .90988 L
.09126 .90874 L
F
.09126 .90874 m
.09126 .90988 L
.0924 .90988 L
.0924 .90874 L
F
.12327 .90874 m
.12327 .90988 L
.12442 .90988 L
.12442 .90874 L
F
.05582 .90988 m
.05582 .91103 L
.05696 .91103 L
.05696 .90988 L
F
.08783 .90988 m
.08783 .91103 L
.08897 .91103 L
.08897 .90988 L
F
.08897 .90988 m
.08897 .91103 L
.09012 .91103 L
.09012 .90988 L
F
.09012 .90988 m
.09012 .91103 L
.09126 .91103 L
.09126 .90988 L
F
.12213 .90988 m
.12213 .91103 L
.12327 .91103 L
.12327 .90988 L
F
.05467 .91103 m
.05467 .91217 L
.05582 .91217 L
.05582 .91103 L
F
.08669 .91103 m
.08669 .91217 L
.08783 .91217 L
.08783 .91103 L
F
.08783 .91103 m
.08783 .91217 L
.08897 .91217 L
.08897 .91103 L
F
.08897 .91103 m
.08897 .91217 L
.09012 .91217 L
.09012 .91103 L
F
.12099 .91103 m
.12099 .91217 L
.12213 .91217 L
.12213 .91103 L
F
.05353 .91217 m
.05353 .91331 L
.05467 .91331 L
.05467 .91217 L
F
.08554 .91217 m
.08554 .91331 L
.08669 .91331 L
.08669 .91217 L
F
.08669 .91217 m
.08669 .91331 L
.08783 .91331 L
.08783 .91217 L
F
.08783 .91217 m
.08783 .91331 L
.08897 .91331 L
.08897 .91217 L
F
.11984 .91217 m
.11984 .91331 L
.12099 .91331 L
.12099 .91217 L
F
.05239 .91331 m
.05239 .91446 L
.05353 .91446 L
.05353 .91331 L
F
.08554 .91331 m
.08554 .91446 L
.08669 .91446 L
.08669 .91331 L
F
.08669 .91331 m
.08669 .91446 L
.08783 .91446 L
.08783 .91331 L
F
.1187 .91331 m
.1187 .91446 L
.11984 .91446 L
.11984 .91331 L
F
.05124 .91446 m
.05124 .9156 L
.05239 .9156 L
.05239 .91446 L
F
.08326 .91446 m
.08326 .9156 L
.0844 .9156 L
.0844 .91446 L
F
.0844 .91446 m
.0844 .9156 L
.08554 .9156 L
.08554 .91446 L
F
.11756 .91446 m
.11756 .9156 L
.1187 .9156 L
.1187 .91446 L
F
.0501 .9156 m
.0501 .91674 L
.05124 .91674 L
.05124 .9156 L
F
.08211 .9156 m
.08211 .91674 L
.08326 .91674 L
.08326 .9156 L
F
.08326 .9156 m
.08326 .91674 L
.0844 .91674 L
.0844 .9156 L
F
.0844 .9156 m
.0844 .91674 L
.08554 .91674 L
.08554 .9156 L
F
.11641 .9156 m
.11641 .91674 L
.11756 .91674 L
.11756 .9156 L
F
.04896 .91674 m
.04896 .91789 L
.0501 .91789 L
.0501 .91674 L
F
.08097 .91674 m
.08097 .91789 L
.08211 .91789 L
.08211 .91674 L
F
.08211 .91674 m
.08211 .91789 L
.08326 .91789 L
.08326 .91674 L
F
.08326 .91674 m
.08326 .91789 L
.0844 .91789 L
.0844 .91674 L
F
.11527 .91674 m
.11527 .91789 L
.11641 .91789 L
.11641 .91674 L
F
.04781 .91789 m
.04781 .91903 L
.04896 .91903 L
.04896 .91789 L
F
.07983 .91789 m
.07983 .91903 L
.08097 .91903 L
.08097 .91789 L
F
.08097 .91789 m
.08097 .91903 L
.08211 .91903 L
.08211 .91789 L
F
.08211 .91789 m
.08211 .91903 L
.08326 .91903 L
.08326 .91789 L
F
.11413 .91789 m
.11413 .91903 L
.11527 .91903 L
.11527 .91789 L
F
.04667 .91903 m
.04667 .92017 L
.04781 .92017 L
.04781 .91903 L
F
.07868 .91903 m
.07868 .92017 L
.07983 .92017 L
.07983 .91903 L
F
.07983 .91903 m
.07983 .92017 L
.08097 .92017 L
.08097 .91903 L
F
.08097 .91903 m
.08097 .92017 L
.08211 .92017 L
.08211 .91903 L
F
.11298 .91903 m
.11298 .92017 L
.11413 .92017 L
.11413 .91903 L
F
.04553 .92017 m
.04553 .92132 L
.04667 .92132 L
.04667 .92017 L
F
.07754 .92017 m
.07754 .92132 L
.07868 .92132 L
.07868 .92017 L
F
.07868 .92017 m
.07868 .92132 L
.07983 .92132 L
.07983 .92017 L
F
.07983 .92017 m
.07983 .92132 L
.08097 .92132 L
.08097 .92017 L
F
.11184 .92017 m
.11184 .92132 L
.11298 .92132 L
.11298 .92017 L
F
.04438 .92132 m
.04438 .92246 L
.04553 .92246 L
.04553 .92132 L
F
.0764 .92132 m
.0764 .92246 L
.07754 .92246 L
.07754 .92132 L
F
.07754 .92132 m
.07754 .92246 L
.07868 .92246 L
.07868 .92132 L
F
.07868 .92132 m
.07868 .92246 L
.07983 .92246 L
.07983 .92132 L
F
.1107 .92132 m
.1107 .92246 L
.11184 .92246 L
.11184 .92132 L
F
.04324 .92246 m
.04324 .9236 L
.04438 .9236 L
.04438 .92246 L
F
.07525 .92246 m
.07525 .9236 L
.0764 .9236 L
.0764 .92246 L
F
.0764 .92246 m
.0764 .9236 L
.07754 .9236 L
.07754 .92246 L
F
.07754 .92246 m
.07754 .9236 L
.07868 .9236 L
.07868 .92246 L
F
.10955 .92246 m
.10955 .9236 L
.1107 .9236 L
.1107 .92246 L
F
.0421 .9236 m
.0421 .92475 L
.04324 .92475 L
.04324 .9236 L
F
.07411 .9236 m
.07411 .92475 L
.07525 .92475 L
.07525 .9236 L
F
.07525 .9236 m
.07525 .92475 L
.0764 .92475 L
.0764 .9236 L
F
.0764 .9236 m
.0764 .92475 L
.07754 .92475 L
.07754 .9236 L
F
.10841 .9236 m
.10841 .92475 L
.10955 .92475 L
.10955 .9236 L
F
.04095 .92475 m
.04095 .92589 L
.0421 .92589 L
.0421 .92475 L
F
.07297 .92475 m
.07297 .92589 L
.07411 .92589 L
.07411 .92475 L
F
.07411 .92475 m
.07411 .92589 L
.07525 .92589 L
.07525 .92475 L
F
.07525 .92475 m
.07525 .92589 L
.0764 .92589 L
.0764 .92475 L
F
.10727 .92475 m
.10727 .92589 L
.10841 .92589 L
.10841 .92475 L
F
.03981 .92589 m
.03981 .92703 L
.04095 .92703 L
.04095 .92589 L
F
.07182 .92589 m
.07182 .92703 L
.07297 .92703 L
.07297 .92589 L
F
.07297 .92589 m
.07297 .92703 L
.07411 .92703 L
.07411 .92589 L
F
.07411 .92589 m
.07411 .92703 L
.07525 .92703 L
.07525 .92589 L
F
.10612 .92589 m
.10612 .92703 L
.10727 .92703 L
.10727 .92589 L
F
.03867 .92703 m
.03867 .92818 L
.03981 .92818 L
.03981 .92703 L
F
.07068 .92703 m
.07068 .92818 L
.07182 .92818 L
.07182 .92703 L
F
.07182 .92703 m
.07182 .92818 L
.07297 .92818 L
.07297 .92703 L
F
.07297 .92703 m
.07297 .92818 L
.07411 .92818 L
.07411 .92703 L
F
.10498 .92703 m
.10498 .92818 L
.10612 .92818 L
.10612 .92703 L
F
.03752 .92818 m
.03752 .92932 L
.03867 .92932 L
.03867 .92818 L
F
.06954 .92818 m
.06954 .92932 L
.07068 .92932 L
.07068 .92818 L
F
.07068 .92818 m
.07068 .92932 L
.07182 .92932 L
.07182 .92818 L
F
.07182 .92818 m
.07182 .92932 L
.07297 .92932 L
.07297 .92818 L
F
.10384 .92818 m
.10384 .92932 L
.10498 .92932 L
.10498 .92818 L
F
.03638 .92932 m
.03638 .93046 L
.03752 .93046 L
.03752 .92932 L
F
.06839 .92932 m
.06839 .93046 L
.06954 .93046 L
.06954 .92932 L
F
.06954 .92932 m
.06954 .93046 L
.07068 .93046 L
.07068 .92932 L
F
.07068 .92932 m
.07068 .93046 L
.07182 .93046 L
.07182 .92932 L
F
.10269 .92932 m
.10269 .93046 L
.10384 .93046 L
.10384 .92932 L
F
.03524 .93046 m
.03524 .93161 L
.03638 .93161 L
.03638 .93046 L
F
.06725 .93046 m
.06725 .93161 L
.06839 .93161 L
.06839 .93046 L
F
.06839 .93046 m
.06839 .93161 L
.06954 .93161 L
.06954 .93046 L
F
.06954 .93046 m
.06954 .93161 L
.07068 .93161 L
.07068 .93046 L
F
.10155 .93046 m
.10155 .93161 L
.10269 .93161 L
.10269 .93046 L
F
.03409 .93161 m
.03409 .93275 L
.03524 .93275 L
.03524 .93161 L
F
.06611 .93161 m
.06611 .93275 L
.06725 .93275 L
.06725 .93161 L
F
.06725 .93161 m
.06725 .93275 L
.06839 .93275 L
.06839 .93161 L
F
.06839 .93161 m
.06839 .93275 L
.06954 .93275 L
.06954 .93161 L
F
.10041 .93161 m
.10041 .93275 L
.10155 .93275 L
.10155 .93161 L
F
.03295 .93275 m
.03295 .93389 L
.03409 .93389 L
.03409 .93275 L
F
.06496 .93275 m
.06496 .93389 L
.06611 .93389 L
.06611 .93275 L
F
.06611 .93275 m
.06611 .93389 L
.06725 .93389 L
.06725 .93275 L
F
.06725 .93275 m
.06725 .93389 L
.06839 .93389 L
.06839 .93275 L
F
.09926 .93275 m
.09926 .93389 L
.10041 .93389 L
.10041 .93275 L
F
.03181 .93389 m
.03181 .93504 L
.03295 .93504 L
.03295 .93389 L
F
.06382 .93389 m
.06382 .93504 L
.06496 .93504 L
.06496 .93389 L
F
.06496 .93389 m
.06496 .93504 L
.06611 .93504 L
.06611 .93389 L
F
.06611 .93389 m
.06611 .93504 L
.06725 .93504 L
.06725 .93389 L
F
.09812 .93389 m
.09812 .93504 L
.09926 .93504 L
.09926 .93389 L
F
.03066 .93504 m
.03066 .93618 L
.03181 .93618 L
.03181 .93504 L
F
.06268 .93504 m
.06268 .93618 L
.06382 .93618 L
.06382 .93504 L
F
.06382 .93504 m
.06382 .93618 L
.06496 .93618 L
.06496 .93504 L
F
.06496 .93504 m
.06496 .93618 L
.06611 .93618 L
.06611 .93504 L
F
.09698 .93504 m
.09698 .93618 L
.09812 .93618 L
.09812 .93504 L
F
.02952 .93618 m
.02952 .93732 L
.03066 .93732 L
.03066 .93618 L
F
.06153 .93618 m
.06153 .93732 L
.06268 .93732 L
.06268 .93618 L
F
.06268 .93618 m
.06268 .93732 L
.06382 .93732 L
.06382 .93618 L
F
.06382 .93618 m
.06382 .93732 L
.06496 .93732 L
.06496 .93618 L
F
.09583 .93618 m
.09583 .93732 L
.09698 .93732 L
.09698 .93618 L
F
.02838 .93732 m
.02838 .93847 L
.02952 .93847 L
.02952 .93732 L
F
.06039 .93732 m
.06039 .93847 L
.06153 .93847 L
.06153 .93732 L
F
.06153 .93732 m
.06153 .93847 L
.06268 .93847 L
.06268 .93732 L
F
.06268 .93732 m
.06268 .93847 L
.06382 .93847 L
.06382 .93732 L
F
.09469 .93732 m
.09469 .93847 L
.09583 .93847 L
.09583 .93732 L
F
.02723 .93847 m
.02723 .93961 L
.02838 .93961 L
.02838 .93847 L
F
.05925 .93847 m
.05925 .93961 L
.06039 .93961 L
.06039 .93847 L
F
.06039 .93847 m
.06039 .93961 L
.06153 .93961 L
.06153 .93847 L
F
.06153 .93847 m
.06153 .93961 L
.06268 .93961 L
.06268 .93847 L
F
.09355 .93847 m
.09355 .93961 L
.09469 .93961 L
.09469 .93847 L
F
.02609 .93961 m
.02609 .94075 L
.02723 .94075 L
.02723 .93961 L
F
.0581 .93961 m
.0581 .94075 L
.05925 .94075 L
.05925 .93961 L
F
.05925 .93961 m
.05925 .94075 L
.06039 .94075 L
.06039 .93961 L
F
.06039 .93961 m
.06039 .94075 L
.06153 .94075 L
.06153 .93961 L
F
.0924 .93961 m
.0924 .94075 L
.09355 .94075 L
.09355 .93961 L
F
.02495 .94075 m
.02495 .9419 L
.02609 .9419 L
.02609 .94075 L
F
.05696 .94075 m
.05696 .9419 L
.0581 .9419 L
.0581 .94075 L
F
.0581 .94075 m
.0581 .9419 L
.05925 .9419 L
.05925 .94075 L
F
.05925 .94075 m
.05925 .9419 L
.06039 .9419 L
.06039 .94075 L
F
.09126 .94075 m
.09126 .9419 L
.0924 .9419 L
.0924 .94075 L
F
.0238 .9419 m
.0238 .94304 L
.02495 .94304 L
.02495 .9419 L
F
.05582 .9419 m
.05582 .94304 L
.05696 .94304 L
.05696 .9419 L
F
.05696 .9419 m
.05696 .94304 L
.0581 .94304 L
.0581 .9419 L
F
.0581 .9419 m
.0581 .94304 L
.05925 .94304 L
.05925 .9419 L
F
.09012 .9419 m
.09012 .94304 L
.09126 .94304 L
.09126 .9419 L
F
.02266 .94304 m
.02266 .94418 L
.0238 .94418 L
.0238 .94304 L
F
.05467 .94304 m
.05467 .94418 L
.05582 .94418 L
.05582 .94304 L
F
.05582 .94304 m
.05582 .94418 L
.05696 .94418 L
.05696 .94304 L
F
.05696 .94304 m
.05696 .94418 L
.0581 .94418 L
.0581 .94304 L
F
.08897 .94304 m
.08897 .94418 L
.09012 .94418 L
.09012 .94304 L
F
.02152 .94418 m
.02152 .94533 L
.02266 .94533 L
.02266 .94418 L
F
.05353 .94418 m
.05353 .94533 L
.05467 .94533 L
.05467 .94418 L
F
.05467 .94418 m
.05467 .94533 L
.05582 .94533 L
.05582 .94418 L
F
.05582 .94418 m
.05582 .94533 L
.05696 .94533 L
.05696 .94418 L
F
.08783 .94418 m
.08783 .94533 L
.08897 .94533 L
.08897 .94418 L
F
.02037 .94533 m
.02037 .94647 L
.02152 .94647 L
.02152 .94533 L
F
.05239 .94533 m
.05239 .94647 L
.05353 .94647 L
.05353 .94533 L
F
.05353 .94533 m
.05353 .94647 L
.05467 .94647 L
.05467 .94533 L
F
.05467 .94533 m
.05467 .94647 L
.05582 .94647 L
.05582 .94533 L
F
.08669 .94533 m
.08669 .94647 L
.08783 .94647 L
.08783 .94533 L
F
.01923 .94647 m
.01923 .94761 L
.02037 .94761 L
.02037 .94647 L
F
.05239 .94647 m
.05239 .94761 L
.05353 .94761 L
.05353 .94647 L
F
.05353 .94647 m
.05353 .94761 L
.05467 .94761 L
.05467 .94647 L
F
.08554 .94647 m
.08554 .94761 L
.08669 .94761 L
.08669 .94647 L
F
.0501 .94761 m
.0501 .94876 L
.05124 .94876 L
.05124 .94761 L
F
.05124 .94761 m
.05124 .94876 L
.05239 .94876 L
.05239 .94761 L
F
.0844 .94761 m
.0844 .94876 L
.08554 .94876 L
.08554 .94761 L
F
.04896 .94876 m
.04896 .9499 L
.0501 .9499 L
.0501 .94876 L
F
.0501 .94876 m
.0501 .9499 L
.05124 .9499 L
.05124 .94876 L
F
.05124 .94876 m
.05124 .9499 L
.05239 .9499 L
.05239 .94876 L
F
.08326 .94876 m
.08326 .9499 L
.0844 .9499 L
.0844 .94876 L
F
.04781 .9499 m
.04781 .95104 L
.04896 .95104 L
.04896 .9499 L
F
.04896 .9499 m
.04896 .95104 L
.0501 .95104 L
.0501 .9499 L
F
.0501 .9499 m
.0501 .95104 L
.05124 .95104 L
.05124 .9499 L
F
.08211 .9499 m
.08211 .95104 L
.08326 .95104 L
.08326 .9499 L
F
.04667 .95104 m
.04667 .95219 L
.04781 .95219 L
.04781 .95104 L
F
.04781 .95104 m
.04781 .95219 L
.04896 .95219 L
.04896 .95104 L
F
.04896 .95104 m
.04896 .95219 L
.0501 .95219 L
.0501 .95104 L
F
.08097 .95104 m
.08097 .95219 L
.08211 .95219 L
.08211 .95104 L
F
.04553 .95219 m
.04553 .95333 L
.04667 .95333 L
.04667 .95219 L
F
.04667 .95219 m
.04667 .95333 L
.04781 .95333 L
.04781 .95219 L
F
.04781 .95219 m
.04781 .95333 L
.04896 .95333 L
.04896 .95219 L
F
.07983 .95219 m
.07983 .95333 L
.08097 .95333 L
.08097 .95219 L
F
.04438 .95333 m
.04438 .95447 L
.04553 .95447 L
.04553 .95333 L
F
.04553 .95333 m
.04553 .95447 L
.04667 .95447 L
.04667 .95333 L
F
.04667 .95333 m
.04667 .95447 L
.04781 .95447 L
.04781 .95333 L
F
.07868 .95333 m
.07868 .95447 L
.07983 .95447 L
.07983 .95333 L
F
.04324 .95447 m
.04324 .95562 L
.04438 .95562 L
.04438 .95447 L
F
.04438 .95447 m
.04438 .95562 L
.04553 .95562 L
.04553 .95447 L
F
.04553 .95447 m
.04553 .95562 L
.04667 .95562 L
.04667 .95447 L
F
.07754 .95447 m
.07754 .95562 L
.07868 .95562 L
.07868 .95447 L
F
.0421 .95562 m
.0421 .95676 L
.04324 .95676 L
.04324 .95562 L
F
.04324 .95562 m
.04324 .95676 L
.04438 .95676 L
.04438 .95562 L
F
.04438 .95562 m
.04438 .95676 L
.04553 .95676 L
.04553 .95562 L
F
.0764 .95562 m
.0764 .95676 L
.07754 .95676 L
.07754 .95562 L
F
.04095 .95676 m
.04095 .9579 L
.0421 .9579 L
.0421 .95676 L
F
.0421 .95676 m
.0421 .9579 L
.04324 .9579 L
.04324 .95676 L
F
.04324 .95676 m
.04324 .9579 L
.04438 .9579 L
.04438 .95676 L
F
.07525 .95676 m
.07525 .9579 L
.0764 .9579 L
.0764 .95676 L
F
.03981 .9579 m
.03981 .95905 L
.04095 .95905 L
.04095 .9579 L
F
.04095 .9579 m
.04095 .95905 L
.0421 .95905 L
.0421 .9579 L
F
.0421 .9579 m
.0421 .95905 L
.04324 .95905 L
.04324 .9579 L
F
.07411 .9579 m
.07411 .95905 L
.07525 .95905 L
.07525 .9579 L
F
.03867 .95905 m
.03867 .96019 L
.03981 .96019 L
.03981 .95905 L
F
.03981 .95905 m
.03981 .96019 L
.04095 .96019 L
.04095 .95905 L
F
.04095 .95905 m
.04095 .96019 L
.0421 .96019 L
.0421 .95905 L
F
.07297 .95905 m
.07297 .96019 L
.07411 .96019 L
.07411 .95905 L
F
.03752 .96019 m
.03752 .96133 L
.03867 .96133 L
.03867 .96019 L
F
.03867 .96019 m
.03867 .96133 L
.03981 .96133 L
.03981 .96019 L
F
.03981 .96019 m
.03981 .96133 L
.04095 .96133 L
.04095 .96019 L
F
.07182 .96019 m
.07182 .96133 L
.07297 .96133 L
.07297 .96019 L
F
.03638 .96133 m
.03638 .96248 L
.03752 .96248 L
.03752 .96133 L
F
.03752 .96133 m
.03752 .96248 L
.03867 .96248 L
.03867 .96133 L
F
.03867 .96133 m
.03867 .96248 L
.03981 .96248 L
.03981 .96133 L
F
.07068 .96133 m
.07068 .96248 L
.07182 .96248 L
.07182 .96133 L
F
.03524 .96248 m
.03524 .96362 L
.03638 .96362 L
.03638 .96248 L
F
.03638 .96248 m
.03638 .96362 L
.03752 .96362 L
.03752 .96248 L
F
.03752 .96248 m
.03752 .96362 L
.03867 .96362 L
.03867 .96248 L
F
.06954 .96248 m
.06954 .96362 L
.07068 .96362 L
.07068 .96248 L
F
.03409 .96362 m
.03409 .96476 L
.03524 .96476 L
.03524 .96362 L
F
.03524 .96362 m
.03524 .96476 L
.03638 .96476 L
.03638 .96362 L
F
.03638 .96362 m
.03638 .96476 L
.03752 .96476 L
.03752 .96362 L
F
.06839 .96362 m
.06839 .96476 L
.06954 .96476 L
.06954 .96362 L
F
.03295 .96476 m
.03295 .96591 L
.03409 .96591 L
.03409 .96476 L
F
.03409 .96476 m
.03409 .96591 L
.03524 .96591 L
.03524 .96476 L
F
.03524 .96476 m
.03524 .96591 L
.03638 .96591 L
.03638 .96476 L
F
.06725 .96476 m
.06725 .96591 L
.06839 .96591 L
.06839 .96476 L
F
.03181 .96591 m
.03181 .96705 L
.03295 .96705 L
.03295 .96591 L
F
.03295 .96591 m
.03295 .96705 L
.03409 .96705 L
.03409 .96591 L
F
.03409 .96591 m
.03409 .96705 L
.03524 .96705 L
.03524 .96591 L
F
.06611 .96591 m
.06611 .96705 L
.06725 .96705 L
.06725 .96591 L
F
.03066 .96705 m
.03066 .96819 L
.03181 .96819 L
.03181 .96705 L
F
.03181 .96705 m
.03181 .96819 L
.03295 .96819 L
.03295 .96705 L
F
.03295 .96705 m
.03295 .96819 L
.03409 .96819 L
.03409 .96705 L
F
.06496 .96705 m
.06496 .96819 L
.06611 .96819 L
.06611 .96705 L
F
.02952 .96819 m
.02952 .96934 L
.03066 .96934 L
.03066 .96819 L
F
.03066 .96819 m
.03066 .96934 L
.03181 .96934 L
.03181 .96819 L
F
.03181 .96819 m
.03181 .96934 L
.03295 .96934 L
.03295 .96819 L
F
.06382 .96819 m
.06382 .96934 L
.06496 .96934 L
.06496 .96819 L
F
.02838 .96934 m
.02838 .97048 L
.02952 .97048 L
.02952 .96934 L
F
.02952 .96934 m
.02952 .97048 L
.03066 .97048 L
.03066 .96934 L
F
.03066 .96934 m
.03066 .97048 L
.03181 .97048 L
.03181 .96934 L
F
.06268 .96934 m
.06268 .97048 L
.06382 .97048 L
.06382 .96934 L
F
.02723 .97048 m
.02723 .97162 L
.02838 .97162 L
.02838 .97048 L
F
.02838 .97048 m
.02838 .97162 L
.02952 .97162 L
.02952 .97048 L
F
.02952 .97048 m
.02952 .97162 L
.03066 .97162 L
.03066 .97048 L
F
.06153 .97048 m
.06153 .97162 L
.06268 .97162 L
.06268 .97048 L
F
.02609 .97162 m
.02609 .97277 L
.02723 .97277 L
.02723 .97162 L
F
.02723 .97162 m
.02723 .97277 L
.02838 .97277 L
.02838 .97162 L
F
.02838 .97162 m
.02838 .97277 L
.02952 .97277 L
.02952 .97162 L
F
.06039 .97162 m
.06039 .97277 L
.06153 .97277 L
.06153 .97162 L
F
.02495 .97277 m
.02495 .97391 L
.02609 .97391 L
.02609 .97277 L
F
.02609 .97277 m
.02609 .97391 L
.02723 .97391 L
.02723 .97277 L
F
.02723 .97277 m
.02723 .97391 L
.02838 .97391 L
.02838 .97277 L
F
.05925 .97277 m
.05925 .97391 L
.06039 .97391 L
.06039 .97277 L
F
.0238 .97391 m
.0238 .97505 L
.02495 .97505 L
.02495 .97391 L
F
.02495 .97391 m
.02495 .97505 L
.02609 .97505 L
.02609 .97391 L
F
.02609 .97391 m
.02609 .97505 L
.02723 .97505 L
.02723 .97391 L
F
.0581 .97391 m
.0581 .97505 L
.05925 .97505 L
.05925 .97391 L
F
.02266 .97505 m
.02266 .9762 L
.0238 .9762 L
.0238 .97505 L
F
.0238 .97505 m
.0238 .9762 L
.02495 .9762 L
.02495 .97505 L
F
.02495 .97505 m
.02495 .9762 L
.02609 .9762 L
.02609 .97505 L
F
.05696 .97505 m
.05696 .9762 L
.0581 .9762 L
.0581 .97505 L
F
.02152 .9762 m
.02152 .97734 L
.02266 .97734 L
.02266 .9762 L
F
.02266 .9762 m
.02266 .97734 L
.0238 .97734 L
.0238 .9762 L
F
.0238 .9762 m
.0238 .97734 L
.02495 .97734 L
.02495 .9762 L
F
.05582 .9762 m
.05582 .97734 L
.05696 .97734 L
.05696 .9762 L
F
.02037 .97734 m
.02037 .97848 L
.02152 .97848 L
.02152 .97734 L
F
.02152 .97734 m
.02152 .97848 L
.02266 .97848 L
.02266 .97734 L
F
.02266 .97734 m
.02266 .97848 L
.0238 .97848 L
.0238 .97734 L
F
.05467 .97734 m
.05467 .97848 L
.05582 .97848 L
.05582 .97734 L
F
.01923 .97848 m
.01923 .97963 L
.02037 .97963 L
.02037 .97848 L
F
.02037 .97848 m
.02037 .97963 L
.02152 .97963 L
.02152 .97848 L
F
.02152 .97848 m
.02152 .97963 L
.02266 .97963 L
.02266 .97848 L
F
.05353 .97848 m
.05353 .97963 L
.05467 .97963 L
.05467 .97848 L
F
.01923 .97963 m
.01923 .98077 L
.02037 .98077 L
.02037 .97963 L
F
.02037 .97963 m
.02037 .98077 L
.02152 .98077 L
.02152 .97963 L
F
.05239 .97963 m
.05239 .98077 L
.05353 .98077 L
.05353 .97963 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{225.875, 225.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0001DR000`400?l00000o`00003oo`3ooomC
0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC
0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`008@3oool0
1@3ookl0M00000000000B9`0gooo03X0oooo00<0gia80000000000000`0000001`1d_ol0oooo0?oo
_`1d000000000018W03Oool00P3oool01@3ookl0M00000000000B9`0gooo03D0oooo00<0oooO09a8
001d_ol00P3oool01@3ookl0M00000000000B9`0gooo0080oooo00D0oono07@00000000004RL0=oo
o`0c0?ooo`050?oo_`1d000000000000M02oool00P3oool01@3ookl0M00000000000B9`0gooo0080
oooo00D0oono07@00000000004RL0=ooo`0d0?ooo`050?noM000000000000000B02Lgol00P3oool0
1@3ookl0M00000000000B9`0gooo0080oooo00D0oono07@00000000004RL0=ooo`0;0?ooo`00803o
ool01P3ooml0W4P004RLg`3oool0gia8001d_cX0oooo00<0omnL04P0001d_ol0103oool03@3ooml0
W4P004RLg`3oool0gia8001d_`3oool0oooO09a80018W=l0oooo0=nLB000M;l0=@3oool04@3ooml0
W4P007Boo`3oool0oooO09a80018W=l0oooo0=nLB000M;l0oooo0?oog`2LB000B9cO0?ooo`3OW4P0
07Bo03<0oooo01<0_g@007Boo`3oool0omnL04Q8W03Oool0oooO09a80018W=l0oooo0=nLB000M;l0
oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo03<0oooo01@0omnL04P0B02Lgol0oooo0?noM00007@0
_ooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`/0oooo
000P0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0j0?ooo`030?oOW0180000M;oo00<0
oooo00h0oono07@0M02oool0oooo0?oOW01807@0_ooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
oc40oooo00<0gia80000000000000`0000003`18W=l0oono07@0M02oool0oooo0?oOW01807@0_ooo
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0a0?ooo`0E0?oo_`1dB9`0gooo0?ooo`3ookl0M018
09cOo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0oono07@0M02oool0oooo0?oOW01807@0_ooo
0380oooo01D0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool02P3oool00200oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo03/0oooo00<0oono07@00018W=l00P3oool03P3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo<@3oool05@3ogi`0B4RL0=ooo`3o
oml0W4P007Boo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`0a0?ooo`0E0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0380oooo01D0omnL04P0B02L
gol0oooo0?noM00007@0_ooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol02P3oool00200oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo03`0
oooo0180oooO09a80018W=l0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`3o_g@004RL0=oo
o`3oool0oono07@0B02Lgolb0?ooo`0D0=nLB018W=l0oooO09a8001d_ol0oooo0?noM000B9`0gooo
0?ooo`3ookl0M01809cOo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgola0?ooo`0E0?oOW0180000
M;oo0?ooo`3ogi`0B4RL0=ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0okmd0018W03Oool0
oooo0?oo_`1d04P0W=oo03<0oooo01@0oono07@00000000004RL0=ooo`3oool0okmd0018W03Oool0
oooo0?oo_`1d04P0W=oo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`X0oooo000P0?ooo`070?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`0m0?ooo`0A0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<P3oool0503ooml0W4Q809cO
g`2LB000M;oo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo<@3oool05@3ogi`0B4RL09ad00000000001809cOo`3oool0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0b0?ooo`0E0?oo_`1d04P0W=oo
0?ooo`3OW4P004RL0=ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo00X0oooo000P0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0i0?oo
o`030?noM000M;l0oooo0080oooo0100_g@007Boo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
oono07@0M02oool0oooo0?oOW01807@0_ooo<`3oool04`3ogi`0B4Qd07A8001d_ol0oooo0?oo_`1d
07@0_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0<@3oool00`3o
okl0M01d0;ooo`040?ooo`0>0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02ooolb0?ooo`0E0?oOW018B9`0gooo0?ooo`3ookl0M01d0;ooo`3ookl0M01d0;oo
o`3oool0omnL04P0M02oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00X0oooo000P0?ooo`06
0?oog`2LB000M;oo0?ooo`3OW4P007Bo>P3oool0503ookl0M01809cOo`3oool0omnL04P0B02Lgol0
oooO09a8001d_ol0oooo0=nLB000M;l0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo=@3oool04@3O
W4P0000007Boo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0oooo0?oog`2LB000M;oo0?ooo`3O
W4P007Bo03<0oooo01<0_g@007Boo`3oool0okmd0018W03Oool0oooO09a8001d_ol0oooo0=nLB000
M;l0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo03<0oooo01@0oono07@0B02Lgol0oooo0=nLB000
B9`0gooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`/0
oooo000Q0?ooo`050?oo_`1d000000000018W03Oool0>`3oool01@3ogi`0B000000000000000M;oo
0080oooo00D0oono07@00000000004RL0=ooo`020?ooo`050?oo_`1d000000000018W03Oool0=@3o
ool00`3ooml0W4P007Boo`020?ooo`050?oo_`1d000000000018W03Oool00P3oool01@3ookl0M000
00000000B9`0gooo03<0oooo00D0oooO09a800000000001809cOo`020?ooo`050?oo_`1d00000000
0018W03Oool00P3oool01@3ookl0M00000000000B9`0gooo03@0oooo00D0omnL04P000000000001d
0;ooo`020?ooo`050?oo_`1d000000000018W03Oool00P3oool01@3ookl0M00000000000B9`0gooo
00/0oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oooe<0oooo003o0?oo
oe<0oooo003o0?oooe<0oooo000M0?ooool00000=P00000001d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00@00
000001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo0140oooo0@0000000140oooo00D0oono07@00000000004RL0=ooo`070?ooo`030000003oool0
oooo0?l0oooo<P3oool100000000403oool01P3ooml0W4P004RLg`3oool0gia8001d_`L0oooo00<0
00000?ooo`3oool0o`3ooolb0?ooo`400000000@0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`060?ooo`030000003oool0oooo0?l0oooo<P3oool100000000403oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol01P3oool300000?l0oooo8@3oool2000000P0oooo0P0000030?ooo`<0
0000000@0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`030000003oool0oooo
0?l0oooo803oool2000000P0oooo0`0000050?ooo`400000000@0?ooo`070?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`060?ooo`030000003oool0oooo0?l0oooo803oool00`000000oooo0?ooo`06
0?ooo`8000001`3oool100000000403oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01P3o
ool00`000000oooo0?ooo`3o0?oooah0oooo0P0000080?ooo`<000001`3oool100000000403oool0
1P3ooml0W4P007Boo`3oool0gia8001d_`L0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`800000
203oool3000000P0oooo0@0000000140oooo00D0oono07@00000000004RL0=ooo`070?ooo`030000
003oool0oooo0?l0oooo703oool2000000P0oooo0`0000090?ooo`400000000M0?ooo`030000003o
ool0oooo0?l0oooo6`3oool2000000P0oooo0`00000:0?ooo`400000000M0?ooo`030000003oool0
oooo0?l0oooo6P3oool2000000P0oooo0`00000;0?ooo`400000000M0?ooo`030000003oool0oooo
0?l0oooo6P3oool00`000000oooo0?ooo`060?ooo`8000003@3oool1000000007@3oool00`000000
oooo0?ooo`3o0?oooaP0oooo0P0000080?ooo`<000003@3oool1000000007@3oool00`000000oooo
0?ooo`3o0?oooaL0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`400000
000M0?ooo`030000003oool0oooo0?l0oooo5P3oool2000000P0oooo0`0000080?ooo`8000001@3o
ool1000000007@3oool00`000000oooo0?ooo`3o0?oooaD0oooo0P0000080?ooo`<00000203oool0
0`000000oooo0?ooo`050?ooo`400000000M0?ooo`030000003oool0oooo0?l0oooo503oool20000
00P0oooo0`0000080?ooo`030000003oool0oooo00H0oooo0@00000001d0oooo00<000000?ooo`3o
ool0o`3ooolD0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00L0
oooo0@00000001d0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo00H0oooo
0`0000080?ooo`8000002@3oool1000000007@3oool00`000000oooo0?ooo`3o0?oooa40oooo0P00
00080?ooo`<00000203oool2000000X0oooo0@00000001d0oooo0P00003o0?oooa40oooo0P000008
0?ooo`<00000203oool2000000X0oooo0P00000001d0oooo00<000000?ooo`3oool0o`3oool?0?oo
o`800000203oool3000000P0oooo00<000000?ooo`3oool02`3oool1000000007@3oool00`000000
oooo0?ooo`3o0?ooo`h0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`0<0?ooo`40
0000000M0?ooo`030000003oool0oooo0?l0oooo3@3oool2000000P0oooo0P0000090?ooo`030000
003oool0oooo00d0oooo0@00000001d0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003o
ool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00h0oooo0@00000001d0oooo00<00000
0?ooo`3oool0o`3oool;0?ooo`800000203oool3000000P0oooo0P00000@0?ooo`400000000M0?oo
o`030000003oool0oooo0?l0oooo2P3oool2000000P0oooo0`0000080?ooo`8000004@3oool10000
00007@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo0P0000080?ooo`<00000203oool00`000000
oooo0?ooo`0A0?ooo`400000000M0?ooo`030000003oool0oooo0?l0oooo203oool2000000P0oooo
0`0000080?ooo`030000003oool0oooo0180oooo0@00000001d0oooo00<000000?ooo`3oool0o`3o
ool70?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool04`3oool1000000007@3oool0
0`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<00000
0?ooo`3oool0503oool1000000007@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo0P0000080?oo
o`<00000203oool2000001H0oooo0@00000001d0oooo00<000000?ooo`3oool0o`3oool40?ooo`80
0000203oool3000000P0oooo0P00000G0?ooo`400000000M0?ooo`030000003oool0oooo0?l0oooo
0`3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo01L0oooo0@00000001d0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0603o
ool1000000007@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0P0000080?ooo`<00000203oool0
0`000000oooo0?ooo`0I0?ooo`400000000M0?ooo`030000003oool0oooo0?l0oooo0@3oool00`00
0000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0J0?ooo`400000000M0?ooo`03
0000003oool0oooo0?l0oooo00<000000?ooo`3oool01P3oool3000000P0oooo0P00000L0?ooo`40
0000000M0?ooo`800000oP3oool2000000P0oooo0`0000080?ooo`800000703oool2000000007@3o
ool00`000000oooo0?ooo`3l0?ooo`800000203oool3000000P0oooo0P00000N0?ooo`400000000M
0?ooo`030000003oool0oooo0?/0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`0N
0?ooo`400000000M0?ooo`030000003oool0oooo0?X0oooo0P0000080?ooo`<00000203oool00`00
0000oooo0?ooo`0O0?ooo`400000000M0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3o
ool01P3oool2000000T0oooo00<000000?ooo`3oool0803oool1000000007@3oool00`000000oooo
0?ooo`3i0?ooo`030000003oool0oooo00H0oooo0`0000080?ooo`8000008P3oool1000000007@3o
ool00`000000oooo0?ooo`3g0?ooo`800000203oool3000000P0oooo0P00000S0?ooo`400000000M
0?ooo`030000003oool0oooo0?H0oooo0P0000080?ooo`<00000203oool2000002@0oooo0@000000
01d0oooo00<000000?ooo`3oool0m@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo
02@0oooo0@00000001d0oooo00<000000?ooo`3oool0m03oool2000000P0oooo0`0000080?ooo`03
0000003oool0oooo02D0oooo0@00000001d0oooo00<000000?ooo`3oool0l`3oool2000000P0oooo
0`0000080?ooo`030000003oool0oooo02H0oooo0@00000001d0oooo00<000000?ooo`3oool0l`3o
ool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0W0?ooo`400000000M
0?ooo`030000003oool0oooo0?40oooo0P0000080?ooo`<00000203oool2000002T0oooo0@000000
01d0oooo00<000000?ooo`3oool0l03oool2000000P0oooo0`0000080?ooo`800000:P3oool10000
00007@3oool00`000000oooo0?ooo`3_0?ooo`800000203oool3000000P0oooo00<000000?ooo`3o
ool0:P3oool1000000007@3oool00`000000oooo0?ooo`3^0?ooo`800000203oool3000000P0oooo
00<000000?ooo`3oool0:`3oool1000000007@3oool00`000000oooo0?ooo`3]0?ooo`800000203o
ool3000000P0oooo00<000000?ooo`3oool0;03oool1000000007@3oool00`000000oooo0?ooo`3]
0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo02d0oooo0@000000
01d0oooo0P00003]0?ooo`030000003oool0oooo00H0oooo0`0000080?ooo`800000;P3oool20000
00007@3oool00`000000oooo0?ooo`3Z0?ooo`800000203oool3000000P0oooo0P00000`0?ooo`40
0000000M0?ooo`030000003oool0oooo0>T0oooo0P0000080?ooo`<00000203oool200000340oooo
0@00000001d0oooo00<000000?ooo`3oool0j03oool2000000P0oooo0`0000080?ooo`030000003o
ool0oooo0340oooo0@00000001d0oooo00<000000?ooo`3oool0i`3oool2000000P0oooo0`000008
0?ooo`030000003oool0oooo0380oooo0@00000001d0oooo00<000000?ooo`3oool0i`3oool00`00
0000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0c0?ooo`400000000M0?ooo`03
0000003oool0oooo0>H0oooo00<000000?ooo`3oool01P3oool3000000P0oooo0P00000e0?ooo`40
0000000M0?ooo`030000003oool0oooo0>@0oooo0P0000080?ooo`<00000203oool2000003H0oooo
0@00000001d0oooo00<000000?ooo`3oool0h`3oool2000000P0oooo0`0000080?ooo`800000=`3o
ool1000000007@3oool00`000000oooo0?ooo`3R0?ooo`800000203oool3000000P0oooo00<00000
0?ooo`3oool0=`3oool1000000007@3oool00`000000oooo0?ooo`3Q0?ooo`800000203oool30000
00P0oooo00<000000?ooo`3oool0>03oool1000000007@3oool00`000000oooo0?ooo`3P0?ooo`80
0000203oool3000000P0oooo00<000000?ooo`3oool0>@3oool1000000007@3oool00`000000oooo
0?ooo`3P0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo03X0oooo
0@00000001d0oooo00<000000?ooo`3oool0gP3oool2000000P0oooo0`0000080?ooo`800000?03o
ool1000000000`3oool00`3OW4P00000000000030000000707Boo`3oool0oono07@00000000004RL
0=ooo`020?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`3M0?ooo`80
0000203oool3000000P0oooo0P00000m0?ooo`40000000030?ooo`030?oOW0180000M;oo00@0oooo
00d0oooO09a80018W=l0oooo0=nLB000M;l0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo00H0oooo
00<000000?ooo`3oool0g03oool2000000P0oooo0`0000080?ooo`030000003oool0oooo03d0oooo
0@00000000@0oooo00<0omnL04P0001d_ol00`3oool03P3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool0oono07@0M02oool0oooo0?oOW01807@0_ooo1@3oool00`000000oooo0?ooo`3K0?ooo`800000
203oool3000000P0oooo00<000000?ooo`3oool0?P3oool1000000001@3oool00`3ookl0M00004RL
g`020?ooo`0>0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol50?ooo`<00000fP3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo03d0oooo
0`00000000H0oooo0180oooO09a80018W=l0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`3o
_g@004RL0=ooo`3oool0oono07@0B02Lgol50?ooo`030000003oool0oooo0=X0oooo00<000000?oo
o`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0@03oool1000000001`3oool04@3ookl0
M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00D0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`060?ooo`<00000203oool2
00000480oooo0@00000000<0oooo00<0okmd001d_`3oool00P3oool0402oM000M;oo0?oo_`1d07@0
_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool50?ooo`030000003o
ool0oooo0=L0oooo0P0000080?ooo`<00000203oool2000004<0oooo0@00000000<0oooo01@0oono
07@0B02Lgol0oooo0?oOW01804P0W=oo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0?ooo`3ooml0W4P0
07Boo`3oool0gia8001d_`H0oooo00<000000?ooo`3oool0eP3oool2000000P0oooo0`0000080?oo
o`800000A03oool100000000103oool01@3ogi`0B000000000000000M;oo0080oooo00D0oono07@0
0000000004RL0=ooo`020?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo0?oo
o`3E0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0A03oool1000000007@3oool0
0`000000oooo0?ooo`3D0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0A@3oool1
000000007@3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00H0oooo0P0000090?oo
o`030000003oool0oooo04H0oooo0@00000001d0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`060?ooo`<00000203oool2000004P0oooo0@00000001d0oooo00<000000?ooo`3oool0
d@3oool2000000P0oooo0`0000080?ooo`800000B@3oool1000000007@3oool00`000000oooo0?oo
o`3@0?ooo`800000203oool3000000P0oooo0P00001:0?ooo`400000000M0?ooo`030000003oool0
oooo0<l0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1:0?ooo`400000000M0?oo
o`030000003oool0oooo0<h0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1;0?oo
o`400000000M0?ooo`030000003oool0oooo0<d0oooo0P0000080?ooo`<00000203oool00`000000
oooo0?ooo`1<0?ooo`400000000M0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0
1P3oool2000000T0oooo00<000000?ooo`3oool0C@3oool1000000007@3oool00`000000oooo0?oo
o`3;0?ooo`800000203oool3000000P0oooo0P00001?0?ooo`400000000M0?ooo`030000003oool0
oooo0<X0oooo0P0000080?ooo`<00000203oool200000500oooo0@00000001d0oooo00<000000?oo
o`3oool0b@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0500oooo0@00000001d0
oooo0P0000390?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0D03oool200000000
7@3oool00`000000oooo0?ooo`370?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0
DP3oool1000000007@3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00H0oooo0P00
00090?ooo`030000003oool0oooo05<0oooo0@00000001d0oooo00<000000?ooo`3oool0aP3oool0
0`000000oooo0?ooo`060?ooo`<00000203oool2000005D0oooo0@00000001d0oooo00<000000?oo
o`3oool0a03oool2000000P0oooo0`0000080?ooo`800000EP3oool1000000007@3oool00`000000
oooo0?ooo`330?ooo`800000203oool3000000P0oooo0P00001G0?ooo`400000000M0?ooo`030000
003oool0oooo0<80oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1G0?ooo`400000
000M0?ooo`030000003oool0oooo0<40oooo0P0000080?ooo`<00000203oool00`000000oooo0?oo
o`1H0?ooo`400000000M0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool01P3oool2
000000T0oooo00<000000?ooo`3oool0F@3oool1000000007@3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo00H0oooo0`0000080?ooo`800000F`3oool1000000007@3oool00`000000
oooo0?ooo`2n0?ooo`800000203oool3000000P0oooo0P00001L0?ooo`400000000M0?ooo`030000
003oool0oooo0;d0oooo0P0000080?ooo`<00000203oool2000005d0oooo0@00000001d0oooo00<0
00000?ooo`3oool0_03oool2000000P0oooo0`0000080?ooo`030000003oool0oooo05d0oooo0@00
000001d0oooo00<000000?ooo`3oool0^`3oool2000000P0oooo0`0000080?ooo`030000003oool0
oooo05h0oooo0@00000001d0oooo00<000000?ooo`3oool0^P3oool2000000P0oooo0`0000080?oo
o`030000003oool0oooo05l0oooo0@00000001d0oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`1P0?ooo`400000000M0?ooo`030000
003oool0oooo0;P0oooo0P0000080?ooo`<00000203oool200000680oooo0@00000001d0oooo0P00
002h0?ooo`800000203oool3000000P0oooo0P00001R0?ooo`800000000M0?ooo`030000003oool0
oooo0;H0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1S0?ooo`400000000M0?oo
o`030000003oool0oooo0;D0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1T0?oo
o`400000000M0?ooo`030000003oool0oooo0;@0oooo0P0000080?ooo`<00000203oool00`000000
oooo0?ooo`1U0?ooo`400000000M0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0
1P3oool2000000T0oooo00<000000?ooo`3oool0IP3oool1000000007@3oool00`000000oooo0?oo
o`2b0?ooo`800000203oool3000000P0oooo0P00001X0?ooo`400000000M0?ooo`030000003oool0
oooo0;40oooo0P0000080?ooo`<00000203oool2000006T0oooo0@00000001d0oooo00<000000?oo
o`3oool0/03oool2000000P0oooo0`0000080?ooo`800000JP3oool1000000007@3oool00`000000
oooo0?ooo`2_0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0JP3oool100000000
7@3oool00`000000oooo0?ooo`2^0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0
J`3oool1000000007@3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo00H0oooo0P00
00090?ooo`030000003oool0oooo06`0oooo0@00000001d0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`060?ooo`<00000203oool2000006h0oooo0@00000001d0oooo00<000000?oo
o`3oool0Z`3oool2000000P0oooo0`0000080?ooo`800000K`3oool1000000007@3oool00`000000
oooo0?ooo`2Z0?ooo`800000203oool3000000P0oooo0P00001`0?ooo`400000000M0?ooo`030000
003oool0oooo0:T0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1`0?ooo`400000
000M0?ooo`030000003oool0oooo0:P0oooo0P0000080?ooo`<00000203oool00`000000oooo0?oo
o`1a0?ooo`400000000M0?ooo`030000003oool0oooo0:L0oooo0P0000080?ooo`8000002@3oool0
0`000000oooo0?ooo`1b0?ooo`400000000M0?ooo`030000003oool0oooo0:L0oooo00<000000?oo
o`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0L`3oool1000000007@3oool200000:H0
oooo0P0000080?ooo`<00000203oool2000007@0oooo0P00000001d0oooo00<000000?ooo`3oool0
Y03oool2000000P0oooo0`0000080?ooo`800000MP3oool1000000007@3oool00`000000oooo0?oo
o`2S0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0MP3oool1000000007@3oool0
0`000000oooo0?ooo`2R0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0M`3oool1
000000007@3oool00`000000oooo0?ooo`2Q0?ooo`800000203oool3000000P0oooo00<000000?oo
o`3oool0N03oool1000000007@3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00H0
oooo0P0000090?ooo`030000003oool0oooo07T0oooo0@00000001d0oooo00<000000?ooo`3oool0
W`3oool2000000P0oooo0`0000080?ooo`800000N`3oool1000000007@3oool00`000000oooo0?oo
o`2N0?ooo`800000203oool3000000P0oooo0P00001l0?ooo`400000000M0?ooo`030000003oool0
oooo09d0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1l0?ooo`400000000M0?oo
o`030000003oool0oooo09`0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`1m0?oo
o`400000000M0?ooo`030000003oool0oooo09/0oooo0P0000080?ooo`<00000203oool00`000000
oooo0?ooo`1n0?ooo`400000000M0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0
1P3oool2000000T0oooo00<000000?ooo`3oool0O`3oool1000000007@3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo00H0oooo0`0000080?ooo`800000P@3oool1000000007@3oool0
0`000000oooo0?ooo`2H0?ooo`800000203oool3000000P0oooo0P0000220?ooo`40000000060?oo
o`030?oog`2LB000M;oo0080oooo00D0oono07@00000000004RL0=ooo`020?ooo`050?oo_`1d0000
00000018W03Oool01P3oool00`000000oooo0?ooo`2G0?ooo`800000203oool3000000P0oooo0P00
00230?ooo`40000000060?ooo`0A0?oog`2LB000M;oo0?ooo`3ooml0W4P004RLg`3oool0gia8001d
_`3oool0oooO09a80018W=l0oooo0=nLB000M;l01P3oool00`000000oooo0?ooo`2F0?ooo`800000
203oool3000000P0oooo00<000000?ooo`3oool0P`3oool1000000000`3oool00`3OW4P000000000
00030000000?04RLg`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0oono07@0M02oool0oooo0?oO
W01807@0_ooo00D0oooo00<000000?ooo`3oool0U@3oool2000000P0oooo0`0000080?ooo`030000
003oool0oooo08@0oooo0@00000000<0oooo01D0omnL04Q8W03Oool0oooO09a8001d_ol0oooo0?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0
oooo08D0oooo0@00000000@0oooo01@0gia804RLg`3ooml0W4P007Boo`3oool0okmd0018W03Oool0
oooo0?oo_`1d04P0W=oo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`D0oooo0`00002D0?ooo`03
0000003oool0oooo00H0oooo0`0000080?ooo`800000Q@3oool300000000103oool0503ooml0W4Q8
09cOg`2LB000M;oo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo1@3oool00`000000oooo0?ooo`2B0?ooo`800000203oool3000000P0oooo0P00
00280?ooo`40000000050?ooo`0C0?oOW018B7@0M4P007Boo`3oool0oono07@0M02oool0oooo0?oO
W01807@0_ooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0oooo0940
oooo0P0000080?ooo`<00000203oool2000008T0oooo0@00000000H0oooo0140gia80000001d_ol0
oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`060?oo
o`030000003oool0oooo0900oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`290?oo
o`40000000060?ooo`030?oog`2LB000M;oo0080oooo00D0oono07@00000000004RL0=ooo`020?oo
o`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`2?0?ooo`800000203oool3
000000P0oooo00<000000?ooo`3oool0RP3oool1000000007@3oool00`000000oooo0?ooo`2>0?oo
o`800000203oool3000000P0oooo00<000000?ooo`3oool0R`3oool1000000007@3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo08`0
oooo0@00000001d0oooo00<000000?ooo`3oool0S03oool2000000P0oooo0`0000080?ooo`800000
SP3oool1000000007@3oool00`000000oooo0?ooo`2;0?ooo`800000203oool3000000P0oooo0P00
002?0?ooo`400000000M0?ooo`030000003oool0oooo08X0oooo0P0000080?ooo`<00000203oool0
0`000000oooo0?ooo`2?0?ooo`400000000M0?ooo`030000003oool0oooo08T0oooo0P0000080?oo
o`<00000203oool00`000000oooo0?ooo`2@0?ooo`400000000M0?ooo`030000003oool0oooo08P0
oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`2A0?ooo`400000000M0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0
TP3oool1000000007@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00H0oooo0`00
00080?ooo`800000U03oool1000000007@3oool00`000000oooo0?ooo`250?ooo`800000203oool3
000000P0oooo0P00002E0?ooo`400000000M0?ooo`030000003oool0oooo08@0oooo0P0000080?oo
o`<00000203oool2000009H0oooo0@00000001d0oooo00<000000?ooo`3oool0P`3oool2000000P0
oooo0`0000080?ooo`030000003oool0oooo09H0oooo0@00000001d0oooo0P0000230?ooo`800000
203oool3000000P0oooo00<000000?ooo`3oool0UP3oool2000000007@3oool00`000000oooo0?oo
o`220?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo09P0oooo0@00
000001d0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`060?ooo`<00000203oool2
000009X0oooo0@00000001d0oooo00<000000?ooo`3oool0O`3oool2000000P0oooo0`0000080?oo
o`800000V`3oool1000000007@3oool00`000000oooo0?ooo`1n0?ooo`800000203oool3000000P0
oooo0P00002L0?ooo`400000000M0?ooo`030000003oool0oooo07d0oooo0P0000080?ooo`<00000
203oool00`000000oooo0?ooo`2L0?ooo`400000000M0?ooo`030000003oool0oooo07`0oooo0P00
00080?ooo`<00000203oool00`000000oooo0?ooo`2M0?ooo`400000000M0?ooo`030000003oool0
oooo07/0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`2N0?ooo`400000000M0?oo
o`030000003oool0oooo07/0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?oo
o`3oool0W`3oool1000000007@3oool00`000000oooo0?ooo`1i0?ooo`800000203oool3000000P0
oooo0P00002Q0?ooo`400000000M0?ooo`030000003oool0oooo07P0oooo0P0000080?ooo`<00000
203oool200000:80oooo0@00000001d0oooo00<000000?ooo`3oool0M`3oool2000000P0oooo0`00
00080?ooo`030000003oool0oooo0:80oooo0@00000001d0oooo00<000000?ooo`3oool0MP3oool2
000000P0oooo0`0000080?ooo`030000003oool0oooo0:<0oooo0@00000001d0oooo00<000000?oo
o`3oool0M@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0:@0oooo0@00000001d0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000
oooo0?ooo`2U0?ooo`400000000M0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
1P3oool3000000P0oooo0P00002W0?ooo`400000000M0?ooo`030000003oool0oooo0780oooo0P00
00080?ooo`<00000203oool200000:P0oooo0@00000001d0oooo00<000000?ooo`3oool0L@3oool2
000000P0oooo0`0000080?ooo`800000Z@3oool1000000007@3oool200000740oooo0P0000080?oo
o`<00000203oool00`000000oooo0?ooo`2X0?ooo`800000000M0?ooo`030000003oool0oooo06l0
oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`2Z0?ooo`400000000M0?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0
Z`3oool1000000007@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00H0oooo0`00
00080?ooo`800000[@3oool1000000007@3oool00`000000oooo0?ooo`1/0?ooo`800000203oool3
000000P0oooo0P00002^0?ooo`400000000M0?ooo`030000003oool0oooo06/0oooo0P0000080?oo
o`<00000203oool200000:l0oooo0@00000001d0oooo00<000000?ooo`3oool0JP3oool2000000P0
oooo0`0000080?ooo`030000003oool0oooo0:l0oooo0@00000001d0oooo00<000000?ooo`3oool0
J@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0;00oooo0@00000001d0oooo00<0
00000?ooo`3oool0J03oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0;40oooo0@00
000001d0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`060?ooo`8000002@3oool0
0`000000oooo0?ooo`2b0?ooo`400000000M0?ooo`030000003oool0oooo06H0oooo0P0000080?oo
o`<00000203oool200000;@0oooo0@00000001d0oooo00<000000?ooo`3oool0I@3oool2000000P0
oooo0`0000080?ooo`800000]@3oool1000000007@3oool00`000000oooo0?ooo`1T0?ooo`800000
203oool3000000P0oooo00<000000?ooo`3oool0]@3oool1000000007@3oool00`000000oooo0?oo
o`1S0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0]P3oool1000000007@3oool0
0`000000oooo0?ooo`1R0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0]`3oool1
000000007@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00H0oooo0P0000090?oo
o`030000003oool0oooo0;P0oooo0@00000001d0oooo00<000000?ooo`3oool0H03oool2000000P0
oooo0`0000080?ooo`800000^P3oool1000000007@3oool200000600oooo0P0000080?ooo`<00000
203oool200000;X0oooo0P00000001d0oooo00<000000?ooo`3oool0GP3oool2000000P0oooo0`00
00080?ooo`800000_03oool1000000007@3oool00`000000oooo0?ooo`1M0?ooo`800000203oool3
000000P0oooo00<000000?ooo`3oool0_03oool1000000007@3oool00`000000oooo0?ooo`1L0?oo
o`800000203oool3000000P0oooo00<000000?ooo`3oool0_@3oool1000000007@3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo0;h0
oooo0@00000001d0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`060?ooo`<00000
203oool200000<00oooo0@00000001d0oooo00<000000?ooo`3oool0F@3oool2000000P0oooo0`00
00080?ooo`800000`@3oool1000000007@3oool00`000000oooo0?ooo`1H0?ooo`800000203oool3
000000P0oooo0P0000320?ooo`400000000M0?ooo`030000003oool0oooo05L0oooo0P0000080?oo
o`<00000203oool00`000000oooo0?ooo`320?ooo`400000000M0?ooo`030000003oool0oooo05H0
oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`330?ooo`400000000M0?ooo`030000
003oool0oooo05D0oooo0P0000080?ooo`8000002@3oool00`000000oooo0?ooo`340?ooo`400000
000M0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<0
00000?ooo`3oool0a@3oool1000000007@3oool00`000000oooo0?ooo`1C0?ooo`800000203oool3
000000P0oooo0P0000370?ooo`400000000M0?ooo`030000003oool0oooo0580oooo0P0000080?oo
o`<00000203oool200000<P0oooo0@00000001d0oooo00<000000?ooo`3oool0D@3oool2000000P0
oooo0`0000080?ooo`030000003oool0oooo0<P0oooo0@00000000@0oooo00D0oono07@000000000
001d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool00P3oool01@3ookl0M00000000000B9`0
gooo00H0oooo00<000000?ooo`3oool0D03oool2000000P0oooo0`0000080?ooo`030000003oool0
oooo0<T0oooo0@00000000@0oooo01<0_g@007Boo`3oool0omnL04Q8W03Oool0oooO09a80018W=l0
oooo0=nLB000M;l0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo00H0oooo00<000000?ooo`3oool0
C`3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0<X0oooo0@00000000<0oooo01D0
oono07A8W03Oool0oooo0?oo_`1d04P0W=oo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00H0oooo0P0000090?ooo`030000003oool0oooo0</0oooo0@00000000<0oooo01D0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol01@3oool3000004d0oooo0P0000080?ooo`<00000203oool200000</0
oooo0`00000000<0oooo01D0omnL04P0001d_ol0oooo0?oOW018B9`0gooo0?noM000B9`0gooo0?oo
o`3ookl0M01809cOo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?oo
o`1<0?ooo`800000203oool3000000P0oooo0P00003>0?ooo`40000000030?ooo`0E0?oOW018B9`0
W7@00000000004P0W=oo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool0B`3oool2000000P0oooo0`0000080?oo
o`030000003oool0oooo0<h0oooo0@00000000<0oooo00<0oono07@0M02oool0103oool03P3ookl0
M01d0;ooo`3oool0omnL04P0M02oool0oono07@0M02oool0oooo0?oOW01807@0_ooo1@3oool00`00
0000oooo0?ooo`1:0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0c`3oool10000
0000103oool04`2oM000M;oo0?ooo`3o_g@004RL0=ooo`3ooml0W4P007Boo`3oool0gia8001d_`3o
ool0oooO09a8001d_ol0oooo0=nLB000M;l01P3oool00`000000oooo0?ooo`190?ooo`800000203o
ool3000000P0oooo00<000000?ooo`3oool0d03oool100000000103oool01@3ooml0W4P000000000
04P0W=oo0080oooo00D0oono07@00000000004RL0=ooo`020?ooo`050?oo_`1d000000000018W03O
ool01P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`03
0000003oool0oooo0=40oooo0@00000001d0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`060?ooo`<00000203oool200000=<0oooo0@00000001d0oooo00<000000?ooo`3oool0AP3o
ool2000000P0oooo0`0000080?ooo`800000e03oool1000000007@3oool00`000000oooo0?ooo`15
0?ooo`800000203oool3000000P0oooo0P00003E0?ooo`400000000M0?ooo`030000003oool0oooo
04@0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3E0?ooo`400000000M0?ooo`03
0000003oool0oooo04<0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3F0?ooo`40
0000000M0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool01P3oool2000000T0oooo
00<000000?ooo`3oool0e`3oool1000000007@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00H0oooo0`0000080?ooo`800000f@3oool1000000007@3oool00`000000oooo0?ooo`10
0?ooo`800000203oool3000000P0oooo0P00003J0?ooo`400000000M0?ooo`030000003oool0oooo
03l0oooo0P0000080?ooo`<00000203oool200000=/0oooo0@00000001d0oooo00<000000?ooo`3o
ool0?P3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0=/0oooo0@00000001d0oooo
00<000000?ooo`3oool0?@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0=`0oooo
0@00000001d0oooo0P00000m0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0g03o
ool2000000007@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00H0oooo0P000009
0?ooo`030000003oool0oooo0=h0oooo0@00000001d0oooo00<000000?ooo`3oool0>P3oool20000
00P0oooo0`0000080?ooo`800000h03oool1000000007@3oool00`000000oooo0?ooo`0i0?ooo`80
0000203oool3000000P0oooo0P00003Q0?ooo`400000000M0?ooo`030000003oool0oooo03P0oooo
0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3Q0?ooo`400000000M0?ooo`030000003o
ool0oooo03L0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3R0?ooo`400000000M
0?ooo`030000003oool0oooo03H0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3S
0?ooo`400000000M0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01P3oool20000
00T0oooo00<000000?ooo`3oool0i03oool1000000007@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00H0oooo0`0000080?ooo`800000iP3oool1000000007@3oool00`000000oooo
0?ooo`0c0?ooo`800000203oool3000000P0oooo0P00003W0?ooo`400000000M0?ooo`030000003o
ool0oooo0380oooo0P0000080?ooo`<00000203oool200000>P0oooo0@00000001d0oooo00<00000
0?ooo`3oool0<@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0>P0oooo0@000000
01d0oooo00<000000?ooo`3oool0<03oool2000000P0oooo0`0000080?ooo`030000003oool0oooo
0>T0oooo0@00000001d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`80
00002@3oool00`000000oooo0?ooo`3Z0?ooo`400000000M0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool01P3oool3000000P0oooo0P00003/0?ooo`400000000M0?ooo`030000003o
ool0oooo02d0oooo0P0000080?ooo`<00000203oool200000>d0oooo0@00000001d0oooo00<00000
0?ooo`3oool0;03oool2000000P0oooo0`0000080?ooo`800000kP3oool1000000007@3oool00`00
0000oooo0?ooo`0[0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0kP3oool10000
00007@3oool2000002/0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3^0?ooo`80
0000000M0?ooo`030000003oool0oooo02T0oooo0P0000080?ooo`<00000203oool00`000000oooo
0?ooo`3`0?ooo`400000000M0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3o
ool2000000T0oooo00<000000?ooo`3oool0l@3oool1000000007@3oool00`000000oooo0?ooo`0W
0?ooo`800000203oool3000000P0oooo0P00003c0?ooo`400000000M0?ooo`030000003oool0oooo
02H0oooo0P0000080?ooo`<00000203oool200000?@0oooo0@00000001d0oooo00<000000?ooo`3o
ool09@3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0?@0oooo0@00000001d0oooo
00<000000?ooo`3oool0903oool2000000P0oooo0`0000080?ooo`030000003oool0oooo0?D0oooo
0@00000001d0oooo00<000000?ooo`3oool08`3oool2000000P0oooo0`0000080?ooo`030000003o
ool0oooo0?H0oooo0@00000001d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`06
0?ooo`8000002@3oool00`000000oooo0?ooo`3g0?ooo`400000000M0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01P3oool3000000P0oooo0P00003i0?ooo`400000000M0?ooo`03
0000003oool0oooo0200oooo0P0000080?ooo`<00000203oool200000?X0oooo0@00000001d0oooo
00<000000?ooo`3oool07`3oool2000000P0oooo0`0000080?ooo`800000n`3oool1000000007@3o
ool00`000000oooo0?ooo`0N0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0n`3o
ool1000000007@3oool00`000000oooo0?ooo`0M0?ooo`800000203oool3000000P0oooo00<00000
0?ooo`3oool0o03oool1000000007@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00H0oooo0P0000090?ooo`030000003oool0oooo0?d0oooo0@00000001d0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`060?ooo`<00000203oool200000?l0oooo0@00000001d0oooo
00<000000?ooo`3oool06P3oool2000000P0oooo0`0000080?ooo`800000o`3oool10?ooo`400000
000M0?ooo`030000003oool0oooo01T0oooo0P0000080?ooo`<00000203oool200000?l0oooo0P3o
ool1000000007@3oool2000001T0oooo0P0000080?ooo`<00000203oool00`000000oooo0?ooo`3o
0?ooo`40oooo0P00000001d0oooo00<000000?ooo`3oool05`3oool2000000P0oooo0`0000080?oo
o`030000003oool0oooo0?l0oooo0`3oool1000000007@3oool00`000000oooo0?ooo`0F0?ooo`80
0000203oool3000000P0oooo00<000000?ooo`3oool0o`3oool40?ooo`400000000M0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0
o`3oool50?ooo`400000000M0?ooo`030000003oool0oooo01@0oooo0P0000080?ooo`<00000203o
ool200000?l0oooo1`3oool1000000007@3oool00`000000oooo0?ooo`0C0?ooo`800000203oool3
000000P0oooo0P00003o0?ooo`P0oooo0@00000001d0oooo00<000000?ooo`3oool04P3oool20000
00P0oooo0`0000080?ooo`030000003oool0oooo0?l0oooo203oool1000000007@3oool00`000000
oooo0?ooo`0A0?ooo`800000203oool3000000P0oooo00<000000?ooo`3oool0o`3oool90?ooo`40
0000000M0?ooo`030000003oool0oooo0100oooo0P0000080?ooo`<00000203oool00`000000oooo
0?ooo`3o0?ooo`X0oooo0@00000001d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`060?ooo`8000002@3oool00`000000oooo0?ooo`3o0?ooo`/0oooo0@00000001d0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`<00000203oool200000?l0oooo3@3oool1
000000007@3oool00`000000oooo0?ooo`0=0?ooo`800000203oool3000000P0oooo0P00003o0?oo
o`h0oooo0@00000001d0oooo00<000000?ooo`3oool0303oool2000000P0oooo0`0000080?ooo`80
0000o`3oool?0?ooo`400000000M0?ooo`030000003oool0oooo00/0oooo0P0000080?ooo`<00000
203oool00`000000oooo0?ooo`3o0?ooo`l0oooo0@00000000@0oooo00D0okmd0000000000000018
09cOo`020?ooo`050?oo_`1d000000000018W03Oool00P3oool01@3ookl0M00000000000B9`0gooo
00H0oooo00<000000?ooo`3oool02P3oool2000000P0oooo0`0000080?ooo`030000003oool0oooo
0?l0oooo403oool1000000000`3oool0503ogi`0B01809cOo`3oool0okmd0000M02oool0oooO09a8
0018W=l0oooo0=nLB000M;l0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo1P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo0?l0oooo
4@3oool1000000000`3oool05@3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0oono07@0M02oool0
oooo0?oOW01807@0_ooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool3000000P0oooo0P00003o0?oooa<0oooo0@000000
00<0oooo01D0omnL04P0B02Lgol0oooo0?noM00007@0_ooo0?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool3000000L0oooo0P0000080?ooo`<0
0000203oool200000?l0oooo4P3oool300000000103oool0503ookl0M00000000000B9`0gooo0?oo
o`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo1@3o
ool00`000000oooo0?ooo`060?ooo`800000203oool3000000P0oooo0P00003o0?oooaD0oooo0@00
000000<0oooo01D0oono07@0B02Lgol0oooo0=nLB000B9`0gooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`050?oo
o`800000203oool3000000P0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`40000000030?ooo`0E
0?oOW018B9`0gooo0?ooo`3ookl0M01d0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0oono
07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool0103oool2000000P0oooo
0`0000080?ooo`030000003oool0oooo0?l0oooo5P3oool1000000000`3oool0503ookl0M01809cO
o`3oool0gia80018W03Oool0oooO09a8001d_ol0oooo0=nLB000M;l0oooo0?oog`2LB000M;oo0?oo
o`3OW4P007Bo1P3oool00`000000oooo0?ooo`030?ooo`800000203oool3000000P0oooo00<00000
0?ooo`3oool0o`3ooolG0?ooo`40000000040?ooo`050?oOW018000000000000M02oool00P3oool0
1@3ookl0M00000000000B9`0gooo0080oooo00D0oono07@00000000004RL0=ooo`060?ooo`030000
003oool0oooo00`0oooo0P0000090?ooo`030000003oool0oooo0?l0oooo603oool1000000007@3o
ool00`000000oooo0?ooo`0;0?ooo`<00000203oool200000?l0oooo6P3oool1000000007@3oool0
0`000000oooo0?ooo`0:0?ooo`<00000203oool200000?l0oooo6`3oool1000000007@3oool00`00
0000oooo0?ooo`090?ooo`<00000203oool00`000000oooo0?ooo`3o0?oooa/0oooo0@00000001d0
oooo00<000000?ooo`3oool0203oool3000000P0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`40
0000000M0?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`030000003oool0oooo0?l0oooo
7@3oool1000000007@3oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?oo
o`3o0?oooah0oooo0@00000001d0oooo00<000000?ooo`3oool01@3oool3000000P0oooo0P00003o
0?ooob00oooo0@00000001d0oooo00<000000?ooo`3oool0103oool3000000P0oooo0P00003o0?oo
ob40oooo0@00000001d0oooo00<000000?ooo`3oool00`3oool3000000P0oooo0P00003o0?ooob80
oooo0@00000001d0oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3oool0
o`3ooolR0?ooo`400000000M0?ooo`030000003oool0oooo0?l0oooo<P3oool1000000007@3oool0
0`000000oooo0?ooo`3o0?oooc80oooo0@00000001d0oooo0P00003o0?oooc80oooo0P00000001d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00@00000001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00@00000001d0ooooo`00
000f00000000o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 337.813}, {337.813, 0}} -> {-101.548, -88.2287, \
4.26229, 4.26229}}]
}, Open  ]],

Cell["\<\
The most exciting part though is that you can do some really large scale \
linear algebra. \
\>", "MathCaption"],

Cell[BoxData[
    \(\(n = 10\^5;\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(A\  = \ 
      SparseArray[\ {{i_, \ j_}\  /; \ 
              Abs[i - j] \[LessEqual] 1\  \[RuleDelayed] \ Random[]}, \ {n, 
          n}]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          
          InterpretationBox[\("<"\[InvisibleSpace]299998\[InvisibleSpace]">"\)\
,
            SequenceForm[ "<", 299998, ">"],
            Editable->False], ",", \({100000, 100000}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[BoxData[
    \(\(b\  = \ Table[\ Random[], \ {n}];\)\)], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
Notice the big difference in size between sparse and dense representations. \
In this case 80 gigabytes would have been needed just to store the matrix. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sparseMemory\  = \ N[\ ByteCount[\ A\ ]\ ]\ Byte\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(4.000352`*^6\ Byte\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(denseMemory\  = \ N[\ 10\^5\ 10\^5\ 8\ ]\ Byte\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(8.`*^10\ Byte\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["\<\
Now we can use these large matrices to solve truly large problems.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\ \(LinearSolve[\ A, \ b\ ];\)\ ]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({0.8810000000000002`\ Second, Null}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\ \(A . A;\)\ ]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({0.04999999999999982`\ Second, Null}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Other Optimization and Equation Solving Functionality", "Section"],

Cell[CellGroupData[{

Cell["FindMinimum / FindMaximum", "Subsection"],

Cell["Supports general array variables", "BulletText"],

Cell["New and improved methods; better for large scale problems", "BulletText"],

Cell[CellGroupData[{

Cell["Example: Computing a Matrix Norm", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell["In this case we are using a vector variable.", "MathCaption"],

Cell[BoxData[
    \(\(A\  = \ {{1, 2}, \ {3, 4}};\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMaximum[\ Norm[A . x, \ 4]/Norm[x, 4], \ {x, \ {1, 1}}]\)], "Input",\

  CellLabel->"In[40]:="],

Cell[BoxData[
    \({5.957344304139015`, {x \[Rule] {0.9497993444847234`, 
            1.049948744337927`}}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFit", "Subsection"],

Cell[TextData[{
  "New function for curve fitting. Supersedes ",
  StyleBox["Fit", "MR"],
  " and ",
  StyleBox["NonlinearFit", "MR"]
}], "BulletText"],

Cell["Supports general array variables", "BulletText"],

Cell[CellGroupData[{

Cell["Example: Fitting a Circle", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell["Suppose we are taking measurements along a circle. ", "MathCaption"],

Cell[BoxData[
    \(data = 
      Table[{Cos[t] + 5, Sin[t] + 15, 0. } + 
          Random[Real, {\(-0.05\), 0.05}], {t, 0. , 2\ \[Pi], 
          0.01}]; \)], "Input",
  CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(dg = 
      ListPlot[Take[data, All, 2], Frame \[Rule] True, PlotStyle \[Rule] Red, 
        AspectRatio \[Rule] Automatic]; \)], "Input",
  CellLabel->"In[42]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99753 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.78338 0.456318 -6.3461 0.456318 [
[.04189 -0.0125 -4.21875 -10.9375 ]
[.04189 -0.0125 4.21875 0 ]
[.27005 -0.0125 -7.5625 -10.9375 ]
[.27005 -0.0125 7.5625 0 ]
[.49821 -0.0125 -4.21875 -10.9375 ]
[.49821 -0.0125 4.21875 0 ]
[.72637 -0.0125 -7.5625 -10.9375 ]
[.72637 -0.0125 7.5625 0 ]
[.95453 -0.0125 -4.21875 -10.9375 ]
[.95453 -0.0125 4.21875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04235 -12.875 -5.46875 ]
[-0.0125 .04235 0 5.46875 ]
[-0.0125 .27051 -19.5625 -5.46875 ]
[-0.0125 .27051 0 5.46875 ]
[-0.0125 .49867 -12.875 -5.46875 ]
[-0.0125 .49867 0 5.46875 ]
[-0.0125 .72683 -19.5625 -5.46875 ]
[-0.0125 .72683 0 5.46875 ]
[-0.0125 .95499 -12.875 -5.46875 ]
[-0.0125 .95499 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 .99753 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .99753 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04189 0 m
.04189 .00625 L
s
gsave
.04189 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.27005 0 m
.27005 .00625 L
s
gsave
.27005 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
.49821 0 m
.49821 .00625 L
s
gsave
.49821 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.72637 0 m
.72637 .00625 L
s
gsave
.72637 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
1.000 setlinewidth
grestore
.95453 0 m
.95453 .00625 L
s
gsave
.95453 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.08753 0 m
.08753 .00375 L
s
.13316 0 m
.13316 .00375 L
s
.17879 0 m
.17879 .00375 L
s
.22442 0 m
.22442 .00375 L
s
.31568 0 m
.31568 .00375 L
s
.36132 0 m
.36132 .00375 L
s
.40695 0 m
.40695 .00375 L
s
.45258 0 m
.45258 .00375 L
s
.54384 0 m
.54384 .00375 L
s
.58948 0 m
.58948 .00375 L
s
.63511 0 m
.63511 .00375 L
s
.68074 0 m
.68074 .00375 L
s
.772 0 m
.772 .00375 L
s
.81763 0 m
.81763 .00375 L
s
.86327 0 m
.86327 .00375 L
s
.9089 0 m
.9089 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04235 m
.00625 .04235 L
s
gsave
-0.0125 .04235 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
0 .27051 m
.00625 .27051 L
s
gsave
-0.0125 .27051 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.5) show
1.000 setlinewidth
grestore
0 .49867 m
.00625 .49867 L
s
gsave
-0.0125 .49867 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .72683 m
.00625 .72683 L
s
gsave
-0.0125 .72683 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.5) show
1.000 setlinewidth
grestore
0 .95499 m
.00625 .95499 L
s
gsave
-0.0125 .95499 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08798 m
.00375 .08798 L
s
0 .13361 m
.00375 .13361 L
s
0 .17925 m
.00375 .17925 L
s
0 .22488 m
.00375 .22488 L
s
0 .31614 m
.00375 .31614 L
s
0 .36177 m
.00375 .36177 L
s
0 .4074 m
.00375 .4074 L
s
0 .45304 m
.00375 .45304 L
s
0 .5443 m
.00375 .5443 L
s
0 .58993 m
.00375 .58993 L
s
0 .63556 m
.00375 .63556 L
s
0 .6812 m
.00375 .6812 L
s
0 .77246 m
.00375 .77246 L
s
0 .81809 m
.00375 .81809 L
s
0 .86372 m
.00375 .86372 L
s
0 .90935 m
.00375 .90935 L
s
.25 Mabswid
0 0 m
0 .99753 L
s
.04189 .99128 m
.04189 .99753 L
s
.27005 .99128 m
.27005 .99753 L
s
.49821 .99128 m
.49821 .99753 L
s
.72637 .99128 m
.72637 .99753 L
s
.95453 .99128 m
.95453 .99753 L
s
.125 Mabswid
.08753 .99378 m
.08753 .99753 L
s
.13316 .99378 m
.13316 .99753 L
s
.17879 .99378 m
.17879 .99753 L
s
.22442 .99378 m
.22442 .99753 L
s
.31568 .99378 m
.31568 .99753 L
s
.36132 .99378 m
.36132 .99753 L
s
.40695 .99378 m
.40695 .99753 L
s
.45258 .99378 m
.45258 .99753 L
s
.54384 .99378 m
.54384 .99753 L
s
.58948 .99378 m
.58948 .99753 L
s
.63511 .99378 m
.63511 .99753 L
s
.68074 .99378 m
.68074 .99753 L
s
.772 .99378 m
.772 .99753 L
s
.81763 .99378 m
.81763 .99753 L
s
.86327 .99378 m
.86327 .99753 L
s
.9089 .99378 m
.9089 .99753 L
s
.25 Mabswid
0 .99753 m
1 .99753 L
s
.99375 .04235 m
1 .04235 L
s
.99375 .27051 m
1 .27051 L
s
.99375 .49867 m
1 .49867 L
s
.99375 .72683 m
1 .72683 L
s
.99375 .95499 m
1 .95499 L
s
.125 Mabswid
.99625 .08798 m
1 .08798 L
s
.99625 .13361 m
1 .13361 L
s
.99625 .17925 m
1 .17925 L
s
.99625 .22488 m
1 .22488 L
s
.99625 .31614 m
1 .31614 L
s
.99625 .36177 m
1 .36177 L
s
.99625 .4074 m
1 .4074 L
s
.99625 .45304 m
1 .45304 L
s
.99625 .5443 m
1 .5443 L
s
.99625 .58993 m
1 .58993 L
s
.99625 .63556 m
1 .63556 L
s
.99625 .6812 m
1 .6812 L
s
.99625 .77246 m
1 .77246 L
s
.99625 .81809 m
1 .81809 L
s
.99625 .86372 m
1 .86372 L
s
.99625 .90935 m
1 .90935 L
s
.25 Mabswid
1 0 m
1 .99753 L
s
0 0 m
1 0 L
1 .99753 L
0 .99753 L
closepath
clip
newpath
1 0 0 r
.008 w
.96959 .51373 Mdot
.93183 .48056 Mdot
.96336 .51671 Mdot
.96458 .52262 Mdot
.97019 .53294 Mdot
.94393 .51144 Mdot
.94343 .51575 Mdot
.94884 .52601 Mdot
.95853 .5406 Mdot
.96391 .55091 Mdot
.94223 .5342 Mdot
.93047 .52746 Mdot
.94857 .55062 Mdot
.94767 .55481 Mdot
.93353 .54581 Mdot
.92943 .54689 Mdot
.93749 .56016 Mdot
.94974 .57766 Mdot
.94887 .58207 Mdot
.96388 .60241 Mdot
.92807 .57196 Mdot
.94366 .59295 Mdot
.92816 .58288 Mdot
.94584 .60602 Mdot
.93184 .59753 Mdot
.93936 .61058 Mdot
.93772 .61451 Mdot
.95388 .63626 Mdot
.93395 .62196 Mdot
.92171 .61539 Mdot
.92015 .61952 Mdot
.93041 .63551 Mdot
.94591 .65675 Mdot
.92773 .64436 Mdot
.94724 .66968 Mdot
.92299 .65126 Mdot
.91968 .65382 Mdot
.90167 .6417 Mdot
.93454 .68048 Mdot
.91354 .66544 Mdot
.9013 .65916 Mdot
.91576 .67961 Mdot
.9029 .67277 Mdot
.91152 .68743 Mdot
.88841 .67037 Mdot
.93181 .71986 Mdot
.88768 .68183 Mdot
.92308 .72335 Mdot
.91273 .71915 Mdot
.90171 .7143 Mdot
.90354 .72231 Mdot
.87579 .70076 Mdot
.88397 .71516 Mdot
.88376 .72118 Mdot
.88566 .72933 Mdot
.89175 .74169 Mdot
.88286 .73909 Mdot
.89921 .76174 Mdot
.87994 .74878 Mdot
.86296 .73812 Mdot
.85564 .73714 Mdot
.88822 .77607 Mdot
.87989 .7741 Mdot
.88204 .78261 Mdot
.88506 .79202 Mdot
.8556 .76895 Mdot
.85815 .77789 Mdot
.84964 .77579 Mdot
.87371 .80628 Mdot
.84438 .78336 Mdot
.84327 .78869 Mdot
.84282 .79466 Mdot
.82937 .78766 Mdot
.85442 .81914 Mdot
.84918 .82035 Mdot
.8285 .80611 Mdot
.85012 .83419 Mdot
.82733 .81785 Mdot
.81774 .81471 Mdot
.8341 .83752 Mdot
.81644 .82632 Mdot
.82036 .83669 Mdot
.82742 .8502 Mdot
.81249 .84172 Mdot
.79946 .83514 Mdot
.81372 .85583 Mdot
.78072 .82928 Mdot
.80648 .86147 Mdot
.78761 .84902 Mdot
.78282 .85066 Mdot
.79002 .86427 Mdot
.77572 .85638 Mdot
.77545 .86251 Mdot
.75137 .84481 Mdot
.75664 .85646 Mdot
.78536 .89156 Mdot
.74979 .86235 Mdot
.74317 .86208 Mdot
.7505 .87575 Mdot
.75109 .88266 Mdot
.73629 .87418 Mdot
.7492 .89338 Mdot
.71721 .86767 Mdot
.74374 .90047 Mdot
.74325 .90624 Mdot
.70322 .87245 Mdot
.70638 .88183 Mdot
.69877 .88042 Mdot
.70784 .89567 Mdot
.69569 .88969 Mdot
.68268 .88282 Mdot
.69138 .89766 Mdot
.71573 .92811 Mdot
.70475 .92322 Mdot
.68091 .90543 Mdot
.70024 .93081 Mdot
.67554 .91213 Mdot
.68493 .9275 Mdot
.65206 .90061 Mdot
.68454 .93903 Mdot
.64598 .90639 Mdot
.65817 .92447 Mdot
.65976 .93193 Mdot
.64215 .92016 Mdot
.66012 .94395 Mdot
.65549 .9451 Mdot
.6395 .93487 Mdot
.63704 .93813 Mdot
.65152 .9583 Mdot
.63728 .94973 Mdot
.61411 .93219 Mdot
.61521 .9389 Mdot
.61657 .94582 Mdot
.6104 .94518 Mdot
.59614 .93643 Mdot
.58441 .93017 Mdot
.60291 .9541 Mdot
.60356 .96015 Mdot
.56333 .92529 Mdot
.57371 .94099 Mdot
.56707 .93964 Mdot
.5541 .93193 Mdot
.58813 .97118 Mdot
.56178 .95 Mdot
.54379 .93715 Mdot
.55998 .95845 Mdot
.54249 .94601 Mdot
.52942 .93797 Mdot
.53477 .94829 Mdot
.55125 .96971 Mdot
.54538 .96874 Mdot
.53042 .95863 Mdot
.5169 .94992 Mdot
.4976 .93539 Mdot
.5105 .95301 Mdot
.49003 .93721 Mdot
.51637 .96819 Mdot
.49881 .95522 Mdot
.4759 .93685 Mdot
.50833 .97378 Mdot
.46608 .93599 Mdot
.48904 .96335 Mdot
.45625 .93492 Mdot
.47383 .9568 Mdot
.47938 .96661 Mdot
.46517 .95662 Mdot
.43949 .9351 Mdot
.43329 .93301 Mdot
.45231 .9561 Mdot
.46304 .97084 Mdot
.45034 .96211 Mdot
.45269 .96836 Mdot
.41622 .93575 Mdot
.40594 .92929 Mdot
.44022 .96732 Mdot
.40737 .93817 Mdot
.42552 .95997 Mdot
.43002 .96807 Mdot
.40123 .94283 Mdot
.38434 .92942 Mdot
.41725 .96577 Mdot
.38916 .94105 Mdot
.37876 .93398 Mdot
.37054 .92903 Mdot
.39555 .95725 Mdot
.38562 .95048 Mdot
.35786 .92582 Mdot
.37319 .9442 Mdot
.34252 .91652 Mdot
.34229 .91921 Mdot
.33573 .91552 Mdot
.35278 .93538 Mdot
.34423 .9296 Mdot
.3288 .91686 Mdot
.33047 .92117 Mdot
.34071 .93399 Mdot
.31856 .91436 Mdot
.30896 .90722 Mdot
.31755 .91821 Mdot
.31059 .91359 Mdot
.3115 .91678 Mdot
.293 .9005 Mdot
.28035 .89 Mdot
.2859 .89766 Mdot
.29516 .90895 Mdot
.30039 .91616 Mdot
.29379 .91148 Mdot
.2576 .87714 Mdot
.28316 .90449 Mdot
.29402 .91708 Mdot
.26525 .88998 Mdot
.25509 .88141 Mdot
.26142 .88929 Mdot
.26827 .89762 Mdot
.24183 .87259 Mdot
.25603 .88815 Mdot
.26671 .90012 Mdot
.23918 .87381 Mdot
.25254 .88834 Mdot
.25236 .88925 Mdot
.23543 .87336 Mdot
.21339 .85229 Mdot
.21407 .85388 Mdot
.21678 .85743 Mdot
.19489 .83633 Mdot
.23295 .87511 Mdot
.19665 .83946 Mdot
.18982 .83321 Mdot
.20034 .84425 Mdot
.18359 .82797 Mdot
.1956 .84037 Mdot
.17543 .82053 Mdot
.20215 .84751 Mdot
.17069 .81626 Mdot
.16201 .80772 Mdot
.19383 .83961 Mdot
.16481 .81059 Mdot
.16838 .81411 Mdot
.18242 .82802 Mdot
.1507 .79612 Mdot
.15296 .79813 Mdot
.18042 .82527 Mdot
.17747 .82194 Mdot
.14234 .78637 Mdot
.15796 .80148 Mdot
.15829 .80124 Mdot
.15114 .79345 Mdot
.15546 .79707 Mdot
.14388 .78473 Mdot
.14836 .78838 Mdot
.12849 .76761 Mdot
.13628 .77445 Mdot
.11085 .748 Mdot
.12877 .76483 Mdot
.13925 .77416 Mdot
.11835 .75205 Mdot
.10862 .74105 Mdot
.10919 .74028 Mdot
.12521 .7549 Mdot
.11501 .74324 Mdot
.08559 .71229 Mdot
.12518 .75029 Mdot
.12415 .74761 Mdot
.09707 .71881 Mdot
.10808 .72805 Mdot
.1173 .73544 Mdot
.11636 .73259 Mdot
.07593 .6902 Mdot
.06852 .68077 Mdot
.07465 .68482 Mdot
.07812 .68614 Mdot
.07631 .68213 Mdot
.07783 .68138 Mdot
.07686 .67808 Mdot
.09762 .69645 Mdot
.08547 .68186 Mdot
.06428 .65816 Mdot
.08855 .67987 Mdot
.05076 .63946 Mdot
.05713 .64314 Mdot
.08894 .67221 Mdot
.06469 .64516 Mdot
.05424 .63185 Mdot
.06856 .64326 Mdot
.08196 .65368 Mdot
.0616 .63029 Mdot
.05006 .61566 Mdot
.04375 .60621 Mdot
.04409 .60336 Mdot
.05814 .61415 Mdot
.04559 .59829 Mdot
.03217 .5815 Mdot
.03804 .58395 Mdot
.04413 .58656 Mdot
.07194 .61085 Mdot
.05857 .59389 Mdot
.06122 .5929 Mdot
.06661 .5946 Mdot
.02642 .55066 Mdot
.06924 .58969 Mdot
.04591 .56251 Mdot
.02553 .53823 Mdot
.06729 .57605 Mdot
.05671 .56146 Mdot
.04584 .54654 Mdot
.04837 .54497 Mdot
.05368 .54612 Mdot
.02753 .51578 Mdot
.0477 .53169 Mdot
.02381 .50351 Mdot
.03955 .5149 Mdot
.06427 .53523 Mdot
.03745 .50397 Mdot
.04416 .5062 Mdot
.02589 .48339 Mdot
.06316 .51608 Mdot
.02961 .47791 Mdot
.02945 .47307 Mdot
.02823 .46715 Mdot
.03253 .46669 Mdot
.0413 .47066 Mdot
.03513 .45964 Mdot
.02791 .44754 Mdot
.03448 .44919 Mdot
.0661 .47583 Mdot
.03423 .43896 Mdot
.03049 .43016 Mdot
.0473 .44188 Mdot
.04385 .4333 Mdot
.05482 .43911 Mdot
.04555 .42463 Mdot
.04271 .41655 Mdot
.06461 .43316 Mdot
.05376 .41699 Mdot
.02872 .3866 Mdot
.04679 .39928 Mdot
.04994 .397 Mdot
.03248 .37408 Mdot
.07149 .4076 Mdot
.05249 .38307 Mdot
.0438 .36881 Mdot
.07241 .39184 Mdot
.06733 .38113 Mdot
.04442 .35256 Mdot
.073 .37545 Mdot
.06262 .35936 Mdot
.06527 .35626 Mdot
.08197 .36717 Mdot
.07953 .35894 Mdot
.05603 .3296 Mdot
.06312 .33083 Mdot
.06374 .32556 Mdot
.06553 .32144 Mdot
.07751 .32748 Mdot
.09473 .33874 Mdot
.0991 .33712 Mdot
.07996 .31196 Mdot
.10379 .32976 Mdot
.10146 .32137 Mdot
.08884 .30268 Mdot
.06768 .27542 Mdot
.11015 .31176 Mdot
.11566 .31113 Mdot
.07767 .26698 Mdot
.11215 .29528 Mdot
.08172 .25865 Mdot
.0937 .26441 Mdot
.1257 .29018 Mdot
.08744 .24567 Mdot
.11454 .2665 Mdot
.12543 .27112 Mdot
.09671 .2361 Mdot
.10817 .24125 Mdot
.11482 .24158 Mdot
.12037 .24079 Mdot
.13843 .25251 Mdot
.10428 .212 Mdot
.14645 .2478 Mdot
.13666 .23164 Mdot
.1523 .24088 Mdot
.13927 .22146 Mdot
.15963 .23541 Mdot
.15424 .22361 Mdot
.13896 .20191 Mdot
.14923 .20576 Mdot
.12931 .1794 Mdot
.16625 .20991 Mdot
.14559 .1828 Mdot
.16932 .20009 Mdot
.18216 .20648 Mdot
.16387 .18174 Mdot
.15926 .17068 Mdot
.17807 .18304 Mdot
.16631 .16482 Mdot
.18528 .17734 Mdot
.16632 .15193 Mdot
.17628 .15544 Mdot
.20613 .17884 Mdot
.17661 .14287 Mdot
.18793 .14775 Mdot
.18916 .14254 Mdot
.22526 .17221 Mdot
.20834 .14886 Mdot
.20689 .14098 Mdot
.22403 .15171 Mdot
.19707 .11834 Mdot
.23413 .14901 Mdot
.20532 .1138 Mdot
.21522 .11732 Mdot
.21124 .10697 Mdot
.21446 .10382 Mdot
.25507 .13808 Mdot
.2444 .12107 Mdot
.23077 .10112 Mdot
.2555 .11953 Mdot
.25834 .11608 Mdot
.27778 .12923 Mdot
.27924 .12442 Mdot
.28834 .12726 Mdot
.26789 .10057 Mdot
.28079 .10724 Mdot
.25583 .07608 Mdot
.29792 .11198 Mdot
.26964 .07754 Mdot
.28484 .08658 Mdot
.27296 .06858 Mdot
.28993 .07943 Mdot
.31235 .09576 Mdot
.31403 .09138 Mdot
.33278 .10409 Mdot
.31637 .08165 Mdot
.32568 .08497 Mdot
.32121 .07453 Mdot
.3477 .09507 Mdot
.33187 .07331 Mdot
.35002 .08557 Mdot
.36006 .08974 Mdot
.35841 .08224 Mdot
.36737 .08538 Mdot
.34095 .05318 Mdot
.33549 .04195 Mdot
.38196 .0827 Mdot
.3858 .08083 Mdot
.38383 .0732 Mdot
.36949 .05322 Mdot
.39933 .07745 Mdot
.36513 .03768 Mdot
.39553 .06253 Mdot
.41572 .07722 Mdot
.41592 .07194 Mdot
.41453 .06512 Mdot
.42666 .07184 Mdot
.40371 .04352 Mdot
.43498 .06946 Mdot
.40859 .03776 Mdot
.41562 .03954 Mdot
.44701 .06571 Mdot
.45605 .06956 Mdot
.44976 .05812 Mdot
.44292 .04618 Mdot
.46857 .06677 Mdot
.43795 .03112 Mdot
.47266 .06084 Mdot
.45094 .03418 Mdot
.48641 .06475 Mdot
.45931 .03279 Mdot
.49456 .06322 Mdot
.4792 .04309 Mdot
.48778 .04693 Mdot
.48088 .03535 Mdot
.50911 .05894 Mdot
.51342 .05865 Mdot
.50624 .04692 Mdot
.50359 .03977 Mdot
.49204 .02375 Mdot
.53431 .06161 Mdot
.50892 .03186 Mdot
.52511 .04373 Mdot
.54443 .05879 Mdot
.53853 .04866 Mdot
.53188 .03784 Mdot
.54353 .04537 Mdot
.52802 .02579 Mdot
.53346 .02721 Mdot
.5513 .04108 Mdot
.55246 .03831 Mdot
.55239 .03438 Mdot
.58407 .06224 Mdot
.57097 .04538 Mdot
.55811 .02881 Mdot
.57296 .04 Mdot
.57889 .04232 Mdot
.60737 .06725 Mdot
.60594 .06232 Mdot
.59708 .05002 Mdot
.60323 .05278 Mdot
.59778 .044 Mdot
.60351 .04645 Mdot
.61073 .05045 Mdot
.62475 .06131 Mdot
.64921 .08265 Mdot
.64326 .07365 Mdot
.63566 .06305 Mdot
.66008 .08453 Mdot
.65004 .07162 Mdot
.63694 .05569 Mdot
.64933 .06531 Mdot
.67278 .08606 Mdot
.64937 .06 Mdot
.6852 .09324 Mdot
.65648 .06199 Mdot
.65269 .05574 Mdot
.69245 .09308 Mdot
.69993 .09822 Mdot
.70641 .1024 Mdot
.7011 .09486 Mdot
.71677 .10836 Mdot
.68444 .07393 Mdot
.70414 .09158 Mdot
.69705 .0825 Mdot
.72251 .10604 Mdot
.73442 .11608 Mdot
.70559 .08546 Mdot
.73442 .11254 Mdot
.73973 .11618 Mdot
.71623 .09106 Mdot
.74489 .11818 Mdot
.75355 .12535 Mdot
.72749 .09786 Mdot
.76695 .13596 Mdot
.7418 .1095 Mdot
.77682 .14329 Mdot
.77834 .14363 Mdot
.74048 .10466 Mdot
.74818 .11132 Mdot
.79109 .15325 Mdot
.75695 .11819 Mdot
.76131 .1217 Mdot
.76659 .12619 Mdot
.77321 .13208 Mdot
.77304 .13125 Mdot
.81372 .17133 Mdot
.80327 .16035 Mdot
.82093 .17753 Mdot
.79921 .15542 Mdot
.78626 .14212 Mdot
.80851 .1641 Mdot
.8012 .15658 Mdot
.82364 .17887 Mdot
.83799 .19314 Mdot
.83536 .19049 Mdot
.82315 .17832 Mdot
.82975 .18503 Mdot
.80835 .16381 Mdot
.83455 .19025 Mdot
.8366 .19261 Mdot
.8453 .20168 Mdot
.86536 .22217 Mdot
.8418 .19911 Mdot
.85011 .20798 Mdot
.85084 .20934 Mdot
.87003 .22921 Mdot
.84464 .20458 Mdot
.84976 .21052 Mdot
.85406 .2157 Mdot
.88156 .24415 Mdot
.86996 .23356 Mdot
.86073 .2254 Mdot
.89001 .25582 Mdot
.88809 .2551 Mdot
.85744 .22571 Mdot
.90434 .27394 Mdot
.86869 .23969 Mdot
.90116 .27361 Mdot
.87623 .25019 Mdot
.89275 .2683 Mdot
.89916 .27634 Mdot
.91038 .28927 Mdot
.90782 .28847 Mdot
.87957 .26206 Mdot
.88015 .26453 Mdot
.91979 .30611 Mdot
.89797 .2863 Mdot
.90981 .30022 Mdot
.9124 .30494 Mdot
.88992 .28466 Mdot
.89615 .29314 Mdot
.90549 .30481 Mdot
.90637 .30806 Mdot
.90457 .3087 Mdot
.92492 .33154 Mdot
.90034 .30952 Mdot
.92 .3318 Mdot
.92253 .337 Mdot
.93025 .34745 Mdot
.90673 .32672 Mdot
.91869 .34153 Mdot
.93662 .36237 Mdot
.92585 .35457 Mdot
.9336 .36534 Mdot
.94128 .3761 Mdot
.95008 .38803 Mdot
.94392 .38506 Mdot
.93629 .38067 Mdot
.94535 .39304 Mdot
.96207 .41311 Mdot
.93398 .38844 Mdot
.96198 .4199 Mdot
.92462 .38607 Mdot
.96558 .4306 Mdot
.93298 .40163 Mdot
.9533 .42563 Mdot
.96233 .4384 Mdot
.96104 .4409 Mdot
.95528 .43898 Mdot
.95605 .44364 Mdot
.94688 .43841 Mdot
.94449 .44001 Mdot
.93238 .43194 Mdot
.95801 .46166 Mdot
.93816 .44596 Mdot
.96471 .47671 Mdot
.96457 .48081 Mdot
.93798 .45851 Mdot
.9572 .48207 Mdot
.97603 .50528 Mdot
.93744 .47112 Mdot
.9651 .50326 Mdot
.97619 .51888 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  ImageSize->{288, 287.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001[R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00<P3oool00`3ooml0W4P007Boo`1C0?ooo`090?oog`2LB000M;oo0?ooo`3ogi`0B01d0;oo
o`3oool0gia80080000000<0001809cOo`3oool0C`3oool01@3OW4P000000000000004P0W=oo0500
oooo00/0gia8000000000000001809cOo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000
B02Lgol0oooo0500oooo00D0oono07@000000000001d0;ooo`0A0?ooo`00<P3oool00`3ooml0W4P0
07Boo`1C0?ooo`030?oog`2LB000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo
04h0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo04h0oooo00L0okmd0018W03Oool0oooo
0?oog`2LB7@0_ooo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo0500oooo00H0_g@0
07Boo`3oool0omnL04Q8W03Oool@0?ooo`00;`3oool00`3OW4P00000000000030000000304RLg`3o
ool0oooo04d0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`060?ooo`030;md001d
_ol0oooo0580oooo00<0_g@007Boo`3oool0DP3oool00`2oM000M;oo0?ooo`070?ooo`030;md001d
_ol0oooo04h0oooo00L0oono07A8W03Oool0oooo0?oo_`1d04P0W=oo0100oooo000_0?ooo`060?oO
W018B9`0gooo0?oog`2LB000M;ooD03oool01P3ogi`0B4RL0=ooo`3ooml0W4P007Boo`T0oooo00<0
_g@007Boo`3oool0DP3oool00`2oM000M;oo0?ooo`1B0?ooo`030;md001d_ol0oooo00L0oooo00<0
_g@007Boo`3oool0CP3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0403oool00300oooo
00D0gia804RLg`3ooml0W4P007Boo`1A0?ooo`050=nLB018W=l0oooO09a8001d_ol0103oool01`3o
gi`0B01809cOo`3oool0oooO09a8B02Lgol0CP3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02L
gol0CP3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol00`3oool01`3ogi`0B01809cOo`3o
ool0oooO09a8B02Lgol0C`3oool01`3ogi`0B00007Boo`3oool0omnL04Q8W03Oool0403oool00300
oooo00D0oooO09a8B02Lgml0W4P007Boo`1A0?ooo`050?oog`2LB4P0W=oO09a8001d_ol0103oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo04d0oooo00<0oono07@0000000000P000000
0`1d_ol0oooo0?ooo`1=0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool00P3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo04h0oooo00H0omnL04Q8W02LM00000000000
B02LgolA0?ooo`00<@3oool0103ogi`0B4Qd07A8001d_omB0?ooo`040?oOW018B7@0M4P007Boo`@0
oooo00<0oooO09a8B02Lgol0DP3oool00`3ooml0W4Q809cOo`1B0?ooo`030?oog`2LB4P0W=oo00L0
oooo00<0oooO09a8B02Lgol0D`3oool00`3ookl0M01d0;ooo`0D0?ooo`00<P3oool00`3OW4P00000
07Boo`1C0?ooo`030=nLB0000000M;oo00D0oooo00<0_g@007Boo`3oool0DP3oool00`2oM000M;oo
0?ooo`1B0?ooo`030;md001d_ol0oooo00L0oooo00<0_g@007Boo`3oool0D`3oool01P2oM000M;oo
0?ooo`3o_g@004RL0=oooa00oooo000b0?ooo`030?oog`2LB000M;oo05<0oooo00<0oooO09a8001d
_ol01@3oool01P3OW4P00000000000000000001d0;ooodl0oooo00H0gia800000000000000000000
M02ooom?0?ooo`060=nLB000000000000000000007@0_ooo103oool01P3OW4P00000000000000000
001d0;oooe00oooo00D0oooO09a800000000001809cOo`0A0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`008P3ooooo000008h000000@3oool00280oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool100000040
oooo000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool03`3oool100000040oooo000R
0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo
0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003o
ool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo0<00oooo00<0o`00
0?ooo`3oool0aP3oool100000040oooo000R0?ooo`030000003oool0oooo0;l0oooo0`3o000<0?oo
o`030?l0003oool0o`000;P0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`300?ooo`03
0?l0003oool0oooo00X0oooo1@3o00080?ooo`030?l0003oool0oooo0:`0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`2Z0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?l000080?ooo`<0o`00[@3oool100000040oooo000R0?ooo`030000003o
ool0oooo0:T0oooo0`3o00040?ooo`040?l0003oool0oooo0?l00180oooo0`3o000?0?ooo`030?l0
003oool0o`000:h0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2L
B000M;oo00P0oooo00<000000?ooo`3oool0SP3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo0080oooo1P3o00060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3o
ool30?l00:l0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2LB000
M;oo00P0oooo00<000000?ooo`3oool0S@3oool30?l000l0oooo00@0o`000?ooo`3oool0o`003@3o
ool0103o0000oooo0?ooo`3o00060?ooo`<0o`001`3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2V0?ooo`400000
0@3oool00100oooo00D0omnL04P0M02oool0oooo0=nLB0050000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0PP3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00d0oooo
1P3o000G0?ooo`030?l0003oool0oooo00D0oooo0`3o00090?ooo`<0o`001@3oool30?l000D0oooo
103o002V0?ooo`4000000@3oool00100oooo00X0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?oo
g`2LB000M;oo203oool300000840oooo0`3o000I0?ooo`030?l0003oool0o`000080oooo00<0o`00
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00@0o`00
0?ooo`3oool0o`001@3oool30?l000L0oooo103o00060?ooo`030?l0003oool0oooo09X0oooo0`00
00010?ooo`00403oool00`3ogi`0B01d0;ooo`020?ooo`050=nLB018W=l0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`220?ooo`030?l0003oool0oooo01L0oooo0`3o000=0?ooo`030?l0003o
ool0oooo00/0oooo0`3o00000`3oool0o`000?ooo`050?ooo`030?l0003oool0oooo00@0oooo0`3o
00050?ooo`040?l0003oool0oooo0?l000L0oooo00@0o`000?ooo`3oool0o`001P3oool40?l009`0
oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`020?ooo`050?oog`2LB4P0W=oO09a8001d
_ol0203oool00`000000oooo0?ooo`2M0?ooo`030?l0003oool0oooo00/0oooo0`3o000=0?ooo`03
0?l0003oool0o`000080o`00103oool30?l000H0oooo00<0o`000?ooo`3oool00P3oool40?l000P0
oooo0`3o00080?ooo`D0o`00V`3oool100000040oooo000>0?ooo`050;md000004P0W;nL04P0M02o
ool00`3oool0103ogi`0B4Qd07A8001d_ol80?ooo`030000003oool0oooo0:`0oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo103o000:0?oo
o`030?l0003oool0oooo00H0oooo0`3o00001@3oool0o`000?ooo`3oool0o`0009T0oooo0@000001
0?ooo`003`3oool0103o_g@000000000M02oool40?ooo`030=nLB0000000M;oo00P0oooo00<00000
0?ooo`3oool0Q03oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0400oooo00<0o`00
0?ooo`3oool0503oool00`3o0000oooo0?l000050?l009P0oooo0@0000010?ooo`00403oool00`3o
gi`0B01d0;ooo`040?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0P`3oool30?l0
00P0oooo0`3o001K0?ooo`040?l0003oool0oooo0?l000T0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`260?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0Q03oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool05@3oool20?l0
00`0oooo00<0o`000?ooo`3oool0803oool30?l000<0oooo103o00270?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0VP3oool00`3o0000oooo0?ooo`0A0?ooo`<0o`001`3oool00`3o0000
oooo0?ooo`0;0?ooo`@0o`001`3oool00`3o0000oooo0?ooo`030?l000d0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3o
ool0oooo1@3o00270?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0V@3oool30?l000D0
oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`<0o`00103oool0103o0000
oooo0?ooo`3o00050?ooo`80o`001`3oool30?l00080oooo00<0o`000?ooo`3oool02`3oool30?l0
00H0oooo0`3o00040?ooo`<0o`000`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`00
0080o`00QP3oool100000040oooo000R0?ooo`030000003oool0oooo09X0oooo00<0o`000?ooo`3o
ool00`3oool30?l000/0oooo00<0o`000?ooo`3oool01P3oool20?l000@0oooo1P3o000>0?ooo`03
0?l0003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool20?l000D0oooo00@0o`000?ooo`3o
ool0oooo0`3o00020?ooo`<0o`0000<0oooo0?l0003oool0QP3oool100000040oooo000R0?ooo`03
0000003oool0oooo06T0oooo00<0o`000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?ooo`<0o`000P3oool0103o0000oooo0?ooo`3oool30?l000D0oooo00@0o`00
0?ooo`3oool0o`00:`3oool30?l000T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`280?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0J03oool30?l003L0oooo00H0o`00
0?ooo`3oool0oooo0?l0003oool30?l000<0oooo00<0o`000?ooo`3oool00`3o00030?ooo`030?l0
003oool0oooo03@0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`280?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0@0?ooo`050?l0003o
ool0oooo0?ooo`3o0000503oool00`3o0000oooo0?ooo`090?ooo`<0o`0000H0oooo0?l0003o0000
o`000?ooo`3o00080?ooo`030?l0003oool0oooo04L0oooo103o000<0?ooo`030?l0003oool0oooo
07X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1R0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0403oool30?l000040?ooo`3o0000o`000?l00180oooo0`3o00040?oo
o`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0001D0?ooo`@0o`00303oool3
0?l007/0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1Q0?ooo`<0o`000`3oool30?l0
00H0oooo00<0o`000?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0o`0001@0oooo00<0o`00
0?ooo`3oool00P3oool30?l000@0oooo0`3o001H0?ooo`030?l0003oool0oooo00d0oooo00<0o`00
0?ooo`3oool0NP3oool100000040oooo000R0?ooo`030000003oool0oooo0680oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`<0o`00203oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo05T0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`1e0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0L03oool00`3o0000oooo0?ooo`060?ooo`<0
o`000P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0o`000080o`0000<0oooo0?l0003o
ool00`3oool50?l006D0oooo0`3o00020?ooo`030?l0003oool0oooo00/0oooo0`3o00020?ooo`03
0?l0003oool0oooo0740oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1^0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3o00070?ooo`<0o`0000<0oooo0?l0003oool0
0`3o00040?ooo`030?l0003oool0o`0006L0oooo00<0o`000?ooo`3oool00`3o00040?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o001b0?ooo`4000000@3oool00280oooo0P00
001^0?ooo`<0o`003P3oool00`3o0000oooo0?ooo`070?ooo`070?l0003oool0oooo0?ooo`3o0000
oooo0?l0001c0?ooo`030?l0003oool0oooo0080oooo0`3o000;0?ooo`030?l0003oool0oooo0700
oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`1^0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool03`3oool30?l007X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0K@3oool100000040oooo
000R0?ooo`030000003oool0oooo07P0oooo0`3o000<0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0O@3oool00`3o0000oooo0?l000020?l00080oooo0`3o00020?ooo`<0o`00KP3o
ool100000040oooo000R0?ooo`030000003oool0oooo07T0oooo00<0o`000?ooo`3oool02P3oool3
0?l00880oooo0`3o0000103oool0o`000?ooo`3oool30?l000@0oooo00D0o`000?ooo`3oool0oooo
0?l0001[0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0I`3oool00`3o0000oooo0?oo
o`0>0?ooo`<0o`00303oool00`3o0000oooo0?ooo`220?ooo`030?l0003oool0oooo0080oooo0`3o
00080?ooo`<0o`00JP3oool100000040oooo000R0?ooo`030000003oool0oooo05P0oooo00<0o`00
0?ooo`3oool02`3oool30?l00100oooo00<0o`000?ooo`3oool0UP3oool0103o0000oooo0?ooo`3o
00070?ooo`030?l0003oool0oooo06T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1B
0?ooo`030?l0003oool0oooo0080oooo0`3o000=0?ooo`030?l0003oool0oooo01L0oooo00<0o`00
0?ooo`3oool0T03oool30?l000/0oooo00<0o`000?ooo`3oool0I03oool100000040oooo000R0?oo
o`030000003oool0oooo0500oooo103o00040?ooo`030?l0003oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool30?l00980oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`<0o`00I@3oool100000040oooo000R0?ooo`030000003oool0oooo04l0oooo103o000H0?ooo`<0
o`004`3oool00`3o0000oooo0?ooo`2E0?ooo`@0o`001@3oool20?l006D0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?ooo`2R0?ooo`@0o`00103oool00`3o0000oooo0?l000030?l006<0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0240oooo0`3o
002T0?ooo`030?l0003oool0oooo00<0oooo0`3o00000`3oool0o`000?l000020?l00680oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0o`000080o`000P3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0ZP3oool0
103o0000oooo0?l0003oool20?l000<0oooo00<0o`000?ooo`3oool0G@3oool100000040oooo000R
0?ooo`030000003oool0oooo04X0oooo0`3o0000103oool0o`000?ooo`3oool30?l000h0oooo0`3o
002j0?ooo`L0o`000P3oool30?l005h0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1;
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`03
0?l00;`0oooo00D0o`000?ooo`3o0000oooo0?l000040?ooo`030?l0003oool0o`0005d0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`1M0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo0;X0oooo00<0o`000?ooo`3o00000P3o001L0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0GP3oool00`3o0000oooo0?ooo`090?ooo`<0o`000P3oool00`3o
0000oooo0?ooo`2e0?ooo`<0o`0000@0oooo0?l0003oool0o`00F`3oool100000040oooo000R0?oo
o`030000003oool0oooo06/0oooo00<0o`000?ooo`3oool00`3o002g0?ooo`040?l0003oool0oooo
0?ooo`<0o`00FP3oool100000040oooo000R0?ooo`030000003oool0oooo06X0oooo0`3o00020?oo
o`030?l0003oool0oooo0;/0oooo00<0o`000?ooo`3o0000F@3oool100000040oooo000R0?ooo`80
0000K03oool00`3o0000oooo0?ooo`2o0?ooo`@0o`00E`3oool200000040oooo000R0?ooo`030000
003oool0oooo0680oooo00<0o`000?ooo`3oool0a`3oool40?l005T0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo00l0oooo0`3o00390?ooo`030?l0003o
ool0oooo05T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool30?l00140oooo00<0o`000?ooo`3oool0c03oool0
1@3o0000oooo0?ooo`3oool0o`0005<0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`12
0?ooo`<0o`000P3oool30?l000D0oooo00<0o`000?ooo`3oool0gP3oool30?l000040?ooo`3o0000
o`000?l00580oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`130?ooo`040?l0003oool0
oooo0?ooo`80o`00j03oool01@3o0000oooo0?ooo`3oool0o`0005<0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`160?ooo`<0o`001P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo0?l0oooo;@3oool100000040oooo000R0?ooo`030000003oool0oooo03l0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`<0o`001@3oool00`3o0000oooo0?ooo`03
0?l00=X0oooo00<0o`000?ooo`3oool0D03oool100000040oooo000R0?ooo`030000003oool0oooo
03h0oooo0`3o00020?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool30?l0
0080oooo00<0o`000?ooo`3oool0f03oool30?l00080oooo00<0o`000?ooo`3oool0C03oool10000
0040oooo000R0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool00`3o000A0?ooo`03
0?l0003oool0oooo0=d0oooo00<0o`000?ooo`3oool00`3o001=0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`3c0?ooo`<0o`00C@3oool100000040oooo
000R0?ooo`030000003oool0oooo0?l0oooo>`3oool40?l004/0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0?T0oooo103o001:0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0?P3oool30?l00?/0oooo0`3o001:0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0?03oool0103o0000oooo0?ooo`3o003m0?ooo`030?l0003oool0o`00
04T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`<0o`00603oool00`3o0000
oooo0?ooo`3U0?ooo`<0o`00B03oool100000040oooo000R0?ooo`030000003oool0oooo03`0oooo
00<0o`000?ooo`3oool05P3oool30?l00>L0oooo00<0o`000?ooo`3oool0A`3oool100000040oooo
000R0?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo0>T0oooo0P3o00150?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0B0?ooo`<0o`001@3oool30?l00?40oooo103o0014
0?ooo`4000000@3oool00280oooo0P00000`0?ooo`<0o`00103oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`3a
0?ooo`80o`00A03oool200000040oooo000R0?ooo`030000003oool0oooo0300oooo00<0o`000?oo
o`3oool00P3oool30?l000D0oooo0`3o00020?ooo`<0o`00o`3oool20?ooo`030?l0003oool0oooo
0400oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooo`<0o`00@@3oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooA`3oool00`3o0000oooo0?l000100?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom80?ooo`<0o`00?`3oool100000040oooo000R
0?ooo`030000003oool0oooo0?l0ooooB03oool40?l003h0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo0P3o00000`3oool0o`000?ooo`0l0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`3o0?ooo`P0oooo0`3o000l0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool0=03oool00`3o0000oooo0?ooo`080?ooo`<0o`00
o`3oool:0?ooo`80o`00?03oool100000040oooo000R0?ooo`030000003oool0oooo03<0oooo0`3o
00020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`3o0?ooo`@0oooo0`3o000k0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0=03oool0
0`3o0000oooo0?ooo`030?l000X0oooo0`3o003o0?ooo`D0oooo103o000j0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0o`3oool50?ooo`@0o`00>@3oool100000040oooo000R0?ooo`03
0000003oool0oooo02H0oooo00<0o`000?ooo`3oool05@3oool30?l00?l0oooo3@3oool30?l003T0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0U0?ooo`<0o`005`3oool00`3o0000oooo
0?ooo`3o0?ooo`d0oooo0P3o000i0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`3o0?ooobH0oooo0`3o000h0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0=03oool00`3o0000oooo0?ooo`3o0?oooaT0oooo00<0o`000?ooo`3oool0=`3oool1
00000040oooo000R0?ooo`030000003oool0oooo03<0oooo0`3o00040?ooo`030?l0003oool0oooo
0?l0oooo603oool00`3o0000oooo0?ooo`0b0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0=03oool00`3o0000oooo0?ooo`020?ooo`<0o`00o`3ooolF0?ooo`D0o`00<`3oool100000040
oooo000R0?ooo`800000>`3oool00`3o0000oooo0?ooo`3o0?oooa@0oooo1@3o00000`3oool0o`00
0?ooo`0`0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?oo
o`3o0?oooa`0oooo0P3o00020?ooo`<0o`00<@3oool100000040oooo000R0?ooo`030000003oool0
oooo0380oooo0`3o003o0?ooob80oooo00<0o`000?ooo`3oool0<03oool100000040oooo000R0?oo
o`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo0?l0oooo5`3oool30?l00340oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`0R0?ooo`<0o`005P3oool30?l00?l0oooo6@3oool00`3o0000oooo0?ooo`0`0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`020?ooo`050?l0
003oool0o`000?ooo`3o0000303oool0103o0000oooo0?ooo`3o003o0?oooaT0oooo00<0o`000?oo
o`3oool0<@3oool100000040oooo000R0?ooo`030000003oool0oooo02L0oooo1`3o000:0?ooo`<0
o`00o`3ooolJ0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`0/0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`060?ooo`050?l0003oool0o`000?ooo`3o
0000303oool00`3o0000oooo0?ooo`3o0?oooaX0oooo00@0o`000?ooo`3oool0oooo0`3o000]0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool07P3oool30?l001H0oooo00<0o`000?ooo`3o
ool0o`3ooolQ0?ooo`030?l0003oool0oooo02`0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01@0oooo0`3o003o0?ooob00oooo00<0o`000?ooo`3oool0
;P3oool100000040oooo000R0?ooo`030000003oool0oooo03@0oooo00@0o`000?ooo`3oool0o`00
o`3ooolP0?ooo`<0o`00;`3oool100000040oooo000R0?ooo`030000003oool0oooo03<0oooo0`3o
003o0?ooob<0oooo00<0o`000?ooo`3oool00P3oool20?l002X0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0o`3ooolV
0?ooo`@0o`00:@3oool100000040oooo000R0?ooo`030000003oool0oooo01`0oooo0`3o003o0?oo
oc/0oooo00@0o`000?ooo`3oool0oooo0P3o000Z0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool07@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo=03oool30?l0
02h0oooo0@0000010?ooo`001P3oool00`3ogi`0B01d0;ooo`040?ooo`090?oog`2LB000M;oo0?oo
o`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?oo
o`0L0?ooo`030?l0003oool0oooo0080oooo0`3o00060?ooo`030?l0003oool0oooo0?l0oooo;@3o
ool30?l002d0oooo0@0000010?ooo`001P3oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2LB000
M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0
6`3oool30?l000@0oooo00<0o`000?ooo`3oool0103oool30?l00?l0oooo;`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo02L0oooo0@0000010?ooo`001P3oool01@3ogi`0B01d0;oo
o`3oool0gia800D0000000<0B9cO0?ooo`3oool01P3oool00`2oM000M;oo0?ooo`060?ooo`030000
003oool0oooo01`0oooo00<0o`000?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0o`000?l0
oooo<03oool30?l002P0oooo0@0000010?ooo`001P3oool02P3ogi`0B01d0;ooo`3oool0omnL04Q8
W03Oool0oooO09a8001d_ol90?ooo`030;md001d_ol0oooo00H0oooo0`00000]0?ooo`<0o`00o`3o
ool`0?ooo`030?l0003oool0oooo0080o`008`3oool300000040oooo00060?ooo`030?oOW01807@0
_ooo0080oooo00D0gia804RLg`3ooml0W4P007Boo`040?ooo`070?oOW01804P0W=oo0?ooo`3ooml0
W4Q809cOo`070?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool04`3oool00`3o0000
oooo0?ooo`3o0?oooc40oooo103o000T0?ooo`4000000@3oool000H0oooo00<0omnL04P0M02oool0
0P3oool01@3ooml0W4Q809cOg`2LB000M;oo00@0oooo00<0oono07@0000000000P0000000`1d_ol0
oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo0`3o003o0?ooodL0oooo103o000U0?ooo`40
00000@3oool000@0oooo00D0_g@00000B02L_i`0B01d0;ooo`030?ooo`040?oOW018B7@0M4P007Bo
o`@0oooo00<0oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo
0?l0ooooA`3oool00`3o0000oooo0?ooo`0U0?ooo`4000000@3oool000D0oooo00@0okmd00000000
07@0_ooo103oool00`3OW4P0000007Boo`050?ooo`030;md001d_ol0oooo00X0oooo00<000000?oo
o`3oool0o`3ooomO0?ooo`030?l0003oool0oooo02P0oooo0@0000010?ooo`001P3oool00`3ogi`0
B01d0;ooo`040?ooo`030?oog`2LB000M;oo00D0oooo00H0gia800000000000000000000M02oool7
0?ooo`030000003oool0oooo0?l0ooooGP3oool30?l000030?ooo`3o0000oooo02H0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oooel0oooo00<0o`000?ooo`3o00000P3o00020?oo
o`80o`008P3oool100000040oooo000R0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3o
ool0o`3oool`0?ooo`030?l0003oool0oooo00@0o`008@3oool100000040oooo000R0?ooo`030000
003oool0oooo02h0oooo0`3o003o0?oooc00oooo00<0o`000?ooo`3oool00P3oool20?l00280oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0o`3oool^0?ooo`<0o`009`3oool100000040oooo000R0?ooo`030000003oool0
oooo02P0oooo0`3o003o0?ooocH0oooo00<0o`000?ooo`3oool09P3oool100000040oooo000R0?oo
o`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0o`3ooolj0?ooo`030?l0003oool0oooo
0240oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0?l0
oooo@P3oool40?l00240oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`<0o`00
o`3ooom20?ooo`L0o`007`3oool100000040oooo000R0?ooo`030000003oool0oooo0200oooo00<0
o`000?ooo`3oool0o`3ooom00?ooo`<0o`000P3oool40?l001h0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool0o`00o`3o
oolf0?ooo`D0o`000`3oool00`3o0000oooo0?ooo`0M0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool06`3oool30?l000T0oooo1P3o003o0?ooocH0oooo0`3o000T0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo
0?l00?l0ooooGP3oool100000040oooo000R0?ooo`800000o`3ooon:0?ooo`8000000@3oool00280
oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0
ooooHP3oool100000040oooo000R0?ooo`030000003oool0oooo01H0oooo0`3o000;0?ooo`<0o`00
o`3ooomS0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool05P3oool20?l000<0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo00<0o`000?ooo`3oool08P3o
ool100000040oooo000R0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o00000P3o0002
0?ooo`<0o`002@3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo0`3o000S0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool04P3oool30?l000030?ooo`3o0000oooo00<0oooo00<0o`000?oo
o`3oool01`3oool30?l00?l0oooo?@3oool00`3o0000oooo0?ooo`030?ooo`80o`007@3oool10000
0040oooo000R0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o00000P3o000>0?ooo`03
0?l0003oool0oooo0?l0oooo@@3oool40?l001`0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0o`3ooom40?ooo`80o`00
7@3oool100000040oooo000R0?ooo`030000003oool0oooo0280oooo103o003o0?ooodD0oooo0`3o
000L0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool08@3oool40?l00?l0ooooA@3oool0
0`3o0000oooo0?l0000M0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`3o0?oood@0oooo0`3o000N0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooomZ0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0603oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooKP3oool30?l001T0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0ooooGP3oool00`3o0000oooo0?oo
o`0H0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03@3oool30?l00?l0ooooG@3oool0
0`3o0000oooo0?ooo`0J0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0ooooDP3oool30?l001/0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0F0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`3o0?ooodh0
oooo00<0o`000?ooo`3oool06P3oool100000040oooo000R0?ooo`030000003oool0oooo01D0oooo
0`3o00030?ooo`<0o`00o`3ooomC0?ooo`030?l0003oool0oooo01H0oooo0@0000010?ooo`008P3o
ool2000001L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooe40oooo0`3o
000F0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o
0?ooodl0oooo0`3o000H0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0;0?ooo`<0o`00o`3ooomA0?ooo`030?l0003oool0oooo01L0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0=0?ooo`<0o`003@3oool00`3o0000oooo0?ooo`3o0?ooofX0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`3o
00002`3oool00`3o0000oooo0?ooo`3o0?ooofd0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`090?ooo`<0o`003@3oool30?l00?l0ooooE`3oool00`3o0000oooo0?ooo`0D0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0?l0ooooE03oool40?l001D0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooomF0?ooo`@0o`005P3oool1
00000040oooo000R0?ooo`030000003oool0oooo0140oooo0`3o00020?ooo`<0o`00o`3ooomH0?oo
o`040?l0003oool0oooo0?l001D0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?oo
oe80oooo00<0o`000?ooo`3oool0103oool40?l001<0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`070?ooo`<0o`00o`3ooomQ0?ooo`<0o`000P3oool0103o0000oooo0?ooo`3oool40?l0
0180oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00h0
oooo00<0o`000?ooo`3oool0o`3ooom@0?ooo`030?l0003oool0oooo00<0o`000`3oool20?l001<0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0H0?ooo`<0o`00o`3ooomE0?ooo`040?l0
003oool0oooo0?ooo`<0o`004`3oool100000040oooo000R0?ooo`030000003oool0oooo0140oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oooeT0oooo00<0o`000?ooo`3oool0
4P3oool100000040oooo000R0?ooo`030000003oool0oooo00l0oooo103o003o0?ooogL0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0>0?ooo`@0o`00o`3ooomN0?ooo`030?l0003oool0
oooo01L0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0?l0ooooG@3oool30?l001P0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo0?l0ooooE03oool00`3o0000oooo0?ooo`0G0?ooo`4000000@3oool00280oooo
0P00000I0?ooo`<0o`00o`3ooom^0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`3o0?oooel0oooo00<0o`000?ooo`3oool0303oool100000040oooo000R
0?ooo`030000003oool0oooo0?l0ooooNP3oool30?l000d0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooomX0?ooo`030?l0003oool0
oooo00`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`<0o`0000@0oooo0?l0
003o0000o`00o`3ooomW0?ooo`030?l0003oool0oooo00`0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`3o0000o`3ooomW0?ooo`<0o`003@3oool1
00000040oooo000R0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooomV0?oo
o`040?l0003oool0oooo0?l000h0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0>0?oo
o`<0o`00o`3ooomV0?ooo`<0o`00403oool100000040oooo000R0?ooo`030000003oool0oooo00T0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooofH0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0:0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
203oool30?l000<0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oooeH0oooo
00<0o`000?ooo`3oool02P3oool30?l000/0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`090?ooo`040?l0003oool0oooo0?ooo`<0o`001@3oool30?l00?l0ooooEP3oool30?l000`0oooo
00<0o`000?ooo`3oool02P3oool100000040oooo000R0?ooo`030000003oool0oooo00h0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oooeH0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooomO
0?ooo`<0o`000P3oool40?l000d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`090?oo
o`<0o`000`3oool00`3o0000oooo0?l000020?l00?l0ooooG`3oool30?l00080oooo1@3o000=0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool30?l0
00030?ooo`3o0000oooo0?l0ooooGP3oool00`3o0000oooo0?l000030?ooo`@0o`003P3oool10000
0040oooo000R0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`3o0?oooel0oooo0`3o00050?ooo`030?l0003oool0oooo00h0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`070?ooo`@0o`00o`3ooomW0?ooo`030?l0003oool0oooo01D0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`080?ooo`@0o`00o`3ooomn0?ooo`4000000@3o
ool00280oooo0P00000;0?ooo`030?l0003oool0oooo0?l0ooooO03oool200000040oooo000R0?oo
o`030000003oool0oooo0?l0ooooLP3oool00`3o0000oooo0?ooo`0E0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?ooof<0oooo0`3o000F0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool02P3oool30?l00?l0ooooI@3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00d0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0?l0ooooJ`3oool30?l000h0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`080?ooo`030?l0003oool0o`000?l0ooooK`3oool00`3o0000oooo0?ooo`0=
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool50?l000030?ooo`3o0000oooo
0?l0ooooHP3oool00`3o0000oooo0?ooo`0F0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0203oool0103o0000oooo0?l0003oool30?l00?l0ooooH@3oool30?l001L0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`070?ooo`<0o`000`3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo0?l0ooooE`3oool00`3o0000oooo0?ooo`0F0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`<0o`00o`3ooomS0?ooo`030?l0
003oool0oooo00/0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`070?ooo`<0o`003@3o
ool00`3o0000oooo0?ooo`3o0?oooeD0oooo00<0o`000?ooo`3oool02@3oool30?l000`0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`070?ooo`80o`00o`3ooomU0?ooo`<0o`00203oool0
0`3o0000oooo0?l000020?l000`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`060?oo
o`<0o`00o`3ooomV0?ooo`030?l0003oool0oooo00H0oooo0`3o00000`3oool0o`000?ooo`0<0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?ooofl0
oooo00<0o`000?ooo`3oool03P3oool100000040oooo000R0?ooo`030000003oool0oooo0?l0oooo
RP3oool100000040oooo000@0?ooo`030?oOW01807@0_ooo0080oooo00D0gia80000000000000018
09cOo`080?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000@0?ooo`0;0?oOW018
07@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01`3oool00`000000oooo0?ooo`3o
0?ooohX0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`060?ooo`030;md001d_ol0oooo
00H0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`4000000@3oool00100oooo00<0omnL04P0M02o
ool01P3oool00`2oM000M;oo0?ooo`060?ooo`<00000o`3ooon80?ooo`<000000@3oool00100oooo
00/0omnL04P0M02oool0oooo0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`070?ooo`030000003o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooofd0oooo00<0
o`000?ooo`3oool02`3oool100000040oooo000@0?ooo`060?oOW01807@0_ooo0?ooo`3ookl0M000
0`0000000`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0`3o00030?ooo`@0o`00
o`3ooom/0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`060?ooo`4000000@3oool000h0oooo00T0
_g@00000B02L_i`0B01d0;ooo`3oool0oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo103o003o0?ooof`0oooo00@0o`000?ooo`3oool0oooo0`3o0007
0?ooo`4000000@3oool000l0oooo00@0okmd0000000007@0_ooo0P3oool00`2oM000M;oo0?ooo`0:
0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0o`3ooomS0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool01P3oool100000040oooo000@0?ooo`030?oOW01807@0_ooo
0080oooo00H0gia800000000000000000000M02oool70?ooo`030000003oool0oooo0?l0ooooL`3o
ool30?l000P0oooo00<0o`000?ooo`3oool02@3oool100000040oooo000R0?ooo`030000003oool0
oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo0?l0ooooF`3o
ool00`3o0000oooo0?ooo`050?ooo`@0o`002P3oool100000040oooo000R0?ooo`030000003oool0
oooo00L0oooo0`3o0000103oool0o`000?l0003o00070?ooo`<0o`00o`3ooomK0?ooo`<0o`001@3o
ool40?l00080oooo00<0o`000?ooo`3oool01P3oool100000040oooo000R0?ooo`030000003oool0
oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo0?l0ooooF`3o
ool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`<0o`001`3oool100000040oooo
000R0?ooo`030000003oool0oooo0?l0ooooO03oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00H0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?ooogH0oooo00<0o`00
0?ooo`3oool00P3oool30?l000`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
ofl0oooo00<0o`000?ooo`3oool00`3oool30?l000@0oooo00<0o`000?ooo`3oool02`3oool10000
0040oooo000R0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool0o`3ooomK0?ooo`<0
o`001@3oool00`3o0000oooo0?ooo`0A0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
3`3oool30?l00?l0ooooG@3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3o
ool02@3oool100000040oooo000R0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`3o0?oooeT0oooo0`3o00080?ooo`<0o`002P3oool100000040oooo
000R0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool02`3oool30?l00?l0ooooF`3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`060?ooo`<0o`003@3oool00`3o0000oooo0?ooo`3o0?ooof40oooo00<0o`00
0?ooo`3oool03@3oool100000040oooo000R0?ooo`030000003oool0oooo00L0oooo00<0o`000?oo
o`3oool0o`3ooom_0?ooo`<0o`003P3oool100000040oooo000R0?ooo`800000403oool20?l00003
0?ooo`3o0000oooo0?l0ooooFP3oool00`3o0000oooo0?l000090?ooo`030?l0003oool0oooo00`0
oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`0>0?ooo`H0o`00o`3ooomI0?ooo`D0o`00
603oool100000040oooo000R0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool20?l000030?ooo`3o0000oooo0?l0ooooFP3oool00`3o0000oooo0?l000050?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool100000040oooo000R0?ooo`030000003oool0
oooo00H0oooo0`3o003o0?ooof`0oooo0`3o00030?ooo`<0o`00303oool100000040oooo000R0?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooom/0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool02`3oool100000040oooo000R0?ooo`030000003oool0oooo0?l0
ooooM@3oool30?l00180oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030?l0
003oool0oooo0?l0ooooF`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0o`00o`3o
oomK0?ooo`<0o`005`3oool100000040oooo000R0?ooo`030000003oool0oooo00h0oooo0`3o0002
0?ooo`030?l0003oool0oooo0?l0ooooF`3oool00`3o0000oooo0?ooo`0F0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`3o0?ooogP0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooofh0oooo00<0o`000?ooo`3oool06@3oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooK@3oool30?l001X0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0?l0ooooE03oool00`3o0000oooo0?oo
o`0I0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool05P3oool30?l00?l0ooooG@3oool0
0`3o0000oooo0?ooo`0A0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0ooooF`3oool30?l00180oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`080?ooo`<0o`0000<0oooo0?l0003oool0o`3ooomP0?ooo`03
0?l0003oool0oooo00@0oooo0`3o000B0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
2@3oool00`3o0000oooo0?l000030?l00?l0ooooGP3oool30?l000H0oooo00<0o`000?ooo`3oool0
4@3oool100000040oooo000R0?ooo`030000003oool0oooo00`0oooo103o00080?ooo`030?l0003o
ool0oooo0?l0ooooD`3oool00`3o0000oooo0?ooo`0I0?ooo`4000000@3oool00280oooo0P00000?
0?ooo`030?l0003oool0oooo00H0oooo0`3o003o0?ooofl0oooo0P0000010?ooo`008P3oool00`00
0000oooo0?ooo`0D0?ooo`80o`0000<0oooo0?l0003o0000o`3ooomK0?ooo`030?l0003oool0oooo
01<0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`H0o`00o`3ooomF0?ooo`04
0?l0003oool0oooo0?ooo`<0o`00503oool100000040oooo000R0?ooo`030000003oool0oooo00l0
oooo00<0o`000?ooo`3oool00P3oool20?l000030?ooo`3o0000oooo0?l0ooooE@3oool30?l000<0
oooo00<0o`000?ooo`3oool04`3oool100000040oooo000R0?ooo`030000003oool0oooo00h0oooo
0`3o003o0?oooeh0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool03P3oool20?l00?l0ooooJ`3oool30?l000`0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`<0o`00o`3ooomU0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool02`3oool100000040oooo000R0?ooo`030000003oool0oooo
00d0oooo0`3o003o0?ooof@0oooo0`3o000C0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0ooooEP3oool0103o0000
oooo0?ooo`3o000D0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0503oool0103o0000
oooo0?ooo`3oool30?l00?l0ooooEP3oool30?l001H0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`0A0?ooo`030?l0003oool0o`000080o`000`3oool00`3o0000oooo0?ooo`3o0?ooodl0
oooo00<0o`000?ooo`3oool00`3oool30?l001H0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0@0?ooo`<0o`0000<0oooo0?l0003oool0o`3ooomD0?ooo`<0o`001@3oool00`3o0000oooo
0?ooo`0E0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`3o0?oooeH0oooo0`3o00030?ooo`030?l0003oool0oooo01L0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?ooof/0oooo00@0o`000?ooo`3oool0oooo0`3o000H0?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool0o`3ooom`0?ooo`030?l0003oool0oooo01L0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0ooooLP3oool10000
0040oooo000R0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3o00000P3o003o0?ooog<0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`<0o`0000<0oooo0?l0003oool0
o`3ooomc0?ooo`4000000@3oool00280oooo0P00000C0?ooo`030?l0003oool0oooo0?l0ooooFP3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo0P0000010?ooo`008P3oool0
0`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0?l0ooooFP3oool30?l000H0oooo0`3o000@
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0403oool30?l00?l0ooooD03oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03`3oool10000
0040oooo000R0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3o00000P3oool00`3o0000
oooo0?l0003o0?ooodT0oooo0`3o00090?ooo`030?l0003oool0oooo01T0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0B0?ooo`P0o`00o`3ooom90?ooo`030?l0003oool0oooo00L0oooo
0`3o000J0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04`3oool01P3o0000oooo0?oo
o`3o0000oooo0?l00?l0ooooE@3oool00`3o0000oooo0?ooo`0I0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom/0?ooo`030?l0003oool0oooo01/0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0?l0ooooBP3oool40?l001`0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0L0?ooo`<0o`00o`3ooom:0?ooo`@0o`00203oool0
0`3o0000oooo0?ooo`0B0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0oooo@`3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00L0oooo0`3o000C0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool05@3oool30?l00?l0ooooBP3oool30?l00100oooo00<0o`000?ooo`3oool04P3oool100000040
oooo000R0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0o`3ooom:0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool07`3oool100000040oooo000R0?ooo`030000003o
ool0oooo0?l0ooooI`3oool30?l00200oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oooeh0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0180oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo
0?l0oooo>P3oool30?l000@0oooo00<0o`000?ooo`3oool03@3oool30?l001<0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0O0?ooo`<0o`00o`3oooll0?ooo`030?l0003oool0oooo0080
oooo0`3o000?0?ooo`030?l0003oool0oooo0180oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3ooom10?ooo`030?l0
003oool0oooo02<0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0H0?ooo`030?l0003o
ool0o`000080o`000`3oool00`3o0000oooo0?ooo`3o0?ooodH0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0G0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool05`3oool3
0?l000030?ooo`3o0000o`000080oooo0`3o003o0?oooc`0oooo00<0o`000?ooo`3oool01`3oool3
0?l000@0oooo0`3o000H0?ooo`4000000@3oool00280oooo0P00000I0?ooo`030?l0003oool0o`00
00H0o`00o`3oooll0?ooo`<0o`002@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
01H0oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`0I0?ooo`@0o`000P3oool00`3o0000
oooo0?ooo`3o0?oooc`0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0P0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool06P3oool40?l00?l0ooooB03oool30?l00240oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`<0o`00o`3ooom:0?ooo`030?l0003o
ool0oooo0200oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0
oooo0?l0ooooK03oool100000040oooo000R0?ooo`030000003oool0oooo02<0oooo00<0o`000?oo
o`3oool0o`3ooomT0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool08P3oool30?l00?l0
oooo=03oool00`3o0000oooo0?ooo`0^0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`3o0?oooc80oooo0`3o000_0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool0o`3ooomI0?ooo`030?l0003oool0oooo02h0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
ohX0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo0?l0
ooooJ03oool100000040oooo000R0?ooo`030000003oool0oooo01h0oooo0`3o003o0?oooc/0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0T0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3o0?ooocT0oooo0`3o00040?ooo`<0o`009@3o
ool100000040oooo000R0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0o`3ooolf
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo01P0oooo0@0000010?ooo`001P3oool00`3ogi`0B01d0;ooo`020?oo
o`0;0=nLB000000000000000B02Lgol0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0
W=oo0?ooo`070?ooo`030000003oool0oooo0280oooo0`3o003o0?ooocH0oooo0`3o00060?ooo`03
0?l0003oool0oooo00<0o`000P3oool00`3o0000oooo0?l000020?l001T0oooo0@0000010?ooo`00
1P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00<0oooo00L0
okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`3o0?ooocH0oooo00<0o`000?ooo`3oool0103oool30?l00080oooo00<0o`000?ooo`3o
ool00`3o00000`3oool0o`000?ooo`0I0?ooo`4000000@3oool000H0oooo00<0omnL04P0M02oool0
1P3oool00`2oM000M;oo0?ooo`070?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0
:03oool00`3o0000oooo0?ooo`3o0?ooocT0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0K0?ooo`4000000@3oool000H0oooo00<0omnL04P0M02oool01P3oool00`2oM000M;oo0?oo
o`070?ooo`030;md001d_ol0oooo00H0oooo0`00000W0?ooo`<0o`00o`3ooolc0?ooo`030?l0003o
ool0oooo02P0oooo0`0000010?ooo`001P3oool02`3ogi`0B01d0;ooo`3oool0omnL04P0B02Lgol0
oooo0?oog`2LB4P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00L0oooo00<0
00000?ooo`3oool0:03oool0103o0000oooo0?ooo`3o003o0?oooc00oooo0`3o000[0?ooo`400000
0@3oool000H0oooo00H0omnL04P0M02oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo0080
oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo02X0
oooo0`3o003o0?oooc00oooo00<0o`000?ooo`3oool0:P3oool100000040oooo00040?ooo`090;md
000004P0W;nL04P0M02oool0oooo0?oog`2LB4P0W=oo00L0oooo00<0oooO09a8B02Lgol02`3oool0
0`000000oooo0?ooo`0Z0?ooo`<0o`00o`3ooolT0?ooo`040?l0003oool0oooo0?l003D0oooo0@00
00010?ooo`001@3oool0103o_g@000000000M02oool20?ooo`030;md001d_ol0oooo00L0oooo00<0
_g@007Boo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`040?l0003oool0oooo0?l00?l0oooo
903oool60?l000H0oooo00<0o`000?ooo`3oool0:`3oool100000040oooo00060?ooo`030?oOW018
07@0_ooo0080oooo00H0gia800000000000000000000M02oool40?ooo`060=nLB000000000000000
000007@0_ooo1`3oool00`000000oooo0?ooo`0W0?ooo`@0o`00o`3ooolV0?ooo`040?l0003oool0
oooo0?l000H0oooo0`3o00000`3oool0o`000?ooo`0Y0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0:03oool40?l00?l0oooo<03oool00`3o0000oooo0?l000020?l002T0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`80o`000`3oool00`3o0000oooo0?ooo`3o0?oo
obX0oooo00D0o`000?ooo`3oool0oooo0?l0000Z0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool0:03oool30?l00080oooo0`3o003o0?ooobX0oooo0`3o000]0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`040?l00?l0oooo:`3oool00`3o0000
oooo0?ooo`0/0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0:`3oool40?l00?l0oooo
F`3oool100000040oooo000R0?ooo`030000003oool0oooo02`0oooo103o003o0?oooeX0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0?l0ooooF@3oool1
00000040oooo000R0?ooo`030000003oool0oooo0?l0ooooHP3oool00`3o0000oooo0?ooo`0U0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`3o0?ooobh0
oooo0`3o000V0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0;`3oool30?l00?l0oooo
7`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo02D0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0_0?ooo`<0o`00o`3ooolN0?ooo`<0o`00=`3oool100000040oooo000R
0?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool0o`3ooolN0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool0;03oool100000040oooo000R0?ooo`800000=03oool20?l0
0?l0oooo6P3oool00`3o0000oooo0?ooo`080?ooo`<0o`0000<0oooo0?l0003oool0:@3oool20000
0040oooo000R0?ooo`030000003oool0oooo0380oooo103o003o0?oooaP0oooo0`3o00000`3oool0
o`000?ooo`070?ooo`030?l0003oool0o`000080o`00:P3oool100000040oooo000R0?ooo`030000
003oool0oooo03<0oooo0P3o003o0?oooaX0oooo00<0o`000?ooo`3o00000P3o000:0?ooo`030?l0
003oool0oooo02T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?ooodd0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02`0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooolE0?ooo`<0o`002`3oool3
0?l002d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`D0o`00o`3oool>0?oo
o`030?l0003oool0oooo0080oooo0P3o000=0?ooo`030?l0003oool0oooo02`0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0e0?ooo`D0o`00o`3oool<0?ooo`<0o`000P3oool30?l003`0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0h0?ooo`80o`00o`3oool=0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0Z0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0>03oool30?l00?l0oooo4@3oool00`3o0000oooo0?oo
o`0=0?ooo`<0o`00:`3oool100000040oooo000R0?ooo`030000003oool0oooo03L0oooo103o003o
0?oooa00oooo0`3o000?0?ooo`030?l0003oool0oooo02X0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0h0?ooo`D0o`00o`3oool?0?ooo`030?l0003oool0oooo03/0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0i0?ooo`D0o`00o`3ooom<0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0>`3oool20?l00?l0oooo2@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo02l0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0m0?ooo`030?l0003o
ool0oooo0?l0oooo1@3oool30?l000l0oooo0`3o000`0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0?03oool30?l00?l0oooo1`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo02l0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0m0?ooo`@0o`00o`3ooom90?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0?P3oool40?l00?l0oooo00<0o`000?ooo`3o
ool0A@3oool100000040oooo000R0?ooo`030000003oool0oooo03l0oooo0`3o003n0?ooo`<0o`00
0P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo03H0oooo0@0000010?ooo`008P3o
ool200000440oooo00@0o`000?ooo`3o0000o`00o@3oool00`3o0000oooo0?ooo`030?l000H0oooo
00<0o`000?ooo`3o00000P3o000f0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool0@@3o
ool40?l00?l0oooo0@3oool00`3o0000oooo0?ooo`040?ooo`<0o`0000<0oooo0?l0003oool0=`3o
ool100000040oooo000R0?ooo`030000003oool0oooo0480oooo0`3o003k0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool0>@3oool100000040oooo000R0?ooo`030000003oool0oooo
04<0oooo103o003[0?ooo`030?l0003oool0oooo00X0oooo0`3o00170?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0A03oool40?l00>T0oooo0`3o000<0?ooo`030?l0003oool0oooo04H0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`150?ooo`80o`0000<0oooo0?l0003oool0
j03oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo03P0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`170?ooo`@0o`00k`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00P0oooo0`3o000i0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0B03oool4
0?l00>d0oooo0`3o00050?ooo`<0o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo03P0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`190?ooo`@0o`00k@3oool00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000<0oooo0`3o00100?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0B@3oool40?l00?40oooo0`3o00060?ooo`030?l0003oool0oooo
03l0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1:0?ooo`@0o`00f@3oool00`3o0000
oooo0?ooo`0E0?ooo`030?l0003oool0oooo04L0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`1<0?ooo`80o`00f03oool30?l000`0oooo00<0o`000?ooo`3oool0D@3oool100000040oooo
000R0?ooo`030000003oool0oooo04`0oooo0`3o00020?ooo`030?l0003oool0oooo0=<0oooo00<0
o`000?ooo`3oool02@3oool40?l000h0oooo00<0o`000?ooo`3oool0@@3oool100000040oooo000R
0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool00`3o003O0?ooo`@0o`003P3oool3
0?l00480oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1A0?ooo`<0o`00e@3oool00`3o
0000oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000/0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`110?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0DP3oool20?l0
0=@0oooo0`3o00040?ooo`<0o`00303oool30?l004P0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`1B0?ooo`<0o`00cP3oool0103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?l000190?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`3<0?ooo`H0o`00203oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0`3o001:0?ooo`4000000@3oool00280oooo
0P00003o0?ooobD0oooo00@0o`000?ooo`3oool0o`00203oool30?l000<0oooo0`3o00050?ooo`03
0?l0003oool0oooo04P0oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oooaX0oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0500oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oooaD0oooo00@0o`000?ooo`3oool0oooo
0`3o001^0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0FP3oool0103o0000oooo0?l0
003o002e0?ooo`<0o`000`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo06D0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`1I0?ooo`H0o`00103oool00`3o0000oooo0?oo
o`2^0?ooo`030?l0003oool0oooo00T0oooo0`3o00030?ooo`030?l0003oool0oooo0600oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`1H0?ooo`<0o`0000<0oooo0?l0003o0000103oool3
0?l00;`0oooo00@0o`000?ooo`3oool0oooo0`3o001Q0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0F@3oool00`3o0000oooo0?ooo`060?ooo`80o`00[P3oool0103o0000oooo0?ooo`3o
000@0?ooo`030?l0003oool0oooo0600oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1Q
0?ooo`<0o`00Y`3oool00`3o0000oooo0?ooo`030?ooo`H0o`00403oool00`3o0000oooo0?ooo`1O
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`2U0?oo
o`<0o`001@3oool0103o0000oooo0?ooo`3o000@0?ooo`<0o`00H03oool100000040oooo000R0?oo
o`030000003oool0oooo0640oooo0P3o0000103oool0o`000?ooo`3o00050?ooo`030?l0003oool0
oooo09`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0
oooo05l0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1P0?ooo`P0o`000`3oool30?l0
0:80oooo0`3o000Q0?ooo`030?l0003oool0oooo0580oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`1Q0?ooo`80o`0000@0oooo0?l0003oool0o`001@3oool00`3o0000oooo0?ooo`2R0?oo
o`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool30?l005<0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`1W0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0WP3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00d0oooo0`3o000<0?ooo`03
0?l0003oool0oooo0580oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1V0?ooo`<0o`00
103oool30?l009h0oooo0`3o00030?ooo`<0o`003`3oool00`3o0000oooo0?ooo`1P0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0I@3oool30?l000H0oooo00@0o`000?ooo`3oool0o`00
S@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
303oool00`3o0000oooo0?ooo`1R0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0IP3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0o`00R`3oool30?l00280oooo0`3o
001S0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0K03oool30?l00080oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`230?ooo`030?l0003oool0o`0000/0oooo00<0o`00
0?ooo`3oool05@3oool20?l006@0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1]0?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0`3o00230?ooo`<0o`002`3oool3
0?l001D0oooo0`3o001T0?ooo`4000000@3oool00280oooo0P00001b0?ooo`<0o`000`3oool00`3o
0000oooo0?ooo`230?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o00005`3oool00`3o
0000oooo0?ooo`1R0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool0L03oool30?l000D0
oooo00@0o`000?ooo`3oool0o`00S03oool30?l007h0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`1a0?ooo`040?l0003oool0oooo0?l00080oooo1P3o00020?ooo`040?l0003oool0oooo
0?l00080oooo00<0o`000?ooo`3oool0P@3oool00`3o0000oooo0?ooo`1m0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0L03oool60?l000060?ooo`3o0000o`000?l0003oool0o`000P3o
ool90?l007@0oooo00<0o`000?ooo`3oool0R`3oool100000040oooo000R0?ooo`030000003oool0
oooo0740oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?l000020?l00080oooo0P3o
00000`3oool0o`000?l000020?l007@0oooo0`3o002<0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0N`3oool0103o0000oooo0?ooo`3oool30?l00080oooo00<0o`000?ooo`3oool0E@3o
ool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`1b0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0P03oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo04d0oooo0`3o000S0?ooo`<0o`00203oool0
0`3o0000oooo0?ooo`040?ooo`<0o`00L`3oool100000040oooo000R0?ooo`030000003oool0oooo
08D0oooo00<0o`000?ooo`3oool00P3oool30?l000<0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo03/0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo00H0oooo0`3o00060?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0K@3oool100000040oooo000R0?ooo`030000003oool0oooo08@0
oooo0`3o00040?ooo`040?l0003oool0oooo0?ooo`<0o`000P3oool30?l000H0oooo0`3o00090?oo
o`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0203oool30?l000X0oooo00<0o`000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool30?l006h0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`240?ooo`80
o`000`3oool00`3o0000oooo0?ooo`040?ooo`060?l0003oool0oooo0?l0003oool0o`00203oool0
0`3o0000oooo0?ooo`070?ooo`@0o`001P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0180oooo0`3o000:0?ooo`030?l0003oool0oooo00P0oooo0`3o00080?ooo`030?l0003oool0
oooo00@0oooo0`3o000=0?ooo`<0o`001@3oool00`3o0000oooo0?ooo`1]0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0P`3oool30?l00080oooo0`3o00070?ooo`<0o`003@3oool00`3o
0000oooo0?ooo`040?ooo`@0o`00103oool30?l00080oooo00@0o`000?ooo`3oool0o`001@3oool0
0`3o0000oooo0?l000020?l000/0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0o`000100oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`<0o`001P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo07@0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`240?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00<0o`001`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00H0o`000`3oool30?l000030?ooo`3o0000oooo00X0oooo0`3o0002
0?ooo`<0o`00203oool00`3o0000oooo0?ooo`070?ooo`<0o`001P3oool00`3o0000oooo0?ooo`05
0?ooo`80o`004@3oool00`3o0000oooo0?ooo`1j0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool0U`3oool00`3o0000oooo0?ooo`020?ooo`@0o`000P3oool00`3o0000oooo0?ooo`0A0?oo
o`040?l0003oool0oooo0?l000D0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00H0oooo103o00080?ooo`030?l0003oool0oooo00@0oooo0`3o0005
0?ooo`<0o`00403oool30?l007/0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`2A0?oo
o`030?l0003oool0oooo0080oooo0`3o00020?ooo`@0o`00?`3oool40?l000d0oooo00<0o`000?oo
o`3o00001`3oool00`3o0000oooo0?ooo`050?ooo`80o`002@3oool00`3o0000oooo0?ooo`1j0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0T03oool30?l000@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool40?l000h0oooo103o00250?ooo`4000000@3oool00100oooo00<0omnL04P0M02oool0
0P3oool01@3ookl0M0000000000007@0_ooo00P0oooo00<000000?ooo`3oool0T@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?l000020?l000D0oooo00<0o`000?ooo`3oool04@3oool40?l000H0oooo00<0o`000?ooo`3o
ool01@3oool20?l008H0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`020?ooo`060;md
001d_ol0oooo0?oOW018B9`0gooo1`3oool00`000000oooo0?ooo`2E0?ooo`<0o`00;`3oool00`3o
0000oooo0?l000020?l000@0oooo0`3o00000`3oool0o`000?ooo`040?ooo`<0o`00503oool00`3o
0000oooo0?ooo`040?ooo`<0o`00SP3oool100000040oooo000@0?ooo`0;0?oOW01807@0_ooo0?oo
o`3ookl0M4RL0=ooo`3oool0oono07@0B02Lgol01`3oool00`000000oooo0?ooo`2F0?ooo`030?l0
003oool0oooo02X0oooo00<0o`000?ooo`3oool00`3o00000`3oool0o`000?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo08d0oooo0@0000010?ooo`00403oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00L0oooo0`00002J0?ooo`030?l0003oool0oooo01<0oooo00<0o`00
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo0`3o00020?ooo`030?l0003o
ool0oooo0240oooo0`3o002I0?ooo`<000000@3oool00100oooo00/0omnL04P0M02oool0oooo0?oO
W0180000M;oo0?ooo`3ogi`0B4RL0=ooo`070?ooo`030000003oool0oooo09T0oooo0`3o00090?oo
o`030?l0003oool0oooo00L0oooo0`3o00020?ooo`<0o`0000@0oooo0?l0003o0000o`00203oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo08L0oooo0@0000010?ooo`00403oool02P3o
gi`0B01d0;ooo`3oool0omnL04Q8W02LM00000000000B02Lgol80?ooo`030000003oool0oooo09X0
oooo00<0o`000?ooo`3oool01`3oool30?l000P0oooo0P3o00040?ooo`050?l0003oool0oooo0?oo
o`3o0000503oool30?l000T0oooo0`3o000>0?ooo`<0o`00403oool30?l008P0oooo0@0000010?oo
o`003P3oool02@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`0;0?ooo`030000003o
ool0oooo0:80oooo00@0o`000?ooo`3oool0o`00203oool30?l000h0oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0
403oool00`3o0000oooo0?ooo`270?ooo`4000000@3oool000l0oooo00@0okmd0000000007@0_ooo
0P3oool01P2oM000M;oo0?ooo`3o_g@004RL0=ooo`L0oooo00<000000?ooo`3oool0X@3oool30?l0
00<0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool00`3o00080?ooo`030?l0003oool0oooo0;d0oooo0@0000010?ooo`00403oool00`3o
gi`0B01d0;ooo`020?ooo`050?oog`2LB00000000000B02Lgol0203oool00`000000oooo0?ooo`2R
0?ooo`040?l0003oool0oooo0?ooo`<0o`0000@0oooo0?l0003o0000o`000`3oool01@3o0000oooo
0?ooo`3oool0o`0000D0oooo0`3o00020?ooo`030?l0003oool0oooo00H0oooo0`3o000:0?ooo`03
0?l0003oool0o`000;40oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`2W0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool30?l000040?ooo`3o0000o`000?l000D0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`D0o`003@3oool00`3o0000oooo0?ooo`2P0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0/03oool01@3o0000oooo0?ooo`3oool0o`00
0140oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?l0000=0?ooo`<0o`00X@3oool10000
0040oooo000R0?ooo`030000003oool0oooo0<D0oooo0`3o000N0?ooo`030?l0003oool0oooo0:00
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`360?ooo`030?l0003oool0oooo0<00oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
ohX0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?ooohX0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool03`3oool100000040oooo000R
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`008P3ooooo000008h000000@3oool00?l0
oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0
oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {429.875, 0}} -> {3.71861, 13.7532, \
0.00829032, 0.00829032}}]
}, Open  ]],

Cell[TextData[{
  "This fits a circle with radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and center ",
  Cell[BoxData[
      \(TraditionalForm\`{h, k}\)]],
  " to the data. ",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "MathCaption"],

Cell[BoxData[
    \(\(Clear[x, y, h, k, r];\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = 
      FindFit[data, \((x - h)\)\^2 + \((y - k)\)\^2 - r\^2, {h, k, r}, {x, 
          y}]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({h \[Rule] 4.999187396404156`, k \[Rule] 15.001826234758573`, 
      r \[Rule] 0.9989255751115504`}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(fg = 
        ContourPlot[
          Evaluate[\((x - h)\)\^2 + \((y - k)\)\^2 - 
                r\^2 /. \[InvisibleSpace]s], {x, 3.5, 6.5}, {y, 13.5, 16.5}, 
          Contours \[Rule] {0. }, ContourShading \[Rule] False, 
          ContourStyle \[Rule] Blue];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.10256 0.320513 -4.30769 0.320513 [
[.01923 -0.0125 -7.5625 -10.9375 ]
[.01923 -0.0125 7.5625 0 ]
[.17949 -0.0125 -4.21875 -10.9375 ]
[.17949 -0.0125 4.21875 0 ]
[.33974 -0.0125 -7.5625 -10.9375 ]
[.33974 -0.0125 7.5625 0 ]
[.5 -0.0125 -4.21875 -10.9375 ]
[.5 -0.0125 4.21875 0 ]
[.66026 -0.0125 -7.5625 -10.9375 ]
[.66026 -0.0125 7.5625 0 ]
[.82051 -0.0125 -4.21875 -10.9375 ]
[.82051 -0.0125 4.21875 0 ]
[.98077 -0.0125 -7.5625 -10.9375 ]
[.98077 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -19.5625 -5.46875 ]
[-0.0125 .01923 0 5.46875 ]
[-0.0125 .17949 -12.875 -5.46875 ]
[-0.0125 .17949 0 5.46875 ]
[-0.0125 .33974 -19.5625 -5.46875 ]
[-0.0125 .33974 0 5.46875 ]
[-0.0125 .5 -12.875 -5.46875 ]
[-0.0125 .5 0 5.46875 ]
[-0.0125 .66026 -19.5625 -5.46875 ]
[-0.0125 .66026 0 5.46875 ]
[-0.0125 .82051 -12.875 -5.46875 ]
[-0.0125 .82051 0 5.46875 ]
[-0.0125 .98077 -19.5625 -5.46875 ]
[-0.0125 .98077 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
gsave
.01923 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.17949 0 m
.17949 .00625 L
s
gsave
.17949 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.33974 0 m
.33974 .00625 L
s
gsave
.33974 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.66026 0 m
.66026 .00625 L
s
gsave
.66026 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
1.000 setlinewidth
grestore
.82051 0 m
.82051 .00625 L
s
gsave
.82051 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
gsave
-0.0125 .01923 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.5) show
1.000 setlinewidth
grestore
0 .17949 m
.00625 .17949 L
s
gsave
-0.0125 .17949 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
0 .33974 m
.00625 .33974 L
s
gsave
-0.0125 .33974 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.5) show
1.000 setlinewidth
grestore
0 .5 m
.00625 .5 L
s
gsave
-0.0125 .5 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .66026 m
.00625 .66026 L
s
gsave
-0.0125 .66026 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.5) show
1.000 setlinewidth
grestore
0 .82051 m
.00625 .82051 L
s
gsave
-0.0125 .82051 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.37981 .2037 m
.41987 .19051 L
.45994 .18289 L
.5 .18041 L
.54006 .18296 L
.58013 .19065 L
.62019 .20391 L
.65334 .21955 L
.66026 .22354 L
.70032 .251 L
.71061 .25962 L
.74038 .28934 L
.74906 .29968 L
.77659 .33974 L
.78045 .3464 L
.79629 .37981 L
.80959 .41987 L
.81733 .45994 L
.81991 .5 L
.81747 .54006 L
.8099 .58013 L
.79676 .62019 L
.78045 .65475 L
.77727 .66026 L
.75 .70032 L
.74038 .71184 L
.71195 .74038 L
.70032 .75017 L
.66026 .77762 L
.65541 .78045 L
.62019 .79726 L
.58013 .81052 L
.54006 .81821 L
.51216 .82051 L
.5 .82075 L
.48732 .82051 L
.45994 .81828 L
.41987 .81066 L
.37981 .79748 L
.34408 .78045 L
.33974 .77792 L
.29968 .75059 L
.28753 .74038 L
.25962 .71243 L
.24947 .70032 L
.22221 .66026 L
.21955 .65567 L
.20272 .62019 L
.18958 .58013 L
.18201 .54006 L
Mistroke
.17957 .5 L
.18215 .45994 L
.18989 .41987 L
.20319 .37981 L
.21955 .34548 L
.22289 .33974 L
.25042 .29968 L
.25962 .28875 L
.28886 .25962 L
.29968 .25058 L
.33974 .22324 L
.34615 .21955 L
.37981 .2037 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`008P3oool02`3OW4P000000000
000004P0W=oo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool0=P3oool0
0`3ooml0W4P007Boo`0g0?ooo`090?oog`2LB000M;oo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080
000000<0001809cOo`3oool0=03oool01@3OW4P000000000000004P0W=oo03D0oooo00/0gia80000
00000000001809cOo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo03@0
oooo00D0oono07@000000000001d0;ooo`0e0?ooo`0;0?oo_`1d000000000000M02oool0oooo0?oO
W01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`040?ooo`008@3oool01`3o_g@004RL
0=ooo`3oool0oono07@0B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0=P3o
ool00`3ooml0W4P007Boo`0g0?ooo`030?oog`2LB000M;oo00@0oooo00L0okmd0018W03Oool0oooo
0?oog`2LB7@0_ooo03<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo03<0oooo00L0okmd
0018W03Oool0oooo0?oog`2LB7@0_ooo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo
03@0oooo00H0_g@007Boo`3oool0omnL04Q8W03Ooold0?ooo`060;md001d_ol0oooo0?oOW018B9`0
gooo0`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0103oool002H0oooo00<0_g@007Bo
o`3oool01`3oool00`2oM000M;oo0?ooo`0b0?ooo`030=nLB0000000000000<0000000<0B9cO0?oo
o`3oool0<@3oool00`3OW4P00000000000030000000304RLg`3oool0oooo00H0oooo00<0_g@007Bo
o`3oool0=`3oool00`2oM000M;oo0?ooo`0g0?ooo`030;md001d_ol0oooo00L0oooo00<0_g@007Bo
o`3oool0<P3oool01`3ookl0M4RL0=ooo`3oool0oono07@0B02Lgol0<`3oool01`3ookl0M4RL0=oo
o`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`030?ooo`009@3oool00`3ookl0M018
09cOo`080?ooo`030;md001d_ol0oooo0380oooo00H0omnL04Q8W03Oool0oooO09a8001d_old0?oo
o`060?oOW018B9`0gooo0?oog`2LB000M;oo2@3oool00`2oM000M;oo0?ooo`0g0?ooo`030;md001d
_ol0oooo03L0oooo00<0_g@007Boo`3oool01`3oool00`2oM000M;oo0?ooo`0b0?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`0c0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`08
0?ooo`030;md001d_ol0oooo00<0oooo000S0?ooo`040?oOW0180000001809cOo`@0oooo00L0omnL
04P0B02Lgol0oooo0?oog`2LB4P0W=oo03@0oooo00D0gia804RLg`3ooml0W4P007Boo`0e0?ooo`05
0=nLB018W=l0oooO09a8001d_ol0103oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0<`3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0<`3oool01`3ogi`0B01809cOo`3oool0oooO
09a8B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0<`3oool01`3ogi`0B000
07Boo`3oool0omnL04Q8W03Oool0<`3oool01`3ogi`0B00007Boo`3oool0omnL04Q8W03Oool00`3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0103oool002D0oooo00<0gia8001d_`3oool0
0`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo03<0oooo00D0oooO09a8B02Lgml0
W4P007Boo`0e0?ooo`050?oog`2LB4P0W=oO09a8001d_ol0103oool00`3ookl0M000000000020000
000307Boo`3oool0oooo0380oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0b0?oo
o`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool00P3oool00`3ookl0M000000000020000
000307Boo`3oool0oooo0380oooo00H0omnL04Q8W02LM00000000000B02Lgold0?ooo`060?oOW018
B9`0W7@00000000004P0W=oo103oool00`3ookl0M000000000020000000307Boo`3oool0oooo00<0
oooo000U0?ooo`030?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol0>@3oool0103ogi`0B4Qd
07A8001d_olf0?ooo`040?oOW018B7@0M4P007Boo`@0oooo00<0oooO09a8B02Lgol0=`3oool00`3o
oml0W4Q809cOo`0g0?ooo`030?oog`2LB4P0W=oo00L0oooo00<0oooO09a8B02Lgol0=`3oool00`3o
okl0M01d0;ooo`0g0?ooo`030?oo_`1d07@0_ooo00L0oooo00<0oooO09a8B02Lgol0203oool00240
oooo00H0omnL04P0M02oool0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo03T0oooo00<0gia8
0000001d_ol0=`3oool00`3OW4P0000007Boo`050?ooo`030;md001d_ol0oooo03L0oooo00<0_g@0
07Boo`3oool0=`3oool00`2oM000M;oo0?ooo`070?ooo`030;md001d_ol0oooo03L0oooo00H0_g@0
07Boo`3oool0okmd0018W03Ooold0?ooo`060;md001d_ol0oooo0?noM000B9`0gooo103oool00`2o
M000M;oo0?ooo`070?ooo`008P3oool01@3o_g@000000000000007@0_ooo00D0oooo00H0gia80000
0000000000000000M02ooolf0?ooo`030?oog`2LB000M;oo03L0oooo00<0oooO09a8001d_ol01@3o
ool01P3OW4P00000000000000000001d0;oooc@0oooo00H0gia800000000000000000000M02ooold
0?ooo`060=nLB000000000000000000007@0_ooo103oool01P3OW4P00000000000000000001d0;oo
oc@0oooo00D0oooO09a800000000001809cOo`0e0?ooo`050?oog`2LB00000000000B02Lgol01@3o
ool01P3OW4P00000000000000000001d0;ooo`@0oooo003o0?oook40oooo003o0?oook40oooo003o
0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo000R
0?ooool00000R`0000040?ooo`008P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0oooo
Q`3oool00`000000oooo0?ooo`020?ooo`001P3oool00`3ogi`0B01d0;ooo`020?ooo`0;0=nLB000
000000000000B02Lgol0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`07
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`001P3oool02`3o
gi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0okmd0018W03O
ool0oooo0?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0
oooo0080oooo00060?ooo`030?oOW01807@0_ooo00H0oooo00<0_g@007Boo`3oool01`3oool00`2o
M000M;oo0?ooo`060?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?oo
o`001P3oool00`3ogi`0B01d0;ooo`050?ooo`030?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3o
ool01P3oool300000?l0ooooQ03oool4000000@0oooo00060?ooo`030?oOW01807@0_ooo00<0oooo
00@0omnL04P0000004P0W=oo103oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01`3oool0
0`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool000H0oooo00<0omnL04P0
M02oool01@3oool00`3OW4P007Bo0?ooo`030?ooo`030?oo_`1d000000000080000000<0M;oo0?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool000@0
oooo00D0_g@00000B02L_i`0B01d0;ooo`050?ooo`030?oOW01807@0_ooo00<0oooo00<0oooO09a8
B02Lgol02`3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool000D0
oooo00/0okmd0000000007@0_ooo0?ooo`3ogi`0B01d0;ooo`3oool0gia8001d_`050?ooo`030;md
001d_ol0oooo00X0oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo
00060?ooo`030?oOW01807@0_ooo0080oooo00D0okmd000000000000001d0;ooo`050?ooo`060=nL
B000000000000000000007@0_ooo1`3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3o
ool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000
003oool0oooo0080oooo000R0?ooo`800000o`3ooon60?ooo`<00000103oool00280oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?oo
o`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool0
0280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo
0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3o
oon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool0
0`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00280oooo0P00003o0?ooohH0oooo0`0000040?ooo`008P3oool00`000000oooo
0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3o
oon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool0
0`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3o
ool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000
003oool0oooo0080oooo000R0?ooo`800000o`3ooon60?ooo`<00000103oool00280oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?oo
o`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool0
0280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo
0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3o
oon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool0
0`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00280oooo0P00003o0?ooohH0oooo0`0000040?ooo`008P3oool00`000000oooo
0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3o
oon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool0
0`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3o
ool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000@0?ooo`030?oOW01807@0_ooo
00@0oooo00<0oooO09a8001d_ol0203oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?oo
o`3oool00P3oool00100oooo00<0omnL04P0M02oool0103oool00`3ooml0W4P007Boo`080?ooo`03
0000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`00403oool01@3ogi`0B01d
0;ooo`3oool0gia800D0000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool00100oooo00X0omnL04P0M02oool0oooo0?oOW018B9`0gooo
0?oog`2LB000M;oo203oool300000?l0ooooQ03oool4000000@0oooo000@0?ooo`030?oOW01807@0
_ooo0080oooo00D0gia804RLg`3ooml0W4P007Boo`080?ooo`030000003oool0oooo0;X0oooo3`00
0?nm0?ooo`030000003oool0oooo0080oooo000@0?ooo`030?oOW01807@0_ooo0080oooo00D0oooO
09a8B02Lgml0W4P007Boo`080?ooo`030000003oool0oooo0:l0oooo2`000?l?0?ooo`/0003o/P3o
ool00`000000oooo0?ooo`020?ooo`003P3oool01@2oM000001809boW01807@0_ooo00<0oooo00@0
omnL04Q8M01dB000M;oo203oool00`000000oooo0?ooo`2Z0?ooo`D0003o9@3oool50000ojd0oooo
00<000000?ooo`3oool00P3oool000l0oooo00@0okmd0000000007@0_ooo103oool00`3OW4P00000
07Boo`080?ooo`030000003oool0oooo0:D0oooo1@000?l_0?ooo`H0003oY`3oool00`000000oooo
0?ooo`020?ooo`00403oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2LB000M;oo00P0oooo00<0
00000?ooo`3oool0X@3oool40000ocX0oooo10000?nS0?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo09h0oooo0`000?m20?ooo`<0003oX03oool00`000000oooo0?ooo`02
0?ooo`008P3oool00`000000oooo0?ooo`2K0?ooo`<0003oB03oool30000oid0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0U`3oool40000odh0oooo0`000?nJ0?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo09@0oooo0`000?mE0?ooo`<0003o
U`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`2A0?ooo`<0003oF`3o
ool30000oi@0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0S`3oool2
0000of40oooo0P000?nB0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
08d0oooo0P000?mU0?ooo`80003oT03oool00`000000oooo0?ooo`020?ooo`008P3oool2000008`0
oooo0P000?mY0?ooo`80003oS03oool3000000@0oooo000R0?ooo`030000003oool0oooo08T0oooo
0P000?m]0?ooo`80003oS03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?oo
o`270?ooo`80003oL@3oool20000ohX0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0Q@3oool20000ogD0oooo0P000?n80?ooo`030000003oool0oooo0080oooo000R0?oo
o`030000003oool0oooo08<0oooo0P000?mi0?ooo`80003oQP3oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`220?ooo`030000o`3oool0oooo07/0oooo00<0003o0?ooo`3o
ool0P`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`200?ooo`80003o
O`3oool20000oh<0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0O`3o
ool00`000?l0oooo0?ooo`210?ooo`030000o`3oool0oooo0800oooo00<000000?ooo`3oool00P3o
ool00280oooo00<000000?ooo`3oool0O@3oool20000ohD0oooo0P000?n00?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo07`0oooo00<0003o0?ooo`3oool0Q`3oool20000
ogh0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0NP3oool20000oh`0
oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo
0?ooo`1i0?ooo`030000o`3oool0oooo08d0oooo0P000?mk0?ooo`030000003oool0oooo0080oooo
000R0?ooo`030000003oool0oooo07L0oooo0P000?nB0?ooo`030000o`3oool0oooo07P0oooo00<0
00000?ooo`3oool00P3oool00280oooo0P00001g0?ooo`030000o`3oool0oooo09<0oooo0P000?mf
0?ooo`<00000103oool00280oooo00<000000?ooo`3oool0M03oool20000oiP0oooo0P000?mf0?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`3o
ool0VP3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000
003oool0oooo0780oooo00<0003o0?ooo`3oool0W03oool00`000?l0oooo0?ooo`1b0?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0700oooo0P000?nP0?ooo`030000o`3o
ool0oooo0740oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0K`3oool0
0`000?l0oooo0?ooo`2Q0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool00P3oool0
0280oooo00<000000?ooo`3oool0KP3oool00`000?l0oooo0?ooo`2S0?ooo`030000o`3oool0oooo
06l0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0K@3oool00`000?l0
oooo0?ooo`2U0?ooo`030000o`3oool0oooo06h0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`2W0?ooo`030000o`3oool0oooo06d0oooo
00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?oo
o`2Y0?ooo`030000o`3oool0oooo06`0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`2[0?ooo`030000o`3oool0oooo06/0oooo00<00000
0?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo0?ooo`2]0?oo
o`030000o`3oool0oooo06X0oooo00<000000?ooo`3oool00P3oool00280oooo0P00001Y0?ooo`03
0000o`3oool0oooo0:l0oooo00<0003o0?ooo`3oool0I`3oool3000000@0oooo000R0?ooo`030000
003oool0oooo06L0oooo00<0003o0?ooo`3oool0/@3oool00`000?l0oooo0?ooo`1X0?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool0/`3o
ool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0
oooo06D0oooo00<0003o0?ooo`3oool0]@3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0]`3oool00`00
0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo06<0
oooo00<0003o0?ooo`3oool0^@3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0^`3oool00`000?l0oooo
0?ooo`1S0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0640oooo00<0
003o0?ooo`3oool0_@3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool0_@3oool00`000?l0oooo0?ooo`1R
0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0600oooo00<0003o0?oo
o`3oool0_`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo05l0oooo00<0003o0?ooo`3oool0`@3oool00`000?l0oooo0?ooo`1P0?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0
``3oool00`000?l0oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo05h0oooo00<0003o0?ooo`3oool0``3oool00`000?l0oooo0?ooo`1O0?ooo`030000003o
ool0oooo0080oooo000R0?ooo`800000GP3oool00`000?l0oooo0?ooo`350?ooo`030000o`3oool0
oooo05`0oooo0`0000040?ooo`008P3oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo
0<L0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000
oooo0?ooo`1K0?ooo`030000o`3oool0oooo0<T0oooo00<0003o0?ooo`3oool0G03oool00`000000
oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo0<T0oooo
00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?oo
o`1J0?ooo`030000o`3oool0oooo0</0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?oo
o`020?ooo`008P3oool00`000000oooo0?ooo`1I0?ooo`030000o`3oool0oooo0<d0oooo00<0003o
0?ooo`3oool0FP3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1H0?oo
o`030000o`3oool0oooo0<l0oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo0<l0oooo00<0003o0?ooo`3o
ool0F@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1G0?ooo`030000
o`3oool0oooo0=40oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`001P3o
ool00`3ogi`0B01d0;ooo`040?ooo`090?oog`2LB000M;oo0?ooo`3ogi`0B01d0;ooo`3oool0gia8
0080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`1F0?ooo`030000o`3oool0oooo
0=<0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`001P3oool00`3ogi`0
B01d0;ooo`040?ooo`030?oog`2LB000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo00L0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`3E0?ooo`030000o`3oool0
oooo05H0oooo00<000000?ooo`3oool00P3oool000H0oooo00D0omnL04P0M02oool0oooo0=nLB005
0000000304RLg`3oool0oooo00H0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`1E
0?ooo`030000o`3oool0oooo0=D0oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`02
0?ooo`001P3oool02P3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooO09a8001d_ol90?ooo`03
0;md001d_ol0oooo00H0oooo0`00001D0?ooo`030000o`3oool0oooo0=L0oooo00<0003o0?ooo`3o
ool0DP3oool4000000@0oooo00060?ooo`030?oOW01807@0_ooo0080oooo00D0gia804RLg`3ooml0
W4P007Boo`040?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`070?ooo`030000003oool0
oooo05@0oooo00<0003o0?ooo`3oool0e`3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0
oooo0080oooo00060?ooo`030?oOW01807@0_ooo0080oooo00D0oooO09a8B02Lgml0W4P007Boo`04
0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`1C
0?ooo`030000o`3oool0oooo0=T0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`02
0?ooo`00103oool01@2oM000001809boW01807@0_ooo00<0oooo00@0omnL04Q8M01dB000M;oo103o
ool00`3ooml0W4Q809cOo`0;0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool0f@3o
ool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0080oooo00050?ooo`040?noM0000000
001d0;ooo`@0oooo00<0gia80000001d_ol01@3oool00`2oM000M;oo0?ooo`0:0?ooo`030000003o
ool0oooo05<0oooo00<0003o0?ooo`3oool0fP3oool00`000?l0oooo0?ooo`1C0?ooo`030000003o
ool0oooo0080oooo00060?ooo`030?oOW01807@0_ooo00@0oooo00<0oooO09a8001d_ol01@3oool0
1P3OW4P00000000000000000001d0;ooo`L0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo
0?ooo`3K0?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool00P3oool00280oooo00<0
00000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`3L0?ooo`030000o`3oool0oooo0580oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`3M
0?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?oo
o`3oool0D@3oool00`000?l0oooo0?ooo`3N0?ooo`030000o`3oool0oooo0540oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`3O0?ooo`03
0000o`3oool0oooo0540oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0
D03oool00`000?l0oooo0?ooo`3P0?ooo`030000o`3oool0oooo0500oooo00<000000?ooo`3oool0
0P3oool00280oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`3Q0?ooo`030000o`3o
ool0oooo0500oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0C`3oool0
0`000?l0oooo0?ooo`3R0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool00P3oool0
0280oooo0P00001?0?ooo`030000o`3oool0oooo0><0oooo00<0003o0?ooo`3oool0C@3oool30000
00@0oooo000R0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0i03oool00`000?l0
oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04d0oooo
00<0003o0?ooo`3oool0i@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo
000R0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0iP3oool00`000?l0oooo0?oo
o`1=0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04d0oooo00<0003o
0?ooo`3oool0iP3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo0080oooo000R0?oo
o`030000003oool0oooo04`0oooo00<0003o0?ooo`3oool0j03oool00`000?l0oooo0?ooo`1<0?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04`0oooo00<0003o0?ooo`3o
ool0j03oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000
003oool0oooo04/0oooo00<0003o0?ooo`3oool0j@3oool00`000?l0oooo0?ooo`1<0?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool0jP3o
ool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0
oooo04/0oooo00<0003o0?ooo`3oool0jP3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0j`3oool00`00
0?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04X0
oooo00<0003o0?ooo`3oool0j`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0k03oool00`000?l0oooo
0?ooo`1:0?ooo`030000003oool0oooo0080oooo000R0?ooo`800000BP3oool00`000?l0oooo0?oo
o`3]0?ooo`030000o`3oool0oooo04P0oooo0`0000040?ooo`008P3oool00`000000oooo0?ooo`19
0?ooo`030000o`3oool0oooo0>d0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`02
0?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo0>l0oooo00<0003o0?oo
o`3oool0B@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`180?ooo`03
0000o`3oool0oooo0>l0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`00
8P3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo0>l0oooo00<0003o0?ooo`3oool0
B@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`170?ooo`030000o`3o
ool0oooo0?40oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`008P3oool0
0`000000oooo0?ooo`170?ooo`030000o`3oool0oooo0?40oooo00<0003o0?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo
0?40oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000
oooo0?ooo`170?ooo`030000o`3oool0oooo0?40oooo00<0003o0?ooo`3oool0B03oool00`000000
oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0?<0oooo
00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?oo
o`160?ooo`030000o`3oool0oooo0?<0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?oo
o`020?ooo`008P3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0?<0oooo00<0003o
0?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`008P3oool2000004L0oooo00<0003o0?oo
o`3oool0l`3oool00`000?l0oooo0?ooo`150?ooo`<00000103oool00280oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`3c0?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3o
ool00P3oool00280oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`3d0?ooo`030000
o`3oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A@3o
ool00`000?l0oooo0?ooo`3e0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool00P3o
ool00280oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`3e0?ooo`030000o`3oool0
oooo04H0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A@3oool00`00
0?l0oooo0?ooo`3e0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00280
oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`3e0?ooo`030000o`3oool0oooo04H0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`3e0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00280oooo00<0
00000?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g0?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g
0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?oo
o`3oool0A03oool00`000?l0oooo0?ooo`3g0?ooo`030000o`3oool0oooo04D0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g0?ooo`03
0000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0
A03oool00`000?l0oooo0?ooo`3g0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0
0P3oool00280oooo0P0000150?ooo`030000o`3oool0oooo0?L0oooo00<0003o0?ooo`3oool0@`3o
ool3000000@0oooo000R0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0m`3oool0
0`000?l0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
04@0oooo00<0003o0?ooo`3oool0m`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo
0080oooo000R0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0m`3oool00`000?l0
oooo0?ooo`150?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04@0oooo
00<0003o0?ooo`3oool0m`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo
000R0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0n@3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04<0oooo00<0003o
0?ooo`3oool0n@3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo0080oooo000R0?oo
o`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0n@3oool00`000?l0oooo0?ooo`140?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3o
ool0n@3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo0080oooo000@0?ooo`030?oO
W01807@0_ooo0080oooo00D0gia8000000000000001809cOo`080?ooo`030000003oool0oooo04<0
oooo00<0003o0?ooo`3oool0n@3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo0080
oooo000@0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01`3o
ool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo0?T0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`020?ooo`00403oool00`3ogi`0B01d0;ooo`060?ooo`030;md001d_ol0
oooo00H0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool00P3oool00100oooo00<0omnL04P0M02oool01P3oool00`2o
M000M;oo0?ooo`060?ooo`<00000@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000o`3oool0oooo
0440oooo100000040?ooo`00403oool02`3ogi`0B01d0;ooo`3oool0omnL04P0B02Lgol0oooo0?oo
g`2LB4P0W=oo00L0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool00P3oool00100oooo00H0omnL04P0M02oool0oooo
0?oo_`1d00030000000307Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0@`3oool00`000?l0
oooo0?ooo`3i0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool00P3oool000h0oooo
00T0_g@00000B02L_i`0B01d0;ooo`3oool0oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`13
0?ooo`030000o`3oool0oooo0?T0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`02
0?ooo`003`3oool0103o_g@000000000M02oool20?ooo`030;md001d_ol0oooo00X0oooo00<00000
0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000o`3oool0oooo04@0oooo00<00000
0?ooo`3oool00P3oool00100oooo00<0omnL04P0M02oool00P3oool01P3OW4P00000000000000000
001d0;ooo`L0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000o`3o
ool0oooo04@0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0@`3oool0
0`000?l0oooo0?ooo`3i0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool00P3oool0
0280oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`3i0?ooo`030000o`3oool0oooo
04@0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0@`3oool00`000?l0
oooo0?ooo`3h0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g0?ooo`030000o`3oool0oooo04D0oooo
00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?oo
o`3g0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool00280oooo00<00000
0?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g0?ooo`030000o`3oool0oooo04D0oooo00<00000
0?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`3g0?oo
o`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool00P3oool00280oooo0P0000150?ooo`03
0000o`3oool0oooo0?L0oooo00<0003o0?ooo`3oool0@`3oool3000000@0oooo000R0?ooo`030000
003oool0oooo04@0oooo00<0003o0?ooo`3oool0m`3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0m`3o
ool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0
oooo04@0oooo00<0003o0?ooo`3oool0m`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0m`3oool00`00
0?l0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04@0
oooo00<0003o0?ooo`3oool0m`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0m@3oool00`000?l0oooo
0?ooo`160?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04D0oooo00<0
003o0?ooo`3oool0m@3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0m@3oool00`000?l0oooo0?ooo`16
0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04D0oooo00<0003o0?oo
o`3oool0m@3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo04D0oooo00<0003o0?ooo`3oool0m@3oool00`000?l0oooo0?ooo`160?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0
m03oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo04H0oooo00<0003o0?ooo`3oool0l`3oool00`000?l0oooo0?ooo`170?ooo`030000003o
ool0oooo0080oooo000R0?ooo`800000A`3oool00`000?l0oooo0?ooo`3c0?ooo`030000o`3oool0
oooo04D0oooo0`0000040?ooo`008P3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo
0?<0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000
oooo0?ooo`160?ooo`030000o`3oool0oooo0?<0oooo00<0003o0?ooo`3oool0A`3oool00`000000
oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo0?<0oooo
00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?oo
o`170?ooo`030000o`3oool0oooo0?40oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?oo
o`020?ooo`008P3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo0?40oooo00<0003o
0?ooo`3oool0B03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`170?oo
o`030000o`3oool0oooo0?40oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0oooo0?40oooo00<0003o0?ooo`3o
ool0B03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000
o`3oool0oooo0>l0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`008P3o
ool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo0>l0oooo00<0003o0?ooo`3oool0B@3o
ool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0
oooo0>l0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`190?ooo`030000o`3oool0oooo0>d0oooo00<0003o0?ooo`3oool0BP3oool00`00
0000oooo0?ooo`020?ooo`008P3oool2000004X0oooo00<0003o0?ooo`3oool0k@3oool00`000?l0
oooo0?ooo`180?ooo`<00000103oool00280oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo
0?ooo`3]0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool00P3oool00280oooo00<0
00000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`3/0?ooo`030000o`3oool0oooo04/0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`3[
0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?oo
o`3oool0BP3oool00`000?l0oooo0?ooo`3[0?ooo`030000o`3oool0oooo04/0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`3[0?ooo`03
0000o`3oool0oooo04/0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0
B`3oool00`000?l0oooo0?ooo`3Y0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0
0P3oool00280oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`3Y0?ooo`030000o`3o
ool0oooo04`0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0B`3oool0
0`000?l0oooo0?ooo`3Y0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool00P3oool0
0280oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`3W0?ooo`030000o`3oool0oooo
04d0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`3W0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`3V0?ooo`030000o`3oool0oooo04h0oooo
00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?oo
o`3U0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool00P3oool00280oooo0P00001>
0?ooo`030000o`3oool0oooo0>@0oooo00<0003o0?ooo`3oool0C@3oool3000000@0oooo000R0?oo
o`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0h`3oool00`000?l0oooo0?ooo`1?0?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3o
ool0hP3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000
003oool0oooo04l0oooo00<0003o0?ooo`3oool0h@3oool00`000?l0oooo0?ooo`1@0?ooo`030000
003oool0oooo0080oooo000R0?ooo`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0h03o
ool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0
oooo0500oooo00<0003o0?ooo`3oool0g`3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`3oool0gP3oool00`00
0?l0oooo0?ooo`1B0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0540
oooo00<0003o0?ooo`3oool0g@3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo0080
oooo000R0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0g03oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo0080oooo00060?ooo`030?oOW01807@0_ooo0080oooo00/0
gia8000000000000001809cOo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0
oooo00L0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`3K0?ooo`030000o`3oool0
oooo05<0oooo00<000000?ooo`3oool00P3oool000H0oooo00/0omnL04P0M02oool0oooo0?noM000
B9`0gooo0?ooo`3ooml0W4Qd0;ooo`030?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`07
0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0fP3oool00`000?l0oooo0?ooo`1D
0?ooo`030000003oool0oooo0080oooo00060?ooo`030?oOW01807@0_ooo00H0oooo00<0_g@007Bo
o`3oool01`3oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo05<0oooo00<0003o0?oo
o`3oool0f03oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00060?ooo`03
0?oOW01807@0_ooo00H0oooo00<0_g@007Boo`3oool01`3oool00`2oM000M;oo0?ooo`060?ooo`<0
0000E03oool00`000?l0oooo0?ooo`3G0?ooo`030000o`3oool0oooo0580oooo100000040?ooo`00
1P3oool02`3ogi`0B01d0;ooo`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00<0oooo00L0
omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00L0oooo00<000000?ooo`3oool0E@3oool00`000?l0
oooo0?ooo`3E0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool00P3oool000H0oooo
00H0omnL04P0M02oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo0080oooo00<0oono07@0
000000000P0000000`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<0003o0?oo
o`3oool0e@3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo0080oooo00040?ooo`09
0;md000004P0W;nL04P0M02oool0oooo0?oog`2LB4P0W=oo00L0oooo00<0oooO09a8B02Lgol02`3o
ool00`000000oooo0?ooo`1F0?ooo`030000o`3oool0oooo0=<0oooo00<0003o0?ooo`3oool0E`3o
ool00`000000oooo0?ooo`020?ooo`001@3oool0103o_g@000000000M02oool20?ooo`030;md001d
_ol0oooo00L0oooo00<0_g@007Boo`3oool02P3oool00`000000oooo0?ooo`1G0?ooo`030000o`3o
ool0oooo0=40oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`020?ooo`001P3oool0
0`3ogi`0B01d0;ooo`020?ooo`060=nLB000000000000000000007@0_ooo103oool01P3OW4P00000
000000000000001d0;ooo`L0oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`3A0?oo
o`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3o
ool0F03oool00`000?l0oooo0?ooo`3?0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3o
ool00P3oool00280oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`3=0?ooo`030000
o`3oool0oooo05X0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0F@3o
ool00`000?l0oooo0?ooo`3<0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool00P3o
ool00280oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`3;0?ooo`030000o`3oool0
oooo05/0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0F`3oool00`00
0?l0oooo0?ooo`390?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool00P3oool00280
oooo00<000000?ooo`3oool0G03oool00`000?l0oooo0?ooo`370?ooo`030000o`3oool0oooo05d0
oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0G03oool00`000?l0oooo
0?ooo`370?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00280oooo0P00
001N0?ooo`030000o`3oool0oooo0<D0oooo00<0003o0?ooo`3oool0G03oool3000000@0oooo000R
0?ooo`030000003oool0oooo05h0oooo00<0003o0?ooo`3oool0``3oool00`000?l0oooo0?ooo`1O
0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo05h0oooo00<0003o0?oo
o`3oool0``3oool00`000?l0oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo05l0oooo00<0003o0?ooo`3oool0`@3oool00`000?l0oooo0?ooo`1P0?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0600oooo00<0003o0?ooo`3oool0
_`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo0640oooo00<0003o0?ooo`3oool0_P3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003o
ool0oooo0080oooo000R0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool0_@3oool0
0`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo
0680oooo00<0003o0?ooo`3oool0_03oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo
0080oooo000R0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool0^P3oool00`000?l0
oooo0?ooo`1S0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo06@0oooo
00<0003o0?ooo`3oool0^03oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo
000R0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool0]P3oool00`000?l0oooo0?oo
o`1U0?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo06H0oooo00<0003o
0?ooo`3oool0]03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo000R0?oo
o`800000J03oool00`000?l0oooo0?ooo`2b0?ooo`030000o`3oool0oooo06D0oooo0`0000040?oo
o`008P3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0oooo0;00oooo00<0003o0?ooo`3o
ool0J03oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1Y0?ooo`030000
o`3oool0oooo0:h0oooo00<0003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`020?ooo`008P3o
ool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo0:`0oooo00<0003o0?ooo`3oool0JP3o
ool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo0:X0oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`1/0?ooo`030000o`3oool0oooo0:P0oooo00<0003o0?ooo`3oool0K03oool00`00
0000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo0:H0
oooo00<0003o0?ooo`3oool0K@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo
0?ooo`1^0?ooo`030000o`3oool0oooo0:@0oooo00<0003o0?ooo`3oool0KP3oool00`000000oooo
0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0oooo0:80oooo00<0
003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1`
0?ooo`80003oX03oool20000og80oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?oo
o`3oool0LP3oool00`000?l0oooo0?ooo`2L0?ooo`030000o`3oool0oooo0780oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0L`3oool00`000?l0oooo0?ooo`2J0?ooo`03
0000o`3oool0oooo07<0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0
M03oool20000oiP0oooo0P000?mf0?ooo`030000003oool0oooo0080oooo000R0?ooo`800000M`3o
ool00`000?l0oooo0?ooo`2D0?ooo`030000o`3oool0oooo07@0oooo0`0000040?ooo`008P3oool0
0`000000oooo0?ooo`1g0?ooo`030000o`3oool0oooo0940oooo0P000?mi0?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo07P0oooo0P000?n?0?ooo`80003oN`3oool00`00
0000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo08/0
oooo00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo
0?ooo`1k0?ooo`030000o`3oool0oooo08P0oooo0P000?mn0?ooo`030000003oool0oooo0080oooo
000R0?ooo`030000003oool0oooo07`0oooo0P000?n70?ooo`030000o`3oool0oooo07h0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0?ooo`22
0?ooo`80003oP@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`1o0?oo
o`030000o`3oool0oooo07l0oooo0P000?n30?ooo`030000003oool0oooo0080oooo000R0?ooo`03
0000003oool0oooo0800oooo0P000?mn0?ooo`030000o`3oool0oooo08<0oooo00<000000?ooo`3o
ool00P3oool00280oooo00<000000?ooo`3oool0PP3oool00`000?l0oooo0?ooo`1j0?ooo`030000
o`3oool0oooo08@0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0P`3o
ool30000ogL0oooo0P000?n70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0
oooo08H0oooo0P000?mc0?ooo`80003oR@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`280?ooo`80003oK`3oool20000oh/0oooo00<000000?ooo`3oool00P3oool00280
oooo0P00002;0?ooo`<0003oJ@3oool30000oh/0oooo0`0000040?ooo`008P3oool00`000000oooo
0?ooo`2=0?ooo`80003oI@3oool20000oi00oooo00<000000?ooo`3oool00P3oool00280oooo00<0
00000?ooo`3oool0S`3oool20000of40oooo0P000?nB0?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo0940oooo0`000?mK0?ooo`<0003oU03oool00`000000oooo0?ooo`02
0?ooo`008P3oool00`000000oooo0?ooo`2D0?ooo`<0003oE@3oool30000oiL0oooo00<000000?oo
o`3oool00P3oool00280oooo00<000000?ooo`3oool0U`3oool30000odl0oooo0`000?nJ0?ooo`03
0000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo09X0oooo10000?m80?ooo`<0003o
W@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`2N0?ooo`<0003o@P3o
ool30000oj00oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0X@3oool4
0000ocX0oooo10000?nS0?ooo`030000003oool0oooo0080oooo000@0?ooo`030?oOW01807@0_ooo
0080oooo00D0oono07@000000000001d0;ooo`080?ooo`030000003oool0oooo0:D0oooo1@000?l`
0?ooo`D0003oY`3oool00`000000oooo0?ooo`020?ooo`00403oool00`3ogi`0B01d0;ooo`020?oo
o`060;md001d_ol0oooo0?oOW018B9`0gooo1`3oool00`000000oooo0?ooo`2Z0?ooo`D0003o9@3o
ool60000oj`0oooo00<000000?ooo`3oool00P3oool00100oooo00/0omnL04P0M02oool0oooo0?oo
_`1dB9`0gooo0?ooo`3ookl0M01809cOo`070?ooo`030000003oool0oooo0:l0oooo20000?lE0?oo
o`P0003o/P3oool00`000000oooo0?ooo`020?ooo`00403oool02`3ogi`0B01d0;ooo`3oool0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo0`00002g0?oooaD0003o]`3oool4000000@0oooo
000@0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B00007Boo`3oool0omnL04Q8W03Oool01`3oool0
0`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00100oooo00X0omnL04P0
M02oool0oooo0?oOW018B9`0W7@00000000004P0W=oo203oool00`000000oooo0?ooo`3o0?ooohL0
oooo00<000000?ooo`3oool00P3oool000h0oooo00T0_g@00000B02L_i`0B01d0;ooo`3oool0oono
07@0M02oool02`3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool0
00l0oooo00@0okmd0000000007@0_ooo0P3oool01P2oM000M;oo0?ooo`3o_g@004RL0=ooo`L0oooo
00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000@0?ooo`030?oOW018
07@0_ooo0080oooo00D0oooO09a800000000001809cOo`080?ooo`030000003oool0oooo0?l0oooo
Q`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o
0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo0P00003o0?ooohH0oooo0`0000040?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o
0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000
oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool0
0P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3o
ool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`800000o`3ooon60?ooo`<00000
103oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3o
ool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0oooo
Q`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o
0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo0P00003o0?ooohH0oooo0`0000040?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo
00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003o
ool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o
0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?oo
o`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000
oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool0
0P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3o
ool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0oooo
Q`3oool00`000000oooo0?ooo`020?ooo`008P3oool200000?l0ooooQP3oool3000000@0oooo000R
0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`00
0000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3o
ool0o`3ooon70?ooo`030000003oool0oooo0080oooo000R0?ooo`030000003oool0oooo0?l0oooo
Q`3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<0
00000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0
oooo0080oooo000R0?ooo`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?oo
o`008P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool000H0oooo
00<0omnL04P0M02oool00P3oool02`3ookl0M0000000000007@0_ooo0?ooo`3ogi`0B01d0;ooo`3o
ool0gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<0
00000?ooo`3oool00P3oool000H0oooo00<0omnL04P0M02oool00P3oool01P2oM000M;oo0?ooo`3o
gi`0B4RL0=ooo`<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00L0oooo00<000000?oo
o`3oool0o`3ooon70?ooo`030000003oool0oooo0080oooo00060?ooo`0;0?oOW01807@0_ooo0?oo
o`3ookl0M4RL0=ooo`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`060?ooo`030000
003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`020?ooo`001P3oool02`3ogi`0B01d0;oo
o`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01P3oool3
00000?l0ooooQ03oool4000000@0oooo00060?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B00007Bo
o`3oool0omnL04Q8W03Oool00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01`3oool0
0`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool000H0oooo00X0omnL04P0
M02oool0oooo0?oOW018B9`0W7@00000000004P0W=oo103oool00`3ookl0M0000000000200000003
07Boo`3oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo0080
oooo00040?ooo`090;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo00L0oooo00<0oooO
09a8B02Lgol02`3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool00P3oool0
00D0oooo00@0okmd0000000007@0_ooo0P3oool01P2oM000M;oo0?ooo`3o_g@004RL0=ooo`@0oooo
00<0_g@007Boo`3oool02P3oool00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool0
0P3oool000H0oooo00<0omnL04P0M02oool00P3oool01@3ooml0W4P00000000004P0W=oo00D0oooo
00H0gia800000000000000000000M02oool70?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`008P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00280oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000R0?ooool00000R`00
00040?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {3.16798, 13.2069, 0.0119098, \
0.0119098}}]
}, Open  ]],

Cell["This shows data and fitted circle together.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[{dg, fg}, AspectRatio \[Rule] Automatic]; \)], "Input",
  CellLabel->"In[46]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99753 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.78338 0.456318 -6.3461 0.456318 [
[.04189 -0.0125 -4.21875 -10.9375 ]
[.04189 -0.0125 4.21875 0 ]
[.27005 -0.0125 -7.5625 -10.9375 ]
[.27005 -0.0125 7.5625 0 ]
[.49821 -0.0125 -4.21875 -10.9375 ]
[.49821 -0.0125 4.21875 0 ]
[.72637 -0.0125 -7.5625 -10.9375 ]
[.72637 -0.0125 7.5625 0 ]
[.95453 -0.0125 -4.21875 -10.9375 ]
[.95453 -0.0125 4.21875 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04235 -12.875 -5.46875 ]
[-0.0125 .04235 0 5.46875 ]
[-0.0125 .27051 -19.5625 -5.46875 ]
[-0.0125 .27051 0 5.46875 ]
[-0.0125 .49867 -12.875 -5.46875 ]
[-0.0125 .49867 0 5.46875 ]
[-0.0125 .72683 -19.5625 -5.46875 ]
[-0.0125 .72683 0 5.46875 ]
[-0.0125 .95499 -12.875 -5.46875 ]
[-0.0125 .95499 0 5.46875 ]
[ 0 0 -0.125 0 ]
[ 0 .99753 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .99753 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04189 0 m
.04189 .00625 L
s
gsave
.04189 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.27005 0 m
.27005 .00625 L
s
gsave
.27005 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
1.000 setlinewidth
grestore
.49821 0 m
.49821 .00625 L
s
gsave
.49821 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.72637 0 m
.72637 .00625 L
s
gsave
.72637 -0.0125 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
1.000 setlinewidth
grestore
.95453 0 m
.95453 .00625 L
s
gsave
.95453 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.08753 0 m
.08753 .00375 L
s
.13316 0 m
.13316 .00375 L
s
.17879 0 m
.17879 .00375 L
s
.22442 0 m
.22442 .00375 L
s
.31568 0 m
.31568 .00375 L
s
.36132 0 m
.36132 .00375 L
s
.40695 0 m
.40695 .00375 L
s
.45258 0 m
.45258 .00375 L
s
.54384 0 m
.54384 .00375 L
s
.58948 0 m
.58948 .00375 L
s
.63511 0 m
.63511 .00375 L
s
.68074 0 m
.68074 .00375 L
s
.772 0 m
.772 .00375 L
s
.81763 0 m
.81763 .00375 L
s
.86327 0 m
.86327 .00375 L
s
.9089 0 m
.9089 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04235 m
.00625 .04235 L
s
gsave
-0.0125 .04235 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
0 .27051 m
.00625 .27051 L
s
gsave
-0.0125 .27051 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.5) show
1.000 setlinewidth
grestore
0 .49867 m
.00625 .49867 L
s
gsave
-0.0125 .49867 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .72683 m
.00625 .72683 L
s
gsave
-0.0125 .72683 -80.5625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.5) show
1.000 setlinewidth
grestore
0 .95499 m
.00625 .95499 L
s
gsave
-0.0125 .95499 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08798 m
.00375 .08798 L
s
0 .13361 m
.00375 .13361 L
s
0 .17925 m
.00375 .17925 L
s
0 .22488 m
.00375 .22488 L
s
0 .31614 m
.00375 .31614 L
s
0 .36177 m
.00375 .36177 L
s
0 .4074 m
.00375 .4074 L
s
0 .45304 m
.00375 .45304 L
s
0 .5443 m
.00375 .5443 L
s
0 .58993 m
.00375 .58993 L
s
0 .63556 m
.00375 .63556 L
s
0 .6812 m
.00375 .6812 L
s
0 .77246 m
.00375 .77246 L
s
0 .81809 m
.00375 .81809 L
s
0 .86372 m
.00375 .86372 L
s
0 .90935 m
.00375 .90935 L
s
.25 Mabswid
0 0 m
0 .99753 L
s
.04189 .99128 m
.04189 .99753 L
s
.27005 .99128 m
.27005 .99753 L
s
.49821 .99128 m
.49821 .99753 L
s
.72637 .99128 m
.72637 .99753 L
s
.95453 .99128 m
.95453 .99753 L
s
.125 Mabswid
.08753 .99378 m
.08753 .99753 L
s
.13316 .99378 m
.13316 .99753 L
s
.17879 .99378 m
.17879 .99753 L
s
.22442 .99378 m
.22442 .99753 L
s
.31568 .99378 m
.31568 .99753 L
s
.36132 .99378 m
.36132 .99753 L
s
.40695 .99378 m
.40695 .99753 L
s
.45258 .99378 m
.45258 .99753 L
s
.54384 .99378 m
.54384 .99753 L
s
.58948 .99378 m
.58948 .99753 L
s
.63511 .99378 m
.63511 .99753 L
s
.68074 .99378 m
.68074 .99753 L
s
.772 .99378 m
.772 .99753 L
s
.81763 .99378 m
.81763 .99753 L
s
.86327 .99378 m
.86327 .99753 L
s
.9089 .99378 m
.9089 .99753 L
s
.25 Mabswid
0 .99753 m
1 .99753 L
s
.99375 .04235 m
1 .04235 L
s
.99375 .27051 m
1 .27051 L
s
.99375 .49867 m
1 .49867 L
s
.99375 .72683 m
1 .72683 L
s
.99375 .95499 m
1 .95499 L
s
.125 Mabswid
.99625 .08798 m
1 .08798 L
s
.99625 .13361 m
1 .13361 L
s
.99625 .17925 m
1 .17925 L
s
.99625 .22488 m
1 .22488 L
s
.99625 .31614 m
1 .31614 L
s
.99625 .36177 m
1 .36177 L
s
.99625 .4074 m
1 .4074 L
s
.99625 .45304 m
1 .45304 L
s
.99625 .5443 m
1 .5443 L
s
.99625 .58993 m
1 .58993 L
s
.99625 .63556 m
1 .63556 L
s
.99625 .6812 m
1 .6812 L
s
.99625 .77246 m
1 .77246 L
s
.99625 .81809 m
1 .81809 L
s
.99625 .86372 m
1 .86372 L
s
.99625 .90935 m
1 .90935 L
s
.25 Mabswid
1 0 m
1 .99753 L
s
0 0 m
1 0 L
1 .99753 L
0 .99753 L
closepath
clip
newpath
1 0 0 r
.008 w
.96959 .51373 Mdot
.93183 .48056 Mdot
.96336 .51671 Mdot
.96458 .52262 Mdot
.97019 .53294 Mdot
.94393 .51144 Mdot
.94343 .51575 Mdot
.94884 .52601 Mdot
.95853 .5406 Mdot
.96391 .55091 Mdot
.94223 .5342 Mdot
.93047 .52746 Mdot
.94857 .55062 Mdot
.94767 .55481 Mdot
.93353 .54581 Mdot
.92943 .54689 Mdot
.93749 .56016 Mdot
.94974 .57766 Mdot
.94887 .58207 Mdot
.96388 .60241 Mdot
.92807 .57196 Mdot
.94366 .59295 Mdot
.92816 .58288 Mdot
.94584 .60602 Mdot
.93184 .59753 Mdot
.93936 .61058 Mdot
.93772 .61451 Mdot
.95388 .63626 Mdot
.93395 .62196 Mdot
.92171 .61539 Mdot
.92015 .61952 Mdot
.93041 .63551 Mdot
.94591 .65675 Mdot
.92773 .64436 Mdot
.94724 .66968 Mdot
.92299 .65126 Mdot
.91968 .65382 Mdot
.90167 .6417 Mdot
.93454 .68048 Mdot
.91354 .66544 Mdot
.9013 .65916 Mdot
.91576 .67961 Mdot
.9029 .67277 Mdot
.91152 .68743 Mdot
.88841 .67037 Mdot
.93181 .71986 Mdot
.88768 .68183 Mdot
.92308 .72335 Mdot
.91273 .71915 Mdot
.90171 .7143 Mdot
.90354 .72231 Mdot
.87579 .70076 Mdot
.88397 .71516 Mdot
.88376 .72118 Mdot
.88566 .72933 Mdot
.89175 .74169 Mdot
.88286 .73909 Mdot
.89921 .76174 Mdot
.87994 .74878 Mdot
.86296 .73812 Mdot
.85564 .73714 Mdot
.88822 .77607 Mdot
.87989 .7741 Mdot
.88204 .78261 Mdot
.88506 .79202 Mdot
.8556 .76895 Mdot
.85815 .77789 Mdot
.84964 .77579 Mdot
.87371 .80628 Mdot
.84438 .78336 Mdot
.84327 .78869 Mdot
.84282 .79466 Mdot
.82937 .78766 Mdot
.85442 .81914 Mdot
.84918 .82035 Mdot
.8285 .80611 Mdot
.85012 .83419 Mdot
.82733 .81785 Mdot
.81774 .81471 Mdot
.8341 .83752 Mdot
.81644 .82632 Mdot
.82036 .83669 Mdot
.82742 .8502 Mdot
.81249 .84172 Mdot
.79946 .83514 Mdot
.81372 .85583 Mdot
.78072 .82928 Mdot
.80648 .86147 Mdot
.78761 .84902 Mdot
.78282 .85066 Mdot
.79002 .86427 Mdot
.77572 .85638 Mdot
.77545 .86251 Mdot
.75137 .84481 Mdot
.75664 .85646 Mdot
.78536 .89156 Mdot
.74979 .86235 Mdot
.74317 .86208 Mdot
.7505 .87575 Mdot
.75109 .88266 Mdot
.73629 .87418 Mdot
.7492 .89338 Mdot
.71721 .86767 Mdot
.74374 .90047 Mdot
.74325 .90624 Mdot
.70322 .87245 Mdot
.70638 .88183 Mdot
.69877 .88042 Mdot
.70784 .89567 Mdot
.69569 .88969 Mdot
.68268 .88282 Mdot
.69138 .89766 Mdot
.71573 .92811 Mdot
.70475 .92322 Mdot
.68091 .90543 Mdot
.70024 .93081 Mdot
.67554 .91213 Mdot
.68493 .9275 Mdot
.65206 .90061 Mdot
.68454 .93903 Mdot
.64598 .90639 Mdot
.65817 .92447 Mdot
.65976 .93193 Mdot
.64215 .92016 Mdot
.66012 .94395 Mdot
.65549 .9451 Mdot
.6395 .93487 Mdot
.63704 .93813 Mdot
.65152 .9583 Mdot
.63728 .94973 Mdot
.61411 .93219 Mdot
.61521 .9389 Mdot
.61657 .94582 Mdot
.6104 .94518 Mdot
.59614 .93643 Mdot
.58441 .93017 Mdot
.60291 .9541 Mdot
.60356 .96015 Mdot
.56333 .92529 Mdot
.57371 .94099 Mdot
.56707 .93964 Mdot
.5541 .93193 Mdot
.58813 .97118 Mdot
.56178 .95 Mdot
.54379 .93715 Mdot
.55998 .95845 Mdot
.54249 .94601 Mdot
.52942 .93797 Mdot
.53477 .94829 Mdot
.55125 .96971 Mdot
.54538 .96874 Mdot
.53042 .95863 Mdot
.5169 .94992 Mdot
.4976 .93539 Mdot
.5105 .95301 Mdot
.49003 .93721 Mdot
.51637 .96819 Mdot
.49881 .95522 Mdot
.4759 .93685 Mdot
.50833 .97378 Mdot
.46608 .93599 Mdot
.48904 .96335 Mdot
.45625 .93492 Mdot
.47383 .9568 Mdot
.47938 .96661 Mdot
.46517 .95662 Mdot
.43949 .9351 Mdot
.43329 .93301 Mdot
.45231 .9561 Mdot
.46304 .97084 Mdot
.45034 .96211 Mdot
.45269 .96836 Mdot
.41622 .93575 Mdot
.40594 .92929 Mdot
.44022 .96732 Mdot
.40737 .93817 Mdot
.42552 .95997 Mdot
.43002 .96807 Mdot
.40123 .94283 Mdot
.38434 .92942 Mdot
.41725 .96577 Mdot
.38916 .94105 Mdot
.37876 .93398 Mdot
.37054 .92903 Mdot
.39555 .95725 Mdot
.38562 .95048 Mdot
.35786 .92582 Mdot
.37319 .9442 Mdot
.34252 .91652 Mdot
.34229 .91921 Mdot
.33573 .91552 Mdot
.35278 .93538 Mdot
.34423 .9296 Mdot
.3288 .91686 Mdot
.33047 .92117 Mdot
.34071 .93399 Mdot
.31856 .91436 Mdot
.30896 .90722 Mdot
.31755 .91821 Mdot
.31059 .91359 Mdot
.3115 .91678 Mdot
.293 .9005 Mdot
.28035 .89 Mdot
.2859 .89766 Mdot
.29516 .90895 Mdot
.30039 .91616 Mdot
.29379 .91148 Mdot
.2576 .87714 Mdot
.28316 .90449 Mdot
.29402 .91708 Mdot
.26525 .88998 Mdot
.25509 .88141 Mdot
.26142 .88929 Mdot
.26827 .89762 Mdot
.24183 .87259 Mdot
.25603 .88815 Mdot
.26671 .90012 Mdot
.23918 .87381 Mdot
.25254 .88834 Mdot
.25236 .88925 Mdot
.23543 .87336 Mdot
.21339 .85229 Mdot
.21407 .85388 Mdot
.21678 .85743 Mdot
.19489 .83633 Mdot
.23295 .87511 Mdot
.19665 .83946 Mdot
.18982 .83321 Mdot
.20034 .84425 Mdot
.18359 .82797 Mdot
.1956 .84037 Mdot
.17543 .82053 Mdot
.20215 .84751 Mdot
.17069 .81626 Mdot
.16201 .80772 Mdot
.19383 .83961 Mdot
.16481 .81059 Mdot
.16838 .81411 Mdot
.18242 .82802 Mdot
.1507 .79612 Mdot
.15296 .79813 Mdot
.18042 .82527 Mdot
.17747 .82194 Mdot
.14234 .78637 Mdot
.15796 .80148 Mdot
.15829 .80124 Mdot
.15114 .79345 Mdot
.15546 .79707 Mdot
.14388 .78473 Mdot
.14836 .78838 Mdot
.12849 .76761 Mdot
.13628 .77445 Mdot
.11085 .748 Mdot
.12877 .76483 Mdot
.13925 .77416 Mdot
.11835 .75205 Mdot
.10862 .74105 Mdot
.10919 .74028 Mdot
.12521 .7549 Mdot
.11501 .74324 Mdot
.08559 .71229 Mdot
.12518 .75029 Mdot
.12415 .74761 Mdot
.09707 .71881 Mdot
.10808 .72805 Mdot
.1173 .73544 Mdot
.11636 .73259 Mdot
.07593 .6902 Mdot
.06852 .68077 Mdot
.07465 .68482 Mdot
.07812 .68614 Mdot
.07631 .68213 Mdot
.07783 .68138 Mdot
.07686 .67808 Mdot
.09762 .69645 Mdot
.08547 .68186 Mdot
.06428 .65816 Mdot
.08855 .67987 Mdot
.05076 .63946 Mdot
.05713 .64314 Mdot
.08894 .67221 Mdot
.06469 .64516 Mdot
.05424 .63185 Mdot
.06856 .64326 Mdot
.08196 .65368 Mdot
.0616 .63029 Mdot
.05006 .61566 Mdot
.04375 .60621 Mdot
.04409 .60336 Mdot
.05814 .61415 Mdot
.04559 .59829 Mdot
.03217 .5815 Mdot
.03804 .58395 Mdot
.04413 .58656 Mdot
.07194 .61085 Mdot
.05857 .59389 Mdot
.06122 .5929 Mdot
.06661 .5946 Mdot
.02642 .55066 Mdot
.06924 .58969 Mdot
.04591 .56251 Mdot
.02553 .53823 Mdot
.06729 .57605 Mdot
.05671 .56146 Mdot
.04584 .54654 Mdot
.04837 .54497 Mdot
.05368 .54612 Mdot
.02753 .51578 Mdot
.0477 .53169 Mdot
.02381 .50351 Mdot
.03955 .5149 Mdot
.06427 .53523 Mdot
.03745 .50397 Mdot
.04416 .5062 Mdot
.02589 .48339 Mdot
.06316 .51608 Mdot
.02961 .47791 Mdot
.02945 .47307 Mdot
.02823 .46715 Mdot
.03253 .46669 Mdot
.0413 .47066 Mdot
.03513 .45964 Mdot
.02791 .44754 Mdot
.03448 .44919 Mdot
.0661 .47583 Mdot
.03423 .43896 Mdot
.03049 .43016 Mdot
.0473 .44188 Mdot
.04385 .4333 Mdot
.05482 .43911 Mdot
.04555 .42463 Mdot
.04271 .41655 Mdot
.06461 .43316 Mdot
.05376 .41699 Mdot
.02872 .3866 Mdot
.04679 .39928 Mdot
.04994 .397 Mdot
.03248 .37408 Mdot
.07149 .4076 Mdot
.05249 .38307 Mdot
.0438 .36881 Mdot
.07241 .39184 Mdot
.06733 .38113 Mdot
.04442 .35256 Mdot
.073 .37545 Mdot
.06262 .35936 Mdot
.06527 .35626 Mdot
.08197 .36717 Mdot
.07953 .35894 Mdot
.05603 .3296 Mdot
.06312 .33083 Mdot
.06374 .32556 Mdot
.06553 .32144 Mdot
.07751 .32748 Mdot
.09473 .33874 Mdot
.0991 .33712 Mdot
.07996 .31196 Mdot
.10379 .32976 Mdot
.10146 .32137 Mdot
.08884 .30268 Mdot
.06768 .27542 Mdot
.11015 .31176 Mdot
.11566 .31113 Mdot
.07767 .26698 Mdot
.11215 .29528 Mdot
.08172 .25865 Mdot
.0937 .26441 Mdot
.1257 .29018 Mdot
.08744 .24567 Mdot
.11454 .2665 Mdot
.12543 .27112 Mdot
.09671 .2361 Mdot
.10817 .24125 Mdot
.11482 .24158 Mdot
.12037 .24079 Mdot
.13843 .25251 Mdot
.10428 .212 Mdot
.14645 .2478 Mdot
.13666 .23164 Mdot
.1523 .24088 Mdot
.13927 .22146 Mdot
.15963 .23541 Mdot
.15424 .22361 Mdot
.13896 .20191 Mdot
.14923 .20576 Mdot
.12931 .1794 Mdot
.16625 .20991 Mdot
.14559 .1828 Mdot
.16932 .20009 Mdot
.18216 .20648 Mdot
.16387 .18174 Mdot
.15926 .17068 Mdot
.17807 .18304 Mdot
.16631 .16482 Mdot
.18528 .17734 Mdot
.16632 .15193 Mdot
.17628 .15544 Mdot
.20613 .17884 Mdot
.17661 .14287 Mdot
.18793 .14775 Mdot
.18916 .14254 Mdot
.22526 .17221 Mdot
.20834 .14886 Mdot
.20689 .14098 Mdot
.22403 .15171 Mdot
.19707 .11834 Mdot
.23413 .14901 Mdot
.20532 .1138 Mdot
.21522 .11732 Mdot
.21124 .10697 Mdot
.21446 .10382 Mdot
.25507 .13808 Mdot
.2444 .12107 Mdot
.23077 .10112 Mdot
.2555 .11953 Mdot
.25834 .11608 Mdot
.27778 .12923 Mdot
.27924 .12442 Mdot
.28834 .12726 Mdot
.26789 .10057 Mdot
.28079 .10724 Mdot
.25583 .07608 Mdot
.29792 .11198 Mdot
.26964 .07754 Mdot
.28484 .08658 Mdot
.27296 .06858 Mdot
.28993 .07943 Mdot
.31235 .09576 Mdot
.31403 .09138 Mdot
.33278 .10409 Mdot
.31637 .08165 Mdot
.32568 .08497 Mdot
.32121 .07453 Mdot
.3477 .09507 Mdot
.33187 .07331 Mdot
.35002 .08557 Mdot
.36006 .08974 Mdot
.35841 .08224 Mdot
.36737 .08538 Mdot
.34095 .05318 Mdot
.33549 .04195 Mdot
.38196 .0827 Mdot
.3858 .08083 Mdot
.38383 .0732 Mdot
.36949 .05322 Mdot
.39933 .07745 Mdot
.36513 .03768 Mdot
.39553 .06253 Mdot
.41572 .07722 Mdot
.41592 .07194 Mdot
.41453 .06512 Mdot
.42666 .07184 Mdot
.40371 .04352 Mdot
.43498 .06946 Mdot
.40859 .03776 Mdot
.41562 .03954 Mdot
.44701 .06571 Mdot
.45605 .06956 Mdot
.44976 .05812 Mdot
.44292 .04618 Mdot
.46857 .06677 Mdot
.43795 .03112 Mdot
.47266 .06084 Mdot
.45094 .03418 Mdot
.48641 .06475 Mdot
.45931 .03279 Mdot
.49456 .06322 Mdot
.4792 .04309 Mdot
.48778 .04693 Mdot
.48088 .03535 Mdot
.50911 .05894 Mdot
.51342 .05865 Mdot
.50624 .04692 Mdot
.50359 .03977 Mdot
.49204 .02375 Mdot
.53431 .06161 Mdot
.50892 .03186 Mdot
.52511 .04373 Mdot
.54443 .05879 Mdot
.53853 .04866 Mdot
.53188 .03784 Mdot
.54353 .04537 Mdot
.52802 .02579 Mdot
.53346 .02721 Mdot
.5513 .04108 Mdot
.55246 .03831 Mdot
.55239 .03438 Mdot
.58407 .06224 Mdot
.57097 .04538 Mdot
.55811 .02881 Mdot
.57296 .04 Mdot
.57889 .04232 Mdot
.60737 .06725 Mdot
.60594 .06232 Mdot
.59708 .05002 Mdot
.60323 .05278 Mdot
.59778 .044 Mdot
.60351 .04645 Mdot
.61073 .05045 Mdot
.62475 .06131 Mdot
.64921 .08265 Mdot
.64326 .07365 Mdot
.63566 .06305 Mdot
.66008 .08453 Mdot
.65004 .07162 Mdot
.63694 .05569 Mdot
.64933 .06531 Mdot
.67278 .08606 Mdot
.64937 .06 Mdot
.6852 .09324 Mdot
.65648 .06199 Mdot
.65269 .05574 Mdot
.69245 .09308 Mdot
.69993 .09822 Mdot
.70641 .1024 Mdot
.7011 .09486 Mdot
.71677 .10836 Mdot
.68444 .07393 Mdot
.70414 .09158 Mdot
.69705 .0825 Mdot
.72251 .10604 Mdot
.73442 .11608 Mdot
.70559 .08546 Mdot
.73442 .11254 Mdot
.73973 .11618 Mdot
.71623 .09106 Mdot
.74489 .11818 Mdot
.75355 .12535 Mdot
.72749 .09786 Mdot
.76695 .13596 Mdot
.7418 .1095 Mdot
.77682 .14329 Mdot
.77834 .14363 Mdot
.74048 .10466 Mdot
.74818 .11132 Mdot
.79109 .15325 Mdot
.75695 .11819 Mdot
.76131 .1217 Mdot
.76659 .12619 Mdot
.77321 .13208 Mdot
.77304 .13125 Mdot
.81372 .17133 Mdot
.80327 .16035 Mdot
.82093 .17753 Mdot
.79921 .15542 Mdot
.78626 .14212 Mdot
.80851 .1641 Mdot
.8012 .15658 Mdot
.82364 .17887 Mdot
.83799 .19314 Mdot
.83536 .19049 Mdot
.82315 .17832 Mdot
.82975 .18503 Mdot
.80835 .16381 Mdot
.83455 .19025 Mdot
.8366 .19261 Mdot
.8453 .20168 Mdot
.86536 .22217 Mdot
.8418 .19911 Mdot
.85011 .20798 Mdot
.85084 .20934 Mdot
.87003 .22921 Mdot
.84464 .20458 Mdot
.84976 .21052 Mdot
.85406 .2157 Mdot
.88156 .24415 Mdot
.86996 .23356 Mdot
.86073 .2254 Mdot
.89001 .25582 Mdot
.88809 .2551 Mdot
.85744 .22571 Mdot
.90434 .27394 Mdot
.86869 .23969 Mdot
.90116 .27361 Mdot
.87623 .25019 Mdot
.89275 .2683 Mdot
.89916 .27634 Mdot
.91038 .28927 Mdot
.90782 .28847 Mdot
.87957 .26206 Mdot
.88015 .26453 Mdot
.91979 .30611 Mdot
.89797 .2863 Mdot
.90981 .30022 Mdot
.9124 .30494 Mdot
.88992 .28466 Mdot
.89615 .29314 Mdot
.90549 .30481 Mdot
.90637 .30806 Mdot
.90457 .3087 Mdot
.92492 .33154 Mdot
.90034 .30952 Mdot
.92 .3318 Mdot
.92253 .337 Mdot
.93025 .34745 Mdot
.90673 .32672 Mdot
.91869 .34153 Mdot
.93662 .36237 Mdot
.92585 .35457 Mdot
.9336 .36534 Mdot
.94128 .3761 Mdot
.95008 .38803 Mdot
.94392 .38506 Mdot
.93629 .38067 Mdot
.94535 .39304 Mdot
.96207 .41311 Mdot
.93398 .38844 Mdot
.96198 .4199 Mdot
.92462 .38607 Mdot
.96558 .4306 Mdot
.93298 .40163 Mdot
.9533 .42563 Mdot
.96233 .4384 Mdot
.96104 .4409 Mdot
.95528 .43898 Mdot
.95605 .44364 Mdot
.94688 .43841 Mdot
.94449 .44001 Mdot
.93238 .43194 Mdot
.95801 .46166 Mdot
.93816 .44596 Mdot
.96471 .47671 Mdot
.96457 .48081 Mdot
.93798 .45851 Mdot
.9572 .48207 Mdot
.97603 .50528 Mdot
.93744 .47112 Mdot
.9651 .50326 Mdot
.97619 .51888 Mdot
0 0 1 r
.5 Mabswid
.32709 .07682 m
.38413 .05805 L
.44117 .0472 L
.49821 .04367 L
.55525 .04729 L
.61229 .05824 L
.66933 .07712 L
.71652 .09939 L
.72637 .10507 L
.78341 .14417 L
.79806 .15643 L
.84045 .19875 L
.8528 .21347 L
.892 .27051 L
.89749 .27999 L
.92004 .32755 L
.93898 .38459 L
.94999 .44163 L
.95367 .49867 L
.9502 .55571 L
.93941 .61275 L
.92071 .66979 L
.89749 .71898 L
.89296 .72683 L
.85414 .78387 L
.84045 .80026 L
.79997 .84091 L
.78341 .85484 L
.72637 .89392 L
.71947 .89795 L
.66933 .92189 L
.61229 .94076 L
.55525 .95171 L
.51552 .95499 L
.49821 .95533 L
.48016 .95499 L
.44117 .9518 L
.38413 .94095 L
.32709 .92219 L
.27623 .89795 L
.27005 .89435 L
.21301 .85544 L
.19571 .84091 L
.15597 .80111 L
.14154 .78387 L
.10273 .72683 L
.09893 .72029 L
.07497 .66979 L
.05627 .61275 L
.04548 .55571 L
Mistroke
.04201 .49867 L
.04569 .44163 L
.0567 .38459 L
.07564 .32755 L
.09893 .27867 L
.10369 .27051 L
.14288 .21347 L
.15597 .1979 L
.19761 .15643 L
.21301 .14357 L
.27005 .10465 L
.27917 .09939 L
.32709 .07682 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{288, 287.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001[R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00<P3oool00`3ooml0W4P007Boo`1C0?ooo`090?oog`2LB000M;oo0?ooo`3ogi`0B01d0;oo
o`3oool0gia80080000000<0001809cOo`3oool0C`3oool01@3OW4P000000000000004P0W=oo0500
oooo00/0gia8000000000000001809cOo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000
B02Lgol0oooo0500oooo00D0oono07@000000000001d0;ooo`0A0?ooo`00<P3oool00`3ooml0W4P0
07Boo`1C0?ooo`030?oog`2LB000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo
04h0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo04h0oooo00L0okmd0018W03Oool0oooo
0?oog`2LB7@0_ooo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo0500oooo00H0_g@0
07Boo`3oool0omnL04Q8W03Oool@0?ooo`00;`3oool00`3OW4P00000000000030000000304RLg`3o
ool0oooo04d0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`060?ooo`030;md001d
_ol0oooo0580oooo00<0_g@007Boo`3oool0DP3oool00`2oM000M;oo0?ooo`070?ooo`030;md001d
_ol0oooo04h0oooo00L0oono07A8W03Oool0oooo0?oo_`1d04P0W=oo0100oooo000_0?ooo`060?oO
W018B9`0gooo0?oog`2LB000M;ooD03oool01P3ogi`0B4RL0=ooo`3ooml0W4P007Boo`T0oooo00<0
_g@007Boo`3oool0DP3oool00`2oM000M;oo0?ooo`1B0?ooo`030;md001d_ol0oooo00L0oooo00<0
_g@007Boo`3oool0CP3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0403oool00300oooo
00D0gia804RLg`3ooml0W4P007Boo`1A0?ooo`050=nLB018W=l0oooO09a8001d_ol0103oool01`3o
gi`0B01809cOo`3oool0oooO09a8B02Lgol0CP3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02L
gol0CP3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol00`3oool01`3ogi`0B01809cOo`3o
ool0oooO09a8B02Lgol0C`3oool01`3ogi`0B00007Boo`3oool0omnL04Q8W03Oool0403oool00300
oooo00D0oooO09a8B02Lgml0W4P007Boo`1A0?ooo`050?oog`2LB4P0W=oO09a8001d_ol0103oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo04d0oooo00<0oono07@0000000000P000000
0`1d_ol0oooo0?ooo`1=0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool00P3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo04h0oooo00H0omnL04Q8W02LM00000000000
B02LgolA0?ooo`00<@3oool0103ogi`0B4Qd07A8001d_omB0?ooo`040?oOW018B7@0M4P007Boo`@0
oooo00<0oooO09a8B02Lgol0DP3oool00`3ooml0W4Q809cOo`1B0?ooo`030?oog`2LB4P0W=oo00L0
oooo00<0oooO09a8B02Lgol0D`3oool00`3ookl0M01d0;ooo`0D0?ooo`00<P3oool00`3OW4P00000
07Boo`1C0?ooo`030=nLB0000000M;oo00D0oooo00<0_g@007Boo`3oool0DP3oool00`2oM000M;oo
0?ooo`1B0?ooo`030;md001d_ol0oooo00L0oooo00<0_g@007Boo`3oool0D`3oool01P2oM000M;oo
0?ooo`3o_g@004RL0=oooa00oooo000b0?ooo`030?oog`2LB000M;oo05<0oooo00<0oooO09a8001d
_ol01@3oool01P3OW4P00000000000000000001d0;ooodl0oooo00H0gia800000000000000000000
M02ooom?0?ooo`060=nLB000000000000000000007@0_ooo103oool01P3OW4P00000000000000000
001d0;oooe00oooo00D0oooO09a800000000001809cOo`0A0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`008P3ooooo000008h000000@3oool00280oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool100000040
oooo000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool03`3oool100000040oooo000R
0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo
0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003o
ool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo0<00oooo00<0o`00
0?ooo`3oool0aP3oool100000040oooo000R0?ooo`030000003oool0oooo0;l0oooo0`3o000<0?oo
o`030?l0003oool0o`000;P0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`300?ooo`03
0?l0003oool0oooo00X0oooo1@3o00080?ooo`030?l0003oool0oooo0:`0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`2Z0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0
103oool00`3o0000oooo0?l000080?ooo`<0o`00[@3oool100000040oooo000R0?ooo`030000003o
ool0oooo0:T0oooo0`3o00040?ooo`040?l0003oool0oooo0?l00180oooo0`3o000?0?ooo`030?l0
003oool0o`000:h0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2L
B000M;oo00P0oooo00<000000?ooo`3oool0SP3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo0080oooo1P3o00060?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03@3o
ool30?l00:l0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`040?ooo`030?oog`2LB000
M;oo00P0oooo00<000000?ooo`3oool0S@3oool30?l000l0oooo00@0o`000?ooo`3oool0o`003@3o
ool0103o0000oooo0?ooo`3o00060?ooo`<0o`001`3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2V0?ooo`400000
0@3oool00100oooo00D0omnL04P0M02oool0oooo0=nLB0050000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0PP3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00d0oooo
1P3o000G0?ooo`030?l0003oool0oooo00D0oooo0`3o00090?ooo`<0o`001@3oool30?l000D0oooo
103o002V0?ooo`4000000@3oool00100oooo00X0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?oo
g`2LB000M;oo203oool300000840oooo0`3o000I0?ooo`030?l0003oool0o`000080oooo00<0o`00
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00@0o`00
0?ooo`3oool0o`001@3oool30?l000L0oooo103o00060?ooo`030?l0003oool0oooo09X0oooo0`00
00010?ooo`00403oool00`3ogi`0B01d0;ooo`020?ooo`050=nLB018W=l0oooO09a8001d_ol0203o
ool00`000000oooo0?ooo`220?ooo`030?l0003oool0oooo01L0oooo0`3o000=0?ooo`030?l0003o
ool0oooo00T0oooo5P000?l00`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000L0oooo
00@0o`000?ooo`3oool0o`001P3oool40?l009`0oooo0@0000010?ooo`00403oool00`3ogi`0B01d
0;ooo`020?ooo`050?oog`2LB4P0W=oO09a8001d_ol0203oool00`000000oooo0?ooo`2M0?ooo`03
0?l0003oool0oooo00X0oooo3P000?l30?ooo`030?l0003oool0o`000080o`00103oool30?l000H0
oooo00<0o`000000o`000?l030000?l20?ooo`<0o`00203oool50?l009/0oooo0@0000010?ooo`00
3P3oool01@2oM000001809boW01807@0_ooo00<0oooo00@0omnL04Q8M01dB000M;oo203oool00`00
0000oooo0?ooo`2T0?ooo`H0003o0P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool02@3oool40?l000L0oooo10000?l80?ooo`<0o`0000D0oooo0?l0
003oool0oooo0?l0002I0?ooo`4000000@3oool000l0oooo00@0okmd0000000007@0_ooo103oool0
0`3OW4P0000007Boo`080?ooo`030000003oool0oooo08@0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0<0?ooo`H0003o;P3oool00`3o0000oooo0?ooo`0;0?ooo`D0003o103oool0
0`3o0000oooo0?l000050?l009P0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`040?oo
o`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0P`3oool30?l000P0oooo0`3o00070?oo
o`H0003oA`3oool50000o`80oooo00@0o`000?ooo`3oool0o`002@3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo08H0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`240?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool40000oaL0oooo00<0o`000?oo
o`3oool05@3oool20?l000`0oooo00<0o`000?ooo`3oool04P3oool40000o`X0oooo0`3o00030?oo
o`@0o`00Q`3oool100000040oooo000R0?ooo`030000003oool0oooo0940oooo0`000?l60?ooo`03
0?l0003oool0oooo0140oooo0`3o00070?ooo`030?l0003oool0oooo00/0oooo103o00070?ooo`03
0?l0003oool0oooo00<0o`003@3oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0003o0080
003o0P3oool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`D0o`00Q`3oool10000
0040oooo000R0?ooo`030000003oool0oooo08h0oooo0`000?l80?ooo`<0o`001@3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo0`3o00040?ooo`040?l0003oool0oooo0?l0
00D0oooo0P3o00070?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`<0o`001P3oool30?l0
00<0oooo0`000?l01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?ooo`3o00000P3o0026
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0R`3oool30000o``0oooo00<0o`000?oo
o`3oool00`3oool30?l000/0oooo00<0o`000?ooo`3oool01P3oool20?l000@0oooo1P3o000>0?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool20?l000D0oooo00@0o`000000
o`000?l0003o0`3o00020?ooo`<0o`0000<0oooo0?l0003oool0QP3oool100000040oooo000R0?oo
o`030000003oool0oooo06T0oooo00<0o`000?ooo`3oool07@3oool20000oaH0oooo00<0o`000?oo
o`3oool01@3oool0103o0000oooo0?ooo`3oool30?l00080oooo00@0o`000?ooo`3oool0oooo0`3o
00050?ooo`040?l0003oool0oooo0?l002/0oooo0`3o00080?ooo`<0003o0`3oool00`3o0000oooo
0?ooo`280?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0J03oool30?l001/0oooo0`00
0?lI0?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0`3o00030?ooo`030?l0003oool0oooo00<0
o`000`3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00X0oooo10000?n:0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool0J@3oool00`3o0000oooo0?ooo`0@0?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool30000o`l0oooo00<0o`000?ooo`3oool02@3oool30?l00006
0?ooo`3o0000o`000?l0003oool0o`00203oool00`3o0000oooo0?ooo`170?ooo`<0o`000`000?l:
0?ooo`030?l0003oool0oooo07X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1R0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0403oool30?l000030?ooo`3o0000003o
0080003o4@3oool30?l000@0oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
o`0005@0oooo103o00030?ooo`<0003o1P3oool30?l007/0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`1Q0?ooo`<0o`000`3oool30?l000H0oooo00<0o`000?ooo`3oool02@3oool01@3o
0000003o0000o`000?l0o`0001@0oooo00<0o`000?ooo`3oool00P3oool30?l000@0oooo0`3o001H
0?ooo`030?l0003oool0oooo00H0oooo0`000?l40?ooo`030?l0003oool0oooo07X0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`1R0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool30?l000P0oooo00<0o`000000o`000?l03P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1I0?oo
o`030?l0003oool0oooo00L0oooo0P000?l70?ooo`030?l0003oool0oooo07D0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`1`0?ooo`030?l0003oool0oooo00H0oooo0P000?l0103o0000
oooo0?ooo`3o00090?ooo`030?l0003oool0o`000080o`0000<0oooo0?l0003oool00`3oool50?l0
06D0oooo0`3o00020?ooo`030?l0003oool0oooo00D0oooo0P000?l40?ooo`<0o`000P3oool00`3o
0000oooo0?ooo`1a0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0KP3oool00`3o0000
oooo0?ooo`060?ooo`80003o00@0oooo0?l0003oool0oooo0`3o00070?ooo`<0o`0000<0oooo0?l0
003oool00`3o00040?ooo`030?l0003oool0o`0006L0oooo00<0o`000?ooo`3oool00`3o00040?oo
o`040?l0003oool0oooo0?ooo`80003o0`3oool00`3o0000oooo0?ooo`030?l00780oooo0@000001
0?ooo`008P3oool2000006h0oooo0`3o00050?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?oo
o`070?l0003oool0oooo0?ooo`3o0000oooo0?l0001c0?ooo`030?l0003oool0oooo0080oooo0`3o
00040?ooo`80003o1@3oool00`3o0000oooo0?ooo`1`0?ooo`8000000@3oool00280oooo00<00000
0?ooo`3oool0KP3oool00`3o0000oooo0?ooo`020?ooo`80003o103oool00`3o0000oooo0?ooo`0?
0?ooo`<0o`00NP3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0003o0080oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1]0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool0L@3oool20000o`D0oooo0`3o000<0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0O@3oool00`3o0000oooo0?l000020?l000030?ooo`000?l0003o0080o`000P3oool30?l0
06h0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1_0?ooo`80003o203oool00`3o0000
oooo0?ooo`0:0?ooo`<0o`00PP3oool30?l000040?ooo`3o0000oooo0?ooo`80o`000P000?l30?oo
o`050?l0003oool0oooo0?ooo`3o0000J`3oool100000040oooo000R0?ooo`030000003oool0oooo
06L0oooo00<0o`000?ooo`3oool00`3oool20000o`T0oooo0`3o000<0?ooo`030?l0003oool0oooo
0880oooo00<0o`000?ooo`3oool00P3oool30?l00080oooo0P000?l40?ooo`<0o`00JP3oool10000
0040oooo000R0?ooo`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool02`3oool30?l00080
oooo0P000?l<0?ooo`030?l0003oool0oooo09H0oooo00@0o`000?ooo`3oool0o`000P3oool20000
o`<0oooo00<0o`000?ooo`3oool0J@3oool100000040oooo000R0?ooo`030000003oool0oooo0580
oooo00<0o`000?ooo`3oool00P3oool30?l000d0oooo00@0o`000?ooo`000?l0003o5P3oool00`3o
0000oooo0?ooo`2@0?ooo`<0o`000`3oool20000o`H0oooo00<0o`000?ooo`3oool0I03oool10000
0040oooo000R0?ooo`030000003oool0oooo0500oooo103o00040?ooo`030?l0003oool0oooo00d0
oooo00D0003o0?ooo`3oool0oooo0?l0000C0?ooo`<0o`00TP3oool00`3o0000oooo0?ooo`030?oo
o`030?l000000?l0003o00<0oooo0`3o001U0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0C`3oool40?l001<0oooo0P000?l30?ooo`<0o`004`3oool00`3o0000oooo0?ooo`2E0?ooo`@0
o`0000<0oooo0000o`000?l00P3oool20?l006D0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`1@0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo0:80oooo103o00040?ooo`030000o`3oool0o`0000<0o`00
H`3oool100000040oooo000R0?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool04P3o
ool20000o`d0oooo0`3o002T0?ooo`030?l0003oool0oooo00<0oooo0P3o00000`000?l0oooo0?l0
00030?l00680oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0
o`000080o`000P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o0000oooo00h0oooo00<0o`00
0?ooo`3oool0ZP3oool0103o0000oooo0000o`000?l20?l000<0oooo00<0o`000?ooo`3oool0G@3o
ool100000040oooo000R0?ooo`030000003oool0oooo04X0oooo0`3o0000103oool0o`000?ooo`3o
ool30?l000`0oooo0P000?l30?l00;X0oooo1@3o000010000?l0o`000?ooo`3oool30?l005h0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`1;0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000003o0?ooo`030?l00;`0oooo00H0o`000?ooo`3o0000oooo
0?l000000?l30?ooo`030?l0003oool0o`0005d0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`1M0?ooo`80003o00@0o`000?ooo`3oool0o`00203oool00`3o0000oooo0?ooo`2h0?ooo`80
003o00<0o`000?ooo`3o00000P3o001L0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
F`3oool20000o`030?ooo`3o0000oooo00X0oooo0`3o00020?ooo`030?l0003oool0oooo0;D0oooo
00L0o`000000o`3o0000oooo0?l0003oool0o`0005/0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`1J0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3o002g0?ooo`04
0?l000000?l0003o0?ooo`<0o`00FP3oool100000040oooo000R0?ooo`030000003oool0oooo05P0
oooo0P000?l@0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`2i0?ooo`050000o`3oool0o`000?oo
o`3o0000F@3oool100000040oooo000R0?ooo`800000F03oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0;h0oooo00<0003o0?l0003o00000P3o001G0?ooo`8000000@3oool00280oooo
00<000000?ooo`3oool0E@3oool20000o`/0oooo00<0o`000?ooo`3oool0a`3oool0103o0000003o
0000o`3o001I0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00X0oooo0`3o00390?ooo`030?l0003oool0003o05T0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool30?l000030?ooo`000?l0003o00h0oooo00<0o`000?ooo`3oool0b`3o
ool00`000?l0o`000?ooo`020?ooo`030?l0003oool0oooo0540oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`120?ooo`<0o`000P3oool30?l000D0oooo00<0o`000?ooo`000?l0gP3oool0
103o0000003o0000o`3oool30?l00580oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`13
0?ooo`040?l0003oool0oooo0?ooo`80o`001`3oool00`000?l0oooo0?ooo`3N0?ooo`050?l0003o
ool0003o0?ooo`3o0000D`3oool100000040oooo000R0?ooo`030000003oool0oooo04H0oooo0`3o
00060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0e`3oool00`000?l0oooo0?oo
o`1B0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?l0003o00001@3oool00`3o0000oooo0?ooo`03
0?l00=T0oooo00<0003o0?l0003oool0D@3oool100000040oooo000R0?ooo`030000003oool0oooo
03h0oooo0`3o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o00001@3oool30?l0
0080oooo00<0o`000?ooo`3oool0f03oool00`3o0000003o0000o`020?ooo`030?l0003oool0oooo
04`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00<0
o`001`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0=d0oooo00<0o`000?ooo`00
0?l00`3o001=0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo0>/0oooo00<0003o0?l0003o0000C@3oool100000040oooo
000R0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0k@3oool010000?l0o`000?l0
003o001;0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo0>l0oooo00@0003o0?l0003o0000o`00BP3oool100000040oooo
000R0?ooo`030000003oool0oooo03h0oooo0`3o00070?ooo`030000o`3oool0oooo0?40oooo00<0
003o0?l0003o0000BP3oool100000040oooo000R0?ooo`030000003oool0oooo03`0oooo00@0o`00
0?ooo`3oool0o`001`3oool00`000?l0oooo0?ooo`3c0?ooo`030000o`3oool0o`0004T0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`<0o`00203oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0>D0oooo00<0003o0?l0003o0000B03oool100000040oooo000R0?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?oo
o`<0o`00i`3oool00`000?l0oooo0?ooo`170?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0A03oool00`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0i`3oool010000?l0oooo0?l0003o00150?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0o`000080o`001@3oool30?l00?40
oooo0P000?l20?l004@0oooo0@0000010?ooo`008P3oool200000300oooo0`3o00040?ooo`030?l0
003oool0oooo00D0oooo00H0o`000?ooo`3oool0oooo0000o`3o00020?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0l@3oool00`3o0000003o0?ooo`130?ooo`8000000@3oool00280
oooo00<000000?ooo`3oool0<03oool00`3o0000oooo0?ooo`020?ooo`<0o`001@3oool30?l00003
0?ooo`000?l0o`000080o`00o`3oool00`000?l0oooo0?l000120?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o0080oooo
00<0o`000?ooo`3oool0o`3oool00`000?l0o`000?l000110?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`3o0?ooo`D0oooo00<0003o0?ooo`3o0000@03o
ool100000040oooo000R0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool0o`3oool7
0?ooo`030000o`3o0000o`0003l0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo0?l0oooo203oool0103o0000003o0?l0003o000n0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`3o0?ooo`X0oooo00@0o`000000
o`3oool0o`00?@3oool100000040oooo000R0?ooo`030000003oool0oooo03/0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooo`P0oooo00<0003o0?l0003o0000?03oool10000
0040oooo000R0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`<0o`00o`3oool:0?ooo`030000o`3o0000oooo03/0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0c0?ooo`<0o`000P3oool00`3o0000003o0?ooo`050?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oool40?ooo`030?l000000?l0o`0003/0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`060?l0003oool0oooo0?l000000?l0
o`002P3oool30?l00?l0oooo1@3oool0103o0000003o0?l0003o000j0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0=`3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0o`3oool50?ooo`040?l000000?l0o`000?l003T0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01@3oool30?l00?l0oooo3@3oool00`3o0000003o0?l0000i0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool09@3oool30?l000d0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`3o0?ooo`d0oooo00<0o`000000o`3oool0>03oool100000040oooo000R0?ooo`030000003o
ool0oooo02H0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`3o0?oooaP0oooo0P3o
00000`000?l0oooo0?ooo`0f0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0=03oool0
0`000?l0oooo0?ooo`3o0?oooaT0oooo00<0o`000000o`3oool0=`3oool100000040oooo000R0?oo
o`030000003oool0oooo03<0oooo00<0003o0?l0003o0000103oool00`3o0000oooo0?ooo`3o0?oo
oaD0oooo00@0003o0?ooo`3oool0o`00=03oool100000040oooo000R0?ooo`030000003oool0oooo
0380oooo00<0003o0?ooo`3o0000103oool30?l00?l0oooo5P3oool00`3o0000003o0?l000020?l0
03<0oooo0@0000010?ooo`008P3oool2000003<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`3o0?oooa@0oooo0P3o00001@000?l0o`000?l0003oool0o`000340oooo0P0000010?oo
o`008P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0o`000?l0oooo7P3oool20?l00003
0000o`3oool0o`000080o`00<@3oool100000040oooo000R0?ooo`030000003oool0oooo0300oooo
00<0003o0?ooo`3o00000P3o003o0?ooob00oooo00<0003o0?ooo`3o0000<P3oool100000040oooo
000R0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool02P3oool010000?l0oooo0?oo
o`3o00080?ooo`030?l0003oool0oooo0?l0oooo5P3oool010000?l0o`000?l0003o000a0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool08P3oool30?l000X0oooo00<0003o0?ooo`3oool0
2@3oool30?l00?l0oooo603oool00`000?l0o`000?ooo`0a0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool08`3oool00`3o0000oooo0?ooo`020?ooo`070?l0003oool0o`000?ooo`3o0000
oooo0000o`0:0?ooo`040?l0003oool0oooo0?l00?l0oooo6@3oool00`3o0000003o0?ooo`0a0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool09`3oool70?l000030000o`3oool0oooo00L0
oooo0`3o003o0?oooaX0oooo0P3o00001@000?l0oooo0?ooo`3oool0o`0002h0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00H0oooo00H0o`000?ooo`3o
0000oooo0?l000000?l;0?ooo`030?l0003oool0oooo0?l0oooo6P3oool0103o0000oooo0000o`3o
ool30?l002d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0N0?ooo`<0o`00303oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0oooo7P3oool010000?l0oooo0?ooo`3o
000^0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00L0oooo0`3o003o0?ooob00oooo00<0003o0?ooo`3oool0;P3oool1
00000040oooo000R0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool01P3oool0103o
0000oooo0?ooo`3o003o0?ooob00oooo0P3o00000`000?l0oooo0?ooo`0]0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`050?ooo`<0o`00o`3ooolS0?oo
o`030?l000000?l0oooo0080oooo0P3o000Z0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool0o`3ooolT0?ooo`030000o`3oool0o`0000<0o`00:@3oool100000040oooo000R0?ooo`030000
003oool0oooo01`0oooo0`3o000:0?ooo`030000o`3oool0oooo0?l0oooo;P3oool0103o0000oooo
0000o`3oool20?l002X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`3o0?ooobd0oooo
0`3o00000`000?l0oooo0?ooo`0[0?ooo`4000000@3oool000H0oooo00<0omnL04P0M02oool0103o
ool02@3ooml0W4P007Boo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo
00L0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`020?ooo`<0o`00103oool00`00
0?l0oooo0?l0003o0?ooobl0oooo0`3o00000`000?l0oooo0?ooo`0Z0?ooo`4000000@3oool000H0
oooo00<0omnL04P0M02oool0103oool00`3ooml0W4P007Boo`040?ooo`070?noM000B9`0gooo0?oo
o`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo01/0oooo0`3o00040?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3o00000P3o003o0?ooobl0oooo00H0o`000?ooo`3oool0003o0?oo
o`3o000Y0?ooo`4000000@3oool000H0oooo00D0omnL04P0M02oool0oooo0=nLB0050000000304RL
g`3oool0oooo00H0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030?l0
003oool0oooo00P0oooo00@0003o0?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`3o0?ooobd0
oooo00@0003o0?l0003o0000o`00:03oool100000040oooo00060?ooo`0:0?oOW01807@0_ooo0?oo
o`3ogi`0B4RL0=ooo`3ooml0W4P007Boo`T0oooo00<0_g@007Boo`3oool01P3oool3000002H0oooo
00<0003o0?ooo`3oool0103oool30?l00?l0oooo;`3oool010000?l0o`000?ooo`3oool20?l002<0
oooo0`0000010?ooo`001P3oool00`3ogi`0B01d0;ooo`020?ooo`050=nLB018W=l0oooO09a8001d
_ol0103oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01`3oool00`000000oooo0?ooo`0H
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o
0?ooobl0oooo00<0003o0?ooo`3o00000`3o000T0?ooo`4000000@3oool000H0oooo00<0omnL04P0
M02oool00P3oool01@3ooml0W4Q809cOg`2LB000M;oo00@0oooo00<0oono07@0000000000P000000
0`1d_ol0oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo0`3o000;0?ooo`030000o`3oool0
oooo0?l0oooo>@3oool010000?l0o`000?l0003o000U0?ooo`4000000@3oool000@0oooo00D0_g@0
0000B02L_i`0B01d0;ooo`030?ooo`040?oOW018B7@0M4P007Boo`@0oooo00<0oooO09a8B02Lgol0
2`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
o`3ooolk0?ooo`030000o`3oool0oooo02D0oooo0@0000010?ooo`001@3oool0103o_g@000000000
M02oool40?ooo`030=nLB0000000M;oo00D0oooo00<0_g@007Boo`3oool02P3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0?l0oooo>03oool0103o0000oooo0?ooo`000?lW0?ooo`40
00000@3oool000H0oooo00<0omnL04P0M02oool0103oool00`3ooml0W4P007Boo`050?ooo`060=nL
B000000000000000000007@0_ooo1`3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
0?l0oooo>03oool30?l000030?ooo`3o0000003o02H0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0?l0oooo>@3oool01@3o0000oooo0?l0003o0000003o
0080oooo0P3o000R0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo0?l0oooo<03oool00`3o0000oooo0000o`040?l00240
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00T0oooo
0`3o003o0?oooc00oooo00D0o`000?ooo`3oool0003o0?ooo`020?l00280oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`3o0?ooobh0oooo0`3o00020?ooo`030000o`3oool0oooo0280oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo0`3o
003o0?ooocH0oooo00D0o`000?ooo`3oool0oooo0000o`0T0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool0803oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0oooo>P3o
ool00`000?l0oooo0?ooo`0Q0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`3o0?oood80oooo00@0o`000000o`3o0000o`008@3oool100000040oooo000R
0?ooo`030000003oool0oooo01l0oooo00<0003o0?l0003o0000o`3ooom20?ooo`<0o`0000@0003o
0?l0003o0000o`007`3oool100000040oooo000R0?ooo`030000003oool0oooo01l0oooo00<0003o
0?l0003oool0o`3ooom10?ooo`<0o`0000<0oooo0000o`3o00000`3o000N0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0703oool00`3o0000oooo0000o`090?ooo`040?l0003oool0oooo
0?l00?l0oooo=P3oool50?l000040?ooo`000?l0oooo0?l001l0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0K0?ooo`<0o`0000<0003o0?ooo`3oool01P3oool60?l00?l0oooo=P3oool3
0?l00080oooo00<0003o0?ooo`3oool07`3oool100000040oooo000R0?ooo`030000003oool0oooo
01`0oooo00<0o`000000o`3oool02@3oool0103o0000oooo0?ooo`3o003o0?ooocd0oooo00<0003o
0?ooo`3oool07P3oool100000040oooo000R0?ooo`8000007P3oool00`000?l0oooo0?ooo`3o0?oo
odT0oooo00<0003o0?ooo`3oool07@3oool200000040oooo000R0?ooo`030000003oool0oooo01L0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0
oooo@P3oool00`000?l0oooo0?ooo`0M0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
5P3oool30?l000<0oooo00<0003o0?ooo`3oool01@3oool30?l00?l0oooo@`3oool00`000?l0oooo
0?ooo`0M0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool05P3oool20?l000<0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0L0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04`3oool0
0`3o0000oooo0?l000020?l00080oooo00<0o`000000o`3o00002@3oool00`3o0000oooo0?ooo`3o
0?oooc/0oooo0`3o00040?ooo`030000o`3oool0oooo01`0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0B0?ooo`<0o`0000<0oooo0?l0003oool00`3oool00`000?l0oooo0?ooo`070?oo
o`<0o`00o`3ooolm0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool0703oool10000
0040oooo000R0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o00000P3o00020?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooom10?ooo`80o`0000<0003o0?l0003o
ool06`3oool100000040oooo000R0?ooo`030000003oool0oooo01H0oooo00D0o`000?ooo`3oool0
oooo0000o`090?ooo`030?l0003oool0oooo0?l0ooooA03oool00`3o0000003o0?ooo`0L0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`050?ooo`@0o`00
o`3ooom50?ooo`030?l000000?l0o`0001`0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0I0?ooo`030000o`3oool0oooo00D0oooo103o003o0?ooodD0oooo00@0o`000?ooo`3o0000003o
703oool100000040oooo000R0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`3o0?oood@0oooo0`3o00000`3oool0003o0?ooo`0K0?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`3o0?ooodh0oooo00H0o`00
0?ooo`3oool0003o0?ooo`3o000J0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`3o0?oooe80oooo00@0003o0?l0003o0000o`006@3oool100000040oooo
000R0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`3o0?oooe<0oooo00<0003o0?l0003oool06@3oool100000040oooo000R0?ooo`030000003oool0
oooo00d0oooo0`3o00080?ooo`030000o`3oool0oooo0?l0ooooDP3oool00`3o0000003o0?ooo`0J
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo0?l0ooooDP3oool20?l000030000o`3oool0oooo01T0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0F0?ooo`030?l000000?l0o`0000<0oooo00<0o`000?ooo`3o
ool0o`3ooom>0?ooo`030?l0003oool0003o01X0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0E0?ooo`030?l000000?l0o`0000<0oooo0`3o003o0?oooe40oooo00<0003o0?ooo`3o0000
603oool100000040oooo000R0?ooo`8000005`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0?l0ooooD03oool010000?l0o`000?l0003o000F0?ooo`8000000@3oool00280oooo00<0
00000?ooo`3oool05P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0ooooC`3o
ool00`3o0000003o0?l0000H0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o003o0?oooe40oooo00<0003o
0?ooo`3oool05`3oool100000040oooo000R0?ooo`030000003oool0oooo00d0oooo0`3o00050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3ooom@0?ooo`030000o`3oool0oooo
01L0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?oo
o`3o00001P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0ooooD`3oool00`00
0?l0oooo0?ooo`0G0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool02@3oool30?l000P0
oooo00<0003o0?ooo`3oool00P3oool30?l00?l0ooooE@3oool00`000?l0oooo0?l0000F0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooomD0?ooo`040000o`3o0000o`000?l001D0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0003o0080oooo
00<0o`000?ooo`3oool0o`3ooomF0?ooo`040?l000000?l0o`000?l001H0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0A0?ooo`80o`0000<0003o0?ooo`3oool00`3o003o0?oooeP0oooo
00@0o`000000o`3oool0o`005@3oool100000040oooo000R0?ooo`030000003oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo
DP3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000o`000080o`004`3oool100000040oooo
000R0?ooo`030000003oool0oooo00L0oooo0`3o00090?ooo`030000o`3oool0oooo0?l0ooooE@3o
ool30?l00080oooo00@0o`000?ooo`000?l0oooo103o000B0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0o`3ooom@0?ooo`030?l0003oool0oooo00<0o`0000<0003o0?ooo`3oool00P3o
000C0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`03
0?ooo`<0o`00o`3ooomE0?ooo`040?l0003oool0oooo0000o`<0o`004`3oool100000040oooo000R
0?ooo`030000003oool0oooo0140oooo00<0o`000000o`3oool01@3oool00`3o0000oooo0?ooo`3o
0?oooeL0oooo00<0003o0?ooo`3o0000503oool100000040oooo000R0?ooo`030000003oool0oooo
00l0oooo0`3o00000`000?l0oooo0?ooo`3o0?oooeh0oooo00<0003o0?ooo`3oool0503oool10000
0040oooo000R0?ooo`030000003oool0oooo00h0oooo103o00000`000?l0oooo0?ooo`3o0?oooe/0
oooo00@0o`000?ooo`3oool0003o5P3oool100000040oooo000R0?ooo`030000003oool0oooo00l0
oooo00@0o`000?ooo`3oool0003oo`3ooomL0?ooo`<0o`0000<0oooo0000o`3oool05@3oool10000
0040oooo000R0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`3o0?oooe@0oooo00@0o`000?ooo`3oool0003o5P3oool100000040oooo000R0?ooo`80
00004P3oool00`000?l0oooo0?ooo`040?ooo`<0o`00o`3ooomI0?ooo`030000o`3oool0oooo0180
oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0o`3ooomH0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
303oool100000040oooo000R0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool0o`3o
oomP0?ooo`030000o`3oool0oooo00<0oooo0`3o000=0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool03P3oool01@3o0000oooo0?ooo`000?l0o`000?l0ooooH@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0=
0?ooo`<0o`0000@0oooo0000o`3o0000o`00o`3ooomP0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0303oool100000040oooo000R0?ooo`030000003oool0oooo00h0oooo00D0o`00
0?ooo`3oool0003o0?l0003o0?ooof40oooo00<0003o0?ooo`3oool00`3oool30?l000d0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030?l000000?l0oooo0?l0ooooH`3oool0
10000?l0oooo0?ooo`3o00020?ooo`030?l0003oool0oooo00`0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0>0?ooo`80o`0000<0003o0?ooo`3oool0o`3ooomR0?ooo`030000o`3oool0
o`000080o`00403oool100000040oooo000R0?ooo`030000003oool0oooo00T0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000003o0?ooo`3o0?ooof<0oooo00@0003o0?ooo`3oool0o`00103oool0
0`3o0000oooo0?ooo`0:0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0203oool30?l0
00<0oooo00<0o`000?ooo`000?l01@3oool00`3o0000oooo0?ooo`3o0?oooeH0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`<0o`002`3oool100000040oooo000R0?ooo`03
0000003oool0oooo00T0oooo00@0o`000?ooo`3oool0oooo0`3o00000`000?l0oooo0?ooo`020?oo
o`<0o`00o`3ooomF0?ooo`<0o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0003o00D0
oooo00<0o`000?ooo`3oool0o`3ooomF0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0<0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l00?l0ooooH@3oool20?l00003
0000o`3oool0oooo00@0o`003@3oool100000040oooo000R0?ooo`030000003oool0oooo00T0oooo
0`3o00030?ooo`030000o`3oool0o`000080o`00o`3ooomO0?ooo`<0o`0000<0003o0?ooo`3o0000
103o000=0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool02P3oool02@3o0000oooo0?oo
o`3oool0o`000000o`3o0000oooo0?l0003o0?oooel0oooo00H0o`000?ooo`3o0000oooo0000o`3o
ool40?l000h0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0o`3ooomO0?ooo`<0o`000P3oool010000?l0oooo0?ooo`3o
000@0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool40?l000@0oooo00<0003o
0?ooo`3oool0o`3ooomP0?ooo`050?l0003oool0oooo0?ooo`000?l04`3oool100000040oooo000R
0?ooo`030000003oool0oooo00P0oooo103o00030?ooo`030000o`3oool0oooo0?l0ooooI03oool0
0`000?l0oooo0?ooo`0A0?ooo`4000000@3oool00280oooo0P00000;0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0o`3ooomT0?ooo`030000o`3oool0oooo0100oooo0P0000010?oo
o`008P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0?l0ooooH03oool01@3o0000
oooo0?ooo`3oool0003o01<0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`04
0?l0003oool0oooo0000ool0ooooHP3oool30?l000<0oooo00<0003o0?ooo`3oool0403oool10000
0040oooo000R0?ooo`030000003oool0oooo00X0oooo0`3o00000`3oool0003o0?ooo`3o0?ooof80
oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`3o000?0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool02`3oool0103o0000oooo0?ooo`000?oo0?ooofP0oooo00<0003o0?oo
o`3o00000P3o000>0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0203oool00`3o0000
oooo0?l000030?ooo`030000o`3oool0oooo0?l0ooooIP3oool010000?l0oooo0?ooo`3o000?0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool50?l000030?ooo`3o0000003o0?l0
ooooHP3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`080?ooo`040?l0003oool0o`000?ooo`80o`0000<0003o0?ooo`3o
ool0o`3ooomO0?ooo`<0o`00103oool00`000?l0oooo0?ooo`0@0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool01`3oool30?l000<0oooo00<0o`000000o`3oool01`3oool00`3o0000oooo
0?ooo`3o0?oooeL0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo0`3o003o0?oooeh0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0;0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool30?l000@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?oooeD0oooo00<0o`000?ooo`3oool01@3oool0
10000?l0oooo0?ooo`3oool30?l000`0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`07
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`3o0?oooed0oooo0`3o00060?ooo`040000o`3oool0
o`000?ooo`<0o`00303oool100000040oooo000R0?ooo`030000003oool0oooo00H0oooo0`3o0005
0?ooo`030000o`3oool0oooo0?l0ooooGP3oool00`3o0000oooo0?ooo`050?ooo`060000o`3o0000
o`000?l0003oool0o`003@3oool100000040oooo000R0?ooo`030000003oool0oooo00L0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`3o0?ooofP0oooo00<0003o0?l0003oool03`3o
ool100000040oooo000R0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool0o`3ooomX
0?ooo`030000o`3oool0oooo00l0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`020?oo
o`050=nLB000000000000000B02Lgol0203oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0?l0ooooJ03oool00`000?l0oooo0?ooo`0?0?ooo`4000000@3oool00100oooo00/0omnL04P0
M02oool0oooo0?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo00d0
oooo00<0003o0?ooo`3oool0o`3ooomX0?ooo`030000o`3oool0oooo00l0oooo0@0000010?ooo`00
403oool00`3ogi`0B01d0;ooo`060?ooo`030;md001d_ol0oooo00H0oooo00<000000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`3o0?ooofP0oooo00<0003o0?ooo`3oool03`3oool100000040oooo
000@0?ooo`030?oOW01807@0_ooo00H0oooo00<0_g@007Boo`3oool01P3oool3000000d0oooo00<0
003o0?ooo`3oool0o`3ooomX0?ooo`030000o`3oool0oooo00d0oooo0`0000010?ooo`00403oool0
2`3ogi`0B01d0;ooo`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00L0oooo00<000000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo0?l0ooooJ@3oool01@00
0?l0oooo0?ooo`3oool0o`0000d0oooo0@0000010?ooo`00403oool01P3ogi`0B01d0;ooo`3oool0
oono07@000<0000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`<0o`000`3o
ool20?l000030000o`3o0000oooo0?l0ooooJ03oool00`000?l0oooo0?ooo`030?l000<0oooo00<0
o`000?ooo`3oool01P3oool100000040oooo000>0?ooo`090;md000004P0W;nL04P0M02oool0oooo
0?oog`2LB4P0W=oo00/0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`04
0?l000000?l0o`000?l00?l0ooooJ03oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo0`3o0007
0?ooo`4000000@3oool000l0oooo00@0okmd0000000007@0_ooo0P3oool00`2oM000M;oo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo00<0003o0?l0003oool0o`3ooomT0?ooo`050?l0003oool0
oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`060?ooo`4000000@3oool00100oooo00<0omnL
04P0M02oool00P3oool01P3OW4P00000000000000000001d0;ooo`L0oooo00<000000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`3o0?ooof<0oooo0`3o00020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool02@3oool100000040oooo000R0?ooo`030000003oool0oooo00P0oooo00L0
o`000?ooo`3oool0oooo0?l0003oool0003o00L0oooo00<0o`000?ooo`3oool0o`3ooomK0?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool40?l000X0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`070?ooo`<0o`0000D0oooo0?l0003o0000o`000000o`060?ooo`<0o`00o`3ooomK0?oo
o`<0o`000P3oool00`000?l0oooo0?ooo`040?l00080oooo00<0o`000?ooo`3oool01P3oool10000
0040oooo000R0?ooo`030000003oool0oooo00P0oooo00L0o`000?ooo`3oool0oooo0?l0003oool0
003o00L0oooo00<0o`000?ooo`3oool0o`3ooomK0?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool0103o0000oooo0?ooo`3oool30?l000L0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0?l0ooooI`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0o`000?ooo`3oool01P3oool100000040oooo000R0?ooo`030000003oool0oooo00h0oooo00<0
003o0?ooo`3oool0o`3ooomU0?ooo`030?l0003oool0003o0080oooo0`3o000<0?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`3o0?oooeh0oooo00<0o`00
0?ooo`3oool00`3oool30?l000050000o`3oool0oooo0?ooo`3o00003@3oool100000040oooo000R
0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3o0000o`3ooomM0?ooo`<0o`001@3oool0
0`3o0000003o0?ooo`0A0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03P3oool01000
0?l0o`000?l0003o003o0?oooed0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool100000040oooo000R0?ooo`030000003oool0
oooo00h0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`3o0?oooeT0oooo0`3o0002
0?ooo`030000o`3oool0oooo00<0oooo0`3o000:0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o003o0?oo
oe/0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00T0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`<0o`001@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo0?l0ooooGP3oool010000?l0oooo0?ooo`3o000?0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
0?l0ooooIP3oool00`000?l0oooo0?l000020?l000h0oooo0@0000010?ooo`008P3oool200000100
oooo00@0003o0?l0003oool0o`00o`3ooomK0?ooo`030?l0003oool0o`0000H0oooo00@0003o0?oo
o`3oool0o`003P3oool200000040oooo000R0?ooo`030000003oool0oooo00h0oooo00<0o`000000
o`3o00000`3o003o0?oooeT0oooo1@3o00050?ooo`030000o`3oool0oooo0100oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00@0003o0?l0003o
ool0o`00o`3ooomK0?ooo`030?l0003oool0o`0000D0oooo00<0o`000000o`3oool00`3oool00`3o
0000oooo0?ooo`0;0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool01P3oool30?l000H0
oooo00<0003o0?ooo`3oool0o`3ooomS0?ooo`80o`0000@0003o0?ooo`3oool0oooo0`3o000<0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0?l0ooooI03oool00`3o0000003o0?ooo`030?ooo`030?l0003oool0oooo00/0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0?l0oooo
H`3oool20?l000030000o`3oool0oooo0100oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0?0?ooo`050000o`3oool0oooo0?ooo`3o0000o`3ooomM0?ooo`030?l0003oool0oooo0080oooo
00<0o`000000o`3oool04@3oool100000040oooo000R0?ooo`030000003oool0oooo00l0oooo00<0
003o0?ooo`3oool00`3o003o0?oooe/0oooo0`3o00040?ooo`030000o`3oool0oooo0100oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0>0?ooo`80o`0000@0003o0?ooo`3oool0o`00o`3o
oomM0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool100000040oooo000R
0?ooo`030000003oool0oooo00l0oooo00<0o`000000o`3oool0o`3ooomT0?ooo`030000o`3oool0
oooo0140oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0?l0ooooF`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0?l0ooooFP3oool30?l000H0
oooo00<0003o0?ooo`3oool04@3oool100000040oooo000R0?ooo`030000003oool0oooo0100oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?oooe@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0B0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`030?ooo`<0o`00o`3ooomL0?ooo`030000o`3o0000oooo0180oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooe/0oooo00<0003o0?l0003o00004P3oool1
00000040oooo000R0?ooo`030000003oool0oooo00P0oooo0`3o00000`3oool0o`000?ooo`030?oo
o`030000o`3oool0oooo0?l0ooooFP3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000o`00
0180oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0o`0000<0
o`000P3oool00`000?l0oooo0?ooo`3o0?oooeT0oooo0`3o00040?ooo`030000o`3oool0o`0001<0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`@0o`0000<0oooo0000o`3oool0
1@3oool00`3o0000oooo0?ooo`3o0?oooe<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0C0?ooo`4000000@3oool00280oooo0P00000?0?ooo`040?l0003oool0oooo0000o`D0oooo
0`3o003o0?oooeX0oooo00<0003o0?ooo`3oool04P3oool200000040oooo000R0?ooo`030000003o
ool0oooo0180oooo00D0003o0?ooo`3o0000o`000?ooo`020?l00?l0ooooF`3oool00`000?l0oooo
0?ooo`0C0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04P3oool00`000?l0o`000?l0
00040?l00?l0ooooEP3oool01`3o0000oooo0?ooo`3oool0o`000000o`3o0000503oool100000040
oooo000R0?ooo`030000003oool0oooo00l0oooo00D0o`000?ooo`3oool0003o0?ooo`020?l00003
0?ooo`3o0000oooo0?l0ooooE@3oool30?l00080oooo00<0003o0?l0003oool0503oool100000040
oooo000R0?ooo`030000003oool0oooo00h0oooo0`3o00000`3oool0003o0?ooo`3o0?oooe/0oooo
00D0o`000?ooo`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00/0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0>0?ooo`80o`000P3oool00`000?l0oooo0?ooo`3o0?oooeh0oooo
00<0003o0?ooo`3oool01@3oool30?l000`0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0=0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`3o0?oooeh0oooo00<0003o0?ooo`3o00001P3o
ool00`3o0000oooo0?ooo`0;0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool03@3oool3
0?l000<0oooo00<0003o0?ooo`3oool0o`3ooomL0?ooo`030000o`3oool0o`000080o`004`3oool1
00000040oooo000R0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0ooooEP3oool010000?l0oooo0?ooo`3o000D
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool04`3oool00`000?l0o`000?ooo`020?oo
o`<0o`00o`3ooomF0?ooo`030?l000000?l0o`0001H0oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`0A0?ooo`030?l0003oool0003o0080o`000`3oool00`3o0000oooo0?ooo`3o0?ooodl0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000003o0?l0000F0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0403oool30?l000030?ooo`000?l0oooo0?l0ooooE03oool30?l000@0oooo
00<0003o0?l0003oool05P3oool100000040oooo000R0?ooo`030000003oool0oooo0140oooo00@0
o`000?ooo`3oool0003oo`3ooomE0?ooo`<0o`000`3oool00`3o0000003o0?ooo`0G0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`3o0?oooe@0oooo00@0
o`000?ooo`3oool0oooo0P3o00000`000?l0oooo0?ooo`0F0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool05@3oool00`000?l0oooo0?ooo`3o0?oooeP0oooo00<0003o0?ooo`3oool05`3o
ool100000040oooo000R0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0o`3ooomH
0?ooo`030000o`3oool0oooo01L0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0B0?oo
o`050?l0003oool0o`000000o`3o0000o`3ooomI0?ooo`030000o`3oool0oooo01L0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`<0o`0000<0oooo0?l000000?l0o`3ooomI0?oo
o`030000o`3oool0oooo01L0oooo0@0000010?ooo`008P3oool2000001<0oooo00D0o`000?ooo`3o
ool0oooo0000o`3o0?oooeP0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?oo
o`8000000@3oool00280oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0?l0ooooE@3oool00`3o0000003o0?l000060?ooo`<0o`00403oool100000040
oooo000R0?ooo`030000003oool0oooo0100oooo0`3o00040?ooo`030000o`3oool0oooo0?l0oooo
B@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
3`3oool100000040oooo000R0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3o00000P3o
ool00`3o0000003o0?l0003o0?ooodT0oooo0`3o00090?ooo`030000o`3oool0oooo01T0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`H0o`0000<0003o0?l0003oool0o`3ooom8
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3o00006P3oool100000040oooo000R0?oo
o`030000003oool0oooo01<0oooo00H0o`000?ooo`3oool0o`000?ooo`000?oo0?oooeD0oooo00<0
003o0?ooo`3oool06@3oool100000040oooo000R0?ooo`030000003oool0oooo01P0oooo00<0003o
0?ooo`3oool0o`3ooomA0?ooo`030?l000000?l0oooo01/0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0I0?ooo`050000o`3oool0oooo0?ooo`3o0000o`3ooom<0?ooo`<0o`0000<0003o
0?ooo`3oool06P3oool100000040oooo000R0?ooo`030000003oool0oooo01T0oooo00<0003o0?oo
o`3oool00`3o003o0?ooodX0oooo103o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
0180oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0F0?ooo`040?l0003oool0oooo0000
o`<0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`030?l0003oool0oooo00@0oooo00@0o`000?oo
o`3oool0003o1P3oool30?l001<0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0E0?oo
o`<0o`000P3oool00`000?l0oooo0?ooo`3o0?ooodD0oooo0`3o00070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool04P3oool100000040oooo000R0?ooo`030000003oool0oooo01H0
oooo00D0o`000?ooo`3oool0oooo0000o`3o0?ooodP0oooo00<0o`000?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o01d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo0?l0ooooBP3oool30?l00080oooo00<0003o0?ooo`3oool06`3oool10000
0040oooo000R0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0o`3ooom00?ooo`03
0?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0003o2@3oool00`3o0000oooo0?ooo`0B0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0?l0oooo>P3oool30?l000@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`<0o`004`3oool100000040oooo000R0?ooo`030000003oool0oooo01/0oooo
00@0003o0?ooo`3oool0oooo0`3o003o0?oooc`0oooo00<0o`000?ooo`3oool00P3oool30?l000D0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0B0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool06`3oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo
@@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo01d0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0H0?ooo`050?l0003oool0o`000?l000000?l00`3oool00`3o0000oooo
0?ooo`3o0?ooodH0oooo00<0o`000000o`3oool0103oool00`3o0000oooo0?ooo`0G0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool05`3oool30?l000050?ooo`3o0000o`000000o`3oool0
0`3o003o0?oooc`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000003o0?l000040?ooo`<0o`00
603oool100000040oooo000R0?ooo`8000006@3oool00`3o0000oooo0?l000020?l000040000o`3o
0000o`000?l00?l0oooo?03oool30?l000T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`0F0?ooo`8000000@3oool00280oooo00<000000?ooo`3oool06@3oool40?l000030?ooo`00
0?l0o`000?l0oooo?P3oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo0200oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0J0?ooo`@0o`0000<0003o0?ooo`3oool0o`3ooom5
0?ooo`80o`0000<0003o0?ooo`3oool07`3oool100000040oooo000R0?ooo`030000003oool0oooo
01X0oooo0`3o00020?ooo`030000o`3oool0oooo0?l0ooooA@3oool00`000?l0oooo0?ooo`0P0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0003o
0?l0ooooA`3oool00`000?l0oooo0?ooo`0P0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool07`3oool01@000?l0oooo0?ooo`3oool0o`000?l0oooo@P3oool00`000?l0oooo0?ooo`0Q0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?l000020?l00?l0
oooo=03oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0240oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0P0?ooo`040000o`3oool0oooo0?l00?l0oooo=03oool30?l000/0
oooo00<0003o0?ooo`3oool08@3oool100000040oooo000R0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool0o`3ooole0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
8P3oool100000040oooo000R0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0o`3o
oom10?ooo`030000o`3oool0oooo0280oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo0?l0oooo?`3oool00`000?l0oooo0?ooo`0S0?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool07`3oool0103o0000oooo0?ooo`000?oo0?oood40oooo00<0003o
0?ooo`3oool08`3oool100000040oooo000R0?ooo`030000003oool0oooo01h0oooo0`3o00020?oo
o`030000o`3oool0oooo0?l0oooo=P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
02@0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`050?l0003oool0oooo0?oo
o`000?l0o`3ooolg0?ooo`<0o`00103oool00`3o0000003o0?l0000U0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool08`3oool00`3o0000003o0?ooo`3o0?ooocH0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0603oool100000040oooo00060?ooo`030?oOW01807@0_ooo0080oooo00/0gia8000000000000
001809cOo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool08P3oool20?l000030000o`3oool0oooo0?l0oooo=03oool30?l000@0oooo00<0
003o0?ooo`3o00000P3oool30?l00080oooo00<0o`000?ooo`3o00000P3o000I0?ooo`4000000@3o
ool000H0oooo00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`030?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`070?ooo`030000003oool0oooo02<0oooo00<0
o`000?ooo`000?l0o`3ooolf0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o00000P3o
00020?ooo`030?l0003oool0oooo00<0o`0000<0oooo0?l0003oool06@3oool100000040oooo0006
0?ooo`030?oOW01807@0_ooo00H0oooo00<0_g@007Boo`3oool01`3oool00`2oM000M;oo0?ooo`06
0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`3oool0o`00o`3ooolh0?ooo`040000o`3o
ool0oooo0?l000L0oooo00<0o`000?ooo`3oool06`3oool100000040oooo00060?ooo`030?oOW018
07@0_ooo00H0oooo00<0_g@007Boo`3oool01`3oool00`2oM000M;oo0?ooo`060?ooo`<000009P3o
ool010000?l0o`000?l0003o003o0?oooc<0oooo00@0o`000?ooo`3oool0003o9`3oool300000040
oooo00060?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol00`3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01`3oool00`000000oooo0?ooo`0W0?ooo`05
0000o`3o0000oooo0?ooo`3o0000o`3oool`0?ooo`<0o`0000<0003o0?ooo`3oool0:03oool10000
0040oooo00060?ooo`060?oOW01807@0_ooo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`02
0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo00<0o`00o`3oool`0?ooo`030?l0003oool0003o02X0oooo0@000001
0?ooo`00103oool02@2oM000001809boW01807@0_ooo0?ooo`3ooml0W4Q809cOo`070?ooo`030?oo
g`2LB4P0W=oo00/0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?l000020?l00?l0oooo
903oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo02T0oooo0@0000010?ooo`00
1@3oool0103o_g@000000000M02oool20?ooo`030;md001d_ol0oooo00L0oooo00<0_g@007Boo`3o
ool02P3oool00`000000oooo0?ooo`0X0?ooo`040?l000000?l0oooo0?l00?l0oooo903oool60?l0
00H0oooo00<0o`000000o`3oool0:`3oool100000040oooo00060?ooo`030?oOW01807@0_ooo0080
oooo00H0gia800000000000000000000M02oool40?ooo`060=nLB000000000000000000007@0_ooo
1`3oool00`000000oooo0?ooo`0W0?ooo`80o`0000<0003o0?l0003oool0o`3ooolU0?ooo`040?l0
003oool0oooo0?l000H0oooo00D0o`000000o`3o0000oooo0?l0000Z0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0:03oool20?l000030000o`3o0000oooo0?l0oooo;`3oool00`000?l0
oooo0?l000020?l002T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`80o`00
00@0003o0?ooo`3oool0o`00o`3oool/0?ooo`050000o`3oool0oooo0?ooo`3o0000:P3oool10000
0040oooo000R0?ooo`030000003oool0oooo02P0oooo0`3o00000`000?l0oooo0?l000020?l00?l0
oooo:P3oool00`000?l0o`000?l0000]0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
:@3oool0103o0000oooo0?ooo`000?l30?l00?l0oooo:@3oool00`000?l0oooo0?l0000^0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool0:`3oool20?l000030000o`3o0000oooo0?l0oooo
:@3oool00`000?l0oooo0?ooo`0^0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0;03o
ool0103o0000003o0?l0003o003o0?ooobP0oooo00<0003o0?ooo`3oool0;`3oool100000040oooo
000R0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0o`3ooolV0?ooo`030000o`3o
ool0oooo0300oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0
oooo0?l0oooo9@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02D0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo0?l0oooo8`3oool00`00
0?l0oooo0?ooo`080?ooo`<0o`009P3oool100000040oooo000R0?ooo`030000003oool0oooo02l0
oooo00<0o`000000o`3o0000o`3ooolO0?ooo`050?l0003oool0oooo0?ooo`000?l0303oool00`3o
0000oooo0?ooo`0U0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0;`3oool20?l00003
0000o`3oool0oooo0?l0oooo703oool30?l000030?ooo`000?l0oooo03@0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0`0?ooo`030?l0003oool0003o0?l0oooo7P3oool0103o0000oooo
0?ooo`000?l60?ooo`030?l0003oool0oooo02`0oooo0@0000010?ooo`008P3oool2000003<0oooo
00<0003o0?l0003o0000o`3ooolJ0?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool30?l00003
0?ooo`3o0000oooo02T0oooo0P0000010?ooo`008P3oool00`000000oooo0?ooo`0b0?ooo`040?l0
00000?l0o`000?l00?l0oooo603oool30?l000030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3o
00000P3o000Z0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0<`3oool00`3o0000003o
0?ooo`3o0?oooaT0oooo00<0o`000?ooo`000?l00P3o000:0?ooo`030?l0003oool0oooo02T0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0?l0oooo5P3o
ool01P3o0000oooo0?ooo`3oool0003o0?l000P0oooo00<0o`000?ooo`3oool0;03oool100000040
oooo000R0?ooo`030000003oool0oooo03D0oooo00<0003o0?l0003oool0o`3ooolD0?ooo`<0o`00
00<0oooo0000o`3oool0203oool30?l002d0oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0d0?ooo`80o`0000<0003o0?l0003o0000o`3oool>0?ooo`030?l0003oool0oooo0080oooo0P3o
00000`3oool0003o0?ooo`0:0?ooo`030?l0003oool0oooo02`0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0e0?ooo`80o`0000<0003o0?l0003o0000o`3oool<0?ooo`<0o`000P3oool3
0?l000030?ooo`000?l0oooo03T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0h0?oo
o`030000o`3o0000oooo0?l0oooo303oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0003o
00h0oooo00<0o`000?ooo`3oool0:P3oool100000040oooo000R0?ooo`030000003oool0oooo03P0
oooo00<0003o0?l0003o0000o`3ooolA0?ooo`030?l000000?l0oooo00d0oooo0`3o000[0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool0=`3oool20?l000030000o`3o0000oooo0?l0oooo
3`3oool00`3o0000003o0?l0000?0?ooo`030?l0003oool0oooo02X0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0h0?ooo`80o`0000<0003o0?l0003o0000o`3oool?0?ooo`030000o`3o
ool0oooo03/0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0i0?ooo`80o`0000<0003o
0?l0003o0000o`3oool=0?ooo`030000o`3oool0oooo03`0oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`0k0?ooo`030?l000000?l0oooo0?l0oooo203oool01@3o0000oooo0?ooo`3oool0
003o00d0oooo00<0o`000?ooo`3oool0;`3oool100000040oooo000R0?ooo`030000003oool0oooo
03d0oooo00<0003o0?ooo`3oool0o`3oool50?ooo`<0o`0000<0oooo0000o`3oool0303oool30?l0
0300oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`80o`0000<0003o0?ooo`3o
ool0o`3oool50?ooo`030?l0003oool0003o00l0oooo00<0o`000?ooo`3oool0;`3oool100000040
oooo000R0?ooo`030000003oool0oooo03d0oooo0P3o00000`000?l0o`000?ooo`3o0?ooo`D0oooo
00<0003o0?ooo`3oool0@03oool100000040oooo000R0?ooo`030000003oool0oooo03h0oooo0P3o
00000`000?l0o`000?ooo`3n0?ooo`050?l0003oool0oooo0?ooo`000?l0@`3oool100000040oooo
000R0?ooo`030000003oool0oooo03l0oooo0P3o00000`000?l0oooo0?ooo`3l0?ooo`<0o`0000<0
oooo0000o`3o00002P3oool00`3o0000oooo0?ooo`0f0?ooo`4000000@3oool00280oooo0P000011
0?ooo`040?l0003oool0003o0?l00?d0oooo00<0o`000?ooo`000?l00`3o00060?ooo`030?l0003o
ool0o`000080o`00=P3oool200000040oooo000R0?ooo`030000003oool0oooo0440oooo00@0o`00
0000o`3o0000o`00o@3oool010000?l0oooo0?ooo`3o00060?ooo`<0o`0000<0oooo0?l0003oool0
=`3oool100000040oooo000R0?ooo`030000003oool0oooo0480oooo00<0o`000000o`3o0000n`3o
ool00`3o0000003o0?ooo`0:0?ooo`030?l0003oool0oooo03T0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`130?ooo`040?l000000?l0o`000?l00>/0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000003o0?l000170?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0A03oool0
103o0000003o0?l0003o003Y0?ooo`<0o`002`3oool00`000?l0o`000?ooo`170?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool0A@3oool0103o0000003o0?ooo`3o003Y0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0h0?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool0A`3oool010000?l0o`000?l0003o003_0?ooo`040?l0003o
ool0oooo0000o`@0oooo00<0o`000?ooo`3oool0203oool30?l003T0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`180?ooo`040000o`3o0000o`000?l00>d0oooo0`3o00000`000?l0oooo
0?ooo`020?ooo`<0o`000`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo03P0oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`190?ooo`040000o`3o0000o`000?l00>d0oooo
00<0o`000000o`3oool00P3oool0103o0000oooo0?ooo`3o00030?ooo`<0o`00@03oool100000040
oooo000R0?ooo`030000003oool0oooo04T0oooo00@0o`000000o`3o0000o`00k@3oool010000?l0
oooo0?ooo`3oool30?l000H0oooo00<0o`000?ooo`3oool0?`3oool100000040oooo000R0?ooo`03
0000003oool0oooo04X0oooo00@0o`000000o`3o0000o`00f@3oool00`3o0000oooo0?ooo`0>0?oo
o`80003o1@3oool00`3o0000oooo0?ooo`170?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0C03oool00`000?l0o`000?ooo`3G0?ooo`<0o`00303oool00`3o0000oooo0000o`1A0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool0C03oool00`3o0000003o0000o`020?ooo`030?l0
003oool0oooo0=<0oooo00<0o`000?ooo`3oool02@3oool30?l000030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0@@3oool100000040oooo000R0?ooo`030000003oool0oooo04d0oooo00<0
o`000?ooo`000?l00`3o003O0?ooo`80o`000P000?l>0?ooo`<0o`00@P3oool100000040oooo000R
0?ooo`030000003oool0oooo0500oooo00@0003o0?l0003o0000o`00e@3oool00`3o0000oooo0?oo
o`040?ooo`040?l0003oool0oooo0000o`/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`110?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0D@3oool00`000?l0o`000?l0
003D0?ooo`<0o`00103oool20?l00080003o2`3oool30?l004P0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`1B0?ooo`80003o00<0o`000?ooo`3oool0c03oool0103o0000oooo0?ooo`3o
00020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?l0
00190?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0D`3oool00`3o0000003o0?ooo`3<
0?ooo`H0o`001`3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0oooo00<0oooo0`3o001:
0?ooo`4000000@3oool00280oooo0P00001F0?ooo`80003oc03oool0103o0000oooo0?ooo`3o0006
0?ooo`80003o0`3o00030?ooo`<0o`001@3oool00`3o0000oooo0?ooo`180?ooo`8000000@3oool0
0280oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo0?ooo`2o0?ooo`030?l0003oool0oooo
0100oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0oooo0500oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`1H0?ooo`80003o^P3oool0103o0000oooo0?ooo`3oool3
0?l00100oooo00<0003o0?ooo`3oool0F`3oool100000040oooo000R0?ooo`030000003oool0oooo
05X0oooo00@0003o0?ooo`3o0000o`00]@3oool30?l000<0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`80003oGP3oool100000040oooo000R0?ooo`030000003oool0oooo
05T0oooo0P3o00020000o`80o`00103oool00`3o0000oooo0?ooo`2^0?ooo`030?l0003oool0oooo
00T0oooo0`3o00030?ooo`030?l0003oool0003o0600oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`1H0?ooo`<0o`0000@0oooo0?l000000?l0003o0`3oool30?l00;`0oooo00D0o`000?oo
o`3oool0oooo0?l000020000of40oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1I0?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o002^0?ooo`040?l0003oool0oooo
0?l000l0oooo00<0003o0?l0003oool0H@3oool100000040oooo000R0?ooo`030000003oool0oooo
0600oooo0P000?l20?l00:L0oooo00<0o`000?ooo`3oool00`3oool60?l000d0oooo00@0003o0?oo
o`3oool0o`00H@3oool100000040oooo000R0?ooo`030000003oool0oooo0680oooo00<0003o0?oo
o`3oool0Y@3oool30?l000D0oooo00@0o`000?ooo`3oool0o`00303oool20000o`80oooo0`3o001P
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0H@3oool20?l00080003o00<0oooo0?l0
003oool0103oool00`3o0000oooo0?ooo`2L0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo05l0oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`1P0?ooo`D0o`0000<0003o0?l0003o00000`3oool30?l00:80
oooo0`3o000=0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0DP3oool100000040
oooo000R0?ooo`030000003oool0oooo0640oooo0P3o00000`3oool0o`000?ooo`020000o`@0oooo
00<0o`000?ooo`3oool0XP3oool00`3o0000oooo0?ooo`0:0?ooo`80003o1P3oool00`3o0000oooo
0?ooo`0:0?ooo`<0o`00D`3oool100000040oooo000R0?ooo`030000003oool0oooo06L0oooo00<0
o`000000o`3oool0103oool00`3o0000oooo0?ooo`2N0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`<0o`00303oool00`3o0000oooo0?oo
o`1B0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0IP3oool30?l000040000o`3oool0
oooo0?ooo`<0o`00WP3oool30?l000<0oooo0`3o00040?ooo`80003o2@3oool00`3o0000oooo0?oo
o`1P0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0I@3oool30?l00080oooo0P000?l2
0?ooo`040?l0003oool0oooo0?l008d0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`030?ooo`040?l0003oool0oooo0?ooo`80003o2@3oool00`3o0000oooo0?ooo`1R0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0IP3oool00`3o0000oooo0?ooo`030?ooo`80003o0P3o
ool30?l008/0oooo0`3o000F0?ooo`80003o2P3oool30?l006<0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`1/0?ooo`80o`000P000?l00`3oool0o`000?ooo`040?ooo`030?l0003oool0
oooo08<0oooo00<0o`000?ooo`3o00002`3oool00`3o0000oooo0?ooo`070?ooo`80003o303oool2
0?l006@0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1]0?ooo`030?l0003oool0oooo
0080003o00@0o`000?ooo`3oool0oooo0`3o00230?ooo`<0o`002`3oool30?l000H0oooo0P000?l=
0?ooo`<0o`00I03oool100000040oooo000R0?ooo`800000LP3oool00`3o0000003o0000o`030?oo
o`030?l0003oool0oooo08<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?l000050?oo
o`80003o403oool00`3o0000oooo0?ooo`1R0?ooo`8000000@3oool00280oooo00<000000?ooo`3o
ool0L03oool30?l000060?ooo`000?l0003o0000o`3oool0o`000P3oool00`3o0000oooo0?ooo`2:
0?ooo`<0o`000`3oool30000ogP0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`1a0?oo
o`040?l0003oool0oooo0?l00080oooo0P000?l40?l00080oooo00@0o`000?ooo`3oool0o`000P3o
ool00`3o0000oooo0?ooo`210?ooo`030?l0003oool0oooo0080003oN`3oool100000040oooo000R
0?ooo`030000003oool0oooo0700oooo1P3o00000`3oool0o`000?l000020000o`030?l0003oool0
oooo00T0o`00M03oool00`3o0000oooo0?ooo`0<0?ooo`80003oO@3oool100000040oooo000R0?oo
o`030000003oool0oooo0740oooo00@0o`000?ooo`3oool0o`000`3oool00`3o0000oooo0?l00002
0000o`80oooo0P3o00000`3oool0o`000?l000020?l007@0oooo0`3o000;0?ooo`80003oO`3oool1
00000040oooo000R0?ooo`030000003oool0oooo07/0oooo00<0o`000?ooo`000?l00P000?l20?l0
0080oooo00<0o`000?ooo`3oool0E@3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool00`000?l<0?ooo`030?l0003oool0oooo0780oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`200?ooo`<0003o203oool00`3o0000oooo0?ooo`1=0?ooo`<0
o`008`3oool0103o0000003o0000o`000?l70?ooo`030?l0003oool0oooo00@0oooo0`3o001c0?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0P`3oool30000o`@0oooo0`3o00030?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0k0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0603oool30000o`030?l0003oool0oooo00H0
oooo0`3o00060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0K@3oool100000040
oooo000R0?ooo`030000003oool0oooo08@0oooo0P3o00030000o`80oooo00@0o`000?ooo`3oool0
oooo0`3o00020?ooo`<0o`001P3oool30?l000T0oooo00<0o`000?ooo`3oool0;03oool00`3o0000
oooo0?ooo`080?ooo`<0o`002P3oool00`3o0000oooo0?ooo`090?ooo`<0003o0`3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool30?l006h0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`240?ooo`80o`000`3oool20000o`D0oooo
00H0o`000?ooo`3oool0o`000?ooo`3o00080?ooo`030?l0003oool0oooo00L0oooo103o00060?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool04P3oool30?l000X0oooo00<0o`000?oo
o`3oool0203oool30?l000H0oooo10000?l50?ooo`<0o`003@3oool30?l000D0oooo00<0o`000?oo
o`3oool0K@3oool100000040oooo000R0?ooo`030000003oool0oooo08<0oooo0`3o00020?ooo`<0
o`000`000?l40?ooo`<0o`003@3oool00`3o0000oooo0?ooo`040?ooo`@0o`00103oool30?l00080
oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?l000020?l000/0oooo00<0o`000?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`000100oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`<0003o00@0oooo0?l0003o0000o`001P3oool00`3o0000oooo0?oo
o`0=0?ooo`030?l0003oool0oooo07@0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`24
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?l000L0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?l000<0oooo0`3o00000`3oool0o`000?ooo`0:0?ooo`<0o`000P3oool3
0?l000P0oooo00<0o`000?ooo`3oool01`3oool30?l000H0oooo00@0o`000000o`000?l0003o103o
ool20?l00140oooo00<0o`000?ooo`3oool0NP3oool100000040oooo000R0?ooo`030000003oool0
oooo0940oooo0`000?l30?ooo`030?l0003oool0oooo0080oooo103o00020?ooo`030?l0003oool0
oooo0140oooo00@0o`000?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool01P3oool40?l000P0oooo00<0o`000?ooo`3oool00P3o
ool40000o`030?l0003oool0oooo00<0oooo0`3o000@0?ooo`<0o`00N`3oool100000040oooo000R
0?ooo`030000003oool0oooo0940oooo00<0o`000?ooo`3oool010000?l00`3o0000oooo0?ooo`04
0?l003l0oooo103o00080?ooo`@0003o00@0oooo0?l0003oool0o`001`3oool00`3o0000oooo0?oo
o`050?ooo`80o`002@3oool00`3o0000oooo0?ooo`1j0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0T03oool30?l000@0oooo00<0o`000000o`000?l010000?lf0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00P3oool50000o`@0oooo103o000>0?ooo`@0o`00Q@3oool1
00000040oooo000@0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@000000000001d0;ooo`08
0?ooo`030000003oool0oooo0940oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`05
0?ooo`H0003o9P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0o`000080o`001@3oool0
0`3o0000oooo0?ooo`020?ooo`D0003o2P3oool40?l000H0oooo00<0o`000?ooo`3oool01@3oool2
0?l008H0oooo0@0000010?ooo`00403oool00`3ogi`0B01d0;ooo`020?ooo`060;md001d_ol0oooo
0?oOW018B9`0gooo1`3oool00`000000oooo0?ooo`2E0?ooo`<0o`00303oool60000oad0oooo00<0
o`000?ooo`3o00000P3o00040?ooo`<0o`0000<0oooo0?l0003oool0103oool20?l000@0003o4@3o
ool00`3o0000oooo0?ooo`040?ooo`<0o`00SP3oool100000040oooo000@0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M4RL0=ooo`3oool0oono07@0B02Lgol01`3oool00`000000oooo0?ooo`2F0?oo
o`030?l0003oool0oooo0140oooo2P000?l?0?ooo`030?l0003oool0oooo00<0o`0000<0oooo0?l0
003oool01@3oool00`3o0000003o0000o`080000oa00oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`2=0?ooo`4000000@3oool00100oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`070?ooo`<00000VP3oool00`3o0000oooo0?ooo`0C0?ooo`040?l0
003oool0oooo0?oooah0003o6@3oool30?l009T0oooo0`0000010?ooo`00403oool02`3ogi`0B01d
0;ooo`3oool0omnL04P0001d_ol0oooo0?oOW018B9`0gooo00L0oooo00<000000?ooo`3oool0V@3o
ool30?l000T0oooo00<0o`000?ooo`3oool01`3oool30?l00080oooo0`3o0000103oool0o`000?l0
003o00080?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0Q`3oool100000040oooo
000@0?ooo`0:0?oOW01807@0_ooo0?ooo`3ogi`0B4RL09ad00000000001809cOo`P0oooo00<00000
0?ooo`3oool0VP3oool00`3o0000oooo0?ooo`070?ooo`<0o`00203oool20?l000@0oooo00D0o`00
0?ooo`3oool0oooo0?l0000D0?ooo`<0o`002@3oool30?l000h0oooo0`3o000@0?ooo`<0o`00R03o
ool100000040oooo000>0?ooo`090;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo00/0
oooo00<000000?ooo`3oool0XP3oool0103o0000oooo0?ooo`3o00080?ooo`<0o`003P3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo08L0oooo0@0000010?ooo`003`3oool0103o_g@0
00000000M02oool20?ooo`060;md001d_ol0oooo0?noM000B9`0gooo1`3oool00`000000oooo0?oo
o`2Q0?ooo`<0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`030?l000P0oooo00<0o`000?ooo`3oool0_@3oool100000040oooo
000@0?ooo`030?oOW01807@0_ooo0080oooo00D0oooO09a800000000001809cOo`080?ooo`030000
003oool0oooo0:80oooo00@0o`000?ooo`3oool0oooo0`3o0000103oool0o`000?l0003o00030?oo
o`050?l0003oool0oooo0?ooo`3o00001@3oool30?l00080oooo00<0o`000?ooo`3oool01P3oool3
0?l000X0oooo00<0o`000?ooo`3o0000/@3oool100000040oooo000R0?ooo`030000003oool0oooo
0:L0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`<0o`0000@0oooo0?l0003o0000o`001@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo1@3o000=0?ooo`030?l0003o
ool0oooo0:00oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`2`0?ooo`050?l0003oool0
oooo0?ooo`3o00004@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0o`0000d0oooo0`3o
002Q0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0a@3oool30?l001h0oooo00<0o`00
0?ooo`3oool0X03oool100000040oooo000R0?ooo`030000003oool0oooo0<H0oooo00<0o`000?oo
o`3oool0`03oool100000040oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040
oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003o
ool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool1
00000040oooo000R0?ooo`030000003oool0oooo0?l0ooooRP3oool100000040oooo000R0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0?0?ooo`40
00000@3oool00280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool100000040oooo000R0?ooool00000SP00
00010?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {429.875, 0}} -> {3.71861, 13.7532, \
0.00829032, 0.00829032}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindRoot", "Subsection"],

Cell["Supports general array variables", "BulletText"],

Cell["New and improved methods; better for large scale problems", "BulletText"],

Cell[CellGroupData[{

Cell["Example: Computing Eigenvalues and Eigenvectors", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell["Suppose we have the following matrix. ", "MathCaption"],

Cell[BoxData[
    \(\(A = \ {{1, 2}, {3, 4}};\)\)], "Input",
  CellLabel->"In[47]:="],

Cell[TextData[{
  "This finds a solution to the equations ",
  Cell[BoxData[
      \(TraditionalForm\`A . v = \[Lambda]\ v\ , \ v\  . v \[Equal] 1\)]],
  ", which solves for an eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " and corresponding normalized eigenvector ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{A . v\  == \ \[Lambda]\ v, 
        v . v\  \[Equal] \ 1}, {{v, {1, 2}}, {\[Lambda], \ 1}}]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({v \[Rule] {0.4159735579192843`, 
          0.9093767091321241`}, \[Lambda] \[Rule] 
        5.372281323269014`}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{A . v\  == \ \[Lambda]\ v, 
        v . v\  \[Equal] \ 
          1}, {{v, {1, 2}}, {\[Lambda], \ \(-0.2\)}}]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({v \[Rule] {\(-0.8245648401323937`\), 
          0.5657674649689923`}, \[Lambda] \[Rule] \
\(-0.3722813232690143`\)}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["You can specify a method to compute the Jacobian. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{A . v\  == \ \[Lambda]\ v, 
        v . v\  \[Equal] \ 1}, {{v, {1, 2}}, {\[Lambda], \ 1}}, \ 
      Jacobian\  \[Rule] \ "\<FiniteDifference\>"]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({v \[Rule] {0.4159735579192843`, 
          0.9093767091321241`}, \[Lambda] \[Rule] 
        5.372281323269014`}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["Or you can provide an explicit symbolic Jacobian. ", "MathCaption"],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input",
  CellLabel->"In[58]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{A . v\  == \ \[Lambda]\ v, 
        v . v\  \[Equal] \ 1}, {{v, {1, 2}}, {\[Lambda], \ 1}}, \ 
      Jacobian\  \[RuleDelayed] \ 
        BlockMatrix[\ {{A - \[Lambda]\ IdentityMatrix[2], \ 
              Transpose[{\(-v\)}]}, \ {{2\ v}, \ {{0. }}}}\ ]]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({v \[Rule] {0.41597355791928425`, 
          0.9093767091321241`}, \[Lambda] \[Rule] 
        5.372281323269014`}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[TextData[{
  "For this particular problem there are of course specialized solvers in ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[\ N[\ A\ ]\ ]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \({5.372281323269014`, \(-0.3722813232690143`\)}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[\ N[\ A\ ]\ ]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \({{\(-0.41597355791928436`\), \(-0.9093767091321241`\)}, \
{\(-0.8245648401323937`\), 0.5657674649689923`}}\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NMinimize / NMaximize", "Subsection"],

Cell["Global constrained optimization functionality", "BulletText"],

Cell["Enhanced methods and moved into kernel", "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Differential Equations", "Section"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " now supports use of vector, matrix, or general array variables."
}], "BulletText"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " can now solve differential-algebraic equations (DAEs). "
}], "BulletText"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " can now solve ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-dimensional initial value partial differential equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["NDSolve", "MR"],
  " now has a very complete collection of initial value solvers. "
}], "BulletText"],

Cell["\<\
Competitive Situation: Most complete collection of solvers; beats Matlab on \
speed (rkf45 example). \
\>", "Text"],

Cell[CellGroupData[{

Cell["Example: Vector Variables", "Subsection"],

Cell[TextData[{
  "This is using the fundamental theorem of space curves, uniquely (except \
for rigid motions) defining a space curve based upon knowing the curvature ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa][t]\)]],
  " and torsion ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau][t]\)]],
  ". This is a linear time varying system, of dimension 12. "
}], "MathCaption"],

Cell[BoxData[
    \(\(Off[\ ParametricPlot3D::ppcom\ ];\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(IntrinsicCurve3D[\ {\[Kappa]_, \ \[Tau]_}, {s_, \ smin_, \ 
            smax_}, \ {s0_?NumericQ, \ x0_?VectorQ, \ t0_?VectorQ, \ 
            n0_?VectorQ}, \ 
          opts___?OptionQ]\  := \[IndentingNewLine]Module[\ {x, \ t, \ n, \ 
            b, \ s, \ c}, \[IndentingNewLine]c\  = \ 
            x /. \ First\ @\ \[IndentingNewLine]NDSolve[\[IndentingNewLine]{\
\[IndentingNewLine]\(x'\)[s]\  \[Equal] \ 
                      t[s], \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ x[s0] \[Equal] \ 
                      x0, \[IndentingNewLine]\(t'\)[
                        s]\  \[Equal] \ \[Kappa]\ n[
                          s], \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ t[s0] \[Equal] \ 
                      t0, \[IndentingNewLine]\(n'\)[
                        s]\  \[Equal] \ \[Tau]\ b[s] - \ \[Kappa]\ t[
                            s], \ \ \ \ \ \ \ \ \ \ \ n[
                        s0] \[Equal] \ \ n0, \[IndentingNewLine]\(b'\)[
                        s]\  \[Equal] \ \(-\[Tau]\)\ n[
                          s], \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ b[s0] \[Equal] \ Cross[\ t0, \ 
                        n0]\[IndentingNewLine]}, \[IndentingNewLine]{x, \ 
                    t, \ n, \ b}, \ \[IndentingNewLine]{s, \ smin, \ 
                    smax}\[IndentingNewLine]]; \
\[IndentingNewLine]ParametricPlot3D[c[s], \ {s, \ smin, \ smax}, \ 
            opts\ ]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(\(IntrinsicCurve3D[\ {\[Kappa]_, \ \[Tau]_}, \ {s_, \ smin_, \ 
            smax_}, \ 
          opts___?OptionQ\ ]\  := \ \[IndentingNewLine]IntrinsicCurve3D[{\
\[Kappa], \ \[Tau]}, \ {s, \ smin, \ 
            smax}, \ {0, \ {0, 0, 0}, \ {1, 0, 0}, \ {0, 1, 0}}, \ 
          opts\ ];\)\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
Some examples of space curves defined by curvature and torsion.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(Clear[\ s\ ];\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(IntrinsicCurve3D[\ {Abs[s], \ 0.3}, \ {s, \(-10\), \ 10}, \ 
        PlotPoints\  \[Rule] \ 500\ ];\)\)], "Input",
  CellLabel->"In[55]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .87694 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-0.0142779 1.01428 -0.0485214 1.01428 [
[.31828 .85915 -7.24155 0 ]
[.31828 .85915 6.69595 10.9375 ]
[.58047 .78855 -4.13454 0 ]
[.58047 .78855 4.30296 10.9375 ]
[.8642 .71209 -3.8555 0 ]
[.8642 .71209 4.582 10.9375 ]
[.82287 .00129 0 -7.48904 ]
[.82287 .00129 8.4375 3.44846 ]
[.85392 .05001 0 -7.44313 ]
[.85392 .05001 19.5625 3.49437 ]
[.88385 .09695 0 -7.39926 ]
[.88385 .09695 15.125 3.53824 ]
[.91271 .14223 0 -7.35729 ]
[.91271 .14223 19.5625 3.58021 ]
[.94055 .18592 0 -7.31711 ]
[.94055 .18592 8.4375 3.62039 ]
[.97013 .30603 0 -7.21943 ]
[.97013 .30603 20.625 3.71807 ]
[.98433 .4251 0 -7.12681 ]
[.98433 .4251 8.4375 3.81069 ]
[.99942 .55164 0 -7.02878 ]
[.99942 .55164 15.125 3.90872 ]
[ 0 0 0 0 ]
[ 1 .87694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.206 .87694 m
1 .66249 L
s
.31877 .84648 m
.31902 .84015 L
s
gsave
.31828 .85915 -68.2416 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.58022 .77587 m
.58009 .76953 L
s
gsave
.58047 .78855 -65.1345 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.86312 .69946 m
.86257 .69315 L
s
gsave
.8642 .71209 -64.8555 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.36946 .83279 m
.36957 .82899 L
s
.42093 .81889 m
.421 .81509 L
s
.4732 .80477 m
.47322 .80097 L
s
.52629 .79043 m
.52626 .78663 L
s
.635 .76107 m
.63487 .75727 L
s
.69066 .74604 m
.69048 .74224 L
s
.74722 .73077 m
.74699 .72697 L
s
.80469 .71524 m
.80442 .71145 L
s
.26884 .85997 m
.26904 .85617 L
s
.21966 .87325 m
.21989 .86945 L
s
.9225 .68342 m
.92212 .67964 L
s
.98288 .66712 m
.98245 .66334 L
s
.25 Mabswid
.80735 0 m
.94728 .21936 L
s
.81098 .00568 m
.80503 .00788 L
s
gsave
.82287 .00129 -61 -11.489 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.842 .05431 m
.83604 .05646 L
s
gsave
.85392 .05001 -61 -11.4431 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.87189 .10117 m
.86591 .10328 L
s
gsave
.88385 .09695 -61 -11.3993 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.90072 .14637 m
.89473 .14843 L
s
gsave
.91271 .14223 -61 -11.3573 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.92854 .18998 m
.92254 .19201 L
s
gsave
.94055 .18592 -61 -11.3171 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.81728 .01556 m
.81371 .01687 L
s
.82353 .02535 m
.81995 .02666 L
s
.82973 .03508 m
.82616 .03638 L
s
.83589 .04473 m
.83231 .04603 L
s
.84807 .06382 m
.84449 .06511 L
s
.85409 .07326 m
.85051 .07454 L
s
.86007 .08263 m
.85648 .08391 L
s
.866 .09194 m
.86242 .09321 L
s
.87774 .11034 m
.87415 .1116 L
s
.88355 .11945 m
.87996 .1207 L
s
.88931 .12848 m
.88572 .12973 L
s
.89504 .13746 m
.89144 .1387 L
s
.90636 .15521 m
.90277 .15645 L
s
.91197 .16399 m
.90837 .16523 L
s
.91753 .17272 m
.91393 .17394 L
s
.92305 .18138 m
.91945 .1826 L
s
.93399 .19852 m
.93038 .19973 L
s
.9394 .207 m
.93579 .2082 L
s
.94477 .21542 m
.94116 .21662 L
s
.25 Mabswid
.94728 .21936 m
1 .66249 L
s
.95806 .3099 m
.95202 .31183 L
s
gsave
.97013 .30603 -61 -11.2194 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.9722 .42878 m
.96613 .43062 L
s
gsave
.98433 .4251 -61 -11.1268 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.98723 .55512 m
.98113 .55685 L
s
gsave
.99942 .55164 -61 -11.0288 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.96082 .33311 m
.95719 .33426 L
s
.96361 .3566 m
.95998 .35774 L
s
.96644 .38037 m
.96281 .3815 L
s
.9693 .40443 m
.96566 .40554 L
s
.97513 .45343 m
.97149 .45452 L
s
.9781 .47838 m
.97445 .47946 L
s
.9811 .50364 m
.97745 .50471 L
s
.98415 .52922 m
.98049 .53027 L
s
.95533 .28696 m
.95171 .28813 L
s
.95263 .26429 m
.94901 .26547 L
s
.94996 .24188 m
.94635 .24307 L
s
.94733 .21973 m
.94372 .22093 L
s
.99035 .58134 m
.98668 .58237 L
s
.99351 .6079 m
.98984 .60891 L
s
.9967 .63479 m
.99304 .6358 L
s
.99995 .66204 m
.99627 .66303 L
s
.25 Mabswid
.04993 .28056 m
0 .71811 L
s
0 .71811 m
.206 .87694 L
s
.206 .87694 m
.23289 .4573 L
s
.23289 .4573 m
.04993 .28056 L
s
.80735 0 m
.94728 .21936 L
s
.94728 .21936 m
1 .66249 L
s
1 .66249 m
.84757 .46041 L
s
.84757 .46041 m
.80735 0 L
s
.04993 .28056 m
0 .71811 L
s
0 .71811 m
.84757 .46041 L
s
.84757 .46041 m
.80735 0 L
s
.80735 0 m
.04993 .28056 L
s
.23289 .4573 m
.94728 .21936 L
s
.94728 .21936 m
1 .66249 L
s
1 .66249 m
.206 .87694 L
s
.206 .87694 m
.23289 .4573 L
s
0 0 m
1 0 L
1 .87694 L
0 .87694 L
closepath
clip
newpath
.5 Mabswid
.30753 .5144 m
.29804 .51974 L
s
.31674 .50866 m
.30753 .5144 L
s
.32557 .50256 m
.31674 .50866 L
s
.29804 .51974 m
.28834 .52465 L
s
.33393 .49613 m
.32557 .50256 L
s
.28834 .52465 m
.27851 .52912 L
s
.34173 .48941 m
.33393 .49613 L
s
.27851 .52912 m
.26865 .53312 L
s
.34889 .48245 m
.34173 .48941 L
s
.26865 .53312 m
.25882 .53665 L
s
.3553 .47531 m
.34889 .48245 L
s
.25882 .53665 m
.24909 .53969 L
s
.3609 .46804 m
.3553 .47531 L
s
.26443 .3836 m
.2544 .38785 L
s
.27291 .37768 m
.26443 .3836 L
s
.24909 .53969 m
.23954 .54224 L
s
.2915 .45413 m
.28166 .45893 L
s
.30079 .44857 m
.2915 .45413 L
s
.26477 .39033 m
.25461 .39423 L
s
.27377 .38473 m
.26477 .39033 L
s
.2544 .38785 m
.2443 .38985 L
s
.28166 .45893 m
.27155 .46286 L
s
.30924 .44237 m
.30079 .44857 L
s
.26902 .39631 m
.25898 .40058 L
s
.27786 .39056 m
.26902 .39631 L
s
.25461 .39423 m
.24459 .39599 L
s
.27154 .40503 m
.26146 .40924 L
s
.28062 .39944 m
.27154 .40503 L
s
.25898 .40058 m
.2488 .40295 L
s
.28045 .3781 m
.27377 .38473 L
s
.27858 .37088 m
.27291 .37768 L
s
.2832 .42972 m
.2733 .43438 L
s
.29232 .42407 m
.2832 .42972 L
s
.27877 .4141 m
.26892 .41883 L
s
.28756 .40824 m
.27877 .4141 L
s
.27155 .46286 m
.26145 .46583 L
s
.26892 .41883 m
.25868 .42216 L
s
.2733 .43438 m
.26309 .43786 L
s
.26146 .40924 m
.25127 .41175 L
s
.28451 .38389 m
.27786 .39056 L
s
.31662 .4357 m
.30924 .44237 L
s
.2879 .39291 m
.28062 .39944 L
s
.30022 .41768 m
.29232 .42407 L
s
.36559 .46071 m
.3609 .46804 L
s
.2443 .38985 m
.23559 .38935 L
s
.29467 .40163 m
.28756 .40824 L
s
.23954 .54224 m
.23023 .54431 L
s
.25868 .42216 m
.24874 .42391 L
s
.26309 .43786 m
.25306 .44003 L
s
.2488 .40295 m
.23957 .40322 L
s
.24459 .39599 m
.23596 .39543 L
s
.26145 .46583 m
.25163 .46781 L
s
.25127 .41175 m
.24185 .41237 L
s
.28393 .37123 m
.28045 .3781 L
s
.30646 .41082 m
.30022 .41768 L
s
.32266 .42871 m
.31662 .4357 L
s
.29269 .38598 m
.2879 .39291 L
s
.28054 .36419 m
.27858 .37088 L
s
.28822 .37699 m
.28451 .38389 L
s
.29958 .39467 m
.29467 .40163 L
s
.25306 .44003 m
.24368 .44083 L
s
.36929 .45339 m
.36559 .46071 L
s
.24874 .42391 m
.23975 .42397 L
s
.23023 .54431 m
.22122 .54588 L
s
.23559 .38935 m
.22954 .38645 L
s
.25163 .46781 m
.24235 .46874 L
s
.23957 .40322 m
.23226 .40138 L
s
.31073 .4038 m
.30646 .41082 L
s
.24185 .41237 m
.234 .41107 L
s
.32717 .42161 m
.32266 .42871 L
s
.23596 .39543 m
.2298 .39265 L
s
.28369 .36499 m
.28393 .37123 L
s
.29453 .37925 m
.29269 .38598 L
s
.28854 .37059 m
.28822 .37699 L
s
.30192 .38784 m
.29958 .39467 L
s
.24368 .44083 m
.23538 .44023 L
s
.27845 .35856 m
.28054 .36419 L
s
.37195 .44614 m
.36929 .45339 L
s
.23975 .42397 m
.23232 .42239 L
s
.22122 .54588 m
.21255 .54697 L
s
.24235 .46874 m
.23385 .46864 L
s
.32997 .41458 m
.32717 .42161 L
s
.31276 .39695 m
.31073 .4038 L
s
.22954 .38645 m
.22705 .38161 L
s
.23226 .40138 m
.22765 .39766 L
s
.234 .41107 m
.22841 .40801 L
s
.2298 .39265 m
.22692 .38801 L
s
.29319 .37329 m
.29453 .37925 L
s
.2797 .36016 m
.28369 .36499 L
s
.30146 .38158 m
.30192 .38784 L
s
.23538 .44023 m
.22855 .43828 L
s
.28536 .36537 m
.28854 .37059 L
s
.3735 .43905 m
.37195 .44614 L
s
.21255 .54697 m
.20429 .54759 L
s
.23385 .46864 m
.22636 .46752 L
s
.27255 .35484 m
.27845 .35856 L
s
.23232 .42239 m
.22693 .41928 L
s
.33093 .40783 m
.32997 .41458 L
s
.3124 .39062 m
.31276 .39695 L
s
.22705 .38161 m
.22851 .37554 L
s
.22841 .40801 m
.22558 .40345 L
s
.22765 .39766 m
.22626 .39246 L
s
.22692 .38801 m
.22769 .38212 L
s
.28874 .36866 m
.29319 .37329 L
s
.27244 .3574 m
.2797 .36016 L
s
.22855 .43828 m
.22349 .43511 L
s
.37388 .4322 m
.3735 .43905 L
s
.29818 .37634 m
.30146 .38158 L
s
.20429 .54759 m
.19648 .54775 L
s
.27899 .36192 m
.28536 .36537 L
s
.22636 .46752 m
.22007 .46544 L
s
.2637 .35359 m
.27255 .35484 L
s
.22693 .41928 m
.22396 .41487 L
s
.32999 .40158 m
.33093 .40783 L
s
.30962 .38511 m
.3124 .39062 L
s
.22851 .37554 m
.23376 .36916 L
s
.22626 .39246 m
.22825 .38636 L
s
.22558 .40345 m
.22575 .39781 L
s
.26285 .35705 m
.27244 .3574 L
s
.22769 .38212 m
.23206 .37575 L
s
.28155 .36577 m
.28874 .36866 L
s
.25327 .355 m
.2637 .35359 L
s
.37306 .42567 m
.37388 .4322 L
s
.19648 .54775 m
.18915 .54745 L
s
.29228 .3725 m
.29818 .37634 L
s
.22349 .43511 m
.22045 .43085 L
s
.27012 .36062 m
.27899 .36192 L
s
.22007 .46544 m
.21514 .46245 L
s
.22396 .41487 m
.2236 .40946 L
s
.32714 .39601 m
.32999 .40158 L
s
.24289 .35881 m
.25327 .355 L
s
.23376 .36916 m
.24205 .36341 L
s
.30453 .38073 m
.30962 .38511 L
s
.25223 .35916 m
.26285 .35705 L
s
.22825 .38636 m
.23345 .38001 L
s
.23206 .37575 m
.23951 .36971 L
s
.22575 .39781 m
.22895 .39158 L
s
.25976 .36162 m
.27012 .36062 L
s
.27226 .36491 m
.28155 .36577 L
s
.24205 .36341 m
.25223 .35916 L
s
.37102 .41954 m
.37306 .42567 L
s
.18915 .54745 m
.18235 .54673 L
s
.28415 .37035 m
.29228 .3725 L
s
.22045 .43085 m
.21958 .42573 L
s
.21514 .46245 m
.21169 .45865 L
s
.23951 .36971 m
.24913 .36479 L
s
.24913 .36479 m
.25976 .36162 L
s
.32242 .39131 m
.32714 .39601 L
s
.2236 .40946 m
.22591 .40342 L
s
.29736 .3777 m
.30453 .38073 L
s
.23345 .38001 m
.24134 .37412 L
s
.26178 .36613 m
.27226 .36491 L
s
.22895 .39158 m
.23492 .38532 L
s
.2744 .37004 m
.28415 .37035 L
s
.36776 .41389 m
.37102 .41954 L
s
.18235 .54673 m
.1761 .54558 L
s
.24134 .37412 m
.25111 .36932 L
s
.25111 .36932 m
.26178 .36613 L
s
.21958 .42573 m
.22093 .41999 L
s
.21169 .45865 m
.20982 .45415 L
s
.22591 .40342 m
.23076 .39716 L
s
.31597 .38766 m
.32242 .39131 L
s
.28848 .3762 m
.29736 .3777 L
s
.23492 .38532 m
.24319 .37958 L
s
.26376 .37159 m
.2744 .37004 L
s
.24319 .37958 m
.25307 .37487 L
s
.36328 .40881 m
.36776 .41389 L
s
.25307 .37487 m
.26376 .37159 L
s
.1761 .54558 m
.17043 .54404 L
s
.23076 .39716 m
.23784 .39111 L
s
.27838 .37631 m
.28848 .3762 L
s
.22093 .41999 m
.22444 .4139 L
s
.30798 .38516 m
.31597 .38766 L
s
.20982 .45415 m
.20958 .44907 L
s
.23784 .39111 m
.24672 .38567 L
s
.26763 .37802 m
.27838 .37631 L
s
.35763 .40437 m
.36328 .40881 L
s
.17043 .54404 m
.16536 .54212 L
s
.22444 .4139 m
.22999 .40775 L
s
.25686 .38121 m
.26763 .37802 L
s
.24672 .38567 m
.25686 .38121 L
s
.29872 .38393 m
.30798 .38516 L
s
.20958 .44907 m
.21097 .44356 L
s
.35085 .40064 m
.35763 .40437 L
s
.22999 .40775 m
.23733 .40182 L
s
.28851 .384 m
.29872 .38393 L
s
.16536 .54212 m
.16091 .53984 L
s
.27772 .38537 m
.28851 .384 L
s
.23733 .40182 m
.24617 .39639 L
s
.21097 .44356 m
.21397 .43775 L
s
.34304 .39769 m
.35085 .40064 L
s
.26678 .38797 m
.27772 .38537 L
s
.24617 .39639 m
.25612 .3917 L
s
.25612 .3917 m
.26678 .38797 L
s
.16091 .53984 m
.1571 .53723 L
s
.21397 .43775 m
.21852 .43179 L
s
.33428 .39556 m
.34304 .39769 L
s
.21852 .43179 m
.2245 .42585 L
s
.32471 .3943 m
.33428 .39556 L
s
.1571 .53723 m
.15393 .53431 L
s
.2245 .42585 m
.2318 .42007 L
s
.31447 .39392 m
.32471 .3943 L
s
.15393 .53431 m
.15141 .5311 L
s
.2318 .42007 m
.24024 .41459 L
s
.30374 .39445 m
.31447 .39392 L
s
.2927 .39586 m
.30374 .39445 L
s
.24024 .41459 m
.24965 .40954 L
s
.28156 .39813 m
.2927 .39586 L
s
.24965 .40954 m
.25981 .40505 L
s
.15141 .5311 m
.14954 .52762 L
s
.27052 .40122 m
.28156 .39813 L
s
.25981 .40505 m
.27052 .40122 L
s
.14954 .52762 m
.14832 .52391 L
s
.14832 .52391 m
.14775 .51998 L
s
.14775 .51998 m
.14782 .51586 L
s
.14782 .51586 m
.14852 .51157 L
s
.14852 .51157 m
.14984 .50713 L
s
.14984 .50713 m
.15176 .50256 L
s
.15176 .50256 m
.15427 .49789 L
s
.15427 .49789 m
.15735 .49314 L
s
.15735 .49314 m
.16099 .48832 L
s
.16099 .48832 m
.16515 .48345 L
s
.16515 .48345 m
.16983 .47856 L
s
.16983 .47856 m
.175 .47365 L
s
.175 .47365 m
.18063 .46873 L
s
.18063 .46873 m
.1867 .46384 L
s
.1867 .46384 m
.1932 .45896 L
s
.1932 .45896 m
.2001 .45412 L
s
.2001 .45412 m
.20737 .44933 L
s
.20737 .44933 m
.21499 .44459 L
s
.21499 .44459 m
.22294 .43991 L
s
.22294 .43991 m
.23121 .43529 L
s
.23121 .43529 m
.23976 .43075 L
s
.23976 .43075 m
.24858 .42627 L
s
.24858 .42627 m
.25765 .42187 L
s
.25765 .42187 m
.26695 .41755 L
s
.26695 .41755 m
.27646 .4133 L
s
.27646 .4133 m
.28616 .40913 L
s
.28616 .40913 m
.29604 .40502 L
s
.29604 .40502 m
.30609 .40099 L
s
.30609 .40099 m
.31628 .39702 L
s
.31628 .39702 m
.3266 .39311 L
s
.83208 .60508 m
.82049 .60956 L
s
.84332 .59965 m
.83208 .60508 L
s
.82049 .60956 m
.80866 .61305 L
s
.8541 .59333 m
.84332 .59965 L
s
.3266 .39311 m
.33705 .38925 L
s
.80866 .61305 m
.79671 .61549 L
s
.86432 .58618 m
.8541 .59333 L
s
.79671 .61549 m
.78477 .61686 L
s
.8739 .57827 m
.86432 .58618 L
s
.78477 .61686 m
.77298 .61712 L
s
.88276 .56968 m
.8739 .57827 L
s
.33705 .38925 m
.3476 .38544 L
s
.77298 .61712 m
.76148 .61627 L
s
.89082 .56048 m
.88276 .56968 L
s
.3476 .38544 m
.35825 .38167 L
s
.89804 .55074 m
.89082 .56048 L
s
.76148 .61627 m
.75041 .61431 L
s
.90436 .54054 m
.89804 .55074 L
s
.35825 .38167 m
.36898 .37793 L
s
.75041 .61431 m
.73993 .61124 L
s
.90975 .52996 m
.90436 .54054 L
s
.36898 .37793 m
.37978 .37421 L
s
.73993 .61124 m
.73017 .60709 L
s
.91416 .51908 m
.90975 .52996 L
s
.37978 .37421 m
.39064 .37051 L
s
.73017 .60709 m
.72129 .60192 L
s
.91759 .50797 m
.91416 .51908 L
s
.39064 .37051 m
.40156 .36681 L
s
.72129 .60192 m
.71343 .59577 L
s
.92001 .49671 m
.91759 .50797 L
s
.40156 .36681 m
.41251 .36311 L
s
.92143 .48537 m
.92001 .49671 L
s
.41251 .36311 m
.42351 .3594 L
s
.71343 .59577 m
.70671 .58873 L
s
.92184 .47402 m
.92143 .48537 L
s
.42351 .3594 m
.43455 .35569 L
s
.70671 .58873 m
.70127 .58089 L
s
.43455 .35569 m
.44566 .352 L
s
.92125 .46271 m
.92184 .47402 L
s
.44566 .352 m
.45684 .34834 L
s
.70127 .58089 m
.69721 .57236 L
s
.91968 .45153 m
.92125 .46271 L
s
.45684 .34834 m
.46809 .34473 L
s
.91716 .44052 m
.91968 .45153 L
s
.69721 .57236 m
.69463 .56327 L
s
.46809 .34473 m
.47944 .34117 L
s
.8097 .60768 m
.79739 .61029 L
s
.82168 .60334 m
.8097 .60768 L
s
.83295 .59739 m
.82168 .60334 L
s
.79739 .61029 m
.7851 .61108 L
s
.8432 .58999 m
.83295 .59739 L
s
.9137 .42974 m
.91716 .44052 L
s
.7851 .61108 m
.77323 .61003 L
s
.47944 .34117 m
.49087 .33768 L
s
.85213 .58137 m
.8432 .58999 L
s
.77323 .61003 m
.76215 .60716 L
s
.69463 .56327 m
.69361 .55377 L
s
.90934 .41924 m
.9137 .42974 L
s
.8595 .57174 m
.85213 .58137 L
s
.49087 .33768 m
.50241 .33428 L
s
.76215 .60716 m
.75224 .60256 L
s
.86511 .56136 m
.8595 .57174 L
s
.90412 .40907 m
.90934 .41924 L
s
.50241 .33428 m
.51406 .33098 L
s
.69361 .55377 m
.6942 .544 L
s
.75224 .60256 m
.74385 .59636 L
s
.8688 .55051 m
.86511 .56136 L
s
.51406 .33098 m
.52582 .3278 L
s
.89807 .39926 m
.90412 .40907 L
s
.52582 .3278 m
.5377 .32475 L
s
.89124 .38985 m
.89807 .39926 L
s
.6942 .544 m
.69643 .53416 L
s
.74385 .59636 m
.73729 .58878 L
s
.87048 .53947 m
.8688 .55051 L
s
.5377 .32475 m
.54969 .32186 L
s
.88368 .38088 m
.89124 .38985 L
s
.81281 .60932 m
.80036 .61207 L
s
.82468 .60436 m
.81281 .60932 L
s
.80036 .61207 m
.78796 .61248 L
s
.83541 .59743 m
.82468 .60436 L
s
.87011 .52851 m
.87048 .53947 L
s
.54969 .32186 m
.56181 .31914 L
s
.73729 .58878 m
.73282 .58007 L
s
.69643 .53416 m
.70029 .52441 L
s
.78796 .61248 m
.77625 .61052 L
s
.84446 .58885 m
.83541 .59743 L
s
.87543 .37238 m
.88368 .38088 L
s
.56181 .31914 m
.57404 .31662 L
s
.77625 .61052 m
.76585 .60631 L
s
.8514 .57901 m
.84446 .58885 L
s
.86769 .51791 m
.87011 .52851 L
s
.86654 .36435 m
.87543 .37238 L
s
.57404 .31662 m
.5864 .3143 L
s
.73282 .58007 m
.73063 .57053 L
s
.70029 .52441 m
.70574 .51495 L
s
.76585 .60631 m
.75732 .60003 L
s
.85706 .35683 m
.86654 .36435 L
s
.85591 .56837 m
.8514 .57901 L
s
.5864 .3143 m
.59887 .31222 L
s
.86329 .50792 m
.86769 .51791 L
s
.59887 .31222 m
.61144 .31038 L
s
.84704 .34983 m
.85706 .35683 L
s
.70574 .51495 m
.71273 .50597 L
s
.73063 .57053 m
.73085 .56052 L
s
.85776 .55741 m
.85591 .56837 L
s
.80728 .61399 m
.79471 .61509 L
s
.81961 .61017 m
.80728 .61399 L
s
.75732 .60003 m
.75115 .59204 L
s
.83086 .60388 m
.81961 .61017 L
s
.61144 .31038 m
.62412 .30882 L
s
.83653 .34335 m
.84704 .34983 L
s
.79471 .61509 m
.7828 .61338 L
s
.85703 .49879 m
.86329 .50792 L
s
.84024 .59554 m
.83086 .60388 L
s
.62412 .30882 m
.63689 .30756 L
s
.82558 .3374 m
.83653 .34335 L
s
.7828 .61338 m
.7724 .609 L
s
.71273 .50597 m
.72115 .49767 L
s
.63689 .30756 m
.64974 .3066 L
s
.84713 .58568 m
.84024 .59554 L
s
.85687 .54661 m
.85776 .55741 L
s
.81424 .332 m
.82558 .3374 L
s
.73085 .56052 m
.73352 .55041 L
s
.75115 .59204 m
.74772 .58277 L
s
.84907 .49073 m
.85703 .49879 L
s
.64974 .3066 m
.66266 .30599 L
s
.80255 .32712 m
.81424 .332 L
s
.66266 .30599 m
.67562 .30573 L
s
.7724 .609 m
.76429 .60226 L
s
.79056 .32278 m
.80255 .32712 L
s
.85105 .57495 m
.84713 .58568 L
s
.72115 .49767 m
.73087 .49023 L
s
.67562 .30573 m
.68862 .30586 L
s
.77831 .31896 m
.79056 .32278 L
s
.85328 .53645 m
.85687 .54661 L
s
.68862 .30586 m
.70163 .30638 L
s
.8396 .48392 m
.84907 .49073 L
s
.80914 .61668 m
.79653 .6176 L
s
.82148 .61267 m
.80914 .61668 L
s
.83243 .60591 m
.82148 .61267 L
s
.76585 .31565 m
.77831 .31896 L
s
.70163 .30638 m
.71462 .30732 L
s
.73352 .55041 m
.73857 .54061 L
s
.75322 .31285 m
.76585 .31565 L
s
.71462 .30732 m
.72756 .3087 L
s
.79653 .6176 m
.78477 .61536 L
s
.74772 .58277 m
.74726 .57273 L
s
.74044 .31054 m
.75322 .31285 L
s
.72756 .3087 m
.74044 .31054 L
s
.84105 .59698 m
.83243 .60591 L
s
.73087 .49023 m
.7417 .48384 L
s
.76429 .60226 m
.75911 .59364 L
s
.85174 .56403 m
.85105 .57495 L
s
.82887 .47851 m
.8396 .48392 L
s
.78477 .61536 m
.77496 .61016 L
s
.84713 .52739 m
.85328 .53645 L
s
.84656 .58663 m
.84105 .59698 L
s
.7417 .48384 m
.75346 .47864 L
s
.81713 .4746 m
.82887 .47851 L
s
.73857 .54061 m
.74586 .53151 L
s
.74726 .57273 m
.74986 .5625 L
s
.81939 .61665 m
.80682 .61982 L
s
.83069 .61034 m
.81939 .61665 L
s
.75346 .47864 m
.7659 .47479 L
s
.80682 .61982 m
.79435 .61952 L
s
.84913 .55364 m
.85174 .56403 L
s
.77496 .61016 m
.76804 .60248 L
s
.80468 .47227 m
.81713 .4746 L
s
.75911 .59364 m
.75729 .58381 L
s
.83872 .51981 m
.84713 .52739 L
s
.8395 .60153 m
.83069 .61034 L
s
.7659 .47479 m
.77877 .47239 L
s
.84848 .57572 m
.84656 .58663 L
s
.79435 .61952 m
.78337 .61578 L
s
.79179 .47153 m
.80468 .47227 L
s
.77877 .47239 m
.79179 .47153 L
s
.74586 .53151 m
.75512 .52351 L
s
.84488 .59115 m
.8395 .60153 L
s
.74986 .5625 m
.7554 .55271 L
s
.8434 .54443 m
.84913 .55364 L
s
.82841 .51404 m
.83872 .51981 L
s
.78337 .61578 m
.77513 .60903 L
s
.76804 .60248 m
.7647 .59305 L
s
.75729 .58381 m
.75902 .57351 L
s
.82062 .61898 m
.80803 .62218 L
s
.83175 .61239 m
.82062 .61898 L
s
.80803 .62218 m
.79559 .62161 L
s
.84663 .56518 m
.84848 .57572 L
s
.75512 .52351 m
.76602 .51697 L
s
.84001 .60322 m
.83175 .61239 L
s
.79559 .62161 m
.78494 .61733 L
s
.81667 .5103 m
.82841 .51404 L
s
.84623 .58026 m
.84488 .59115 L
s
.76602 .51697 m
.77814 .51218 L
s
.7554 .55271 m
.76362 .54395 L
s
.8349 .53699 m
.8434 .54443 L
s
.77513 .60903 m
.77059 .60002 L
s
.80401 .50874 m
.81667 .5103 L
s
.7647 .59305 m
.76532 .58276 L
s
.81766 .62263 m
.80491 .62455 L
s
.82936 .61689 m
.81766 .62263 L
s
.84432 .5926 m
.84001 .60322 L
s
.77814 .51218 m
.79098 .50938 L
s
.84115 .55589 m
.84663 .56518 L
s
.75902 .57351 m
.76422 .56357 L
s
.78494 .61733 m
.77751 .60992 L
s
.80491 .62455 m
.793 .62238 L
s
.79098 .50938 m
.80401 .50874 L
s
.83828 .60815 m
.82936 .61689 L
s
.82419 .53177 m
.8349 .53699 L
s
.76362 .54395 m
.77404 .5368 L
s
.84339 .57 m
.84623 .58026 L
s
.793 .62238 m
.78375 .61646 L
s
.77059 .60002 m
.77034 .5898 L
s
.84311 .59764 m
.83828 .60815 L
s
.84413 .58182 m
.84432 .5926 L
s
.8325 .54861 m
.84115 .55589 L
s
.76422 .56357 m
.77253 .5548 L
s
.76532 .58276 m
.76988 .57264 L
s
.77751 .60992 m
.77432 .60037 L
s
.81195 .52909 m
.82419 .53177 L
s
.77404 .5368 m
.78607 .53173 L
s
.79897 .52909 m
.81195 .52909 L
s
.78607 .53173 m
.79897 .52909 L
s
.83665 .56141 m
.84339 .57 L
s
.78375 .61646 m
.77859 .60769 L
s
.84312 .58686 m
.84311 .59764 L
s
.82141 .54394 m
.8325 .54861 L
s
.77253 .5548 m
.78333 .54796 L
s
.83944 .57223 m
.84413 .58182 L
s
.77034 .5898 m
.77446 .57958 L
s
.76988 .57264 m
.77801 .56374 L
s
.77432 .60037 m
.77588 .58998 L
s
.80881 .54225 m
.82141 .54394 L
s
.8267 .55538 m
.83665 .56141 L
s
.78333 .54796 m
.79576 .54364 L
s
.77859 .60769 m
.77837 .59742 L
s
.79576 .54364 m
.80881 .54225 L
s
.83828 .57735 m
.84312 .58686 L
s
.77801 .56374 m
.78891 .55697 L
s
.83082 .56498 m
.83944 .57223 L
s
.77446 .57958 m
.78252 .57061 L
s
.81457 .55252 m
.8267 .55538 L
s
.77588 .58998 m
.78202 .5802 L
s
.78891 .55697 m
.80153 .55308 L
s
.80153 .55308 m
.81457 .55252 L
s
.77837 .59742 m
.78321 .58729 L
s
.81933 .56096 m
.83082 .56498 L
s
.82927 .57045 m
.83828 .57735 L
s
.78252 .57061 m
.79361 .56401 L
s
.78202 .5802 m
.79196 .57244 L
s
.80639 .56064 m
.81933 .56096 L
s
.79361 .56401 m
.80639 .56064 L
s
.81738 .56714 m
.82927 .57045 L
s
.78321 .58729 m
.79238 .57894 L
s
.79196 .57244 m
.80433 .56785 L
s
.80433 .56785 m
.81738 .56714 L
s
.25 Mabswid
.80735 0 m
.94728 .21936 L
s
.94728 .21936 m
1 .66249 L
s
1 .66249 m
.84757 .46041 L
s
.84757 .46041 m
.80735 0 L
s
.04993 .28056 m
0 .71811 L
s
0 .71811 m
.84757 .46041 L
s
.84757 .46041 m
.80735 0 L
s
.80735 0 m
.04993 .28056 L
s
.94728 .21936 m
1 .66249 L
s
.95806 .3099 m
.95202 .31183 L
s
gsave
.97013 .30603 -61 -11.2194 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.9722 .42878 m
.96613 .43062 L
s
gsave
.98433 .4251 -61 -11.1268 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.98723 .55512 m
.98113 .55685 L
s
gsave
.99942 .55164 -61 -11.0288 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.96082 .33311 m
.95719 .33426 L
s
.96361 .3566 m
.95998 .35774 L
s
.96644 .38037 m
.96281 .3815 L
s
.9693 .40443 m
.96566 .40554 L
s
.97513 .45343 m
.97149 .45452 L
s
.9781 .47838 m
.97445 .47946 L
s
.9811 .50364 m
.97745 .50471 L
s
.98415 .52922 m
.98049 .53027 L
s
.95533 .28696 m
.95171 .28813 L
s
.95263 .26429 m
.94901 .26547 L
s
.94996 .24188 m
.94635 .24307 L
s
.94733 .21973 m
.94372 .22093 L
s
.99035 .58134 m
.98668 .58237 L
s
.99351 .6079 m
.98984 .60891 L
s
.9967 .63479 m
.99304 .6358 L
s
.99995 .66204 m
.99627 .66303 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{255.063, 223.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005n0001Cb000`400?l00000o`00003oo`3ooomo
0?ooo`00o`3ooomo0?ooo`00o`3ooomo0?ooo`00o`3ooomo0?ooo`00o`3ooomo0?ooo`00o`3oool/
0?ooo`050?oo_`1d000000000018W03Oool0CP3oool00?l0oooo:`3oool01P3ooml0W4P004RLg`3o
ool0gia8001d_dh0oooo003o0?ooob/0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo04d0
oooo003o0?ooob/0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo04d0oooo003o0?ooob/0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo04d0oooo003o0?ooob/0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo04d0oooo003o0?ooob40oooo0P0000080?ooo`070?oo_`1d07@0
_ooo0?ooo`3ogi`0B01d0;ooo`1=0?ooo`00o`3ooolN0?ooo`<0000000<0oooo0000000000001`3o
ool01P3ooml0W4P007Boo`3oool0gia8001d_dh0oooo003o0?oooa`0oooo0P0000040?ooo`800000
203oool01@3ookl0M00000000000B9`0gooo04h0oooo003o0?oooaT0oooo0`0000050?ooo`800000
00<0oooo0000003oool0F@3oool00?l0oooo5P3oool3000000T0oooo00@000000?ooo`3oool00000
F@3oool00?l0oooo503oool2000000`0oooo00<000000?ooo`3oool00P00001H0?ooo`00o`3ooolA
0?ooo`<000003`3oool4000005P0oooo003o0?ooo`h0oooo0`00000B0?ooo`040000003oool0oooo
000005P0oooo003o0?ooo`/0oooo0`00000E0?ooo`050000003oool0oooo0?ooo`000000E`3oool0
0?l0oooo2@3oool2000001P0oooo00<000000?ooo`3oool00`00001F0?ooo`00o`3oool60?ooo`<0
00006P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05@0oooo003o0?ooo`<0oooo
0`00000M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D`3oool00?l0oooo0@3o
ool200000200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`0:0?oo_`1d
000000000018W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P000000
0`0004P0W=oo0?ooo`0a0?ooo`00o@3oool300000280oooo00<000000?ooo`3oool00`3oool20000
00/0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0
okmd0018W03Oool0oooo0?oog`2LB7@0_ooo0340oooo003j0?ooo`<000009@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo
00@0oooo00<0omnL04P0001d_ol0203oool00`2oM000M;oo0?ooo`0`0?ooo`00m`3oool3000002P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool0<03oool0
0?D0oooo0P00000[0?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`070?noM000B9`0gooo
0?ooo`3ookl0M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO
09a8B02Lgol0<@3oool00?80oooo0`00000]0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool01@3ookl0M01809cO
o`3ookl0M00000<0000000<0M;oo0?ooo`3oool0<03oool00>l0oooo0`00000a0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md001d_ol0oooO09a8B02Lgol0=@3oool00>d0
oooo0P00000d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool01P3ooml0
W4P007Boo`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2o
M000M;oo=@3oool00>X0oooo0`00000f0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool0
00000?ooo`060?ooo`050?oo_`1d000000000018W03Oool01@3oool01@3ogi`0B000000000000000
M;oo0080oooo00H0gia800000000000000000000M02ooola0?ooo`00i`3oool3000003T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1=0?ooo`00i@3oool2000003`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1<0?ooo`00hP3oool3000003h0oooo00<000000?oo
o`3oool0203oool3000004d0oooo003O0?ooo`<00000@@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04/0oooo003L0?ooo`<00000A03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04X0oooo003J0?ooo`800000A`3oool00`000000oooo0?ooo`0:0?ooo`<00000B`3o
ool00=L0oooo0`0000190?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B@3oool0
0=@0oooo0`00001<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool02`3o
okl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3o
ool0;P3oool00=80oooo0P00001?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd0018W03Oool0oooo0?oog`2L
B7@0_ooo02h0oooo003?0?ooo`<00000DP3oool00`000000oooo0?ooo`0<0?ooo`8000002P3oool0
1`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool00`2oM000M;oo0?ooo`0]0?ooo`00c03o
ool3000005D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo02d0oooo00390?ooo`<00000
F03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00L0okmd0018W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo02h0oooo0037
0?ooo`800000F`3oool00`000000oooo0?ooo`0>0?ooo`800000203oool01`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol00`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo02d0oooo
00340?ooo`<00000G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol0<P3oool00<40oooo
0`00001P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool01P3ooml0W4P0
07Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3oool0<@3oool00;l0oooo0P00001S0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool01@3ookl0M00000000000B9`0gooo
00D0oooo00H0gia800000000000000000000M02oool^0?ooo`00_03oool3000006D0oooo00<00000
0?ooo`3oool03`3oool2000000030?ooo`000000oooo04<0oooo002i0?ooo`<00000J03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0480oooo002f0?ooo`<00000J`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0440oooo002d0?ooo`800000KP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool000000480oooo002a0?ooo`<00000L03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0400oooo002^0?ooo`<00000M03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo03l0oooo002/0?ooo`800000M`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool000000400oooo002Y0?ooo`<00000N@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03h0oooo002V0?ooo`<00000O03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00X0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0?oo
_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`0M0?ooo`00X`3oool3000007l0oooo
00<000000?ooo`3oool05@3oool2000000/0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l50?oo
o`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo002Q
0?ooo`800000PP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00L0oono
07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo
0?ooo`0K0?ooo`00WP3oool3000008@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?noM000B9`0gooo00L0
oooo00<0_g@007Boo`3oool06`3oool009/0oooo0`0000270?ooo`030000003oool0oooo01L0oooo
0P0000090?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo
0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo01`0oooo002I0?ooo`800000RP3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00H0oooo00H0gia8001d_`3oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo
01/0oooo002F0?ooo`<00000S03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00H0oooo00L0oono07@0B02Lgol0oooo0?oo
g`2LB4P0W=oo0200oooo002C0?ooo`<00000S`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0gooo0?oo
o`2oM000M;oo803oool00940oooo0P00002C0?ooo`030000003oool0oooo01L0oooo0P0000000`3o
ool000000?ooo`060?ooo`050?oo_`1d000000000018W03Oool0103oool00`3OW4P0000000000003
0000000307Boo`3oool0gia800<0000000<0001d0;ooo`3oool06`3oool008h0oooo0`00002E0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=`3oool008/0oooo0`00002H0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0=`3oool008P0oooo0`00002K0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`000000>03oool008H0oooo0P00002N0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0=@3oool008<0oooo0`00002P0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0=@3oool00800oooo0`00002S0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`000000=P3oool007h0oooo0P00002V0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool03@3oool00`3ogi`0B01d0;ooo`0T0?ooo`00N`3oool300000:P0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo02@0oooo
001h0?ooo`<00000Z`3oool00`000000oooo0?ooo`0N0?ooo`<000003@3oool00`3ogi`0B01d0;oo
o`0T0?ooo`00M@3oool300000:h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;
0?ooo`030?oOW01807@0_ooo02@0oooo001c0?ooo`800000/@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00X0oooo00<0omnL04P0M02oool0903oool00700oooo0`00002d0?ooo`03
0000003oool0oooo01l0oooo0`00000;0?ooo`030?oOW01807@0_ooo02@0oooo001]0?ooo`<00000
]`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00D0_g@00000B02L_i`0
B01d0;ooo`0T0?ooo`00J`3oool200000;X0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`070?ooo`040?noM0000000001d0;ooob@0oooo001X0?ooo`<00000_03oool00`000000oooo
0?ooo`0P0?ooo`@000002@3oool00`3ogi`0B01d0;ooo`0T0?ooo`00I@3oool300000;l0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0^0?ooo`00HP3oool300000<80oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0]0?ooo`00H03oool200000<D0oooo00<000000?oo
o`3oool08`3oool3000002h0oooo001M0?ooo`<00000a`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02`0oooo001J0?ooo`<00000bP3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02/0oooo001H0?ooo`800000c@3oool00`000000oooo0?ooo`0U0?ooo`800000;@3o
ool005D0oooo0`00003?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:P3oool0
0580oooo0`00003B0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool004l0
oooo0`00003F0?ooo`030000003oool0oooo02H0oooo0P00000[0?ooo`00C@3oool200000=T0oooo
00<000000?ooo`3oool09`3oool2000002X0oooo001:0?ooo`<00000f`3oool00`000000oooo0?oo
o`0T0?ooo`D00000:P3oool004L0oooo0`00003N0?ooo`030000003oool0oooo0240oooo0`000004
0?ooo`030000003oool0oooo02P0oooo00150?ooo`800000h@3oool00`000000oooo0?ooo`0N0?oo
o`<000001`3oool00`000000oooo0?ooo`0X0?ooo`00@P3oool300000><0oooo00<000000?ooo`3o
ool06`3oool3000000X0oooo00<000000?ooo`3oool0:03oool003l0oooo0`00003V0?ooo`030000
003oool0oooo01P0oooo0`00000>0?ooo`030000003oool0oooo02L0oooo000m0?ooo`800000j@3o
ool00`000000oooo0?ooo`0E0?ooo`<000004@3oool00`000000oooo0?ooo`0W0?ooo`00>P3oool3
00000>/0oooo00<000000?ooo`3oool04P3oool3000001@0oooo00<000000?ooo`3oool09`3oool0
03L0oooo0`00003^0?ooo`030000003oool0oooo00l0oooo0`00000G0?ooo`030000003oool0oooo
02L0oooo000d0?ooo`<00000l@3oool00`000000oooo0?ooo`0<0?ooo`<000006@3oool2000002T0
oooo000b0?ooo`800000m@3oool00`000000oooo0?ooo`080?ooo`<000007@3oool00`000000oooo
0?ooo`0W0?ooo`00;`3oool300000?L0oooo00<000000?ooo`3oool01@3oool300000200oooo00<0
00000?ooo`3oool09`3oool002`0oooo0`00003j0?ooo`030000003oool0oooo0080oooo0`00000S
0?ooo`030000003oool0oooo02L0oooo000Z0?ooo`800000o@3oool00`000000oooo000000020000
02L0oooo00<000000?ooo`3oool09P3oool002L0oooo0`00003n0?ooo`<00000:P3oool00`000000
oooo0?ooo`0V0?ooo`00903oool300000?h0oooo0`0000000`3oool000000?ooo`0Z0?ooo`030000
003oool0oooo02H0oooo000Q0?ooo`<00000oP3oool3000000@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0V0?ooo`007`3oool200000?h0oooo0`0000070?ooo`030000003oool0
oooo02P0oooo0P00000X0?ooo`00703oool300000?d0oooo0`00000:0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool09P3oool001T0oooo0`00003m0?ooo`<000003@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0oooo000G0?ooo`800000o@3oool300000100oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0V0?ooo`00503oool300000?`0oooo0`00
000C0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool09@3oool00180oooo0P00003l
0?ooo`<000005`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02D0oooo000B0?oo
o`800000n@3oool3000001X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0U0?oo
o`004P3oool00`000000oooo0000003e0?ooo`<000007@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02D0oooo000B0?ooo`040000003oool0oooo00000?40oooo0`00000P0?ooo`03
0000003oool0oooo02P0oooo0P00000W0?ooo`004P3oool01@000000oooo0?ooo`3oool000000>d0
oooo0`00000S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03P3oool02`3ookl0
M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool0
1`3oool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3W0?ooo`<000009P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00H0ooo409a80018W=l0oooo
0=nLB000M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`070?ooo`004@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0><0oooo0`00000Y0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool03@3oool01`3oohl0M01d0;ooo`3oool0omnL04P0M02oool0203o
ool00`2oM000M;oo0?ooo`060?ooo`004@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0=l0oooo0`00000/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01@3oool0
0`3oa5l0500000000003000000090000=@2?ool0olAO04Q8W03Oool0oooo0?oo_`1d04P0W=oo00P0
oooo00<0_g@007Boo`3oool01P3oool00140oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`3K0?ooo`<00000;`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00`0oooo
00L0ohle0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2L
B4P0W=oo00L0oooo000A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0b@3ooolG
000002`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`070?o4G`18B9`0
gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0
1P3oool00140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2o0?ooo`T000002`3o
ool3000000T0oooo2@00000S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0303o
ool01`3oohl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q809cOo`0;0?ooo`00
4@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;D0oooo2@00000A0?ooo`<00000
5@3oool5000001h0oooo00<000000?ooo`3oool0:03oool3000000h0oooo00H0ooo409a8001d_ol0
oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00X0oooo000A0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0/03oool4000001L0oooo0`00000M0?ooo`@000006`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00D0oono07@00000000004RL0=ooo`050?oo
o`060=nLB000000000000000000007@0_ooo1`3oool00140oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2Z0?ooo`D00000603oool3000002@0oooo1@00000F0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0903oool00100oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`2U0?ooo`@000006P3oool3000002`0oooo1000000B0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0903oool00100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`2P0?ooo`@000006`3oool3000003<0oooo0`00000?0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0903oool00100oooo00<000000?ooo`3oool03`3oool2000009/0oooo
1@00000L0?ooo`<00000>@3oool2000000d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0S0?ooo`00403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo09@0oooo1000
000N0?ooo`<00000?P3oool2000000/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0S0?ooo`00403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo08l0oooo1000000O
0?ooo`<00000@`3oool2000000T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0S
0?ooo`00403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo08/0oooo0`00000P0?oo
o`<00000B03oool4000000D0oooo00<000000?ooo`3oool0:@3oool2000002D0oooo000@0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0R03oool200000200oooo0`00001?0?ooo`<0
00000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02<0oooo000@0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0Q03oool3000001h0oooo1000001E0?ooo`030000
003oool0000002`0oooo00<000000?ooo`3oool08`3oool000l0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`1o0?ooo`@000007P3oool3000005X0oooo0P00000/0?ooo`030000003o
ool0oooo02<0oooo000?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0NP3oool4
000001l0oooo0`00001N0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool08`3oool0
00l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1f0?ooo`<00000803oool30000
0680oooo0P00000Z0?ooo`030000003oool0oooo02<0oooo000?0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0L`3oool200000200oooo0`00001U0?ooo`040000003oool000000000
02T0oooo00<000000?ooo`3oool08P3oool000l0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0^0?ooo`<00000?P3oool3000001l0oooo0`00001X0?ooo`040000003oool0oooo0?oo
o`8000009`3oool00`000000oooo0?ooo`0R0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo02T0oooo1P0000000`3oool000000000000h0?ooo`@000007`3oool3000006/0
oooo00<000000?ooo`3oool00`3oool2000002D0oooo00<000000?ooo`3oool08P3oool000l0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0U0?ooo`H000000`3oool5000003<0oooo
0`00000P0?ooo`<00000KP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo
0P00000T0?ooo`003`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo0P00
00020?ooo`T00000<@3oool200000200oooo0`00001a0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`003`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`0000000P0000050?ooo`<0000000<0oooo
000000000000;03oool3000001l0oooo0`00001d0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`003P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo0200oooo100000040?ooo`@000000`3oool3000002P0oooo1000000O0?oo
o`<00000M`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool08P3oool000h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0000000<0oooo0`0000040?ooo`L00000903oool300000200oooo0`00001j0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0R0?ooo`00
3P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01`0oooo0`0000020?ooo`800000
103oool300000080oooo00<000000?ooo`3oool01000000P0?ooo`800000803oool3000007d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0240oooo
000>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06P3oool2000000<0oooo00@0
00000?ooo`3oool0oooo0`0000050?ooo`T000006`3oool3000001l0oooo0`0000200?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Q0?ooo`003P3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01P0oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo100000020?ooo`040000003oool000000?ooo`<000005`3oool4000001l0oooo
0`0000240?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0Q0?ooo`003P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01L0oooo0P00
0000103oool000000?ooo`3oool2000000<0oooo0`000000103oool000000000003oool200000003
0?ooo`000000oooo0080oooo00@000000?ooo`00000000004P3oool300000200oooo0`0000270?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool2000002<0oooo000>0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool3000000030?ooo`000000000000<0
oooo0P0000030?ooo`040000003oool0oooo000000<0oooo1`0000000`3oool000000?ooo`0>0?oo
o`800000803oool3000008X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0240oooo000>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool05@3oool2000000030?ooo`000000oooo0080oooo0P0000030?ooo`80000000@0oooo00000000
0000oooo0`0000030?ooo`030000003oool0oooo00H000002P3oool2000001l0oooo0`00002=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0Q0?oo
o`003P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`00
00002@0000020?ooo`@0000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`0000000000103oool4000001h0oooo0`00002@0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`003@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo0`0000000`3oool000000?ooo`050?oo
o`<00000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool4000001l0oooo0`00002C0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`003@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@0000040?ooo`8000000`3oool0
0`000000oooo0000000A000001X0oooo0`00002F0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`003@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0140oooo0`0000040?ooo`8000001@3oool2000000<0oooo100000020?oo
o`030000003oool0oooo00<0oooo0`0000020?ooo`030000003oool0oooo0080oooo0`00000D0?oo
o`<00000V@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0803oool000d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`@0
000000<0oooo000000000000103oool300000080oooo0`0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`8000003`3oool30000
09`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0200oooo000=0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03`3oool010000000
oooo0?ooo`3oool7000000<0oooo0P0000020?ooo`800000103oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01P3oool2000000X0oooo0`00002O0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?oo
o`003@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool0
0000000000070?ooo`<0000000@0oooo00000000000000001@3oool4000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0`00002R0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool200000280oooo000=0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0303oool00`000000oooo000000060?ooo`<0
000000@0oooo00000000000000001`3oool2000000D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<00000Y@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool01@3oohl0=@0000000000B9`0
gooo01D0oooo000=0?ooo`030000003oool0oooo0380oooo0P00000<0?ooo`80000000<0oooo0000
00000000200000080?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00T0oooo0`00002Y0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`060?ooa01O500055o40?ooo`3OW4P007Bo5@3oool000`0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool3000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`<000000P3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`070?ooS`0e03D0Sooo0?ooo`3ogi`0B01d
0;ooo`0D0?ooo`00303oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo0P00
00030?ooo`8000002P3oool4000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`<000001@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`070?o4G`0D55l0a?oo0?ooo`3ookl0
M01809cOo`0D0?ooo`00303oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`000000oooo0000000:0?ooo`@00000203oool2000000T0oooo00@000000?ooo`3o
ool0oooo0`0000090?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00L0ohle000DG`34ool0oooo0?oo_`1d
04P0W=oo01@0oooo000<0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0000000=000000X0oooo00<000000?ooo`3oool02@3oool4000000`0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool01`3oa5l051AO0<Coo`3oool0oono07@0B02Lgol0503oool000`0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`800000203oool2000000`0oooo0P00
000:0?ooo`<00000403oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`070?ooS`0e03D0Sooo0?ooo`3ogi`0
B01d0;ooo`0D0?ooo`00303oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool2000000`0oooo0P0000090?ooo`<0000000<0oooo0000003oool0
403oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`060?ooa01O5000=Hoo0?ooo`3OW4P007Bo5@3oool000`0
oooo00<000000?ooo`3oool0>`3oool010000000oooo0?ooo`3oool2000000D0oooo0P00000<0?oo
o`800000203oool3000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2U0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0403oool3000000L0oooo00D0oon?03D0
0000000004RL0=ooo`0E0?ooo`00303oool00`000000oooo0?ooo`0l0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00P00000<0?ooo`8000001`3oool3000000D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`00303oool00`000000oooo0?ooo`0m0?ooo`80
00000`3oool2000000X0oooo100000060?ooo`<000001`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01l0oooo000;0?ooo`030000003oool0oooo03h0oooo0P0000020?ooo`030000
003oool0000000X000001`3oool3000000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0O0?ooo`002`3oool00`000000oooo0?ooo`0n0?ooo`040000003oool0000000000140oooo
0`00000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool000/0oooo00<0
00000?ooo`3oool0?@3oool3000000030?ooo`000000oooo00d0oooo0`00000<0?ooo`8000005P3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0N0?ooo`002`3oool00`000000oooo0?ooo`0l0?ooo`800000103oool0
0`000000oooo0?ooo`080?ooo`<000003P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01h0oooo000;0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`040?ooo`<000003`3oool2000001P0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07P3oool000/0
oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
00<00000403oool2000001X0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0100oooo0P00000P0?ooo`002`3oool00`000000oooo0?ooo`0h0?ooo`80
00000`3oool00`000000oooo0?ooo`050?ooo`8000004@3oool2000001`0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool07P3oool000/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool2000001d0oooo00<000000?ooo`3oool0
Z03oool2000001X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0N0?ooo`002`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`@000007`3oool00`000000oooo0?ooo`2U0?ooo`<000000P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07P3o
ool000X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool0
0`000000oooo0?ooo`070?ooo`<000008P3oool00`000000oooo0?ooo`2R0?ooo`@000001P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool0
00X0oooo00<000000?ooo`3oool0=03oool2000000d0oooo3@00000T0?ooo`030000003oool0oooo
0:00oooo0`00000:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0M0?ooo`002P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2G0?ooo`@000000`3oool3000000h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0
oooo000:0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0980oooo1@0000040?ooo`@000004@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool000X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0S`3oool4000000D0oooo100000040?ooo`D000003@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool000X0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0S03oool4000000H0oooo0`00000=0?ooo`<000002P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0100oooo0P00000O0?ooo`002P3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2;0?oo
o`8000001`3oool3000001<0oooo0P0000090?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2:0?ooo`80
00001P3oool3000001P0oooo0P0000080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0M0?ooo`002P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`290?ooo`800000
103oool4000001d0oooo0P0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0M0?ooo`002@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`290?ooo`040000003o
ool0oooo0?ooo`<000008`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`002@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`290?ooo`030000003oool00000008000009`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`002@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`280?ooo`@00000:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`002@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`260?ooo`@00000;`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`002@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`240?ooo`<0000000<0oooo0000003oool0<@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`00
2@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`220?ooo`<000000`3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`800000
7P3oool000T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01h0oooo0P0000210?ooo`@000001@3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01`0oooo00090?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0L0?ooo`800000P03oool3000000P0oooo00<000000?ooo`3oool06@3oool<
000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0703oool000P0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0oooo0P00001o0?ooo`<000002`3oool00`00
0000oooo0?ooo`0E0?ooo`@00000303oool2000000h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06`3oool000P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0O03oool3000000d0oooo00<000000?ooo`3oool0503oool200000180
oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo00080?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`800000N`3oool4000000l0oooo
00<000000?ooo`3oool04`3oool2000001H0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo
00080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0E0?ooo`800000NP3oool3000001<0oooo00<000000?ooo`3oool04@3oool2000001X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`00203oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool3000007T0oooo0`00000E
0?ooo`030000003oool0oooo0100oooo0P00000M0?ooo`800000203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0K
0?ooo`00203oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool04@3oool2000007T0oooo0`00000G0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo00080?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`80
0000M`3oool4000001X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`T0
00002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo0000000H0?ooo`8000007@3oool000P0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo0`00001f0?ooo`<000007@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo0`0000090?ooo`<00000203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000006P3oool00`000000
oooo0?ooo`0K0?ooo`00203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool02P3oool2000007H0oooo0`00000P0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02P3oool2000000l0oooo0P0000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0000000K0?ooo`030000003oool0oooo01X0oooo
00070?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`080?ooo`800000M@3oool3000002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`090?ooo`8000004`3oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool02`3ookl0M0000000
0000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool0103oool0
00L0oooo00<000000?ooo`3oool0;`3oool2000001H0oooo00<000000?ooo`3oool0103oool40000
07<0oooo1000000V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool20000
01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo0P00000K0?ooo`030000003oool0oooo00D0oooo00H0oooO09a80018W=l0oooo0=nLB000
M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`040?ooo`001`3oool00`000000oooo
0?ooo`0a0?ooo`<000004`3oool7000007@0oooo0`00000Z0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01P3oool2000000T0oooo2`0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000001X0
oooo00<000000?ooo`3oool01@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool0
0`2oM000M;oo0?ooo`030?ooo`001`3oool00`000000oooo0?ooo`0d0?ooo`D00000203oool70000
07L0oooo0`00000]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`8000002`3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003o
ool0oooo00D0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3o
ool00`3oool000L0oooo00<000000?ooo`3oool0>@3oool8000000H0oooo00<000000?ooo`3oool0
LP3oool3000002l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo0P00000?0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool0
1`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0103oool000L0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`1^0?ooo`@00000<P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool2000000X0oooo100000050?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`03
0?ooo`001`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo06/0oooo0`00000f0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo1@0000040?ooo`<000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`030?ooo`030?oog`2LB4P0W=oo00P0oooo00070?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0J03oool3000003T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000000`0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo0`0000070?oo
o`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`070?ooo`001`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo06D0oooo0`00000m0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`H00000103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`050?oo_`1d000000000018W03Oool01@3oool01P3O
W4P00000000000000000001d0;ooo`@0oooo00060?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0H@3oool400000400oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`8000001P3o
ool2000000<0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1N0?ooo`<00000A03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo0P00000:0?ooo`8000000P3oool01@000000oooo
0?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?ooo`001P3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo05/0oooo0`0000170?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
0000103oool2000000<0oooo200000030?ooo`80000000D0oooo0000003oool000000?ooo`020000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool06@3oool000H0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`1H0?ooo`<00000B`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?oo
o`800000203oool300000080oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01T0oooo00060?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0E@3oool40000
04h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000003@3o
ool3000000030?ooo`000000oooo0080000000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool000H0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`1B0?ooo`<00000DP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo008000004@3oool2000000030?ooo`0000000000008000001`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06@3o
ool000H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1?0?ooo`<00000EP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000003`3oool2000000030?oo
o`0000000000008000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool06@3oool000H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`1<0?ooo`<00000F@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool03`3oool5000000D0oooo0P00000G0?ooo`030000003oool0oooo00h0oooo0`00000J0?oo
o`001P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04P0oooo1000001M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool000000080oooo00@000000?ooo`00000000004P3oool4000000@0oooo0P00000J
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0603oool000D0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`150?ooo`<00000HP3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000000P3oool02P000000oooo0?ooo`000000oooo0000003oool0
00000?ooo`00000E0?ooo`800000103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0603oool000D0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`120?ooo`<00000IP3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000D0?ooo`800000
103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
603oool000D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0n0?ooo`@00000J@3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo
0000003oool000000?ooo`800000503oool3000000<0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo00050?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0>`3oool3000006h0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool000000080oooo0P0000001@3oool000000000003oool000000180oooo0P000000
103oool000000000003oool200000280oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0H0?ooo`001@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03P0oooo0`00001b
0?ooo`8000002@3oool200000080oooo00@000000?ooo`000000oooo0`0000000`3oool000000?oo
o`0@0?ooo`80000000<0oooo0000000000000P00000U0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0603oool000D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0e
0?ooo`<00000M`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0000003oool01000
00000`3oool000000?ooo`0>0?ooo`L000009`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01P0oooo00050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0<@3oool4
000007/0oooo0P0000090?ooo`80000000<0oooo0000003oool00`0000000`3oool000000?ooo`0<
0?ooo`<0000000H0oooo00000000000000000?ooo`00000X0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0603oool000D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0^0?ooo`<00000P@3oool2000000T0oooo200000080?ooo`/0000000<0oooo0000003oool0:@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00040?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0:`3oool3000008H0oooo0`0000090?ooo`d0000000<0oooo
0000000000001`0000000`3oool000000?ooo`0[0?ooo`030000003oool0oooo00L0oooo0`00000I
0?ooo`00103oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02P0oooo0`00002<0?oo
o`8000002P3oool>000000030?ooo`00000000000080000000<0oooo0000003oool0;03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00040?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0903oool400000940oooo1`0000050?ooo`l0000000<0oooo00000000
0000;`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01L0oooo00040?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool08@3oool3000009`0oooo1@0000000`3oool00000
0000000>00000340oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`00103o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01l0oooo0`00002W0?ooo``00000=03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00040?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0703oool300000:d0oooo1@00000h0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05`3oool000@0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0H0?ooo`@00000kP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01L0oooo00040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05@3oool300000?<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`00103oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo0180oooo0`00003g0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05P3oool000<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`<00000nP3oool00`000000oooo0?ooo`020?ooo`<00000603oool000<0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0;0?ooo`@00000oP3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01H0oooo00030?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0203oool300000?l0oooo103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool300000?l0
oooo203oool01@000000oooo0?ooo`3oool0000001P0oooo00030?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00P3oool300000?l0oooo2`3oool01@000000oooo0?ooo`3oool00000
01P0oooo00030?ooo`030000003oool0oooo04T0oooo1@00003o0?ooo`l0oooo00@000000?ooo`3o
ool00000603oool000<0oooo00<000000?ooo`3oool0A`3oool300000?l0oooo503oool010000000
oooo0?ooo`00000G0?ooo`000`3oool00`000000oooo0?ooo`140?ooo`<000000P3oool00`000000
oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`0000005`3oool000<0oooo00<000000?ooo`3oool0
@@3oool3000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0000001L0oooo
00020?ooo`030000003oool0oooo03h0oooo100000080?ooo`030000003oool0oooo0?l0oooo503o
ool2000001L0oooo00020?ooo`030000003oool0oooo03/0oooo0`00000<0?ooo`030000003oool0
oooo0?l0oooo3`3oool00`000000oooo0?ooo`020?ooo`8000005`3oool00080oooo00<000000?oo
o`3oool0>03oool3000000h0oooo00<000000?ooo`3oool0o`3oool@0?ooo`D000006@3oool00080
oooo00<000000?ooo`3oool0=@3oool300000140oooo00<000000?ooo`3oool0o`3oool=0?ooo`@0
00007@3oool00080oooo00<000000?ooo`3oool0<@3oool4000001@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`@000008@3oool00080oooo00<000000?ooo`3oool0;P3oool3000001P0oooo00<0
00000?ooo`3oool0o`3oool60?ooo`<000009@3oool00080oooo00<000000?ooo`3oool0:`3oool3
000001/0oooo00<000000?ooo`3oool0o`3oool20?ooo`@00000:03oool00080oooo00<000000?oo
o`3oool09`3oool4000001h0oooo00<000000?ooo`3oool0n@3oool010000000oooo0?ooo`3oool4
000002`0oooo00000`3oool000000?ooo`0V0?ooo`<000008P3oool00`000000oooo0?ooo`3i0?oo
o`@00000<03oool000030?ooo`000000oooo02<0oooo0`00000U0?ooo`030000003oool0oooo0?H0
oooo0`00000d0?ooo`0000<0oooo0000003oool0803oool3000002P0oooo00<000000?ooo`3oool0
lP3oool4000003L0oooo00000`3oool000000?ooo`0L0?ooo`@00000:`3oool00`000000oooo0?oo
o`3^0?ooo`@00000>`3oool000030?ooo`000000oooo01T0oooo0`00000_0?ooo`030000003oool0
oooo0>@0oooo00<000000?ooo`3oool0103oool3000003l0oooo00000`3oool000000?ooo`0F0?oo
o`<00000<P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo00@00000@P3oool00003
0?ooo`000000oooo01<0oooo0`00000e0?ooo`030000003oool0oooo0><0oooo100000160?ooo`00
00<0oooo0000003oool03`3oool4000003P0oooo00<000000?ooo`3oool0g`3oool4000004X0oooo
00000`3oool000000?ooo`0<0?ooo`<00000?03oool00`000000oooo0?ooo`3L0?ooo`<00000CP3o
ool000030000003oool0oooo00T0oooo0`00000o0?ooo`030000003oool0oooo0=P0oooo1000001A
0?ooo`0000<000000?ooo`3oool01P3oool300000480oooo00<000000?ooo`3oool0c`3oool00`00
0000oooo0?ooo`020?ooo`@00000E@3oool000030000003oool0oooo0080oooo100000140?ooo`03
0000003oool0oooo0=00oooo1@00001I0?ooo`0000<000000?ooo`0000000P0000180?ooo`030000
003oool0oooo0<h0oooo0`00001M0?ooo`000P00001;0?ooo`030000003oool0oooo0<X0oooo1000
001P0?ooo`0000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`360?ooo`@00000I03oool0
0080oooo0P0000190?ooo`030000003oool0oooo0<80oooo1000001X0?ooo`00103oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0;/0oooo00@000000?ooo`3oool0oooo0`00000T0?oo
o`030?oOW01807@0_ooo04D0oooo00050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0^`3oool4000002L0oooo00<0omnL04P0M02oool0A@3oool000H0oooo0P0000150?ooo`030000
003oool0oooo0;L0oooo1000000[0?ooo`030?oOW01807@0_ooo04D0oooo00080?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0/`3oool4000002l0oooo00<0omnL04P0M02oool0A@3o
ool000T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2`0?ooo`<00000<`3oool0
0`3ogi`0B01d0;ooo`150?ooo`002P3oool200000440oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`020?ooo`@00000=P3oool00`3ogi`0B01d0;ooo`150?ooo`00303oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0:L0oooo1@00000h0?ooo`050;md000004P0W;nL04P0
M02oool0A@3oool000d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2U0?ooo`<0
0000?@3oool0103o_g@000000000M02ooom50?ooo`003P3oool2000003d0oooo00<000000?ooo`3o
ool0X@3oool400000440oooo00<0omnL04P0M02oool0A@3oool00100oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`2M0?ooo`@00000S@3oool00140oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2I0?ooo`@00000T@3oool00180oooo0P00000i0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool00`00002E0?ooo`00503oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo09<0oooo1000002H0?ooo`005@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo08l0oooo1000002L0?ooo`005P3oool2000003@0oooo00<000000?ooo`3oool0
R`3oool400000:00oooo000H0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`040?ooo`<00000Y03oool001T0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo00@00000Y`3oool001X0oooo0P00000`0?oo
o`030000003oool0oooo0800oooo1000002[0?ooo`00703oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo07`0oooo1000002_0?ooo`007@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo07T0oooo0`00002c0?ooo`007P3oool2000002`0oooo00<000000?ooo`3oool0M@3o
ool400000;H0oooo000P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0K@3oool0
10000000oooo0?ooo`3oool400000;X0oooo000Q0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0K@3oool400000;h0oooo000R0?ooo`800000:03oool00`000000oooo0?ooo`1Z0?oo
o`@00000`@3oool002@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1V0?ooo`@0
0000a@3oool002D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1R0?ooo`@00000
b@3oool002H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo0080oooo0`00003=0?ooo`009`3oool2000002<0oooo00<000000?ooo`3oool0FP3oool5
00000200oooo00D0oono07@00000000004RL0=ooo`2[0?ooo`00:@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05P0oooo1000000S0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo
Z`3oool002X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1D0?ooo`@000009`3o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0ZP3oool002/0oooo0P00000N0?ooo`030000
003oool0oooo0540oooo0`00000[0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`2Z0?oo
o`00;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04T0oooo00@000000?ooo`3o
ool0oooo1000000^0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`2Z0?ooo`00;P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04T0oooo1000000b0?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`2Z0?ooo`00;`3oool2000001X0oooo00<000000?ooo`3oool0A@3o
ool5000003D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0:X0oooo000a0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool3000003X0oooo00H0oooO09a8001d_ol0
oooo0=nLB000M;n[0?ooo`00<P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03h0
oooo1000000n0?ooo`050?oo_`1d000000000018W03Oool0Z`3oool003<0oooo0P00000F0?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool0oooo1000003b0?ooo`00=@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo1000003f0?ooo`00=P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03<0oooo1000003i0?ooo`00=`3oool200000180oooo00<0
00000?ooo`3oool0;`3oool400000?d0oooo000i0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`@00000o`3oool20?ooo`00>P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01000003o0?oo
o`H0oooo000k0?ooo`8000003P3oool00`000000oooo0?ooo`0T0?ooo`<00000o`3oool:0?ooo`00
?@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo1@00003o0?ooo``0oooo
000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool400000?l0oooo4@3o
ool003l0oooo0P0000090?ooo`030000003oool0oooo01X0oooo0`00003o0?oooaD0oooo00110?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040000
0?l0oooo603oool00480oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`@0
0000o`3ooolL0?ooo`00@`3oool2000000D0oooo00<000000?ooo`3oool03P3oool400000?l0oooo
803oool004D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`<00000o`3o
oolT0?ooo`00AP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000003o0?ooobL0oooo0017
0?ooo`80000000<0oooo0000003oool00`3oool500000?l0oooo:`3oool004T0oooo0P0000000`3o
ool0000000000002000002D0oooo00<0omnL04P0M02oool0o`3oool70?ooo`00BP3oool2000002T0
oooo00<0omnL04P0M02oool0o`3oool70?ooo`00M@3oool00`3ogi`0B01d0;ooo`3o0?ooo`L0oooo
001Z0?ooo`030?oOW0180000000000<0000000<0001d0;ooo`3oool00P3oool00`3ogi`0B01d0;oo
o`3o0?ooo`L0oooo001e0?ooo`030?oOW01807@0_ooo0?l0oooo1`3oool007D0oooo00<0omnL04P0
M02oool0o`3oool70?ooo`00L`3oool01@2oM000001809boW01807@0_ooo0?l0oooo1`3oool007@0
oooo00@0okmd0000000007@0_oooo`3oool70?ooo`00M@3oool00`3ogi`0B01d0;ooo`3o0?ooo`L0
oooo003o0?ooogl0oooo003o0?ooogl0oooo003o0?ooogl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 381.563}, {334.5, 0}} -> {0.0121726, 0.0181431, \
0.00413441, 0.00413441}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(IntrinsicCurve3D[\ {1.3, \ 0.5\ Sin[s]}, \ {s, 0, \ 12  \[Pi]}, 
        PlotPoints \[Rule] 200];\)\)], "Input",
  CellLabel->"In[56]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05456 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-0.0437787 1.13321 -1.73472e-018 1.13321 [
[.19351 .18827 -19.6775 -10.9375 ]
[.19351 .18827 .94753 0 ]
[.35587 .12082 -7.61277 -10.9375 ]
[.35587 .12082 .82473 0 ]
[.52909 .04892 -12.863 -10.9375 ]
[.52909 .04892 2.26197 0 ]
[.043 .82516 -4.80584 0 ]
[.043 .82516 3.63166 10.9375 ]
[.16859 .91489 -8.31976 0 ]
[.16859 .91489 6.80524 10.9375 ]
[.2797 .99426 -4.50232 0 ]
[.2797 .99426 3.93518 10.9375 ]
[.3787 1.06499 -7.85806 0 ]
[.3787 1.06499 7.26694 10.9375 ]
[.04958 .37558 -8.4375 -3.3337 ]
[.04958 .37558 0 7.6038 ]
[.02588 .52864 -15.125 -3.49578 ]
[.02588 .52864 0 7.44172 ]
[-0.00038 .69821 -8.4375 -3.67722 ]
[-0.00038 .69821 0 7.26028 ]
[ 0 0 0 0 ]
[ 1 1.05456 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08143 .24906 m
.68351 0 L
s
.20303 .19876 m
.20779 .204 L
s
gsave
.19351 .18827 -80.6775 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36475 .13186 m
.36919 .13738 L
s
gsave
.35587 .12082 -68.6128 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.53722 .06052 m
.54128 .06632 L
s
gsave
.52909 .04892 -73.863 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.23456 .18571 m
.23738 .18889 L
s
.26649 .1725 m
.26928 .17572 L
s
.29883 .15913 m
.30157 .16237 L
s
.33158 .14558 m
.33428 .14886 L
s
.39835 .11796 m
.40097 .1213 L
s
.43239 .10388 m
.43497 .10726 L
s
.46687 .08962 m
.46941 .09303 L
s
.50181 .07516 m
.5043 .07861 L
s
.17189 .21164 m
.17478 .21475 L
s
.14113 .22436 m
.14405 .22744 L
s
.11075 .23693 m
.1137 .23998 L
s
.5731 .04568 m
.57549 .04919 L
s
.60946 .03063 m
.6118 .03418 L
s
.64631 .01539 m
.6486 .01897 L
s
.25 Mabswid
0 .7789 m
.38445 1.05456 L
s
.04495 .81113 m
.04593 .80411 L
s
gsave
.043 .82516 -65.8058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.17 .90079 m
.1707 .89374 L
s
gsave
.16859 .91489 -69.3198 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.28065 .98013 m
.28112 .97306 L
s
gsave
.2797 .99426 -65.5023 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.37925 1.05083 m
.37953 1.04375 L
s
gsave
.3787 1.06499 -68.8581 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07124 .82998 m
.0718 .82577 L
s
.09687 .84836 m
.09739 .84414 L
s
.12186 .86627 m
.12234 .86205 L
s
.14623 .88375 m
.14668 .87952 L
s
.1932 .91742 m
.19359 .91319 L
s
.21584 .93366 m
.21621 .92943 L
s
.23795 .94952 m
.23829 .94528 L
s
.25955 .965 m
.25986 .96076 L
s
.30127 .99491 m
.30153 .99067 L
s
.32142 1.00937 m
.32166 1.00512 L
s
.34113 1.0235 m
.34134 1.01925 L
s
.3604 1.03731 m
.36059 1.03307 L
s
.01796 .79178 m
.01859 .78757 L
s
.25 Mabswid
.08143 .24906 m
0 .7789 L
s
.06278 .37043 m
.06938 .36786 L
s
gsave
.04958 .37558 -69.4375 -7.3337 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.0392 .52383 m
.04587 .52143 L
s
gsave
.02588 .52864 -76.125 -7.49578 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.01308 .6938 m
.01981 .6916 L
s
gsave
-0.00038 .69821 -69.4375 -7.67722 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05825 .3999 m
.06222 .39838 L
s
.05363 .42996 m
.0576 .42845 L
s
.04892 .46062 m
.0529 .45914 L
s
.04411 .49191 m
.0481 .49044 L
s
.03419 .55642 m
.0382 .555 L
s
.02908 .58968 m
.03309 .58829 L
s
.02386 .62366 m
.02788 .62228 L
s
.01853 .65835 m
.02256 .657 L
s
.06722 .34153 m
.07117 .33996 L
s
.07158 .31318 m
.07552 .3116 L
s
.07585 .28537 m
.07979 .28377 L
s
.08005 .25808 m
.08398 .25646 L
s
.00751 .73002 m
.01156 .72873 L
s
.00182 .76704 m
.00588 .76577 L
s
.25 Mabswid
.08143 .24906 m
0 .7789 L
s
0 .7789 m
.38445 1.05456 L
s
.38445 1.05456 m
.40256 .57325 L
s
.40256 .57325 m
.08143 .24906 L
s
.68351 0 m
.93123 .40078 L
s
.93123 .40078 m
1 .9099 L
s
1 .9099 m
.71757 .55584 L
s
.71757 .55584 m
.68351 0 L
s
.08143 .24906 m
0 .7789 L
s
0 .7789 m
.71757 .55584 L
s
.71757 .55584 m
.68351 0 L
s
.68351 0 m
.08143 .24906 L
s
.40256 .57325 m
.93123 .40078 L
s
.93123 .40078 m
1 .9099 L
s
1 .9099 m
.38445 1.05456 L
s
.38445 1.05456 m
.40256 .57325 L
s
0 0 m
1 0 L
1 1.05456 L
0 1.05456 L
closepath
clip
newpath
.5 Mabswid
.54483 .607 m
.51237 .6608 L
s
.57637 .55162 m
.54483 .607 L
s
.60443 .49619 m
.57637 .55162 L
s
.51237 .6608 m
.48161 .71152 L
s
.62651 .44234 m
.60443 .49619 L
s
.61068 .48637 m
.55205 .45968 L
s
.66718 .5149 m
.61068 .48637 L
s
.55205 .45968 m
.49423 .4347 L
s
.46283 .68761 m
.40681 .65551 L
s
.52033 .71555 m
.46283 .68761 L
s
.40681 .65551 m
.35532 .61934 L
s
.71855 .5454 m
.66718 .5149 L
s
.49423 .4347 m
.44014 .41139 L
s
.48161 .71152 m
.45515 .75763 L
s
.57628 .7393 m
.52033 .71555 L
s
.64026 .39186 m
.62651 .44234 L
s
.35532 .61934 m
.31137 .57936 L
s
.62767 .75885 m
.57628 .7393 L
s
.76174 .57795 m
.71855 .5454 L
s
.4012 .43699 m
.35523 .48393 L
s
.4487 .3933 m
.4012 .43699 L
s
.35523 .48393 m
.31345 .53297 L
s
.44014 .41139 m
.39265 .38989 L
s
.45515 .75763 m
.43559 .7975 L
s
.31137 .57936 m
.27795 .53611 L
s
.49514 .35411 m
.4487 .3933 L
s
.31345 .53297 m
.27863 .58294 L
s
.64355 .34676 m
.64026 .39186 L
s
.67145 .77412 m
.62767 .75885 L
s
.79371 .61248 m
.76174 .57795 L
s
.53801 .32078 m
.49514 .35411 L
s
.39265 .38989 m
.35465 .37054 L
s
.27863 .58294 m
.25356 .63258 L
s
.27795 .53611 m
.25783 .49051 L
s
.71516 .71215 m
.66608 .75812 L
s
.75822 .66075 m
.71516 .71215 L
s
.72615 .70292 m
.67782 .74997 L
s
.76778 .65068 m
.72615 .70292 L
s
.66608 .75812 m
.61372 .79731 L
s
.67782 .74997 m
.62558 .79049 L
s
.47601 .34082 m
.41066 .35336 L
s
.54318 .3335 m
.47601 .34082 L
s
.60943 .33201 m
.54318 .3335 L
s
.43559 .7975 m
.42534 .82943 L
s
.79249 .60537 m
.75822 .66075 L
s
.79998 .59475 m
.76778 .65068 L
s
.63469 .30921 m
.64355 .34676 L
s
.62558 .79049 m
.57215 .82316 L
s
.41066 .35336 m
.34993 .37061 L
s
.61372 .79731 m
.56081 .82841 L
s
.67197 .33715 m
.60943 .33201 L
s
.57488 .2949 m
.53801 .32078 L
s
.8153 .54769 m
.79249 .60537 L
s
.25356 .63258 m
.24095 .68045 L
s
.70458 .78496 m
.67145 .77412 L
s
.81158 .64861 m
.79371 .61248 L
s
.82009 .53685 m
.79998 .59475 L
s
.35465 .37054 m
.32896 .35396 L
s
.25783 .49051 m
.25335 .44391 L
s
.57215 .82316 m
.52028 .84666 L
s
.34993 .37061 m
.29668 .39224 L
s
.72794 .34976 m
.67197 .33715 L
s
.56081 .82841 m
.51011 .85007 L
s
.50083 .8334 m
.43227 .8278 L
s
.56961 .82992 m
.50083 .8334 L
s
.63559 .81785 m
.56961 .82992 L
s
.8242 .48965 m
.8153 .54769 L
s
.43227 .8278 m
.36698 .81264 L
s
.59917 .28092 m
.5681 .29939 L
s
.42534 .82943 m
.42654 .85165 L
s
.82575 .47898 m
.82009 .53685 L
s
.61264 .2815 m
.63469 .30921 L
s
.69576 .79768 m
.63559 .81785 L
s
.24095 .68045 m
.24318 .72497 L
s
.60338 .2782 m
.57488 .2949 L
s
.36698 .81264 m
.3081 .78754 L
s
.52028 .84666 m
.47273 .8596 L
s
.29668 .39224 m
.2539 .41798 L
s
.81298 .68564 m
.81158 .64861 L
s
.72418 .79104 m
.70458 .78496 L
s
.77436 .37069 m
.72794 .34976 L
s
.25335 .44391 m
.26614 .39819 L
s
.51011 .85007 m
.46436 .86089 L
s
.81725 .43353 m
.8242 .48965 L
s
.32896 .35396 m
.31816 .34106 L
s
.74708 .76992 m
.69576 .79768 L
s
.81516 .4235 m
.82575 .47898 L
s
.3081 .78754 m
.2588 .75239 L
s
.6202 .2731 m
.59917 .28092 L
s
.24318 .72497 m
.26194 .76438 L
s
.42654 .85165 m
.44071 .86246 L
s
.57731 .26584 m
.61264 .2815 L
s
.47273 .8596 m
.43224 .86062 L
s
.2539 .41798 m
.2246 .4476 L
s
.79334 .38187 m
.81725 .43353 L
s
.6214 .27256 m
.60338 .2782 L
s
.80835 .40057 m
.77436 .37069 L
s
.26614 .39819 m
.29671 .35571 L
s
.46436 .86089 m
.42629 .85952 L
s
.78645 .73515 m
.74708 .76992 L
s
.2588 .75239 m
.2222 .70751 L
s
.79631 .7224 m
.81298 .68564 L
s
.78747 .373 m
.81516 .4235 L
s
.72774 .79198 m
.72418 .79104 L
s
.31816 .34106 m
.32427 .33302 L
s
.75259 .33738 m
.79334 .38187 L
s
.26194 .76438 m
.29782 .79684 L
s
.2222 .70751 m
.20103 .65388 L
s
.29671 .35571 m
.34411 .31912 L
s
.7431 .33019 m
.78747 .373 L
s
.43224 .86062 m
.40146 .8485 L
s
.2246 .4476 m
.21156 .48078 L
s
.52987 .26409 m
.57731 .26584 L
s
.62936 .27774 m
.6202 .2731 L
s
.81092 .69415 m
.78645 .73515 L
s
.82729 .43961 m
.80835 .40057 L
s
.44071 .86246 m
.46847 .86044 L
s
.76127 .7573 m
.79631 .7224 L
s
.42629 .85952 m
.39849 .84478 L
s
.62722 .27975 m
.6214 .27256 L
s
.69664 .30264 m
.75259 .33738 L
s
.71343 .78729 m
.72774 .79198 L
s
.68409 .2976 m
.7431 .33019 L
s
.20103 .65388 m
.19729 .59334 L
s
.34411 .31912 m
.40576 .29116 L
s
.29782 .79684 m
.34992 .82067 L
s
.32427 .33302 m
.34839 .33122 L
s
.47293 .27738 m
.52987 .26409 L
s
.81796 .64803 m
.81092 .69415 L
s
.82931 .48733 m
.82729 .43961 L
s
.62878 .2798 m
.69664 .30264 L
s
.21156 .48078 m
.21698 .51702 L
s
.40146 .8485 m
.38274 .82238 L
s
.70919 .78835 m
.76127 .7573 L
s
.39249 .29593 m
.46239 .27687 L
s
.61411 .27725 m
.68409 .2976 L
s
.62549 .29632 m
.62936 .27774 L
s
.40576 .29116 m
.47746 .27429 L
s
.46847 .86044 m
.50917 .84474 L
s
.39849 .84478 m
.38318 .81592 L
s
.19729 .59334 m
.21177 .52867 L
s
.5538 .27024 m
.62878 .2798 L
s
.6199 .30116 m
.62722 .27975 L
s
.46239 .27687 m
.53825 .27031 L
s
.53825 .27031 m
.61411 .27725 L
s
.47746 .27429 m
.5538 .27024 L
s
.34992 .82067 m
.41553 .83456 L
s
.41053 .30581 m
.47293 .27738 L
s
.68068 .77653 m
.71343 .78729 L
s
.64323 .81341 m
.70919 .78835 L
s
.80587 .59832 m
.81796 .64803 L
s
.81367 .5423 m
.82931 .48733 L
s
.34839 .33122 m
.39017 .33705 L
s
.21177 .52867 m
.24368 .46348 L
s
.21698 .51702 m
.24192 .55556 L
s
.41553 .83456 m
.49022 .83778 L
s
.38274 .82238 m
.37778 .78215 L
s
.50917 .84474 m
.56057 .81539 L
s
.34782 .34817 m
.41053 .30581 L
s
.56824 .83042 m
.64323 .81341 L
s
.60846 .32961 m
.62549 .29632 L
s
.38318 .81592 m
.38184 .77302 L
s
.24368 .46348 m
.29044 .40193 L
s
.49022 .83778 m
.56824 .83042 L
s
.29044 .40193 m
.34782 .34817 L
s
.59964 .33734 m
.6199 .30116 L
s
.78128 .60206 m
.81367 .5423 L
s
.63055 .7594 m
.68068 .77653 L
s
.77436 .54701 m
.80587 .59832 L
s
.39017 .33705 m
.44739 .35164 L
s
.56057 .81539 m
.61886 .77358 L
s
.24192 .55556 m
.28574 .5953 L
s
.37778 .78215 m
.38724 .72878 L
s
.73487 .66318 m
.78128 .60206 L
s
.38184 .77302 m
.39481 .71731 L
s
.57957 .37722 m
.60846 .32961 L
s
.61886 .77358 m
.67889 .7217 L
s
.725 .49656 m
.77436 .54701 L
s
.56811 .38762 m
.59964 .33734 L
s
.5662 .73594 m
.63055 .7594 L
s
.67889 .7217 m
.73487 .66318 L
s
.44739 .35164 m
.51583 .37556 L
s
.28574 .5953 m
.34568 .63481 L
s
.38724 .72878 m
.4103 .6646 L
s
.66151 .44959 m
.725 .49656 L
s
.39481 .71731 m
.42088 .65141 L
s
.54169 .43725 m
.57957 .37722 L
s
.51583 .37556 m
.58951 .4086 L
s
.49275 .70664 m
.5662 .73594 L
s
.52855 .44977 m
.56811 .38762 L
s
.34568 .63481 m
.41686 .67246 L
s
.58951 .4086 m
.66151 .44959 L
s
.41686 .67246 m
.49275 .70664 L
s
.4103 .6646 m
.44444 .59338 L
s
.42088 .65141 m
.45712 .57937 L
s
.49914 .50621 m
.54169 .43725 L
s
.48556 .51999 m
.52855 .44977 L
s
.44444 .59338 m
.48556 .51999 L
s
.45712 .57937 m
.49914 .50621 L
s
.25 Mabswid
.68351 0 m
.93123 .40078 L
s
.93123 .40078 m
1 .9099 L
s
1 .9099 m
.71757 .55584 L
s
.71757 .55584 m
.68351 0 L
s
.08143 .24906 m
0 .7789 L
s
0 .7789 m
.71757 .55584 L
s
.71757 .55584 m
.68351 0 L
s
.68351 0 m
.08143 .24906 L
s
.08143 .24906 m
.68351 0 L
s
.20303 .19876 m
.20779 .204 L
s
gsave
.19351 .18827 -80.6775 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36475 .13186 m
.36919 .13738 L
s
gsave
.35587 .12082 -68.6128 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.53722 .06052 m
.54128 .06632 L
s
gsave
.52909 .04892 -73.863 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.23456 .18571 m
.23738 .18889 L
s
.26649 .1725 m
.26928 .17572 L
s
.29883 .15913 m
.30157 .16237 L
s
.33158 .14558 m
.33428 .14886 L
s
.39835 .11796 m
.40097 .1213 L
s
.43239 .10388 m
.43497 .10726 L
s
.46687 .08962 m
.46941 .09303 L
s
.50181 .07516 m
.5043 .07861 L
s
.17189 .21164 m
.17478 .21475 L
s
.14113 .22436 m
.14405 .22744 L
s
.11075 .23693 m
.1137 .23998 L
s
.5731 .04568 m
.57549 .04919 L
s
.60946 .03063 m
.6118 .03418 L
s
.64631 .01539 m
.6486 .01897 L
s
.25 Mabswid
0 .7789 m
.38445 1.05456 L
s
.04495 .81113 m
.04593 .80411 L
s
gsave
.043 .82516 -65.8058 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.17 .90079 m
.1707 .89374 L
s
gsave
.16859 .91489 -69.3198 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.28065 .98013 m
.28112 .97306 L
s
gsave
.2797 .99426 -65.5023 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.37925 1.05083 m
.37953 1.04375 L
s
gsave
.3787 1.06499 -68.8581 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07124 .82998 m
.0718 .82577 L
s
.09687 .84836 m
.09739 .84414 L
s
.12186 .86627 m
.12234 .86205 L
s
.14623 .88375 m
.14668 .87952 L
s
.1932 .91742 m
.19359 .91319 L
s
.21584 .93366 m
.21621 .92943 L
s
.23795 .94952 m
.23829 .94528 L
s
.25955 .965 m
.25986 .96076 L
s
.30127 .99491 m
.30153 .99067 L
s
.32142 1.00937 m
.32166 1.00512 L
s
.34113 1.0235 m
.34134 1.01925 L
s
.3604 1.03731 m
.36059 1.03307 L
s
.01796 .79178 m
.01859 .78757 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{207.75, 219.063},
  ImageMargins->{{3.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004g0001B2000`400?l00000o`00003oo`3ooolh
0?ooo`00o`3ooolh0?ooo`00e`3oool2000005h0oooo003E0?ooo`80000000<0oooo000000000000
G@3oool00=80oooo0`0000030?ooo`800000G@3oool009`0oooo00/0oon?03D00000000001AO0<Co
o`3oool0olAO01@0=@2?ool0oooo0<AO5002000000030000501Oa?l0oooo02@0oooo0P0000060?oo
o`030000003oool0000005`0oooo002K0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?103oool0
1`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool08P3oool2000000P0oooo00<000000?ooo`000000
G03oool009/0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo00P0oooo00<0ScD003F?o`3o
ool07P3oool3000000X0oooo00@000000?ooo`3oool00000F`3oool009/0oooo00L0olAO01@DG`34
ool0oooo0?ooS`0e01@0GlCo00P0oooo00<0ScD003F?o`3oool0703oool2000000<0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000005X0oooo002K0?ooo`070?n?=@0055l0
a?oo0?ooo`3oohl0=@0D05o4o`030?ooo`070?o4G`0D01@0GlCo0?ooo`3ool@0Ga@D05o4o`0J0?oo
o`<000003`3oool01@000000oooo0?ooo`3oool0000005X0oooo002K0?ooo`070?o4G`0D55l0a?oo
0?ooo`3oohl0=@0D05o4o`030?ooo`030?ooS`0e000000000080000000<0=Hoo0?ooo`3oool05`3o
ool200000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`00V`3oool0
1`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool00`3oool00`3ool@0Ga@D05o4o`0I0?ooo`<00000
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05H0oooo002K0?ooo`060?ooa01O
5000=Hoo0?ooo`34Ga@003F?1@3oool00`2?=@00=Hoo0?ooo`0F0?ooo`8000000P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0EP3oool009`0oooo
00D0oon?03D00000000001AO0<Coo`050?ooo`060<AO5000000000000000000003D0Sooo4@3oool2
000001X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`00^P3oool30000
01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`00^03oool2000001l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1D0?ooo`00]@3oool400000200oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`00/`3oool2000002@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`00/03oool3000002H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`00[P3oool2000002T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1B0?ooo`00[03oool2000002/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1A0?ooo`00Z@3oool300000080oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0500oooo002W0?ooo`800000<03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0500oooo002T0?ooo`<00000<P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04l0oooo002R0?ooo`800000=@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04l0oooo002O0?ooo`<000000P3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0CP3oool00740oooo
00D0oon?03D00000000001AO0<Coo`0W0?ooo`800000>P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo04d0oooo001`0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?9@3oool20000
03d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1=0?ooo`00L03oool01`3oohl0
=@0e08ooo`3oool0olAO01@0=@2?ool08@3oool3000003l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1<0?ooo`00L03oool01`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l07`3o
ool200000080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo04/0oooo001`0?ooo`070?n?=@0055l0a?oo0?ooo`3oohl0=@0D05o4o`0L0?ooo`<00000
A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04/0oooo001`0?ooo`070?o4G`0D
55l0a?oo0?ooo`3oohl0=@0D05o4o`0J0?ooo`800000A`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo04X0oooo001`0?ooo`070?ooS`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0G0?oo
o`<00000B@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04X0oooo001`0?ooo`06
0?ooa01O5000=Hoo0?ooo`34Ga@003F?5P3oool200000080oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04T0oooo001a0?ooo`050?ooS`0e00000000
000DG`34ool0503oool2000004h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`18
0?ooo`00Q`3oool300000500oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`180?oo
o`00Q@3oool2000005<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`170?ooo`00
PP3oool3000000030?ooo`000000oooo0580oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`170?ooo`00P03oool2000005P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`160?ooo`00O@3oool3000005X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`15
0?ooo`00N`3oool2000005d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`150?oo
o`00N03oool4000005h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`140?ooo`00
MP3oool2000000@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04@0oooo001d0?ooo`800000I@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo04<0oooo001a0?ooo`<00000I`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0480oooo000h0?ooo`0;0?ooS`0e00000000000DG`34ool0oooo0?o4G`0D03D0Sooo0?ooo`34
Ga@00P0000000`0001@0GlCo0?ooo`0W0?ooo`80000000<0oooo0000003oool0I`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0480oooo000g0?ooo`060?ooa01O500055o40?ooo`34
Ga@003F?103oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool0903oool3000006`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`110?ooo`00=`3oool01`3oohl0=@0e08ooo`3o
ool0olAO01@0=@2?ool0203oool00`2?=@00=Hoo0?ooo`0Q0?ooo`800000K`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0400oooo000_0?ooo`030?o4G`0D0000000000<0000000T0
000e08ooo`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l0203oool00`2?=@00=Hoo0?ooo`0N0?oo
o`<00000L@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0400oooo000g0?ooo`07
0?n?=@0055l0a?oo0?ooo`3oohl0=@0D05o4o`030?ooo`070?o4G`0D01@0GlCo0?ooo`3ool@0Ga@D
05o4o`0M0?ooo`8000000P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0?`3oool003L0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo00<0
oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`800000MP3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo03l0oooo000g0?ooo`070?ooS`0e03D0Sooo0?ooo`3o
a5l0500e08ooo`030?ooo`030?ooa01O51@0GlCo01`0oooo0`00001h0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0?P3oool003L0oooo00H0ooo405lD000eSol0oooo0<AO5000=Hl5
0?ooo`0308le000eSol0oooo01T0oooo0P00001k0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0?@3oool003P0oooo00D0oon?03D00000000001AO0<Coo`050?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000000030?ooo`000000oooo07X0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0m0?ooo`00F@3oool200000800oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0l0?ooo`00EP3oool300000880oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0l0?ooo`00E03oool2000008D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0k0?ooo`00DP3oool200000080oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo001?0?ooo`<00000R@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo03X0oooo001=0?ooo`800000S@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo03T0oooo001:0?ooo`<00000S`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo03T0oooo00180?ooo`8000000`3oool2000008d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool3000009@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0g0?ooo`00@`3oool2000009L0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0g0?ooo`00@@3oool4000009L0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0f0?ooo`00?P3oool3000009/0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0e0?ooo`00?03oool2000009h0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0e0?ooo`00>@3oool300000:00oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0d0?ooo`00=`3oool200000080oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03@0oooo000d0?ooo`<00000Y@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo03<0oooo000b0?ooo`800000Z03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0380oooo000`0?ooo`800000ZP3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0380oooo000]0?ooo`<000000P3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool002/0oooo0P00002_0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool002T0oooo0P00002a0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0<03oool002T0oooo0P00002b0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0;`3oool002T0oooo00<000000?ooo`000000/@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo02l0oooo000Y0?ooo`80000000<0oooo0000003o
ool0[`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02h0oooo000X0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02d0oooo000X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0N@3o
ool@000002<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0]0?ooo`00:03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo07@0oooo1000000@0?ooo`8000008@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02`0oooo000X0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0K`3ooolF000000@0oooo0P0000070?ooo`8000005P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02`0oooo000X0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0HP3ooolB000000`0oooo4@0000000`3oool000000000000E0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0:`3oool002P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1N0?ooo`/000008@3oool;000001<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0Z0?ooo`009`3oool00`000000oooo000000090?ooo`030000003o
ool0oooo05T0oooo1`0000020?ooo`800000903oool3000000030?ooo`00000000000080oooo1`00
000@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:P3oool002L0oooo0P00000;
0?ooo`030000003oool0oooo05D0oooo1P0000040?ooo`8000009@3oool2000000D0oooo00H00000
0?ooo`000000oooo0000003oool5000000h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0Y0?ooo`009`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0540oooo1@00
00050?ooo`<000009@3oool2000000L0oooo00@000000?ooo`00000000001P3oool4000000/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0Y0?ooo`009`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04`0oooo1@0000070?ooo`8000009P3oool2000000X0oooo0`00
000:0?ooo`@000001`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02P0oooo000W
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B@3oool3000000P0oooo0`00000V
0?ooo`8000003@3oool2000000d0oooo100000040?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool09`3oool002L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`170?oo
o`800000203oool2000002P0oooo0P00000=0?ooo`<000003`3oool400000080oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04@0oooo0P0000080?ooo`800000:@3oool00`000000oooo0?ooo`0=0?ooo`<0
00004P3oool400000300oooo00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`100?ooo`<00000203oool2000002T0oooo0P00000?0?ooo`800000
0P3oool00`000000oooo0?ooo`0A0?ooo`<00000;`3oool00`000000oooo0?ooo`0V0?ooo`009P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03d0oooo0P0000090?ooo`800000:@3o
ool200000140oooo0P0000030?ooo`030000003oool0oooo0180oooo0P00000_0?ooo`030000003o
ool0oooo02D0oooo000V0?ooo`800000503oool00`000000oooo0?ooo`0j0?ooo`8000002P3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo0P0000040?ooo`030000003oool0
oooo0180oooo00@000000?ooo`0000000000;P3oool00`000000oooo0?ooo`0T0?ooo`009P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03L0oooo0P00000:0?ooo`800000:@3oool2
000001<0oooo0P0000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`00000/
0?ooo`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0=03oool2000000/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?oo
o`8000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo0P00000/0?oo
o`030000003oool0oooo02<0oooo000V0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0<@3oool2000000/0oooo0P00000Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo0P00000[0?ooo`03
0000003oool0oooo0280oooo000U0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
4`3oool2000000L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`800000
:@3oool00`000000oooo0?ooo`0R0?ooo`009@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`0000001P0000030?ooo`800000:P3oool2000000h0oooo3P00
00040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool2000002T0oooo00<0
00000?ooo`3oool08@3oool002D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Z
0?ooo`@000001`3oool6000002P0oooo00<000000?ooo`3oool03P0000070?ooo`8000001@3oool9
000000h0oooo00<000000?ooo`3oool02@3oool2000002L0oooo00<000000?ooo`3oool08@3oool0
02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo0P0000040?ooo`D00000703oool:000001@0oooo00<000000?ooo`0000002@3oool00`00
0000oooo0?ooo`020?ooo`L000001`3oool00`000000oooo0?ooo`0:0?ooo`8000009`3oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool2000001d0oooo00<000000?ooo`3oool09@3oool3000000X0
oooo00<000000?ooo`3oool02@3oool400000100oooo200000050?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`090?ooo`@000000`3oool00`000000
oooo0?ooo`0;0?ooo`8000009`3oool00`000000oooo0?ooo`0O0?ooo`009@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000070?ooo`80
0000403oool4000000L0oooo1@00000<0?ooo`030000003oool0oooo01H0oooo0P00000<0?ooo`03
0000003oool0oooo00`0oooo1000000>0?ooo`8000009P3oool00`000000oooo0?ooo`0O0?ooo`00
903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo1`00000?0?ooo`800000
603oool00`000000oooo0000000<0?ooo`030000003oool0oooo00l0oooo1@00000;0?ooo`800000
9P3oool00`000000oooo0?ooo`0N0?ooo`00903oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01h0oooo0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3o
ool5000000030?ooo`0000000000008000003@3oool00`000000oooo0?ooo`0H0?ooo`8000003@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo100000080?ooo`8000009@3o
ool00`000000oooo0?ooo`0N0?ooo`00903oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000B0?ooo`@000002P3o
ool3000000T0oooo00<000000?ooo`3oool0603oool2000000h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`060?ooo`8000001`3oool2000002D0oooo00<000000?ooo`3oool07@3o
ool002@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00T0oooo0P00000?0?ooo`@000004@3oool3000000D0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0000000>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool2
000000H0oooo0P00000U0?ooo`030000003oool0oooo01`0oooo000T0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool00000
00/0oooo0`00000H0?ooo`8000000P3oool00`000000oooo0?ooo`0I0?ooo`8000003`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`800000903oool00`00
0000oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000L0oooo0`00000M0?oo
o`<000006P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02`3oool2000000@0oooo0P00000T0?ooo`030000003oool0oooo01/0oooo000T0?ooo`80
00009P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool2000000030?ooo`0000000000008000007`3oool010000000oooo0?ooo`3oool30000
01L0oooo0P00000@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool20000
00<0oooo0P00000S0?ooo`030000003oool0oooo01/0oooo000S0?ooo`800000:03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool400000240
oooo00<000000?ooo`3oool01@3oool3000001<0oooo0P00000@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03`3oool2000000040?ooo`000000oooo000002<0oooo00<000000?oo
o`3oool06P3oool001L0oooo00D0oono07@00000000004RL0=ooo`070?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`8000007P3oool00`000000oooo0?ooo`090?ooo`<000003`3oool00`00
0000oooo0000000@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool01@00
0000oooo0000003oool0000002<0oooo00<000000?ooo`3oool06@3oool001H0oooo00H0oooO09a8
0018W=l0oooo0=nLB000M;l70?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`<00000203oool2000001/0oooo
00<000000?ooo`3oool03@3oool2000000d0oooo0P00000A0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04P3oool4000002<0oooo00<000000?ooo`3oool06@3oool001H0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P00000=0?ooo`80
00005`3oool200000180oooo0P00000:0?ooo`8000004P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01@0oooo0`00000S0?ooo`030000003oool0oooo01P0oooo000F0?ooo`070?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`<000004P3oool2000001@0oooo00<000000?oo
o`3oool0503oool2000000P0oooo0P00000B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05@3oool2000002@0oooo00<000000?ooo`3oool05`3oool001H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo00H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00D0oooo0`00000F0?ooo`<00000403oool00`000000oooo0?ooo`0G
0?ooo`8000001@3oool2000001<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F
0?ooo`8000008`3oool00`000000oooo0?ooo`0G0?ooo`005P3oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol01@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0103oool3000001/0oooo0P00000=0?ooo`030000003oool0oooo01X0oooo0P00
00020?ooo`800000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo0`00
000S0?ooo`030000003oool0oooo01H0oooo000F0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`80000000<0oooo0000003oool07@3oool2000000X0oooo00<000000?ooo`3oool0
7@3oool4000001@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`<00000
8P3oool00`000000oooo0?ooo`0F0?ooo`005P3oool01P3ooml0W4P007Boo`3oool0gia8001d_`H0
oooo0P00000a0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`030000003oool0oooo01l0oooo0`0000060?ooo`030000003oool0oooo01l0oooo0`00000C0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool2000000030?ooo`000000oooo
0200oooo0P00000G0?ooo`005`3oool01@3ookl0M00000000000B9`0gooo00H0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool08`3oool2000000<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`02
00000140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`<000007P3oool3
000000030?ooo`000000oooo01H0oooo000R0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0103oool010000000oooo0000000000030?ooo`030000003oool0oooo02H0oooo0`00000R
0?ooo`800000103oool2000000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H
0?ooo`80000000<0oooo0000003oool06@3oool3000000@0oooo00<000000?ooo`3oool05@3oool0
0280oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`040?ooo`800000103oool00`00
0000oooo0?ooo`0X0?ooo`@000007`3oool2000000L0oooo0P00000=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool06@3oool3000001L0oooo0`0000070?ooo`030000003oool0oooo
01D0oooo000R0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3oool0oooo0`0000050?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool2000001d0oooo0P0000090?oo
o`8000002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01T0oooo0P0000000`3o
ool000000?ooo`0B0?ooo`<000002`3oool00`000000oooo0?ooo`0D0?ooo`008@3oool00`000000
oooo0?ooo`0e0?ooo`050000003oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0V0?oo
o`8000001`3oool2000001X0oooo0P00000<0?ooo`800000203oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo01T0oooo0`00000@0?ooo`<000003P3oool00`000000oooo0?ooo`0D0?oo
o`008@3oool00`000000oooo0?ooo`0f0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`090?ooo`8000005`3oool2000000l0oooo0P0000060?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool06@3oool3000000d0oooo0`00000A0?oo
o`030000003oool0oooo01@0oooo000Q0?ooo`030000003oool0oooo03D0oooo00D000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303oool30000
01@0oooo0P00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0J0?ooo`<000002@3oool3000001@0oooo00<000000?ooo`3oool0503oool00240
oooo0P00000e0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0100oooo0P00000A0?ooo`8000004`3oool200000080oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`<000001@3oool4000001L0oooo00<000000?oo
o`3oool0503oool00240oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01<0oooo0P00000?0?ooo`03
0000003oool0oooo01@0oooo0`00000G0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`00
0000oooo0`00000K0?ooo`030000003oool0oooo01@0oooo000Q0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000W0?ooo`030000003oool0oooo
01H0oooo0`00000;0?ooo`800000603oool2000001H0oooo00<000000?ooo`3oool06`3oool40000
01h0oooo00<000000?ooo`3oool0503oool00200oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`030?ooo`040000003oool00000000002H0oooo00<000000?ooo`3oool06P3oool20000
00P0oooo0P00000H0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool06@3oool4
000000030?ooo`000000oooo01d0oooo00<000000?ooo`3oool0503oool00200oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0M0?ooo`<000001@3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo0?ooo`8000004`3oool00`000000oooo0?ooo`0F0?ooo`<000000P3oool2
000000030?ooo`000000oooo01h0oooo00<000000?ooo`3oool04`3oool00200oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`8000000P3oool2000001T0oooo00<000000?oo
o`3oool00`3oool200000140oooo00<000000?ooo`3oool04`3oool3000000D0oooo0P0000000`3o
ool000000?ooo`0N0?ooo`030000003oool0oooo01<0oooo000P0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0T0?ooo`<000006@3oool00`000000oooo0?ooo`060?ooo`8000003`3oool00`000000
oooo0?ooo`0@0?ooo`<00000203oool2000000030?ooo`000000oooo01h0oooo00<000000?ooo`3o
ool04`3oool00200oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0V0?ooo`@00000
5`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool3000000`0oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`0C0?ooo`00803o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool09P3oool2000000<0oooo0P00000D0?ooo`030000003o
ool0oooo00X0oooo0P00000<0?ooo`030000003oool0oooo00X0oooo0`00000?0?ooo`<000007`3o
ool00`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0000000`0?ooo`030000003oool0
oooo00D0oooo0P0000090?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`040?ooo`<000004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool300000180oooo0`00000O0?ooo`030000003oool0
oooo01<0oooo000O0?ooo`800000<03oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`8000002@3oool20000
00l0oooo00<000000?ooo`3oool03@3oool2000000T0oooo00<000000?ooo`3oool0103oool30000
01D0oooo0`00000O0?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool09`3oool2000000`0oooo0P00000<0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool3000001P0oooo0`00000P
0?ooo`030000003oool0oooo0180oooo000O0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0X0?ooo`8000003P3oool2000000X0oooo00<000000?ooo`3oool04@3oool2
000000H0oooo1000000K0?ooo`80000000<0oooo0000003oool07P3oool00`000000oooo0?ooo`0B
0?ooo`007`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0:03oool200000140oooo0P0000080?ooo`030000003oool0oooo01<0oooo00@000000?oo
o`3oool0oooo1000000M0?ooo`040000003oool00000000001l0oooo00<000000?ooo`3oool04P3o
ool001l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02P0oooo0P00000D0?ooo`8000001@3oool00`000000oooo0?ooo`0E0?ooo`<000000`3oool0
0`000000oooo0?ooo`0K0?ooo`040000003oool00000000001l0oooo00<000000?ooo`3oool04P3o
ool001l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02T0oooo0P00000F0?ooo`8000000`3oool00`000000oooo0?ooo`0B0?ooo`<0000000<0oooo
0000000000000`3oool00`000000oooo0?ooo`0L0?ooo`<000007`3oool00`000000oooo0?ooo`0B
0?ooo`007P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:@3oool2000001T0oooo0`00000B0?ooo`<000001P3oool010000000oooo0?ooo`00000N
0?ooo`<000007`3oool00`000000oooo0?ooo`0B0?ooo`007P3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0000000K0?oo
o`8000003@3oool4000000X0oooo0`00000N0?ooo`<000007`3oool00`000000oooo0?ooo`0B0?oo
o`007P3oool2000002l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`80
0000703oool010000000oooo0000000000080?ooo`<00000403oool00`000000oooo0?ooo`0L0?oo
o`<00000803oool00`000000oooo0?ooo`0A0?ooo`007P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool2000001`0oooo00<000000?ooo`3o
ool00P3oool2000000<0oooo0`00000C0?ooo`<00000703oool300000200oooo00<000000?ooo`3o
ool04@3oool001h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02/0oooo0P00000L0?ooo`030000003oool0oooo00@0oooo0`00000F0?ooo`040000
003oool0oooo000001/0oooo0P00000Q0?ooo`030000003oool0oooo0140oooo000N0?ooo`030000
003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0140
oooo00D000000?ooo`3oool0oooo0000000/0?ooo`800000703oool00`000000oooo0?ooo`020?oo
o`<000000P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000006P3oool2
00000240oooo00<000000?ooo`3oool04@3oool001d0oooo00<000000?ooo`3oool0<03oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`000000;03oool0
0`000000oooo0000000L0?ooo`030000003oool00000008000001P3oool2000001@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`8000008@3oool00`000000oooo0?ooo`0A
0?ooo`007@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0000000/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0[0?ooo`800000703oool3000000/0oooo0P00000B0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool200000280oooo00<000000?oo
o`3oool04@3oool001d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`000000:`3oool2000001X0oooo1000000?0?ooo`80
0000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo0P00000R0?ooo`03
0000003oool0oooo0140oooo000M0?ooo`030000003oool0oooo0300oooo0P00000=0?ooo`030000
003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`030000003oool0000001L0
oooo0`0000020?ooo`030000003oool0oooo0100oooo0P00000>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04`3oool200000280oooo00<000000?ooo`3oool04@3oool001d0oooo
00<000000?ooo`3oool0<03oool2000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02H0oooo0P00000E0?ooo`<000001@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0B0?ooo`8000008`3oool00`000000oooo0?ooo`0@0?ooo`007@3oool00`000000oooo0000
000`0?ooo`8000003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0000000B0?ooo`<000001`3oool00`000000oooo0?oo
o`0D0?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo0P00
000S0?ooo`030000003oool0oooo0100oooo000M0?ooo`800000<@3oool2000000h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`000000403oool3000000X0oooo00<000000?ooo`3oool05P3oool2000000T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0403oool000H0oooo00/0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0
oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool0<03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0000000d0oooo0`00000<0?ooo`030000003oool0oooo
01T0oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool20000
02@0oooo00<000000?ooo`3oool0403oool000D0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l4
0?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo0300oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000/0oooo0`00000?0?ooo`03
0000003oool0oooo01/0oooo0P0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03P3oool2000002@0oooo00<000000?ooo`3oool0403oool000D0oooo00L0oono07@0M02oool0
oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool07P3oool2000000T0oooo0`00000A0?oo
o`030000003oool0oooo01h0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool03@3oool2000002@0oooo00<000000?ooo`3oool0403oool000D0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo00000006
0?ooo`<00000503oool00`000000oooo0?ooo`0P0?ooo`8000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo0`00000T0?ooo`030000003oool0oooo0100oooo00050?oo
o`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0W=oo0?ooo`3ooml0
W4Q809cOo`060?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0K0?ooo`800000103oool3000001H0oooo00<000000?ooo`3oool08`3oool3000000d0
oooo00<000000?ooo`3oool02P3oool3000002D0oooo00<000000?ooo`3oool03`3oool000D0oooo
00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d
_ol0oooo0?ooo`050?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0000000@000006@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000V0?oo
o`030000003oool0oooo00l0oooo00050?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`03
0?ooo`030?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01L0oooo1000000L0?ooo`030000003oool0oooo02H0oooo0P00000>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`0?
0?ooo`001@3oool01P3ooml0W4P007Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3oool0203o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo01@0oooo0`0000000`3oool00000
0?ooo`0L0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`0000003P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool03`3oool000H0oooo
00D0oono07@00000000004RL0=ooo`050?ooo`060=nLB000000000000000000007@0_ooo1@3oool2
00000300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
000001P0oooo00<000000?ooo`3oool0403oool3000000040?ooo`000000oooo000001d0oooo00<0
00000?ooo`3oool09P3oool200000080oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000009`3oool00`000000oooo0?ooo`0?0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00`0oooo0`0000040?ooo`8000007P3oool00`000000oooo0?ooo`0S
0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo00l0oooo000K0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0000001X0oooo00<000000?ooo`3oool0203oool3000000H0oooo00<000000?ooo`0000007@3o
ool00`000000oooo0?ooo`0P0?ooo`@000001P3oool01@000000oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool00`3oool010000000oooo00000000000W0?ooo`030000003oool0oooo00l0
oooo000K0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0103oool3000000T0
oooo0P00000M0?ooo`030000003oool0oooo01h0oooo0`00000:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
01/0oooo00<000000?ooo`3oool00`00000;0?ooo`030000003oool0000001d0oooo00<000000?oo
o`3oool06`3oool3000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0>
0?ooo`006P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo0P00000=0?oo
o`030000003oool0000001d0oooo00<000000?ooo`3oool06@3oool300000180oooo00<000000?oo
o`3oool00P3oool2000000T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00h0oooo000J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000001d0oooo00<000000?ooo`3o
ool05P3oool3000001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`80
00000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo000J0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000001d0
oooo00<000000?ooo`3oool04`3oool4000001X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00800000:P3oool00`000000oooo0?ooo`0>0?ooo`00
6P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo0P00000M0?ooo`030000
003oool0oooo0140oooo0`00000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool2000000030?ooo`000000oooo02X0oooo00<000000?ooo`3oool03P3oool001X0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`8000002`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000007@3oool00`000000oooo0?oo
o`0>0?ooo`<000008P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P00000[0?ooo`030000003oool0oooo00h0oooo000J0?ooo`800000;`3oool0
0`000000oooo0?ooo`0C0?ooo`800000303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00X0oooo0P00000M0?ooo`030000003oool0oooo00`0oooo0`00000V0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000002/0oooo00<00000
0?ooo`3oool03P3oool001T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000001`0oooo00<000000?ooo`3oool02P3oool3000002X0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000030?ooo`800000;03oool00`000000oooo0?ooo`0=
0?ooo`006@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool2
000001d0oooo00<000000?ooo`3oool01P3oool4000002d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000020?ooo`<00000;03oool00`000000oooo0?ooo`0=0?ooo`006@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool20000
00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool00000
01`0oooo00<000000?ooo`3oool0103oool300000380oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=
0?ooo`006@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01@3oool2000000X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`8000007@3oool010000000oooo0?ooo`3oool3000003H0oooo00<000000?ooo`3oool0103oool2
000000030?ooo`00000000000080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0=
0?ooo`006@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0000000L0?ooo`030000003oool0000000800000>P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00d0oooo000I0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`090?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo0P00000K0?ooo`@00000?P3oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03@3oool001P0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`000000603oool3000000030?ooo`000000oooo03l0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool03@3oool001P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00d0oooo0P0000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool2000001H0oooo0`0000030?ooo`030000003oool0oooo0400oooo0P0000030?ooo`80
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0
oooo000H0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`8000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000004`3oool3000000H0oooo00<000000?ooo`3oool0@03oool200000080oooo
0P0000030?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`0<0?ooo`00
603oool200000340oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00D0oooo0P00000:0?ooo`030000003oool0oooo00H0oooo0P00000A0?ooo`<00000
203oool00`000000oooo0?ooo`110?ooo`050000003oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool0303oool001P0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo0P0000070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000=0?ooo`@0
00002`3oool00`000000oooo0?ooo`100?ooo`040000003oool0oooo0?ooo`8000001@3oool01000
0000oooo0?ooo`00000Z0?ooo`030000003oool0oooo00`0oooo000H0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`8000001P3oool20000
00L0oooo00<000000?ooo`3oool01@3oool2000000/0oooo0`00000>0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`000000:@3oool00`000000oooo0?ooo`0<0?ooo`00603oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000080?oo
o`<00000403oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0080oooo0`0000060?oo
o`040000003oool0oooo000002T0oooo00<000000?ooo`3oool0303oool001L0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo0P0000060?oo
o`800000103oool00`000000oooo0?ooo`040?ooo`8000001P3oool3000001<0oooo00<000000?oo
o`3oool0@03oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`00000Y0?ooo`030000003oool0oooo00`0oooo000G0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`8000001P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000000`3oool3000001D0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000002T0oooo00<000000?ooo`3oool0303oool001L0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo0P000005
0?ooo`80000000<0oooo0000003oool0103oool6000001P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000002T0oooo00<000000?ooo`3oool02`3oool001L0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo0P0000050?ooo`800000103oool3
000001/0oooo00<000000?ooo`3oool0@03oool01`000000oooo0?ooo`3oool000000?ooo`000000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000002T0oooo00<000000?ooo`3oool0
2`3oool001L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00`3oool7000001`0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000002T0oooo00<000000?ooo`3oool02`3oool001L0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo0P0000020?ooo`@0000000@0oooo
0000003oool000006`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo0P00
00090?ooo`070000003oool0oooo0?ooo`000000oooo0000000Y0?ooo`030000003oool0oooo00/0
oooo000F0?ooo`<00000<`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo
10000000103oool000000?ooo`3oool3000001`0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00H000000?ooo`3oool000000?ooo`00000Y
0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`<00000103oool200000080oooo00@000000?oo
o`00000000006P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo0P00000;
0?ooo`030000003oool0oooo00800000:P3oool00`000000oooo0?ooo`0;0?ooo`005P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool30000
00P0oooo10000000103oool000000?ooo`00000H0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool00P3oool2000000d0oooo00@000000?ooo`0000000000:P3oool00`000000oooo0?oo
o`0;0?ooo`005P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0703oool3000000/0oooo00<000000?ooo`3oool00P0000030?ooo`8000005P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`<00000:`3oool0
0`000000oooo0?ooo`0:0?ooo`005P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool06@3oool3000000h0oooo00@000000?ooo`000000oooo0`000003
0?ooo`8000004`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03`3oool2000002/0oooo00<000000?ooo`3oool02P3oool001H0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo1000000A0?oo
o`040000003oool00000000000<0oooo0P0000030?ooo`8000004@3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool2000002/0oooo00<00000
0?ooo`3oool02P3oool001H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01<0oooo0`00000E0?ooo`040000003oool00000000000D0oooo0P000003
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`03
0?ooo`8000004P3oool2000002/0oooo00<000000?ooo`3oool02P3oool001D0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo0`00000H0?oo
o`80000000<0oooo0000003oool01P3oool200000080oooo0P00000<0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool00`3oool2000001<0oooo0`00000Z0?ooo`030000003oool0oooo
00X0oooo000E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0=0?ooo`<000006`3oool3000000X0oooo0P0000020?ooo`8000002P3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo0P00000D0?ooo`040000003oool0oooo0000
02T0oooo00<000000?ooo`3oool02P3oool001D0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo1000000N0?ooo`<00000303oool300000003
0?ooo`000000oooo00L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo
00X0oooo000E0?ooo`<00000>03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo0`00000R0?ooo`030000003oool0000000l0oooo100000060?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`8000000`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030?oOW01807@0_ooo00L0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
0`00000U0?ooo`8000004P3oool4000000<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`040?ooo`8000005@3oool2000000@0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`090?ooo`002`3oool00`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`03000002P0oooo0P00000D0?ooo`D00000?@3o
ool00`000000oooo0?ooo`040?ooo`8000005@3oool2000000H0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`090?ooo`002`3oool00`3ogi`0B01d0;ooo`060?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool3000002/0oooo00<000000?ooo`3oool05@3oool4
000003/0oooo00<000000?ooo`3oool0103oool2000001H0oooo0P0000070?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool02@3oool000/0oooo00<0omnL04P0M02oool01P3oool00`00
0000oooo0?ooo`0k0?ooo`D0000000<0oooo0000003oool0:P3oool2000001P0oooo1@00000h0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool2000000T0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`3ogi`0B01d0;ooo`060?ooo`03
0000003oool0oooo03T0oooo100000040?ooo`030000003oool0oooo02T0oooo0P00000H0?ooo`04
0000003oool0oooo0?ooo`<00000=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00T0oooo000;0?ooo`030?oOW01807@0_ooo00H0oooo00<000000?ooo`3oool0=P3oool3000000@0
oooo00D000000?ooo`3oool0oooo0000000[0?ooo`8000005`3oool00`000000oooo0?ooo`040?oo
o`<00000<P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo00090?ooo`05
0;md000004P0W;nL04P0M02oool01P3oool00`000000oooo0?ooo`0c0?ooo`<000001`3oool01@00
0000oooo0?ooo`3oool0000002X0oooo0P00000G0?ooo`030000003oool0oooo00P0oooo0`00000^
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool000X0oooo00@0okmd0000
000007@0_ooo1P3oool00`000000oooo0?ooo`0`0?ooo`<000002`3oool010000000oooo0?ooo`00
000Z0?ooo`8000005`3oool00`000000oooo0?ooo`0:0?ooo`<00000:`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030?oOW01807@0_ooo00D0oooo00<00000
0?ooo`3oool0;@3oool4000000l0oooo00<000000?ooo`000000:P3oool2000001H0oooo00<00000
0?ooo`3oool03@3oool4000002L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F
0?ooo`800000403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000C0?oo
o`030000003oool0oooo02X0oooo0`00000D0?ooo`800000:@3oool3000001H0oooo00<000000?oo
o`3oool0403oool3000002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oo
o`8000004@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0oooo000C0?ooo`<0
00009`3oool3000001L0oooo00<000000?ooo`000000:03oool3000001D0oooo00<000000?ooo`3o
ool04`3oool300000240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`00
4`3oool00`000000oooo0?ooo`0T0?ooo`<000006`3oool2000002P0oooo0`00000D0?ooo`030000
003oool0oooo01L0oooo0`00000M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
203oool001<0oooo00<000000?ooo`3oool0803oool4000001l0oooo0P00000W0?ooo`030000003o
ool0000001@0oooo00<000000?ooo`3oool06@3oool3000001T0oooo0P0000060?ooo`8000006@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203o
ool001<0oooo00<000000?ooo`3oool07@3oool3000002@0oooo00<000000?ooo`3oool0903oool2
000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool07@3oool3000001D0oooo00<00000
0?ooo`3oool01@3oool2000001T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00P0oooo000C0?ooo`030000003oool0oooo01X0oooo0`00000W0?oo
o`030000003oool0oooo02@0oooo0P0000000`3oool000000?ooo`0A0?ooo`030000003oool0oooo
0240oooo0`00000A0?ooo`030000003oool0oooo00D0oooo0P00000I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`004P3oool00`000000
oooo0?ooo`0H0?ooo`<00000:`3oool00`000000oooo0?ooo`0S0?ooo`80000000<0oooo0000003o
ool04@3oool00`000000oooo0?ooo`0T0?ooo`<000003@3oool00`000000oooo0?ooo`050?ooo`80
00006@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01`3oool00180oooo00<000000?ooo`3oool05@3oool3000002h0oooo0P00000T0?ooo`040000
003oool0oooo00000140oooo00<000000?ooo`3oool09`3oool4000000T0oooo00<000000?ooo`3o
ool01@3oool2000001P0oooo0P00000N0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01`3oool00180oooo00<000000?ooo`3oool04@3oool400000380oooo0`00000R0?ooo`040000
003oool0oooo00000140oooo00<000000?ooo`3oool0:P3oool4000000D0oooo00<000000?ooo`3o
ool01@3oool2000001P0oooo0P00000P0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01`3oool00180oooo00<000000?ooo`3oool03P3oool3000003H0oooo00@000000?ooo`3oool0
0000803oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0^0?ooo`@0
000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0G0?ooo`8000008@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo000B0?ooo`030000003oool0oooo00/0oooo
0`00000j0?ooo`040000003oool0oooo000001l0oooo0P0000020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<@3oool4000000@0oooo0P00000I0?ooo`8000008`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo000B0?ooo`8000002@3oool3000003d0oooo
00@000000?ooo`3oool0oooo0P00000M0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00L00000603oool2000002H0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`070?ooo`004@3oool2000000L0oooo0`0000110?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`D000005P3oool20000
02P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`004@3oool00`000000
oooo0?ooo`020?ooo`@00000A@3oool2000000<0oooo00<000000?ooo`3oool06@3oool01@000000
oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?oo
o`8000000P3oool500000140oooo0`00000Z0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01P3oool00140oooo00<000000?ooo`0000000P00001;0?ooo`040000003oool0oooo0?oo
o`800000603oool2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00@0oooo0P0000050?ooo`H00000303oool3000002`0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`060?ooo`004@3oool2000004l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0E0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02h0oooo0P0000050?ooo`8000002P3oool5000000T0oooo0P00000_0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00180oooo0P00001?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool2000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo0P00000>0?ooo`@00000
1@3oool300000340oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`00503o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0080oooo0P00000D0?ooo`8000000`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3o
ool3000001<0oooo1P00000d0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00<000000?ooo`000000C@3oool2000000@0oooo0P00000B0?ooo`8000000`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo0P0000050?ooo`8000005P3oool4
000003D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`005P3oool20000
04l0oooo00<000000?ooo`3oool00`3oool200000100oooo0P0000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`<00000503oool50000
0080oooo0`00000c0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool001P0
oooo00<000000?ooo`3oool0C@3oool2000000D0oooo0`00000=0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Y0?ooo`8000001@3oool2000001@0
oooo0P0000000`3oool000000000000k0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool001T0oooo0P00001?0?ooo`8000001P3oool2000000/0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
0`3oool300000180oooo0`0000000`3oool000000000000n0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool01@3oool001/0oooo00D000000?ooo`3oool0oooo0000001<0?ooo`800000
1P3oool2000000T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02L0oooo0P0000040?ooo`<000004@3oool700000440oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`050?ooo`00703oool00`000000oooo0000001?0?ooo`8000001P3o
ool3000000L0oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`030?ooo`8000004@3oool5000004D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`050?ooo`007@3oool200000540oooo0P0000070?ooo`8000001@3oool2
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0080oooo0`00000?0?ooo`D00000B@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo000O0?ooo`030000003oool0oooo0500oooo0P0000070?ooo`@0000000D0oooo0000
00000000oooo0000000:0?ooo`030000003oool0oooo02@0oooo0P0000030?ooo`<000003@3oool6
000004d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`00803oool20000
0580oooo0P0000090?ooo`D000002P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0080oooo0`00000:0?ooo`H00000DP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00D0oooo000R0?ooo`030000003oool0oooo0540oooo100000060?ooo`80000000<0oooo00000000
00000`0000060?ooo`030000003oool0oooo0240oooo0P0000030?ooo`<00000203oool6000005L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`008`3oool00`000000oooo
0?ooo`1D0?ooo`D0000000<0oooo0000003oool00P0000040?ooo`D0000000<0oooo0000003oool0
803oool2000000<0oooo0`0000050?ooo`H00000G03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00@0oooo000T0?ooo`<00000F03oool5000000T0oooo1`00000J0?ooo`8000000`3o
ool3000000<0oooo1P00001Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103o
ool002H0oooo00<000000?ooo`3oool0F@3oool6000000D0oooo00<000000?ooo`3oool0103oool:
000000h0oooo3P00001W0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool0
02L0oooo0P00001J0?ooo`030000003oool0oooo0080oooo3@0000090?oooa@00000L03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`030000003oool0oooo05L0
oooo0P0000080?ooo`030000003oool0oooo00D0oooo4@0000020?ooo`8000000`3oool300000780
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`00:P3oool00`000000oooo
0?ooo`1F0?ooo`800000203oool00`000000oooo0?ooo`0F0?ooo`8000000`3oool3000007D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`006`3oool01@3oohl0=@000000
000055l0a?oo00/0oooo0P0000000`3oool000000?ooo`1C0?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool0503oool2000000<0oooo0`00001h0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool001X0oooo00H0ooo405lD000DGl@0oooo0<AO5000=Hl=0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo0180
oooo0P0000030?ooo`<00000N`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo000J0?ooo`070?ooS`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0=0?ooo`800000D`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooo`80000000<0oooo0000
000000000P00001o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool001X0
oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo00l0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`0<0?ooo`H00000P`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000J0?ooo`070?n?=@0055l0a?oo
0?ooo`3oohl0=@0D05o4o`0@0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01P3o
ool7000000P0oooo1@0000270?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool001X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo0140oooo0P0000000`3oool00000
0?ooo`1<0?ooo`030000003oool0oooo00P0oooo3P00002<0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool001X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01<0
oooo0P00001=0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`006P3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaD0oooo0P00001<0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`006`3oool01@3oohl0=@000000000055l0a?oo01L0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003P0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool003T0oooo0P0000000`3oool000000?ooo`150?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`00>`3o
ool2000004H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo000l0?ooo`800000A@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool003h0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2X0?ooo`050000003oool0oooo0?ooo`000000103oool003l0oooo00D000000?oo
o`3oool0oooo0000000o0?ooo`030000003oool0oooo0:T0oooo00@000000?ooo`3oool00000103o
ool00400oooo0P0000000`3oool000000?ooo`0n0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`000000103oool00480oooo0P00000o0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`0000000`3oool004<0oooo0P00000n0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`00
00000`3oool004D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2/0?ooo`800000
0`3oool004H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2/0?ooo`<000000`3o
ool004L0oooo0P0000000`3oool000000?ooo`0f0?ooo`030000003oool0oooo0:P0oooo10000006
0?ooo`00B@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0:@0oooo1000000:0?oo
o`00BP3oool2000003H0oooo00<000000?ooo`3oool0X03oool4000000h0oooo001<0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0V`3oool500000180oooo001=0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0U`3oool4000001L0oooo001>0?ooo`<00000<@3oool0
0`000000oooo0?ooo`2C0?ooo`@000006`3oool003X0oooo00/0oon?03D00000000001AO0<Coo`3o
ool0olAO01@0=@2?ool0oooo0<AO5002000000030000501Oa?l0oooo00H0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`2?0?ooo`@000007`3oool003T0oooo00H0ooo405lD000DGl@0
oooo0<AO5000=Hl40?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08ooo`070?ooo`800000;`3o
ool00`000000oooo0?ooo`2:0?ooo`D000008`3oool003T0oooo00L0oon?03D0=@2?ool0oooo0?o4
G`0D03D0Sooo00P0oooo00<0ScD003F?o`3oool0203oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo08H0oooo1000000X0?ooo`00>@3oool01`3oa5l051AO0<Coo`3oool0oon?03D0501O
a?l0203oool00`2?=@00=Hoo0?ooo`090?ooo`030000003oool0000002/0oooo00<000000?ooo`3o
ool0PP3oool4000002`0oooo000i0?ooo`070?n?=@0055l0a?oo0?ooo`3oohl0=@0D05o4o`030?oo
o`070?o4G`0D01@0GlCo0?ooo`3ool@0Ga@D05o4o`0;0?ooo`800000:`3oool00`000000oooo0?oo
o`1n0?ooo`@00000<03oool003T0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo00<0oooo
00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0;0?ooo`800000:P3oool00`000000oooo
0?ooo`1j0?ooo`@00000=03oool003T0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo00<0
oooo00<0ooo405lD501Oa?l04P3oool2000002P0oooo00<000000?ooo`3oool0M@3oool5000003P0
oooo000i0?ooo`060?ooa01O5000=Hoo0?ooo`34Ga@003F?1@3oool00`2?=@00=Hoo0?ooo`0C0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0L@3oool4000003d0oooo000j0?ooo`05
0?ooS`0e00000000000DG`34ool01@3oool01P34Ga@00000000000000000000e08oooa40oooo00<0
00000?ooo`000000903oool00`000000oooo0?ooo`1]0?ooo`@00000@@3oool005`0oooo0P00000T
0?ooo`030000003oool0oooo06T0oooo100000150?ooo`00GP3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo06@0oooo1@0000190?ooo`00G`3oool200000080oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1P0?ooo`@00000CP3oool00640oooo00<000000?ooo`000000
7P3oool00`000000oooo0?ooo`1L0?ooo`@00000DP3oool00680oooo0P00000N0?ooo`030000003o
ool0oooo05P0oooo1000001F0?ooo`00H`3oool2000001d0oooo00<000000?ooo`3oool0D`3oool5
000005X0oooo001U0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C`3oool40000
05l0oooo001V0?ooo`8000006P3oool00`000000oooo0?ooo`1;0?ooo`@00000H`3oool006P0oooo
0P00000H0?ooo`030000003oool0oooo04L0oooo1000001W0?ooo`00J@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0480oooo1@00001[0?ooo`00JP3oool2000001H0oooo00<00000
0?ooo`3oool0?P3oool400000700oooo001/0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0>P3oool4000007@0oooo001]0?ooo`<000004@3oool00`000000oooo0?ooo`0g0?ooo`@0
0000N03oool006l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0b0?ooo`D00000
O03oool00680oooo00<0olAO01@0=@2?ool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo02h0oooo100000210?ooo`00HP3oool00`3oa5l0500e08ooo`0<0?ooo`8000003P3oool0
0`000000oooo0?ooo`0Z0?ooo`@00000Q@3oool00680oooo00<0olAO01@0=@2?ool03P3oool20000
00`0oooo00<000000?ooo`3oool09P3oool4000008T0oooo001R0?ooo`030?o4G`0D03D0Sooo00l0
oooo0P00000;0?ooo`030000003oool0oooo0280oooo1000002=0?ooo`00HP3oool00`3oa5l0500e
08ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool500000940oooo
001R0?ooo`030?o4G`0D03D0Sooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0I0?ooo`@00000UP3oool00600oooo00D0ScD00000501OSel0500e08ooo`0C0?ooo`<000001P3o
ool00`000000oooo0?ooo`0E0?ooo`@00000VP3oool00640oooo00@0ohle0000000003D0Sooo5@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo1000002N0?ooo`00HP3oool0
0`3oa5l0500e08ooo`0F0?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`D00000XP3oool0
07d0oooo00D000000?ooo`000000oooo0000000:0?ooo`@00000Y`3oool007h0oooo0P0000000`3o
ool000000?ooo`050?ooo`@00000Z`3oool007l0oooo0`0000020?ooo`@00000[`3oool00840oooo
0`00002c0?ooo`00o`3ooolh0?ooo`00o`3ooolh0?ooo`00o`3ooolh0?ooo`00o`3ooolh0?ooo`00
o`3ooolh0?ooo`00o`3ooolh0?ooo`00o`3ooolh0?ooo`00N@3oool02@3ogi`0B01d0;ooo`3oool0
omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo0;00oooo001i0?ooo`030?oOW018
07@0_ooo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo0;00oooo001i0?ooo`030?oO
W01807@0_ooo00T0oooo00<0_g@007Boo`3oool0[`3oool007T0oooo00<0omnL04P0M02oool02@3o
ool00`2oM000M;oo0?ooo`2_0?ooo`00N@3oool00`3ogi`0B01d0;ooo`040?ooo`070?oOW01804P0
W=oo0?ooo`3ooml0W4Q809cOo`2`0?ooo`00N@3oool00`3ogi`0B01d0;ooo`040?ooo`030?oo_`1d
000000000080000000<0M;oo0?ooo`3oool0[`3oool007L0oooo00D0_g@00000B02L_i`0B01d0;oo
o`040?ooo`030?oog`2LB4P0W=oo0;@0oooo001h0?ooo`040?noM0000000001d0;ooo`D0oooo00<0
_g@007Boo`3oool0/`3oool007T0oooo00<0omnL04P0M02oool01@3oool01P3OW4P0000000000000
0000001d0;oook00oooo003o0?ooocP0oooo003o0?ooocP0oooo003o0?ooocP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 310.625}, {327.563, 0}} -> {-0.0156978, -0.00674341, \
0.00456305, 0.00456305}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Matrix Variables", "Subsection"],

Cell[TextData[{
  "This is a matrix differential equation, whose solution is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["MatrixExp",
            "MR"], "[", " ", \(A, \ t\), " ", "]"}], TraditionalForm]]],
  ". "
}], "MathCaption"],

Cell[BoxData[
    \(\(A\  = \ \(-{{1, 2, 3}, \ {4, 5, 6}, \ {7, 8, 9}}\);\)\)], "Input",
  CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(NDSolve[\ \(X'\)[t] \[Equal] \ A\  . \ X[t]\  \[And] \ 
        X[0]\  \[Equal] \ IdentityMatrix[3], \ 
      X, \ {t, \ 0, \ 5}\ ]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"X", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 5.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(matrixExpA\  = \ X\  /. \ First[\ %\ ]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 5.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
Let us define a particular matrix norm and look at the differences.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogListPlot[\ 
        Table[\ Norm[\ 
            MatrixExp[\ A, \ t]\  - \ matrixExpA[\ t\ ]\ ], \ {t, \ 0, \ 
            5, \  .2}], \ PlotJoined\  \[Rule] \ True];\)\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    RowBox[{\(Graphics::"gptn"\), \(\(:\)\(\ \)\), "\<\"Coordinate \
\\!\\(Indeterminate\\) in \\!\\({1, Indeterminate}\\) is not a floating-point \
number. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Graphics::gptn\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[60]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.03663 1.2495 0.140376 [
[.02381 -0.0125 -4.21875 -10.9375 ]
[.02381 -0.0125 4.21875 0 ]
[.20696 -0.0125 -4.21875 -10.9375 ]
[.20696 -0.0125 4.21875 0 ]
[.39011 -0.0125 -6.4375 -10.9375 ]
[.39011 -0.0125 6.4375 0 ]
[.57326 -0.0125 -6.4375 -10.9375 ]
[.57326 -0.0125 6.4375 0 ]
[.75641 -0.0125 -6.4375 -10.9375 ]
[.75641 -0.0125 6.4375 0 ]
[.93956 -0.0125 -6.4375 -10.9375 ]
[.93956 -0.0125 6.4375 0 ]
[-0.0125 .12649 -34.25 -5.5625 ]
[-0.0125 .12649 0 5.5625 ]
[-0.0125 .26686 -34.25 -5.5625 ]
[-0.0125 .26686 0 5.5625 ]
[-0.0125 .40724 -34.25 -5.5625 ]
[-0.0125 .40724 0 5.5625 ]
[-0.0125 .54762 -32.875 -5.46875 ]
[-0.0125 .54762 0 5.46875 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20696 0 m
.20696 .00625 L
s
gsave
.20696 -0.0125 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.39011 0 m
.39011 .00625 L
s
gsave
.39011 -0.0125 -67.4375 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.57326 0 m
.57326 .00625 L
s
gsave
.57326 -0.0125 -67.4375 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.75641 0 m
.75641 .00625 L
s
gsave
.75641 -0.0125 -67.4375 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.93956 0 m
.93956 .00625 L
s
gsave
.93956 -0.0125 -67.4375 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.06044 0 m
.06044 .00375 L
s
.09707 0 m
.09707 .00375 L
s
.1337 0 m
.1337 .00375 L
s
.17033 0 m
.17033 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.31685 0 m
.31685 .00375 L
s
.35348 0 m
.35348 .00375 L
s
.42674 0 m
.42674 .00375 L
s
.46337 0 m
.46337 .00375 L
s
.5 0 m
.5 .00375 L
s
.53663 0 m
.53663 .00375 L
s
.60989 0 m
.60989 .00375 L
s
.64652 0 m
.64652 .00375 L
s
.68315 0 m
.68315 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.79304 0 m
.79304 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.8663 0 m
.8663 .00375 L
s
.90293 0 m
.90293 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12649 m
.00625 .12649 L
s
gsave
-0.0125 .12649 -95.25 -9.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.375 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
69.688 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.875 12.375 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.188 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
86.063 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
86.063 9.063 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
89.625 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
92.750 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .26686 m
.00625 .26686 L
s
gsave
-0.0125 .26686 -95.25 -9.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.375 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
69.688 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.875 12.375 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.188 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
86.063 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
86.063 9.063 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
89.625 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
92.750 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .40724 m
.00625 .40724 L
s
gsave
-0.0125 .40724 -95.25 -9.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.375 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
69.688 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
70.875 12.375 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.188 12.375 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
86.063 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
86.063 9.063 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
89.625 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
92.750 9.063 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 5.688 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54762 m
.00625 .54762 L
s
gsave
-0.0125 .54762 -93.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
91.875 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .02837 m
.00375 .02837 L
s
0 .05309 m
.00375 .05309 L
s
0 .07063 m
.00375 .07063 L
s
0 .08423 m
.00375 .08423 L
s
0 .09535 m
.00375 .09535 L
s
0 .10474 m
.00375 .10474 L
s
0 .11288 m
.00375 .11288 L
s
0 .12006 m
.00375 .12006 L
s
0 .16875 m
.00375 .16875 L
s
0 .19346 m
.00375 .19346 L
s
0 .211 m
.00375 .211 L
s
0 .22461 m
.00375 .22461 L
s
0 .23572 m
.00375 .23572 L
s
0 .24512 m
.00375 .24512 L
s
0 .25326 m
.00375 .25326 L
s
0 .26044 m
.00375 .26044 L
s
0 .30912 m
.00375 .30912 L
s
0 .33384 m
.00375 .33384 L
s
0 .35138 m
.00375 .35138 L
s
0 .36498 m
.00375 .36498 L
s
0 .3761 m
.00375 .3761 L
s
0 .3855 m
.00375 .3855 L
s
0 .39364 m
.00375 .39364 L
s
0 .40082 m
.00375 .40082 L
s
0 .4495 m
.00375 .4495 L
s
0 .47422 m
.00375 .47422 L
s
0 .49176 m
.00375 .49176 L
s
0 .50536 m
.00375 .50536 L
s
0 .51647 m
.00375 .51647 L
s
0 .52587 m
.00375 .52587 L
s
0 .53401 m
.00375 .53401 L
s
0 .54119 m
.00375 .54119 L
s
0 .58987 m
.00375 .58987 L
s
0 .61459 m
.00375 .61459 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09707 .29779 m
.1337 .04393 L
.17033 .01472 L
.20696 .06294 L
.24359 .14969 L
.28022 .29836 L
.31685 .10997 L
.35348 .20203 L
.39011 .29746 L
.42674 .31266 L
.46337 .30978 L
.5 .42232 L
.53663 .42918 L
.57326 .41716 L
.60989 .43088 L
.64652 .35934 L
.68315 .45553 L
.71978 .52078 L
.75641 .47358 L
.79304 .469 L
.82967 .53637 L
.8663 .5521 L
.90293 .57003 L
.93956 .56337 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[60]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00?P3oool01@3ookl0M00000000000B9`0gooo0400oooo00D0gia8000000000000001809cO
o`0n0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0k0?ooo`030?oO
W01807@0_ooo0080oooo00D0gia8000000000000001809cOo`0h0?ooo`030=nLB0000000000000<0
000000L0M;oo0?ooo`3ookl0M00000000000B9`0gooo03L0oooo00<0gia80000000000000`000000
0`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo0140oooo000m0?ooo`060?oog`2LB000B9cO
0?ooo`3OW4P007Bo?`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0?@3oool02P3ogi`0
B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000M;lk0?ooo`0;0?oOW01807@0_ooo0?ooo`3o
_g@004RL0=ooo`3oool0oooO09a8M02oool0=`3oool00`3ogi`0B00007Boo`040?ooo`060?oog`2L
B000B9cO0?ooo`3OW4P007Bo=`3oool00`3ogi`0B00007Boo`040?ooo`070?noM000B9`0gooo0?oo
o`3ooml0W4Qd0;ooo`0A0?ooo`00?@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0@`3o
ool00`2oM000M;oo0?ooo`0l0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool0>P3oool00`3ogi`0B01d0;ooo`060?ooo`030;md001d_ol0oooo03L0oooo00<0omnL
04P0001d_ol00`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0=`3oool00`3ogi`0B000
07Boo`080?ooo`030;md001d_ol0oooo0100oooo000m0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`130?ooo`030;md001d_ol0oooo03`0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`0j0?ooo`030?oOW01807@0_ooo00H0oooo00<0_g@007Boo`3oool0
>03oool00`3ookl0M00004RLg`020?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0h0?oo
o`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool0403oool003d0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo03h0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03d0oooo
00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0j0?ooo`0;0?oOW018
07@0_ooo0?ooo`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0>P3oool02`3ooml0W4P004RLg`3o
ool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo03T0oooo00/0oooO09a80018W=l0oooo0?oOW018
04P0W=oo0?ooo`3ooml0W4Q809cOo`0A0?ooo`00?@3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol0?P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo03`0oooo00/0omnL04P0
M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0j0?ooo`060?oOW01807@0_ooo0?oo
o`3ookl0M0000`0000000`1d_ol0oooo0?ooo`0j0?ooo`0:0?oo_`1d04P0W=oo0?oOW018B9`0gooo
0?ooo`3ookl0M01809cOocX0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0
oooo0100oooo000m0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0n0?ooo`030?oog`2L
B4P0W=oo03l0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW018
07@0_ooo03P0oooo00T0_g@00000B02L_i`0B01d0;ooo`3oool0oooO09a8B02Lgol0>`3oool00`3o
_g@007Bo0?ooo`020?ooo`090;md001d_ol0oono07@0M02oool0oooo0?oOW01807@0_ooo03H0oooo
00<0okmd001d_`3oool00P3oool01@2oM000M;oo0?oog`2LB4P0W=oo01D0oooo000m0?ooo`060?oo
g`2LB000M;oo0?ooo`3OW4P007Bo@03oool00`2oM000M;oo0?ooo`0o0?ooo`0;0?noM0000000001d
0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0>P3oool0103o_g@000000000M02oool20?oo
o`030;md001d_ol0oooo03X0oooo00d0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?oog`2LB000
M;oo0?ooo`3OW4P007Bo03L0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000
M;oo5@3oool003h0oooo00D0oono07@00000000004RL0=ooo`100?ooo`060=nLB000000000000000
000007@0_ooo?@3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0>`3o
ool00`3ogi`0B01d0;ooo`020?ooo`060=nLB000000000000000000007@0_ooo>03oool01@3ogi`0
B000000000000000M;oo0080oooo00D0oono07@00000000004RL0=ooo`0h0?ooo`050?oOW0180000
00000000001d_ol00P3oool01P3OW4P00000000000000000001d0;oooa40oooo003o0?oook40oooo
003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo
003o0?oook40oooo000h0?ooool00000N@00000003P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool003P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01`3oool003P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool003P0oooo00<0
00000?ooo`3oool0o`3ooomf0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooogH0oooo000h0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00>03oool00`000000
oooo0?ooo`0k0?ooo`030000003oool000000?l0oooo>03oool003P0oooo00<000000?ooo`3oool0
>P3oool01@000000oooo0?ooo`3oool000000?l0oooo=`3oool003P0oooo00<000000?ooo`3oool0
>03oool2000000@0oooo00<000000?ooo`3oool0o`3ooole0?ooo`00>03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00>03oool2
000003L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooc<0oooo000h0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
oc80oooo000h0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3o0?oooc80oooo000h0?ooo`030000003oool0oooo0380oooo0P00000>0?ooo`030000
003oool0oooo0?l0oooo<@3oool003P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0oooo<03oool003P0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo;`3oool003P0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo;P3oool003P0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0
oooo;P3oool003P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0?l0oooo;@3oool003P0oooo0P00000`0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0o`3oool/0?ooo`00>03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00>03oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00>03oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00
>03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
o`3ooolY0?ooo`00>03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0o`3ooolY0?ooo`00>03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00>03oool2000002l0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000h0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooobL0oooo000h0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooobL0oooo
000h0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3o0?ooobH0oooo000h0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`3o0?ooobH0oooo000h0?ooo`800000;P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0?l0oooo9P3oool003P0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo9@3oool003P0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo9@3oool003P0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo903o
ool003P0oooo0P00000]0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooolT
0?ooo`00>03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0o`3ooolS0?ooo`00>03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00>03oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00>03oool2000002d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooob80oooo000h0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0?l0oooo000h0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0oooo000h0?ooo`800000;03oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo0P00003o0?ooo`40oooo00060?ooo`0;0?oO
W01807@0_ooo0?ooo`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool00P3oool00`3ogi`0B4RL0=oo
o`050?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0C0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool000000?l0oooo0@3oool000H0oooo00<0omnL04P0M02oool01P3oool01P3ogi`0B4RL0=oo
o`3ogi`0B4RL0=ooo`H0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo
4`3oool2000002`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`040000
003oool0oooo00000?l0oooo00060?ooo`030?oOW01807@0_ooo00L0oooo00@0omnL04P00000B9`0
gooo1`3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo0180oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01/0oooo
00@000000?ooo`3oool00000o`3oool000H0oooo00<0omnL04P0M02oool01`3oool0103ogi`0B000
0018W03Oool70?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
4P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
6`3oool010000000oooo0?ooo`00003o0?ooo`001P3oool00`3ogi`0B01d0;ooo`060?ooo`060?oO
W018B9`0gooo0?oOW018B9`0gooo1P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo
0?oo_`1d04P0W=oo0180oooo0`00000Z0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool06`3oool01@000000oooo0?ooo`3oool000000?h0oooo00060?ooo`030?oOW01807@0_ooo00D0
oooo00<0omnL04Q8W03Oool00P3oool00`3ogi`0B4RL0=ooo`050?ooo`0;0?oOW01807@0_ooo0?oo
o`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000/0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01X0oooo00D000000?ooo`3oool0
oooo0000003n0?ooo`00103oool01@2oM000001809boW01807@0_ooo0100oooo00d0_g@00000B02L
_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?/0oooo00050?ooo`04
0?noM0000000001d0;oooa40oooo00`0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0
gia8001d_`3oool500000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?/0oooo00060?ooo`030?oOW01807@0_ooo0180oooo00<0omnL04P0M02o
ool00P3oool01@3ookl0M00000000000B9`0gooo00H0oooo0P00000;0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0n`3oool002X0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?X0oooo000Z0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3j0?ooo`00:`3oool2000000/0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3i0?ooo`00>03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0?T0oooo000h0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0n@3oool003P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3h
0?ooo`00>03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?P0oooo000h0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0m`3oool003P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3g0?ooo`00>03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0?L0oooo000h0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0mP3oool0
03P0oooo0P00000Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?H0oooo000h0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0m@3oool003P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`3e0?ooo`00>03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?D0oooo000h
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0m03oool003P0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3d0?ooo`00>03oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0?<0oooo000h0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
l`3oool003P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3c0?ooo`00>03oool2
000002P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0lP3oool003P0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`3b0?ooo`00>03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?40
oooo000h0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0l@3oool003P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`3a0?ooo`00>03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?00oooo000h0?ooo`8000009`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3`0?oo
o`00>03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0>l0oooo000h0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0k`3oool003P0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`3_0?ooo`00>03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0>h0oooo000h0?ooo`8000009P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3^0?ooo`00>03oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0>h0oooo000h0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0k@3oool003P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`3]0?ooo`00>03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>`0oooo000h0?oo
o`8000009@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`3/0?ooo`00>03oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0>`0oooo000h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
j`3oool003P0oooo0P00000U0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0>/0oooo000h0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0jP3oool003P0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3Z0?ooo`00>03oool2000002D0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0jP3oool003P0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3Y0?ooo`001P3oool02`3ogi`0B01d0;oo
o`3oool0omnL04P0M02oool0oooo0?oOW018B9`0gooo0080oooo00<0omnL04Q8W03Oool01@3oool0
0`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool04`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0>T0oooo00060?ooo`030?oOW01807@0_ooo00H0oooo00H0omnL
04Q8W03Oool0omnL04Q8W03Oool60?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0
gia8001d_a<0oooo0P00000T0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>P0oooo00060?ooo`030?oOW01807@0
_ooo00L0oooo00@0omnL04P00000B9`0gooo1`3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02o
ool0oooo0?oOW01807@0_ooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3X
0?ooo`001P3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW018000004RL0=ooo`L0oooo00/0omnL
04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0B0?ooo`<000008`3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`3X0?ooo`001P3oool00`3ogi`0B01d0;ooo`060?ooo`060?oOW018B9`0gooo0?oO
W018B9`0gooo1P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo
0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3W0?ooo`001P3oool00`3ogi`0
B01d0;ooo`050?ooo`030?oOW018B9`0gooo0080oooo00<0omnL04Q8W03Oool01@3oool02`3ogi`0
B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0>L0oooo00040?ooo`050;md0000
04P0W;nL04P0M02oool0403oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0?`3oool01@000000oooo0?ooo`3oool000000280oooo00<000000?ooo`3o
ool0i`3oool000D0oooo00@0okmd0000000007@0_ooo4@3oool0303o_g@000000000M02oool0oooo
0?oog`2LB000M;oo0?ooo`3OW4P007Bo0?ooo`@0000000<0oooo0000003oool02`3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3oool00000903oool00`00
0000oooo0?ooo`3V0?ooo`001P3oool00`3ogi`0B01d0;ooo`0B0?ooo`030?oOW01807@0_ooo0080
oooo00D0oono07@00000000004RL0=ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000002@0oooo00<00000
0?ooo`3oool0iP3oool002`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo03l0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`3U
0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0@03oool00`000000oooo0000000U0?ooo`030000003oool0oooo0>D0oooo000Z0?ooo`@0
00002P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0400oooo00<000000?ooo`00
00009@3oool00`000000oooo0?ooo`3U0?ooo`00>03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`3T0?ooo`00>03o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0440oooo0P00000W0?ooo`030000003o
ool0oooo0>@0oooo000h0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0><0oooo000h0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0V0?ooo`800000i03oool003P0
oooo00<000000?ooo`3oool0T@3oool300000>40oooo000h0?ooo`030000003oool0oooo09@0oooo
0P00003O0?ooo`00>03oool00`000000oooo0?ooo`2F0?ooo`<00000g03oool003P0oooo0P00002J
0?ooo`<00000203oool700000<X0oooo000h0?ooo`030000003oool0oooo09`0oooo200000060?oo
o`030000003oool0oooo0<P0oooo000h0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool0a`3oool003P0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`370?ooo`00>03o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0<L0oooo000h0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool0aP3oool003P0oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`360?ooo`00>03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0<H0
oooo000h0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0a@3oool003P0oooo0P00
002^0?ooo`030000003oool0oooo0<D0oooo000h0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0a@3oool003P0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`340?oo
o`00>03oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0<@0oooo000h0?ooo`030000
003oool0oooo0:h0oooo00<000000?ooo`3oool0a03oool003P0oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`330?ooo`00>03oool00`000000oooo0?ooo`2_0?ooo`030000003oool0
oooo0<<0oooo000h0?ooo`800000/03oool00`000000oooo0?ooo`330?ooo`00>03oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo0<80oooo000h0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0`P3oool003P0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo08<0oooo000h0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool0>P3oool2000008D0oooo000h0?ooo`800000/P3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0000008@0oooo000h0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3o
ool0>@3oool010000000oooo0?ooo`0000240?ooo`00>03oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo000000230?ooo`00>03oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`210?ooo`00>03oool200000;<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0840oooo000h0?ooo`030000003oool0oooo0;80oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0800oooo000h
0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0800oooo000h0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0800oooo000h0?ooo`80
0000]03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0O`3oool003P0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0O`3oool003P0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3o
ool003P0oooo0P00002e0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1n0?ooo`00>03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1n0?ooo`001P3oool02`3ogi`0
B01d0;ooo`3oool0omnL04P0M02oool0oooo0?oOW018B9`0gooo0080oooo00<0omnL04Q8W03Oool0
1@3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool04`3oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1m0?ooo`001P3oool00`3ogi`0B01d0;ooo`060?ooo`060?oOW018B9`0gooo0?oOW018
B9`0gooo1P3oool02P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000M;lC0?ooo`80
0000]P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0O@3oool000H0oooo00<0omnL04P0M02oool01`3oool0103ogi`0B0000018W03Oool70?ooo`0;
0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool04P3oool00`000000oooo
0?ooo`2f0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1l0?ooo`001P3oool00`3ogi`0B01d0;ooo`070?ooo`040?oOW018000004RL0=ooo`L0oooo
00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0B0?ooo`<00000]P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03o
ool000H0oooo00<0omnL04P0M02oool01P3oool01P3ogi`0B4RL0=ooo`3ogi`0B4RL0=ooo`H0oooo
00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0B0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo07`0oooo00060?ooo`030?oOW01807@0_ooo00D0oooo00<0omnL04Q8W03Oool00P3oool0
0`3ogi`0B4RL0=ooo`050?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol01@3oool2000000/0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N`3oool000@0oooo00D0_g@00000B02L
_i`0B01d0;ooo`0@0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N`3oool0
00D0oooo00@0okmd0000000007@0_ooo4@3oool0303o_g@000000000M02oool0oooo0?oog`2LB000
M;oo0?ooo`3OW4P007Bo0?ooo`D000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0;L0oooo00<000000?ooo`3oool06@3oool3000000h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1j0?ooo`001P3oool00`3ogi`0B01d0;ooo`0B0?ooo`030?oOW01807@0_ooo
0080oooo00D0oono07@00000000004RL0=ooo`050?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0^03oool00`000000oooo0?ooo`0D0?ooo`@000000`3oool2000000/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1j0?ooo`00:P3oool3000000/0oooo00<00000
0?ooo`3oool0^03oool400000100oooo0`0000090?ooo`<00000203oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo07X0oooo000Z0?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0_03oool7000000D0oooo1000000?0?ooo`<00000103oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo07T0oooo000[0?ooo`8000002`3oool00`000000oooo0?ooo`330?oo
o`D000005P3oool200000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1i0?oo
o`00>03oool00`000000oooo0?ooo`3P0?ooo`8000005`3oool00`000000oooo0?ooo`1i0?ooo`00
>03oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo07P0oooo000h0?ooo`030000003o
ool0oooo0?X0oooo00<000000?ooo`3oool0N03oool003P0oooo00<000000?ooo`3oool0n`3oool0
0`000000oooo0?ooo`1g0?ooo`00>03oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo
07L0oooo000h0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0M`3oool003P0oooo
00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`1f0?ooo`00>03oool200000?d0oooo00<0
00000?ooo`3oool0MP3oool003P0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`1e
0?ooo`00>03oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo07D0oooo000h0?ooo`03
0000003oool0oooo0?h0oooo00<000000?ooo`3oool0M03oool003P0oooo00<000000?ooo`3oool0
oP3oool00`000000oooo0?ooo`1d0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooo`030000003o
ool0oooo07<0oooo000h0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0L`3oool0
03P0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo0200oooo1000001>0?oo
o`00>03oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool06@3oool7000000@0
oooo00<000000?ooo`3oool0B`3oool003P0oooo0P00003o0?ooo`<0oooo00<000000?ooo`3oool0
503oool4000000/0oooo00<000000?ooo`3oool0B`3oool003P0oooo00<000000?ooo`3oool0o`3o
ool20?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1:0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04X0oooo000h0?ooo`030000003oool0oooo
0?l0oooo0`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0B@3oool003P0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`190?ooo`00>03oool00`000000oooo
0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04P0oooo000h0?ooo`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0B03oool003P0oooo0P00003o
0?ooo`H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04L0oooo000h0?ooo`030000003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0AP3oool003P0oooo00<000000?ooo`3o
ool0o`3oool60?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`160?ooo`00>03oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04D0oooo000h0?ooo`030000003o
ool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0A@3oool003P0oooo0P00003o0?ooo`T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04@0oooo000h0?ooo`030000003oool0oooo
0?l0oooo203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0A03oool003P0oooo00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`130?ooo`00>03oool00`000000oooo
0?ooo`3o0?ooo`T0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo0480
oooo000h0?ooo`800000o`3oool;0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3o
ool0@P3oool003P0oooo00<000000?ooo`3oool0o`3oool:0?ooo`030000003oool0000002D0oooo
00<000000?ooo`3oool0@@3oool003P0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@@3oool003P0oooo0P00003o0?oooc@0oooo00<00000
0?ooo`3oool0@03oool003P0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0oooo
0400oooo000h0?ooo`030000003oool0oooo0?l0oooo=03oool00`000000oooo0?ooo`0o0?ooo`00
>03oool200000?l0oooo=@3oool00`000000oooo0?ooo`0o0?ooo`00>03oool00`000000oooo0?oo
o`3o0?ooocD0oooo0P00000o0?ooo`001P3oool03`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0
B01d0;ooo`3oool0oono07@00000000004RL0=ooo`020?ooo`050?oo_`1d000000000018W03Oool0
0P3oool01@3ookl0M00000000000B9`0gooo0080oooo00D0oono07@00000000004RL0=ooo`040?oo
o`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000?@3oool000D0
oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`0K0?oog`2LB000B9cO0?ooo`3OW4P007Bo
0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`3oool0oooO09a80018W=l0oooo0=nLB000M;l0oooo
0?oog`2LB000B9cO0?ooo`3OW4P007Bo00@0oooo00<0omnL04P0M02oool01`3oool200000?l0oooo
>P3oool2000003/0oooo00050?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`0L
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0oono
07@0M02oool0oooo0?oOW01807@0_ooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`<0oooo00<0
omnL04P0M02oool01`3oool00`000000oooo0?ooo`3o0?oooc/0oooo0P00000i0?ooo`001@3oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool0703ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol30?ooo`030?oOW01807@0_ooo00L0oooo00<00000
0?ooo`3oool0o`3ooolm0?ooo`800000=`3oool000D0oooo00L0okmd0018W03Oool0oooo0?oo_`1d
04P0W=oo00<0oooo01`0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0?noM000B9`0gooo0?ooo`3o
okl0M01809cOo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0okmd0018W03Oool0oooo0?oo_`1d
04P0W=oo0`3oool00`3ogi`0B01d0;ooo`070?ooo`<00000o`3ooolo0?ooo`800000=@3oool000D0
oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo01`0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0`3oool00`3ogi`0B01d0;ooo`070?ooo`03
0000003oool0oooo0?l0oooo@@3oool2000003<0oooo00050?ooo`070?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`030?ooo`0R0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool0oono07@0M02oool0oooo0?oOW01807@0_ooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`3oool0_g@00000B02L_i`0B01d0;ooo`L0oooo00<000000?ooo`3oool0o`3ooom3
0?ooo`800000<@3oool000D0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0K0?oog`2L
B000M;oo0?ooo`3OW4P007Bo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`3oool0oooO09a8001d
_ol0oooo0=nLB000M;l0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00<0oooo00@0okmd00000000
07@0_ooo1`3oool00`000000oooo0?ooo`3o0?ooodD0oooo0P00000_0?ooo`001P3oool01@3ookl0
M00000000000B9`0gooo00D0oooo00D0oono07@00000000004RL0=ooo`020?ooo`050?oo_`1d0000
00000018W03Oool00P3oool01@3ookl0M00000000000B9`0gooo0080oooo00D0oono07@000000000
04RL0=ooo`040?ooo`030?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooom70?ooo`80
0000;@3oool003P0oooo00<000000?ooo`3oool0o`3ooom90?ooo`8000004@3oool3000001L0oooo
000h0?ooo`030000003oool0oooo0?l0ooooB`3oool2000000/0oooo100000030?ooo`030000003o
ool0oooo01@0oooo000h0?ooo`030000003oool0oooo0?l0ooooC@3oool2000000@0oooo1@000008
0?ooo`030000003oool0oooo01<0oooo000h0?ooo`030000003oool0oooo0?l0ooooC`3oool40000
00h0oooo00<000000?ooo`3oool04P3oool003P0oooo00<000000?ooo`3oool0o`3ooomR0?ooo`03
0000003oool0oooo0140oooo000h0?ooo`030000003oool0oooo0?l0ooooH`3oool00`000000oooo
0?ooo`0@0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool03`3o
ool003P0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo00h0oooo000h0?oo
o`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0>0?ooo`00>03oool00`000000
oooo0?ooo`3o0?ooofH0oooo00<000000?ooo`3oool03@3oool003P0oooo0P00003o0?ooofP0oooo
00<000000?ooo`3oool0303oool003P0oooo00<000000?ooo`3oool0o`3ooomX0?ooo`030000003o
ool0oooo00/0oooo000h0?ooo`030000003oool0oooo0?l0ooooJ@3oool00`000000oooo0?ooo`0:
0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooofX0oooo00<000000?ooo`3oool02@3oool003P0
oooo00<000000?ooo`3oool0o`3ooom[0?ooo`030000003oool0oooo00P0oooo000h0?ooo`030000
003oool0oooo0?l0ooooK03oool00`000000oooo0?ooo`070?ooo`00>03oool00`000000oooo0?oo
o`3o0?ooogH0oooo000h0?ooo`030000003oool0oooo0?l0ooooMP3oool003P0oooo00<000000?oo
o`3oool0o`3ooomf0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooogH0oooo000h0?ooo`800000
o`3ooomg0?ooo`00>03oool00`000000oooo0?ooo`3o0?ooogH0oooo003o0?oook40oooo003o0?oo
ok40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-4.73215, -9.42594, \
0.109219, 0.0284999}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: Differential Algebraic Equations \[Dash] Basic\
\>", "Subsection"],

Cell[TextData[{
  "In the following example we have one differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`x' \((t)\) = x(t) + 2 \( y(t)\)\)]],
  " and one explicit algebraic equation ",
  Cell[BoxData[
      \(TraditionalForm\`0 = \ x(t) + y(t)\)]],
  ". Notice how, in this case, we only give one initial value equation ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 1\)]],
  ". The initial value equation for ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\)]],
  " is implicitly determined by the algebraic equation. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NDSolve", "[", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], 
            "\[Equal]", \(x[t] + 2\ y[t]\)}], 
          "\[And]", \(0 \[Equal] x[t] + y[t]\), 
          "\[And]", \(x[0] \[Equal] 1\)}], ",", \({x, y}\), 
        ",", \({t, 0, 1}\)}], "]"}]], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"x", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{"y", "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\ 
        Evaluate[\ {x[t], \ y[t]}\  /. \ First[\ %\ ]\ ], \ {t, \ 0, \ 
          1}];\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[.21429 .29652 -7.5625 -10.9375 ]
[.21429 .29652 7.5625 0 ]
[.40476 .29652 -7.5625 -10.9375 ]
[.40476 .29652 7.5625 0 ]
[.59524 .29652 -7.5625 -10.9375 ]
[.59524 .29652 7.5625 0 ]
[.78571 .29652 -7.5625 -10.9375 ]
[.78571 .29652 7.5625 0 ]
[.97619 .29652 -4.21875 -10.9375 ]
[.97619 .29652 4.21875 0 ]
[.01131 .01472 -13.9375 -5.46875 ]
[.01131 .01472 0 5.46875 ]
[.01131 .16187 -20.625 -5.46875 ]
[.01131 .16187 0 5.46875 ]
[.01131 .45617 -15.125 -5.46875 ]
[.01131 .45617 0 5.46875 ]
[.01131 .60332 -8.4375 -5.46875 ]
[.01131 .60332 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
gsave
.21429 .29652 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .30902 m
.40476 .31527 L
s
gsave
.40476 .29652 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .30902 m
.59524 .31527 L
s
gsave
.59524 .29652 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .30902 m
.78571 .31527 L
s
gsave
.78571 .29652 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
gsave
.01131 .01472 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .16187 m
.03006 .16187 L
s
gsave
.01131 .16187 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .59162 L
.10458 .57939 L
.14415 .56838 L
.18221 .55822 L
.22272 .54785 L
.26171 .53827 L
.30316 .5285 L
.34309 .51949 L
.3815 .51117 L
.42237 .50268 L
.46172 .49484 L
.49955 .4876 L
.53984 .48021 L
.57861 .47338 L
.61984 .46642 L
.65954 .45999 L
.69774 .45405 L
.73838 .44799 L
.77751 .4424 L
.81909 .4367 L
.85916 .43144 L
.89771 .42658 L
.93871 .42163 L
.97619 .41728 L
s
.02381 .01472 m
.06244 .02642 L
.10458 .03865 L
.14415 .04965 L
.18221 .05981 L
.22272 .07019 L
.26171 .07977 L
.30316 .08953 L
.34309 .09854 L
.3815 .10686 L
.42237 .11535 L
.46172 .12319 L
.49955 .13043 L
.53984 .13783 L
.57861 .14466 L
.61984 .15162 L
.65954 .15805 L
.69774 .16398 L
.73838 .17004 L
.77751 .17563 L
.81909 .18133 L
.85916 .18659 L
.89771 .19145 L
.93871 .1964 L
.97619 .20075 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo
000S0?ooo`030000003oool0oooo0?l0ooooR`3oool001P0oooo00<0omnL04P0M02oool0203oool0
0`000000oooo0?ooo`3o0?oooh/0oooo000H0?ooo`030?oOW01807@0_ooo00P0oooo00<000000?oo
o`3oool0o`3ooon;0?ooo`00603oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo0?l0
ooooR`3oool000d0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`020?ooo`030?oO
W01807@0_ooo00P0oooo1000003o0?ooohX0oooo000H0?ooo`030?oOW01807@0_ooo00P0oooo00<0
00000?ooo`0000000P00003o0?ooohT0oooo000H0?ooo`030?oOW01807@0_ooo00P0oooo00<00000
0?ooo`3oool00P3oool300000?l0ooooQP3oool001H0oooo00D0_g@00000B02L_i`0B01d0;ooo`08
0?ooo`030000003oool0oooo00D0oooo1000003o0?oooh80oooo000G0?ooo`040?noM0000000001d
0;ooo`P0oooo00<000000?ooo`3oool02@3oool300000?l0ooooO`3oool001P0oooo00<0omnL04P0
M02oool0203oool00`000000oooo0?ooo`0<0?ooo`<00000o`3oooml0?ooo`008`3oool00`000000
oooo0?ooo`0?0?ooo`@00000o`3ooomh0?ooo`008`3oool00`000000oooo0?ooo`0C0?ooo`<00000
o`3ooome0?ooo`008`3oool00`000000oooo0?ooo`0F0?ooo`<00000o`3ooomb0?ooo`008`3oool0
0`000000oooo0?ooo`0I0?ooo`@00000o`3ooom^0?ooo`008`3oool00`000000oooo0?ooo`0M0?oo
o`<00000o`3ooom[0?ooo`008`3oool00`000000oooo0?ooo`0P0?ooo`<00000o`3ooomX0?ooo`00
8`3oool3000002<0oooo0`00003o0?ooofD0oooo000S0?ooo`030000003oool0oooo02H0oooo1000
003o0?ooof40oooo000S0?ooo`030000003oool0oooo02X0oooo0`00003o0?oooeh0oooo000S0?oo
o`030000003oool0oooo02d0oooo0`00003o0?oooe/0oooo000S0?ooo`030000003oool0oooo0300
oooo1000003o0?oooeL0oooo000S0?ooo`030000003oool0oooo03@0oooo1000003o0?oooe<0oooo
000S0?ooo`030000003oool0oooo03P0oooo1000003o0?ooodl0oooo000S0?ooo`030000003oool0
oooo03`0oooo1000003o0?oood/0oooo000S0?ooo`030000003oool0oooo0400oooo1000003o0?oo
odL0oooo000S0?ooo`030000003oool0oooo04@0oooo1000003o0?oood<0oooo000S0?ooo`030000
003oool0oooo04P0oooo1000003o0?ooocl0oooo000S0?ooo`030000003oool0oooo04`0oooo1000
003o0?oooc/0oooo000S0?ooo`<00000D03oool400000?l0oooo=`3oool002<0oooo00<000000?oo
o`3oool0E03oool400000?l0oooo<`3oool002<0oooo00<000000?ooo`3oool0F03oool400000?l0
oooo;`3oool002<0oooo00<000000?ooo`3oool0G03oool500000?l0oooo:P3oool002<0oooo00<0
00000?ooo`3oool0H@3oool400000?l0oooo9P3oool002<0oooo00<000000?ooo`3oool0I@3oool4
00000?l0oooo8P3oool002<0oooo00<000000?ooo`3oool0J@3oool400000?l0oooo7P3oool002<0
oooo00<000000?ooo`3oool0K@3oool500000?l0oooo6@3oool002<0oooo00<000000?ooo`3oool0
LP3oool500000?l0oooo503oool002<0oooo00<000000?ooo`3oool0M`3oool600000?l0oooo3P3o
ool002<0oooo00<000000?ooo`3oool0O@3oool400000?l0oooo2P3oool002<0oooo00<000000?oo
o`3oool0P@3oool400000?l0oooo1P3oool002<0oooo0`0000250?ooo`@00000o`3oool20?ooo`00
8`3oool00`000000oooo0?ooo`290?ooo`@00000o@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool400000?T0oooo000S0?ooo`030000003oool0oooo0940oooo1P00003c0?ooo`008`3oool00`00
0000oooo0?ooo`2G0?ooo`H00000k@3oool002<0oooo00<000000?ooo`3oool0W@3oool500000>P0
oooo000S0?ooo`030000003oool0oooo0:80oooo1@00003S0?ooo`008`3oool00`000000oooo0?oo
o`2W0?ooo`H00000g@3oool002<0oooo00<000000?ooo`3oool0[@3oool500000=P0oooo000S0?oo
o`030000003oool0oooo0;80oooo1@00003C0?ooo`008`3oool00`000000oooo0?ooo`2g0?ooo`D0
0000cP3oool002<0oooo00<000000?ooo`3oool0_03oool500000<T0oooo000S0?ooo`<00000`@3o
ool500000<@0oooo000S0?ooo`030000003oool0oooo0<H0oooo1P00002n0?ooo`008`3oool00`00
0000oooo0?ooo`3<0?ooo`D00000^@3oool002<0oooo00<000000?ooo`3oool0d@3oool500000;@0
oooo000S0?ooo`030000003oool0oooo0=H0oooo1P00002^0?ooo`008`3oool00`000000oooo0?oo
o`3L0?ooo`D00000Z@3oool002<0oooo00<000000?ooo`3oool0h@3oool600000:<0oooo000S0?oo
o`030000003oool0oooo0>L0oooo1P00002M0?ooo`008`3oool00`000000oooo0?ooo`3]0?ooo`H0
0000U`3oool000`0oooo00/0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nL
B002000000030000B02Lgol0oooo00L0oooo00<000000?ooo`3oool0l`3oool8000008l0oooo000;
0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool01`3oool00`000000oooo0?ooo`3k0?ooo`L00000R03oool000/0oooo00L0oono07@0M02o
ool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3oool01P3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo1@0000230?ooo`000`3oool00`3ogi`0B00000000003000000090000M02oool0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01P3oool400000?l0oooo
1`3oool5000007h0oooo000;0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`07
0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`070?ooo`030000003oool0oooo0?l0oooo3@3oool7
000007L0oooo000;0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d
000000000080000000<0M;oo0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooa@0oooo2000
001_0?ooo`002`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q8
09cOo`0;0?ooo`030000003oool0oooo0?l0oooo703oool7000006P0oooo000;0?ooo`060?oog`2L
B000M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`0:0?ooo`030000003oool0oooo0?l0
oooo8`3oool5000006<0oooo000<0?ooo`050?oo_`1d000000000018W03Oool01@3oool01P3OW4P0
0000000000000000001d0;ooo`L0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`D00000GP3oool0
02<0oooo00<000000?ooo`3oool0o`3oool]0?ooo`L00000E`3oool002<0oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`P00000C`3oool002<0oooo00<000000?ooo`3oool0o`3oooll0?ooo`T00000
AP3oool002<0oooo00<000000?ooo`3oool0o`3ooom50?ooo`P00000?P3oool002<0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`P00000=P3oool002<0oooo00<000000?ooo`3oool0o`3ooomE0?oo
o`P00000;P3oool002<0oooo0`00003o0?oooed0oooo2000000V0?ooo`008`3oool00`000000oooo
0?ooo`3o0?ooofD0oooo2000000N0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooofd0oooo2000
000F0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooogD0oooo2000000>0?ooo`008`3oool00`00
0000oooo0?ooo`3o0?ooogd0oooo1000000:0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0
oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3o
oon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo
0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo
0?ooo`3o0?oooh/0oooo000S0?ooo`<00000o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o
0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3o
ool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003o
ool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo
00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S
0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo0`00003o0?oooh/0oooo000S0?ooo`03
0000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool0
02<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0
oooo000S0?ooo`030000003oool0oooo04<0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL
04P0M02oool0gia81@0000000`1d_ol0oooo0?ooo`0k0?ooo`090?oo_`1d000000000018W03Oool0
oooo0?oOW01807@0_ooo00<0oooo00<0oooO09a8001d_ol0?P3oool03`3ookl0M00000000000B9`0
gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@000000000001d0;ooo`0n0?ooo`0;0?oo_`1d0000
00000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3o_g@00P0000000`0004P0W=oo0?ooo`150?oo
o`030?oOW01807@0_ooo00P0oooo000S0?ooo`030000003oool0oooo0480oooo00H0oooO09a80018
W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo0400oooo00H0oooO09a80018W=l0oooo0=nL
B000M;l70?ooo`030?oog`2LB000M;oo03d0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l50?oo
o`060;md001d_ol0oooo0?oOW018B9`0gooo?03oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo00L0omnL04P0B02Lgol0oooo0?noM00007@0_ooo04D0oooo00<0omnL04P0M02oool0203oool0
02<0oooo00<000000?ooo`3oool0@P3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0103o
ool00`3ogi`0B00007Boo`0o0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`03
0=nLB0000000000000<0000000<0B9cO0?ooo`3oool0>P3oool01`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool00`3oool01`3ookl0M4RL0=ooo`3oool0oono07@0B02Lgol0?03oool01`3ookl0M01d
0;ooo`3oool0omnL04P0M02oool00`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0A@3o
ool00`3ogi`0B01d0;ooo`080?ooo`008`3oool00`000000oooo0?ooo`120?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO03h0oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo00H0omnL04Q8W03Oool0oooO09a8001d_olm0?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0l
0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0W=oo0?ooo`3o
_g@0001d0;ooo`150?ooo`030?oOW01807@0_ooo00P0oooo000S0?ooo`030000003oool0oooo0480
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00<0oooO09a80018W=l0?@3oool0
1`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0103oool01@3OW4P0B9cO0?oog`2LB000M;oo03d0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0001d_ol0oooo0?oO
W018B9`0gooo03`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00@0oooo00D0oono07@0
0000000004RL0=ooo`160?ooo`030?oOW01807@0_ooo00P0oooo000S0?ooo`<00000@P3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool00`3ookl0M01809cOo`0l0?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`040?ooo`050?oog`2LB4P0W=oO09a8001d_ol0?@3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool01P3ogi`0B4RL09ad00000000001809cOocd0
oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0oono07@0B02Lgol0oooo0=nL
B000B9`0gooo04D0oooo00<0omnL04P0M02oool0203oool002<0oooo00<000000?ooo`3oool0@P3o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`03
0;md001d_ol0oooo03/0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00@0omnL
04Q8M01dB000M;oo?@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ookl0
M01d0;ooo`100?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01d0;ooo`130?ooo`050;md000004P0W;nL04P0M02oool0203oool002<0oooo
00<000000?ooo`3oool0@P3oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00L0oono07@0
B02Lgol0oooo0?oOW01804P0W=oo03`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l70?ooo`03
0=nLB0000000M;oo03d0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`060;md001d_ol0
oooo0?noM000B9`0gooo?03oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00L0oono07@0
B02Lgol0oooo0=nLB000B9`0gooo04@0oooo00@0okmd0000000007@0_ooo203oool002<0oooo00<0
00000?ooo`3oool0@`3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P000000000
000007Boo`0n0?ooo`050?oo_`1d000000000018W03Oool01`3oool00`3ooml0W4P007Boo`0n0?oo
o`050?oo_`1d000000000018W03Oool01@3oool01@3ooml0W4P00000000004P0W=oo03h0oooo00D0
oono07@00000000004RL0=ooo`050?ooo`050?oOW018000000000000M02oool0AP3oool00`3ogi`0
B01d0;ooo`080?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003o
ool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo
00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S
0?ooo`030000003oool0oooo0?l0ooooR`3oool001X0ooooo`00002F00000040oooo000S0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`00
8`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
203oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o
0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3o
ool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003o
ool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`<00000o`3ooon;0?ooo`008`3oool00`000000oooo
0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<00000
0?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`03
0000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool0
02<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0
oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo0`00003o0?oooh/0oooo000S
0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?oo
o`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0oooo
R`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o
0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3o
ool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`030000003o
ool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool30000
0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo
0?ooo`3o0?oooh/0oooo000S0?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<00000
0?ooo`3oool0o`3ooon;0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooh/0oooo000S0?ooo`03
0000003oool0oooo0?l0ooooR`3oool002<0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?ooogd0oooo1000000:0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooogD0oooo2000000>0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooofd0oooo2000000F0?oo
o`008`3oool00`000000oooo0?ooo`3o0?ooofD0oooo2000000N0?ooo`008`3oool300000?l0oooo
G@3oool8000002H0oooo000S0?ooo`030000003oool0oooo0?l0ooooE@3oool8000002h0oooo000S
0?ooo`030000003oool0oooo0?l0ooooC@3oool8000003H0oooo000S0?ooo`030000003oool0oooo
0?l0ooooA@3oool8000003h0oooo000S0?ooo`030000003oool0oooo0?l0oooo?P3oool7000004H0
oooo000S0?ooo`030000003oool0oooo0?l0oooo>03oool6000004d0oooo000S0?ooo`030000003o
ool0oooo0?l0oooo<P3oool6000005<0oooo000S0?ooo`030000003oool0oooo0?l0oooo;03oool6
000005T0oooo000S0?ooo`030000003oool0oooo0?l0oooo903oool8000005l0oooo000<0?ooo`0;
0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo
0?ooo`070?ooo`030000003oool0oooo0?l0oooo703oool8000006L0oooo000;0?ooo`060?oog`2L
B000B9cO0?ooo`3OW4P007Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01`3oool0
0`000000oooo0?ooo`3o0?oooa@0oooo2000001_0?ooo`002`3oool01`3ookl0M01d0;ooo`3oool0
omnL04P0M02oool0203oool00`2oM000M;oo0?ooo`060?ooo`030000003oool0oooo0?l0oooo3@3o
ool7000007L0oooo000;0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md
001d_ol0oooo00H0oooo1000003o0?ooo`L0oooo1@00001n0?ooo`002`3oool01`3o_g@004RL0=oo
o`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo1@0000230?ooo`002`3oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol00`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00H0oooo00<0
00000?ooo`3oool0o03oool6000008P0oooo000;0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`030?oog`2LB4P0W=oo00/0oooo00<000000?ooo`3oool0m03oool8000008h0oooo
000;0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`0:0?ooo`03
0000003oool0oooo0>d0oooo1`00002F0?ooo`00303oool01@3ookl0M00000000000B9`0gooo00D0
oooo00H0gia800000000000000000000M02oool70?ooo`030000003oool0oooo0>L0oooo1P00002M
0?ooo`008`3oool00`000000oooo0?ooo`3Q0?ooo`H00000X`3oool002<0oooo00<000000?ooo`3o
ool0g03oool500000:T0oooo000S0?ooo`030000003oool0oooo0=L0oooo1@00002^0?ooo`008`3o
ool00`000000oooo0?ooo`3A0?ooo`H00000/`3oool002<0oooo00<000000?ooo`3oool0c03oool5
00000;T0oooo000S0?ooo`030000003oool0oooo0<L0oooo1@00002n0?ooo`008`3oool300000<40
oooo1P0000330?ooo`008`3oool00`000000oooo0?ooo`2l0?ooo`D00000b@3oool002<0oooo00<0
00000?ooo`3oool0]`3oool500000<h0oooo000S0?ooo`030000003oool0oooo0;80oooo1@00003C
0?ooo`008`3oool00`000000oooo0?ooo`2]0?ooo`D00000f03oool002<0oooo00<000000?ooo`3o
ool0Z03oool500000=d0oooo000S0?ooo`030000003oool0oooo0:80oooo1P00003R0?ooo`008`3o
ool00`000000oooo0?ooo`2M0?ooo`D00000j03oool002<0oooo00<000000?ooo`3oool0U`3oool6
00000>d0oooo000S0?ooo`030000003oool0oooo0940oooo1P00003c0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`@00000n@3oool002<0oooo00<000000?ooo`3oool0R@3oool400000?d0oooo
000S0?ooo`<00000Q@3oool400000?l0oooo0P3oool002<0oooo00<000000?ooo`3oool0P@3oool4
00000?l0oooo1P3oool002<0oooo00<000000?ooo`3oool0O@3oool400000?l0oooo2P3oool002<0
oooo00<000000?ooo`3oool0N03oool500000?l0oooo3P3oool002<0oooo00<000000?ooo`3oool0
LP3oool600000?l0oooo4`3oool002<0oooo00<000000?ooo`3oool0K@3oool500000?l0oooo6@3o
ool002<0oooo00<000000?ooo`3oool0J@3oool400000?l0oooo7P3oool002<0oooo00<000000?oo
o`3oool0I@3oool400000?l0oooo8P3oool002<0oooo00<000000?ooo`3oool0H@3oool400000?l0
oooo9P3oool002<0oooo00<000000?ooo`3oool0G@3oool400000?l0oooo:P3oool002<0oooo00<0
00000?ooo`3oool0F@3oool400000?l0oooo;P3oool002<0oooo00<000000?ooo`3oool0E@3oool4
00000?l0oooo<P3oool002<0oooo0`00001A0?ooo`@00000o`3ooolf0?ooo`008`3oool00`000000
oooo0?ooo`1=0?ooo`@00000o`3ooolj0?ooo`008`3oool00`000000oooo0?ooo`190?ooo`@00000
o`3oooln0?ooo`008`3oool00`000000oooo0?ooo`150?ooo`@00000o`3ooom20?ooo`008`3oool0
0`000000oooo0?ooo`110?ooo`@00000o`3ooom60?ooo`008`3oool00`000000oooo0?ooo`0m0?oo
o`@00000o`3ooom:0?ooo`008`3oool00`000000oooo0?ooo`0j0?ooo`<00000o`3ooom>0?ooo`00
8`3oool00`000000oooo0?ooo`0g0?ooo`<00000o`3ooomA0?ooo`008`3oool00`000000oooo0?oo
o`0c0?ooo`@00000o`3ooomD0?ooo`008`3oool00`000000oooo0?ooo`0`0?ooo`<00000o`3ooomH
0?ooo`008`3oool00`000000oooo0?ooo`0]0?ooo`<00000o`3ooomK0?ooo`008`3oool00`000000
oooo0?ooo`0Y0?ooo`@00000o`3ooomN0?ooo`008`3oool3000002D0oooo1000003o0?ooof80oooo
000S0?ooo`030000003oool0oooo0240oooo1000003o0?ooofH0oooo000S0?ooo`030000003oool0
oooo01d0oooo1000003o0?ooofX0oooo000S0?ooo`030000003oool0oooo01T0oooo1000003o0?oo
ofh0oooo000S0?ooo`030000003oool0oooo01H0oooo0`00003o0?ooog80oooo000S0?ooo`030000
003oool0oooo01<0oooo0`00003o0?ooogD0oooo000S0?ooo`030000003oool0oooo00l0oooo1000
003o0?ooogP0oooo000S0?ooo`030000003oool0oooo00`0oooo0`00003o0?ooog`0oooo000S0?oo
o`030000003oool0oooo00T0oooo0`00003o0?ooogl0oooo000H0?ooo`030?oOW01807@0_ooo00P0
oooo00<000000?ooo`3oool01P3oool300000?l0ooooPP3oool001P0oooo00<0omnL04P0M02oool0
203oool00`000000oooo0?ooo`020?ooo`@00000o`3ooon50?ooo`00603oool00`3ogi`0B01d0;oo
o`080?ooo`030000003oool0000000800000o`3ooon90?ooo`00603oool00`3ogi`0B01d0;ooo`08
0?ooo`@00000o`3ooon:0?ooo`00603oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo
0?l0ooooR`3oool001P0oooo00<0omnL04P0M02oool0203oool00`000000oooo0?ooo`3o0?oooh/0
oooo000F0?ooo`050;md000004P0W;nL04P0M02oool0203oool00`000000oooo0?ooo`3o0?oooh/0
oooo000G0?ooo`040?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`00
603oool00`3ogi`0B01d0;ooo`080?ooo`030000003oool0oooo0?l0ooooR`3oool002<0oooo00<0
00000?ooo`3oool0o`3ooon;0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.0934104, -1.11632, \
0.0038924, 0.0125961}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: Partial Differential Equation \[Dash] Korteweg de Vries (2D) Soliton \
Collision\
\>", "Subsection"],

Cell[TextData[{
  "A soliton is a solitary wave that survives collisions with other solitary \
waves. The example below was used to coin the phrase ",
  StyleBox["soliton",
    FontSlant->"Italic"],
  ". They have since been used for long-haul optical fiber transmission \
systems, etc. "
}], "Text"],

Cell["\<\
This is the Korteweg  and de Vries equation in one spatial dimension.\
\>", "MathCaption"],

Cell[BoxData[
    \(KdV[{\[Alpha]_}, t_, 
        x_] := \[PartialD]\_t \[Psi][t, x] + \[Alpha]\ \[Psi][t, 
              x]\ \[PartialD]\_x \[Psi][t, x] + \[PartialD]\_{x, 3}\[Psi][t, 
              x] \[Equal] 0; \)], "Input",
  CellLabel->"In[88]:="],

Cell["This is a solitary wave solution to the KdV equation above.", \
"MathCaption"],

Cell[BoxData[
    \(\(S[{\[Alpha]_, \ c0_, \ x0_}, t_, \ 
          x_\ ]\  := \ \(3\ c0\)\/\[Alpha]\ \((Sech[\ \(\@c0\/2\) \((x - x0 - \
c0\ t)\)])\)\^2;\)\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
Since we are going to use periodic boundary condition we will add up all the \
period contributions so that we get the initial state.\
\>", "MathCaption"],

Cell[BoxData[
    \(\[CapitalPhi] = 
      S[{1, 3, 5}, 0, x] + S[{1, 3\/2, 15}, 0, x] + S[{1, 3, 5 + 40}, 0, x] + 
        S[{1, 3\/2, 15 + 40}, 0, x] + S[{1, 3, 5 - 40}, 0, x] + 
        S[{1, 3\/2, 15 - 40}, 0, x]; \)], "Input",
  CellLabel->"In[90]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[CapitalPhi] /. \[InvisibleSpace]x \[Rule] 
            0. )\) \[Equal] \((\[CapitalPhi] /. \[InvisibleSpace]x \[Rule] 
            40. )\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell["Here we can see how these solitary waves interact. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(s = 
          NDSolve[\ 
            KdV[{1}, \ t, \ 
                x]\  && \ \[Psi][0, x] \[Equal] \ \[CapitalPhi]\  && \ \[Psi][
                  t, 0] \[Equal] \ \[Psi][t, 40], \ \[Psi], \ {t, 0, \ 
              10}, \ {x, \ 0, \ 40}, \ 
            Method \[Rule] StiffnessSwitching];\)\  // Timing\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \({8.342`\ Second, Null}\)], "Output",
  CellLabel->"Out[92]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      Evaluate[\[Psi][t, x] /. \[InvisibleSpace]First[s]], {x, 0, 40}, {t, 0, 
        10}, PlotRange \[Rule] {0, 10}, PlotPoints \[Rule] 100, 
      Mesh \[Rule] False]; \)], "Input",
  CellLabel->"In[93]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
1.48536e-016 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -8.4375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -12.6592 -10.9375 ]
[.17646 .18758 .21579 0 ]
[.3345 .12542 -11.9881 -10.9375 ]
[.3345 .12542 .88687 0 ]
[.50253 .05935 -11.3171 -10.9375 ]
[.50253 .05935 1.55795 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 8.4375 3.32736 ]
[.76745 .09703 0 -7.48838 ]
[.76745 .09703 8.4375 3.44912 ]
[.82812 .18993 0 -7.37973 ]
[.82812 .18993 8.4375 3.55777 ]
[.88369 .27502 0 -7.28216 ]
[.88369 .27502 8.4375 3.65534 ]
[.93478 .35327 0 -7.19408 ]
[.93478 .35327 8.4375 3.74342 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.0179 .30404 -8.4375 -3.37266 ]
[.0179 .30404 0 7.56484 ]
[.01066 .34944 -8.4375 -3.41941 ]
[.01066 .34944 0 7.51809 ]
[.0032 .39618 -8.4375 -3.46769 ]
[.0032 .39618 0 7.46981 ]
[-0.00448 .44432 -8.4375 -3.51757 ]
[-0.00448 .44432 0 7.41993 ]
[-0.0124 .49393 -12.875 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -69.4375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -73.6592 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -72.9881 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -72.3171 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.75514 .10158 m
.74899 .10385 L
s
gsave
.76745 .09703 -61 -11.4884 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81573 .19425 m
.80953 .19642 L
s
gsave
.82812 .18993 -61 -11.3797 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.87123 .27915 m
.865 .28122 L
s
gsave
.88369 .27502 -61 -11.2822 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92227 .35722 m
.91601 .35919 L
s
gsave
.93478 .35327 -61 -11.1941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.03016 .29934 m
.03628 .29699 L
s
gsave
.0179 .30404 -69.4375 -7.37266 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02295 .34483 m
.02909 .34253 L
s
gsave
.01066 .34944 -69.4375 -7.41941 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.01552 .39167 m
.02169 .38942 L
s
gsave
.0032 .39618 -69.4375 -7.46769 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.00788 .43991 m
.01406 .43771 L
s
gsave
-0.00448 .44432 -69.4375 -7.51757 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -73.875 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.02837 .31059 m
.03205 .30919 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02111 .35641 m
.0248 .35504 L
s
.01926 .36808 m
.02295 .36671 L
s
.0174 .37983 m
.02109 .37847 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00981 .42772 m
.01352 .42639 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.709 .668 .807 r
.40213 .59857 .40514 .60316 .41038 .5995 .40734 .59577 Mtetra
.695 .7 .85 r
.40734 .59577 .41038 .5995 .41559 .59688 .41254 .59358 Mtetra
.683 .72 .877 r
.41254 .59358 .41559 .59688 .42079 .59479 .41774 .59171 Mtetra
.675 .731 .892 r
.41774 .59171 .42079 .59479 .42599 .59298 .42294 .58997 Mtetra
.669 .735 .899 r
.42294 .58997 .42599 .59298 .43119 .59129 .42815 .58832 Mtetra
.666 .737 .903 r
.42815 .58832 .43119 .59129 .43641 .58966 .43337 .58672 Mtetra
.665 .739 .905 r
.43337 .58672 .43641 .58966 .44163 .58804 .4386 .58513 Mtetra
.664 .741 .907 r
.4386 .58513 .44163 .58804 .44686 .58644 .44384 .58354 Mtetra
.665 .742 .908 r
.44384 .58354 .44686 .58644 .4521 .58487 .44909 .58195 Mtetra
.664 .741 .907 r
.44909 .58195 .4521 .58487 .45736 .58329 .45435 .58036 Mtetra
.664 .74 .907 r
.45435 .58036 .45736 .58329 .46262 .58171 .45962 .57877 Mtetra
.45962 .57877 .46262 .58171 .46789 .58011 .4649 .57718 Mtetra
.664 .741 .908 r
.4649 .57718 .46789 .58011 .47317 .57852 .47018 .57559 Mtetra
.664 .742 .908 r
.47018 .57559 .47317 .57852 .47847 .57693 .47548 .57398 Mtetra
.664 .741 .907 r
.47548 .57398 .47847 .57693 .48377 .57534 .48079 .57238 Mtetra
.664 .74 .907 r
.48079 .57238 .48377 .57534 .48908 .57374 .48611 .57078 Mtetra
.664 .741 .907 r
.48611 .57078 .48908 .57374 .49441 .57214 .49145 .56917 Mtetra
.663 .741 .908 r
.49145 .56917 .49441 .57214 .49974 .57053 .49679 .56757 Mtetra
.664 .742 .908 r
.49679 .56757 .49974 .57053 .50509 .56893 .50214 .56595 Mtetra
.664 .741 .907 r
.50214 .56595 .50509 .56893 .51044 .56732 .5075 .56433 Mtetra
.664 .74 .907 r
.5075 .56433 .51044 .56732 .51581 .5657 .51287 .56271 Mtetra
.664 .741 .907 r
.51287 .56271 .51581 .5657 .52118 .56408 .51826 .56109 Mtetra
.664 .741 .908 r
.51826 .56109 .52118 .56408 .52657 .56246 .52365 .55946 Mtetra
.664 .741 .907 r
.52365 .55946 .52657 .56246 .53197 .56084 .52905 .55783 Mtetra
.664 .74 .907 r
.52905 .55783 .53197 .56084 .53738 .55921 .53447 .55619 Mtetra
.664 .741 .907 r
.53447 .55619 .53738 .55921 .5428 .55758 .53989 .55456 Mtetra
.53989 .55456 .5428 .55758 .54822 .55594 .54533 .55292 Mtetra
.54533 .55292 .54822 .55594 .55366 .55431 .55078 .55128 Mtetra
.55078 .55128 .55366 .55431 .55912 .55267 .55623 .54963 Mtetra
.55623 .54963 .55912 .55267 .56458 .55102 .5617 .54798 Mtetra
.5617 .54798 .56458 .55102 .57005 .54938 .56718 .54633 Mtetra
.56718 .54633 .57005 .54938 .57553 .54773 .57267 .54468 Mtetra
.57267 .54468 .57553 .54773 .58103 .54607 .57817 .54301 Mtetra
.57817 .54301 .58103 .54607 .58653 .54442 .58369 .54135 Mtetra
.58369 .54135 .58653 .54442 .59205 .54276 .58921 .53969 Mtetra
.58921 .53969 .59205 .54276 .59757 .5411 .59474 .53802 Mtetra
.59474 .53802 .59757 .5411 .60311 .53943 .60029 .53635 Mtetra
.60029 .53635 .60311 .53943 .60866 .53776 .60584 .53467 Mtetra
.60584 .53467 .60866 .53776 .61422 .53609 .61141 .53299 Mtetra
.61141 .53299 .61422 .53609 .61979 .53441 .61699 .53131 Mtetra
.61699 .53131 .61979 .53441 .62537 .53273 .62258 .52962 Mtetra
.62258 .52962 .62537 .53273 .63096 .53105 .62818 .52793 Mtetra
.62818 .52793 .63096 .53105 .63657 .52937 .63379 .52624 Mtetra
.664 .74 .907 r
.63379 .52624 .63657 .52937 .64218 .52768 .63941 .52455 Mtetra
.664 .741 .907 r
.63941 .52455 .64218 .52768 .64781 .52598 .64505 .52286 Mtetra
.664 .741 .908 r
.64505 .52286 .64781 .52598 .65345 .52429 .65069 .52116 Mtetra
.663 .741 .908 r
.65069 .52116 .65345 .52429 .6591 .5226 .65635 .51946 Mtetra
.65635 .51946 .6591 .5226 .66476 .52092 .66202 .51776 Mtetra
.662 .74 .908 r
.66202 .51776 .66476 .52092 .67043 .51923 .6677 .51607 Mtetra
.661 .74 .908 r
.6677 .51607 .67043 .51923 .67612 .51753 .67339 .51439 Mtetra
.66 .741 .91 r
.67339 .51439 .67612 .51753 .68181 .51587 .6791 .51273 Mtetra
.658 .741 .912 r
.6791 .51273 .68181 .51587 .68753 .51425 .68482 .5111 Mtetra
.653 .74 .913 r
.68482 .5111 .68753 .51425 .69325 .51267 .69055 .50953 Mtetra
.646 .738 .916 r
.69055 .50953 .69325 .51267 .69899 .51115 .69631 .50807 Mtetra
.633 .737 .923 r
.69631 .50807 .69899 .51115 .70475 .50976 .70208 .50677 Mtetra
.61 .735 .934 r
.70208 .50677 .70475 .50976 .71054 .50862 .70788 .50573 Mtetra
.57 .728 .949 r
.70788 .50573 .71054 .50862 .71636 .50784 .71372 .50511 Mtetra
.487 .704 .965 r
.71372 .50511 .71636 .50784 .72223 .50764 .71962 .50519 Mtetra
.298 .629 .962 r
.71962 .50519 .72223 .50764 .72818 .50834 .7256 .50638 Mtetra
0 .385 .801 r
.7256 .50638 .72818 .50834 .73423 .51048 .7317 .50925 Mtetra
.604 .046 0 r
.7317 .50925 .73423 .51048 .74045 .51478 .738 .51456 Mtetra
.809 .325 .038 r
.738 .51456 .74045 .51478 .7469 .52208 .74455 .52317 Mtetra
.861 .441 .222 r
.74455 .52317 .7469 .52208 .75366 .5331 .7514 .53565 Mtetra
.869 .483 .305 r
.7514 .53565 .75366 .5331 .76072 .54778 .75855 .55138 Mtetra
.859 .482 .333 r
.75855 .55138 .76072 .54778 .76799 .56423 .7658 .56748 Mtetra
.82 .419 .291 r
.7658 .56748 .76799 .56423 .77513 .57798 .77277 .57873 Mtetra
.367 0 0 r
.77277 .57873 .77513 .57798 .78172 .5834 .77905 .57993 Mtetra
.894 .779 .727 r
.77905 .57993 .78172 .5834 .78745 .57732 .78449 .56976 Mtetra
.875 .683 .639 r
.78449 .56976 .78745 .57732 .79243 .56168 .7893 .55186 Mtetra
.858 .654 .626 r
.7893 .55186 .79243 .56168 .79703 .54187 .7939 .53188 Mtetra
.844 .646 .635 r
.7939 .53188 .79703 .54187 .80165 .52289 .79862 .514 Mtetra
.831 .65 .657 r
.79862 .514 .80165 .52289 .80651 .50733 .8036 .49988 Mtetra
.817 .661 .69 r
.8036 .49988 .80651 .50733 .81166 .4956 .80887 .48942 Mtetra
.799 .678 .73 r
.80887 .48942 .81166 .4956 .81707 .48706 .81437 .48186 Mtetra
.778 .696 .773 r
.81437 .48186 .81707 .48706 .82267 .48087 .82005 .47636 Mtetra
.754 .713 .814 r
.82005 .47636 .82267 .48087 .82842 .47628 .82585 .47223 Mtetra
.73 .725 .846 r
.82585 .47223 .82842 .47628 .83428 .47276 .83174 .46898 Mtetra
.709 .731 .869 r
.83174 .46898 .83428 .47276 .8402 .46992 .83769 .4663 Mtetra
.69 .734 .885 r
.83769 .4663 .8402 .46992 .84617 .46749 .84368 .46401 Mtetra
.672 .737 .898 r
.84368 .46401 .84617 .46749 .85219 .46536 .84972 .46205 Mtetra
.653 .74 .913 r
.84972 .46205 .85219 .46536 .85824 .4635 .85581 .46038 Mtetra
.621 .741 .933 r
.85581 .46038 .85824 .4635 .86434 .46196 .86195 .45914 Mtetra
.544 .729 .96 r
.86195 .45914 .86434 .46196 .87051 .46093 .86818 .45869 Mtetra
.305 .651 .97 r
.86818 .45869 .87051 .46093 .87678 .46078 .8746 .45973 Mtetra
.399 0 0 r
.8746 .45973 .87678 .46078 .88327 .46237 .88135 .46364 Mtetra
.804 .332 .103 r
.88135 .46364 .88327 .46237 .89016 .46732 .88873 .47292 Mtetra
.854 .479 .34 r
.88873 .47292 .89016 .46732 .89779 .47852 .89723 .49166 Mtetra
.851 .521 .428 r
.89723 .49166 .89779 .47852 .90671 .50042 .90746 .52477 Mtetra
.832 .525 .469 r
.90746 .52477 .90671 .50042 .91753 .53762 .91961 .57306 Mtetra
.79 .499 .495 r
.91961 .57306 .91753 .53762 .93012 .58826 .93206 .62212 Mtetra
.682 .412 .507 r
.93206 .62212 .93012 .58826 .94218 .63277 .94103 .64042 Mtetra
.786 .694 .151 r
.94103 .64042 .94218 .63277 .94976 .63922 .94429 .61124 Mtetra
.857 .601 .551 r
.94429 .61124 .94976 .63922 .95178 .60058 .94432 .55671 Mtetra
.787 .543 .567 r
.94432 .55671 .95178 .60058 .95151 .54502 .94472 .50676 Mtetra
.757 .525 .582 r
.94472 .50676 .95151 .54502 .95224 .4987 .94697 .47251 Mtetra
.743 .529 .604 r
.94697 .47251 .95224 .4987 .95489 .46831 .95087 .45189 Mtetra
.737 .549 .639 r
.95087 .45189 .95489 .46831 .95908 .45032 .95585 .43995 Mtetra
.732 .586 .692 r
.95585 .43995 .95908 .45032 .96424 .43992 .96146 .43287 Mtetra
.723 .631 .755 r
.96146 .43287 .96424 .43992 .96995 .43366 .96741 .42835 Mtetra
.699 .693 .841 r
.39908 .59467 .40213 .59857 .40734 .59577 .40428 .59236 Mtetra
.685 .714 .871 r
.40428 .59236 .40734 .59577 .41254 .59358 .40948 .59044 Mtetra
.675 .727 .889 r
.40948 .59044 .41254 .59358 .41774 .59171 .41468 .58869 Mtetra
.67 .735 .898 r
.41468 .58869 .41774 .59171 .42294 .58997 .41989 .58702 Mtetra
.668 .738 .903 r
.41989 .58702 .42294 .58997 .42815 .58832 .4251 .58539 Mtetra
.666 .74 .905 r
.4251 .58539 .42815 .58832 .43337 .58672 .43033 .58378 Mtetra
.665 .74 .906 r
.43033 .58378 .43337 .58672 .4386 .58513 .43556 .58219 Mtetra
.664 .74 .906 r
.43556 .58219 .4386 .58513 .44384 .58354 .44081 .58061 Mtetra
.664 .74 .907 r
.44081 .58061 .44384 .58354 .44909 .58195 .44606 .57902 Mtetra
.664 .741 .907 r
.44606 .57902 .44909 .58195 .45435 .58036 .45133 .57743 Mtetra
.45133 .57743 .45435 .58036 .45962 .57877 .4566 .57583 Mtetra
.4566 .57583 .45962 .57877 .4649 .57718 .46189 .57423 Mtetra
.46189 .57423 .4649 .57718 .47018 .57559 .46718 .57263 Mtetra
.664 .74 .907 r
.46718 .57263 .47018 .57559 .47548 .57398 .47249 .57103 Mtetra
.663 .741 .908 r
.47249 .57103 .47548 .57398 .48079 .57238 .47781 .56943 Mtetra
.664 .741 .908 r
.47781 .56943 .48079 .57238 .48611 .57078 .48313 .56781 Mtetra
.664 .741 .907 r
.48313 .56781 .48611 .57078 .49145 .56917 .48847 .56619 Mtetra
.48847 .56619 .49145 .56917 .49679 .56757 .49382 .56458 Mtetra
.664 .74 .907 r
.49382 .56458 .49679 .56757 .50214 .56595 .49918 .56296 Mtetra
.663 .74 .907 r
.49918 .56296 .50214 .56595 .5075 .56433 .50455 .56134 Mtetra
.664 .741 .908 r
.50455 .56134 .5075 .56433 .51287 .56271 .50993 .55972 Mtetra
.664 .741 .907 r
.50993 .55972 .51287 .56271 .51826 .56109 .51532 .55808 Mtetra
.51532 .55808 .51826 .56109 .52365 .55946 .52072 .55645 Mtetra
.664 .74 .907 r
.52072 .55645 .52365 .55946 .52905 .55783 .52613 .55481 Mtetra
.664 .741 .907 r
.52613 .55481 .52905 .55783 .53447 .55619 .53155 .55318 Mtetra
.664 .741 .908 r
.53155 .55318 .53447 .55619 .53989 .55456 .53698 .55153 Mtetra
.664 .741 .907 r
.53698 .55153 .53989 .55456 .54533 .55292 .54243 .54988 Mtetra
.664 .74 .907 r
.54243 .54988 .54533 .55292 .55078 .55128 .54788 .54824 Mtetra
.664 .741 .907 r
.54788 .54824 .55078 .55128 .55623 .54963 .55334 .54658 Mtetra
.55334 .54658 .55623 .54963 .5617 .54798 .55882 .54493 Mtetra
.55882 .54493 .5617 .54798 .56718 .54633 .56431 .54327 Mtetra
.56431 .54327 .56718 .54633 .57267 .54468 .5698 .54161 Mtetra
.664 .74 .907 r
.5698 .54161 .57267 .54468 .57817 .54301 .57531 .53994 Mtetra
.664 .741 .907 r
.57531 .53994 .57817 .54301 .58369 .54135 .58083 .53828 Mtetra
.58083 .53828 .58369 .54135 .58921 .53969 .58636 .53661 Mtetra
.58636 .53661 .58921 .53969 .59474 .53802 .5919 .53493 Mtetra
.5919 .53493 .59474 .53802 .60029 .53635 .59746 .53325 Mtetra
.59746 .53325 .60029 .53635 .60584 .53467 .60302 .53157 Mtetra
.60302 .53157 .60584 .53467 .61141 .53299 .60859 .52989 Mtetra
.664 .741 .908 r
.60859 .52989 .61141 .53299 .61699 .53131 .61418 .5282 Mtetra
.664 .741 .907 r
.61418 .5282 .61699 .53131 .62258 .52962 .61978 .5265 Mtetra
.61978 .5265 .62258 .52962 .62818 .52793 .62538 .52481 Mtetra
.62538 .52481 .62818 .52793 .63379 .52624 .631 .52311 Mtetra
.663 .741 .908 r
.631 .52311 .63379 .52624 .63941 .52455 .63663 .52142 Mtetra
.664 .741 .907 r
.63663 .52142 .63941 .52455 .64505 .52286 .64228 .51971 Mtetra
.64228 .51971 .64505 .52286 .65069 .52116 .64793 .518 Mtetra
.663 .741 .908 r
.64793 .518 .65069 .52116 .65635 .51946 .6536 .5163 Mtetra
.6536 .5163 .65635 .51946 .66202 .51776 .65927 .51461 Mtetra
.662 .741 .909 r
.65927 .51461 .66202 .51776 .6677 .51607 .66496 .51291 Mtetra
.661 .741 .909 r
.66496 .51291 .6677 .51607 .67339 .51439 .67066 .51123 Mtetra
.659 .74 .91 r
.67066 .51123 .67339 .51439 .6791 .51273 .67638 .50958 Mtetra
.656 .74 .912 r
.67638 .50958 .6791 .51273 .68482 .5111 .6821 .50797 Mtetra
.651 .74 .915 r
.6821 .50797 .68482 .5111 .69055 .50953 .68785 .50643 Mtetra
.642 .739 .92 r
.68785 .50643 .69055 .50953 .69631 .50807 .69361 .505 Mtetra
.627 .737 .927 r
.69361 .505 .69631 .50807 .70208 .50677 .6994 .50377 Mtetra
.598 .731 .938 r
.6994 .50377 .70208 .50677 .70788 .50573 .70521 .50287 Mtetra
.545 .72 .954 r
.70521 .50287 .70788 .50573 .71372 .50511 .71107 .50248 Mtetra
.432 .686 .971 r
.71107 .50248 .71372 .50511 .71962 .50519 .717 .50292 Mtetra
.172 .568 .934 r
.717 .50292 .71962 .50519 .7256 .50638 .72302 .50464 Mtetra
0 .23 .653 r
.72302 .50464 .7256 .50638 .7317 .50925 .72919 .50832 Mtetra
.711 .176 0 r
.72919 .50832 .7317 .50925 .738 .51456 .73556 .51478 Mtetra
.838 .382 .123 r
.73556 .51478 .738 .51456 .74455 .52317 .74221 .52484 Mtetra
.867 .462 .262 r
.74221 .52484 .74455 .52317 .7514 .53565 .74916 .53871 Mtetra
.867 .487 .322 r
.74916 .53871 .7514 .53565 .75855 .55138 .75636 .55505 Mtetra
.849 .469 .329 r
.75636 .55505 .75855 .55138 .7658 .56748 .76354 .57002 Mtetra
.779 .345 .221 r
.76354 .57002 .7658 .56748 .77277 .57873 .77029 .578 Mtetra
.705 .952 .953 r
.77029 .578 .77277 .57873 .77905 .57993 .77625 .57481 Mtetra
.889 .727 .675 r
.77625 .57481 .77905 .57993 .78449 .56976 .78143 .56109 Mtetra
.869 .669 .63 r
.78143 .56109 .78449 .56976 .7893 .55186 .78614 .54173 Mtetra
.852 .649 .628 r
.78614 .54173 .7893 .55186 .7939 .53188 .79079 .52217 Mtetra
.839 .646 .642 r
.79079 .52217 .7939 .53188 .79862 .514 .79562 .50563 Mtetra
.826 .653 .668 r
.79562 .50563 .79862 .514 .8036 .49988 .80073 .49294 Mtetra
.811 .668 .704 r
.80073 .49294 .8036 .49988 .80887 .48942 .80611 .48366 Mtetra
.792 .686 .747 r
.80611 .48366 .80887 .48942 .81437 .48186 .81169 .47693 Mtetra
.769 .702 .789 r
.81169 .47693 .81437 .48186 .82005 .47636 .81743 .472 Mtetra
.743 .716 .826 r
.81743 .472 .82005 .47636 .82585 .47223 .82328 .46826 Mtetra
.72 .727 .855 r
.82328 .46826 .82585 .47223 .83174 .46898 .8292 .46527 Mtetra
.701 .734 .877 r
.8292 .46527 .83174 .46898 .83769 .4663 .83517 .46277 Mtetra
.682 .738 .893 r
.83517 .46277 .83769 .4663 .84368 .46401 .84119 .46062 Mtetra
.662 .739 .907 r
.84119 .46062 .84368 .46401 .84972 .46205 .84726 .45881 Mtetra
.633 .738 .924 r
.84726 .45881 .84972 .46205 .85581 .46038 .85338 .45743 Mtetra
.572 .732 .951 r
.85338 .45743 .85581 .46038 .86195 .45914 .85958 .45672 Mtetra
.395 .688 .978 r
.85958 .45672 .86195 .45914 .86818 .45869 .86594 .45728 Mtetra
0 .349 .737 r
.86594 .45728 .86818 .45869 .8746 .45973 .87257 .46027 Mtetra
.761 .254 0 r
.87257 .46027 .8746 .45973 .88135 .46364 .87973 .46788 Mtetra
.85 .458 .302 r
.87973 .46788 .88135 .46364 .88873 .47292 .88786 .48379 Mtetra
.854 .516 .412 r
.88786 .48379 .88873 .47292 .89723 .49166 .89755 .51295 Mtetra
.838 .527 .461 r
.89755 .51295 .89723 .49166 .90746 .52477 .90918 .55803 Mtetra
.804 .509 .49 r
.90918 .55803 .90746 .52477 .91961 .57306 .92174 .60944 Mtetra
.723 .446 .507 r
.92174 .60944 .91961 .57306 .93206 .62212 .93188 .63835 Mtetra
.127 0 .361 r
.93188 .63835 .93206 .62212 .94103 .64042 .93654 .62032 Mtetra
.889 .632 .543 r
.93654 .62032 .94103 .64042 .94429 .61124 .93709 .56886 Mtetra
.799 .552 .564 r
.93709 .56886 .94429 .61124 .94432 .55671 .93727 .51587 Mtetra
.762 .527 .578 r
.93727 .51587 .94432 .55671 .94472 .50676 .9391 .47755 Mtetra
.745 .526 .597 r
.9391 .47755 .94472 .50676 .94697 .47251 .94269 .45397 Mtetra
.738 .542 .629 r
.94269 .45397 .94697 .47251 .95087 .45189 .94748 .4403 Mtetra
.733 .575 .677 r
.94748 .4403 .95087 .45189 .95585 .43995 .95298 .43228 Mtetra
.727 .621 .739 r
.95298 .43228 .95585 .43995 .96146 .43287 .95887 .42725 Mtetra
.714 .665 .801 r
.95887 .42725 .96146 .43287 .96741 .42835 .96497 .42376 Mtetra
.688 .712 .866 r
.396 .5912 .39908 .59467 .40428 .59236 .4012 .58918 Mtetra
.679 .727 .886 r
.4012 .58918 .40428 .59236 .40948 .59044 .4064 .58738 Mtetra
.672 .733 .896 r
.4064 .58738 .40948 .59044 .41468 .58869 .41161 .58569 Mtetra
.667 .735 .901 r
.41161 .58569 .41468 .58869 .41989 .58702 .41682 .58406 Mtetra
.665 .738 .904 r
.41682 .58406 .41989 .58702 .4251 .58539 .42204 .58247 Mtetra
.665 .741 .907 r
.42204 .58247 .4251 .58539 .43033 .58378 .42727 .58087 Mtetra
.665 .742 .907 r
.42727 .58087 .43033 .58378 .43556 .58219 .43251 .57926 Mtetra
.664 .741 .907 r
.43251 .57926 .43556 .58219 .44081 .58061 .43776 .57767 Mtetra
.664 .74 .907 r
.43776 .57767 .44081 .58061 .44606 .57902 .44303 .57607 Mtetra
.44303 .57607 .44606 .57902 .45133 .57743 .4483 .57448 Mtetra
.664 .741 .907 r
.4483 .57448 .45133 .57743 .4566 .57583 .45358 .57288 Mtetra
.45358 .57288 .4566 .57583 .46189 .57423 .45887 .57127 Mtetra
.45887 .57127 .46189 .57423 .46718 .57263 .46417 .56966 Mtetra
.46417 .56966 .46718 .57263 .47249 .57103 .46949 .56805 Mtetra
.46949 .56805 .47249 .57103 .47781 .56943 .47481 .56644 Mtetra
.664 .74 .907 r
.47481 .56644 .47781 .56943 .48313 .56781 .48014 .56483 Mtetra
.664 .741 .907 r
.48014 .56483 .48313 .56781 .48847 .56619 .48549 .56321 Mtetra
.48549 .56321 .48847 .56619 .49382 .56458 .49084 .56159 Mtetra
.49084 .56159 .49382 .56458 .49918 .56296 .49621 .55996 Mtetra
.49621 .55996 .49918 .56296 .50455 .56134 .50158 .55833 Mtetra
.664 .74 .907 r
.50158 .55833 .50455 .56134 .50993 .55972 .50697 .5567 Mtetra
.663 .74 .907 r
.50697 .5567 .50993 .55972 .51532 .55808 .51237 .55507 Mtetra
.664 .741 .908 r
.51237 .55507 .51532 .55808 .52072 .55645 .51777 .55343 Mtetra
.664 .742 .908 r
.51777 .55343 .52072 .55645 .52613 .55481 .52319 .55178 Mtetra
.664 .741 .907 r
.52319 .55178 .52613 .55481 .53155 .55318 .52862 .55014 Mtetra
.664 .74 .907 r
.52862 .55014 .53155 .55318 .53698 .55153 .53406 .54849 Mtetra
.53406 .54849 .53698 .55153 .54243 .54988 .53951 .54684 Mtetra
.664 .741 .908 r
.53951 .54684 .54243 .54988 .54788 .54824 .54497 .54519 Mtetra
.664 .742 .908 r
.54497 .54519 .54788 .54824 .55334 .54658 .55044 .54353 Mtetra
.664 .741 .907 r
.55044 .54353 .55334 .54658 .55882 .54493 .55593 .54186 Mtetra
.55593 .54186 .55882 .54493 .56431 .54327 .56142 .5402 Mtetra
.56142 .5402 .56431 .54327 .5698 .54161 .56692 .53853 Mtetra
.664 .741 .908 r
.56692 .53853 .5698 .54161 .57531 .53994 .57244 .53687 Mtetra
.664 .741 .907 r
.57244 .53687 .57531 .53994 .58083 .53828 .57797 .53519 Mtetra
.57797 .53519 .58083 .53828 .58636 .53661 .5835 .53351 Mtetra
.664 .74 .907 r
.5835 .53351 .58636 .53661 .5919 .53493 .58905 .53183 Mtetra
.664 .741 .907 r
.58905 .53183 .5919 .53493 .59746 .53325 .59461 .53014 Mtetra
.664 .741 .908 r
.59461 .53014 .59746 .53325 .60302 .53157 .60018 .52846 Mtetra
.664 .741 .907 r
.60018 .52846 .60302 .53157 .60859 .52989 .60577 .52676 Mtetra
.60577 .52676 .60859 .52989 .61418 .5282 .61136 .52507 Mtetra
.664 .74 .907 r
.61136 .52507 .61418 .5282 .61978 .5265 .61696 .52337 Mtetra
.663 .741 .908 r
.61696 .52337 .61978 .5265 .62538 .52481 .62258 .52168 Mtetra
.664 .741 .908 r
.62258 .52168 .62538 .52481 .631 .52311 .62821 .51997 Mtetra
.664 .741 .907 r
.62821 .51997 .631 .52311 .63663 .52142 .63384 .51826 Mtetra
.664 .74 .907 r
.63384 .51826 .63663 .52142 .64228 .51971 .63949 .51655 Mtetra
.663 .74 .907 r
.63949 .51655 .64228 .51971 .64793 .518 .64516 .51485 Mtetra
.663 .741 .908 r
.64516 .51485 .64793 .518 .6536 .5163 .65083 .51315 Mtetra
.65083 .51315 .6536 .5163 .65927 .51461 .65651 .51144 Mtetra
.662 .741 .908 r
.65651 .51144 .65927 .51461 .66496 .51291 .66221 .50974 Mtetra
.66 .74 .909 r
.66221 .50974 .66496 .51291 .67066 .51123 .66792 .50806 Mtetra
.658 .74 .911 r
.66792 .50806 .67066 .51123 .67638 .50958 .67364 .50642 Mtetra
.654 .74 .913 r
.67364 .50642 .67638 .50958 .6821 .50797 .67938 .50483 Mtetra
.648 .74 .916 r
.67938 .50483 .6821 .50797 .68785 .50643 .68513 .50332 Mtetra
.637 .738 .921 r
.68513 .50332 .68785 .50643 .69361 .505 .69091 .50195 Mtetra
.617 .735 .93 r
.69091 .50195 .69361 .505 .6994 .50377 .69671 .50082 Mtetra
.582 .729 .944 r
.69671 .50082 .6994 .50377 .70521 .50287 .70254 .50008 Mtetra
.513 .712 .962 r
.70254 .50008 .70521 .50287 .71107 .50248 .70842 .49995 Mtetra
.36 .657 .969 r
.70842 .49995 .71107 .50248 .717 .50292 .71438 .5008 Mtetra
.012 .472 .872 r
.71438 .5008 .717 .50292 .72302 .50464 .72045 .50317 Mtetra
.504 0 0 r
.72045 .50317 .72302 .50464 .72919 .50832 .72668 .5078 Mtetra
.78 .276 0 r
.72668 .5078 .72919 .50832 .73556 .51478 .73314 .51552 Mtetra
.855 .421 .189 r
.73314 .51552 .73556 .51478 .74221 .52484 .73989 .52703 Mtetra
.869 .477 .291 r
.73989 .52703 .74221 .52484 .74916 .53871 .74693 .54212 Mtetra
.863 .486 .331 r
.74693 .54212 .74916 .53871 .75636 .55505 .75414 .55856 Mtetra
.835 .446 .312 r
.75414 .55856 .75636 .55505 .76354 .57002 .76119 .57159 Mtetra
.658 .152 .032 r
.76119 .57159 .76354 .57002 .77029 .578 .76767 .57564 Mtetra
.887 .838 .792 r
.76767 .57564 .77029 .578 .77625 .57481 .77334 .56812 Mtetra
.88 .696 .649 r
.77334 .56812 .77625 .57481 .78143 .56109 .77831 .55158 Mtetra
.862 .659 .627 r
.77831 .55158 .78143 .56109 .78614 .54173 .78299 .5316 Mtetra
.847 .647 .632 r
.78299 .5316 .78614 .54173 .79079 .52217 .78771 .51292 Mtetra
.834 .648 .651 r
.78771 .51292 .79079 .52217 .79562 .50563 .79266 .49778 Mtetra
.821 .658 .681 r
.79266 .49778 .79562 .50563 .80073 .49294 .7979 .48645 Mtetra
.804 .673 .72 r
.7979 .48645 .80073 .49294 .80611 .48366 .80337 .47823 Mtetra
.784 .692 .763 r
.80337 .47823 .80611 .48366 .81169 .47693 .80903 .47227 Mtetra
.76 .709 .805 r
.80903 .47227 .81169 .47693 .81743 .472 .81482 .46783 Mtetra
.735 .722 .839 r
.81482 .46783 .81743 .472 .82328 .46826 .8207 .46439 Mtetra
.712 .729 .864 r
.8207 .46439 .82328 .46826 .8292 .46527 .82665 .46161 Mtetra
.691 .733 .883 r
.82665 .46161 .8292 .46527 .83517 .46277 .83265 .45929 Mtetra
.671 .737 .9 r
.83265 .45929 .83517 .46277 .84119 .46062 .8387 .45734 Mtetra
.645 .74 .919 r
.8387 .45734 .84119 .46062 .84726 .45881 .8448 .45578 Mtetra
.596 .738 .943 r
.8448 .45578 .84726 .45881 .85338 .45743 .85097 .45482 Mtetra
.464 .71 .975 r
.85097 .45482 .85338 .45743 .85958 .45672 .85728 .45496 Mtetra
.011 .494 .871 r
.85728 .45496 .85958 .45672 .86594 .45728 .86381 .45719 Mtetra
.689 .145 0 r
.86381 .45719 .86594 .45728 .87257 .46027 .8708 .46337 Mtetra
.842 .429 .255 r
.8708 .46337 .87257 .46027 .87973 .46788 .8786 .47677 Mtetra
.855 .507 .394 r
.8786 .47677 .87973 .46788 .88786 .48379 .88778 .50216 Mtetra
.843 .527 .452 r
.88778 .50216 .88786 .48379 .89755 .51295 .89885 .54345 Mtetra
.815 .516 .484 r
.89885 .54345 .89755 .51295 .90918 .55803 .9113 .59534 Mtetra
.752 .469 .504 r
.9113 .59534 .90918 .55803 .92174 .60944 .92236 .63317 Mtetra
.487 .247 .475 r
.92236 .63317 .92174 .60944 .93188 .63835 .92847 .62722 Mtetra
.935 .68 .527 r
.92847 .62722 .93188 .63835 .93654 .62032 .92978 .58099 Mtetra
.814 .564 .561 r
.92978 .58099 .93654 .62032 .93709 .56886 .92987 .52598 Mtetra
.769 .531 .574 r
.92987 .52598 .93709 .56886 .93727 .51587 .93131 .48356 Mtetra
.749 .524 .591 r
.93131 .48356 .93727 .51587 .9391 .47755 .93455 .4567 Mtetra
.739 .537 .619 r
.93455 .4567 .9391 .47755 .94269 .45397 .93912 .44098 Mtetra
.735 .566 .663 r
.93912 .44098 .94269 .45397 .94748 .4403 .94449 .43183 Mtetra
.728 .608 .723 r
.94449 .43183 .94748 .4403 .95298 .43228 .95031 .42622 Mtetra
.716 .653 .786 r
.95031 .42622 .95298 .43228 .95887 .42725 .95638 .42245 Mtetra
.701 .69 .837 r
.95638 .42245 .95887 .42725 .96497 .42376 .96258 .41962 Mtetra
.68 .722 .881 r
.39291 .58793 .396 .5912 .4012 .58918 .39811 .58609 Mtetra
.672 .731 .894 r
.39811 .58609 .4012 .58918 .4064 .58738 .40331 .58439 Mtetra
.668 .737 .901 r
.40331 .58439 .4064 .58738 .41161 .58569 .40852 .58274 Mtetra
.667 .74 .905 r
.40852 .58274 .41161 .58569 .41682 .58406 .41374 .58112 Mtetra
.665 .74 .906 r
.41374 .58112 .41682 .58406 .42204 .58247 .41897 .57951 Mtetra
.664 .739 .906 r
.41897 .57951 .42204 .58247 .42727 .58087 .4242 .57791 Mtetra
.663 .739 .906 r
.4242 .57791 .42727 .58087 .43251 .57926 .42945 .57633 Mtetra
.664 .741 .908 r
.42945 .57633 .43251 .57926 .43776 .57767 .43471 .57473 Mtetra
.665 .742 .908 r
.43471 .57473 .43776 .57767 .44303 .57607 .43998 .57312 Mtetra
.664 .741 .907 r
.43998 .57312 .44303 .57607 .4483 .57448 .44526 .57152 Mtetra
.664 .74 .907 r
.44526 .57152 .4483 .57448 .45358 .57288 .45054 .56991 Mtetra
.45054 .56991 .45358 .57288 .45887 .57127 .45584 .5683 Mtetra
.663 .741 .908 r
.45584 .5683 .45887 .57127 .46417 .56966 .46115 .5667 Mtetra
.664 .742 .908 r
.46115 .5667 .46417 .56966 .46949 .56805 .46647 .56508 Mtetra
.664 .741 .907 r
.46647 .56508 .46949 .56805 .47481 .56644 .4718 .56346 Mtetra
.4718 .56346 .47481 .56644 .48014 .56483 .47714 .56183 Mtetra
.47714 .56183 .48014 .56483 .48549 .56321 .48249 .56021 Mtetra
.663 .74 .907 r
.48249 .56021 .48549 .56321 .49084 .56159 .48785 .55859 Mtetra
.664 .741 .907 r
.48785 .55859 .49084 .56159 .49621 .55996 .49323 .55695 Mtetra
.49323 .55695 .49621 .55996 .50158 .55833 .49861 .55531 Mtetra
.49861 .55531 .50158 .55833 .50697 .5567 .504 .55368 Mtetra
.504 .55368 .50697 .5567 .51237 .55507 .5094 .55203 Mtetra
.664 .74 .907 r
.5094 .55203 .51237 .55507 .51777 .55343 .51482 .55039 Mtetra
.51482 .55039 .51777 .55343 .52319 .55178 .52024 .54875 Mtetra
.664 .741 .908 r
.52024 .54875 .52319 .55178 .52862 .55014 .52568 .5471 Mtetra
.664 .741 .907 r
.52568 .5471 .52862 .55014 .53406 .54849 .53113 .54544 Mtetra
.53113 .54544 .53406 .54849 .53951 .54684 .53658 .54378 Mtetra
.53658 .54378 .53951 .54684 .54497 .54519 .54205 .54212 Mtetra
.664 .74 .907 r
.54205 .54212 .54497 .54519 .55044 .54353 .54753 .54046 Mtetra
.663 .741 .907 r
.54753 .54046 .55044 .54353 .55593 .54186 .55302 .5388 Mtetra
.664 .741 .908 r
.55302 .5388 .55593 .54186 .56142 .5402 .55852 .53712 Mtetra
.664 .741 .907 r
.55852 .53712 .56142 .5402 .56692 .53853 .56403 .53544 Mtetra
.56403 .53544 .56692 .53853 .57244 .53687 .56956 .53377 Mtetra
.664 .74 .907 r
.56956 .53377 .57244 .53687 .57797 .53519 .57509 .53208 Mtetra
.663 .741 .907 r
.57509 .53208 .57797 .53519 .5835 .53351 .58064 .53041 Mtetra
.664 .741 .908 r
.58064 .53041 .5835 .53351 .58905 .53183 .58619 .52872 Mtetra
.664 .741 .907 r
.58619 .52872 .58905 .53183 .59461 .53014 .59176 .52702 Mtetra
.59176 .52702 .59461 .53014 .60018 .52846 .59734 .52533 Mtetra
.664 .74 .907 r
.59734 .52533 .60018 .52846 .60577 .52676 .60293 .52363 Mtetra
.663 .741 .907 r
.60293 .52363 .60577 .52676 .61136 .52507 .60853 .52194 Mtetra
.664 .741 .908 r
.60853 .52194 .61136 .52507 .61696 .52337 .61414 .52023 Mtetra
.664 .741 .907 r
.61414 .52023 .61696 .52337 .62258 .52168 .61976 .51852 Mtetra
.664 .74 .907 r
.61976 .51852 .62258 .52168 .62821 .51997 .6254 .51681 Mtetra
.663 .74 .907 r
.6254 .51681 .62821 .51997 .63384 .51826 .63104 .5151 Mtetra
.663 .741 .908 r
.63104 .5151 .63384 .51826 .63949 .51655 .6367 .51339 Mtetra
.663 .742 .908 r
.6367 .51339 .63949 .51655 .64516 .51485 .64237 .51168 Mtetra
.663 .741 .908 r
.64237 .51168 .64516 .51485 .65083 .51315 .64805 .50996 Mtetra
.662 .74 .908 r
.64805 .50996 .65083 .51315 .65651 .51144 .65374 .50825 Mtetra
.661 .74 .909 r
.65374 .50825 .65651 .51144 .66221 .50974 .65945 .50657 Mtetra
.659 .741 .91 r
.65945 .50657 .66221 .50974 .66792 .50806 .66517 .5049 Mtetra
.657 .741 .912 r
.66517 .5049 .66792 .50806 .67364 .50642 .6709 .50326 Mtetra
.653 .74 .914 r
.6709 .50326 .67364 .50642 .67938 .50483 .67664 .50168 Mtetra
.644 .738 .917 r
.67664 .50168 .67938 .50483 .68513 .50332 .68241 .50021 Mtetra
.63 .737 .924 r
.68241 .50021 .68513 .50332 .69091 .50195 .68819 .49893 Mtetra
.607 .734 .935 r
.68819 .49893 .69091 .50195 .69671 .50082 .69401 .49792 Mtetra
.562 .725 .95 r
.69401 .49792 .69671 .50082 .70254 .50008 .69986 .49736 Mtetra
.47 .699 .968 r
.69986 .49736 .70254 .50008 .70842 .49995 .70577 .49754 Mtetra
.259 .611 .956 r
.70577 .49754 .70842 .49995 .71438 .5008 .71176 .49889 Mtetra
0 .335 .756 r
.71176 .49889 .71438 .5008 .72045 .50317 .71788 .50201 Mtetra
.645 .093 0 r
.71788 .50201 .72045 .50317 .72668 .5078 .72418 .50769 Mtetra
.821 .347 .069 r
.72418 .50769 .72668 .5078 .73314 .51552 .73073 .51679 Mtetra
.864 .449 .237 r
.73073 .51679 .73314 .51552 .73989 .52703 .73758 .52976 Mtetra
.869 .485 .312 r
.73758 .52976 .73989 .52703 .74693 .54212 .74469 .54576 Mtetra
.856 .478 .333 r
.74469 .54576 .74693 .54212 .75414 .55856 .75187 .56159 Mtetra
.81 .4 .273 r
.75187 .56159 .75414 .55856 .76119 .57159 .75874 .57184 Mtetra
.01 0 0 r
.75874 .57184 .76119 .57159 .76767 .57564 .76493 .57159 Mtetra
.893 .758 .706 r
.76493 .57159 .76767 .57564 .77334 .56812 .77032 .56013 Mtetra
.873 .678 .635 r
.77032 .56013 .77334 .56812 .77831 .55158 .77516 .54159 Mtetra
.856 .652 .626 r
.77516 .54159 .77831 .55158 .78299 .5316 .77984 .52164 Mtetra
.842 .646 .637 r
.77984 .52164 .78299 .5316 .78771 .51292 .78467 .50415 Mtetra
.829 .651 .661 r
.78467 .50415 .78771 .51292 .79266 .49778 .78975 .49048 Mtetra
.815 .664 .695 r
.78975 .49048 .79266 .49778 .7979 .48645 .79509 .48039 Mtetra
.797 .681 .736 r
.79509 .48039 .7979 .48645 .80337 .47823 .80065 .4731 Mtetra
.775 .699 .779 r
.80065 .4731 .80337 .47823 .80903 .47227 .80638 .46778 Mtetra
.75 .714 .818 r
.80638 .46778 .80903 .47227 .81482 .46783 .81221 .46378 Mtetra
.725 .725 .849 r
.81221 .46378 .81482 .46783 .8207 .46439 .81813 .46063 Mtetra
.703 .733 .874 r
.81813 .46063 .8207 .46439 .82665 .46161 .82411 .45805 Mtetra
.682 .737 .893 r
.82411 .45805 .82665 .46161 .83265 .45929 .83014 .45591 Mtetra
.657 .739 .91 r
.83014 .45591 .83265 .45929 .8387 .45734 .83622 .45418 Mtetra
.614 .737 .933 r
.83622 .45418 .8387 .45734 .8448 .45578 .84236 .45302 Mtetra
.514 .721 .967 r
.84236 .45302 .8448 .45578 .85097 .45482 .84862 .4528 Mtetra
.178 .593 .94 r
.84862 .4528 .85097 .45482 .85728 .45496 .85508 .45436 Mtetra
.573 0 0 r
.85508 .45436 .85728 .45496 .86381 .45719 .8619 .45928 Mtetra
.829 .389 .191 r
.8619 .45928 .86381 .45719 .8708 .46337 .86943 .47046 Mtetra
.855 .496 .371 r
.86943 .47046 .8708 .46337 .8786 .47677 .87816 .49239 Mtetra
.848 .525 .442 r
.87816 .49239 .8786 .47677 .88778 .50216 .88866 .52967 Mtetra
.824 .521 .477 r
.88866 .52967 .88778 .50216 .89885 .54345 .90082 .58042 Mtetra
.773 .486 .5 r
.90082 .58042 .89885 .54345 .9113 .59534 .9125 .62499 Mtetra
.616 .355 .499 r
.9125 .62499 .9113 .59534 .92236 .63317 .92002 .63143 Mtetra
.992 .756 .475 r
.92002 .63143 .92236 .63317 .92847 .62722 .92233 .5927 Mtetra
.832 .579 .557 r
.92233 .5927 .92847 .62722 .92978 .58099 .9225 .53701 Mtetra
.777 .536 .57 r
.9225 .53701 .92978 .58099 .92987 .52598 .92359 .49057 Mtetra
.752 .524 .586 r
.92359 .49057 .92987 .52598 .93131 .48356 .92646 .46009 Mtetra
.741 .532 .611 r
.92646 .46009 .93131 .48356 .93455 .4567 .93078 .44206 Mtetra
.735 .557 .651 r
.93078 .44206 .93455 .4567 .93912 .44098 .93601 .43162 Mtetra
.73 .597 .707 r
.93601 .43162 .93912 .44098 .94449 .43183 .94176 .42532 Mtetra
.721 .644 .771 r
.94176 .42532 .94449 .43183 .95031 .42622 .94778 .42119 Mtetra
.706 .683 .826 r
.94778 .42119 .95031 .42622 .95638 .42245 .95395 .41816 Mtetra
.69 .709 .863 r
.95395 .41816 .95638 .42245 .96258 .41962 .96021 .41568 Mtetra
.675 .73 .892 r
.3898 .58481 .39291 .58793 .39811 .58609 .395 .58306 Mtetra
.669 .735 .899 r
.395 .58306 .39811 .58609 .40331 .58439 .40021 .5814 Mtetra
.666 .737 .903 r
.40021 .5814 .40331 .58439 .40852 .58274 .40542 .57979 Mtetra
.665 .739 .905 r
.40542 .57979 .40852 .58274 .41374 .58112 .41065 .57818 Mtetra
.665 .741 .907 r
.41065 .57818 .41374 .58112 .41897 .57951 .41588 .57657 Mtetra
.41588 .57657 .41897 .57951 .4242 .57791 .42113 .57497 Mtetra
.664 .741 .907 r
.42113 .57497 .4242 .57791 .42945 .57633 .42638 .57337 Mtetra
.664 .74 .907 r
.42638 .57337 .42945 .57633 .43471 .57473 .43164 .57177 Mtetra
.43164 .57177 .43471 .57473 .43998 .57312 .43692 .57016 Mtetra
.664 .741 .907 r
.43692 .57016 .43998 .57312 .44526 .57152 .4422 .56855 Mtetra
.4422 .56855 .44526 .57152 .45054 .56991 .4475 .56694 Mtetra
.4475 .56694 .45054 .56991 .45584 .5683 .4528 .56532 Mtetra
.4528 .56532 .45584 .5683 .46115 .5667 .45812 .56371 Mtetra
.664 .74 .907 r
.45812 .56371 .46115 .5667 .46647 .56508 .46345 .56208 Mtetra
.663 .74 .907 r
.46345 .56208 .46647 .56508 .4718 .56346 .46878 .56047 Mtetra
.664 .741 .908 r
.46878 .56047 .4718 .56346 .47714 .56183 .47413 .55884 Mtetra
.664 .742 .908 r
.47413 .55884 .47714 .56183 .48249 .56021 .47949 .5572 Mtetra
.664 .741 .907 r
.47949 .5572 .48249 .56021 .48785 .55859 .48485 .55557 Mtetra
.664 .74 .907 r
.48485 .55557 .48785 .55859 .49323 .55695 .49023 .55393 Mtetra
.663 .74 .907 r
.49023 .55393 .49323 .55695 .49861 .55531 .49562 .5523 Mtetra
.664 .741 .908 r
.49562 .5523 .49861 .55531 .504 .55368 .50102 .55066 Mtetra
.665 .742 .908 r
.50102 .55066 .504 .55368 .5094 .55203 .50643 .549 Mtetra
.664 .741 .907 r
.50643 .549 .5094 .55203 .51482 .55039 .51185 .54735 Mtetra
.51185 .54735 .51482 .55039 .52024 .54875 .51729 .54569 Mtetra
.663 .74 .907 r
.51729 .54569 .52024 .54875 .52568 .5471 .52273 .54404 Mtetra
.664 .741 .907 r
.52273 .54404 .52568 .5471 .53113 .54544 .52818 .54238 Mtetra
.52818 .54238 .53113 .54544 .53658 .54378 .53365 .54071 Mtetra
.53365 .54071 .53658 .54378 .54205 .54212 .53912 .53904 Mtetra
.53912 .53904 .54205 .54212 .54753 .54046 .54461 .53737 Mtetra
.54461 .53737 .54753 .54046 .55302 .5388 .55011 .5357 Mtetra
.664 .74 .907 r
.55011 .5357 .55302 .5388 .55852 .53712 .55561 .53402 Mtetra
.55561 .53402 .55852 .53712 .56403 .53544 .56113 .53235 Mtetra
.664 .741 .908 r
.56113 .53235 .56403 .53544 .56956 .53377 .56666 .53066 Mtetra
.664 .741 .907 r
.56666 .53066 .56956 .53377 .57509 .53208 .5722 .52897 Mtetra
.5722 .52897 .57509 .53208 .58064 .53041 .57776 .52728 Mtetra
.664 .74 .907 r
.57776 .52728 .58064 .53041 .58619 .52872 .58332 .52559 Mtetra
.58332 .52559 .58619 .52872 .59176 .52702 .5889 .5239 Mtetra
.664 .741 .908 r
.5889 .5239 .59176 .52702 .59734 .52533 .59448 .5222 Mtetra
.664 .742 .908 r
.59448 .5222 .59734 .52533 .60293 .52363 .60008 .52049 Mtetra
.664 .741 .907 r
.60008 .52049 .60293 .52363 .60853 .52194 .60569 .51878 Mtetra
.664 .74 .907 r
.60569 .51878 .60853 .52194 .61414 .52023 .61131 .51707 Mtetra
.663 .74 .907 r
.61131 .51707 .61414 .52023 .61976 .51852 .61694 .51536 Mtetra
.663 .741 .908 r
.61694 .51536 .61976 .51852 .6254 .51681 .62258 .51365 Mtetra
.664 .742 .908 r
.62258 .51365 .6254 .51681 .63104 .5151 .62823 .51193 Mtetra
.664 .741 .907 r
.62823 .51193 .63104 .5151 .6367 .51339 .6339 .5102 Mtetra
.663 .74 .907 r
.6339 .5102 .6367 .51339 .64237 .51168 .63958 .50849 Mtetra
.662 .74 .908 r
.63958 .50849 .64237 .51168 .64805 .50996 .64526 .50678 Mtetra
.662 .741 .909 r
.64526 .50678 .64805 .50996 .65374 .50825 .65096 .50507 Mtetra
.661 .741 .909 r
.65096 .50507 .65374 .50825 .65945 .50657 .65668 .50338 Mtetra
.659 .74 .91 r
.65668 .50338 .65945 .50657 .66517 .5049 .6624 .50171 Mtetra
.655 .739 .912 r
.6624 .50171 .66517 .5049 .6709 .50326 .66814 .50009 Mtetra
.65 .739 .915 r
.66814 .50009 .6709 .50326 .67664 .50168 .6739 .49855 Mtetra
.64 .739 .921 r
.6739 .49855 .67664 .50168 .68241 .50021 .67967 .49713 Mtetra
.624 .737 .928 r
.67967 .49713 .68241 .50021 .68819 .49893 .68547 .49592 Mtetra
.594 .731 .94 r
.68547 .49592 .68819 .49893 .69401 .49792 .6913 .49505 Mtetra
.535 .717 .957 r
.6913 .49505 .69401 .49792 .69986 .49736 .69717 .49473 Mtetra
.409 .677 .971 r
.69717 .49473 .69986 .49736 .70577 .49754 .70311 .4953 Mtetra
.121 .539 .917 r
.70311 .4953 .70577 .49754 .71176 .49889 .70914 .49722 Mtetra
.384 0 0 r
.70914 .49722 .71176 .49889 .71788 .50201 .71532 .50119 Mtetra
.738 .213 0 r
.71532 .50119 .71788 .50201 .72418 .50769 .7217 .50806 Mtetra
.845 .397 .148 r
.7217 .50806 .72418 .50769 .73073 .51679 .72835 .51861 Mtetra
.868 .468 .273 r
.72835 .51861 .73073 .51679 .73758 .52976 .73529 .53294 Mtetra
.866 .487 .326 r
.73529 .53294 .73758 .52976 .74469 .54576 .74244 .5494 Mtetra
.845 .463 .324 r
.74244 .5494 .74469 .54576 .75187 .56159 .74953 .56383 Mtetra
.754 .302 .178 r
.74953 .56383 .75187 .56159 .75874 .57184 .75617 .57057 Mtetra
.825 .925 .901 r
.75617 .57057 .75874 .57184 .76493 .57159 .76206 .56589 Mtetra
.886 .715 .665 r
.76206 .56589 .76493 .57159 .77032 .56013 .76722 .55109 Mtetra
.866 .665 .629 r
.76722 .55109 .77032 .56013 .77516 .54159 .77199 .53139 Mtetra
.851 .648 .629 r
.77199 .53139 .77516 .54159 .77984 .52164 .77673 .51205 Mtetra
.838 .647 .645 r
.77673 .51205 .77984 .52164 .78467 .50415 .78167 .49592 Mtetra
.825 .655 .672 r
.78167 .49592 .78467 .50415 .78975 .49048 .78687 .48365 Mtetra
.809 .669 .709 r
.78687 .48365 .78975 .49048 .79509 .48039 .79231 .4747 Mtetra
.789 .687 .752 r
.79231 .4747 .79509 .48039 .80065 .4731 .79795 .46824 Mtetra
.766 .705 .795 r
.79795 .46824 .80065 .4731 .80638 .46778 .80373 .46348 Mtetra
.741 .719 .832 r
.80373 .46348 .80638 .46778 .81221 .46378 .80961 .45984 Mtetra
.716 .728 .86 r
.80961 .45984 .81221 .46378 .81813 .46063 .81556 .45694 Mtetra
.693 .733 .882 r
.81556 .45694 .81813 .46063 .82411 .45805 .82156 .45458 Mtetra
.667 .737 .902 r
.82156 .45458 .82411 .45805 .83014 .45591 .82762 .45267 Mtetra
.631 .739 .925 r
.82762 .45267 .83014 .45591 .83622 .45418 .83375 .45129 Mtetra
.553 .731 .958 r
.83375 .45129 .83622 .45418 .84236 .45302 .83996 .45074 Mtetra
.312 .655 .971 r
.83996 .45074 .84236 .45302 .84862 .4528 .84635 .45172 Mtetra
.399 0 0 r
.84635 .45172 .84862 .4528 .85508 .45436 .85305 .45558 Mtetra
.805 .334 .106 r
.85305 .45558 .85508 .45436 .8619 .45928 .86033 .46485 Mtetra
.854 .48 .342 r
.86033 .46485 .8619 .45928 .86943 .47046 .86866 .48361 Mtetra
.851 .522 .429 r
.86866 .48361 .86943 .47046 .87816 .49239 .87861 .51678 Mtetra
.832 .525 .47 r
.87861 .51678 .87816 .49239 .88866 .52967 .89035 .56515 Mtetra
.79 .499 .495 r
.89035 .56515 .88866 .52967 .90082 .58042 .90239 .6143 Mtetra
.682 .411 .505 r
.90239 .6143 .90082 .58042 .9125 .62499 .91119 .63264 Mtetra
.811 .714 .18 r
.91119 .63264 .9125 .62499 .92002 .63143 .91468 .60339 Mtetra
.856 .601 .552 r
.91468 .60339 .92002 .63143 .92233 .5927 .91513 .54871 Mtetra
.787 .543 .567 r
.91513 .54871 .92233 .5927 .9225 .53701 .91592 .49862 Mtetra
.757 .525 .581 r
.91592 .49862 .9225 .53701 .92359 .49057 .91843 .4643 Mtetra
.743 .528 .603 r
.91843 .4643 .92359 .49057 .92646 .46009 .92248 .44363 Mtetra
.737 .549 .639 r
.92248 .44363 .92646 .46009 .93078 .44206 .92754 .43164 Mtetra
.732 .586 .692 r
.92754 .43164 .93078 .44206 .93601 .43162 .9332 .42453 Mtetra
.723 .631 .755 r
.9332 .42453 .93601 .43162 .94176 .42532 .93917 .41998 Mtetra
.709 .673 .814 r
.93917 .41998 .94176 .42532 .94778 .42119 .94531 .41676 Mtetra
.694 .705 .856 r
.94531 .41676 .94778 .42119 .95395 .41816 .95156 .41418 Mtetra
.682 .723 .881 r
.95156 .41418 .95395 .41816 .96021 .41568 .95785 .41191 Mtetra
.67 .734 .898 r
.38668 .58176 .3898 .58481 .395 .58306 .39188 .58009 Mtetra
.667 .739 .904 r
.39188 .58009 .395 .58306 .40021 .5814 .3971 .57845 Mtetra
.666 .74 .905 r
.3971 .57845 .40021 .5814 .40542 .57979 .40232 .57682 Mtetra
.665 .739 .906 r
.40232 .57682 .40542 .57979 .41065 .57818 .40755 .57521 Mtetra
.664 .739 .906 r
.40755 .57521 .41065 .57818 .41588 .57657 .41279 .57362 Mtetra
.663 .74 .907 r
.41279 .57362 .41588 .57657 .42113 .57497 .41804 .57202 Mtetra
.664 .742 .908 r
.41804 .57202 .42113 .57497 .42638 .57337 .4233 .57041 Mtetra
.664 .741 .907 r
.4233 .57041 .42638 .57337 .43164 .57177 .42857 .5688 Mtetra
.42857 .5688 .43164 .57177 .43692 .57016 .43385 .56719 Mtetra
.43385 .56719 .43692 .57016 .4422 .56855 .43914 .56557 Mtetra
.663 .74 .907 r
.43914 .56557 .4422 .56855 .4475 .56694 .44444 .56396 Mtetra
.664 .741 .908 r
.44444 .56396 .4475 .56694 .4528 .56532 .44975 .56234 Mtetra
.664 .741 .907 r
.44975 .56234 .4528 .56532 .45812 .56371 .45508 .56071 Mtetra
.45508 .56071 .45812 .56371 .46345 .56208 .46041 .55908 Mtetra
.46041 .55908 .46345 .56208 .46878 .56047 .46575 .55745 Mtetra
.664 .74 .907 r
.46575 .55745 .46878 .56047 .47413 .55884 .4711 .55582 Mtetra
.4711 .55582 .47413 .55884 .47949 .5572 .47647 .55419 Mtetra
.664 .741 .908 r
.47647 .55419 .47949 .5572 .48485 .55557 .48184 .55254 Mtetra
.664 .741 .907 r
.48184 .55254 .48485 .55557 .49023 .55393 .48723 .5509 Mtetra
.48723 .5509 .49023 .55393 .49562 .5523 .49263 .54925 Mtetra
.664 .74 .907 r
.49263 .54925 .49562 .5523 .50102 .55066 .49803 .5476 Mtetra
.49803 .5476 .50102 .55066 .50643 .549 .50345 .54595 Mtetra
.663 .741 .908 r
.50345 .54595 .50643 .549 .51185 .54735 .50888 .5443 Mtetra
.664 .742 .908 r
.50888 .5443 .51185 .54735 .51729 .54569 .51432 .54264 Mtetra
.664 .741 .907 r
.51432 .54264 .51729 .54569 .52273 .54404 .51977 .54097 Mtetra
.664 .74 .907 r
.51977 .54097 .52273 .54404 .52818 .54238 .52523 .5393 Mtetra
.52523 .5393 .52818 .54238 .53365 .54071 .5307 .53763 Mtetra
.663 .741 .908 r
.5307 .53763 .53365 .54071 .53912 .53904 .53618 .53597 Mtetra
.664 .742 .908 r
.53618 .53597 .53912 .53904 .54461 .53737 .54168 .53429 Mtetra
.664 .741 .907 r
.54168 .53429 .54461 .53737 .55011 .5357 .54718 .5326 Mtetra
.54718 .5326 .55011 .5357 .55561 .53402 .5527 .53092 Mtetra
.5527 .53092 .55561 .53402 .56113 .53235 .55822 .52923 Mtetra
.663 .74 .907 r
.55822 .52923 .56113 .53235 .56666 .53066 .56376 .52755 Mtetra
.664 .741 .907 r
.56376 .52755 .56666 .53066 .5722 .52897 .56931 .52585 Mtetra
.56931 .52585 .5722 .52897 .57776 .52728 .57487 .52415 Mtetra
.57487 .52415 .57776 .52728 .58332 .52559 .58044 .52245 Mtetra
.58044 .52245 .58332 .52559 .5889 .5239 .58602 .52075 Mtetra
.664 .74 .907 r
.58602 .52075 .5889 .5239 .59448 .5222 .59161 .51904 Mtetra
.59161 .51904 .59448 .5222 .60008 .52049 .59722 .51734 Mtetra
.664 .741 .907 r
.59722 .51734 .60008 .52049 .60569 .51878 .60283 .51563 Mtetra
.664 .741 .908 r
.60283 .51563 .60569 .51878 .61131 .51707 .60846 .51391 Mtetra
.664 .741 .907 r
.60846 .51391 .61131 .51707 .61694 .51536 .6141 .51218 Mtetra
.664 .74 .907 r
.6141 .51218 .61694 .51536 .62258 .51365 .61975 .51046 Mtetra
.663 .74 .907 r
.61975 .51046 .62258 .51365 .62823 .51193 .62541 .50874 Mtetra
.663 .74 .908 r
.62541 .50874 .62823 .51193 .6339 .5102 .63108 .50703 Mtetra
.663 .742 .909 r
.63108 .50703 .6339 .5102 .63958 .50849 .63677 .5053 Mtetra
.663 .742 .908 r
.63677 .5053 .63958 .50849 .64526 .50678 .64247 .50357 Mtetra
.662 .74 .908 r
.64247 .50357 .64526 .50678 .65096 .50507 .64817 .50186 Mtetra
.66 .739 .909 r
.64817 .50186 .65096 .50507 .65668 .50338 .6539 .50018 Mtetra
.657 .74 .911 r
.6539 .50018 .65668 .50338 .6624 .50171 .65963 .49853 Mtetra
.654 .741 .914 r
.65963 .49853 .6624 .50171 .66814 .50009 .66538 .49693 Mtetra
.648 .74 .917 r
.66538 .49693 .66814 .50009 .6739 .49855 .67115 .49541 Mtetra
.635 .737 .922 r
.67115 .49541 .6739 .49855 .67967 .49713 .67693 .49405 Mtetra
.614 .734 .931 r
.67693 .49405 .67967 .49713 .68547 .49592 .68274 .49296 Mtetra
.576 .728 .946 r
.68274 .49296 .68547 .49592 .6913 .49505 .68859 .49226 Mtetra
.499 .709 .965 r
.68859 .49226 .6913 .49505 .69717 .49473 .69448 .49222 Mtetra
.329 .645 .967 r
.69448 .49222 .69717 .49473 .70311 .4953 .70045 .49321 Mtetra
0 .431 .84 r
.70045 .49321 .70311 .4953 .70914 .49722 .70653 .49581 Mtetra
.557 0 0 r
.70653 .49581 .70914 .49722 .71532 .50119 .71277 .50078 Mtetra
.797 .303 .005 r
.71277 .50078 .71532 .50119 .7217 .50806 .71923 .50896 Mtetra
.858 .432 .208 r
.71923 .50896 .7217 .50806 .72835 .51861 .72597 .52098 Mtetra
.869 .48 .299 r
.72597 .52098 .72835 .51861 .73529 .53294 .73299 .53642 Mtetra
.861 .484 .332 r
.73299 .53642 .73529 .53294 .74244 .5494 .74014 .55276 Mtetra
.828 .434 .302 r
.74014 .55276 .74244 .5494 .74953 .56383 .7471 .56498 Mtetra
.554 .006 0 r
.7471 .56498 .74953 .56383 .75617 .57057 .75348 .56763 Mtetra
.892 .804 .755 r
.75348 .56763 .75617 .57057 .76206 .56589 .75908 .5587 Mtetra
.878 .689 .644 r
.75908 .5587 .76206 .56589 .76722 .55109 .76407 .54135 Mtetra
.86 .656 .626 r
.76407 .54135 .76722 .55109 .77199 .53139 .76882 .52127 Mtetra
.846 .647 .633 r
.76882 .52127 .77199 .53139 .77673 .51205 .77365 .50291 Mtetra
.833 .649 .654 r
.77365 .50291 .77673 .51205 .78167 .49592 .7787 .48822 Mtetra
.819 .66 .685 r
.7787 .48822 .78167 .49592 .78687 .48365 .78402 .47727 Mtetra
.802 .676 .725 r
.78402 .47727 .78687 .48365 .79231 .4747 .78956 .46936 Mtetra
.781 .695 .769 r
.78956 .46936 .79231 .4747 .79795 .46824 .79526 .46361 Mtetra
.756 .711 .81 r
.79526 .46361 .79795 .46824 .80373 .46348 .80109 .45933 Mtetra
.731 .723 .843 r
.80109 .45933 .80373 .46348 .80961 .45984 .80701 .45601 Mtetra
.706 .731 .87 r
.80701 .45601 .80961 .45984 .81556 .45694 .81299 .45336 Mtetra
.68 .736 .893 r
.81299 .45336 .81556 .45694 .82156 .45458 .81902 .45124 Mtetra
.647 .739 .916 r
.81902 .45124 .82156 .45458 .82762 .45267 .82512 .44964 Mtetra
.584 .735 .947 r
.82512 .44964 .82762 .45267 .83375 .45129 .83131 .44879 Mtetra
.407 .691 .978 r
.83131 .44879 .83375 .45129 .83996 .45074 .83763 .44927 Mtetra
0 .354 .743 r
.83763 .44927 .83996 .45074 .84635 .45172 .84422 .45222 Mtetra
.763 .256 0 r
.84422 .45222 .84635 .45172 .85305 .45558 .8513 .45981 Mtetra
.85 .459 .306 r
.8513 .45981 .85305 .45558 .86033 .46485 .85928 .47572 Mtetra
.853 .516 .414 r
.85928 .47572 .86033 .46485 .86866 .48361 .86871 .50491 Mtetra
.838 .527 .462 r
.86871 .50491 .86866 .48361 .87861 .51678 .87996 .55006 Mtetra
.804 .509 .49 r
.87996 .55006 .87861 .51678 .89035 .56515 .89209 .60159 Mtetra
.723 .445 .506 r
.89209 .60159 .89035 .56515 .90239 .6143 .90198 .63058 Mtetra
.108 0 .347 r
.90198 .63058 .90239 .6143 .91119 .63264 .90677 .61247 Mtetra
.888 .632 .545 r
.90677 .61247 .91119 .63264 .91468 .60339 .90772 .56086 Mtetra
.799 .552 .564 r
.90772 .56086 .91468 .60339 .91513 .54871 .90832 .50775 Mtetra
.762 .527 .577 r
.90832 .50775 .91513 .54871 .91592 .49862 .91045 .46934 Mtetra
.746 .526 .597 r
.91045 .46934 .91592 .49862 .91843 .4643 .9142 .4457 Mtetra
.738 .542 .628 r
.9142 .4457 .91843 .4643 .92248 .44363 .91909 .43197 Mtetra
.733 .575 .677 r
.91909 .43197 .92248 .44363 .92754 .43164 .92464 .42392 Mtetra
.726 .62 .739 r
.92464 .42392 .92754 .43164 .9332 .42453 .93055 .41887 Mtetra
.714 .665 .801 r
.93055 .41887 .9332 .42453 .93917 .41998 .93667 .41537 Mtetra
.698 .699 .847 r
.93667 .41537 .93917 .41998 .94531 .41676 .94289 .41265 Mtetra
.684 .718 .875 r
.94289 .41265 .94531 .41676 .95156 .41418 .94917 .41033 Mtetra
.674 .728 .89 r
.94917 .41033 .95156 .41418 .95785 .41191 .9555 .4082 Mtetra
.668 .736 .901 r
.38355 .57875 .38668 .58176 .39188 .58009 .38875 .5771 Mtetra
.665 .738 .904 r
.38875 .5771 .39188 .58009 .3971 .57845 .39397 .57549 Mtetra
.664 .74 .906 r
.39397 .57549 .3971 .57845 .40232 .57682 .3992 .57388 Mtetra
.665 .741 .907 r
.3992 .57388 .40232 .57682 .40755 .57521 .40443 .57227 Mtetra
.665 .742 .907 r
.40443 .57227 .40755 .57521 .41279 .57362 .40968 .57065 Mtetra
.664 .741 .907 r
.40968 .57065 .41279 .57362 .41804 .57202 .41494 .56905 Mtetra
.664 .74 .907 r
.41494 .56905 .41804 .57202 .4233 .57041 .4202 .56743 Mtetra
.663 .74 .907 r
.4202 .56743 .4233 .57041 .42857 .5688 .42548 .56583 Mtetra
.664 .741 .908 r
.42548 .56583 .42857 .5688 .43385 .56719 .43077 .56421 Mtetra
.664 .741 .907 r
.43077 .56421 .43385 .56719 .43914 .56557 .43606 .56258 Mtetra
.43606 .56258 .43914 .56557 .44444 .56396 .44137 .56096 Mtetra
.664 .74 .907 r
.44137 .56096 .44444 .56396 .44975 .56234 .44669 .55933 Mtetra
.44669 .55933 .44975 .56234 .45508 .56071 .45202 .55771 Mtetra
.664 .741 .908 r
.45202 .55771 .45508 .56071 .46041 .55908 .45736 .55608 Mtetra
.665 .742 .908 r
.45736 .55608 .46041 .55908 .46575 .55745 .46271 .55443 Mtetra
.664 .741 .907 r
.46271 .55443 .46575 .55745 .4711 .55582 .46807 .55279 Mtetra
.46807 .55279 .4711 .55582 .47647 .55419 .47344 .55115 Mtetra
.664 .74 .907 r
.47344 .55115 .47647 .55419 .48184 .55254 .47882 .54951 Mtetra
.664 .741 .908 r
.47882 .54951 .48184 .55254 .48723 .5509 .48422 .54786 Mtetra
.664 .742 .908 r
.48422 .54786 .48723 .5509 .49263 .54925 .48962 .5462 Mtetra
.664 .741 .907 r
.48962 .5462 .49263 .54925 .49803 .5476 .49503 .54455 Mtetra
.49503 .54455 .49803 .5476 .50345 .54595 .50046 .54289 Mtetra
.50046 .54289 .50345 .54595 .50888 .5443 .50589 .54122 Mtetra
.664 .74 .907 r
.50589 .54122 .50888 .5443 .51432 .54264 .51134 .53956 Mtetra
.664 .741 .907 r
.51134 .53956 .51432 .54264 .51977 .54097 .5168 .53789 Mtetra
.5168 .53789 .51977 .54097 .52523 .5393 .52226 .53622 Mtetra
.52226 .53622 .52523 .5393 .5307 .53763 .52774 .53454 Mtetra
.52774 .53454 .5307 .53763 .53618 .53597 .53323 .53286 Mtetra
.664 .74 .907 r
.53323 .53286 .53618 .53597 .54168 .53429 .53873 .53118 Mtetra
.663 .74 .907 r
.53873 .53118 .54168 .53429 .54718 .5326 .54424 .5295 Mtetra
.664 .741 .908 r
.54424 .5295 .54718 .5326 .5527 .53092 .54977 .52781 Mtetra
.665 .742 .908 r
.54977 .52781 .5527 .53092 .55822 .52923 .5553 .52611 Mtetra
.664 .741 .907 r
.5553 .52611 .55822 .52923 .56376 .52755 .56084 .52441 Mtetra
.664 .74 .907 r
.56084 .52441 .56376 .52755 .56931 .52585 .5664 .52272 Mtetra
.663 .74 .907 r
.5664 .52272 .56931 .52585 .57487 .52415 .57197 .52102 Mtetra
.664 .741 .908 r
.57197 .52102 .57487 .52415 .58044 .52245 .57755 .51932 Mtetra
.665 .742 .908 r
.57755 .51932 .58044 .52245 .58602 .52075 .58314 .5176 Mtetra
.664 .741 .907 r
.58314 .5176 .58602 .52075 .59161 .51904 .58874 .51588 Mtetra
.58874 .51588 .59161 .51904 .59722 .51734 .59435 .51417 Mtetra
.663 .74 .907 r
.59435 .51417 .59722 .51734 .60283 .51563 .59997 .51246 Mtetra
.664 .741 .908 r
.59997 .51246 .60283 .51563 .60846 .51391 .60561 .51074 Mtetra
.664 .741 .907 r
.60561 .51074 .60846 .51391 .6141 .51218 .61125 .509 Mtetra
.61125 .509 .6141 .51218 .61975 .51046 .61691 .50727 Mtetra
.663 .741 .908 r
.61691 .50727 .61975 .51046 .62541 .50874 .62258 .50554 Mtetra
.62258 .50554 .62541 .50874 .63108 .50703 .62826 .50382 Mtetra
.663 .74 .907 r
.62826 .50382 .63108 .50703 .63677 .5053 .63395 .50209 Mtetra
.662 .74 .908 r
.63395 .50209 .63677 .5053 .64247 .50357 .63966 .50037 Mtetra
.661 .741 .909 r
.63966 .50037 .64247 .50357 .64817 .50186 .64537 .49867 Mtetra
.66 .742 .911 r
.64537 .49867 .64817 .50186 .6539 .50018 .6511 .49698 Mtetra
.657 .741 .911 r
.6511 .49698 .6539 .50018 .65963 .49853 .65685 .49533 Mtetra
.652 .739 .913 r
.65685 .49533 .65963 .49853 .66538 .49693 .66261 .49375 Mtetra
.643 .738 .918 r
.66261 .49375 .66538 .49693 .67115 .49541 .66838 .4923 Mtetra
.628 .738 .926 r
.66838 .4923 .67115 .49541 .67693 .49405 .67418 .49102 Mtetra
.603 .734 .937 r
.67418 .49102 .67693 .49405 .68274 .49296 .68 .49003 Mtetra
.555 .723 .952 r
.68 .49003 .68274 .49296 .68859 .49226 .68587 .48953 Mtetra
.452 .692 .969 r
.68587 .48953 .68859 .49226 .69448 .49222 .69179 .48983 Mtetra
.216 .59 .946 r
.69179 .48983 .69448 .49222 .70045 .49321 .69779 .49136 Mtetra
0 .281 .704 r
.69779 .49136 .70045 .49321 .70653 .49581 .70392 .49475 Mtetra
.682 .138 0 r
.70392 .49475 .70653 .49581 .71277 .50078 .71023 .5008 Mtetra
.831 .366 .099 r
.71023 .5008 .71277 .50078 .71923 .50896 .71678 .51038 Mtetra
.866 .457 .251 r
.71678 .51038 .71923 .50896 .72597 .52098 .72361 .52385 Mtetra
.868 .486 .318 r
.72361 .52385 .72597 .52098 .73299 .53642 .73069 .54009 Mtetra
.853 .474 .331 r
.73069 .54009 .73299 .53642 .74014 .55276 .73779 .55556 Mtetra
.796 .376 .249 r
.73779 .55556 .74014 .55276 .7471 .56498 .74456 .56472 Mtetra
.435 .868 .917 r
.74456 .56472 .7471 .56498 .75348 .56763 .75066 .56298 Mtetra
.89 .74 .689 r
.75066 .56298 .75348 .56763 .75908 .5587 .75602 .55029 Mtetra
.871 .673 .633 r
.75602 .55029 .75908 .5587 .76407 .54135 .7609 .53123 Mtetra
.854 .651 .627 r
.7609 .53123 .76407 .54135 .76882 .52127 .76568 .51137 Mtetra
.841 .646 .639 r
.76568 .51137 .76882 .52127 .77365 .50291 .7706 .49427 Mtetra
.828 .652 .664 r
.7706 .49427 .77365 .50291 .7787 .48822 .77578 .48104 Mtetra
.813 .665 .7 r
.77578 .48104 .7787 .48822 .78402 .47727 .7812 .47133 Mtetra
.795 .684 .742 r
.7812 .47133 .78402 .47727 .78956 .46936 .78682 .46431 Mtetra
.772 .701 .785 r
.78682 .46431 .78956 .46936 .79526 .46361 .79258 .45917 Mtetra
.746 .716 .823 r
.79258 .45917 .79526 .46361 .80109 .45933 .79845 .4553 Mtetra
.72 .726 .855 r
.79845 .4553 .80109 .45933 .80701 .45601 .8044 .45229 Mtetra
.693 .734 .882 r
.8044 .45229 .80701 .45601 .81299 .45336 .81042 .44991 Mtetra
.662 .738 .906 r
.81042 .44991 .81299 .45336 .81902 .45124 .81649 .44808 Mtetra
.61 .737 .936 r
.81649 .44808 .81902 .45124 .82512 .44964 .82264 .44695 Mtetra
.477 .712 .973 r
.82264 .44695 .82512 .44964 .83131 .44879 .82892 .44699 Mtetra
.019 .5 .875 r
.82892 .44699 .83131 .44879 .83763 .44927 .83542 .44915 Mtetra
.69 .146 0 r
.83542 .44915 .83763 .44927 .84422 .45222 .84233 .45528 Mtetra
.842 .431 .258 r
.84233 .45528 .84422 .45222 .8513 .45981 .85 .46867 Mtetra
.855 .508 .396 r
.85 .46867 .8513 .45981 .85928 .47572 .85896 .4941 Mtetra
.843 .527 .453 r
.85896 .4941 .85928 .47572 .86871 .50491 .86967 .53546 Mtetra
.815 .516 .484 r
.86967 .53546 .86871 .50491 .87996 .55006 .88168 .58744 Mtetra
.752 .469 .503 r
.88168 .58744 .87996 .55006 .89209 .60159 .89241 .62534 Mtetra
.482 .24 .47 r
.89241 .62534 .89209 .60159 .90198 .63058 .89855 .61939 Mtetra
.934 .68 .53 r
.89855 .61939 .90198 .63058 .90677 .61247 .90023 .57304 Mtetra
.814 .564 .561 r
.90023 .57304 .90677 .61247 .90772 .56086 .90075 .51788 Mtetra
.769 .531 .574 r
.90075 .51788 .90772 .56086 .90832 .50775 .90252 .47534 Mtetra
.749 .524 .591 r
.90252 .47534 .90832 .50775 .91045 .46934 .90597 .44841 Mtetra
.739 .536 .619 r
.90597 .44841 .91045 .46934 .9142 .4457 .91065 .43265 Mtetra
.735 .566 .663 r
.91065 .43265 .9142 .4457 .91909 .43197 .91608 .42347 Mtetra
.729 .609 .723 r
.91608 .42347 .91909 .43197 .92464 .42392 .92193 .41783 Mtetra
.717 .654 .786 r
.92193 .41783 .92464 .42392 .93055 .41887 .92801 .41403 Mtetra
.701 .69 .837 r
.92801 .41403 .93055 .41887 .93667 .41537 .93421 .41117 Mtetra
.687 .714 .87 r
.93421 .41117 .93667 .41537 .94289 .41265 .94048 .40878 Mtetra
.677 .728 .889 r
.94048 .40878 .94289 .41265 .94917 .41033 .9468 .4066 Mtetra
.671 .735 .898 r
.9468 .4066 .94917 .41033 .9555 .4082 .95314 .40453 Mtetra
.666 .739 .905 r
.3804 .57577 .38355 .57875 .38875 .5771 .38561 .57414 Mtetra
.665 .74 .906 r
.38561 .57414 .38875 .5771 .39397 .57549 .39083 .57252 Mtetra
.39083 .57252 .39397 .57549 .3992 .57388 .39607 .5709 Mtetra
.664 .74 .906 r
.39607 .5709 .3992 .57388 .40443 .57227 .40131 .5693 Mtetra
.664 .74 .907 r
.40131 .5693 .40443 .57227 .40968 .57065 .40656 .56769 Mtetra
.664 .741 .908 r
.40656 .56769 .40968 .57065 .41494 .56905 .41182 .56607 Mtetra
.664 .741 .907 r
.41182 .56607 .41494 .56905 .4202 .56743 .4171 .56445 Mtetra
.4171 .56445 .4202 .56743 .42548 .56583 .42238 .56283 Mtetra
.664 .74 .907 r
.42238 .56283 .42548 .56583 .43077 .56421 .42767 .56121 Mtetra
.42767 .56121 .43077 .56421 .43606 .56258 .43298 .55959 Mtetra
.664 .741 .908 r
.43298 .55959 .43606 .56258 .44137 .56096 .43829 .55796 Mtetra
.664 .741 .907 r
.43829 .55796 .44137 .56096 .44669 .55933 .44362 .55632 Mtetra
.44362 .55632 .44669 .55933 .45202 .55771 .44895 .55468 Mtetra
.664 .74 .907 r
.44895 .55468 .45202 .55771 .45736 .55608 .4543 .55305 Mtetra
.4543 .55305 .45736 .55608 .46271 .55443 .45966 .5514 Mtetra
.663 .741 .908 r
.45966 .5514 .46271 .55443 .46807 .55279 .46502 .54976 Mtetra
.664 .741 .908 r
.46502 .54976 .46807 .55279 .47344 .55115 .4704 .54811 Mtetra
.664 .741 .907 r
.4704 .54811 .47344 .55115 .47882 .54951 .47579 .54646 Mtetra
.664 .74 .907 r
.47579 .54646 .47882 .54951 .48422 .54786 .48119 .5448 Mtetra
.48119 .5448 .48422 .54786 .48962 .5462 .4866 .54314 Mtetra
.663 .741 .908 r
.4866 .54314 .48962 .5462 .49503 .54455 .49202 .54149 Mtetra
.664 .742 .908 r
.49202 .54149 .49503 .54455 .50046 .54289 .49745 .53982 Mtetra
.664 .741 .907 r
.49745 .53982 .50046 .54289 .50589 .54122 .50289 .53815 Mtetra
.50289 .53815 .50589 .54122 .51134 .53956 .50835 .53647 Mtetra
.664 .74 .907 r
.50835 .53647 .51134 .53956 .5168 .53789 .51381 .5348 Mtetra
.663 .74 .907 r
.51381 .5348 .5168 .53789 .52226 .53622 .51929 .53313 Mtetra
.664 .741 .908 r
.51929 .53313 .52226 .53622 .52774 .53454 .52477 .53145 Mtetra
.664 .741 .907 r
.52477 .53145 .52774 .53454 .53323 .53286 .53027 .52975 Mtetra
.53027 .52975 .53323 .53286 .53873 .53118 .53578 .52806 Mtetra
.53578 .52806 .53873 .53118 .54424 .5295 .5413 .52637 Mtetra
.664 .74 .907 r
.5413 .52637 .54424 .5295 .54977 .52781 .54683 .52468 Mtetra
.54683 .52468 .54977 .52781 .5553 .52611 .55237 .52298 Mtetra
.664 .741 .908 r
.55237 .52298 .5553 .52611 .56084 .52441 .55792 .52128 Mtetra
.664 .741 .907 r
.55792 .52128 .56084 .52441 .5664 .52272 .56348 .51957 Mtetra
.56348 .51957 .5664 .52272 .57197 .52102 .56906 .51786 Mtetra
.664 .74 .907 r
.56906 .51786 .57197 .52102 .57755 .51932 .57464 .51615 Mtetra
.57464 .51615 .57755 .51932 .58314 .5176 .58024 .51443 Mtetra
.663 .741 .908 r
.58024 .51443 .58314 .5176 .58874 .51588 .58585 .51272 Mtetra
.664 .742 .908 r
.58585 .51272 .58874 .51588 .59435 .51417 .59147 .511 Mtetra
.664 .741 .907 r
.59147 .511 .59435 .51417 .59997 .51246 .5971 .50926 Mtetra
.664 .74 .907 r
.5971 .50926 .59997 .51246 .60561 .51074 .60274 .50753 Mtetra
.663 .74 .907 r
.60274 .50753 .60561 .51074 .61125 .509 .60839 .50581 Mtetra
.663 .741 .908 r
.60839 .50581 .61125 .509 .61691 .50727 .61406 .50409 Mtetra
.664 .742 .908 r
.61406 .50409 .61691 .50727 .62258 .50554 .61974 .50235 Mtetra
.61974 .50235 .62258 .50554 .62826 .50382 .62543 .5006 Mtetra
.663 .74 .907 r
.62543 .5006 .62826 .50382 .63395 .50209 .63113 .49886 Mtetra
.661 .74 .908 r
.63113 .49886 .63395 .50209 .63966 .50037 .63684 .49716 Mtetra
.66 .74 .909 r
.63684 .49716 .63966 .50037 .64537 .49867 .64256 .49546 Mtetra
.659 .741 .911 r
.64256 .49546 .64537 .49867 .6511 .49698 .6483 .49378 Mtetra
.656 .741 .912 r
.6483 .49378 .6511 .49698 .65685 .49533 .65405 .49214 Mtetra
.649 .74 .916 r
.65405 .49214 .65685 .49533 .66261 .49375 .65982 .49059 Mtetra
.638 .738 .921 r
.65982 .49059 .66261 .49375 .66838 .4923 .66561 .48919 Mtetra
.621 .736 .929 r
.66561 .48919 .66838 .4923 .67418 .49102 .67142 .488 Mtetra
.588 .73 .941 r
.67142 .488 .67418 .49102 .68 .49003 .67726 .48717 Mtetra
.524 .715 .959 r
.67726 .48717 .68 .49003 .68587 .48953 .68314 .48693 Mtetra
.384 .668 .971 r
.68314 .48693 .68587 .48953 .69179 .48983 .68909 .48762 Mtetra
.067 .507 .896 r
.68909 .48762 .69179 .48983 .69779 .49136 .69513 .48974 Mtetra
.446 0 0 r
.69513 .48974 .69779 .49136 .70392 .49475 .70131 .49402 Mtetra
.761 .247 0 r
.70131 .49402 .70392 .49475 .71023 .5008 .7077 .50133 Mtetra
.851 .411 .171 r
.7077 .50133 .71023 .5008 .71678 .51038 .71434 .51239 Mtetra
.869 .473 .284 r
.71434 .51239 .71678 .51038 .72361 .52385 .72126 .52713 Mtetra
.864 .487 .329 r
.72126 .52713 .72361 .52385 .73069 .54009 .72836 .54364 Mtetra
.841 .455 .318 r
.72836 .54364 .73069 .54009 .73779 .55556 .73536 .55745 Mtetra
.716 .239 .115 r
.73536 .55745 .73779 .55556 .74456 .56472 .74191 .56289 Mtetra
.869 .878 .84 r
.74191 .56289 .74456 .56472 .75066 .56298 .74772 .55673 Mtetra
.883 .705 .656 r
.74772 .55673 .75066 .56298 .75602 .55029 .75289 .54094 Mtetra
.864 .662 .628 r
.75289 .54094 .75602 .55029 .7609 .53123 .75772 .52098 Mtetra
.849 .647 .63 r
.75772 .52098 .7609 .53123 .76568 .51137 .76256 .50188 Mtetra
.836 .647 .647 r
.76256 .50188 .76568 .51137 .7706 .49427 .7676 .48619 Mtetra
.823 .657 .676 r
.7676 .48619 .7706 .49427 .77578 .48104 .77289 .47434 Mtetra
.807 .672 .715 r
.77289 .47434 .77578 .48104 .7812 .47133 .7784 .46572 Mtetra
.786 .69 .758 r
.7784 .46572 .7812 .47133 .78682 .46431 .78409 .4595 Mtetra
.762 .707 .8 r
.78409 .4595 .78682 .46431 .79258 .45917 .78991 .45492 Mtetra
.736 .721 .838 r
.78991 .45492 .79258 .45917 .79845 .4553 .79582 .45143 Mtetra
.709 .731 .868 r
.79582 .45143 .79845 .4553 .8044 .45229 .8018 .4487 Mtetra
.678 .736 .894 r
.8018 .4487 .8044 .45229 .81042 .44991 .80785 .44661 Mtetra
.631 .737 .924 r
.80785 .44661 .81042 .44991 .81649 .44808 .81398 .44522 Mtetra
.53 .725 .963 r
.81398 .44522 .81649 .44808 .82264 .44695 .82021 .44487 Mtetra
.195 .601 .945 r
.82021 .44487 .82264 .44695 .82892 .44699 .82663 .44633 Mtetra
.571 0 0 r
.82663 .44633 .82892 .44699 .83542 .44915 .83339 .4512 Mtetra
.829 .391 .194 r
.83339 .4512 .83542 .44915 .84233 .45528 .8408 .46236 Mtetra
.855 .497 .373 r
.8408 .46236 .84233 .45528 .85 .46867 .84933 .48431 Mtetra
.847 .526 .443 r
.84933 .48431 .85 .46867 .85896 .4941 .85951 .52163 Mtetra
.824 .522 .478 r
.85951 .52163 .85896 .4941 .86967 .53546 .87123 .57246 Mtetra
.773 .486 .5 r
.87123 .57246 .86967 .53546 .88168 .58744 .88253 .61714 Mtetra
.615 .353 .497 r
.88253 .61714 .88168 .58744 .89241 .62534 .88999 .6236 Mtetra
.991 .756 .482 r
.88999 .6236 .89241 .62534 .89855 .61939 .8926 .58476 Mtetra
.832 .579 .557 r
.8926 .58476 .89855 .61939 .90023 .57304 .89321 .52891 Mtetra
.777 .536 .57 r
.89321 .52891 .90023 .57304 .90075 .51788 .89466 .48236 Mtetra
.752 .524 .586 r
.89466 .48236 .90075 .51788 .90252 .47534 .89777 .45182 Mtetra
.741 .532 .61 r
.89777 .45182 .90252 .47534 .90597 .44841 .90222 .43373 Mtetra
.736 .557 .65 r
.90222 .43373 .90597 .44841 .91065 .43265 .90752 .42323 Mtetra
.73 .597 .707 r
.90752 .42323 .91065 .43265 .91608 .42347 .9133 .41691 Mtetra
.72 .643 .771 r
.9133 .41691 .91608 .42347 .92193 .41783 .91934 .41276 Mtetra
.705 .683 .826 r
.91934 .41276 .92193 .41783 .92801 .41403 .92552 .40971 Mtetra
.69 .71 .863 r
.92552 .40971 .92801 .41403 .93421 .41117 .93178 .40722 Mtetra
.679 .725 .884 r
.93178 .40722 .93421 .41117 .94048 .40878 .93808 .40499 Mtetra
.672 .732 .895 r
.93808 .40499 .94048 .40878 .9468 .4066 .94442 .40291 Mtetra
.668 .736 .901 r
.94442 .40291 .9468 .4066 .95314 .40453 .95078 .40089 Mtetra
.666 .74 .905 r
.37724 .57279 .3804 .57577 .38561 .57414 .38246 .57116 Mtetra
.665 .74 .906 r
.38246 .57116 .38561 .57414 .39083 .57252 .38768 .56955 Mtetra
.664 .74 .907 r
.38768 .56955 .39083 .57252 .39607 .5709 .39292 .56794 Mtetra
.664 .741 .908 r
.39292 .56794 .39607 .5709 .40131 .5693 .39817 .56632 Mtetra
.664 .741 .907 r
.39817 .56632 .40131 .5693 .40656 .56769 .40343 .5647 Mtetra
.664 .74 .907 r
.40343 .5647 .40656 .56769 .41182 .56607 .4087 .56308 Mtetra
.664 .741 .907 r
.4087 .56308 .41182 .56607 .4171 .56445 .41398 .56146 Mtetra
.41398 .56146 .4171 .56445 .42238 .56283 .41927 .55984 Mtetra
.41927 .55984 .42238 .56283 .42767 .56121 .42457 .5582 Mtetra
.42457 .5582 .42767 .56121 .43298 .55959 .42988 .55657 Mtetra
.664 .74 .907 r
.42988 .55657 .43298 .55959 .43829 .55796 .4352 .55494 Mtetra
.4352 .55494 .43829 .55796 .44362 .55632 .44053 .5533 Mtetra
.664 .741 .908 r
.44053 .5533 .44362 .55632 .44895 .55468 .44588 .55166 Mtetra
.664 .741 .907 r
.44588 .55166 .44895 .55468 .4543 .55305 .45123 .55001 Mtetra
.45123 .55001 .4543 .55305 .45966 .5514 .45659 .54836 Mtetra
.45659 .54836 .45966 .5514 .46502 .54976 .46197 .54671 Mtetra
.664 .74 .907 r
.46197 .54671 .46502 .54976 .4704 .54811 .46735 .54506 Mtetra
.663 .741 .907 r
.46735 .54506 .4704 .54811 .47579 .54646 .47275 .5434 Mtetra
.664 .741 .908 r
.47275 .5434 .47579 .54646 .48119 .5448 .47815 .54174 Mtetra
.664 .741 .907 r
.47815 .54174 .48119 .5448 .4866 .54314 .48357 .54007 Mtetra
.48357 .54007 .4866 .54314 .49202 .54149 .489 .5384 Mtetra
.664 .74 .907 r
.489 .5384 .49202 .54149 .49745 .53982 .49444 .53673 Mtetra
.663 .74 .907 r
.49444 .53673 .49745 .53982 .50289 .53815 .49989 .53506 Mtetra
.664 .741 .908 r
.49989 .53506 .50289 .53815 .50835 .53647 .50535 .53339 Mtetra
.664 .741 .907 r
.50535 .53339 .50835 .53647 .51381 .5348 .51082 .5317 Mtetra
.51082 .5317 .51381 .5348 .51929 .53313 .5163 .53001 Mtetra
.664 .74 .907 r
.5163 .53001 .51929 .53313 .52477 .53145 .52179 .52832 Mtetra
.663 .74 .907 r
.52179 .52832 .52477 .53145 .53027 .52975 .5273 .52664 Mtetra
.664 .741 .908 r
.5273 .52664 .53027 .52975 .53578 .52806 .53281 .52495 Mtetra
.665 .742 .908 r
.53281 .52495 .53578 .52806 .5413 .52637 .53834 .52324 Mtetra
.664 .741 .907 r
.53834 .52324 .5413 .52637 .54683 .52468 .54387 .52154 Mtetra
.54387 .52154 .54683 .52468 .55237 .52298 .54942 .51983 Mtetra
.664 .74 .907 r
.54942 .51983 .55237 .52298 .55792 .52128 .55498 .51813 Mtetra
.663 .741 .908 r
.55498 .51813 .55792 .52128 .56348 .51957 .56055 .51642 Mtetra
.664 .742 .908 r
.56055 .51642 .56348 .51957 .56906 .51786 .56613 .5147 Mtetra
.664 .741 .907 r
.56613 .5147 .56906 .51786 .57464 .51615 .57173 .51298 Mtetra
.57173 .51298 .57464 .51615 .58024 .51443 .57733 .51125 Mtetra
.57733 .51125 .58024 .51443 .58585 .51272 .58295 .50953 Mtetra
.663 .74 .907 r
.58295 .50953 .58585 .51272 .59147 .511 .58858 .50781 Mtetra
.664 .741 .907 r
.58858 .50781 .59147 .511 .5971 .50926 .59421 .50607 Mtetra
.664 .741 .908 r
.59421 .50607 .5971 .50926 .60274 .50753 .59986 .50433 Mtetra
.59986 .50433 .60274 .50753 .60839 .50581 .60553 .50259 Mtetra
.664 .74 .907 r
.60553 .50259 .60839 .50581 .61406 .50409 .6112 .50085 Mtetra
.663 .739 .907 r
.6112 .50085 .61406 .50409 .61974 .50235 .61688 .49912 Mtetra
.662 .74 .908 r
.61688 .49912 .61974 .50235 .62543 .5006 .62258 .49739 Mtetra
.662 .742 .909 r
.62258 .49739 .62543 .5006 .63113 .49886 .62829 .49566 Mtetra
.662 .742 .91 r
.62829 .49566 .63113 .49886 .63684 .49716 .63401 .49393 Mtetra
.661 .741 .909 r
.63401 .49393 .63684 .49716 .64256 .49546 .63974 .49221 Mtetra
.657 .739 .91 r
.63974 .49221 .64256 .49546 .6483 .49378 .64549 .49055 Mtetra
.652 .739 .913 r
.64549 .49055 .6483 .49378 .65405 .49214 .65125 .48896 Mtetra
.645 .74 .918 r
.65125 .48896 .65405 .49214 .65982 .49059 .65703 .48746 Mtetra
.634 .739 .924 r
.65703 .48746 .65982 .49059 .66561 .48919 .66283 .4861 Mtetra
.612 .735 .933 r
.66283 .4861 .66561 .48919 .67142 .488 .66865 .485 Mtetra
.569 .725 .947 r
.66865 .485 .67142 .488 .67726 .48717 .6745 .48437 Mtetra
.483 .702 .966 r
.6745 .48437 .67726 .48717 .68314 .48693 .68041 .48444 Mtetra
.294 .629 .962 r
.68041 .48444 .68314 .48693 .68909 .48762 .68639 .48559 Mtetra
0 .386 .801 r
.68639 .48559 .68909 .48762 .69513 .48974 .69248 .48843 Mtetra
.605 .047 0 r
.69248 .48843 .69513 .48974 .70131 .49402 .69872 .49373 Mtetra
.81 .327 .041 r
.69872 .49373 .70131 .49402 .7077 .50133 .70518 .50238 Mtetra
.862 .442 .224 r
.70518 .50238 .7077 .50133 .71434 .51239 .71192 .51491 Mtetra
.869 .483 .306 r
.71192 .51491 .71434 .51239 .72126 .52713 .7189 .53069 Mtetra
.859 .482 .333 r
.7189 .53069 .72126 .52713 .72836 .54364 .72598 .54685 Mtetra
.82 .418 .288 r
.72598 .54685 .72836 .54364 .73536 .55745 .73285 .55815 Mtetra
.353 0 0 r
.73285 .55815 .73536 .55745 .74191 .56289 .73913 .55934 Mtetra
.893 .777 .727 r
.73913 .55934 .74191 .56289 .74772 .55673 .74469 .54905 Mtetra
.875 .683 .639 r
.74469 .54905 .74772 .55673 .75289 .54094 .74971 .531 Mtetra
.858 .654 .626 r
.74971 .531 .75289 .54094 .75772 .52098 .75455 .51088 Mtetra
.844 .646 .635 r
.75455 .51088 .75772 .52098 .76256 .50188 .75947 .49287 Mtetra
.831 .65 .657 r
.75947 .49287 .76256 .50188 .7676 .48619 .76463 .47862 Mtetra
.817 .661 .69 r
.76463 .47862 .7676 .48619 .77289 .47434 .77002 .46807 Mtetra
.799 .678 .731 r
.77002 .46807 .77289 .47434 .7784 .46572 .77562 .46047 Mtetra
.778 .697 .775 r
.77562 .46047 .7784 .46572 .78409 .4595 .78137 .45494 Mtetra
.752 .714 .816 r
.78137 .45494 .78409 .4595 .78991 .45492 .78724 .45081 Mtetra
.724 .725 .85 r
.78724 .45081 .78991 .45492 .79582 .45143 .79319 .44767 Mtetra
.693 .732 .881 r
.79319 .44767 .79582 .45143 .8018 .4487 .79921 .44528 Mtetra
.652 .737 .912 r
.79921 .44528 .8018 .4487 .80785 .44661 .8053 .4436 Mtetra
.572 .733 .951 r
.8053 .4436 .80785 .44661 .81398 .44522 .8115 .44287 Mtetra
.333 .664 .974 r
.8115 .44287 .81398 .44522 .82021 .44487 .81785 .44372 Mtetra
.39 0 0 r
.81785 .44372 .82021 .44487 .82663 .44633 .82449 .44751 Mtetra
.805 .335 .109 r
.82449 .44751 .82663 .44633 .83339 .4512 .83168 .45674 Mtetra
.853 .481 .345 r
.83168 .45674 .83339 .4512 .8408 .46236 .83983 .47551 Mtetra
.85 .522 .431 r
.83983 .47551 .8408 .46236 .84933 .48431 .84949 .50871 Mtetra
.832 .525 .471 r
.84949 .50871 .84933 .48431 .85951 .52163 .86081 .55715 Mtetra
.79 .499 .495 r
.86081 .55715 .85951 .52163 .87123 .57246 .87242 .60639 Mtetra
.682 .41 .504 r
.87242 .60639 .87123 .57246 .88253 .61714 .88106 .62478 Mtetra
.834 .733 .208 r
.88106 .62478 .88253 .61714 .88999 .6236 .88477 .59546 Mtetra
.856 .601 .553 r
.88477 .59546 .88999 .6236 .8926 .58476 .88566 .54064 Mtetra
.787 .543 .567 r
.88566 .54064 .8926 .58476 .89321 .52891 .88685 .49043 Mtetra
.757 .525 .581 r
.88685 .49043 .89321 .52891 .89466 .48236 .88962 .45601 Mtetra
.743 .528 .603 r
.88962 .45601 .89466 .48236 .89777 .45182 .89382 .43528 Mtetra
.737 .549 .639 r
.89382 .43528 .89777 .45182 .90222 .43373 .89897 .42325 Mtetra
.732 .586 .692 r
.89897 .42325 .90222 .43373 .90752 .42323 .90466 .41611 Mtetra
.723 .632 .755 r
.90466 .41611 .90752 .42323 .9133 .41691 .91066 .41155 Mtetra
.709 .674 .814 r
.91066 .41155 .9133 .41691 .91934 .41276 .91681 .40829 Mtetra
.694 .705 .856 r
.91681 .40829 .91934 .41276 .92552 .40971 .92306 .40568 Mtetra
.682 .722 .88 r
.92306 .40568 .92552 .40971 .93178 .40722 .92935 .40339 Mtetra
.673 .731 .893 r
.92935 .40339 .93178 .40722 .93808 .40499 .93568 .40128 Mtetra
.668 .736 .901 r
.93568 .40128 .93808 .40499 .94442 .40291 .94204 .39925 Mtetra
.666 .739 .904 r
.94204 .39925 .94442 .40291 .95078 .40089 .94841 .39725 Mtetra
.664 .739 .906 r
.37406 .5698 .37724 .57279 .38246 .57116 .37929 .56819 Mtetra
.664 .74 .907 r
.37929 .56819 .38246 .57116 .38768 .56955 .38452 .56658 Mtetra
.664 .741 .907 r
.38452 .56658 .38768 .56955 .39292 .56794 .38977 .56496 Mtetra
.38977 .56496 .39292 .56794 .39817 .56632 .39502 .56333 Mtetra
.39502 .56333 .39817 .56632 .40343 .5647 .40029 .56171 Mtetra
.40029 .56171 .40343 .5647 .4087 .56308 .40557 .56008 Mtetra
.40557 .56008 .4087 .56308 .41398 .56146 .41085 .55846 Mtetra
.41085 .55846 .41398 .56146 .41927 .55984 .41615 .55682 Mtetra
.41615 .55682 .41927 .55984 .42457 .5582 .42146 .55519 Mtetra
.42146 .55519 .42457 .5582 .42988 .55657 .42677 .55355 Mtetra
.42677 .55355 .42988 .55657 .4352 .55494 .4321 .55191 Mtetra
.4321 .55191 .4352 .55494 .44053 .5533 .43744 .55026 Mtetra
.43744 .55026 .44053 .5533 .44588 .55166 .44279 .54862 Mtetra
.664 .74 .907 r
.44279 .54862 .44588 .55166 .45123 .55001 .44815 .54696 Mtetra
.664 .741 .907 r
.44815 .54696 .45123 .55001 .45659 .54836 .45352 .54531 Mtetra
.45352 .54531 .45659 .54836 .46197 .54671 .4589 .54366 Mtetra
.4589 .54366 .46197 .54671 .46735 .54506 .46429 .54199 Mtetra
.46429 .54199 .46735 .54506 .47275 .5434 .46969 .54033 Mtetra
.664 .74 .907 r
.46969 .54033 .47275 .5434 .47815 .54174 .47511 .53866 Mtetra
.663 .74 .907 r
.47511 .53866 .47815 .54174 .48357 .54007 .48053 .537 Mtetra
.664 .741 .908 r
.48053 .537 .48357 .54007 .489 .5384 .48596 .53532 Mtetra
.664 .741 .907 r
.48596 .53532 .489 .5384 .49444 .53673 .49141 .53364 Mtetra
.49141 .53364 .49444 .53673 .49989 .53506 .49687 .53196 Mtetra
.664 .74 .907 r
.49687 .53196 .49989 .53506 .50535 .53339 .50233 .53027 Mtetra
.663 .74 .907 r
.50233 .53027 .50535 .53339 .51082 .5317 .50781 .52859 Mtetra
.664 .741 .908 r
.50781 .52859 .51082 .5317 .5163 .53001 .5133 .5269 Mtetra
.664 .741 .907 r
.5133 .5269 .5163 .53001 .52179 .52832 .5188 .5252 Mtetra
.5188 .5252 .52179 .52832 .5273 .52664 .52431 .5235 Mtetra
.664 .74 .907 r
.52431 .5235 .5273 .52664 .53281 .52495 .52983 .5218 Mtetra
.52983 .5218 .53281 .52495 .53834 .52324 .53537 .5201 Mtetra
.664 .741 .908 r
.53537 .5201 .53834 .52324 .54387 .52154 .54091 .51839 Mtetra
.54091 .51839 .54387 .52154 .54942 .51983 .54647 .51668 Mtetra
.664 .741 .907 r
.54647 .51668 .54942 .51983 .55498 .51813 .55203 .51496 Mtetra
.664 .74 .907 r
.55203 .51496 .55498 .51813 .56055 .51642 .55761 .51324 Mtetra
.55761 .51324 .56055 .51642 .56613 .5147 .5632 .51152 Mtetra
.663 .74 .907 r
.5632 .51152 .56613 .5147 .57173 .51298 .5688 .5098 Mtetra
.664 .742 .908 r
.5688 .5098 .57173 .51298 .57733 .51125 .57441 .50807 Mtetra
.57441 .50807 .57733 .51125 .58295 .50953 .58004 .50633 Mtetra
.664 .741 .907 r
.58004 .50633 .58295 .50953 .58858 .50781 .58567 .5046 Mtetra
.664 .74 .907 r
.58567 .5046 .58858 .50781 .59421 .50607 .59132 .50286 Mtetra
.663 .74 .907 r
.59132 .50286 .59421 .50607 .59986 .50433 .59698 .50113 Mtetra
.664 .741 .908 r
.59698 .50113 .59986 .50433 .60553 .50259 .60265 .49939 Mtetra
.664 .742 .908 r
.60265 .49939 .60553 .50259 .6112 .50085 .60833 .49763 Mtetra
.664 .741 .908 r
.60833 .49763 .6112 .50085 .61688 .49912 .61402 .49588 Mtetra
.662 .74 .908 r
.61402 .49588 .61688 .49912 .62258 .49739 .61972 .49414 Mtetra
.661 .74 .908 r
.61972 .49414 .62258 .49739 .62829 .49566 .62544 .49242 Mtetra
.661 .74 .909 r
.62544 .49242 .62829 .49566 .63401 .49393 .63117 .4907 Mtetra
.659 .741 .91 r
.63117 .4907 .63401 .49393 .63974 .49221 .63691 .489 Mtetra
.656 .741 .912 r
.63691 .489 .63974 .49221 .64549 .49055 .64267 .48734 Mtetra
.651 .74 .915 r
.64267 .48734 .64549 .49055 .65125 .48896 .64844 .48576 Mtetra
.642 .738 .919 r
.64844 .48576 .65125 .48896 .65703 .48746 .65422 .48429 Mtetra
.626 .735 .926 r
.65422 .48429 .65703 .48746 .66283 .4861 .66003 .48303 Mtetra
.598 .732 .938 r
.66003 .48303 .66283 .4861 .66865 .485 .66587 .4821 Mtetra
.544 .722 .956 r
.66587 .4821 .66865 .485 .6745 .48437 .67174 .48167 Mtetra
.432 .687 .971 r
.67174 .48167 .6745 .48437 .68041 .48444 .67767 .48207 Mtetra
.175 .568 .935 r
.67767 .48207 .68041 .48444 .68639 .48559 .68369 .48376 Mtetra
0 .228 .653 r
.68369 .48376 .68639 .48559 .69248 .48843 .68982 .48744 Mtetra
.714 .181 0 r
.68982 .48744 .69248 .48843 .69872 .49373 .69614 .49392 Mtetra
.839 .383 .128 r
.69614 .49392 .69872 .49373 .70518 .50238 .70268 .504 Mtetra
.867 .463 .264 r
.70268 .504 .70518 .50238 .71192 .51491 .7095 .5179 Mtetra
.867 .487 .322 r
.7095 .5179 .71192 .51491 .7189 .53069 .71652 .53431 Mtetra
.85 .469 .328 r
.71652 .53431 .7189 .53069 .72598 .54685 .72355 .54937 Mtetra
.778 .343 .218 r
.72355 .54937 .72598 .54685 .73285 .55815 .73023 .55737 Mtetra
.713 .95 .953 r
.73023 .55737 .73285 .55815 .73913 .55934 .73624 .5541 Mtetra
.888 .726 .676 r
.73624 .5541 .73913 .55934 .74469 .54905 .74159 .54025 Mtetra
.868 .669 .631 r
.74159 .54025 .74469 .54905 .74971 .531 .74652 .52076 Mtetra
.852 .65 .628 r
.74652 .52076 .74971 .531 .75455 .51088 .7514 .50107 Mtetra
.839 .646 .642 r
.7514 .50107 .75455 .51088 .75947 .49287 .75642 .48438 Mtetra
.826 .653 .668 r
.75642 .48438 .75947 .49287 .76463 .47862 .76169 .47158 Mtetra
.811 .668 .705 r
.76169 .47158 .76463 .47862 .77002 .46807 .76718 .46223 Mtetra
.792 .686 .748 r
.76718 .46223 .77002 .46807 .77562 .46047 .77286 .45548 Mtetra
.768 .703 .791 r
.77286 .45548 .77562 .46047 .78137 .45494 .77866 .45055 Mtetra
.74 .718 .83 r
.77866 .45055 .78137 .45494 .78724 .45081 .78457 .44687 Mtetra
.71 .729 .865 r
.78457 .44687 .78724 .45081 .79319 .44767 .79056 .4441 Mtetra
.672 .736 .899 r
.79056 .4441 .79319 .44767 .79921 .44528 .79663 .4421 Mtetra
.606 .736 .937 r
.79663 .4421 .79921 .44528 .8053 .4436 .80278 .441 Mtetra
.433 .699 .977 r
.80278 .441 .8053 .4436 .8115 .44287 .80907 .44132 Mtetra
0 .37 .759 r
.80907 .44132 .8115 .44287 .81785 .44372 .81561 .44417 Mtetra
.763 .256 0 r
.81561 .44417 .81785 .44372 .82449 .44751 .82261 .45171 Mtetra
.85 .46 .308 r
.82261 .45171 .82449 .44751 .83168 .45674 .83044 .46761 Mtetra
.853 .517 .416 r
.83044 .46761 .83168 .45674 .83983 .47551 .8396 .49682 Mtetra
.838 .527 .463 r
.8396 .49682 .83983 .47551 .84949 .50871 .85046 .54202 Mtetra
.804 .509 .49 r
.85046 .54202 .84949 .50871 .86081 .55715 .86214 .59364 Mtetra
.723 .444 .504 r
.86214 .59364 .86081 .55715 .87242 .60639 .87177 .62269 Mtetra
.088 0 .332 r
.87177 .62269 .87242 .60639 .88106 .62478 .8767 .60454 Mtetra
.887 .632 .546 r
.8767 .60454 .88106 .62478 .88477 .59546 .87806 .5528 Mtetra
.799 .552 .564 r
.87806 .5528 .88477 .59546 .88566 .54064 .87909 .49957 Mtetra
.763 .527 .577 r
.87909 .49957 .88566 .54064 .88685 .49043 .88152 .46107 Mtetra
.746 .526 .596 r
.88152 .46107 .88685 .49043 .88962 .45601 .88545 .43735 Mtetra
.738 .542 .628 r
.88545 .43735 .88962 .45601 .89382 .43528 .89043 .42357 Mtetra
.733 .575 .677 r
.89043 .42357 .89382 .43528 .89897 .42325 .89603 .41548 Mtetra
.726 .62 .74 r
.89603 .41548 .89897 .42325 .90466 .41611 .90197 .41042 Mtetra
.714 .666 .801 r
.90197 .41042 .90466 .41611 .91066 .41155 .9081 .40689 Mtetra
.698 .698 .847 r
.9081 .40689 .91066 .41155 .91681 .40829 .91432 .40415 Mtetra
.684 .718 .875 r
.91432 .40415 .91681 .40829 .92306 .40568 .92061 .4018 Mtetra
.674 .729 .891 r
.92061 .4018 .92306 .40568 .92935 .40339 .92693 .39966 Mtetra
.669 .736 .9 r
.92693 .39966 .92935 .40339 .93568 .40128 .93328 .39761 Mtetra
.667 .739 .904 r
.93328 .39761 .93568 .40128 .94204 .39925 .93965 .39559 Mtetra
.666 .739 .905 r
.93965 .39559 .94204 .39925 .94841 .39725 .94604 .39359 Mtetra
.664 .741 .907 r
.37088 .56683 .37406 .5698 .37929 .56819 .37611 .56521 Mtetra
.665 .742 .907 r
.37611 .56521 .37929 .56819 .38452 .56658 .38135 .56358 Mtetra
.664 .74 .907 r
.38135 .56358 .38452 .56658 .38977 .56496 .3866 .56196 Mtetra
.3866 .56196 .38977 .56496 .39502 .56333 .39187 .56033 Mtetra
.663 .741 .908 r
.39187 .56033 .39502 .56333 .40029 .56171 .39714 .55871 Mtetra
.664 .741 .908 r
.39714 .55871 .40029 .56171 .40557 .56008 .40242 .55708 Mtetra
.664 .741 .907 r
.40242 .55708 .40557 .56008 .41085 .55846 .40771 .55544 Mtetra
.40771 .55544 .41085 .55846 .41615 .55682 .41302 .5538 Mtetra
.41302 .5538 .41615 .55682 .42146 .55519 .41833 .55216 Mtetra
.663 .741 .908 r
.41833 .55216 .42146 .55519 .42677 .55355 .42365 .55052 Mtetra
.664 .741 .907 r
.42365 .55052 .42677 .55355 .4321 .55191 .42899 .54887 Mtetra
.42899 .54887 .4321 .55191 .43744 .55026 .43433 .54722 Mtetra
.43433 .54722 .43744 .55026 .44279 .54862 .43969 .54557 Mtetra
.43969 .54557 .44279 .54862 .44815 .54696 .44506 .54391 Mtetra
.44506 .54391 .44815 .54696 .45352 .54531 .45043 .54225 Mtetra
.45043 .54225 .45352 .54531 .4589 .54366 .45582 .54058 Mtetra
.45582 .54058 .4589 .54366 .46429 .54199 .46122 .53892 Mtetra
.46122 .53892 .46429 .54199 .46969 .54033 .46663 .53725 Mtetra
.46663 .53725 .46969 .54033 .47511 .53866 .47205 .53557 Mtetra
.47205 .53557 .47511 .53866 .48053 .537 .47748 .53389 Mtetra
.664 .74 .907 r
.47748 .53389 .48053 .537 .48596 .53532 .48292 .53221 Mtetra
.48292 .53221 .48596 .53532 .49141 .53364 .48837 .53053 Mtetra
.663 .741 .908 r
.48837 .53053 .49141 .53364 .49687 .53196 .49384 .52885 Mtetra
.664 .741 .908 r
.49384 .52885 .49687 .53196 .50233 .53027 .49931 .52716 Mtetra
.664 .741 .907 r
.49931 .52716 .50233 .53027 .50781 .52859 .5048 .52546 Mtetra
.664 .74 .907 r
.5048 .52546 .50781 .52859 .5133 .5269 .51029 .52376 Mtetra
.51029 .52376 .5133 .5269 .5188 .5252 .5158 .52206 Mtetra
.663 .741 .908 r
.5158 .52206 .5188 .5252 .52431 .5235 .52132 .52037 Mtetra
.664 .742 .908 r
.52132 .52037 .52431 .5235 .52983 .5218 .52685 .51865 Mtetra
.664 .741 .907 r
.52685 .51865 .52983 .5218 .53537 .5201 .53239 .51694 Mtetra
.53239 .51694 .53537 .5201 .54091 .51839 .53794 .51522 Mtetra
.664 .74 .907 r
.53794 .51522 .54091 .51839 .54647 .51668 .5435 .51351 Mtetra
.664 .741 .908 r
.5435 .51351 .54647 .51668 .55203 .51496 .54908 .51179 Mtetra
.664 .742 .908 r
.54908 .51179 .55203 .51496 .55761 .51324 .55466 .51006 Mtetra
.664 .741 .907 r
.55466 .51006 .55761 .51324 .5632 .51152 .56026 .50833 Mtetra
.56026 .50833 .5632 .51152 .5688 .5098 .56587 .5066 Mtetra
.664 .74 .907 r
.56587 .5066 .5688 .5098 .57441 .50807 .57149 .50487 Mtetra
.663 .74 .907 r
.57149 .50487 .57441 .50807 .58004 .50633 .57712 .50313 Mtetra
.664 .741 .908 r
.57712 .50313 .58004 .50633 .58567 .5046 .58276 .50139 Mtetra
.58276 .50139 .58567 .5046 .59132 .50286 .58841 .49964 Mtetra
.664 .741 .907 r
.58841 .49964 .59132 .50286 .59698 .50113 .59408 .49789 Mtetra
.663 .74 .907 r
.59408 .49789 .59698 .50113 .60265 .49939 .59976 .49614 Mtetra
.59976 .49614 .60265 .49939 .60833 .49763 .60544 .4944 Mtetra
.663 .741 .908 r
.60544 .4944 .60833 .49763 .61402 .49588 .61115 .49266 Mtetra
.663 .742 .909 r
.61115 .49266 .61402 .49588 .61972 .49414 .61686 .4909 Mtetra
.663 .741 .909 r
.61686 .4909 .61972 .49414 .62544 .49242 .62258 .48916 Mtetra
.66 .74 .909 r
.62258 .48916 .62544 .49242 .63117 .4907 .62832 .48744 Mtetra
.657 .739 .91 r
.62832 .48744 .63117 .4907 .63691 .489 .63407 .48576 Mtetra
.654 .74 .913 r
.63407 .48576 .63691 .489 .64267 .48734 .63983 .48414 Mtetra
.648 .741 .917 r
.63983 .48414 .64267 .48734 .64844 .48576 .64561 .48258 Mtetra
.638 .739 .922 r
.64561 .48258 .64844 .48576 .65422 .48429 .65141 .48116 Mtetra
.618 .735 .93 r
.65141 .48116 .65422 .48429 .66003 .48303 .65723 .47999 Mtetra
.582 .728 .943 r
.65723 .47999 .66003 .48303 .66587 .4821 .66308 .47922 Mtetra
.512 .711 .962 r
.66308 .47922 .66587 .4821 .67174 .48167 .66898 .47907 Mtetra
.358 .657 .97 r
.66898 .47907 .67174 .48167 .67767 .48207 .67494 .47989 Mtetra
.007 .47 .869 r
.67494 .47989 .67767 .48207 .68369 .48376 .68099 .48223 Mtetra
.508 0 0 r
.68099 .48223 .68369 .48376 .68982 .48744 .68717 .48684 Mtetra
.781 .278 0 r
.68717 .48684 .68982 .48744 .69614 .49392 .69356 .49458 Mtetra
.855 .422 .19 r
.69356 .49458 .69614 .49392 .70268 .504 .70019 .50614 Mtetra
.869 .477 .292 r
.70019 .50614 .70268 .504 .7095 .5179 .70708 .5213 Mtetra
.863 .486 .331 r
.70708 .5213 .7095 .5179 .71652 .53431 .71412 .5378 Mtetra
.835 .445 .311 r
.71412 .5378 .71652 .53431 .72355 .54937 .72104 .55087 Mtetra
.654 .143 .018 r
.72104 .55087 .72355 .54937 .73023 .55737 .72749 .55492 Mtetra
.884 .834 .792 r
.72749 .55492 .73023 .55737 .73624 .5541 .73325 .54732 Mtetra
.88 .696 .65 r
.73325 .54732 .73624 .5541 .74159 .54025 .73843 .53066 Mtetra
.862 .659 .627 r
.73843 .53066 .74159 .54025 .74652 .52076 .74333 .51051 Mtetra
.847 .647 .631 r
.74333 .51051 .74652 .52076 .7514 .50107 .74827 .49167 Mtetra
.834 .648 .65 r
.74827 .49167 .7514 .50107 .75642 .48438 .75341 .47642 Mtetra
.821 .658 .681 r
.75341 .47642 .75642 .48438 .76169 .47158 .75878 .46501 Mtetra
.804 .675 .72 r
.75878 .46501 .76169 .47158 .76718 .46223 .76436 .45674 Mtetra
.784 .693 .764 r
.76436 .45674 .76718 .46223 .77286 .45548 .7701 .45075 Mtetra
.758 .71 .807 r
.7701 .45075 .77286 .45548 .77866 .45055 .77596 .44636 Mtetra
.727 .723 .846 r
.77596 .44636 .77866 .45055 .78457 .44687 .78192 .44311 Mtetra
.691 .732 .882 r
.78192 .44311 .78457 .44687 .79056 .4441 .78795 .44075 Mtetra
.636 .736 .921 r
.78795 .44075 .79056 .4441 .79663 .4421 .79407 .43929 Mtetra
.506 .719 .968 r
.79407 .43929 .79663 .4421 .80278 .441 .80031 .43911 Mtetra
.051 .52 .89 r
.80031 .43911 .80278 .441 .80907 .44132 .80676 .44113 Mtetra
.688 .143 0 r
.80676 .44113 .80907 .44132 .81561 .44417 .81359 .44719 Mtetra
.842 .432 .26 r
.81359 .44719 .81561 .44417 .82261 .45171 .82113 .46055 Mtetra
.854 .509 .398 r
.82113 .46055 .82261 .45171 .83044 .46761 .82986 .48598 Mtetra
.843 .527 .455 r
.82986 .48598 .83044 .46761 .8396 .49682 .84021 .52739 Mtetra
.815 .516 .485 r
.84021 .52739 .8396 .49682 .85046 .54202 .85176 .57944 Mtetra
.752 .468 .502 r
.85176 .57944 .85046 .54202 .86214 .59364 .86216 .61741 Mtetra
.478 .234 .465 r
.86216 .61741 .86214 .59364 .87177 .62269 .86834 .61144 Mtetra
.932 .679 .533 r
.86834 .61144 .87177 .62269 .8767 .60454 .87039 .565 Mtetra
.814 .564 .561 r
.87039 .565 .8767 .60454 .87806 .5528 .87135 .50972 Mtetra
.769 .531 .573 r
.87135 .50972 .87806 .5528 .87909 .49957 .87346 .46708 Mtetra
.749 .524 .59 r
.87346 .46708 .87909 .49957 .88152 .46107 .87711 .44006 Mtetra
.739 .536 .618 r
.87711 .44006 .88152 .46107 .88545 .43735 .8819 .42424 Mtetra
.735 .566 .663 r
.8819 .42424 .88545 .43735 .89043 .42357 .88739 .41503 Mtetra
.729 .609 .723 r
.88739 .41503 .89043 .42357 .89603 .41548 .89327 .40936 Mtetra
.717 .655 .786 r
.89327 .40936 .89603 .41548 .90197 .41042 .89937 .40554 Mtetra
.701 .69 .837 r
.89937 .40554 .90197 .41042 .9081 .40689 .90558 .40265 Mtetra
.686 .714 .87 r
.90558 .40265 .9081 .40689 .91432 .40415 .91185 .40024 Mtetra
.677 .728 .889 r
.91185 .40024 .91432 .40415 .92061 .4018 .91817 .39805 Mtetra
.671 .735 .898 r
.91817 .39805 .92061 .4018 .92693 .39966 .92451 .39596 Mtetra
.668 .737 .902 r
.92451 .39596 .92693 .39966 .93328 .39761 .93087 .39393 Mtetra
.665 .738 .904 r
.93087 .39393 .93328 .39761 .93965 .39559 .93726 .39193 Mtetra
.664 .739 .906 r
.93726 .39193 .93965 .39559 .94604 .39359 .94365 .38995 Mtetra
.664 .74 .906 r
.36769 .56384 .37088 .56683 .37611 .56521 .37292 .56221 Mtetra
.664 .74 .907 r
.37292 .56221 .37611 .56521 .38135 .56358 .37817 .56058 Mtetra
.663 .741 .907 r
.37817 .56058 .38135 .56358 .3866 .56196 .38343 .55896 Mtetra
.664 .741 .908 r
.38343 .55896 .3866 .56196 .39187 .56033 .3887 .55733 Mtetra
.664 .741 .907 r
.3887 .55733 .39187 .56033 .39714 .55871 .39397 .55569 Mtetra
.664 .74 .907 r
.39397 .55569 .39714 .55871 .40242 .55708 .39926 .55405 Mtetra
.664 .741 .907 r
.39926 .55405 .40242 .55708 .40771 .55544 .40456 .55241 Mtetra
.663 .741 .908 r
.40456 .55241 .40771 .55544 .41302 .5538 .40987 .55078 Mtetra
.664 .741 .908 r
.40987 .55078 .41302 .5538 .41833 .55216 .41519 .54913 Mtetra
.664 .741 .907 r
.41519 .54913 .41833 .55216 .42365 .55052 .42052 .54747 Mtetra
.664 .74 .907 r
.42052 .54747 .42365 .55052 .42899 .54887 .42586 .54582 Mtetra
.664 .741 .907 r
.42586 .54582 .42899 .54887 .43433 .54722 .43122 .54417 Mtetra
.664 .741 .908 r
.43122 .54417 .43433 .54722 .43969 .54557 .43658 .54251 Mtetra
.664 .741 .907 r
.43658 .54251 .43969 .54557 .44506 .54391 .44195 .54084 Mtetra
.44195 .54084 .44506 .54391 .45043 .54225 .44733 .53917 Mtetra
.44733 .53917 .45043 .54225 .45582 .54058 .45273 .5375 Mtetra
.45273 .5375 .45582 .54058 .46122 .53892 .45813 .53584 Mtetra
.664 .741 .908 r
.45813 .53584 .46122 .53892 .46663 .53725 .46355 .53416 Mtetra
.664 .741 .907 r
.46355 .53416 .46663 .53725 .47205 .53557 .46898 .53247 Mtetra
.46898 .53247 .47205 .53557 .47748 .53389 .47442 .53079 Mtetra
.47442 .53079 .47748 .53389 .48292 .53221 .47986 .5291 Mtetra
.663 .741 .907 r
.47986 .5291 .48292 .53221 .48837 .53053 .48532 .52742 Mtetra
.664 .741 .907 r
.48532 .52742 .48837 .53053 .49384 .52885 .49079 .52572 Mtetra
.49079 .52572 .49384 .52885 .49931 .52716 .49627 .52402 Mtetra
.49627 .52402 .49931 .52716 .5048 .52546 .50177 .52232 Mtetra
.50177 .52232 .5048 .52546 .51029 .52376 .50727 .52062 Mtetra
.50727 .52062 .51029 .52376 .5158 .52206 .51279 .51891 Mtetra
.51279 .51891 .5158 .52206 .52132 .52037 .51831 .5172 Mtetra
.664 .74 .907 r
.51831 .5172 .52132 .52037 .52685 .51865 .52385 .51549 Mtetra
.664 .741 .907 r
.52385 .51549 .52685 .51865 .53239 .51694 .5294 .51377 Mtetra
.664 .741 .908 r
.5294 .51377 .53239 .51694 .53794 .51522 .53495 .51206 Mtetra
.664 .741 .907 r
.53495 .51206 .53794 .51522 .5435 .51351 .54052 .51032 Mtetra
.54052 .51032 .5435 .51351 .54908 .51179 .54611 .5086 Mtetra
.664 .74 .907 r
.54611 .5086 .54908 .51179 .55466 .51006 .5517 .50687 Mtetra
.663 .741 .907 r
.5517 .50687 .55466 .51006 .56026 .50833 .5573 .50514 Mtetra
.664 .741 .908 r
.5573 .50514 .56026 .50833 .56587 .5066 .56292 .5034 Mtetra
.664 .742 .908 r
.56292 .5034 .56587 .5066 .57149 .50487 .56855 .50165 Mtetra
.664 .741 .907 r
.56855 .50165 .57149 .50487 .57712 .50313 .57418 .4999 Mtetra
.664 .74 .907 r
.57418 .4999 .57712 .50313 .58276 .50139 .57983 .49816 Mtetra
.663 .74 .907 r
.57983 .49816 .58276 .50139 .58841 .49964 .5855 .49642 Mtetra
.664 .742 .908 r
.5855 .49642 .58841 .49964 .59408 .49789 .59117 .49466 Mtetra
.59117 .49466 .59408 .49789 .59976 .49614 .59685 .4929 Mtetra
.664 .741 .907 r
.59685 .4929 .59976 .49614 .60544 .4944 .60255 .49114 Mtetra
.662 .74 .907 r
.60255 .49114 .60544 .4944 .61115 .49266 .60826 .48939 Mtetra
.662 .74 .908 r
.60826 .48939 .61115 .49266 .61686 .4909 .61398 .48765 Mtetra
.661 .741 .909 r
.61398 .48765 .61686 .4909 .62258 .48916 .61971 .48592 Mtetra
.66 .742 .91 r
.61971 .48592 .62258 .48916 .62832 .48744 .62546 .4842 Mtetra
.657 .741 .912 r
.62546 .4842 .62832 .48744 .63407 .48576 .63122 .48251 Mtetra
.652 .739 .913 r
.63122 .48251 .63407 .48576 .63983 .48414 .63699 .4809 Mtetra
.644 .738 .917 r
.63699 .4809 .63983 .48414 .64561 .48258 .64278 .4794 Mtetra
.63 .737 .924 r
.64278 .4794 .64561 .48258 .65141 .48116 .64859 .47807 Mtetra
.607 .735 .936 r
.64859 .47807 .65141 .48116 .65723 .47999 .65442 .47702 Mtetra
.562 .726 .951 r
.65442 .47702 .65723 .47999 .66308 .47922 .66029 .47642 Mtetra
.47 .699 .968 r
.66029 .47642 .66308 .47922 .66898 .47907 .6662 .47657 Mtetra
.259 .611 .956 r
.6662 .47657 .66898 .47907 .67494 .47989 .67219 .4779 Mtetra
0 .333 .754 r
.67219 .4779 .67494 .47989 .68099 .48223 .67829 .48101 Mtetra
.649 .098 0 r
.67829 .48101 .68099 .48223 .68717 .48684 .68453 .4867 Mtetra
.821 .348 .074 r
.68453 .4867 .68717 .48684 .69356 .49458 .69099 .4958 Mtetra
.864 .45 .239 r
.69099 .4958 .69356 .49458 .70019 .50614 .69771 .50881 Mtetra
.869 .485 .313 r
.69771 .50881 .70019 .50614 .70708 .5213 .70465 .52488 Mtetra
.856 .479 .332 r
.70465 .52488 .70708 .5213 .71412 .5378 .71167 .5408 Mtetra
.809 .399 .27 r
.71167 .5408 .71412 .5378 .72104 .55087 .71844 .55108 Mtetra
0 0 0 r
.71844 .55108 .72104 .55087 .72749 .55492 .72464 .55078 Mtetra
.891 .756 .706 r
.72464 .55078 .72749 .55492 .73325 .54732 .73017 .5392 Mtetra
.872 .677 .636 r
.73017 .5392 .73325 .54732 .73843 .53066 .73523 .52053 Mtetra
.856 .652 .626 r
.73523 .52053 .73843 .53066 .74333 .51051 .74015 .50044 Mtetra
.842 .646 .637 r
.74015 .50044 .74333 .51051 .74827 .49167 .74518 .48281 Mtetra
.83 .651 .661 r
.74518 .48281 .74827 .49167 .75341 .47642 .75043 .46902 Mtetra
.815 .664 .695 r
.75043 .46902 .75341 .47642 .75878 .46501 .7559 .45886 Mtetra
.797 .681 .737 r
.7559 .45886 .75878 .46501 .76436 .45674 .76156 .45155 Mtetra
.773 .699 .781 r
.76156 .45155 .76436 .45674 .7701 .45075 .76736 .44626 Mtetra
.745 .716 .825 r
.76736 .44626 .7701 .45075 .77596 .44636 .77327 .4424 Mtetra
.711 .729 .864 r
.77327 .4424 .77596 .44636 .78192 .44311 .77927 .43958 Mtetra
.663 .736 .904 r
.77927 .43958 .78192 .44311 .78795 .44075 .78535 .43771 Mtetra
.563 .729 .953 r
.78535 .43771 .78795 .44075 .79407 .43929 .79154 .43706 Mtetra
.237 .62 .956 r
.79154 .43706 .79407 .43929 .80031 .43911 .79792 .43836 Mtetra
.562 0 0 r
.79792 .43836 .80031 .43911 .80676 .44113 .80462 .44314 Mtetra
.829 .392 .197 r
.80462 .44314 .80676 .44113 .81359 .44719 .81191 .45426 Mtetra
.854 .497 .375 r
.81191 .45426 .81359 .44719 .82113 .46055 .82024 .47617 Mtetra
.847 .526 .444 r
.82024 .47617 .82113 .46055 .82986 .48598 .83008 .51351 Mtetra
.824 .522 .479 r
.83008 .51351 .82986 .48598 .84021 .52739 .84136 .56441 Mtetra
.773 .486 .499 r
.84136 .56441 .84021 .52739 .85176 .57944 .85227 .60917 Mtetra
.614 .35 .494 r
.85227 .60917 .85176 .57944 .86216 .61741 .85965 .61564 Mtetra
.989 .756 .489 r
.85965 .61564 .86216 .61741 .86834 .61144 .86257 .57672 Mtetra
.832 .579 .558 r
.86257 .57672 .86834 .61144 .87039 .565 .86363 .52077 Mtetra
.777 .536 .57 r
.86363 .52077 .87039 .565 .87135 .50972 .86546 .47411 Mtetra
.753 .524 .585 r
.86546 .47411 .87135 .50972 .87346 .46708 .8688 .44347 Mtetra
.741 .532 .61 r
.8688 .44347 .87346 .46708 .87711 .44006 .87339 .42532 Mtetra
.736 .557 .65 r
.87339 .42532 .87711 .44006 .8819 .42424 .87876 .41478 Mtetra
.731 .597 .707 r
.87876 .41478 .8819 .42424 .88739 .41503 .88457 .40843 Mtetra
.72 .643 .771 r
.88457 .40843 .88739 .41503 .89327 .40936 .89063 .40425 Mtetra
.705 .683 .826 r
.89063 .40425 .89327 .40936 .89937 .40554 .89682 .40118 Mtetra
.69 .71 .863 r
.89682 .40118 .89937 .40554 .90558 .40265 .90308 .39867 Mtetra
.679 .725 .885 r
.90308 .39867 .90558 .40265 .91185 .40024 .90939 .39642 Mtetra
.672 .733 .896 r
.90939 .39642 .91185 .40024 .91817 .39805 .91572 .39432 Mtetra
.668 .736 .901 r
.91572 .39432 .91817 .39805 .92451 .39596 .92208 .39228 Mtetra
.666 .739 .904 r
.92208 .39228 .92451 .39596 .93087 .39393 .92846 .39027 Mtetra
.665 .74 .906 r
.92846 .39027 .93087 .39393 .93726 .39193 .93485 .38828 Mtetra
.665 .741 .907 r
.93485 .38828 .93726 .39193 .94365 .38995 .94126 .38628 Mtetra
.664 .741 .907 r
.36448 .56084 .36769 .56384 .37292 .56221 .36972 .55921 Mtetra
.36972 .55921 .37292 .56221 .37817 .56058 .37498 .55758 Mtetra
.37498 .55758 .37817 .56058 .38343 .55896 .38024 .55594 Mtetra
.664 .74 .907 r
.38024 .55594 .38343 .55896 .3887 .55733 .38551 .55431 Mtetra
.664 .741 .907 r
.38551 .55431 .3887 .55733 .39397 .55569 .3908 .55267 Mtetra
.3908 .55267 .39397 .55569 .39926 .55405 .39609 .55103 Mtetra
.39609 .55103 .39926 .55405 .40456 .55241 .4014 .54938 Mtetra
.4014 .54938 .40456 .55241 .40987 .55078 .40672 .54773 Mtetra
.664 .74 .907 r
.40672 .54773 .40987 .55078 .41519 .54913 .41204 .54607 Mtetra
.664 .741 .907 r
.41204 .54607 .41519 .54913 .42052 .54747 .41738 .54442 Mtetra
.664 .741 .908 r
.41738 .54442 .42052 .54747 .42586 .54582 .42273 .54276 Mtetra
.664 .741 .907 r
.42273 .54276 .42586 .54582 .43122 .54417 .42809 .5411 Mtetra
.42809 .5411 .43122 .54417 .43658 .54251 .43346 .53943 Mtetra
.664 .74 .907 r
.43346 .53943 .43658 .54251 .44195 .54084 .43884 .53776 Mtetra
.664 .741 .907 r
.43884 .53776 .44195 .54084 .44733 .53917 .44423 .53609 Mtetra
.664 .741 .908 r
.44423 .53609 .44733 .53917 .45273 .5375 .44963 .53442 Mtetra
.664 .741 .907 r
.44963 .53442 .45273 .5375 .45813 .53584 .45504 .53273 Mtetra
.664 .74 .907 r
.45504 .53273 .45813 .53584 .46355 .53416 .46046 .53105 Mtetra
.46046 .53105 .46355 .53416 .46898 .53247 .4659 .52936 Mtetra
.663 .741 .908 r
.4659 .52936 .46898 .53247 .47442 .53079 .47134 .52768 Mtetra
.664 .741 .908 r
.47134 .52768 .47442 .53079 .47986 .5291 .4768 .52599 Mtetra
.664 .741 .907 r
.4768 .52599 .47986 .5291 .48532 .52742 .48226 .52428 Mtetra
.664 .74 .907 r
.48226 .52428 .48532 .52742 .49079 .52572 .48774 .52258 Mtetra
.664 .741 .907 r
.48774 .52258 .49079 .52572 .49627 .52402 .49323 .52088 Mtetra
.663 .741 .908 r
.49323 .52088 .49627 .52402 .50177 .52232 .49873 .51918 Mtetra
.664 .742 .908 r
.49873 .51918 .50177 .52232 .50727 .52062 .50424 .51747 Mtetra
.664 .741 .907 r
.50424 .51747 .50727 .52062 .51279 .51891 .50976 .51575 Mtetra
.50976 .51575 .51279 .51891 .51831 .5172 .51529 .51403 Mtetra
.51529 .51403 .51831 .5172 .52385 .51549 .52084 .51232 Mtetra
.664 .741 .908 r
.52084 .51232 .52385 .51549 .5294 .51377 .52639 .5106 Mtetra
.664 .741 .907 r
.52639 .5106 .5294 .51377 .53495 .51206 .53196 .50886 Mtetra
.664 .74 .907 r
.53196 .50886 .53495 .51206 .54052 .51032 .53754 .50713 Mtetra
.664 .741 .907 r
.53754 .50713 .54052 .51032 .54611 .5086 .54313 .5054 Mtetra
.54313 .5054 .54611 .5086 .5517 .50687 .54873 .50366 Mtetra
.54873 .50366 .5517 .50687 .5573 .50514 .55434 .50192 Mtetra
.664 .74 .907 r
.55434 .50192 .5573 .50514 .56292 .5034 .55996 .50017 Mtetra
.55996 .50017 .56292 .5034 .56855 .50165 .5656 .49843 Mtetra
.663 .741 .908 r
.5656 .49843 .56855 .50165 .57418 .4999 .57124 .49668 Mtetra
.664 .741 .908 r
.57124 .49668 .57418 .4999 .57983 .49816 .5769 .49493 Mtetra
.664 .741 .907 r
.5769 .49493 .57983 .49816 .5855 .49642 .58257 .49316 Mtetra
.664 .74 .907 r
.58257 .49316 .5855 .49642 .59117 .49466 .58825 .4914 Mtetra
.663 .74 .907 r
.58825 .4914 .59117 .49466 .59685 .4929 .59394 .48965 Mtetra
.663 .741 .908 r
.59394 .48965 .59685 .4929 .60255 .49114 .59965 .4879 Mtetra
.663 .742 .909 r
.59965 .4879 .60255 .49114 .60826 .48939 .60536 .48613 Mtetra
.663 .741 .908 r
.60536 .48613 .60826 .48939 .61398 .48765 .61109 .48437 Mtetra
.661 .739 .908 r
.61109 .48437 .61398 .48765 .61971 .48592 .61683 .48264 Mtetra
.658 .739 .91 r
.61683 .48264 .61971 .48592 .62546 .4842 .62259 .48095 Mtetra
.655 .74 .913 r
.62259 .48095 .62546 .4842 .63122 .48251 .62835 .47929 Mtetra
.651 .741 .916 r
.62835 .47929 .63122 .48251 .63699 .4809 .63413 .47769 Mtetra
.641 .739 .92 r
.63413 .47769 .63699 .4809 .64278 .4794 .63993 .47622 Mtetra
.624 .736 .927 r
.63993 .47622 .64278 .4794 .64859 .47807 .64575 .47498 Mtetra
.593 .73 .939 r
.64575 .47498 .64859 .47807 .65442 .47702 .6516 .47408 Mtetra
.534 .718 .957 r
.6516 .47408 .65442 .47702 .66029 .47642 .65749 .47373 Mtetra
.409 .679 .972 r
.65749 .47373 .66029 .47642 .6662 .47657 .66343 .47426 Mtetra
.119 .539 .917 r
.66343 .47426 .6662 .47657 .67219 .4779 .66945 .47615 Mtetra
.388 0 0 r
.66945 .47615 .67219 .4779 .67829 .48101 .67559 .48011 Mtetra
.74 .216 0 r
.67559 .48011 .67829 .48101 .68453 .4867 .6819 .487 Mtetra
.846 .398 .15 r
.6819 .487 .68453 .4867 .69099 .4958 .68844 .49759 Mtetra
.868 .469 .275 r
.68844 .49759 .69099 .4958 .69771 .50881 .69523 .51196 Mtetra
.866 .487 .327 r
.69523 .51196 .69771 .50881 .70465 .52488 .70221 .52848 Mtetra
.845 .462 .324 r
.70221 .52848 .70465 .52488 .71167 .5408 .70915 .54298 Mtetra
.753 .298 .171 r
.70915 .54298 .71167 .5408 .71844 .55108 .71573 .54973 Mtetra
.824 .919 .9 r
.71573 .54973 .71844 .55108 .72464 .55078 .72169 .54499 Mtetra
.885 .714 .665 r
.72169 .54499 .72464 .55078 .73017 .5392 .72703 .53007 Mtetra
.866 .665 .629 r
.72703 .53007 .73017 .5392 .73523 .52053 .73203 .51021 Mtetra
.851 .648 .629 r
.73203 .51021 .73523 .52053 .74015 .50044 .737 .4907 Mtetra
.837 .647 .645 r
.737 .4907 .74015 .50044 .74518 .48281 .74213 .47447 Mtetra
.824 .655 .672 r
.74213 .47447 .74518 .48281 .75043 .46902 .74748 .46212 Mtetra
.809 .67 .71 r
.74748 .46212 .75043 .46902 .7559 .45886 .75304 .45313 Mtetra
.789 .689 .754 r
.75304 .45313 .7559 .45886 .76156 .45155 .75877 .44666 Mtetra
.763 .707 .799 r
.75877 .44666 .76156 .45155 .76736 .44626 .76463 .442 Mtetra
.73 .721 .842 r
.76463 .442 .76736 .44626 .77327 .4424 .77058 .43863 Mtetra
.686 .731 .885 r
.77058 .43863 .77327 .4424 .77927 .43958 .77663 .43634 Mtetra
.607 .734 .935 r
.77663 .43634 .77927 .43958 .78535 .43771 .78278 .43523 Mtetra
.376 .68 .977 r
.78278 .43523 .78535 .43771 .79154 .43706 .78909 .43585 Mtetra
.37 0 0 r
.78909 .43585 .79154 .43706 .79792 .43836 .79567 .43948 Mtetra
.804 .335 .109 r
.79567 .43948 .79792 .43836 .80462 .44314 .80276 .44863 Mtetra
.853 .482 .346 r
.80276 .44863 .80462 .44314 .81191 .45426 .81073 .46736 Mtetra
.85 .523 .432 r
.81073 .46736 .81191 .45426 .82024 .47617 .82009 .50059 Mtetra
.831 .525 .472 r
.82009 .50059 .82024 .47617 .83008 .51351 .83098 .54908 Mtetra
.79 .499 .495 r
.83098 .54908 .83008 .51351 .84136 .56441 .84215 .59836 Mtetra
.682 .408 .502 r
.84215 .59836 .84136 .56441 .85227 .60917 .85062 .61676 Mtetra
.857 .751 .238 r
.85062 .61676 .85227 .60917 .85965 .61564 .85457 .58743 Mtetra
.855 .601 .554 r
.85457 .58743 .85965 .61564 .86257 .57672 .8559 .53253 Mtetra
.787 .543 .567 r
.8559 .53253 .86257 .57672 .86363 .52077 .8575 .48219 Mtetra
.757 .525 .581 r
.8575 .48219 .86363 .52077 .86546 .47411 .86054 .44766 Mtetra
.743 .528 .602 r
.86054 .44766 .86546 .47411 .8688 .44347 .8649 .42686 Mtetra
.737 .549 .638 r
.8649 .42686 .8688 .44347 .87339 .42532 .87013 .4148 Mtetra
.732 .586 .692 r
.87013 .4148 .87339 .42532 .87876 .41478 .87586 .40763 Mtetra
.724 .632 .755 r
.87586 .40763 .87876 .41478 .88457 .40843 .88188 .40302 Mtetra
.709 .674 .814 r
.88188 .40302 .88457 .40843 .89063 .40425 .88804 .39973 Mtetra
.693 .704 .856 r
.88804 .39973 .89063 .40425 .89682 .40118 .89429 .39711 Mtetra
.681 .722 .88 r
.89429 .39711 .89682 .40118 .90308 .39867 .90059 .39482 Mtetra
.673 .731 .894 r
.90059 .39482 .90308 .39867 .90939 .39642 .90692 .39268 Mtetra
.669 .736 .9 r
.90692 .39268 .90939 .39642 .91572 .39432 .91327 .39062 Mtetra
.666 .739 .904 r
.91327 .39062 .91572 .39432 .92208 .39228 .91965 .3886 Mtetra
.665 .74 .906 r
.91965 .3886 .92208 .39228 .92846 .39027 .92604 .3866 Mtetra
.92604 .3866 .92846 .39027 .93485 .38828 .93244 .3846 Mtetra
.664 .74 .907 r
.93244 .3846 .93485 .38828 .94126 .38628 .93886 .3826 Mtetra
.664 .741 .907 r
.36126 .55783 .36448 .56084 .36972 .55921 .36651 .5562 Mtetra
.36651 .5562 .36972 .55921 .37498 .55758 .37177 .55456 Mtetra
.37177 .55456 .37498 .55758 .38024 .55594 .37704 .55292 Mtetra
.37704 .55292 .38024 .55594 .38551 .55431 .38232 .55128 Mtetra
.38232 .55128 .38551 .55431 .3908 .55267 .38761 .54963 Mtetra
.38761 .54963 .3908 .55267 .39609 .55103 .39291 .54798 Mtetra
.39291 .54798 .39609 .55103 .4014 .54938 .39823 .54633 Mtetra
.39823 .54633 .4014 .54938 .40672 .54773 .40355 .54467 Mtetra
.40355 .54467 .40672 .54773 .41204 .54607 .40888 .54301 Mtetra
.40888 .54301 .41204 .54607 .41738 .54442 .41423 .54135 Mtetra
.41423 .54135 .41738 .54442 .42273 .54276 .41958 .53969 Mtetra
.664 .74 .907 r
.41958 .53969 .42273 .54276 .42809 .5411 .42495 .53802 Mtetra
.664 .741 .907 r
.42495 .53802 .42809 .5411 .43346 .53943 .43032 .53635 Mtetra
.43032 .53635 .43346 .53943 .43884 .53776 .43571 .53467 Mtetra
.43571 .53467 .43884 .53776 .44423 .53609 .44111 .53299 Mtetra
.44111 .53299 .44423 .53609 .44963 .53442 .44651 .53131 Mtetra
.664 .74 .907 r
.44651 .53131 .44963 .53442 .45504 .53273 .45193 .52962 Mtetra
.664 .741 .907 r
.45193 .52962 .45504 .53273 .46046 .53105 .45736 .52794 Mtetra
.664 .741 .908 r
.45736 .52794 .46046 .53105 .4659 .52936 .4628 .52625 Mtetra
.664 .741 .907 r
.4628 .52625 .4659 .52936 .47134 .52768 .46826 .52455 Mtetra
.664 .74 .907 r
.46826 .52455 .47134 .52768 .4768 .52599 .47372 .52285 Mtetra
.47372 .52285 .4768 .52599 .48226 .52428 .47919 .52114 Mtetra
.663 .741 .908 r
.47919 .52114 .48226 .52428 .48774 .52258 .48468 .51945 Mtetra
.664 .741 .908 r
.48468 .51945 .48774 .52258 .49323 .52088 .49017 .51773 Mtetra
.664 .741 .907 r
.49017 .51773 .49323 .52088 .49873 .51918 .49568 .51602 Mtetra
.664 .74 .907 r
.49568 .51602 .49873 .51918 .50424 .51747 .5012 .5143 Mtetra
.664 .741 .907 r
.5012 .5143 .50424 .51747 .50976 .51575 .50672 .51258 Mtetra
.663 .741 .908 r
.50672 .51258 .50976 .51575 .51529 .51403 .51226 .51086 Mtetra
.664 .742 .908 r
.51226 .51086 .51529 .51403 .52084 .51232 .51782 .50913 Mtetra
.664 .741 .907 r
.51782 .50913 .52084 .51232 .52639 .5106 .52338 .5074 Mtetra
.664 .74 .907 r
.52338 .5074 .52639 .5106 .53196 .50886 .52895 .50566 Mtetra
.664 .741 .907 r
.52895 .50566 .53196 .50886 .53754 .50713 .53454 .50393 Mtetra
.664 .741 .908 r
.53454 .50393 .53754 .50713 .54313 .5054 .54013 .5022 Mtetra
.664 .742 .908 r
.54013 .5022 .54313 .5054 .54873 .50366 .54574 .50044 Mtetra
.664 .741 .907 r
.54574 .50044 .54873 .50366 .55434 .50192 .55136 .49869 Mtetra
.55136 .49869 .55434 .50192 .55996 .50017 .55699 .49694 Mtetra
.663 .741 .907 r
.55699 .49694 .55996 .50017 .5656 .49843 .56263 .49519 Mtetra
.664 .741 .908 r
.56263 .49519 .5656 .49843 .57124 .49668 .56829 .49344 Mtetra
.664 .741 .907 r
.56829 .49344 .57124 .49668 .5769 .49493 .57395 .49167 Mtetra
.664 .74 .907 r
.57395 .49167 .5769 .49493 .58257 .49316 .57963 .48991 Mtetra
.663 .741 .908 r
.57963 .48991 .58257 .49316 .58825 .4914 .58532 .48815 Mtetra
.58532 .48815 .58825 .4914 .59394 .48965 .59102 .48638 Mtetra
.59102 .48638 .59394 .48965 .59965 .4879 .59673 .48461 Mtetra
.663 .74 .907 r
.59673 .48461 .59965 .4879 .60536 .48613 .60245 .48285 Mtetra
.661 .74 .908 r
.60245 .48285 .60536 .48613 .61109 .48437 .60819 .48111 Mtetra
.66 .741 .91 r
.60819 .48111 .61109 .48437 .61683 .48264 .61394 .47938 Mtetra
.658 .742 .911 r
.61394 .47938 .61683 .48264 .62259 .48095 .6197 .47767 Mtetra
.654 .74 .912 r
.6197 .47767 .62259 .48095 .62835 .47929 .62548 .47602 Mtetra
.647 .738 .916 r
.62548 .47602 .62835 .47929 .63413 .47769 .63127 .47448 Mtetra
.634 .737 .923 r
.63127 .47448 .63413 .47769 .63993 .47622 .63708 .47309 Mtetra
.614 .736 .933 r
.63708 .47309 .63993 .47622 .64575 .47498 .64291 .47195 Mtetra
.577 .73 .947 r
.64291 .47195 .64575 .47498 .6516 .47408 .64877 .4712 Mtetra
.5 .708 .964 r
.64877 .4712 .6516 .47408 .65749 .47373 .65468 .47112 Mtetra
.328 .643 .966 r
.65468 .47112 .65749 .47373 .66343 .47426 .66064 .4721 Mtetra
0 .427 .836 r
.66064 .4721 .66343 .47426 .66945 .47615 .6667 .4747 Mtetra
.562 0 0 r
.6667 .4747 .66945 .47615 .67559 .48011 .67289 .47965 Mtetra
.797 .305 .009 r
.67289 .47965 .67559 .48011 .6819 .487 .67927 .48783 Mtetra
.859 .433 .209 r
.67927 .48783 .6819 .487 .68844 .49759 .68589 .49989 Mtetra
.87 .48 .3 r
.68589 .49989 .68844 .49759 .69523 .51196 .69275 .51541 Mtetra
.861 .484 .332 r
.69275 .51541 .69523 .51196 .70221 .52848 .69972 .53183 Mtetra
.828 .432 .3 r
.69972 .53183 .70221 .52848 .70915 .54298 .70656 .54408 Mtetra
.545 0 0 r
.70656 .54408 .70915 .54298 .71573 .54973 .71292 .5467 Mtetra
.89 .802 .755 r
.71292 .5467 .71573 .54973 .72169 .54499 .71864 .53768 Mtetra
.877 .689 .644 r
.71864 .53768 .72169 .54499 .72703 .53007 .72384 .52021 Mtetra
.86 .656 .626 r
.72384 .52021 .72703 .53007 .73203 .51021 .72883 .49997 Mtetra
.846 .647 .633 r
.72883 .49997 .73203 .51021 .737 .4907 .73387 .48146 Mtetra
.833 .649 .654 r
.73387 .48146 .737 .4907 .74213 .47447 .7391 .46667 Mtetra
.819 .66 .685 r
.7391 .46667 .74213 .47447 .74748 .46212 .74456 .45566 Mtetra
.801 .676 .726 r
.74456 .45566 .74748 .46212 .75304 .45313 .7502 .44774 Mtetra
.779 .695 .772 r
.7502 .44774 .75304 .45313 .75877 .44666 .75599 .44207 Mtetra
.75 .714 .818 r
.75599 .44207 .75877 .44666 .76463 .442 .7619 .43799 Mtetra
.711 .728 .864 r
.7619 .43799 .76463 .442 .77058 .43863 .76791 .43516 Mtetra
.646 .735 .914 r
.76791 .43516 .77058 .43863 .77663 .43634 .77402 .43355 Mtetra
.48 .711 .971 r
.77402 .43355 .77663 .43634 .78278 .43523 .78027 .43356 Mtetra
0 .404 .791 r
.78027 .43356 .78278 .43523 .78909 .43585 .78675 .43622 Mtetra
.76 .252 0 r
.78675 .43622 .78909 .43585 .79567 .43948 .79366 .44364 Mtetra
.849 .461 .31 r
.79366 .44364 .79567 .43948 .80276 .44863 .80132 .45947 Mtetra
.852 .517 .418 r
.80132 .45947 .80276 .44863 .81073 .46736 .81022 .48867 Mtetra
.838 .527 .464 r
.81022 .48867 .81073 .46736 .82009 .50059 .82067 .53389 Mtetra
.804 .509 .49 r
.82067 .53389 .82009 .50059 .83098 .54908 .83189 .58556 Mtetra
.723 .444 .503 r
.83189 .58556 .83098 .54908 .84215 .59836 .84127 .61465 Mtetra
.067 0 .316 r
.84127 .61465 .84215 .59836 .85062 .61676 .84633 .5965 Mtetra
.887 .632 .548 r
.84633 .5965 .85062 .61676 .85457 .58743 .84812 .54469 Mtetra
.799 .552 .564 r
.84812 .54469 .85457 .58743 .8559 .53253 .84957 .49134 Mtetra
.763 .527 .577 r
.84957 .49134 .8559 .53253 .8575 .48219 .85231 .45274 Mtetra
.746 .526 .596 r
.85231 .45274 .8575 .48219 .86054 .44766 .85643 .42895 Mtetra
.738 .542 .628 r
.85643 .42895 .86054 .44766 .8649 .42686 .8615 .41511 Mtetra
.734 .575 .677 r
.8615 .41511 .8649 .42686 .87013 .4148 .86715 .40697 Mtetra
.726 .62 .739 r
.86715 .40697 .87013 .4148 .87586 .40763 .87312 .40187 Mtetra
.713 .665 .801 r
.87312 .40187 .87586 .40763 .88188 .40302 .87926 .39834 Mtetra
.698 .699 .847 r
.87926 .39834 .88188 .40302 .88804 .39973 .88549 .39558 Mtetra
.684 .719 .876 r
.88549 .39558 .88804 .39973 .89429 .39711 .89178 .39321 Mtetra
.675 .73 .891 r
.89178 .39321 .89429 .39711 .90059 .39482 .8981 .39103 Mtetra
.669 .734 .899 r
.8981 .39103 .90059 .39482 .90692 .39268 .90445 .38896 Mtetra
.666 .738 .903 r
.90445 .38896 .90692 .39268 .91327 .39062 .91082 .38693 Mtetra
.665 .74 .906 r
.91082 .38693 .91327 .39062 .91965 .3886 .9172 .38492 Mtetra
.665 .741 .906 r
.9172 .38492 .91965 .3886 .92604 .3866 .9236 .38292 Mtetra
.665 .74 .907 r
.9236 .38292 .92604 .3866 .93244 .3846 .93002 .38091 Mtetra
.664 .74 .907 r
.93002 .38091 .93244 .3846 .93886 .3826 .93645 .37891 Mtetra
.664 .741 .907 r
.35803 .55482 .36126 .55783 .36651 .5562 .36328 .55317 Mtetra
.36328 .55317 .36651 .5562 .37177 .55456 .36855 .55153 Mtetra
.36855 .55153 .37177 .55456 .37704 .55292 .37383 .54988 Mtetra
.37383 .54988 .37704 .55292 .38232 .55128 .37912 .54824 Mtetra
.37912 .54824 .38232 .55128 .38761 .54963 .38441 .54658 Mtetra
.38441 .54658 .38761 .54963 .39291 .54798 .38972 .54493 Mtetra
.38972 .54493 .39291 .54798 .39823 .54633 .39504 .54327 Mtetra
.39504 .54327 .39823 .54633 .40355 .54467 .40037 .54161 Mtetra
.40037 .54161 .40355 .54467 .40888 .54301 .40571 .53994 Mtetra
.40571 .53994 .40888 .54301 .41423 .54135 .41106 .53827 Mtetra
.41106 .53827 .41423 .54135 .41958 .53969 .41642 .5366 Mtetra
.41642 .5366 .41958 .53969 .42495 .53802 .42179 .53493 Mtetra
.42179 .53493 .42495 .53802 .43032 .53635 .42718 .53325 Mtetra
.42718 .53325 .43032 .53635 .43571 .53467 .43257 .53157 Mtetra
.43257 .53157 .43571 .53467 .44111 .53299 .43797 .52988 Mtetra
.43797 .52988 .44111 .53299 .44651 .53131 .44339 .52819 Mtetra
.44339 .52819 .44651 .53131 .45193 .52962 .44881 .5265 Mtetra
.44881 .5265 .45193 .52962 .45736 .52794 .45425 .52481 Mtetra
.45425 .52481 .45736 .52794 .4628 .52625 .4597 .52311 Mtetra
.4597 .52311 .4628 .52625 .46826 .52455 .46516 .52141 Mtetra
.46516 .52141 .46826 .52455 .47372 .52285 .47063 .5197 Mtetra
.47063 .5197 .47372 .52285 .47919 .52114 .47611 .51799 Mtetra
.47611 .51799 .47919 .52114 .48468 .51945 .4816 .51628 Mtetra
.664 .74 .907 r
.4816 .51628 .48468 .51945 .49017 .51773 .4871 .51456 Mtetra
.4871 .51456 .49017 .51773 .49568 .51602 .49262 .51285 Mtetra
.664 .741 .907 r
.49262 .51285 .49568 .51602 .5012 .5143 .49814 .51113 Mtetra
.49814 .51113 .5012 .5143 .50672 .51258 .50368 .5094 Mtetra
.50368 .5094 .50672 .51258 .51226 .51086 .50922 .50766 Mtetra
.664 .74 .907 r
.50922 .50766 .51226 .51086 .51782 .50913 .51478 .50593 Mtetra
.664 .741 .907 r
.51478 .50593 .51782 .50913 .52338 .5074 .52035 .5042 Mtetra
.664 .741 .908 r
.52035 .5042 .52338 .5074 .52895 .50566 .52593 .50246 Mtetra
.664 .741 .907 r
.52593 .50246 .52895 .50566 .53454 .50393 .53153 .50071 Mtetra
.664 .74 .907 r
.53153 .50071 .53454 .50393 .54013 .5022 .53713 .49896 Mtetra
.53713 .49896 .54013 .5022 .54574 .50044 .54275 .49721 Mtetra
.663 .741 .908 r
.54275 .49721 .54574 .50044 .55136 .49869 .54837 .49547 Mtetra
.664 .741 .908 r
.54837 .49547 .55136 .49869 .55699 .49694 .55401 .49371 Mtetra
.664 .742 .908 r
.55401 .49371 .55699 .49694 .56263 .49519 .55966 .49194 Mtetra
.664 .74 .907 r
.55966 .49194 .56263 .49519 .56829 .49344 .56532 .49017 Mtetra
.56532 .49017 .56829 .49344 .57395 .49167 .571 .48841 Mtetra
.663 .741 .908 r
.571 .48841 .57395 .49167 .57963 .48991 .57668 .48665 Mtetra
.664 .742 .908 r
.57668 .48665 .57963 .48991 .58532 .48815 .58238 .48488 Mtetra
.664 .741 .908 r
.58238 .48488 .58532 .48815 .59102 .48638 .58808 .4831 Mtetra
.663 .74 .907 r
.58808 .4831 .59102 .48638 .59673 .48461 .5938 .48132 Mtetra
.662 .74 .908 r
.5938 .48132 .59673 .48461 .60245 .48285 .59954 .47957 Mtetra
.661 .741 .909 r
.59954 .47957 .60245 .48285 .60819 .48111 .60528 .47783 Mtetra
.66 .741 .91 r
.60528 .47783 .60819 .48111 .61394 .47938 .61104 .47609 Mtetra
.657 .74 .911 r
.61104 .47609 .61394 .47938 .6197 .47767 .61681 .4744 Mtetra
.651 .74 .914 r
.61681 .4744 .6197 .47767 .62548 .47602 .62259 .47279 Mtetra
.643 .739 .919 r
.62259 .47279 .62548 .47602 .63127 .47448 .62839 .47128 Mtetra
.629 .738 .926 r
.62839 .47128 .63127 .47448 .63708 .47309 .63421 .46996 Mtetra
.603 .733 .936 r
.63421 .46996 .63708 .47309 .64291 .47195 .64006 .46894 Mtetra
.554 .722 .952 r
.64006 .46894 .64291 .47195 .64877 .4712 .64594 .46841 Mtetra
.449 .692 .97 r
.64594 .46841 .64877 .4712 .65468 .47112 .65186 .46868 Mtetra
.212 .59 .946 r
.65186 .46868 .65468 .47112 .66064 .4721 .65786 .47018 Mtetra
0 .281 .703 r
.65786 .47018 .66064 .4721 .6667 .4747 .66396 .47354 Mtetra
.683 .14 0 r
.66396 .47354 .6667 .4747 .67289 .47965 .67021 .4796 Mtetra
.831 .368 .102 r
.67021 .4796 .67289 .47965 .67927 .48783 .67666 .48922 Mtetra
.866 .457 .253 r
.67666 .48922 .67927 .48783 .68589 .49989 .68335 .50273 Mtetra
.868 .486 .319 r
.68335 .50273 .68589 .49989 .69275 .51541 .69025 .51902 Mtetra
.853 .474 .33 r
.69025 .51902 .69275 .51541 .69972 .53183 .69719 .53456 Mtetra
.796 .374 .245 r
.69719 .53456 .69972 .53183 .70656 .54408 .70387 .54376 Mtetra
.449 .874 .926 r
.70387 .54376 .70656 .54408 .71292 .5467 .71 .54198 Mtetra
.89 .74 .689 r
.71 .54198 .71292 .5467 .71864 .53768 .71552 .52917 Mtetra
.87 .673 .633 r
.71552 .52917 .71864 .53768 .72384 .52021 .72063 .50994 Mtetra
.854 .651 .627 r
.72063 .50994 .72384 .52021 .72883 .49997 .72564 .48994 Mtetra
.84 .646 .639 r
.72564 .48994 .72883 .49997 .73387 .48146 .73077 .47274 Mtetra
.828 .652 .665 r
.73077 .47274 .73387 .48146 .7391 .46667 .73611 .45942 Mtetra
.814 .666 .7 r
.73611 .45942 .7391 .46667 .74456 .45566 .74166 .44966 Mtetra
.794 .685 .744 r
.74166 .44966 .74456 .45566 .7502 .44774 .74738 .44268 Mtetra
.768 .703 .791 r
.74738 .44268 .7502 .44774 .75599 .44207 .75323 .43771 Mtetra
.732 .719 .838 r
.75323 .43771 .75599 .44207 .7619 .43799 .75919 .43426 Mtetra
.678 .731 .891 r
.75919 .43426 .7619 .43799 .76791 .43516 .76526 .43212 Mtetra
.556 .728 .955 r
.76526 .43212 .76791 .43516 .77402 .43355 .77145 .43152 Mtetra
.117 .56 .919 r
.77145 .43152 .77402 .43355 .78027 .43356 .77785 .43326 Mtetra
.679 .13 0 r
.77785 .43326 .78027 .43356 .78675 .43622 .7846 .43915 Mtetra
.842 .432 .261 r
.7846 .43915 .78675 .43622 .79366 .44364 .792 .45243 Mtetra
.854 .509 .399 r
.792 .45243 .79366 .44364 .80132 .45947 .80049 .47784 Mtetra
.843 .528 .456 r
.80049 .47784 .80132 .45947 .81022 .48867 .81046 .51925 Mtetra
.815 .516 .485 r
.81046 .51925 .81022 .48867 .82067 .53389 .82155 .57131 Mtetra
.752 .468 .502 r
.82155 .57131 .82067 .53389 .83189 .58556 .83161 .6093 Mtetra
.473 .227 .46 r
.83161 .6093 .83189 .58556 .84127 .61465 .83782 .60337 Mtetra
.93 .679 .536 r
.83782 .60337 .84127 .61465 .84633 .5965 .84025 .5569 Mtetra
.814 .564 .561 r
.84025 .5569 .84633 .5965 .84812 .54469 .84167 .50151 Mtetra
.77 .531 .573 r
.84167 .50151 .84812 .54469 .84957 .49134 .84413 .45875 Mtetra
.749 .524 .59 r
.84413 .45875 .84957 .49134 .85231 .45274 .84798 .43165 Mtetra
.74 .536 .618 r
.84798 .43165 .85231 .45274 .85643 .42895 .85289 .41578 Mtetra
.735 .565 .663 r
.85289 .41578 .85643 .42895 .8615 .41511 .85844 .40652 Mtetra
.729 .609 .723 r
.85844 .40652 .8615 .41511 .86715 .40697 .86435 .40082 Mtetra
.718 .655 .787 r
.86435 .40082 .86715 .40697 .87312 .40187 .87046 .39697 Mtetra
.702 .691 .837 r
.87046 .39697 .87312 .40187 .87926 .39834 .87667 .39405 Mtetra
.687 .714 .869 r
.87667 .39405 .87926 .39834 .88549 .39558 .88295 .39161 Mtetra
.676 .727 .888 r
.88295 .39161 .88549 .39558 .89178 .39321 .88927 .38941 Mtetra
.671 .734 .898 r
.88927 .38941 .89178 .39321 .8981 .39103 .89561 .38731 Mtetra
.668 .739 .903 r
.89561 .38731 .8981 .39103 .90445 .38896 .90197 .38526 Mtetra
.666 .74 .905 r
.90197 .38526 .90445 .38896 .91082 .38693 .90835 .38323 Mtetra
.665 .739 .906 r
.90835 .38323 .91082 .38693 .9172 .38492 .91475 .38122 Mtetra
.664 .739 .906 r
.91475 .38122 .9172 .38492 .9236 .38292 .92116 .37922 Mtetra
.664 .741 .907 r
.92116 .37922 .9236 .38292 .93002 .38091 .92759 .37722 Mtetra
.664 .742 .908 r
.92759 .37722 .93002 .38091 .93645 .37891 .93402 .37521 Mtetra
.664 .74 .907 r
.35479 .55178 .35803 .55482 .36328 .55317 .36005 .55014 Mtetra
.664 .741 .908 r
.36005 .55014 .36328 .55317 .36855 .55153 .36532 .54849 Mtetra
.664 .741 .907 r
.36532 .54849 .36855 .55153 .37383 .54988 .3706 .54684 Mtetra
.3706 .54684 .37383 .54988 .37912 .54824 .3759 .54518 Mtetra
.3759 .54518 .37912 .54824 .38441 .54658 .3812 .54352 Mtetra
.3812 .54352 .38441 .54658 .38972 .54493 .38652 .54187 Mtetra
.38652 .54187 .38972 .54493 .39504 .54327 .39184 .5402 Mtetra
.39184 .5402 .39504 .54327 .40037 .54161 .39718 .53853 Mtetra
.39718 .53853 .40037 .54161 .40571 .53994 .40253 .53686 Mtetra
.40253 .53686 .40571 .53994 .41106 .53827 .40788 .53519 Mtetra
.40788 .53519 .41106 .53827 .41642 .5366 .41325 .53351 Mtetra
.41325 .53351 .41642 .5366 .42179 .53493 .41863 .53183 Mtetra
.41863 .53183 .42179 .53493 .42718 .53325 .42402 .53014 Mtetra
.42402 .53014 .42718 .53325 .43257 .53157 .42942 .52845 Mtetra
.42942 .52845 .43257 .53157 .43797 .52988 .43483 .52676 Mtetra
.43483 .52676 .43797 .52988 .44339 .52819 .44025 .52507 Mtetra
.44025 .52507 .44339 .52819 .44881 .5265 .44569 .52337 Mtetra
.44569 .52337 .44881 .5265 .45425 .52481 .45113 .52167 Mtetra
.45113 .52167 .45425 .52481 .4597 .52311 .45658 .51996 Mtetra
.45658 .51996 .4597 .52311 .46516 .52141 .46205 .51825 Mtetra
.46205 .51825 .46516 .52141 .47063 .5197 .46753 .51654 Mtetra
.46753 .51654 .47063 .5197 .47611 .51799 .47301 .51483 Mtetra
.47301 .51483 .47611 .51799 .4816 .51628 .47851 .51311 Mtetra
.47851 .51311 .4816 .51628 .4871 .51456 .48402 .51139 Mtetra
.48402 .51139 .4871 .51456 .49262 .51285 .48954 .50966 Mtetra
.48954 .50966 .49262 .51285 .49814 .51113 .49508 .50793 Mtetra
.49508 .50793 .49814 .51113 .50368 .5094 .50062 .5062 Mtetra
.50062 .5062 .50368 .5094 .50922 .50766 .50617 .50446 Mtetra
.50617 .50446 .50922 .50766 .51478 .50593 .51174 .50272 Mtetra
.51174 .50272 .51478 .50593 .52035 .5042 .51732 .50098 Mtetra
.51732 .50098 .52035 .5042 .52593 .50246 .5229 .49923 Mtetra
.664 .74 .907 r
.5229 .49923 .52593 .50246 .53153 .50071 .5285 .49748 Mtetra
.664 .741 .907 r
.5285 .49748 .53153 .50071 .53713 .49896 .53412 .49573 Mtetra
.53412 .49573 .53713 .49896 .54275 .49721 .53974 .49397 Mtetra
.53974 .49397 .54275 .49721 .54837 .49547 .54537 .49221 Mtetra
.664 .74 .907 r
.54537 .49221 .54837 .49547 .55401 .49371 .55102 .49044 Mtetra
.55102 .49044 .55401 .49371 .55966 .49194 .55668 .48868 Mtetra
.663 .741 .908 r
.55668 .48868 .55966 .49194 .56532 .49017 .56235 .48691 Mtetra
.664 .741 .908 r
.56235 .48691 .56532 .49017 .571 .48841 .56803 .48514 Mtetra
.56803 .48514 .571 .48841 .57668 .48665 .57372 .48336 Mtetra
.664 .74 .907 r
.57372 .48336 .57668 .48665 .58238 .48488 .57942 .48158 Mtetra
.663 .74 .907 r
.57942 .48158 .58238 .48488 .58808 .4831 .58514 .47981 Mtetra
.662 .741 .908 r
.58514 .47981 .58808 .4831 .5938 .48132 .59087 .47805 Mtetra
.662 .742 .909 r
.59087 .47805 .5938 .48132 .59954 .47957 .59661 .47628 Mtetra
.661 .741 .909 r
.59661 .47628 .59954 .47957 .60528 .47783 .60236 .47452 Mtetra
.659 .74 .91 r
.60236 .47452 .60528 .47783 .61104 .47609 .60812 .4728 Mtetra
.654 .739 .912 r
.60812 .4728 .61104 .47609 .61681 .4744 .6139 .47114 Mtetra
.648 .74 .916 r
.6139 .47114 .61681 .4744 .62259 .47279 .6197 .46955 Mtetra
.639 .739 .921 r
.6197 .46955 .62259 .47279 .62839 .47128 .62551 .4681 Mtetra
.622 .736 .929 r
.62551 .4681 .62839 .47128 .63421 .46996 .63134 .46686 Mtetra
.588 .73 .942 r
.63134 .46686 .63421 .46996 .64006 .46894 .6372 .46599 Mtetra
.523 .715 .96 r
.6372 .46599 .64006 .46894 .64594 .46841 .64309 .46572 Mtetra
.383 .668 .971 r
.64309 .46572 .64594 .46841 .65186 .46868 .64904 .46639 Mtetra
.066 .507 .896 r
.64904 .46639 .65186 .46868 .65786 .47018 .65507 .46849 Mtetra
.451 0 0 r
.65507 .46849 .65786 .47018 .66396 .47354 .66121 .47276 Mtetra
.763 .25 0 r
.66121 .47276 .66396 .47354 .67021 .4796 .66752 .48007 Mtetra
.851 .412 .174 r
.66752 .48007 .67021 .4796 .67666 .48922 .67405 .49116 Mtetra
.869 .473 .284 r
.67405 .49116 .67666 .48922 .68335 .50273 .68081 .50596 Mtetra
.865 .487 .329 r
.68081 .50596 .68335 .50273 .69025 .51902 .68773 .52255 Mtetra
.841 .454 .318 r
.68773 .52255 .69025 .51902 .69719 .53456 .69459 .53642 Mtetra
.714 .235 .109 r
.69459 .53642 .69719 .53456 .70387 .54376 .70108 .54185 Mtetra
.868 .874 .839 r
.70108 .54185 .70387 .54376 .71 .54198 .70698 .53561 Mtetra
.882 .704 .657 r
.70698 .53561 .71 .54198 .71552 .52917 .71234 .5197 Mtetra
.864 .662 .628 r
.71234 .5197 .71552 .52917 .72063 .50994 .71741 .4996 Mtetra
.849 .648 .63 r
.71741 .4996 .72063 .50994 .72564 .48994 .72248 .48036 Mtetra
.836 .648 .647 r
.72248 .48036 .72564 .48994 .73077 .47274 .72771 .46455 Mtetra
.823 .657 .677 r
.72771 .46455 .73077 .47274 .73611 .45942 .73315 .45264 Mtetra
.806 .672 .716 r
.73315 .45264 .73611 .45942 .74166 .44966 .73878 .44406 Mtetra
.784 .692 .762 r
.73878 .44406 .74166 .44966 .74738 .44268 .74457 .43796 Mtetra
.754 .712 .812 r
.74457 .43796 .74738 .44268 .75323 .43771 .75048 .43369 Mtetra
.708 .727 .865 r
.75048 .43369 .75323 .43771 .75919 .43426 .7565 .43091 Mtetra
.616 .733 .929 r
.7565 .43091 .75919 .43426 .76526 .43212 .76264 .42969 Mtetra
.317 .654 .971 r
.76264 .42969 .76526 .43212 .77145 .43152 .76896 .43062 Mtetra
.535 0 0 r
.76896 .43062 .77145 .43152 .77785 .43326 .77559 .43519 Mtetra
.828 .391 .197 r
.77559 .43519 .77785 .43326 .7846 .43915 .78276 .44618 Mtetra
.854 .498 .377 r
.78276 .44618 .7846 .43915 .792 .45243 .79087 .46803 Mtetra
.847 .526 .445 r
.79087 .46803 .792 .45243 .80049 .47784 .80037 .50534 Mtetra
.824 .522 .479 r
.80037 .50534 .80049 .47784 .81046 .51925 .81119 .55625 Mtetra
.773 .486 .499 r
.81119 .55625 .81046 .51925 .82155 .57131 .82169 .60102 Mtetra
.613 .347 .491 r
.82169 .60102 .82155 .57131 .83161 .6093 .829 .60751 Mtetra
.988 .756 .497 r
.829 .60751 .83161 .6093 .83782 .60337 .83225 .5686 Mtetra
.832 .58 .558 r
.83225 .5686 .83782 .60337 .84025 .5569 .83378 .51259 Mtetra
.778 .536 .57 r
.83378 .51259 .84025 .5569 .84167 .50151 .83598 .46582 Mtetra
.753 .524 .585 r
.83598 .46582 .84167 .50151 .84413 .45875 .83957 .43508 Mtetra
.742 .532 .609 r
.83957 .43508 .84413 .45875 .84798 .43165 .84429 .41685 Mtetra
.736 .557 .65 r
.84429 .41685 .84798 .43165 .85289 .41578 .84972 .40625 Mtetra
.731 .597 .707 r
.84972 .40625 .85289 .41578 .85844 .40652 .85557 .39987 Mtetra
.72 .643 .771 r
.85557 .39987 .85844 .40652 .86435 .40082 .86165 .39567 Mtetra
.705 .683 .826 r
.86165 .39567 .86435 .40082 .87046 .39697 .86784 .39258 Mtetra
.691 .711 .864 r
.86784 .39258 .87046 .39697 .87667 .39405 .87411 .39003 Mtetra
.679 .726 .885 r
.87411 .39003 .87667 .39405 .88295 .39161 .88042 .38776 Mtetra
.672 .733 .896 r
.88042 .38776 .88295 .39161 .88927 .38941 .88675 .38564 Mtetra
.668 .736 .901 r
.88675 .38564 .88927 .38941 .89561 .38731 .89311 .38359 Mtetra
.666 .738 .904 r
.89311 .38359 .89561 .38731 .90197 .38526 .89949 .38156 Mtetra
.665 .74 .906 r
.89949 .38156 .90197 .38526 .90835 .38323 .90588 .37955 Mtetra
.665 .741 .907 r
.90588 .37955 .90835 .38323 .91475 .38122 .91229 .37753 Mtetra
.664 .741 .907 r
.91229 .37753 .91475 .38122 .92116 .37922 .91871 .37551 Mtetra
.664 .74 .907 r
.91871 .37551 .92116 .37922 .92759 .37722 .92514 .3735 Mtetra
.92514 .3735 .92759 .37722 .93402 .37521 .93159 .37149 Mtetra
.664 .741 .907 r
.35153 .54874 .35479 .55178 .36005 .55014 .3568 .54709 Mtetra
.664 .74 .907 r
.3568 .54709 .36005 .55014 .36532 .54849 .36208 .54544 Mtetra
.664 .741 .907 r
.36208 .54544 .36532 .54849 .3706 .54684 .36737 .54379 Mtetra
.36737 .54379 .3706 .54684 .3759 .54518 .37267 .54212 Mtetra
.37267 .54212 .3759 .54518 .3812 .54352 .37798 .54046 Mtetra
.37798 .54046 .3812 .54352 .38652 .54187 .3833 .53879 Mtetra
.3833 .53879 .38652 .54187 .39184 .5402 .38863 .53712 Mtetra
.38863 .53712 .39184 .5402 .39718 .53853 .39398 .53545 Mtetra
.39398 .53545 .39718 .53853 .40253 .53686 .39933 .53377 Mtetra
.39933 .53377 .40253 .53686 .40788 .53519 .40469 .53208 Mtetra
.40469 .53208 .40788 .53519 .41325 .53351 .41007 .5304 Mtetra
.41007 .5304 .41325 .53351 .41863 .53183 .41545 .52871 Mtetra
.41545 .52871 .41863 .53183 .42402 .53014 .42085 .52702 Mtetra
.42085 .52702 .42402 .53014 .42942 .52845 .42626 .52533 Mtetra
.42626 .52533 .42942 .52845 .43483 .52676 .43168 .52363 Mtetra
.43168 .52363 .43483 .52676 .44025 .52507 .4371 .52193 Mtetra
.4371 .52193 .44025 .52507 .44569 .52337 .44254 .52023 Mtetra
.44254 .52023 .44569 .52337 .45113 .52167 .44799 .51852 Mtetra
.44799 .51852 .45113 .52167 .45658 .51996 .45346 .51681 Mtetra
.45346 .51681 .45658 .51996 .46205 .51825 .45893 .51509 Mtetra
.45893 .51509 .46205 .51825 .46753 .51654 .46441 .51337 Mtetra
.46441 .51337 .46753 .51654 .47301 .51483 .46991 .51165 Mtetra
.46991 .51165 .47301 .51483 .47851 .51311 .47541 .50993 Mtetra
.47541 .50993 .47851 .51311 .48402 .51139 .48093 .5082 Mtetra
.48093 .5082 .48402 .51139 .48954 .50966 .48646 .50647 Mtetra
.48646 .50647 .48954 .50966 .49508 .50793 .492 .50473 Mtetra
.492 .50473 .49508 .50793 .50062 .5062 .49755 .50299 Mtetra
.49755 .50299 .50062 .5062 .50617 .50446 .50311 .50125 Mtetra
.50311 .50125 .50617 .50446 .51174 .50272 .50868 .4995 Mtetra
.50868 .4995 .51174 .50272 .51732 .50098 .51427 .49775 Mtetra
.51427 .49775 .51732 .50098 .5229 .49923 .51986 .496 Mtetra
.51986 .496 .5229 .49923 .5285 .49748 .52547 .49424 Mtetra
.52547 .49424 .5285 .49748 .53412 .49573 .53109 .49248 Mtetra
.53109 .49248 .53412 .49573 .53974 .49397 .53672 .49072 Mtetra
.53672 .49072 .53974 .49397 .54537 .49221 .54236 .48895 Mtetra
.54236 .48895 .54537 .49221 .55102 .49044 .54802 .48718 Mtetra
.54802 .48718 .55102 .49044 .55668 .48868 .55368 .4854 Mtetra
.55368 .4854 .55668 .48868 .56235 .48691 .55936 .48363 Mtetra
.664 .74 .907 r
.55936 .48363 .56235 .48691 .56803 .48514 .56505 .48185 Mtetra
.663 .741 .907 r
.56505 .48185 .56803 .48514 .57372 .48336 .57075 .48007 Mtetra
.663 .741 .908 r
.57075 .48007 .57372 .48336 .57942 .48158 .57646 .47829 Mtetra
.57646 .47829 .57942 .48158 .58514 .47981 .58218 .47651 Mtetra
.662 .741 .908 r
.58218 .47651 .58514 .47981 .59087 .47805 .58792 .47473 Mtetra
.661 .74 .908 r
.58792 .47473 .59087 .47805 .59661 .47628 .59367 .47297 Mtetra
.66 .74 .909 r
.59367 .47297 .59661 .47628 .60236 .47452 .59943 .47123 Mtetra
.657 .741 .911 r
.59943 .47123 .60236 .47452 .60812 .4728 .6052 .46952 Mtetra
.653 .741 .914 r
.6052 .46952 .60812 .4728 .6139 .47114 .61099 .46786 Mtetra
.646 .739 .917 r
.61099 .46786 .6139 .47114 .6197 .46955 .61679 .46631 Mtetra
.633 .737 .923 r
.61679 .46631 .6197 .46955 .62551 .4681 .62261 .46492 Mtetra
.61 .734 .933 r
.62261 .46492 .62551 .4681 .63134 .46686 .62846 .46381 Mtetra
.569 .727 .949 r
.62846 .46381 .63134 .46686 .6372 .46599 .63433 .46313 Mtetra
.484 .705 .967 r
.63433 .46313 .6372 .46599 .64309 .46572 .64024 .46315 Mtetra
.295 .629 .962 r
.64024 .46315 .64309 .46572 .64904 .46639 .64622 .46427 Mtetra
0 .383 .799 r
.64622 .46427 .64904 .46639 .65507 .46849 .65228 .4671 Mtetra
.609 .051 0 r
.65228 .4671 .65507 .46849 .66121 .47276 .65847 .47241 Mtetra
.811 .329 .044 r
.65847 .47241 .66121 .47276 .66752 .48007 .66484 .48108 Mtetra
.862 .442 .226 r
.66484 .48108 .66752 .48007 .67405 .49116 .67144 .49364 Mtetra
.869 .483 .307 r
.67144 .49364 .67405 .49116 .68081 .50596 .67825 .50948 Mtetra
.859 .482 .332 r
.67825 .50948 .68081 .50596 .68773 .52255 .68516 .52571 Mtetra
.82 .417 .286 r
.68516 .52571 .68773 .52255 .69459 .53642 .69191 .53705 Mtetra
.337 0 0 r
.69191 .53705 .69459 .53642 .70108 .54185 .6982 .53822 Mtetra
.891 .776 .727 r
.6982 .53822 .70108 .54185 .70698 .53561 .70389 .52784 Mtetra
.875 .683 .64 r
.70389 .52784 .70698 .53561 .71234 .5197 .70913 .50964 Mtetra
.858 .654 .626 r
.70913 .50964 .71234 .5197 .71741 .4996 .7142 .48937 Mtetra
.844 .646 .635 r
.7142 .48937 .71741 .4996 .72248 .48036 .71935 .47124 Mtetra
.831 .65 .657 r
.71935 .47124 .72248 .48036 .72771 .46455 .72468 .45692 Mtetra
.817 .662 .691 r
.72468 .45692 .72771 .46455 .73315 .45264 .73021 .44636 Mtetra
.799 .68 .734 r
.73021 .44636 .73315 .45264 .73878 .44406 .73592 .43883 Mtetra
.772 .7 .783 r
.73592 .43883 .73878 .44406 .74457 .43796 .74177 .43355 Mtetra
.733 .718 .836 r
.74177 .43355 .74457 .43796 .75048 .43369 .74774 .43004 Mtetra
.662 .732 .901 r
.74774 .43004 .75048 .43369 .7565 .43091 .75383 .42816 Mtetra
.458 .705 .974 r
.75383 .42816 .7565 .43091 .76264 .42969 .76009 .4283 Mtetra
0 .261 .647 r
.76009 .4283 .76264 .42969 .76896 .43062 .7666 .43164 Mtetra
.802 .33 .104 r
.7666 .43164 .76896 .43062 .77559 .43519 .77357 .44061 Mtetra
.853 .482 .348 r
.77357 .44061 .77559 .43519 .78276 .44618 .78136 .45924 Mtetra
.85 .523 .433 r
.78136 .45924 .78276 .44618 .79087 .46803 .7904 .49242 Mtetra
.831 .526 .473 r
.7904 .49242 .79087 .46803 .80037 .50534 .80085 .5409 Mtetra
.79 .499 .495 r
.80085 .5409 .80037 .50534 .81119 .55625 .81158 .59015 Mtetra
.681 .407 .5 r
.81158 .59015 .81119 .55625 .82169 .60102 .81987 .60856 Mtetra
.877 .768 .266 r
.81987 .60856 .82169 .60102 .829 .60751 .82407 .5793 Mtetra
.855 .601 .555 r
.82407 .5793 .829 .60751 .83225 .5686 .82586 .52438 Mtetra
.787 .543 .567 r
.82586 .52438 .83225 .5686 .83378 .51259 .82787 .47392 Mtetra
.758 .525 .58 r
.82787 .47392 .83378 .51259 .83598 .46582 .83118 .43928 Mtetra
.743 .528 .602 r
.83118 .43928 .83598 .46582 .83957 .43508 .8357 .4184 Mtetra
.737 .549 .638 r
.8357 .4184 .83957 .43508 .84429 .41685 .84101 .40629 Mtetra
.733 .586 .692 r
.84101 .40629 .84429 .41685 .84972 .40625 .84679 .39907 Mtetra
.724 .633 .756 r
.84679 .39907 .84972 .40625 .85557 .39987 .85282 .39442 Mtetra
.71 .675 .814 r
.85282 .39442 .85557 .39987 .86165 .39567 .859 .3911 Mtetra
.693 .703 .855 r
.859 .3911 .86165 .39567 .86784 .39258 .86525 .38846 Mtetra
.681 .721 .88 r
.86525 .38846 .86784 .39258 .87411 .39003 .87155 .38615 Mtetra
.673 .732 .894 r
.87155 .38615 .87411 .39003 .88042 .38776 .87788 .384 Mtetra
.669 .737 .901 r
.87788 .384 .88042 .38776 .88675 .38564 .88424 .38192 Mtetra
.667 .739 .904 r
.88424 .38192 .88675 .38564 .89311 .38359 .89061 .37987 Mtetra
.665 .739 .905 r
.89061 .37987 .89311 .38359 .89949 .38156 .89699 .37784 Mtetra
.664 .739 .906 r
.89699 .37784 .89949 .38156 .90588 .37955 .9034 .37583 Mtetra
.664 .74 .907 r
.9034 .37583 .90588 .37955 .91229 .37753 .90982 .37383 Mtetra
.664 .741 .907 r
.90982 .37383 .91229 .37753 .91871 .37551 .91625 .37181 Mtetra
.664 .742 .908 r
.91625 .37181 .91871 .37551 .92514 .3735 .92269 .36978 Mtetra
.664 .741 .907 r
.92269 .36978 .92514 .3735 .93159 .37149 .92915 .36775 Mtetra
.34826 .5457 .35153 .54874 .3568 .54709 .35354 .54404 Mtetra
.35354 .54404 .3568 .54709 .36208 .54544 .35883 .54238 Mtetra
.35883 .54238 .36208 .54544 .36737 .54379 .36412 .54071 Mtetra
.664 .74 .907 r
.36412 .54071 .36737 .54379 .37267 .54212 .36943 .53905 Mtetra
.664 .741 .907 r
.36943 .53905 .37267 .54212 .37798 .54046 .37475 .53738 Mtetra
.37475 .53738 .37798 .54046 .3833 .53879 .38007 .5357 Mtetra
.38007 .5357 .3833 .53879 .38863 .53712 .38541 .53402 Mtetra
.38541 .53402 .38863 .53712 .39398 .53545 .39076 .53234 Mtetra
.39076 .53234 .39398 .53545 .39933 .53377 .39612 .53066 Mtetra
.664 .74 .907 r
.39612 .53066 .39933 .53377 .40469 .53208 .40149 .52898 Mtetra
.664 .741 .908 r
.40149 .52898 .40469 .53208 .41007 .5304 .40687 .52729 Mtetra
.664 .741 .907 r
.40687 .52729 .41007 .5304 .41545 .52871 .41227 .52559 Mtetra
.41227 .52559 .41545 .52871 .42085 .52702 .41767 .52389 Mtetra
.41767 .52389 .42085 .52702 .42626 .52533 .42308 .52219 Mtetra
.42308 .52219 .42626 .52533 .43168 .52363 .42851 .52049 Mtetra
.42851 .52049 .43168 .52363 .4371 .52193 .43394 .51878 Mtetra
.43394 .51878 .4371 .52193 .44254 .52023 .43939 .51707 Mtetra
.43939 .51707 .44254 .52023 .44799 .51852 .44485 .51536 Mtetra
.44485 .51536 .44799 .51852 .45346 .51681 .45032 .51364 Mtetra
.45032 .51364 .45346 .51681 .45893 .51509 .4558 .51192 Mtetra
.4558 .51192 .45893 .51509 .46441 .51337 .46129 .51019 Mtetra
.46129 .51019 .46441 .51337 .46991 .51165 .46679 .50847 Mtetra
.46679 .50847 .46991 .51165 .47541 .50993 .4723 .50673 Mtetra
.4723 .50673 .47541 .50993 .48093 .5082 .47783 .505 Mtetra
.47783 .505 .48093 .5082 .48646 .50647 .48336 .50326 Mtetra
.48336 .50326 .48646 .50647 .492 .50473 .48891 .50152 Mtetra
.48891 .50152 .492 .50473 .49755 .50299 .49447 .49977 Mtetra
.49447 .49977 .49755 .50299 .50311 .50125 .50004 .49802 Mtetra
.50004 .49802 .50311 .50125 .50868 .4995 .50562 .49627 Mtetra
.50562 .49627 .50868 .4995 .51427 .49775 .51121 .49451 Mtetra
.51121 .49451 .51427 .49775 .51986 .496 .51681 .49275 Mtetra
.51681 .49275 .51986 .496 .52547 .49424 .52243 .49099 Mtetra
.52243 .49099 .52547 .49424 .53109 .49248 .52805 .48922 Mtetra
.52805 .48922 .53109 .49248 .53672 .49072 .53369 .48745 Mtetra
.53369 .48745 .53672 .49072 .54236 .48895 .53934 .48568 Mtetra
.53934 .48568 .54236 .48895 .54802 .48718 .545 .4839 Mtetra
.545 .4839 .54802 .48718 .55368 .4854 .55067 .48212 Mtetra
.664 .741 .908 r
.55067 .48212 .55368 .4854 .55936 .48363 .55636 .48034 Mtetra
.55636 .48034 .55936 .48363 .56505 .48185 .56205 .47855 Mtetra
.664 .741 .907 r
.56205 .47855 .56505 .48185 .57075 .48007 .56776 .47676 Mtetra
.663 .741 .908 r
.56776 .47676 .57075 .48007 .57646 .47829 .57348 .47498 Mtetra
.57348 .47498 .57646 .47829 .58218 .47651 .57921 .47319 Mtetra
.662 .741 .908 r
.57921 .47319 .58218 .47651 .58792 .47473 .58496 .47142 Mtetra
.661 .741 .909 r
.58496 .47142 .58792 .47473 .59367 .47297 .59071 .46965 Mtetra
.659 .741 .91 r
.59071 .46965 .59367 .47297 .59943 .47123 .59648 .46791 Mtetra
.656 .74 .912 r
.59648 .46791 .59943 .47123 .6052 .46952 .60227 .46622 Mtetra
.65 .739 .915 r
.60227 .46622 .6052 .46952 .61099 .46786 .60806 .46459 Mtetra
.642 .739 .919 r
.60806 .46459 .61099 .46786 .61679 .46631 .61387 .46309 Mtetra
.626 .737 .927 r
.61387 .46309 .61679 .46631 .62261 .46492 .61971 .46178 Mtetra
.598 .732 .938 r
.61971 .46178 .62261 .46492 .62846 .46381 .62556 .46079 Mtetra
.544 .72 .955 r
.62556 .46079 .62846 .46381 .63433 .46313 .63145 .46034 Mtetra
.43 .685 .971 r
.63145 .46034 .63433 .46313 .64024 .46315 .63738 .46072 Mtetra
.168 .566 .933 r
.63738 .46072 .64024 .46315 .64622 .46427 .64339 .4624 Mtetra
0 .223 .644 r
.64339 .4624 .64622 .46427 .65228 .4671 .64949 .46605 Mtetra
.715 .182 0 r
.64949 .46605 .65228 .4671 .65847 .47241 .65573 .47251 Mtetra
.839 .384 .129 r
.65573 .47251 .65847 .47241 .66484 .48108 .66217 .48262 Mtetra
.867 .464 .265 r
.66217 .48262 .66484 .48108 .67144 .49364 .66884 .4966 Mtetra
.867 .487 .323 r
.66884 .4966 .67144 .49364 .67825 .50948 .67568 .51308 Mtetra
.849 .469 .328 r
.67568 .51308 .67825 .50948 .68516 .52571 .68255 .52818 Mtetra
.777 .341 .213 r
.68255 .52818 .68516 .52571 .69191 .53705 .68914 .5362 Mtetra
.717 .946 .955 r
.68914 .5362 .69191 .53705 .6982 .53822 .69521 .5329 Mtetra
.887 .725 .676 r
.69521 .5329 .6982 .53822 .70389 .52784 .70073 .51894 Mtetra
.868 .669 .631 r
.70073 .51894 .70389 .52784 .70913 .50964 .7059 .49929 Mtetra
.853 .65 .628 r
.7059 .49929 .70913 .50964 .7142 .48937 .71101 .47945 Mtetra
.839 .647 .642 r
.71101 .47945 .7142 .48937 .71935 .47124 .71625 .46266 Mtetra
.826 .654 .669 r
.71625 .46266 .71935 .47124 .72468 .45692 .72167 .44983 Mtetra
.811 .669 .706 r
.72167 .44983 .72468 .45692 .73021 .44636 .72729 .44053 Mtetra
.789 .688 .753 r
.72729 .44053 .73021 .44636 .73592 .43883 .73308 .43398 Mtetra
.757 .708 .807 r
.73308 .43398 .73592 .43883 .74177 .43355 .73899 .42955 Mtetra
.701 .727 .87 r
.73899 .42955 .74177 .43355 .74774 .43004 .74503 .42691 Mtetra
.561 .726 .951 r
.74503 .42691 .74774 .43004 .75383 .42816 .75122 .42626 Mtetra
0 .477 .857 r
.75122 .42626 .75383 .42816 .76009 .4283 .75764 .42852 Mtetra
.753 .24 0 r
.75764 .42852 .76009 .4283 .7666 .43164 .76444 .4357 Mtetra
.849 .461 .311 r
.76444 .4357 .7666 .43164 .77357 .44061 .77194 .45139 Mtetra
.852 .517 .419 r
.77194 .45139 .77357 .44061 .78136 .45924 .78056 .48051 Mtetra
.837 .528 .465 r
.78056 .48051 .78136 .45924 .7904 .49242 .79059 .52568 Mtetra
.804 .509 .49 r
.79059 .52568 .7904 .49242 .80085 .5409 .80134 .57729 Mtetra
.723 .443 .502 r
.80134 .57729 .80085 .5409 .81158 .59015 .81044 .60638 Mtetra
.046 0 .3 r
.81044 .60638 .81158 .59015 .81987 .60856 .81566 .58833 Mtetra
.886 .632 .549 r
.81566 .58833 .81987 .60856 .82407 .5793 .81789 .53655 Mtetra
.799 .552 .564 r
.81789 .53655 .82407 .5793 .82586 .52438 .81978 .48311 Mtetra
.763 .527 .576 r
.81978 .48311 .82586 .52438 .82787 .47392 .82283 .44439 Mtetra
.746 .525 .595 r
.82283 .44439 .82787 .47392 .83118 .43928 .82713 .4205 Mtetra
.739 .542 .627 r
.82713 .4205 .83118 .43928 .8357 .4184 .83231 .40659 Mtetra
.734 .575 .677 r
.83231 .40659 .8357 .4184 .84101 .40629 .838 .3984 Mtetra
.726 .62 .739 r
.838 .3984 .84101 .40629 .84679 .39907 .84399 .39327 Mtetra
.713 .664 .801 r
.84399 .39327 .84679 .39907 .85282 .39442 .85014 .3897 Mtetra
.698 .699 .847 r
.85014 .3897 .85282 .39442 .859 .3911 .85638 .38692 Mtetra
.685 .72 .876 r
.85638 .38692 .859 .3911 .86525 .38846 .86267 .38453 Mtetra
.675 .73 .891 r
.86267 .38453 .86525 .38846 .87155 .38615 .86899 .38233 Mtetra
.669 .734 .898 r
.86899 .38233 .87155 .38615 .87788 .384 .87534 .38023 Mtetra
.666 .737 .903 r
.87534 .38023 .87788 .384 .88424 .38192 .88171 .37819 Mtetra
.665 .739 .906 r
.88171 .37819 .88424 .38192 .89061 .37987 .88809 .37617 Mtetra
.665 .742 .907 r
.88809 .37617 .89061 .37987 .89699 .37784 .89449 .37414 Mtetra
.665 .741 .907 r
.89449 .37414 .89699 .37784 .9034 .37583 .9009 .37211 Mtetra
.664 .74 .907 r
.9009 .37211 .9034 .37583 .90982 .37383 .90733 .37009 Mtetra
.90733 .37009 .90982 .37383 .91625 .37181 .91377 .36807 Mtetra
.663 .74 .907 r
.91377 .36807 .91625 .37181 .92269 .36978 .92023 .36605 Mtetra
.664 .741 .908 r
.92023 .36605 .92269 .36978 .92915 .36775 .9267 .36401 Mtetra
.663 .74 .907 r
.34499 .54263 .34826 .5457 .35354 .54404 .35027 .54098 Mtetra
.664 .742 .908 r
.35027 .54098 .35354 .54404 .35883 .54238 .35556 .53931 Mtetra
.664 .741 .907 r
.35556 .53931 .35883 .54238 .36412 .54071 .36086 .53763 Mtetra
.36086 .53763 .36412 .54071 .36943 .53905 .36618 .53596 Mtetra
.36618 .53596 .36943 .53905 .37475 .53738 .3715 .53428 Mtetra
.664 .74 .907 r
.3715 .53428 .37475 .53738 .38007 .5357 .37684 .53261 Mtetra
.664 .741 .908 r
.37684 .53261 .38007 .5357 .38541 .53402 .38218 .53093 Mtetra
.664 .741 .907 r
.38218 .53093 .38541 .53402 .39076 .53234 .38754 .52923 Mtetra
.38754 .52923 .39076 .53234 .39612 .53066 .3929 .52754 Mtetra
.3929 .52754 .39612 .53066 .40149 .52898 .39828 .52585 Mtetra
.39828 .52585 .40149 .52898 .40687 .52729 .40367 .52415 Mtetra
.664 .74 .907 r
.40367 .52415 .40687 .52729 .41227 .52559 .40907 .52246 Mtetra
.664 .741 .908 r
.40907 .52246 .41227 .52559 .41767 .52389 .41448 .52075 Mtetra
.664 .741 .907 r
.41448 .52075 .41767 .52389 .42308 .52219 .4199 .51904 Mtetra
.4199 .51904 .42308 .52219 .42851 .52049 .42533 .51733 Mtetra
.42533 .51733 .42851 .52049 .43394 .51878 .43077 .51562 Mtetra
.43077 .51562 .43394 .51878 .43939 .51707 .43623 .5139 Mtetra
.43623 .5139 .43939 .51707 .44485 .51536 .44169 .51219 Mtetra
.44169 .51219 .44485 .51536 .45032 .51364 .44717 .51046 Mtetra
.44717 .51046 .45032 .51364 .4558 .51192 .45265 .50873 Mtetra
.45265 .50873 .4558 .51192 .46129 .51019 .45815 .507 Mtetra
.45815 .507 .46129 .51019 .46679 .50847 .46366 .50526 Mtetra
.46366 .50526 .46679 .50847 .4723 .50673 .46918 .50353 Mtetra
.664 .741 .908 r
.46918 .50353 .4723 .50673 .47783 .505 .47471 .50179 Mtetra
.664 .741 .907 r
.47471 .50179 .47783 .505 .48336 .50326 .48025 .50004 Mtetra
.48025 .50004 .48336 .50326 .48891 .50152 .48581 .49829 Mtetra
.48581 .49829 .48891 .50152 .49447 .49977 .49137 .49654 Mtetra
.49137 .49654 .49447 .49977 .50004 .49802 .49695 .49478 Mtetra
.49695 .49478 .50004 .49802 .50562 .49627 .50254 .49303 Mtetra
.50254 .49303 .50562 .49627 .51121 .49451 .50814 .49126 Mtetra
.50814 .49126 .51121 .49451 .51681 .49275 .51375 .48949 Mtetra
.51375 .48949 .51681 .49275 .52243 .49099 .51937 .48772 Mtetra
.51937 .48772 .52243 .49099 .52805 .48922 .525 .48595 Mtetra
.525 .48595 .52805 .48922 .53369 .48745 .53065 .48417 Mtetra
.53065 .48417 .53369 .48745 .53934 .48568 .53631 .48239 Mtetra
.53631 .48239 .53934 .48568 .545 .4839 .54198 .4806 Mtetra
.54198 .4806 .545 .4839 .55067 .48212 .54766 .47882 Mtetra
.663 .741 .907 r
.54766 .47882 .55067 .48212 .55636 .48034 .55335 .47703 Mtetra
.664 .741 .908 r
.55335 .47703 .55636 .48034 .56205 .47855 .55905 .47524 Mtetra
.55905 .47524 .56205 .47855 .56776 .47676 .56477 .47345 Mtetra
.663 .741 .908 r
.56477 .47345 .56776 .47676 .57348 .47498 .5705 .47165 Mtetra
.662 .741 .908 r
.5705 .47165 .57348 .47498 .57921 .47319 .57623 .46987 Mtetra
.662 .741 .909 r
.57623 .46987 .57921 .47319 .58496 .47142 .58199 .46809 Mtetra
.66 .74 .909 r
.58199 .46809 .58496 .47142 .59071 .46965 .58775 .46633 Mtetra
.658 .74 .911 r
.58775 .46633 .59071 .46965 .59648 .46791 .59353 .4646 Mtetra
.654 .74 .913 r
.59353 .4646 .59648 .46791 .60227 .46622 .59932 .46292 Mtetra
.648 .74 .916 r
.59932 .46292 .60227 .46622 .60806 .46459 .60512 .46133 Mtetra
.637 .738 .922 r
.60512 .46133 .60806 .46459 .61387 .46309 .61095 .45988 Mtetra
.618 .735 .93 r
.61095 .45988 .61387 .46309 .61971 .46178 .61679 .45867 Mtetra
.582 .729 .944 r
.61679 .45867 .61971 .46178 .62556 .46079 .62266 .45785 Mtetra
.511 .712 .962 r
.62266 .45785 .62556 .46079 .63145 .46034 .62856 .45766 Mtetra
.357 .657 .97 r
.62856 .45766 .63145 .46034 .63738 .46072 .63452 .45845 Mtetra
.007 .469 .869 r
.63452 .45845 .63738 .46072 .64339 .4624 .64055 .46078 Mtetra
.51 0 0 r
.64055 .46078 .64339 .4624 .64949 .46605 .64669 .46539 Mtetra
.783 .281 0 r
.64669 .46539 .64949 .46605 .65573 .47251 .653 .47314 Mtetra
.855 .424 .194 r
.653 .47314 .65573 .47251 .66217 .48262 .6595 .48474 Mtetra
.869 .477 .294 r
.6595 .48474 .66217 .48262 .66884 .4966 .66622 .49993 Mtetra
.863 .486 .331 r
.66622 .49993 .66884 .4966 .67568 .51308 .67308 .5165 Mtetra
.835 .444 .309 r
.67308 .5165 .67568 .51308 .68255 .52818 .67987 .52965 Mtetra
.651 .138 .01 r
.67987 .52965 .68255 .52818 .68914 .5362 .68628 .5337 Mtetra
.884 .833 .791 r
.68628 .5337 .68914 .5362 .69521 .5329 .69214 .52601 Mtetra
.879 .696 .65 r
.69214 .52601 .69521 .5329 .70073 .51894 .69752 .50919 Mtetra
.861 .659 .627 r
.69752 .50919 .70073 .51894 .7059 .49929 .70267 .48891 Mtetra
.847 .647 .632 r
.70267 .48891 .7059 .49929 .71101 .47945 .70785 .46998 Mtetra
.835 .649 .651 r
.70785 .46998 .71101 .47945 .71625 .46266 .71317 .45467 Mtetra
.821 .659 .682 r
.71317 .45467 .71625 .46266 .72167 .44983 .7187 .44325 Mtetra
.803 .676 .724 r
.7187 .44325 .72167 .44983 .72729 .44053 .7244 .43512 Mtetra
.776 .696 .775 r
.7244 .43512 .72729 .44053 .73308 .43398 .73025 .42956 Mtetra
.733 .718 .837 r
.73025 .42956 .73308 .43398 .73899 .42955 .73624 .42604 Mtetra
.635 .732 .918 r
.73624 .42604 .73899 .42955 .74503 .42691 .74236 .42457 Mtetra
.253 .625 .959 r
.74236 .42457 .74503 .42691 .75122 .42626 .74869 .42578 Mtetra
.655 .099 0 r
.74869 .42578 .75122 .42626 .75764 .42852 .75536 .43136 Mtetra
.841 .43 .26 r
.75536 .43136 .75764 .42852 .76444 .4357 .76261 .44442 Mtetra
.854 .509 .401 r
.76261 .44442 .76444 .4357 .77194 .45139 .77084 .46969 Mtetra
.842 .528 .457 r
.77084 .46969 .77194 .45139 .78056 .48051 .78043 .51101 Mtetra
.815 .516 .485 r
.78043 .51101 .78056 .48051 .79059 .52568 .79103 .563 Mtetra
.752 .468 .501 r
.79103 .563 .79059 .52568 .80134 .57729 .80074 .60098 Mtetra
.47 .221 .454 r
.80074 .60098 .80134 .57729 .81044 .60638 .80699 .59514 Mtetra
.929 .679 .539 r
.80699 .59514 .81044 .60638 .81566 .58833 .80982 .54874 Mtetra
.814 .564 .561 r
.80982 .54874 .81566 .58833 .81789 .53655 .81171 .4933 Mtetra
.77 .531 .573 r
.81171 .4933 .81789 .53655 .81978 .48311 .81451 .45043 Mtetra
.749 .524 .589 r
.81451 .45043 .81978 .48311 .82283 .44439 .81858 .42322 Mtetra
.74 .536 .618 r
.81858 .42322 .82283 .44439 .82713 .4205 .8236 .40726 Mtetra
.735 .565 .663 r
.8236 .40726 .82713 .4205 .83231 .40659 .82921 .39795 Mtetra
.729 .609 .723 r
.82921 .39795 .83231 .40659 .838 .3984 .83515 .39221 Mtetra
.718 .655 .787 r
.83515 .39221 .838 .3984 .84399 .39327 .84127 .38832 Mtetra
.702 .692 .837 r
.84127 .38832 .84399 .39327 .85014 .3897 .84749 .38538 Mtetra
.687 .714 .869 r
.84749 .38538 .85014 .3897 .85638 .38692 .85377 .38292 Mtetra
.676 .727 .888 r
.85377 .38292 .85638 .38692 .86267 .38453 .86009 .38069 Mtetra
.671 .734 .898 r
.86009 .38069 .86267 .38453 .86899 .38233 .86643 .37857 Mtetra
.668 .739 .903 r
.86643 .37857 .86899 .38233 .87534 .38023 .8728 .3765 Mtetra
.666 .74 .905 r
.8728 .3765 .87534 .38023 .88171 .37819 .87917 .37445 Mtetra
.665 .739 .905 r
.87917 .37445 .88171 .37819 .88809 .37617 .88557 .37242 Mtetra
.664 .739 .906 r
.88557 .37242 .88809 .37617 .89449 .37414 .89198 .37041 Mtetra
.664 .741 .907 r
.89198 .37041 .89449 .37414 .9009 .37211 .8984 .36839 Mtetra
.664 .742 .908 r
.8984 .36839 .9009 .37211 .90733 .37009 .90484 .36635 Mtetra
.664 .741 .907 r
.90484 .36635 .90733 .37009 .91377 .36807 .91129 .36432 Mtetra
.91129 .36432 .91377 .36807 .92023 .36605 .91776 .36228 Mtetra
.664 .74 .907 r
.91776 .36228 .92023 .36605 .9267 .36401 .92424 .36024 Mtetra
.664 .741 .907 r
.3417 .53956 .34499 .54263 .35027 .54098 .34698 .53789 Mtetra
.664 .74 .907 r
.34698 .53789 .35027 .54098 .35556 .53931 .35228 .53622 Mtetra
.663 .74 .907 r
.35228 .53622 .35556 .53931 .36086 .53763 .35759 .53455 Mtetra
.664 .741 .908 r
.35759 .53455 .36086 .53763 .36618 .53596 .36291 .53287 Mtetra
.665 .742 .908 r
.36291 .53287 .36618 .53596 .3715 .53428 .36824 .53118 Mtetra
.664 .741 .907 r
.36824 .53118 .3715 .53428 .37684 .53261 .37358 .52949 Mtetra
.664 .74 .907 r
.37358 .52949 .37684 .53261 .38218 .53093 .37894 .5278 Mtetra
.663 .74 .907 r
.37894 .5278 .38218 .53093 .38754 .52923 .3843 .52612 Mtetra
.663 .741 .908 r
.3843 .52612 .38754 .52923 .3929 .52754 .38967 .52443 Mtetra
.665 .742 .908 r
.38967 .52443 .3929 .52754 .39828 .52585 .39506 .52272 Mtetra
.664 .741 .907 r
.39506 .52272 .39828 .52585 .40367 .52415 .40045 .52101 Mtetra
.40045 .52101 .40367 .52415 .40907 .52246 .40586 .51931 Mtetra
.664 .74 .907 r
.40586 .51931 .40907 .52246 .41448 .52075 .41127 .5176 Mtetra
.663 .741 .907 r
.41127 .5176 .41448 .52075 .4199 .51904 .4167 .51589 Mtetra
.664 .742 .908 r
.4167 .51589 .4199 .51904 .42533 .51733 .42214 .51417 Mtetra
.664 .741 .907 r
.42214 .51417 .42533 .51733 .43077 .51562 .42759 .51245 Mtetra
.42759 .51245 .43077 .51562 .43623 .5139 .43305 .51072 Mtetra
.43305 .51072 .43623 .5139 .44169 .51219 .43852 .509 Mtetra
.664 .74 .907 r
.43852 .509 .44169 .51219 .44717 .51046 .444 .50727 Mtetra
.664 .741 .907 r
.444 .50727 .44717 .51046 .45265 .50873 .4495 .50554 Mtetra
.4495 .50554 .45265 .50873 .45815 .507 .455 .50379 Mtetra
.455 .50379 .45815 .507 .46366 .50526 .46052 .50205 Mtetra
.46052 .50205 .46366 .50526 .46918 .50353 .46605 .50031 Mtetra
.46605 .50031 .46918 .50353 .47471 .50179 .47158 .49856 Mtetra
.664 .74 .907 r
.47158 .49856 .47471 .50179 .48025 .50004 .47713 .49681 Mtetra
.664 .741 .907 r
.47713 .49681 .48025 .50004 .48581 .49829 .4827 .49506 Mtetra
.664 .741 .908 r
.4827 .49506 .48581 .49829 .49137 .49654 .48827 .4933 Mtetra
.664 .741 .907 r
.48827 .4933 .49137 .49654 .49695 .49478 .49385 .49153 Mtetra
.49385 .49153 .49695 .49478 .50254 .49303 .49945 .48976 Mtetra
.49945 .48976 .50254 .49303 .50814 .49126 .50505 .48799 Mtetra
.50505 .48799 .50814 .49126 .51375 .48949 .51067 .48623 Mtetra
.664 .741 .908 r
.51067 .48623 .51375 .48949 .51937 .48772 .5163 .48445 Mtetra
.664 .741 .907 r
.5163 .48445 .51937 .48772 .525 .48595 .52194 .48266 Mtetra
.52194 .48266 .525 .48595 .53065 .48417 .5276 .48088 Mtetra
.5276 .48088 .53065 .48417 .53631 .48239 .53326 .47909 Mtetra
.663 .741 .908 r
.53326 .47909 .53631 .48239 .54198 .4806 .53894 .47731 Mtetra
.664 .741 .908 r
.53894 .47731 .54198 .4806 .54766 .47882 .54463 .47551 Mtetra
.664 .741 .907 r
.54463 .47551 .54766 .47882 .55335 .47703 .55033 .47371 Mtetra
.664 .74 .907 r
.55033 .47371 .55335 .47703 .55905 .47524 .55604 .47191 Mtetra
.663 .74 .907 r
.55604 .47191 .55905 .47524 .56477 .47345 .56176 .47012 Mtetra
.663 .741 .908 r
.56176 .47012 .56477 .47345 .5705 .47165 .5675 .46833 Mtetra
.663 .741 .909 r
.5675 .46833 .5705 .47165 .57623 .46987 .57324 .46654 Mtetra
.662 .741 .909 r
.57324 .46654 .57623 .46987 .58199 .46809 .579 .46475 Mtetra
.66 .74 .909 r
.579 .46475 .58199 .46809 .58775 .46633 .58478 .46299 Mtetra
.656 .74 .911 r
.58478 .46299 .58775 .46633 .59353 .4646 .59056 .46128 Mtetra
.652 .74 .914 r
.59056 .46128 .59353 .4646 .59932 .46292 .59636 .45962 Mtetra
.645 .739 .918 r
.59636 .45962 .59932 .46292 .60512 .46133 .60218 .45807 Mtetra
.631 .738 .924 r
.60218 .45807 .60512 .46133 .61095 .45988 .60801 .45669 Mtetra
.607 .734 .935 r
.60801 .45669 .61095 .45988 .61679 .45867 .61386 .4556 Mtetra
.561 .725 .951 r
.61386 .4556 .61679 .45867 .62266 .45785 .61974 .45498 Mtetra
.468 .699 .968 r
.61974 .45498 .62266 .45785 .62856 .45766 .62567 .4551 Mtetra
.256 .611 .956 r
.62567 .4551 .62856 .45766 .63452 .45845 .63165 .45639 Mtetra
0 .331 .752 r
.63165 .45639 .63452 .45845 .64055 .46078 .63771 .45947 Mtetra
.651 .1 0 r
.63771 .45947 .64055 .46078 .64669 .46539 .6439 .46516 Mtetra
.822 .35 .076 r
.6439 .46516 .64669 .46539 .653 .47314 .65026 .4743 Mtetra
.864 .451 .241 r
.65026 .4743 .653 .47314 .6595 .48474 .65683 .48736 Mtetra
.869 .485 .314 r
.65683 .48736 .6595 .48474 .66622 .49993 .6636 .50349 Mtetra
.856 .478 .332 r
.6636 .50349 .66622 .49993 .67308 .5165 .67044 .51947 Mtetra
.809 .398 .268 r
.67044 .51947 .67308 .5165 .67987 .52965 .6771 .52979 Mtetra
.037 .607 .706 r
.6771 .52979 .67987 .52965 .68628 .5337 .68332 .52947 Mtetra
.89 .755 .706 r
.68332 .52947 .68628 .5337 .69214 .52601 .689 .51779 Mtetra
.872 .677 .636 r
.689 .51779 .69214 .52601 .69752 .50919 .69429 .49898 Mtetra
.856 .653 .627 r
.69429 .49898 .69752 .50919 .70267 .48891 .69946 .47875 Mtetra
.843 .646 .637 r
.69946 .47875 .70267 .48891 .70785 .46998 .70471 .46102 Mtetra
.829 .651 .661 r
.70471 .46102 .70785 .46998 .71317 .45467 .71013 .44722 Mtetra
.814 .665 .697 r
.71013 .44722 .71317 .45467 .7187 .44325 .71574 .43718 Mtetra
.793 .684 .744 r
.71574 .43718 .7187 .44325 .7244 .43512 .72152 .43019 Mtetra
.759 .707 .803 r
.72152 .43019 .7244 .43512 .73025 .42956 .72745 .42561 Mtetra
.689 .727 .879 r
.72745 .42561 .73025 .42956 .73624 .42604 .73351 .42323 Mtetra
.449 .698 .973 r
.73351 .42323 .73624 .42604 .74236 .42457 .73977 .42345 Mtetra
.466 0 0 r
.73977 .42345 .74236 .42457 .74869 .42578 .7463 .42756 Mtetra
.826 .386 .19 r
.7463 .42756 .74869 .42578 .75536 .43136 .75334 .43827 Mtetra
.854 .498 .378 r
.75334 .43827 .75536 .43136 .76261 .44442 .76123 .45993 Mtetra
.846 .526 .446 r
.76123 .45993 .76261 .44442 .77084 .46969 .77037 .4971 Mtetra
.824 .522 .479 r
.77037 .4971 .77084 .46969 .78043 .51101 .78071 .54789 Mtetra
.774 .485 .498 r
.78071 .54789 .78043 .51101 .79103 .563 .7908 .59262 Mtetra
.612 .345 .488 r
.7908 .59262 .79103 .563 .80074 .60098 .79805 .59923 Mtetra
.986 .756 .503 r
.79805 .59923 .80074 .60098 .80699 .59514 .80163 .56043 Mtetra
.832 .58 .559 r
.80163 .56043 .80699 .59514 .80982 .54874 .80363 .50439 Mtetra
.778 .536 .57 r
.80363 .50439 .80982 .54874 .81171 .4933 .80622 .45752 Mtetra
.753 .524 .584 r
.80622 .45752 .81171 .4933 .81451 .45043 .81005 .42667 Mtetra
.742 .531 .609 r
.81005 .42667 .81451 .45043 .81858 .42322 .81491 .40835 Mtetra
.736 .557 .65 r
.81491 .40835 .81858 .42322 .8236 .40726 .82042 .3977 Mtetra
.731 .597 .707 r
.82042 .3977 .8236 .40726 .82921 .39795 .8263 .39126 Mtetra
.721 .644 .771 r
.8263 .39126 .82921 .39795 .83515 .39221 .83239 .38701 Mtetra
.706 .683 .826 r
.83239 .38701 .83515 .39221 .84127 .38832 .83859 .38389 Mtetra
.69 .71 .863 r
.83859 .38389 .84127 .38832 .84749 .38538 .84486 .38132 Mtetra
.679 .725 .885 r
.84486 .38132 .84749 .38538 .85377 .38292 .85117 .37904 Mtetra
.672 .733 .896 r
.85117 .37904 .85377 .38292 .86009 .38069 .85751 .37689 Mtetra
.668 .736 .901 r
.85751 .37689 .86009 .38069 .86643 .37857 .86386 .37481 Mtetra
.666 .738 .904 r
.86386 .37481 .86643 .37857 .8728 .3765 .87024 .37276 Mtetra
.665 .74 .906 r
.87024 .37276 .8728 .3765 .87917 .37445 .87663 .37073 Mtetra
.665 .741 .907 r
.87663 .37073 .87917 .37445 .88557 .37242 .88304 .3687 Mtetra
.88304 .3687 .88557 .37242 .89198 .37041 .88946 .36666 Mtetra
.664 .74 .907 r
.88946 .36666 .89198 .37041 .8984 .36839 .89589 .36463 Mtetra
.89589 .36463 .8984 .36839 .90484 .36635 .90234 .36259 Mtetra
.663 .74 .907 r
.90234 .36259 .90484 .36635 .91129 .36432 .9088 .36056 Mtetra
.664 .741 .908 r
.9088 .36056 .91129 .36432 .91776 .36228 .91528 .35852 Mtetra
.91528 .35852 .91776 .36228 .92424 .36024 .92177 .35646 Mtetra
.664 .741 .907 r
.33839 .53647 .3417 .53956 .34698 .53789 .34369 .5348 Mtetra
.34369 .5348 .34698 .53789 .35228 .53622 .34899 .53312 Mtetra
.34899 .53312 .35228 .53622 .35759 .53455 .35431 .53144 Mtetra
.664 .74 .907 r
.35431 .53144 .35759 .53455 .36291 .53287 .35964 .52975 Mtetra
.35964 .52975 .36291 .53287 .36824 .53118 .36497 .52807 Mtetra
.663 .741 .908 r
.36497 .52807 .36824 .53118 .37358 .52949 .37032 .52638 Mtetra
.664 .741 .908 r
.37032 .52638 .37358 .52949 .37894 .5278 .37568 .52468 Mtetra
.664 .741 .907 r
.37568 .52468 .37894 .5278 .3843 .52612 .38105 .52298 Mtetra
.664 .74 .907 r
.38105 .52298 .3843 .52612 .38967 .52443 .38643 .52127 Mtetra
.38643 .52127 .38967 .52443 .39506 .52272 .39182 .51957 Mtetra
.663 .741 .908 r
.39182 .51957 .39506 .52272 .40045 .52101 .39722 .51787 Mtetra
.664 .742 .908 r
.39722 .51787 .40045 .52101 .40586 .51931 .40263 .51615 Mtetra
.664 .741 .907 r
.40263 .51615 .40586 .51931 .41127 .5176 .40806 .51443 Mtetra
.40806 .51443 .41127 .5176 .4167 .51589 .41349 .51271 Mtetra
.664 .74 .907 r
.41349 .51271 .4167 .51589 .42214 .51417 .41894 .51099 Mtetra
.663 .74 .907 r
.41894 .51099 .42214 .51417 .42759 .51245 .42439 .50928 Mtetra
.664 .742 .908 r
.42439 .50928 .42759 .51245 .43305 .51072 .42986 .50754 Mtetra
.665 .742 .908 r
.42986 .50754 .43305 .51072 .43852 .509 .43534 .5058 Mtetra
.664 .741 .907 r
.43534 .5058 .43852 .509 .444 .50727 .44083 .50406 Mtetra
.44083 .50406 .444 .50727 .4495 .50554 .44633 .50232 Mtetra
.663 .74 .907 r
.44633 .50232 .4495 .50554 .455 .50379 .45184 .50058 Mtetra
.664 .741 .908 r
.45184 .50058 .455 .50379 .46052 .50205 .45737 .49884 Mtetra
.665 .742 .908 r
.45737 .49884 .46052 .50205 .46605 .50031 .4629 .49708 Mtetra
.664 .741 .907 r
.4629 .49708 .46605 .50031 .47158 .49856 .46845 .49532 Mtetra
.46845 .49532 .47158 .49856 .47713 .49681 .474 .49356 Mtetra
.474 .49356 .47713 .49681 .4827 .49506 .47957 .4918 Mtetra
.47957 .4918 .4827 .49506 .48827 .4933 .48515 .49004 Mtetra
.48515 .49004 .48827 .4933 .49385 .49153 .49074 .48827 Mtetra
.49074 .48827 .49385 .49153 .49945 .48976 .49635 .48649 Mtetra
.49635 .48649 .49945 .48976 .50505 .48799 .50196 .48472 Mtetra
.50196 .48472 .50505 .48799 .51067 .48623 .50759 .48294 Mtetra
.664 .74 .907 r
.50759 .48294 .51067 .48623 .5163 .48445 .51322 .48115 Mtetra
.51322 .48115 .5163 .48445 .52194 .48266 .51887 .47937 Mtetra
.664 .741 .907 r
.51887 .47937 .52194 .48266 .5276 .48088 .52453 .47758 Mtetra
.52453 .47758 .5276 .48088 .53326 .47909 .5302 .47578 Mtetra
.5302 .47578 .53326 .47909 .53894 .47731 .53589 .47398 Mtetra
.664 .74 .907 r
.53589 .47398 .53894 .47731 .54463 .47551 .54158 .47218 Mtetra
.663 .74 .907 r
.54158 .47218 .54463 .47551 .55033 .47371 .54729 .47039 Mtetra
.663 .741 .908 r
.54729 .47039 .55033 .47371 .55604 .47191 .55301 .46859 Mtetra
.663 .742 .908 r
.55301 .46859 .55604 .47191 .56176 .47012 .55874 .46678 Mtetra
.663 .741 .908 r
.55874 .46678 .56176 .47012 .5675 .46833 .56449 .46497 Mtetra
.662 .74 .908 r
.56449 .46497 .5675 .46833 .57324 .46654 .57024 .46318 Mtetra
.66 .74 .909 r
.57024 .46318 .57324 .46654 .579 .46475 .57601 .46141 Mtetra
.658 .741 .911 r
.57601 .46141 .579 .46475 .58478 .46299 .58179 .45966 Mtetra
.656 .741 .913 r
.58179 .45966 .58478 .46299 .59056 .46128 .58758 .45795 Mtetra
.65 .74 .915 r
.58758 .45795 .59056 .46128 .59636 .45962 .59339 .45632 Mtetra
.64 .738 .92 r
.59339 .45632 .59636 .45962 .60218 .45807 .59922 .45482 Mtetra
.623 .736 .928 r
.59922 .45482 .60218 .45807 .60801 .45669 .60506 .45354 Mtetra
.593 .732 .941 r
.60506 .45354 .60801 .45669 .61386 .4556 .61092 .45259 Mtetra
.535 .719 .958 r
.61092 .45259 .61386 .4556 .61974 .45498 .61682 .4522 Mtetra
.409 .678 .971 r
.61682 .4522 .61974 .45498 .62567 .4551 .62276 .45269 Mtetra
.119 .537 .916 r
.62276 .45269 .62567 .4551 .63165 .45639 .62877 .45457 Mtetra
.394 0 0 r
.62877 .45457 .63165 .45639 .63771 .45947 .63487 .45853 Mtetra
.743 .22 0 r
.63487 .45853 .63771 .45947 .6439 .46516 .64111 .46542 Mtetra
.846 .399 .154 r
.64111 .46542 .6439 .46516 .65026 .4743 .64753 .47602 Mtetra
.868 .469 .276 r
.64753 .47602 .65026 .4743 .65683 .48736 .65416 .49045 Mtetra
.866 .487 .327 r
.65416 .49045 .65683 .48736 .6636 .50349 .66096 .50706 Mtetra
.845 .462 .323 r
.66096 .50706 .6636 .50349 .67044 .51947 .66774 .52163 Mtetra
.751 .295 .167 r
.66774 .52163 .67044 .51947 .6771 .52979 .67426 .52839 Mtetra
.825 .916 .898 r
.67426 .52839 .6771 .52979 .68332 .52947 .68028 .52357 Mtetra
.884 .714 .666 r
.68028 .52357 .68332 .52947 .689 .51779 .68581 .50854 Mtetra
.866 .665 .629 r
.68581 .50854 .689 .51779 .69429 .49898 .69105 .48856 Mtetra
.851 .649 .629 r
.69105 .48856 .69429 .49898 .69946 .47875 .69626 .46895 Mtetra
.838 .647 .645 r
.69626 .46895 .69946 .47875 .70471 .46102 .7016 .45265 Mtetra
.824 .656 .674 r
.7016 .45265 .70471 .46102 .71013 .44722 .70712 .44036 Mtetra
.807 .672 .715 r
.70712 .44036 .71013 .44722 .71574 .43718 .71281 .43162 Mtetra
.78 .693 .768 r
.71281 .43162 .71574 .43718 .72152 .43019 .71867 .42575 Mtetra
.728 .717 .839 r
.71867 .42575 .72152 .43019 .72745 .42561 .72467 .42234 Mtetra
.578 .725 .943 r
.72467 .42234 .72745 .42561 .73351 .42323 .73085 .42152 Mtetra
0 .38 .77 r
.73085 .42152 .73351 .42323 .73977 .42345 .73728 .42427 Mtetra
.796 .317 .085 r
.73728 .42427 .73977 .42345 .7463 .42756 .74413 .43285 Mtetra
.852 .482 .347 r
.74413 .43285 .7463 .42756 .75334 .43827 .75172 .45122 Mtetra
.849 .523 .434 r
.75172 .45122 .75334 .43827 .76123 .45993 .76044 .48419 Mtetra
.831 .526 .473 r
.76044 .48419 .76123 .45993 .77037 .4971 .77043 .53249 Mtetra
.79 .499 .494 r
.77043 .53249 .77037 .4971 .78071 .54789 .7807 .58169 Mtetra
.682 .406 .498 r
.7807 .58169 .78071 .54789 .7908 .59262 .78881 .60022 Mtetra
.89 .78 .287 r
.78881 .60022 .7908 .59262 .79805 .59923 .79326 .57107 Mtetra
.855 .602 .555 r
.79326 .57107 .79805 .59923 .80163 .56043 .79552 .51617 Mtetra
.788 .543 .567 r
.79552 .51617 .80163 .56043 .80363 .50439 .79796 .46566 Mtetra
.758 .525 .58 r
.79796 .46566 .80363 .50439 .80622 .45752 .80155 .43091 Mtetra
.744 .528 .601 r
.80155 .43091 .80622 .45752 .81005 .42667 .80623 .40992 Mtetra
.738 .549 .638 r
.80623 .40992 .81005 .42667 .81491 .40835 .81163 .39773 Mtetra
.733 .586 .691 r
.81163 .39773 .81491 .40835 .82042 .3977 .81744 .39045 Mtetra
.725 .633 .755 r
.81744 .39045 .82042 .3977 .8263 .39126 .8235 .38576 Mtetra
.71 .675 .814 r
.8235 .38576 .8263 .39126 .83239 .38701 .82968 .38241 Mtetra
.694 .704 .855 r
.82968 .38241 .83239 .38701 .83859 .38389 .83593 .37974 Mtetra
.681 .722 .88 r
.83593 .37974 .83859 .38389 .84486 .38132 .84224 .37741 Mtetra
.674 .732 .894 r
.84224 .37741 .84486 .38132 .85117 .37904 .84857 .37523 Mtetra
.669 .736 .9 r
.84857 .37523 .85117 .37904 .85751 .37689 .85492 .37312 Mtetra
.667 .738 .904 r
.85492 .37312 .85751 .37689 .86386 .37481 .86129 .37106 Mtetra
.665 .739 .906 r
.86129 .37106 .86386 .37481 .87024 .37276 .86767 .36902 Mtetra
.664 .74 .906 r
.86767 .36902 .87024 .37276 .87663 .37073 .87408 .36699 Mtetra
.664 .74 .907 r
.87408 .36699 .87663 .37073 .88304 .3687 .88049 .36495 Mtetra
.664 .741 .907 r
.88049 .36495 .88304 .3687 .88946 .36666 .88692 .36291 Mtetra
.88692 .36291 .88946 .36666 .89589 .36463 .89337 .36087 Mtetra
.89337 .36087 .89589 .36463 .90234 .36259 .89983 .35883 Mtetra
.89983 .35883 .90234 .36259 .9088 .36056 .9063 .35678 Mtetra
.664 .74 .907 r
.9063 .35678 .9088 .36056 .91528 .35852 .91279 .35472 Mtetra
.91279 .35472 .91528 .35852 .92177 .35646 .91929 .35267 Mtetra
.664 .741 .907 r
.33508 .53338 .33839 .53647 .34369 .5348 .34038 .5317 Mtetra
.34038 .5317 .34369 .5348 .34899 .53312 .34569 .53001 Mtetra
.34569 .53001 .34899 .53312 .35431 .53144 .35102 .52832 Mtetra
.35102 .52832 .35431 .53144 .35964 .52975 .35635 .52663 Mtetra
.35635 .52663 .35964 .52975 .36497 .52807 .36169 .52494 Mtetra
.36169 .52494 .36497 .52807 .37032 .52638 .36705 .52324 Mtetra
.664 .74 .907 r
.36705 .52324 .37032 .52638 .37568 .52468 .37241 .52154 Mtetra
.664 .741 .907 r
.37241 .52154 .37568 .52468 .38105 .52298 .37779 .51983 Mtetra
.37779 .51983 .38105 .52298 .38643 .52127 .38317 .51812 Mtetra
.38317 .51812 .38643 .52127 .39182 .51957 .38857 .51641 Mtetra
.38857 .51641 .39182 .51957 .39722 .51787 .39398 .5147 Mtetra
.664 .74 .907 r
.39398 .5147 .39722 .51787 .40263 .51615 .3994 .51298 Mtetra
.663 .74 .907 r
.3994 .51298 .40263 .51615 .40806 .51443 .40483 .51126 Mtetra
.664 .741 .908 r
.40483 .51126 .40806 .51443 .41349 .51271 .41027 .50954 Mtetra
.664 .741 .907 r
.41027 .50954 .41349 .51271 .41894 .51099 .41572 .5078 Mtetra
.41572 .5078 .41894 .51099 .42439 .50928 .42119 .50607 Mtetra
.664 .74 .907 r
.42119 .50607 .42439 .50928 .42986 .50754 .42666 .50433 Mtetra
.663 .74 .907 r
.42666 .50433 .42986 .50754 .43534 .5058 .43215 .5026 Mtetra
.663 .741 .908 r
.43215 .5026 .43534 .5058 .44083 .50406 .43764 .50086 Mtetra
.665 .742 .908 r
.43764 .50086 .44083 .50406 .44633 .50232 .44315 .4991 Mtetra
.664 .741 .907 r
.44315 .4991 .44633 .50232 .45184 .50058 .44867 .49735 Mtetra
.664 .74 .907 r
.44867 .49735 .45184 .50058 .45737 .49884 .4542 .49559 Mtetra
.4542 .49559 .45737 .49884 .4629 .49708 .45974 .49384 Mtetra
.663 .741 .908 r
.45974 .49384 .4629 .49708 .46845 .49532 .4653 .49209 Mtetra
.665 .742 .908 r
.4653 .49209 .46845 .49532 .474 .49356 .47086 .49031 Mtetra
.664 .741 .907 r
.47086 .49031 .474 .49356 .47957 .4918 .47644 .48854 Mtetra
.47644 .48854 .47957 .4918 .48515 .49004 .48202 .48677 Mtetra
.664 .74 .907 r
.48202 .48677 .48515 .49004 .49074 .48827 .48762 .48499 Mtetra
.663 .741 .908 r
.48762 .48499 .49074 .48827 .49635 .48649 .49323 .48322 Mtetra
.664 .742 .908 r
.49323 .48322 .49635 .48649 .50196 .48472 .49885 .48144 Mtetra
.664 .741 .907 r
.49885 .48144 .50196 .48472 .50759 .48294 .50449 .47964 Mtetra
.50449 .47964 .50759 .48294 .51322 .48115 .51013 .47785 Mtetra
.51013 .47785 .51322 .48115 .51887 .47937 .51579 .47606 Mtetra
.663 .741 .907 r
.51579 .47606 .51887 .47937 .52453 .47758 .52146 .47427 Mtetra
.664 .741 .907 r
.52146 .47427 .52453 .47758 .5302 .47578 .52714 .47246 Mtetra
.52714 .47246 .5302 .47578 .53589 .47398 .53283 .47066 Mtetra
.664 .741 .908 r
.53283 .47066 .53589 .47398 .54158 .47218 .53853 .46885 Mtetra
.53853 .46885 .54158 .47218 .54729 .47039 .54425 .46704 Mtetra
.663 .741 .907 r
.54425 .46704 .54729 .47039 .55301 .46859 .54997 .46523 Mtetra
.663 .74 .908 r
.54997 .46523 .55301 .46859 .55874 .46678 .55571 .46343 Mtetra
.662 .741 .908 r
.55571 .46343 .55874 .46678 .56449 .46497 .56146 .46163 Mtetra
.662 .741 .909 r
.56146 .46163 .56449 .46497 .57024 .46318 .56723 .45983 Mtetra
.66 .741 .91 r
.56723 .45983 .57024 .46318 .57601 .46141 .573 .45805 Mtetra
.658 .74 .911 r
.573 .45805 .57601 .46141 .58179 .45966 .57879 .45631 Mtetra
.654 .739 .913 r
.57879 .45631 .58179 .45966 .58758 .45795 .5846 .45462 Mtetra
.646 .739 .917 r
.5846 .45462 .58758 .45795 .59339 .45632 .59041 .45303 Mtetra
.635 .739 .923 r
.59041 .45303 .59339 .45632 .59922 .45482 .59625 .4516 Mtetra
.615 .736 .932 r
.59625 .4516 .59922 .45482 .60506 .45354 .6021 .45041 Mtetra
.576 .728 .946 r
.6021 .45041 .60506 .45354 .61092 .45259 .60798 .44963 Mtetra
.499 .707 .964 r
.60798 .44963 .61092 .45259 .61682 .4522 .61389 .44952 Mtetra
.325 .643 .967 r
.61389 .44952 .61682 .4522 .62276 .45269 .61985 .45048 Mtetra
0 .425 .833 r
.61985 .45048 .62276 .45269 .62877 .45457 .62589 .45304 Mtetra
.564 .002 0 r
.62589 .45304 .62877 .45457 .63487 .45853 .63203 .45798 Mtetra
.798 .307 .011 r
.63203 .45798 .63487 .45853 .64111 .46542 .63832 .46619 Mtetra
.859 .434 .211 r
.63832 .46619 .64111 .46542 .64753 .47602 .6448 .4783 Mtetra
.869 .481 .302 r
.6448 .4783 .64753 .47602 .65416 .49045 .65148 .49388 Mtetra
.861 .484 .333 r
.65148 .49388 .65416 .49045 .66096 .50706 .65828 .51036 Mtetra
.828 .432 .299 r
.65828 .51036 .66096 .50706 .66774 .52163 .66498 .52266 Mtetra
.538 0 0 r
.66498 .52266 .66774 .52163 .67426 .52839 .67132 .52528 Mtetra
.889 .8 .756 r
.67132 .52528 .67426 .52839 .68028 .52357 .67716 .5162 Mtetra
.877 .689 .645 r
.67716 .5162 .68028 .52357 .68581 .50854 .68258 .49858 Mtetra
.86 .657 .627 r
.68258 .49858 .68581 .50854 .69105 .48856 .68782 .4782 Mtetra
.846 .647 .633 r
.68782 .4782 .69105 .48856 .69626 .46895 .69309 .45964 Mtetra
.833 .65 .655 r
.69309 .45964 .69626 .46895 .7016 .45265 .69852 .44487 Mtetra
.818 .662 .689 r
.69852 .44487 .7016 .45265 .70712 .44036 .70413 .43405 Mtetra
.797 .681 .736 r
.70413 .43405 .70712 .44036 .71281 .43162 .70991 .4266 Mtetra
.759 .705 .8 r
.70991 .4266 .71281 .43162 .71867 .42575 .71585 .42197 Mtetra
.664 .728 .897 r
.71585 .42197 .71867 .42575 .72467 .42234 .72195 .42003 Mtetra
.201 .599 .946 r
.72195 .42003 .72467 .42234 .73085 .42152 .72828 .42147 Mtetra
.731 .205 0 r
.72828 .42147 .73085 .42152 .73728 .42427 .73498 .42814 Mtetra
.848 .459 .308 r
.73498 .42814 .73728 .42427 .74413 .43285 .7423 .4435 Mtetra
.852 .517 .419 r
.7423 .4435 .74413 .43285 .75172 .45122 .75062 .47236 Mtetra
.837 .527 .466 r
.75062 .47236 .75172 .45122 .76044 .48419 .76021 .51729 Mtetra
.804 .509 .49 r
.76021 .51729 .76044 .48419 .77043 .53249 .77048 .56874 Mtetra
.724 .443 .5 r
.77048 .56874 .77043 .53249 .7807 .58169 .7793 .59789 Mtetra
.029 0 .284 r
.7793 .59789 .7807 .58169 .78881 .60022 .78468 .58002 Mtetra
.885 .632 .551 r
.78468 .58002 .78881 .60022 .79326 .57107 .78736 .52835 Mtetra
.799 .552 .564 r
.78736 .52835 .79326 .57107 .79552 .51617 .78971 .47488 Mtetra
.763 .527 .576 r
.78971 .47488 .79552 .51617 .79796 .46566 .79308 .43606 Mtetra
.747 .525 .595 r
.79308 .43606 .79796 .46566 .80155 .43091 .79756 .41206 Mtetra
.739 .542 .627 r
.79756 .41206 .80155 .43091 .80623 .40992 .80283 .39805 Mtetra
.735 .576 .676 r
.80283 .39805 .80623 .40992 .81163 .39773 .80858 .38979 Mtetra
.727 .62 .739 r
.80858 .38979 .81163 .39773 .81744 .39045 .81459 .3846 Mtetra
.713 .665 .8 r
.81459 .3846 .81744 .39045 .8235 .38576 .82075 .381 Mtetra
.698 .699 .847 r
.82075 .381 .8235 .38576 .82968 .38241 .82699 .37819 Mtetra
.685 .72 .876 r
.82699 .37819 .82968 .38241 .83593 .37974 .83328 .37577 Mtetra
.676 .73 .891 r
.83328 .37577 .83593 .37974 .84224 .37741 .83961 .37355 Mtetra
.67 .734 .898 r
.83961 .37355 .84224 .37741 .84857 .37523 .84595 .37143 Mtetra
.666 .737 .903 r
.84595 .37143 .84857 .37523 .85492 .37312 .85232 .36937 Mtetra
.665 .74 .906 r
.85232 .36937 .85492 .37312 .86129 .37106 .8587 .36732 Mtetra
.665 .741 .907 r
.8587 .36732 .86129 .37106 .86767 .36902 .8651 .36527 Mtetra
.8651 .36527 .86767 .36902 .87408 .36699 .87151 .36322 Mtetra
.664 .74 .907 r
.87151 .36322 .87408 .36699 .88049 .36495 .87794 .36118 Mtetra
.87794 .36118 .88049 .36495 .88692 .36291 .88438 .35915 Mtetra
.664 .741 .908 r
.88438 .35915 .88692 .36291 .89337 .36087 .89084 .3571 Mtetra
.89084 .3571 .89337 .36087 .89983 .35883 .8973 .35504 Mtetra
.664 .741 .907 r
.8973 .35504 .89983 .35883 .9063 .35678 .90379 .35298 Mtetra
.90379 .35298 .9063 .35678 .91279 .35472 .91029 .35092 Mtetra
.91029 .35092 .91279 .35472 .91929 .35267 .9168 .34886 Mtetra
.33175 .53027 .33508 .53338 .34038 .5317 .33706 .52858 Mtetra
.33706 .52858 .34038 .5317 .34569 .53001 .34238 .52689 Mtetra
.34238 .52689 .34569 .53001 .35102 .52832 .34771 .5252 Mtetra
.34771 .5252 .35102 .52832 .35635 .52663 .35305 .5235 Mtetra
.35305 .5235 .35635 .52663 .36169 .52494 .3584 .5218 Mtetra
.3584 .5218 .36169 .52494 .36705 .52324 .36376 .52009 Mtetra
.36376 .52009 .36705 .52324 .37241 .52154 .36913 .51839 Mtetra
.36913 .51839 .37241 .52154 .37779 .51983 .37451 .51668 Mtetra
.37451 .51668 .37779 .51983 .38317 .51812 .37991 .51496 Mtetra
.37991 .51496 .38317 .51812 .38857 .51641 .38531 .51324 Mtetra
.38531 .51324 .38857 .51641 .39398 .5147 .39073 .51152 Mtetra
.39073 .51152 .39398 .5147 .3994 .51298 .39615 .50979 Mtetra
.39615 .50979 .3994 .51298 .40483 .51126 .40159 .50806 Mtetra
.664 .74 .907 r
.40159 .50806 .40483 .51126 .41027 .50954 .40704 .50633 Mtetra
.40704 .50633 .41027 .50954 .41572 .5078 .4125 .5046 Mtetra
.664 .741 .907 r
.4125 .5046 .41572 .5078 .42119 .50607 .41797 .50286 Mtetra
.41797 .50286 .42119 .50607 .42666 .50433 .42345 .50111 Mtetra
.42345 .50111 .42666 .50433 .43215 .5026 .42894 .49937 Mtetra
.664 .74 .907 r
.42894 .49937 .43215 .5026 .43764 .50086 .43445 .49762 Mtetra
.43445 .49762 .43764 .50086 .44315 .4991 .43996 .49586 Mtetra
.664 .741 .907 r
.43996 .49586 .44315 .4991 .44867 .49735 .44549 .49411 Mtetra
.44549 .49411 .44867 .49735 .4542 .49559 .45102 .49235 Mtetra
.45102 .49235 .4542 .49559 .45974 .49384 .45657 .49058 Mtetra
.664 .74 .907 r
.45657 .49058 .45974 .49384 .4653 .49209 .46213 .48881 Mtetra
.46213 .48881 .4653 .49209 .47086 .49031 .46771 .48704 Mtetra
.663 .74 .907 r
.46771 .48704 .47086 .49031 .47644 .48854 .47329 .48528 Mtetra
.664 .741 .908 r
.47329 .48528 .47644 .48854 .48202 .48677 .47888 .4835 Mtetra
.664 .742 .907 r
.47888 .4835 .48202 .48677 .48762 .48499 .48449 .4817 Mtetra
.664 .741 .907 r
.48449 .4817 .48762 .48499 .49323 .48322 .49011 .47992 Mtetra
.664 .74 .907 r
.49011 .47992 .49323 .48322 .49885 .48144 .49574 .47813 Mtetra
.663 .74 .907 r
.49574 .47813 .49885 .48144 .50449 .47964 .50138 .47634 Mtetra
.664 .741 .908 r
.50138 .47634 .50449 .47964 .51013 .47785 .50703 .47455 Mtetra
.665 .742 .908 r
.50703 .47455 .51013 .47785 .51579 .47606 .51269 .47274 Mtetra
.664 .741 .907 r
.51269 .47274 .51579 .47606 .52146 .47427 .51837 .47093 Mtetra
.664 .74 .907 r
.51837 .47093 .52146 .47427 .52714 .47246 .52406 .46912 Mtetra
.663 .74 .907 r
.52406 .46912 .52714 .47246 .53283 .47066 .52976 .46732 Mtetra
.663 .741 .908 r
.52976 .46732 .53283 .47066 .53853 .46885 .53547 .46551 Mtetra
.664 .742 .908 r
.53547 .46551 .53853 .46885 .54425 .46704 .54119 .46369 Mtetra
.664 .741 .908 r
.54119 .46369 .54425 .46704 .54997 .46523 .54693 .46187 Mtetra
.663 .74 .908 r
.54693 .46187 .54997 .46523 .55571 .46343 .55267 .46005 Mtetra
.662 .74 .908 r
.55267 .46005 .55571 .46343 .56146 .46163 .55843 .45826 Mtetra
.661 .74 .909 r
.55843 .45826 .56146 .46163 .56723 .45983 .5642 .45647 Mtetra
.66 .741 .91 r
.5642 .45647 .56723 .45983 .573 .45805 .56999 .4547 Mtetra
.657 .741 .912 r
.56999 .4547 .573 .45805 .57879 .45631 .57578 .45296 Mtetra
.652 .74 .914 r
.57578 .45296 .57879 .45631 .5846 .45462 .58159 .45129 Mtetra
.643 .739 .919 r
.58159 .45129 .5846 .45462 .59041 .45303 .58742 .44975 Mtetra
.629 .737 .925 r
.58742 .44975 .59041 .45303 .59625 .4516 .59326 .44839 Mtetra
.603 .733 .936 r
.59326 .44839 .59625 .4516 .6021 .45041 .59913 .44733 Mtetra
.553 .723 .953 r
.59913 .44733 .6021 .45041 .60798 .44963 .60502 .44676 Mtetra
.449 .693 .97 r
.60502 .44676 .60798 .44963 .61389 .44952 .61095 .44699 Mtetra
.213 .589 .946 r
.61095 .44699 .61389 .44952 .61985 .45048 .61693 .44846 Mtetra
0 .277 .7 r
.61693 .44846 .61985 .45048 .62589 .45304 .623 .45182 Mtetra
.686 .144 0 r
.623 .45182 .62589 .45304 .63203 .45798 .62918 .45789 Mtetra
.832 .369 .106 r
.62918 .45789 .63203 .45798 .63832 .46619 .63553 .46752 Mtetra
.866 .458 .255 r
.63553 .46752 .63832 .46619 .6448 .4783 .64207 .48108 Mtetra
.868 .487 .319 r
.64207 .48108 .6448 .4783 .65148 .49388 .64878 .49745 Mtetra
.853 .474 .33 r
.64878 .49745 .65148 .49388 .65828 .51036 .65555 .51307 Mtetra
.796 .372 .243 r
.65555 .51307 .65828 .51036 .66498 .52266 .66213 .52231 Mtetra
.462 .879 .933 r
.66213 .52231 .66498 .52266 .67132 .52528 .6683 .52048 Mtetra
.889 .739 .69 r
.6683 .52048 .67132 .52528 .67716 .5162 .67398 .50756 Mtetra
.87 .673 .633 r
.67398 .50756 .67716 .5162 .68258 .49858 .67933 .48823 Mtetra
.854 .651 .627 r
.67933 .48823 .68258 .49858 .68782 .4782 .68459 .46814 Mtetra
.841 .647 .64 r
.68459 .46814 .68782 .4782 .69309 .45964 .68995 .4509 Mtetra
.828 .654 .666 r
.68995 .4509 .69309 .45964 .69852 .44487 .69547 .4377 Mtetra
.81 .668 .706 r
.69547 .4377 .69852 .44487 .70413 .43405 .70116 .42834 Mtetra
.783 .691 .763 r
.70116 .42834 .70413 .43405 .70991 .4266 .70703 .42224 Mtetra
.72 .719 .848 r
.70703 .42224 .70991 .4266 .71585 .42197 .71306 .41906 Mtetra
.461 .7 .971 r
.71306 .41906 .71585 .42197 .72195 .42003 .7193 .4192 Mtetra
.584 .012 0 r
.7193 .4192 .72195 .42003 .72828 .42147 .72586 .42409 Mtetra
.839 .425 .252 r
.72586 .42409 .72828 .42147 .73498 .42814 .73295 .43671 Mtetra
.853 .509 .401 r
.73295 .43671 .73498 .42814 .7423 .4435 .74092 .46164 Mtetra
.842 .528 .457 r
.74092 .46164 .7423 .4435 .75062 .47236 .7501 .50267 Mtetra
.814 .516 .485 r
.7501 .50267 .75062 .47236 .76021 .51729 .7602 .55441 Mtetra
.752 .467 .5 r
.7602 .55441 .76021 .51729 .77048 .56874 .76954 .59229 Mtetra
.467 .216 .448 r
.76954 .59229 .77048 .56874 .7793 .59789 .77585 .58665 Mtetra
.927 .679 .542 r
.77585 .58665 .7793 .59789 .78468 .58002 .77909 .54053 Mtetra
.814 .564 .562 r
.77909 .54053 .78468 .58002 .78736 .52835 .78146 .48516 Mtetra
.77 .531 .572 r
.78146 .48516 .78736 .52835 .78971 .47488 .78462 .44218 Mtetra
.75 .524 .589 r
.78462 .44218 .78971 .47488 .79308 .43606 .78891 .41483 Mtetra
.741 .536 .617 r
.78891 .41483 .79308 .43606 .79756 .41206 .79404 .39875 Mtetra
.736 .566 .662 r
.79404 .39875 .79756 .41206 .80283 .39805 .79971 .38934 Mtetra
.73 .609 .723 r
.79971 .38934 .80283 .39805 .80858 .38979 .80568 .38354 Mtetra
.718 .655 .786 r
.80568 .38354 .80858 .38979 .81459 .3846 .81181 .37962 Mtetra
.702 .692 .837 r
.81181 .37962 .81459 .3846 .82075 .381 .81804 .37664 Mtetra
.687 .714 .869 r
.81804 .37664 .82075 .381 .82699 .37819 .82432 .37414 Mtetra
.677 .727 .887 r
.82432 .37414 .82699 .37819 .83328 .37577 .83063 .37189 Mtetra
.671 .734 .897 r
.83063 .37189 .83328 .37577 .83961 .37355 .83698 .36975 Mtetra
.668 .738 .903 r
.83698 .36975 .83961 .37355 .84595 .37143 .84334 .36766 Mtetra
.666 .74 .905 r
.84334 .36766 .84595 .37143 .85232 .36937 .84971 .3656 Mtetra
.665 .74 .906 r
.84971 .3656 .85232 .36937 .8587 .36732 .85611 .36355 Mtetra
.664 .74 .906 r
.85611 .36355 .8587 .36732 .8651 .36527 .86252 .3615 Mtetra
.664 .74 .907 r
.86252 .3615 .8651 .36527 .87151 .36322 .86894 .35946 Mtetra
.664 .741 .908 r
.86894 .35946 .87151 .36322 .87794 .36118 .87538 .35741 Mtetra
.664 .741 .907 r
.87538 .35741 .87794 .36118 .88438 .35915 .88183 .35536 Mtetra
.664 .74 .907 r
.88183 .35536 .88438 .35915 .89084 .3571 .88829 .3533 Mtetra
.88829 .3533 .89084 .3571 .8973 .35504 .89477 .35124 Mtetra
.664 .741 .907 r
.89477 .35124 .8973 .35504 .90379 .35298 .90127 .34918 Mtetra
.664 .741 .908 r
.90127 .34918 .90379 .35298 .91029 .35092 .90778 .34711 Mtetra
.664 .741 .907 r
.90778 .34711 .91029 .35092 .9168 .34886 .9143 .34503 Mtetra
.32841 .52716 .33175 .53027 .33706 .52858 .33373 .52546 Mtetra
.33373 .52546 .33706 .52858 .34238 .52689 .33905 .52376 Mtetra
.33905 .52376 .34238 .52689 .34771 .5252 .34439 .52206 Mtetra
.34439 .52206 .34771 .5252 .35305 .5235 .34973 .52036 Mtetra
.34973 .52036 .35305 .5235 .3584 .5218 .35509 .51865 Mtetra
.35509 .51865 .3584 .5218 .36376 .52009 .36046 .51694 Mtetra
.36046 .51694 .36376 .52009 .36913 .51839 .36584 .51522 Mtetra
.36584 .51522 .36913 .51839 .37451 .51668 .37123 .51351 Mtetra
.37123 .51351 .37451 .51668 .37991 .51496 .37663 .51178 Mtetra
.37663 .51178 .37991 .51496 .38531 .51324 .38204 .51006 Mtetra
.38204 .51006 .38531 .51324 .39073 .51152 .38746 .50833 Mtetra
.38746 .50833 .39073 .51152 .39615 .50979 .39289 .5066 Mtetra
.39289 .5066 .39615 .50979 .40159 .50806 .39834 .50486 Mtetra
.39834 .50486 .40159 .50806 .40704 .50633 .40379 .50312 Mtetra
.40379 .50312 .40704 .50633 .4125 .5046 .40926 .50138 Mtetra
.40926 .50138 .4125 .5046 .41797 .50286 .41474 .49964 Mtetra
.41474 .49964 .41797 .50286 .42345 .50111 .42022 .49789 Mtetra
.42022 .49789 .42345 .50111 .42894 .49937 .42572 .49613 Mtetra
.42572 .49613 .42894 .49937 .43445 .49762 .43124 .49438 Mtetra
.43124 .49438 .43445 .49762 .43996 .49586 .43676 .49262 Mtetra
.43676 .49262 .43996 .49586 .44549 .49411 .44229 .49085 Mtetra
.664 .74 .907 r
.44229 .49085 .44549 .49411 .45102 .49235 .44784 .48909 Mtetra
.664 .741 .907 r
.44784 .48909 .45102 .49235 .45657 .49058 .45339 .48732 Mtetra
.45339 .48732 .45657 .49058 .46213 .48881 .45896 .48554 Mtetra
.45896 .48554 .46213 .48881 .46771 .48704 .46454 .48376 Mtetra
.46454 .48376 .46771 .48704 .47329 .48528 .47013 .48198 Mtetra
.664 .74 .907 r
.47013 .48198 .47329 .48528 .47888 .4835 .47573 .4802 Mtetra
.663 .74 .907 r
.47573 .4802 .47888 .4835 .48449 .4817 .48134 .47841 Mtetra
.664 .742 .908 r
.48134 .47841 .48449 .4817 .49011 .47992 .48697 .47662 Mtetra
.664 .741 .907 r
.48697 .47662 .49011 .47992 .49574 .47813 .49261 .47481 Mtetra
.49261 .47481 .49574 .47813 .50138 .47634 .49825 .47301 Mtetra
.664 .74 .907 r
.49825 .47301 .50138 .47634 .50703 .47455 .50391 .47121 Mtetra
.663 .74 .907 r
.50391 .47121 .50703 .47455 .51269 .47274 .50959 .46941 Mtetra
.664 .741 .908 r
.50959 .46941 .51269 .47274 .51837 .47093 .51527 .4676 Mtetra
.664 .742 .908 r
.51527 .4676 .51837 .47093 .52406 .46912 .52096 .46577 Mtetra
.664 .741 .907 r
.52096 .46577 .52406 .46912 .52976 .46732 .52667 .46395 Mtetra
.664 .74 .907 r
.52667 .46395 .52976 .46732 .53547 .46551 .53239 .46214 Mtetra
.663 .74 .907 r
.53239 .46214 .53547 .46551 .54119 .46369 .53812 .46033 Mtetra
.663 .741 .908 r
.53812 .46033 .54119 .46369 .54693 .46187 .54386 .45851 Mtetra
.663 .742 .909 r
.54386 .45851 .54693 .46187 .55267 .46005 .54962 .45669 Mtetra
.662 .742 .909 r
.54962 .45669 .55267 .46005 .55843 .45826 .55539 .45487 Mtetra
.661 .74 .909 r
.55539 .45487 .55843 .45826 .5642 .45647 .56117 .45308 Mtetra
.658 .739 .91 r
.56117 .45308 .5642 .45647 .56999 .4547 .56696 .45132 Mtetra
.654 .74 .912 r
.56696 .45132 .56999 .4547 .57578 .45296 .57276 .44961 Mtetra
.649 .74 .916 r
.57276 .44961 .57578 .45296 .58159 .45129 .57858 .44798 Mtetra
.639 .739 .921 r
.57858 .44798 .58159 .45129 .58742 .44975 .58442 .44648 Mtetra
.621 .736 .929 r
.58442 .44648 .58742 .44975 .59326 .44839 .59027 .4452 Mtetra
.588 .73 .942 r
.59027 .4452 .59326 .44839 .59913 .44733 .59615 .4443 Mtetra
.523 .715 .96 r
.59615 .4443 .59913 .44733 .60502 .44676 .60205 .44399 Mtetra
.383 .667 .971 r
.60205 .44399 .60502 .44676 .61095 .44699 .608 .44462 Mtetra
.061 .504 .894 r
.608 .44462 .61095 .44699 .61693 .44846 .61401 .44671 Mtetra
.456 0 0 r
.61401 .44671 .61693 .44846 .623 .45182 .62011 .45097 Mtetra
.765 .253 0 r
.62011 .45097 .623 .45182 .62918 .45789 .62634 .45829 Mtetra
.851 .413 .176 r
.62634 .45829 .62918 .45789 .63553 .46752 .63274 .46942 Mtetra
.869 .474 .286 r
.63274 .46942 .63553 .46752 .64207 .48108 .63933 .48429 Mtetra
.864 .487 .33 r
.63933 .48429 .64207 .48108 .64878 .49745 .64606 .50096 Mtetra
.841 .454 .317 r
.64606 .50096 .64878 .49745 .65555 .51307 .65277 .51489 Mtetra
.712 .23 .101 r
.65277 .51489 .65555 .51307 .66213 .52231 .65921 .52033 Mtetra
.866 .871 .839 r
.65921 .52033 .66213 .52231 .6683 .52048 .6652 .51404 Mtetra
.881 .704 .657 r
.6652 .51404 .6683 .52048 .67398 .50756 .67075 .49802 Mtetra
.864 .662 .628 r
.67075 .49802 .67398 .50756 .67933 .48823 .67608 .4778 Mtetra
.849 .648 .63 r
.67608 .4778 .67933 .48823 .68459 .46814 .68139 .4585 Mtetra
.836 .648 .649 r
.68139 .4585 .68459 .46814 .68995 .4509 .68683 .44278 Mtetra
.821 .658 .681 r
.68683 .44278 .68995 .4509 .69547 .4377 .69244 .43119 Mtetra
.801 .678 .729 r
.69244 .43119 .69547 .4377 .70116 .42834 .69823 .42331 Mtetra
.758 .705 .801 r
.69823 .42331 .70116 .42834 .70703 .42224 .70419 .4187 Mtetra
.614 .725 .925 r
.70419 .4187 .70703 .42224 .71306 .41906 .71034 .41747 Mtetra
0 .292 .684 r
.71034 .41747 .71306 .41906 .7193 .4192 .71678 .42067 Mtetra
.82 .372 .169 r
.71678 .42067 .7193 .4192 .72586 .42409 .72367 .43079 Mtetra
.853 .497 .377 r
.72367 .43079 .72586 .42409 .73295 .43671 .73132 .45204 Mtetra
.846 .526 .447 r
.73132 .45204 .73295 .43671 .74092 .46164 .74009 .48886 Mtetra
.823 .522 .48 r
.74009 .48886 .74092 .46164 .7501 .50267 .74993 .53926 Mtetra
.774 .485 .497 r
.74993 .53926 .7501 .50267 .7602 .55441 .75958 .58374 Mtetra
.613 .343 .485 r
.75958 .58374 .7602 .55441 .76954 .59229 .76676 .59054 Mtetra
.985 .757 .511 r
.76676 .59054 .76954 .59229 .77585 .58665 .7707 .55217 Mtetra
.832 .581 .559 r
.7707 .55217 .77585 .58665 .77909 .54053 .7732 .4963 Mtetra
.779 .536 .569 r
.7732 .4963 .77909 .54053 .78146 .48516 .77619 .44934 Mtetra
.754 .524 .584 r
.77619 .44934 .78146 .48516 .78462 .44218 .78027 .41833 Mtetra
.742 .532 .608 r
.78027 .41833 .78462 .44218 .78891 .41483 .78526 .39987 Mtetra
.737 .557 .649 r
.78526 .39987 .78891 .41483 .79404 .39875 .79084 .38912 Mtetra
.732 .597 .706 r
.79084 .38912 .79404 .39875 .79971 .38934 .79675 .3826 Mtetra
.722 .644 .771 r
.79675 .3826 .79971 .38934 .80568 .38354 .80286 .3783 Mtetra
.706 .683 .826 r
.80286 .3783 .80568 .38354 .81181 .37962 .80906 .37514 Mtetra
.691 .71 .863 r
.80906 .37514 .81181 .37962 .81804 .37664 .81534 .37254 Mtetra
.679 .725 .884 r
.81534 .37254 .81804 .37664 .82432 .37414 .82164 .37023 Mtetra
.672 .733 .896 r
.82164 .37023 .82432 .37414 .83063 .37189 .82798 .36806 Mtetra
.668 .737 .901 r
.82798 .36806 .83063 .37189 .83698 .36975 .83434 .36595 Mtetra
.666 .738 .904 r
.83434 .36595 .83698 .36975 .84334 .36766 .84071 .36389 Mtetra
.665 .74 .906 r
.84071 .36389 .84334 .36766 .84971 .3656 .8471 .36184 Mtetra
.665 .741 .907 r
.8471 .36184 .84971 .3656 .85611 .36355 .8535 .35978 Mtetra
.664 .741 .907 r
.8535 .35978 .85611 .36355 .86252 .3615 .85992 .35773 Mtetra
.85992 .35773 .86252 .3615 .86894 .35946 .86635 .35567 Mtetra
.664 .74 .907 r
.86635 .35567 .86894 .35946 .87538 .35741 .8728 .35362 Mtetra
.8728 .35362 .87538 .35741 .88183 .35536 .87926 .35156 Mtetra
.664 .741 .908 r
.87926 .35156 .88183 .35536 .88829 .3533 .88574 .3495 Mtetra
.664 .741 .907 r
.88574 .3495 .88829 .3533 .89477 .35124 .89223 .34742 Mtetra
.89223 .34742 .89477 .35124 .90127 .34918 .89873 .34535 Mtetra
.89873 .34535 .90127 .34918 .90778 .34711 .90525 .34327 Mtetra
.664 .74 .907 r
.90525 .34327 .90778 .34711 .9143 .34503 .91179 .34119 Mtetra
.664 .741 .907 r
.32506 .52402 .32841 .52716 .33373 .52546 .33038 .52232 Mtetra
.33038 .52232 .33373 .52546 .33905 .52376 .33571 .52062 Mtetra
.663 .741 .908 r
.33571 .52062 .33905 .52376 .34439 .52206 .34106 .51892 Mtetra
.664 .741 .907 r
.34106 .51892 .34439 .52206 .34973 .52036 .34641 .5172 Mtetra
.34641 .5172 .34973 .52036 .35509 .51865 .35177 .51549 Mtetra
.35177 .51549 .35509 .51865 .36046 .51694 .35715 .51377 Mtetra
.35715 .51377 .36046 .51694 .36584 .51522 .36253 .51205 Mtetra
.663 .741 .908 r
.36253 .51205 .36584 .51522 .37123 .51351 .36793 .51033 Mtetra
.664 .741 .907 r
.36793 .51033 .37123 .51351 .37663 .51178 .37334 .5086 Mtetra
.37334 .5086 .37663 .51178 .38204 .51006 .37875 .50687 Mtetra
.37875 .50687 .38204 .51006 .38746 .50833 .38418 .50513 Mtetra
.38418 .50513 .38746 .50833 .39289 .5066 .38962 .50339 Mtetra
.663 .741 .908 r
.38962 .50339 .39289 .5066 .39834 .50486 .39507 .50166 Mtetra
.664 .741 .908 r
.39507 .50166 .39834 .50486 .40379 .50312 .40053 .49991 Mtetra
.664 .741 .907 r
.40053 .49991 .40379 .50312 .40926 .50138 .40601 .49816 Mtetra
.40601 .49816 .40926 .50138 .41474 .49964 .41149 .4964 Mtetra
.41149 .4964 .41474 .49964 .42022 .49789 .41699 .49465 Mtetra
.41699 .49465 .42022 .49789 .42572 .49613 .42249 .49289 Mtetra
.42249 .49289 .42572 .49613 .43124 .49438 .42801 .49113 Mtetra
.42801 .49113 .43124 .49438 .43676 .49262 .43354 .48936 Mtetra
.43354 .48936 .43676 .49262 .44229 .49085 .43908 .48759 Mtetra
.43908 .48759 .44229 .49085 .44784 .48909 .44463 .48581 Mtetra
.44463 .48581 .44784 .48909 .45339 .48732 .4502 .48404 Mtetra
.4502 .48404 .45339 .48732 .45896 .48554 .45577 .48225 Mtetra
.45577 .48225 .45896 .48554 .46454 .48376 .46136 .48047 Mtetra
.46136 .48047 .46454 .48376 .47013 .48198 .46696 .47868 Mtetra
.46696 .47868 .47013 .48198 .47573 .4802 .47257 .47689 Mtetra
.47257 .47689 .47573 .4802 .48134 .47841 .47819 .47509 Mtetra
.664 .74 .907 r
.47819 .47509 .48134 .47841 .48697 .47662 .48382 .47329 Mtetra
.48382 .47329 .48697 .47662 .49261 .47481 .48946 .47149 Mtetra
.664 .741 .908 r
.48946 .47149 .49261 .47481 .49825 .47301 .49512 .46969 Mtetra
.49512 .46969 .49825 .47301 .50391 .47121 .50079 .46787 Mtetra
.664 .741 .907 r
.50079 .46787 .50391 .47121 .50959 .46941 .50647 .46605 Mtetra
.664 .74 .907 r
.50647 .46605 .50959 .46941 .51527 .4676 .51216 .46423 Mtetra
.663 .74 .907 r
.51216 .46423 .51527 .4676 .52096 .46577 .51786 .46242 Mtetra
.663 .741 .908 r
.51786 .46242 .52096 .46577 .52667 .46395 .52358 .46061 Mtetra
.664 .742 .908 r
.52358 .46061 .52667 .46395 .53239 .46214 .5293 .45877 Mtetra
.5293 .45877 .53239 .46214 .53812 .46033 .53504 .45693 Mtetra
.663 .74 .907 r
.53504 .45693 .53812 .46033 .54386 .45851 .54079 .4551 Mtetra
.661 .739 .908 r
.54079 .4551 .54386 .45851 .54962 .45669 .54655 .4533 Mtetra
.661 .74 .909 r
.54655 .4533 .54962 .45669 .55539 .45487 .55233 .45151 Mtetra
.66 .742 .91 r
.55233 .45151 .55539 .45487 .56117 .45308 .55812 .44971 Mtetra
.659 .742 .911 r
.55812 .44971 .56117 .45308 .56696 .45132 .56392 .44794 Mtetra
.653 .739 .913 r
.56392 .44794 .56696 .45132 .57276 .44961 .56973 .44624 Mtetra
.645 .738 .917 r
.56973 .44624 .57276 .44961 .57858 .44798 .57556 .44466 Mtetra
.632 .737 .924 r
.57556 .44466 .57858 .44798 .58442 .44648 .5814 .44324 Mtetra
.611 .736 .934 r
.5814 .44324 .58442 .44648 .59027 .4452 .58727 .44208 Mtetra
.57 .728 .949 r
.58727 .44208 .59027 .4452 .59615 .4443 .59315 .44134 Mtetra
.484 .704 .966 r
.59315 .44134 .59615 .4443 .60205 .44399 .59908 .44132 Mtetra
.291 .627 .962 r
.59908 .44132 .60205 .44399 .608 .44462 .60504 .44243 Mtetra
0 .378 .794 r
.60504 .44243 .608 .44462 .61401 .44671 .61108 .44525 Mtetra
.612 .055 0 r
.61108 .44525 .61401 .44671 .62011 .45097 .61721 .45056 Mtetra
.812 .331 .048 r
.61721 .45056 .62011 .45097 .62634 .45829 .62349 .45924 Mtetra
.862 .443 .228 r
.62349 .45924 .62634 .45829 .63274 .46942 .62994 .47185 Mtetra
.869 .484 .309 r
.62994 .47185 .63274 .46942 .63933 .48429 .63658 .48778 Mtetra
.859 .482 .333 r
.63658 .48778 .63933 .48429 .64606 .50096 .6433 .5041 Mtetra
.82 .416 .285 r
.6433 .5041 .64606 .50096 .65277 .51489 .64992 .51549 Mtetra
.326 0 0 r
.64992 .51549 .65277 .51489 .65921 .52033 .6562 .51664 Mtetra
.89 .775 .728 r
.6562 .51664 .65921 .52033 .6652 .51404 .66203 .50619 Mtetra
.875 .683 .64 r
.66203 .50619 .6652 .51404 .67075 .49802 .6675 .48788 Mtetra
.858 .655 .627 r
.6675 .48788 .67075 .49802 .67608 .4778 .67284 .46753 Mtetra
.844 .647 .636 r
.67284 .46753 .67608 .4778 .68139 .4585 .67822 .44943 Mtetra
.831 .652 .66 r
.67822 .44943 .68139 .4585 .68683 .44278 .68375 .43535 Mtetra
.814 .666 .699 r
.68375 .43535 .68683 .44278 .69244 .43119 .68945 .42537 Mtetra
.784 .689 .759 r
.68945 .42537 .69244 .43119 .69823 .42331 .69533 .41909 Mtetra
.701 .72 .864 r
.69533 .41909 .69823 .42331 .70419 .4187 .7014 .41638 Mtetra
.179 .586 .939 r
.7014 .41638 .70419 .4187 .71034 .41747 .70773 .41791 Mtetra
.777 .282 .034 r
.70773 .41791 .71034 .41747 .71678 .42067 .71444 .4257 Mtetra
.851 .479 .344 r
.71444 .4257 .71678 .42067 .72367 .43079 .72181 .44353 Mtetra
.849 .522 .434 r
.72181 .44353 .72367 .43079 .73132 .45204 .73019 .47603 Mtetra
.831 .525 .473 r
.73019 .47603 .73132 .45204 .74009 .48886 .73969 .52386 Mtetra
.791 .499 .494 r
.73969 .52386 .74009 .48886 .74993 .53926 .74948 .57271 Mtetra
.683 .405 .496 r
.74948 .57271 .74993 .53926 .75958 .58374 .75742 .59135 Mtetra
.9 .792 .307 r
.75742 .59135 .75958 .58374 .76676 .59054 .76214 .56267 Mtetra
.855 .603 .556 r
.76214 .56267 .76676 .59054 .7707 .55217 .7649 .50808 Mtetra
.788 .543 .567 r
.7649 .50808 .7707 .55217 .7732 .4963 .76777 .45755 Mtetra
.758 .525 .579 r
.76777 .45755 .7732 .4963 .77619 .44934 .77165 .42265 Mtetra
.745 .528 .601 r
.77165 .42265 .77619 .44934 .78027 .41833 .77648 .4015 Mtetra
.738 .549 .637 r
.77648 .4015 .78027 .41833 .78526 .39987 .78196 .38917 Mtetra
.734 .586 .691 r
.78196 .38917 .78526 .39987 .79084 .38912 .78782 .3818 Mtetra
.725 .632 .755 r
.78782 .3818 .79084 .38912 .79675 .3826 .79389 .37706 Mtetra
.711 .675 .813 r
.79389 .37706 .79675 .3826 .80286 .3783 .80008 .37366 Mtetra
.695 .705 .855 r
.80008 .37366 .80286 .3783 .80906 .37514 .80634 .37095 Mtetra
.682 .722 .88 r
.80634 .37095 .80906 .37514 .81534 .37254 .81264 .36858 Mtetra
.674 .731 .893 r
.81264 .36858 .81534 .37254 .82164 .37023 .81897 .36637 Mtetra
.669 .736 .9 r
.81897 .36637 .82164 .37023 .82798 .36806 .82532 .36425 Mtetra
.666 .738 .904 r
.82532 .36425 .82798 .36806 .83434 .36595 .83169 .36217 Mtetra
.665 .74 .906 r
.83169 .36217 .83434 .36595 .84071 .36389 .83807 .36011 Mtetra
.83807 .36011 .84071 .36389 .8471 .36184 .84447 .35805 Mtetra
.664 .74 .907 r
.84447 .35805 .8471 .36184 .8535 .35978 .85089 .35599 Mtetra
.85089 .35599 .8535 .35978 .85992 .35773 .85732 .35394 Mtetra
.664 .741 .907 r
.85732 .35394 .85992 .35773 .86635 .35567 .86376 .35188 Mtetra
.664 .741 .908 r
.86376 .35188 .86635 .35567 .8728 .35362 .87022 .34981 Mtetra
.664 .741 .907 r
.87022 .34981 .8728 .35362 .87926 .35156 .87669 .34774 Mtetra
.87669 .34774 .87926 .35156 .88574 .3495 .88318 .34567 Mtetra
.88318 .34567 .88574 .3495 .89223 .34742 .88968 .34359 Mtetra
.88968 .34359 .89223 .34742 .89873 .34535 .89619 .34152 Mtetra
.664 .741 .908 r
.89619 .34152 .89873 .34535 .90525 .34327 .90272 .33943 Mtetra
.664 .741 .907 r
.90272 .33943 .90525 .34327 .91179 .34119 .90926 .33733 Mtetra
.3217 .52088 .32506 .52402 .33038 .52232 .32703 .51918 Mtetra
.32703 .51918 .33038 .52232 .33571 .52062 .33236 .51747 Mtetra
.33236 .51747 .33571 .52062 .34106 .51892 .33771 .51575 Mtetra
.664 .74 .907 r
.33771 .51575 .34106 .51892 .34641 .5172 .34307 .51403 Mtetra
.664 .741 .907 r
.34307 .51403 .34641 .5172 .35177 .51549 .34844 .51231 Mtetra
.34844 .51231 .35177 .51549 .35715 .51377 .35382 .51059 Mtetra
.35382 .51059 .35715 .51377 .36253 .51205 .35921 .50886 Mtetra
.35921 .50886 .36253 .51205 .36793 .51033 .36462 .50713 Mtetra
.664 .74 .907 r
.36462 .50713 .36793 .51033 .37334 .5086 .37003 .5054 Mtetra
.664 .741 .907 r
.37003 .5054 .37334 .5086 .37875 .50687 .37546 .50366 Mtetra
.664 .741 .908 r
.37546 .50366 .37875 .50687 .38418 .50513 .38089 .50193 Mtetra
.664 .741 .907 r
.38089 .50193 .38418 .50513 .38962 .50339 .38634 .50017 Mtetra
.38634 .50017 .38962 .50339 .39507 .50166 .3918 .49842 Mtetra
.664 .74 .907 r
.3918 .49842 .39507 .50166 .40053 .49991 .39727 .49667 Mtetra
.664 .741 .907 r
.39727 .49667 .40053 .49991 .40601 .49816 .40275 .49492 Mtetra
.664 .741 .908 r
.40275 .49492 .40601 .49816 .41149 .4964 .40824 .49317 Mtetra
.664 .742 .907 r
.40824 .49317 .41149 .4964 .41699 .49465 .41374 .4914 Mtetra
.664 .741 .907 r
.41374 .4914 .41699 .49465 .42249 .49289 .41925 .48963 Mtetra
.664 .74 .907 r
.41925 .48963 .42249 .49289 .42801 .49113 .42478 .48786 Mtetra
.663 .741 .907 r
.42478 .48786 .42801 .49113 .43354 .48936 .43031 .48609 Mtetra
.664 .741 .908 r
.43031 .48609 .43354 .48936 .43908 .48759 .43586 .48432 Mtetra
.665 .742 .907 r
.43586 .48432 .43908 .48759 .44463 .48581 .44142 .48253 Mtetra
.664 .741 .907 r
.44142 .48253 .44463 .48581 .4502 .48404 .44699 .48074 Mtetra
.44699 .48074 .4502 .48404 .45577 .48225 .45257 .47895 Mtetra
.663 .741 .907 r
.45257 .47895 .45577 .48225 .46136 .48047 .45817 .47717 Mtetra
.664 .741 .908 r
.45817 .47717 .46136 .48047 .46696 .47868 .46377 .47538 Mtetra
.664 .741 .907 r
.46377 .47538 .46696 .47868 .47257 .47689 .46939 .47357 Mtetra
.46939 .47357 .47257 .47689 .47819 .47509 .47502 .47176 Mtetra
.47502 .47176 .47819 .47509 .48382 .47329 .48066 .46996 Mtetra
.48066 .46996 .48382 .47329 .48946 .47149 .48631 .46815 Mtetra
.48631 .46815 .48946 .47149 .49512 .46969 .49197 .46634 Mtetra
.49197 .46634 .49512 .46969 .50079 .46787 .49765 .46451 Mtetra
.49765 .46451 .50079 .46787 .50647 .46605 .50334 .46269 Mtetra
.50334 .46269 .50647 .46605 .51216 .46423 .50903 .46087 Mtetra
.50903 .46087 .51216 .46423 .51786 .46242 .51474 .45904 Mtetra
.664 .74 .907 r
.51474 .45904 .51786 .46242 .52358 .46061 .52047 .45721 Mtetra
.663 .74 .907 r
.52047 .45721 .52358 .46061 .5293 .45877 .5262 .45538 Mtetra
.663 .74 .908 r
.5262 .45538 .5293 .45877 .53504 .45693 .53195 .45356 Mtetra
.663 .742 .909 r
.53195 .45356 .53504 .45693 .54079 .4551 .53771 .45173 Mtetra
.53771 .45173 .54079 .4551 .54655 .4533 .54348 .4499 Mtetra
.662 .74 .909 r
.54348 .4499 .54655 .4533 .55233 .45151 .54926 .44808 Mtetra
.659 .739 .909 r
.54926 .44808 .55233 .45151 .55812 .44971 .55506 .4463 Mtetra
.655 .739 .912 r
.55506 .4463 .55812 .44971 .56392 .44794 .56087 .44458 Mtetra
.65 .741 .916 r
.56087 .44458 .56392 .44794 .56973 .44624 .56669 .44291 Mtetra
.643 .741 .92 r
.56669 .44291 .56973 .44624 .57556 .44466 .57252 .44135 Mtetra
.627 .737 .926 r
.57252 .44135 .57556 .44466 .5814 .44324 .57838 .43999 Mtetra
.598 .73 .937 r
.57838 .43999 .5814 .44324 .58727 .44208 .58425 .43897 Mtetra
.542 .719 .955 r
.58425 .43897 .58727 .44208 .59315 .44134 .59015 .43849 Mtetra
.427 .686 .972 r
.59015 .43849 .59315 .44134 .59908 .44132 .59609 .43884 Mtetra
.164 .566 .932 r
.59609 .43884 .59908 .44132 .60504 .44243 .60208 .44048 Mtetra
0 .222 .643 r
.60208 .44048 .60504 .44243 .61108 .44525 .60814 .44411 Mtetra
.717 .184 0 r
.60814 .44411 .61108 .44525 .61721 .45056 .61431 .45059 Mtetra
.84 .387 .132 r
.61431 .45059 .61721 .45056 .62349 .45924 .62064 .46075 Mtetra
.867 .465 .267 r
.62064 .46075 .62349 .45924 .62994 .47185 .62714 .4748 Mtetra
.867 .487 .324 r
.62714 .4748 .62994 .47185 .63658 .48778 .6338 .49135 Mtetra
.849 .469 .327 r
.6338 .49135 .63658 .48778 .6433 .5041 .64049 .50653 Mtetra
.777 .339 .209 r
.64049 .50653 .6433 .5041 .64992 .51549 .647 .5146 Mtetra
.717 .944 .956 r
.647 .5146 .64992 .51549 .6562 .51664 .65312 .51128 Mtetra
.887 .726 .677 r
.65312 .51128 .6562 .51664 .66203 .50619 .65882 .49722 Mtetra
.868 .669 .631 r
.65882 .49722 .66203 .50619 .6675 .48788 .66424 .47747 Mtetra
.853 .65 .629 r
.66424 .47747 .6675 .48788 .67284 .46753 .66961 .45763 Mtetra
.839 .648 .644 r
.66961 .45763 .67284 .46753 .67822 .44943 .67507 .441 Mtetra
.825 .656 .674 r
.67507 .441 .67822 .44943 .68375 .43535 .68069 .42864 Mtetra
.803 .675 .723 r
.68069 .42864 .68375 .43535 .68945 .42537 .68649 .42039 Mtetra
.753 .706 .807 r
.68649 .42039 .68945 .42537 .69533 .41909 .69248 .41599 Mtetra
.505 .709 .963 r
.69248 .41599 .69533 .41909 .7014 .41638 .6987 .41581 Mtetra
.662 .108 0 r
.6987 .41581 .7014 .41638 .70773 .41791 .70526 .42144 Mtetra
.846 .452 .298 r
.70526 .42144 .70773 .41791 .71444 .4257 .71239 .43609 Mtetra
.851 .516 .419 r
.71239 .43609 .71444 .4257 .72181 .44353 .7204 .46436 Mtetra
.837 .527 .466 r
.7204 .46436 .72181 .44353 .73019 .47603 .72953 .50869 Mtetra
.804 .509 .49 r
.72953 .50869 .73019 .47603 .73969 .52386 .73928 .55966 Mtetra
.725 .442 .499 r
.73928 .55966 .73969 .52386 .74948 .57271 .74782 .58881 Mtetra
.021 0 .27 r
.74782 .58881 .74948 .57271 .75742 .59135 .75337 .57144 Mtetra
.885 .633 .553 r
.75337 .57144 .75742 .59135 .76214 .56267 .75653 .52022 Mtetra
.8 .553 .564 r
.75653 .52022 .76214 .56267 .7649 .50808 .75935 .46685 Mtetra
.764 .528 .575 r
.75935 .46685 .7649 .50808 .76777 .45755 .76304 .42789 Mtetra
.747 .526 .594 r
.76304 .42789 .76777 .45755 .77165 .42265 .76771 .40371 Mtetra
.74 .542 .626 r
.76771 .40371 .77165 .42265 .77648 .4015 .77308 .38955 Mtetra
.736 .576 .675 r
.77308 .38955 .77648 .4015 .78196 .38917 .77888 .38117 Mtetra
.728 .621 .738 r
.77888 .38117 .78196 .38917 .78782 .3818 .78491 .3759 Mtetra
.715 .665 .8 r
.78491 .3759 .78782 .3818 .79389 .37706 .79108 .37224 Mtetra
.699 .699 .846 r
.79108 .37224 .79389 .37706 .80008 .37366 .79733 .36939 Mtetra
.685 .719 .875 r
.79733 .36939 .80008 .37366 .80634 .37095 .80362 .36694 Mtetra
.676 .73 .89 r
.80362 .36694 .80634 .37095 .81264 .36858 .80994 .36469 Mtetra
.67 .735 .899 r
.80994 .36469 .81264 .36858 .81897 .36637 .81629 .36255 Mtetra
.667 .738 .903 r
.81629 .36255 .81897 .36637 .82532 .36425 .82265 .36046 Mtetra
.666 .74 .905 r
.82265 .36046 .82532 .36425 .83169 .36217 .82903 .35839 Mtetra
.665 .74 .906 r
.82903 .35839 .83169 .36217 .83807 .36011 .83543 .35632 Mtetra
.664 .74 .907 r
.83543 .35632 .83807 .36011 .84447 .35805 .84184 .35425 Mtetra
.84184 .35425 .84447 .35805 .85089 .35599 .84826 .3522 Mtetra
.664 .741 .907 r
.84826 .3522 .85089 .35599 .85732 .35394 .8547 .35013 Mtetra
.8547 .35013 .85732 .35394 .86376 .35188 .86115 .34806 Mtetra
.86115 .34806 .86376 .35188 .87022 .34981 .86762 .34599 Mtetra
.86762 .34599 .87022 .34981 .87669 .34774 .8741 .34391 Mtetra
.8741 .34391 .87669 .34774 .88318 .34567 .8806 .34183 Mtetra
.8806 .34183 .88318 .34567 .88968 .34359 .88711 .33975 Mtetra
.88711 .33975 .88968 .34359 .89619 .34152 .89364 .33765 Mtetra
.664 .74 .907 r
.89364 .33765 .89619 .34152 .90272 .33943 .90018 .33556 Mtetra
.664 .741 .907 r
.90018 .33556 .90272 .33943 .90926 .33733 .90673 .33346 Mtetra
.31832 .51773 .3217 .52088 .32703 .51918 .32366 .51602 Mtetra
.32366 .51602 .32703 .51918 .33236 .51747 .329 .5143 Mtetra
.329 .5143 .33236 .51747 .33771 .51575 .33436 .51258 Mtetra
.33436 .51258 .33771 .51575 .34307 .51403 .33972 .51086 Mtetra
.33972 .51086 .34307 .51403 .34844 .51231 .3451 .50913 Mtetra
.3451 .50913 .34844 .51231 .35382 .51059 .35049 .5074 Mtetra
.35049 .5074 .35382 .51059 .35921 .50886 .35588 .50566 Mtetra
.35588 .50566 .35921 .50886 .36462 .50713 .36129 .50393 Mtetra
.36129 .50393 .36462 .50713 .37003 .5054 .36671 .50219 Mtetra
.36671 .50219 .37003 .5054 .37546 .50366 .37215 .50044 Mtetra
.37215 .50044 .37546 .50366 .38089 .50193 .37759 .49869 Mtetra
.664 .74 .907 r
.37759 .49869 .38089 .50193 .38634 .50017 .38304 .49694 Mtetra
.664 .741 .907 r
.38304 .49694 .38634 .50017 .3918 .49842 .38851 .49519 Mtetra
.38851 .49519 .3918 .49842 .39727 .49667 .39398 .49343 Mtetra
.39398 .49343 .39727 .49667 .40275 .49492 .39947 .49167 Mtetra
.664 .74 .907 r
.39947 .49167 .40275 .49492 .40824 .49317 .40497 .4899 Mtetra
.40497 .4899 .40824 .49317 .41374 .4914 .41048 .48813 Mtetra
.664 .741 .907 r
.41048 .48813 .41374 .4914 .41925 .48963 .416 .48636 Mtetra
.416 .48636 .41925 .48963 .42478 .48786 .42153 .48459 Mtetra
.42153 .48459 .42478 .48786 .43031 .48609 .42707 .4828 Mtetra
.664 .74 .907 r
.42707 .4828 .43031 .48609 .43586 .48432 .43263 .48102 Mtetra
.43263 .48102 .43586 .48432 .44142 .48253 .4382 .47923 Mtetra
.664 .741 .907 r
.4382 .47923 .44142 .48253 .44699 .48074 .44377 .47744 Mtetra
.664 .741 .908 r
.44377 .47744 .44699 .48074 .45257 .47895 .44936 .47565 Mtetra
.664 .741 .907 r
.44936 .47565 .45257 .47895 .45817 .47717 .45496 .47384 Mtetra
.664 .74 .907 r
.45496 .47384 .45817 .47717 .46377 .47538 .46058 .47204 Mtetra
.46058 .47204 .46377 .47538 .46939 .47357 .4662 .47024 Mtetra
.663 .741 .907 r
.4662 .47024 .46939 .47357 .47502 .47176 .47184 .46843 Mtetra
.664 .741 .908 r
.47184 .46843 .47502 .47176 .48066 .46996 .47748 .46662 Mtetra
.664 .741 .907 r
.47748 .46662 .48066 .46996 .48631 .46815 .48314 .46479 Mtetra
.48314 .46479 .48631 .46815 .49197 .46634 .48881 .46297 Mtetra
.664 .74 .907 r
.48881 .46297 .49197 .46634 .49765 .46451 .4945 .46115 Mtetra
.663 .741 .907 r
.4945 .46115 .49765 .46451 .50334 .46269 .50019 .45933 Mtetra
.664 .741 .908 r
.50019 .45933 .50334 .46269 .50903 .46087 .5059 .4575 Mtetra
.664 .742 .908 r
.5059 .4575 .50903 .46087 .51474 .45904 .51162 .45565 Mtetra
.664 .741 .907 r
.51162 .45565 .51474 .45904 .52047 .45721 .51735 .45381 Mtetra
.663 .74 .907 r
.51735 .45381 .52047 .45721 .5262 .45538 .52309 .45198 Mtetra
.662 .74 .908 r
.52309 .45198 .5262 .45538 .53195 .45356 .52884 .45015 Mtetra
.662 .741 .908 r
.52884 .45015 .53195 .45356 .53771 .45173 .53461 .44832 Mtetra
.53461 .44832 .53771 .45173 .54348 .4499 .54039 .44649 Mtetra
.661 .741 .909 r
.54039 .44649 .54348 .4499 .54926 .44808 .54618 .44468 Mtetra
.658 .741 .911 r
.54618 .44468 .54926 .44808 .55506 .4463 .55198 .44291 Mtetra
.654 .74 .913 r
.55198 .44291 .55506 .4463 .56087 .44458 .5578 .44119 Mtetra
.648 .739 .916 r
.5578 .44119 .56087 .44458 .56669 .44291 .56363 .43955 Mtetra
.637 .738 .921 r
.56363 .43955 .56669 .44291 .57252 .44135 .56948 .43806 Mtetra
.618 .736 .931 r
.56948 .43806 .57252 .44135 .57838 .43999 .57534 .43681 Mtetra
.582 .731 .945 r
.57534 .43681 .57838 .43999 .58425 .43897 .58123 .43595 Mtetra
.511 .713 .963 r
.58123 .43595 .58425 .43897 .59015 .43849 .58714 .43572 Mtetra
.357 .656 .969 r
.58714 .43572 .59015 .43849 .59609 .43884 .59309 .43648 Mtetra
.004 .467 .868 r
.59309 .43648 .59609 .43884 .60208 .44048 .5991 .4388 Mtetra
.516 0 0 r
.5991 .4388 .60208 .44048 .60814 .44411 .6052 .4434 Mtetra
.785 .284 0 r
.6052 .4434 .60814 .44411 .61431 .45059 .61141 .45118 Mtetra
.855 .425 .197 r
.61141 .45118 .61431 .45059 .62064 .46075 .61778 .46281 Mtetra
.869 .478 .295 r
.61778 .46281 .62064 .46075 .62714 .4748 .62433 .47809 Mtetra
.863 .486 .331 r
.62433 .47809 .62714 .4748 .6338 .49135 .631 .49477 Mtetra
.835 .444 .309 r
.631 .49477 .6338 .49135 .64049 .50653 .63763 .50801 Mtetra
.648 .134 .007 r
.63763 .50801 .64049 .50653 .647 .5146 .64401 .51207 Mtetra
.883 .833 .792 r
.64401 .51207 .647 .5146 .65312 .51128 .64997 .50431 Mtetra
.879 .696 .651 r
.64997 .50431 .65312 .51128 .65882 .49722 .65557 .48743 Mtetra
.862 .66 .628 r
.65557 .48743 .65882 .49722 .66424 .47747 .66099 .46712 Mtetra
.848 .648 .633 r
.66099 .46712 .66424 .47747 .66961 .45763 .66641 .44827 Mtetra
.834 .651 .654 r
.66641 .44827 .66961 .45763 .67507 .441 .67195 .43332 Mtetra
.817 .664 .693 r
.67195 .43332 .67507 .441 .68069 .42864 .67767 .42277 Mtetra
.784 .689 .759 r
.67767 .42277 .68069 .42864 .68649 .42039 .68358 .41645 Mtetra
.663 .722 .892 r
.68358 .41645 .68649 .42039 .69248 .41599 .6897 .41448 Mtetra
.343 0 0 r
.6897 .41448 .69248 .41599 .6987 .41581 .69613 .418 Mtetra
.834 .41 .23 r
.69613 .418 .6987 .41581 .70526 .42144 .70304 .42968 Mtetra
.852 .507 .399 r
.70304 .42968 .70526 .42144 .71239 .43609 .71072 .45388 Mtetra
.841 .527 .457 r
.71072 .45388 .71239 .43609 .7204 .46436 .71947 .49419 Mtetra
.815 .516 .485 r
.71947 .49419 .7204 .46436 .72953 .50869 .72904 .54527 Mtetra
.753 .467 .498 r
.72904 .54527 .72953 .50869 .73928 .55966 .73801 .58292 Mtetra
.469 .213 .443 r
.73801 .58292 .73928 .55966 .74782 .58881 .74437 .57777 Mtetra
.926 .68 .546 r
.74437 .57777 .74782 .58881 .75337 .57144 .74806 .53232 Mtetra
.814 .565 .562 r
.74806 .53232 .75337 .57144 .75653 .52022 .75093 .47722 Mtetra
.771 .532 .572 r
.75093 .47722 .75653 .52022 .75935 .46685 .75446 .43415 Mtetra
.751 .525 .588 r
.75446 .43415 .75935 .46685 .76304 .42789 .75896 .40658 Mtetra
.742 .537 .616 r
.75896 .40658 .76304 .42789 .76771 .40371 .76421 .3903 Mtetra
.737 .566 .661 r
.76421 .3903 .76771 .40371 .77308 .38955 .76993 .38075 Mtetra
.731 .609 .722 r
.76993 .38075 .77308 .38955 .77888 .38117 .77592 .37486 Mtetra
.719 .655 .785 r
.77592 .37486 .77888 .38117 .78491 .3759 .78207 .37087 Mtetra
.703 .692 .836 r
.78207 .37087 .78491 .3759 .79108 .37224 .7883 .36784 Mtetra
.688 .715 .869 r
.7883 .36784 .79108 .37224 .79733 .36939 .79458 .3653 Mtetra
.678 .727 .887 r
.79458 .3653 .79733 .36939 .80362 .36694 .8009 .36301 Mtetra
.671 .734 .897 r
.8009 .36301 .80362 .36694 .80994 .36469 .80724 .36085 Mtetra
.668 .738 .902 r
.80724 .36085 .80994 .36469 .81629 .36255 .8136 .35874 Mtetra
.666 .74 .905 r
.8136 .35874 .81629 .36255 .82265 .36046 .81997 .35666 Mtetra
.665 .74 .906 r
.81997 .35666 .82265 .36046 .82903 .35839 .82636 .35458 Mtetra
.664 .74 .906 r
.82636 .35458 .82903 .35839 .83543 .35632 .83277 .35251 Mtetra
.664 .74 .907 r
.83277 .35251 .83543 .35632 .84184 .35425 .83919 .35045 Mtetra
.664 .741 .907 r
.83919 .35045 .84184 .35425 .84826 .3522 .84562 .34839 Mtetra
.84562 .34839 .84826 .3522 .8547 .35013 .85207 .34631 Mtetra
.85207 .34631 .8547 .35013 .86115 .34806 .85854 .34423 Mtetra
.85854 .34423 .86115 .34806 .86762 .34599 .86502 .34215 Mtetra
.86502 .34215 .86762 .34599 .8741 .34391 .87151 .34007 Mtetra
.87151 .34007 .8741 .34391 .8806 .34183 .87802 .33798 Mtetra
.87802 .33798 .8806 .34183 .88711 .33975 .88454 .33588 Mtetra
.88454 .33588 .88711 .33975 .89364 .33765 .89107 .33378 Mtetra
.89107 .33378 .89364 .33765 .90018 .33556 .89762 .33168 Mtetra
.89762 .33168 .90018 .33556 .90673 .33346 .90419 .32957 Mtetra
.31493 .51456 .31832 .51773 .32366 .51602 .32027 .51284 Mtetra
.32027 .51284 .32366 .51602 .329 .5143 .32562 .51112 Mtetra
.32562 .51112 .329 .5143 .33436 .51258 .33099 .50939 Mtetra
.33099 .50939 .33436 .51258 .33972 .51086 .33636 .50766 Mtetra
.33636 .50766 .33972 .51086 .3451 .50913 .34174 .50593 Mtetra
.34174 .50593 .3451 .50913 .35049 .5074 .34714 .50419 Mtetra
.34714 .50419 .35049 .5074 .35588 .50566 .35254 .50245 Mtetra
.35254 .50245 .35588 .50566 .36129 .50393 .35796 .50071 Mtetra
.35796 .50071 .36129 .50393 .36671 .50219 .36339 .49896 Mtetra
.36339 .49896 .36671 .50219 .37215 .50044 .36882 .49721 Mtetra
.36882 .49721 .37215 .50044 .37759 .49869 .37427 .49546 Mtetra
.37427 .49546 .37759 .49869 .38304 .49694 .37973 .4937 Mtetra
.37973 .4937 .38304 .49694 .38851 .49519 .38521 .49194 Mtetra
.38521 .49194 .38851 .49519 .39398 .49343 .39069 .49017 Mtetra
.39069 .49017 .39398 .49343 .39947 .49167 .39618 .48841 Mtetra
.39618 .48841 .39947 .49167 .40497 .4899 .40169 .48663 Mtetra
.40169 .48663 .40497 .4899 .41048 .48813 .4072 .48485 Mtetra
.4072 .48485 .41048 .48813 .416 .48636 .41273 .48308 Mtetra
.41273 .48308 .416 .48636 .42153 .48459 .41827 .48129 Mtetra
.41827 .48129 .42153 .48459 .42707 .4828 .42382 .47951 Mtetra
.42382 .47951 .42707 .4828 .43263 .48102 .42939 .47771 Mtetra
.42939 .47771 .43263 .48102 .4382 .47923 .43496 .47592 Mtetra
.43496 .47592 .4382 .47923 .44377 .47744 .44054 .47412 Mtetra
.44054 .47412 .44377 .47744 .44936 .47565 .44614 .47232 Mtetra
.664 .74 .907 r
.44614 .47232 .44936 .47565 .45496 .47384 .45175 .47052 Mtetra
.664 .741 .907 r
.45175 .47052 .45496 .47384 .46058 .47204 .45737 .46871 Mtetra
.45737 .46871 .46058 .47204 .4662 .47024 .463 .46689 Mtetra
.463 .46689 .4662 .47024 .47184 .46843 .46864 .46507 Mtetra
.664 .74 .907 r
.46864 .46507 .47184 .46843 .47748 .46662 .4743 .46325 Mtetra
.4743 .46325 .47748 .46662 .48314 .46479 .47997 .46143 Mtetra
.664 .741 .908 r
.47997 .46143 .48314 .46479 .48881 .46297 .48564 .4596 Mtetra
.664 .741 .907 r
.48564 .4596 .48881 .46297 .4945 .46115 .49133 .45777 Mtetra
.49133 .45777 .4945 .46115 .50019 .45933 .49704 .45593 Mtetra
.664 .74 .907 r
.49704 .45593 .50019 .45933 .5059 .4575 .50275 .4541 Mtetra
.663 .74 .907 r
.50275 .4541 .5059 .4575 .51162 .45565 .50848 .45226 Mtetra
.664 .741 .908 r
.50848 .45226 .51162 .45565 .51735 .45381 .51422 .45042 Mtetra
.664 .742 .908 r
.51422 .45042 .51735 .45381 .52309 .45198 .51997 .44857 Mtetra
.663 .741 .908 r
.51997 .44857 .52309 .45198 .52884 .45015 .52573 .44673 Mtetra
.662 .74 .908 r
.52573 .44673 .52884 .45015 .53461 .44832 .5315 .44489 Mtetra
.661 .74 .908 r
.5315 .44489 .53461 .44832 .54039 .44649 .53729 .44307 Mtetra
.66 .74 .91 r
.53729 .44307 .54039 .44649 .54618 .44468 .54309 .44127 Mtetra
.657 .741 .912 r
.54309 .44127 .54618 .44468 .55198 .44291 .5489 .43951 Mtetra
.652 .74 .914 r
.5489 .43951 .55198 .44291 .5578 .44119 .55473 .4378 Mtetra
.645 .739 .918 r
.55473 .4378 .5578 .44119 .56363 .43955 .56056 .43621 Mtetra
.631 .737 .924 r
.56056 .43621 .56363 .43955 .56948 .43806 .56642 .43479 Mtetra
.607 .734 .935 r
.56642 .43479 .56948 .43806 .57534 .43681 .57229 .43366 Mtetra
.561 .725 .951 r
.57229 .43366 .57534 .43681 .58123 .43595 .57819 .433 Mtetra
.467 .699 .969 r
.57819 .433 .58123 .43595 .58714 .43572 .58412 .43309 Mtetra
.253 .611 .955 r
.58412 .43309 .58714 .43572 .59309 .43648 .59009 .43435 Mtetra
0 .328 .748 r
.59009 .43435 .59309 .43648 .5991 .4388 .59612 .43741 Mtetra
.654 .104 0 r
.59612 .43741 .5991 .4388 .6052 .4434 .60225 .44311 Mtetra
.824 .353 .08 r
.60225 .44311 .6052 .4434 .61141 .45118 .6085 .45229 Mtetra
.864 .452 .243 r
.6085 .45229 .61141 .45118 .61778 .46281 .61492 .46543 Mtetra
.868 .486 .315 r
.61492 .46543 .61778 .46281 .62433 .47809 .6215 .48165 Mtetra
.856 .478 .333 r
.6215 .48165 .62433 .47809 .631 .49477 .62815 .49772 Mtetra
.809 .397 .266 r
.62815 .49772 .631 .49477 .63763 .50801 .6347 .50812 Mtetra
.04 .61 .713 r
.6347 .50812 .63763 .50801 .64401 .51207 .64094 .50782 Mtetra
.89 .756 .708 r
.64094 .50782 .64401 .51207 .64997 .50431 .64677 .49608 Mtetra
.873 .679 .637 r
.64677 .49608 .64997 .50431 .65557 .48743 .65231 .47719 Mtetra
.856 .654 .628 r
.65231 .47719 .65557 .48743 .66099 .46712 .65774 .457 Mtetra
.842 .648 .64 r
.65774 .457 .66099 .46712 .66641 .44827 .66323 .43958 Mtetra
.828 .655 .668 r
.66323 .43958 .66641 .44827 .67195 .43332 .66887 .42649 Mtetra
.805 .674 .719 r
.66887 .42649 .67195 .43332 .67767 .42277 .67469 .41795 Mtetra
.742 .709 .821 r
.67469 .41795 .67767 .42277 .68358 .41645 .68072 .41399 Mtetra
.218 .603 .95 r
.68072 .41399 .68358 .41645 .6897 .41448 .68702 .41538 Mtetra
.803 .334 .11 r
.68702 .41538 .6897 .41448 .69613 .418 .69375 .42428 Mtetra
.852 .493 .372 r
.69375 .42428 .69613 .418 .70304 .42968 .70114 .44463 Mtetra
.845 .525 .446 r
.70114 .44463 .70304 .42968 .71072 .45388 .70951 .48058 Mtetra
.823 .521 .479 r
.70951 .48058 .71072 .45388 .71947 .49419 .71882 .5301 Mtetra
.775 .485 .496 r
.71882 .5301 .71947 .49419 .72904 .54527 .72802 .57409 Mtetra
.616 .343 .481 r
.72802 .57409 .72904 .54527 .73801 .58292 .73514 .5813 Mtetra
.984 .759 .518 r
.73514 .5813 .73801 .58292 .74437 .57777 .73946 .54381 Mtetra
.833 .582 .56 r
.73946 .54381 .74437 .57777 .74806 .53232 .74249 .48841 Mtetra
.78 .537 .569 r
.74249 .48841 .74806 .53232 .75093 .47722 .74588 .44143 Mtetra
.755 .525 .583 r
.74588 .44143 .75093 .47722 .75446 .43415 .75021 .41021 Mtetra
.744 .532 .608 r
.75021 .41021 .75446 .43415 .75896 .40658 .75533 .39153 Mtetra
.738 .557 .648 r
.75533 .39153 .75896 .40658 .76421 .3903 .76098 .38059 Mtetra
.733 .598 .705 r
.76098 .38059 .76421 .3903 .76993 .38075 .76692 .37395 Mtetra
.723 .644 .769 r
.76692 .37395 .76993 .38075 .77592 .37486 .77304 .36956 Mtetra
.707 .683 .824 r
.77304 .36956 .77592 .37486 .78207 .37087 .77925 .36633 Mtetra
.691 .709 .862 r
.77925 .36633 .78207 .37087 .7883 .36784 .78553 .3637 Mtetra
.68 .725 .884 r
.78553 .3637 .7883 .36784 .79458 .3653 .79184 .36135 Mtetra
.673 .733 .896 r
.79184 .36135 .79458 .3653 .8009 .36301 .79817 .35915 Mtetra
.669 .737 .901 r
.79817 .35915 .8009 .36301 .80724 .36085 .80452 .35702 Mtetra
.666 .738 .904 r
.80452 .35702 .80724 .36085 .8136 .35874 .81089 .35492 Mtetra
.665 .739 .905 r
.81089 .35492 .8136 .35874 .81997 .35666 .81728 .35285 Mtetra
.664 .74 .907 r
.81728 .35285 .81997 .35666 .82636 .35458 .82368 .35078 Mtetra
.664 .741 .907 r
.82368 .35078 .82636 .35458 .83277 .35251 .8301 .34871 Mtetra
.8301 .34871 .83277 .35251 .83919 .35045 .83653 .34663 Mtetra
.83653 .34663 .83919 .35045 .84562 .34839 .84298 .34455 Mtetra
.664 .74 .907 r
.84298 .34455 .84562 .34839 .85207 .34631 .84944 .34247 Mtetra
.664 .741 .907 r
.84944 .34247 .85207 .34631 .85854 .34423 .85591 .34039 Mtetra
.85591 .34039 .85854 .34423 .86502 .34215 .8624 .3383 Mtetra
.8624 .3383 .86502 .34215 .87151 .34007 .8689 .3362 Mtetra
.8689 .3362 .87151 .34007 .87802 .33798 .87542 .33411 Mtetra
.87542 .33411 .87802 .33798 .88454 .33588 .88195 .332 Mtetra
.88195 .332 .88454 .33588 .89107 .33378 .8885 .32989 Mtetra
.8885 .32989 .89107 .33378 .89762 .33168 .89506 .32778 Mtetra
.89506 .32778 .89762 .33168 .90419 .32957 .90164 .32566 Mtetra
.31153 .51139 .31493 .51456 .32027 .51284 .31688 .50966 Mtetra
.31688 .50966 .32027 .51284 .32562 .51112 .32224 .50793 Mtetra
.32224 .50793 .32562 .51112 .33099 .50939 .3276 .5062 Mtetra
.3276 .5062 .33099 .50939 .33636 .50766 .33298 .50446 Mtetra
.33298 .50446 .33636 .50766 .34174 .50593 .33837 .50273 Mtetra
.33837 .50273 .34174 .50593 .34714 .50419 .34377 .50098 Mtetra
.34377 .50098 .34714 .50419 .35254 .50245 .34919 .49923 Mtetra
.34919 .49923 .35254 .50245 .35796 .50071 .35461 .49748 Mtetra
.35461 .49748 .35796 .50071 .36339 .49896 .36004 .49573 Mtetra
.36004 .49573 .36339 .49896 .36882 .49721 .36549 .49397 Mtetra
.36549 .49397 .36882 .49721 .37427 .49546 .37095 .49221 Mtetra
.37095 .49221 .37427 .49546 .37973 .4937 .37641 .49044 Mtetra
.37641 .49044 .37973 .4937 .38521 .49194 .38189 .48868 Mtetra
.38189 .48868 .38521 .49194 .39069 .49017 .38738 .48691 Mtetra
.38738 .48691 .39069 .49017 .39618 .48841 .39288 .48513 Mtetra
.39288 .48513 .39618 .48841 .40169 .48663 .3984 .48335 Mtetra
.3984 .48335 .40169 .48663 .4072 .48485 .40392 .48157 Mtetra
.40392 .48157 .4072 .48485 .41273 .48308 .40945 .47978 Mtetra
.40945 .47978 .41273 .48308 .41827 .48129 .415 .47799 Mtetra
.415 .47799 .41827 .48129 .42382 .47951 .42056 .4762 Mtetra
.42056 .4762 .42382 .47951 .42939 .47771 .42613 .4744 Mtetra
.42613 .4744 .42939 .47771 .43496 .47592 .43171 .4726 Mtetra
.43171 .4726 .43496 .47592 .44054 .47412 .4373 .47079 Mtetra
.4373 .47079 .44054 .47412 .44614 .47232 .44291 .46899 Mtetra
.44291 .46899 .44614 .47232 .45175 .47052 .44852 .46717 Mtetra
.44852 .46717 .45175 .47052 .45737 .46871 .45415 .46535 Mtetra
.45415 .46535 .45737 .46871 .463 .46689 .45979 .46353 Mtetra
.663 .741 .908 r
.45979 .46353 .463 .46689 .46864 .46507 .46544 .46172 Mtetra
.664 .741 .908 r
.46544 .46172 .46864 .46507 .4743 .46325 .4711 .45989 Mtetra
.664 .741 .907 r
.4711 .45989 .4743 .46325 .47997 .46143 .47678 .45805 Mtetra
.664 .74 .907 r
.47678 .45805 .47997 .46143 .48564 .4596 .48246 .45621 Mtetra
.48246 .45621 .48564 .4596 .49133 .45777 .48816 .45438 Mtetra
.663 .741 .908 r
.48816 .45438 .49133 .45777 .49704 .45593 .49387 .45255 Mtetra
.664 .742 .908 r
.49387 .45255 .49704 .45593 .50275 .4541 .49959 .45069 Mtetra
.664 .741 .907 r
.49959 .45069 .50275 .4541 .50848 .45226 .50533 .44884 Mtetra
.663 .74 .907 r
.50533 .44884 .50848 .45226 .51422 .45042 .51107 .44699 Mtetra
.662 .74 .907 r
.51107 .44699 .51422 .45042 .51997 .44857 .51683 .44515 Mtetra
.662 .741 .908 r
.51683 .44515 .51997 .44857 .52573 .44673 .5226 .44332 Mtetra
.663 .742 .909 r
.5226 .44332 .52573 .44673 .5315 .44489 .52838 .44147 Mtetra
.662 .741 .909 r
.52838 .44147 .5315 .44489 .53729 .44307 .53418 .43963 Mtetra
.659 .74 .91 r
.53418 .43963 .53729 .44307 .54309 .44127 .53998 .43784 Mtetra
.654 .739 .912 r
.53998 .43784 .54309 .44127 .5489 .43951 .5458 .4361 Mtetra
.649 .74 .915 r
.5458 .4361 .5489 .43951 .55473 .4378 .55164 .43444 Mtetra
.641 .74 .921 r
.55164 .43444 .55473 .4378 .56056 .43621 .55749 .43288 Mtetra
.624 .737 .928 r
.55749 .43288 .56056 .43621 .56642 .43479 .56335 .43154 Mtetra
.593 .731 .94 r
.56335 .43154 .56642 .43479 .57229 .43366 .56923 .43055 Mtetra
.533 .717 .957 r
.56923 .43055 .57229 .43366 .57819 .433 .57514 .43014 Mtetra
.406 .677 .971 r
.57514 .43014 .57819 .433 .58412 .43309 .58108 .43061 Mtetra
.114 .536 .915 r
.58108 .43061 .58412 .43309 .59009 .43435 .58707 .43246 Mtetra
.399 0 0 r
.58707 .43246 .59009 .43435 .59612 .43741 .59313 .4364 Mtetra
.745 .223 0 r
.59313 .4364 .59612 .43741 .60225 .44311 .59929 .44331 Mtetra
.847 .402 .158 r
.59929 .44331 .60225 .44311 .6085 .45229 .60559 .45398 Mtetra
.868 .47 .278 r
.60559 .45398 .6085 .45229 .61492 .46543 .61205 .4685 Mtetra
.866 .488 .328 r
.61205 .4685 .61492 .46543 .6215 .48165 .61865 .48522 Mtetra
.845 .462 .324 r
.61865 .48522 .6215 .48165 .62815 .49772 .62527 .4999 Mtetra
.751 .295 .167 r
.62527 .4999 .62815 .49772 .6347 .50812 .63171 .50673 Mtetra
.823 .918 .9 r
.63171 .50673 .6347 .50812 .64094 .50782 .6378 .5019 Mtetra
.884 .715 .667 r
.6378 .5019 .64094 .50782 .64677 .49608 .64353 .48681 Mtetra
.866 .666 .63 r
.64353 .48681 .64677 .49608 .65231 .47719 .64904 .46684 Mtetra
.851 .65 .631 r
.64904 .46684 .65231 .47719 .65774 .457 .65451 .44744 Mtetra
.838 .65 .65 r
.65451 .44744 .65774 .457 .66323 .43958 .66009 .4317 Mtetra
.82 .662 .688 r
.66009 .4317 .66323 .43958 .66887 .42649 .66583 .42065 Mtetra
.781 .689 .762 r
.66583 .42065 .66887 .42649 .67469 .41795 .67177 .41449 Mtetra
.575 .718 .94 r
.67177 .41449 .67469 .41795 .68072 .41399 .67796 .41369 Mtetra
.709 .173 0 r
.67796 .41369 .68072 .41399 .68702 .41538 .68451 .41991 Mtetra
.849 .471 .333 r
.68451 .41991 .68702 .41538 .69375 .42428 .69164 .43656 Mtetra
.848 .521 .433 r
.69164 .43656 .69375 .42428 .70114 .44463 .69965 .46801 Mtetra
.83 .525 .473 r
.69965 .46801 .70114 .44463 .70951 .48058 .70864 .51476 Mtetra
.792 .499 .493 r
.70864 .51476 .70951 .48058 .71882 .5301 .71791 .56284 Mtetra
.686 .406 .493 r
.71791 .56284 .71882 .5301 .72802 .57409 .72567 .58168 Mtetra
.905 .803 .325 r
.72567 .58168 .72802 .57409 .73514 .5813 .73069 .55401 Mtetra
.855 .604 .558 r
.73069 .55401 .73514 .5813 .73946 .54381 .73398 .50019 Mtetra
.789 .545 .567 r
.73398 .50019 .73946 .54381 .74249 .48841 .73731 .44982 Mtetra
.76 .526 .579 r
.73731 .44982 .74249 .48841 .74588 .44143 .74147 .41471 Mtetra
.746 .529 .6 r
.74147 .41471 .74588 .44143 .75021 .41021 .74646 .39328 Mtetra
.74 .55 .636 r
.74646 .39328 .75021 .41021 .75533 .39153 .75202 .38071 Mtetra
.735 .586 .689 r
.75202 .38071 .75533 .39153 .76098 .38059 .75791 .37319 Mtetra
.726 .632 .753 r
.75791 .37319 .76098 .38059 .76692 .37395 .764 .36834 Mtetra
.712 .675 .812 r
.764 .36834 .76692 .37395 .77304 .36956 .7702 .36488 Mtetra
.696 .705 .854 r
.7702 .36488 .77304 .36956 .77925 .36633 .77646 .3621 Mtetra
.683 .723 .879 r
.77646 .3621 .77925 .36633 .78553 .3637 .78276 .35968 Mtetra
.674 .731 .892 r
.78276 .35968 .78553 .3637 .79184 .36135 .78909 .35744 Mtetra
.669 .735 .9 r
.78909 .35744 .79184 .36135 .79817 .35915 .79543 .3553 Mtetra
.666 .738 .904 r
.79543 .3553 .79817 .35915 .80452 .35702 .8018 .3532 Mtetra
.666 .74 .906 r
.8018 .3532 .80452 .35702 .81089 .35492 .80818 .35111 Mtetra
.665 .741 .906 r
.80818 .35111 .81089 .35492 .81728 .35285 .81458 .34903 Mtetra
.664 .74 .906 r
.81458 .34903 .81728 .35285 .82368 .35078 .82099 .34695 Mtetra
.664 .74 .907 r
.82099 .34695 .82368 .35078 .8301 .34871 .82742 .34488 Mtetra
.82742 .34488 .8301 .34871 .83653 .34663 .83386 .3428 Mtetra
.664 .741 .908 r
.83386 .3428 .83653 .34663 .84298 .34455 .84032 .34072 Mtetra
.84032 .34072 .84298 .34455 .84944 .34247 .84679 .33862 Mtetra
.664 .741 .907 r
.84679 .33862 .84944 .34247 .85591 .34039 .85327 .33653 Mtetra
.85327 .33653 .85591 .34039 .8624 .3383 .85977 .33443 Mtetra
.663 .741 .907 r
.85977 .33443 .8624 .3383 .8689 .3362 .86629 .33233 Mtetra
.664 .741 .908 r
.86629 .33233 .8689 .3362 .87542 .33411 .87281 .33022 Mtetra
.664 .741 .907 r
.87281 .33022 .87542 .33411 .88195 .332 .87936 .32811 Mtetra
.87936 .32811 .88195 .332 .8885 .32989 .88591 .32599 Mtetra
.88591 .32599 .8885 .32989 .89506 .32778 .89249 .32387 Mtetra
.89249 .32387 .89506 .32778 .90164 .32566 .89907 .32175 Mtetra
.30812 .5082 .31153 .51139 .31688 .50966 .31347 .50647 Mtetra
.31347 .50647 .31688 .50966 .32224 .50793 .31884 .50473 Mtetra
.31884 .50473 .32224 .50793 .3276 .5062 .32421 .503 Mtetra
.32421 .503 .3276 .5062 .33298 .50446 .3296 .50125 Mtetra
.3296 .50125 .33298 .50446 .33837 .50273 .33499 .4995 Mtetra
.33499 .4995 .33837 .50273 .34377 .50098 .3404 .49775 Mtetra
.3404 .49775 .34377 .50098 .34919 .49923 .34582 .496 Mtetra
.34582 .496 .34919 .49923 .35461 .49748 .35125 .49425 Mtetra
.35125 .49425 .35461 .49748 .36004 .49573 .35669 .49248 Mtetra
.35669 .49248 .36004 .49573 .36549 .49397 .36214 .49072 Mtetra
.36214 .49072 .36549 .49397 .37095 .49221 .36761 .48895 Mtetra
.36761 .48895 .37095 .49221 .37641 .49044 .37308 .48718 Mtetra
.37308 .48718 .37641 .49044 .38189 .48868 .37856 .48541 Mtetra
.37856 .48541 .38189 .48868 .38738 .48691 .38406 .48362 Mtetra
.38406 .48362 .38738 .48691 .39288 .48513 .38957 .48184 Mtetra
.38957 .48184 .39288 .48513 .3984 .48335 .39509 .48005 Mtetra
.39509 .48005 .3984 .48335 .40392 .48157 .40062 .47827 Mtetra
.40062 .47827 .40392 .48157 .40945 .47978 .40616 .47648 Mtetra
.40616 .47648 .40945 .47978 .415 .47799 .41172 .47467 Mtetra
.41172 .47467 .415 .47799 .42056 .4762 .41728 .47287 Mtetra
.41728 .47287 .42056 .4762 .42613 .4744 .42286 .47107 Mtetra
.42286 .47107 .42613 .4744 .43171 .4726 .42845 .46926 Mtetra
.42845 .46926 .43171 .4726 .4373 .47079 .43405 .46745 Mtetra
.43405 .46745 .4373 .47079 .44291 .46899 .43966 .46563 Mtetra
.43966 .46563 .44291 .46899 .44852 .46717 .44528 .46381 Mtetra
.44528 .46381 .44852 .46717 .45415 .46535 .45092 .46199 Mtetra
.45092 .46199 .45415 .46535 .45979 .46353 .45656 .46017 Mtetra
.45656 .46017 .45979 .46353 .46544 .46172 .46222 .45833 Mtetra
.664 .74 .907 r
.46222 .45833 .46544 .46172 .4711 .45989 .46789 .4565 Mtetra
.46789 .4565 .4711 .45989 .47678 .45805 .47357 .45466 Mtetra
.663 .741 .908 r
.47357 .45466 .47678 .45805 .48246 .45621 .47927 .45282 Mtetra
.664 .741 .908 r
.47927 .45282 .48246 .45621 .48816 .45438 .48497 .45098 Mtetra
.664 .741 .907 r
.48497 .45098 .48816 .45438 .49387 .45255 .49069 .44912 Mtetra
.664 .74 .907 r
.49069 .44912 .49387 .45255 .49959 .45069 .49642 .44727 Mtetra
.663 .74 .907 r
.49642 .44727 .49959 .45069 .50533 .44884 .50216 .44542 Mtetra
.663 .741 .908 r
.50216 .44542 .50533 .44884 .51107 .44699 .50791 .44357 Mtetra
.663 .742 .908 r
.50791 .44357 .51107 .44699 .51683 .44515 .51368 .44171 Mtetra
.663 .741 .908 r
.51368 .44171 .51683 .44515 .5226 .44332 .51946 .43986 Mtetra
.662 .739 .908 r
.51946 .43986 .5226 .44332 .52838 .44147 .52525 .43802 Mtetra
.659 .74 .909 r
.52525 .43802 .52838 .44147 .53418 .43963 .53105 .43621 Mtetra
.657 .741 .912 r
.53105 .43621 .53418 .43963 .53998 .43784 .53687 .43443 Mtetra
.654 .742 .914 r
.53687 .43443 .53998 .43784 .5458 .4361 .5427 .43269 Mtetra
.648 .739 .916 r
.5427 .43269 .5458 .4361 .55164 .43444 .54854 .43104 Mtetra
.635 .736 .922 r
.54854 .43104 .55164 .43444 .55749 .43288 .55439 .42956 Mtetra
.613 .734 .932 r
.55439 .42956 .55749 .43288 .56335 .43154 .56027 .42835 Mtetra
.575 .729 .947 r
.56027 .42835 .56335 .43154 .56923 .43055 .56616 .42754 Mtetra
.498 .71 .965 r
.56616 .42754 .56923 .43055 .57514 .43014 .57208 .42738 Mtetra
.326 .644 .967 r
.57208 .42738 .57514 .43014 .58108 .43061 .57804 .42829 Mtetra
0 .424 .834 r
.57804 .42829 .58108 .43061 .58707 .43246 .58404 .43084 Mtetra
.57 .009 0 r
.58404 .43084 .58707 .43246 .59313 .4364 .59013 .43581 Mtetra
.801 .311 .019 r
.59013 .43581 .59313 .4364 .59929 .44331 .59633 .44406 Mtetra
.859 .435 .216 r
.59633 .44406 .59929 .44331 .60559 .45398 .60267 .45623 Mtetra
.869 .482 .304 r
.60267 .45623 .60559 .45398 .61205 .4685 .60916 .47191 Mtetra
.861 .485 .334 r
.60916 .47191 .61205 .4685 .61865 .48522 .61576 .48855 Mtetra
.828 .432 .3 r
.61576 .48855 .61865 .48522 .62527 .4999 .62232 .50099 Mtetra
.54 0 0 r
.62232 .50099 .62527 .4999 .63171 .50673 .62865 .50366 Mtetra
.889 .803 .758 r
.62865 .50366 .63171 .50673 .6378 .5019 .63461 .49453 Mtetra
.877 .69 .646 r
.63461 .49453 .6378 .5019 .64353 .48681 .64026 .4769 Mtetra
.86 .658 .628 r
.64026 .4769 .64353 .48681 .64904 .46684 .64577 .45667 Mtetra
.846 .649 .637 r
.64577 .45667 .64904 .46684 .65451 .44744 .65131 .43854 Mtetra
.831 .654 .664 r
.65131 .43854 .65451 .44744 .66009 .4317 .65698 .42482 Mtetra
.806 .675 .718 r
.65698 .42482 .66009 .4317 .66583 .42065 .66283 .41616 Mtetra
.717 .716 .848 r
.66283 .41616 .66583 .42065 .67177 .41449 .66891 .41298 Mtetra
.359 0 0 r
.66891 .41298 .67177 .41449 .67796 .41369 .67532 .41656 Mtetra
.841 .435 .272 r
.67532 .41656 .67796 .41369 .68451 .41991 .68223 .42974 Mtetra
.85 .513 .416 r
.68223 .42974 .68451 .41991 .69164 .43656 .6899 .45674 Mtetra
.836 .526 .465 r
.6899 .45674 .69164 .43656 .69965 .46801 .69854 .49976 Mtetra
.804 .509 .488 r
.69854 .49976 .69965 .46801 .70864 .51476 .70774 .5496 Mtetra
.727 .443 .496 r
.70774 .5496 .70864 .51476 .71791 .56284 .71598 .57863 Mtetra
.029 0 .26 r
.71598 .57863 .71791 .56284 .72567 .58168 .72173 .56236 Mtetra
.885 .635 .555 r
.72173 .56236 .72567 .58168 .73069 .55401 .72541 .51228 Mtetra
.801 .554 .565 r
.72541 .51228 .73069 .55401 .73398 .50019 .72873 .45927 Mtetra
.766 .529 .575 r
.72873 .45927 .73398 .50019 .73731 .44982 .73274 .42014 Mtetra
.749 .527 .593 r
.73274 .42014 .73731 .44982 .74147 .41471 .7376 .39565 Mtetra
.742 .543 .625 r
.7376 .39565 .74147 .41471 .74646 .39328 .74306 .38122 Mtetra
.737 .576 .674 r
.74306 .38122 .74646 .39328 .75202 .38071 .7489 .37264 Mtetra
.73 .621 .737 r
.7489 .37264 .75202 .38071 .75791 .37319 .75495 .36722 Mtetra
.717 .666 .798 r
.75495 .36722 .75791 .37319 .764 .36834 .76113 .36345 Mtetra
.7 .698 .844 r
.76113 .36345 .764 .36834 .7702 .36488 .76737 .36053 Mtetra
.685 .717 .873 r
.76737 .36053 .7702 .36488 .77646 .3621 .77367 .35804 Mtetra
.676 .729 .89 r
.77367 .35804 .77646 .3621 .78276 .35968 .77999 .35577 Mtetra
.671 .736 .899 r
.77999 .35577 .78276 .35968 .78909 .35744 .78633 .35359 Mtetra
.668 .739 .903 r
.78633 .35359 .78909 .35744 .79543 .3553 .79269 .35146 Mtetra
.666 .739 .905 r
.79269 .35146 .79543 .3553 .8018 .3532 .79907 .34936 Mtetra
.664 .739 .905 r
.79907 .34936 .8018 .3532 .80818 .35111 .80546 .34728 Mtetra
.664 .74 .907 r
.80546 .34728 .80818 .35111 .81458 .34903 .81187 .34521 Mtetra
.664 .741 .908 r
.81187 .34521 .81458 .34903 .82099 .34695 .81829 .34313 Mtetra
.665 .742 .908 r
.81829 .34313 .82099 .34695 .82742 .34488 .82473 .34103 Mtetra
.664 .741 .907 r
.82473 .34103 .82742 .34488 .83386 .3428 .83118 .33894 Mtetra
.664 .74 .907 r
.83118 .33894 .83386 .3428 .84032 .34072 .83765 .33685 Mtetra
.83765 .33685 .84032 .34072 .84679 .33862 .84413 .33476 Mtetra
.664 .741 .908 r
.84413 .33476 .84679 .33862 .85327 .33653 .85063 .33266 Mtetra
.664 .742 .908 r
.85063 .33266 .85327 .33653 .85977 .33443 .85713 .33054 Mtetra
.664 .741 .907 r
.85713 .33054 .85977 .33443 .86629 .33233 .86366 .32843 Mtetra
.664 .74 .907 r
.86366 .32843 .86629 .33233 .87281 .33022 .8702 .32632 Mtetra
.8702 .32632 .87281 .33022 .87936 .32811 .87675 .3242 Mtetra
.664 .741 .908 r
.87675 .3242 .87936 .32811 .88591 .32599 .88332 .32208 Mtetra
.88332 .32208 .88591 .32599 .89249 .32387 .8899 .31994 Mtetra
.664 .741 .907 r
.8899 .31994 .89249 .32387 .89907 .32175 .8965 .31781 Mtetra
.30469 .505 .30812 .5082 .31347 .50647 .31005 .50326 Mtetra
.31005 .50326 .31347 .50647 .31884 .50473 .31542 .50152 Mtetra
.31542 .50152 .31884 .50473 .32421 .503 .3208 .49977 Mtetra
.664 .74 .907 r
.3208 .49977 .32421 .503 .3296 .50125 .3262 .49802 Mtetra
.664 .741 .907 r
.3262 .49802 .3296 .50125 .33499 .4995 .3316 .49627 Mtetra
.3316 .49627 .33499 .4995 .3404 .49775 .33701 .49452 Mtetra
.33701 .49452 .3404 .49775 .34582 .496 .34244 .49275 Mtetra
.34244 .49275 .34582 .496 .35125 .49425 .34788 .49099 Mtetra
.34788 .49099 .35125 .49425 .35669 .49248 .35332 .48922 Mtetra
.35332 .48922 .35669 .49248 .36214 .49072 .35878 .48745 Mtetra
.35878 .48745 .36214 .49072 .36761 .48895 .36425 .48568 Mtetra
.36425 .48568 .36761 .48895 .37308 .48718 .36973 .4839 Mtetra
.36973 .4839 .37308 .48718 .37856 .48541 .37523 .48212 Mtetra
.37523 .48212 .37856 .48541 .38406 .48362 .38073 .48033 Mtetra
.38073 .48033 .38406 .48362 .38957 .48184 .38625 .47854 Mtetra
.38625 .47854 .38957 .48184 .39509 .48005 .39177 .47675 Mtetra
.39177 .47675 .39509 .48005 .40062 .47827 .39731 .47495 Mtetra
.39731 .47495 .40062 .47827 .40616 .47648 .40286 .47315 Mtetra
.40286 .47315 .40616 .47648 .41172 .47467 .40842 .47135 Mtetra
.40842 .47135 .41172 .47467 .41728 .47287 .41399 .46954 Mtetra
.41399 .46954 .41728 .47287 .42286 .47107 .41958 .46773 Mtetra
.41958 .46773 .42286 .47107 .42845 .46926 .42517 .46591 Mtetra
.42517 .46591 .42845 .46926 .43405 .46745 .43078 .46409 Mtetra
.43078 .46409 .43405 .46745 .43966 .46563 .4364 .46227 Mtetra
.4364 .46227 .43966 .46563 .44528 .46381 .44203 .46045 Mtetra
.44203 .46045 .44528 .46381 .45092 .46199 .44767 .45862 Mtetra
.44767 .45862 .45092 .46199 .45656 .46017 .45332 .45678 Mtetra
.45332 .45678 .45656 .46017 .46222 .45833 .45899 .45494 Mtetra
.45899 .45494 .46222 .45833 .46789 .4565 .46467 .4531 Mtetra
.46467 .4531 .46789 .4565 .47357 .45466 .47036 .45126 Mtetra
.664 .741 .908 r
.47036 .45126 .47357 .45466 .47927 .45282 .47606 .44941 Mtetra
.664 .741 .907 r
.47606 .44941 .47927 .45282 .48497 .45098 .48177 .44755 Mtetra
.48177 .44755 .48497 .45098 .49069 .44912 .4875 .4457 Mtetra
.664 .741 .908 r
.4875 .4457 .49069 .44912 .49642 .44727 .49324 .44384 Mtetra
.663 .741 .908 r
.49324 .44384 .49642 .44727 .50216 .44542 .49898 .44198 Mtetra
.49898 .44198 .50216 .44542 .50791 .44357 .50475 .44012 Mtetra
.663 .74 .908 r
.50475 .44012 .50791 .44357 .51368 .44171 .51052 .43826 Mtetra
.662 .74 .908 r
.51052 .43826 .51368 .44171 .51946 .43986 .51631 .43641 Mtetra
.661 .741 .909 r
.51631 .43641 .51946 .43986 .52525 .43802 .5221 .43458 Mtetra
.659 .741 .91 r
.5221 .43458 .52525 .43802 .53105 .43621 .52791 .43276 Mtetra
.657 .74 .911 r
.52791 .43276 .53105 .43621 .53687 .43443 .53374 .43098 Mtetra
.652 .739 .914 r
.53374 .43098 .53687 .43443 .5427 .43269 .53957 .42927 Mtetra
.643 .739 .919 r
.53957 .42927 .5427 .43269 .54854 .43104 .54542 .42768 Mtetra
.628 .738 .926 r
.54542 .42768 .54854 .43104 .55439 .42956 .55129 .42628 Mtetra
.602 .734 .937 r
.55129 .42628 .55439 .42956 .56027 .42835 .55717 .42517 Mtetra
.553 .723 .953 r
.55717 .42517 .56027 .42835 .56616 .42754 .56308 .42457 Mtetra
.449 .692 .969 r
.56308 .42457 .56616 .42754 .57208 .42738 .56901 .42477 Mtetra
.209 .587 .945 r
.56901 .42477 .57208 .42738 .57804 .42829 .57498 .42622 Mtetra
0 .269 .69 r
.57498 .42622 .57804 .42829 .58404 .43084 .58101 .42957 Mtetra
.691 .15 0 r
.58101 .42957 .58404 .43084 .59013 .43581 .58712 .43566 Mtetra
.833 .372 .11 r
.58712 .43566 .59013 .43581 .59633 .44406 .59336 .44535 Mtetra
.866 .46 .257 r
.59336 .44535 .59633 .44406 .60267 .45623 .59974 .45902 Mtetra
.868 .488 .322 r
.59974 .45902 .60267 .45623 .60916 .47191 .60626 .47555 Mtetra
.852 .474 .333 r
.60626 .47555 .60916 .47191 .61576 .48855 .61284 .49133 Mtetra
.795 .373 .245 r
.61284 .49133 .61576 .48855 .62232 .50099 .61932 .50067 Mtetra
.446 .872 .927 r
.61932 .50067 .62232 .50099 .62865 .50366 .62552 .49888 Mtetra
.889 .741 .692 r
.62552 .49888 .62865 .50366 .63461 .49453 .63137 .48598 Mtetra
.871 .675 .635 r
.63137 .48598 .63461 .49453 .64026 .4769 .63699 .46672 Mtetra
.855 .654 .63 r
.63699 .46672 .64026 .4769 .64577 .45667 .64253 .44695 Mtetra
.84 .651 .646 r
.64253 .44695 .64577 .45667 .65131 .43854 .64814 .43057 Mtetra
.822 .662 .685 r
.64814 .43057 .65131 .43854 .65698 .42482 .65391 .41919 Mtetra
.776 .694 .773 r
.65391 .41919 .65698 .42482 .66283 .41616 .6599 .41345 Mtetra
.328 .651 .97 r
.6599 .41345 .66283 .41616 .66891 .41298 .66617 .41433 Mtetra
.817 .366 .164 r
.66617 .41433 .66891 .41298 .67532 .41656 .67288 .42414 Mtetra
.85 .502 .392 r
.67288 .42414 .67532 .41656 .68223 .42974 .68025 .44679 Mtetra
.841 .526 .456 r
.68025 .44679 .68223 .42974 .6899 .45674 .68853 .48554 Mtetra
.815 .516 .484 r
.68853 .48554 .6899 .45674 .69854 .49976 .69754 .53512 Mtetra
.756 .468 .496 r
.69754 .53512 .69854 .49976 .70774 .5496 .70611 .57223 Mtetra
.478 .215 .437 r
.70611 .57223 .70774 .5496 .71598 .57863 .71255 .56812 Mtetra
.926 .683 .55 r
.71255 .56812 .71598 .57863 .72173 .56236 .71673 .52417 Mtetra
.816 .567 .563 r
.71673 .52417 .72173 .56236 .72541 .51228 .72013 .46978 Mtetra
.773 .533 .572 r
.72013 .46978 .72541 .51228 .72873 .45927 .72403 .42665 Mtetra
.753 .526 .588 r
.72403 .42665 .72873 .45927 .73274 .42014 .72874 .39874 Mtetra
.744 .538 .615 r
.72874 .39874 .73274 .42014 .7376 .39565 .7341 .38212 Mtetra
.739 .567 .66 r
.7341 .38212 .7376 .39565 .74306 .38122 .73987 .3723 Mtetra
.733 .609 .719 r
.73987 .3723 .74306 .38122 .7489 .37264 .74589 .36623 Mtetra
.721 .654 .783 r
.74589 .36623 .7489 .37264 .75495 .36722 .75204 .36212 Mtetra
.705 .691 .834 r
.75204 .36212 .75495 .36722 .76113 .36345 .75827 .35901 Mtetra
.69 .715 .868 r
.75827 .35901 .76113 .36345 .76737 .36053 .76456 .35641 Mtetra
.679 .728 .887 r
.76456 .35641 .76737 .36053 .77367 .35804 .77087 .35407 Mtetra
.672 .733 .896 r
.77087 .35407 .77367 .35804 .77999 .35577 .77721 .35187 Mtetra
.668 .736 .901 r
.77721 .35187 .77999 .35577 .78633 .35359 .78356 .34974 Mtetra
.666 .739 .904 r
.78356 .34974 .78633 .35359 .79269 .35146 .78994 .34764 Mtetra
.665 .741 .906 r
.78994 .34764 .79269 .35146 .79907 .34936 .79633 .34554 Mtetra
.665 .741 .907 r
.79633 .34554 .79907 .34936 .80546 .34728 .80273 .34344 Mtetra
.664 .741 .907 r
.80273 .34344 .80546 .34728 .81187 .34521 .80915 .34135 Mtetra
.664 .74 .907 r
.80915 .34135 .81187 .34521 .81829 .34313 .81558 .33926 Mtetra
.663 .74 .907 r
.81558 .33926 .81829 .34313 .82473 .34103 .82203 .33718 Mtetra
.664 .741 .908 r
.82203 .33718 .82473 .34103 .83118 .33894 .82849 .33508 Mtetra
.664 .742 .908 r
.82849 .33508 .83118 .33894 .83765 .33685 .83497 .33298 Mtetra
.664 .741 .907 r
.83497 .33298 .83765 .33685 .84413 .33476 .84146 .33087 Mtetra
.664 .74 .907 r
.84146 .33087 .84413 .33476 .85063 .33266 .84797 .32876 Mtetra
.84797 .32876 .85063 .33266 .85713 .33054 .85449 .32664 Mtetra
.664 .741 .907 r
.85449 .32664 .85713 .33054 .86366 .32843 .86102 .32453 Mtetra
.664 .741 .908 r
.86102 .32453 .86366 .32843 .8702 .32632 .86757 .3224 Mtetra
.664 .741 .907 r
.86757 .3224 .8702 .32632 .87675 .3242 .87413 .32027 Mtetra
.87413 .32027 .87675 .3242 .88332 .32208 .88071 .31813 Mtetra
.664 .74 .907 r
.88071 .31813 .88332 .32208 .8899 .31994 .88731 .316 Mtetra
.664 .741 .907 r
.88731 .316 .8899 .31994 .8965 .31781 .89392 .31386 Mtetra
.30125 .50178 .30469 .505 .31005 .50326 .30662 .50004 Mtetra
.30662 .50004 .31005 .50326 .31542 .50152 .31199 .49829 Mtetra
.31199 .49829 .31542 .50152 .3208 .49977 .31738 .49654 Mtetra
.31738 .49654 .3208 .49977 .3262 .49802 .32278 .49478 Mtetra
.32278 .49478 .3262 .49802 .3316 .49627 .32819 .49302 Mtetra
.32819 .49302 .3316 .49627 .33701 .49452 .33361 .49126 Mtetra
.664 .74 .907 r
.33361 .49126 .33701 .49452 .34244 .49275 .33905 .4895 Mtetra
.664 .741 .907 r
.33905 .4895 .34244 .49275 .34788 .49099 .34449 .48773 Mtetra
.34449 .48773 .34788 .49099 .35332 .48922 .34994 .48595 Mtetra
.34994 .48595 .35332 .48922 .35878 .48745 .35541 .48417 Mtetra
.35541 .48417 .35878 .48745 .36425 .48568 .36089 .48239 Mtetra
.36089 .48239 .36425 .48568 .36973 .4839 .36637 .48061 Mtetra
.36637 .48061 .36973 .4839 .37523 .48212 .37187 .47882 Mtetra
.37187 .47882 .37523 .48212 .38073 .48033 .37739 .47702 Mtetra
.37739 .47702 .38073 .48033 .38625 .47854 .38291 .47523 Mtetra
.38291 .47523 .38625 .47854 .39177 .47675 .38844 .47343 Mtetra
.38844 .47343 .39177 .47675 .39731 .47495 .39399 .47163 Mtetra
.39399 .47163 .39731 .47495 .40286 .47315 .39954 .46982 Mtetra
.39954 .46982 .40286 .47315 .40842 .47135 .40511 .46801 Mtetra
.40511 .46801 .40842 .47135 .41399 .46954 .41069 .46619 Mtetra
.41069 .46619 .41399 .46954 .41958 .46773 .41628 .46437 Mtetra
.41628 .46437 .41958 .46773 .42517 .46591 .42188 .46255 Mtetra
.42188 .46255 .42517 .46591 .43078 .46409 .4275 .46073 Mtetra
.4275 .46073 .43078 .46409 .4364 .46227 .43313 .4589 Mtetra
.43313 .4589 .4364 .46227 .44203 .46045 .43876 .45706 Mtetra
.43876 .45706 .44203 .46045 .44767 .45862 .44441 .45522 Mtetra
.44441 .45522 .44767 .45862 .45332 .45678 .45007 .45339 Mtetra
.45007 .45339 .45332 .45678 .45899 .45494 .45575 .45154 Mtetra
.45575 .45154 .45899 .45494 .46467 .4531 .46143 .44969 Mtetra
.46143 .44969 .46467 .4531 .47036 .45126 .46713 .44784 Mtetra
.46713 .44784 .47036 .45126 .47606 .44941 .47284 .44598 Mtetra
.47284 .44598 .47606 .44941 .48177 .44755 .47856 .44412 Mtetra
.47856 .44412 .48177 .44755 .4875 .4457 .48429 .44226 Mtetra
.664 .741 .908 r
.48429 .44226 .4875 .4457 .49324 .44384 .49004 .4404 Mtetra
.663 .741 .908 r
.49004 .4404 .49324 .44384 .49898 .44198 .4958 .43853 Mtetra
.4958 .43853 .49898 .44198 .50475 .44012 .50157 .43667 Mtetra
.50157 .43667 .50475 .44012 .51052 .43826 .50735 .4348 Mtetra
.662 .741 .909 r
.50735 .4348 .51052 .43826 .51631 .43641 .51314 .43295 Mtetra
.66 .741 .909 r
.51314 .43295 .51631 .43641 .5221 .43458 .51895 .43111 Mtetra
.658 .74 .91 r
.51895 .43111 .5221 .43458 .52791 .43276 .52477 .42931 Mtetra
.655 .74 .912 r
.52477 .42931 .52791 .43276 .53374 .43098 .5306 .42755 Mtetra
.649 .74 .916 r
.5306 .42755 .53374 .43098 .53957 .42927 .53644 .42586 Mtetra
.639 .739 .921 r
.53644 .42586 .53957 .42927 .54542 .42768 .5423 .42432 Mtetra
.62 .736 .929 r
.5423 .42432 .54542 .42768 .55129 .42628 .54817 .42301 Mtetra
.587 .73 .942 r
.54817 .42301 .55129 .42628 .55717 .42517 .55407 .42207 Mtetra
.523 .716 .96 r
.55407 .42207 .55717 .42517 .56308 .42457 .55998 .42172 Mtetra
.382 .668 .971 r
.55998 .42172 .56308 .42457 .56901 .42477 .56593 .42231 Mtetra
.056 .501 .892 r
.56593 .42231 .56901 .42477 .57498 .42622 .57191 .42439 Mtetra
.464 0 0 r
.57191 .42439 .57498 .42622 .58101 .42957 .57797 .42867 Mtetra
.768 .258 0 r
.57797 .42867 .58101 .42957 .58712 .43566 .58411 .43604 Mtetra
.852 .415 .181 r
.58411 .43604 .58712 .43566 .59336 .44535 .59038 .44725 Mtetra
.869 .475 .29 r
.59038 .44725 .59336 .44535 .59974 .45902 .59679 .46225 Mtetra
.864 .488 .332 r
.59679 .46225 .59974 .45902 .60626 .47555 .60332 .47911 Mtetra
.84 .455 .319 r
.60332 .47911 .60626 .47555 .61284 .49133 .60987 .49324 Mtetra
.714 .235 .109 r
.60987 .49324 .61284 .49133 .61932 .50067 .61626 .49881 Mtetra
.866 .879 .845 r
.61626 .49881 .61932 .50067 .62552 .49888 .62234 .49254 Mtetra
.883 .708 .66 r
.62234 .49254 .62552 .49888 .63137 .48598 .62811 .47656 Mtetra
.864 .664 .63 r
.62811 .47656 .63137 .48598 .63699 .46672 .63371 .4566 Mtetra
.849 .652 .635 r
.63371 .4566 .63699 .46672 .64253 .44695 .63931 .43799 Mtetra
.834 .656 .661 r
.63931 .43799 .64253 .44695 .64814 .43057 .64501 .42377 Mtetra
.806 .677 .721 r
.64501 .42377 .64814 .43057 .65391 .41919 .65091 .41522 Mtetra
.66 .723 .896 r
.65091 .41522 .65391 .41919 .6599 .41345 .65706 .41328 Mtetra
.729 .202 0 r
.65706 .41328 .6599 .41345 .66617 .41433 .66359 .41981 Mtetra
.849 .483 .357 r
.66359 .41981 .66617 .41433 .67288 .42414 .6707 .43826 Mtetra
.844 .522 .444 r
.6707 .43826 .67288 .42414 .68025 .44679 .67863 .47235 Mtetra
.823 .52 .478 r
.67863 .47235 .68025 .44679 .68853 .48554 .68737 .51999 Mtetra
.777 .485 .494 r
.68737 .51999 .68853 .48554 .69754 .53512 .69609 .5629 Mtetra
.623 .346 .476 r
.69609 .5629 .69754 .53512 .70611 .57223 .70316 .57091 Mtetra
.984 .765 .527 r
.70316 .57091 .70611 .57223 .71255 .56812 .70791 .53528 Mtetra
.834 .584 .561 r
.70791 .53528 .71255 .56812 .71673 .52417 .71149 .48106 Mtetra
.782 .539 .569 r
.71149 .48106 .71673 .52417 .72013 .46978 .71531 .43422 Mtetra
.757 .526 .583 r
.71531 .43422 .72013 .46978 .72403 .42665 .71988 .40264 Mtetra
.746 .533 .607 r
.71988 .40264 .72403 .42665 .72874 .39874 .72514 .38355 Mtetra
.741 .558 .647 r
.72514 .38355 .72874 .39874 .7341 .38212 .73084 .37228 Mtetra
.736 .598 .703 r
.73084 .37228 .7341 .38212 .73987 .3723 .73682 .36539 Mtetra
.726 .644 .767 r
.73682 .36539 .73987 .3723 .74589 .36623 .74294 .36084 Mtetra
.71 .683 .822 r
.74294 .36084 .74589 .36623 .75204 .36212 .74916 .35751 Mtetra
.694 .709 .86 r
.74916 .35751 .75204 .36212 .75827 .35901 .75543 .3548 Mtetra
.681 .724 .882 r
.75543 .3548 .75827 .35901 .76456 .35641 .76174 .35241 Mtetra
.674 .733 .895 r
.76174 .35241 .76456 .35641 .77087 .35407 .76807 .35017 Mtetra
.67 .738 .901 r
.76807 .35017 .77087 .35407 .77721 .35187 .77442 .348 Mtetra
.667 .739 .904 r
.77442 .348 .77721 .35187 .78356 .34974 .78079 .34588 Mtetra
.665 .739 .905 r
.78079 .34588 .78356 .34974 .78994 .34764 .78717 .34378 Mtetra
.664 .739 .906 r
.78717 .34378 .78994 .34764 .79633 .34554 .79357 .34169 Mtetra
.664 .74 .907 r
.79357 .34169 .79633 .34554 .80273 .34344 .79999 .3396 Mtetra
.664 .741 .907 r
.79999 .3396 .80273 .34344 .80915 .34135 .80642 .3375 Mtetra
.664 .742 .908 r
.80642 .3375 .80915 .34135 .81558 .33926 .81286 .3354 Mtetra
.664 .741 .907 r
.81286 .3354 .81558 .33926 .82203 .33718 .81932 .3333 Mtetra
.664 .74 .907 r
.81932 .3333 .82203 .33718 .82849 .33508 .82579 .33119 Mtetra
.663 .74 .907 r
.82579 .33119 .82849 .33508 .83497 .33298 .83228 .32909 Mtetra
.664 .741 .908 r
.83228 .32909 .83497 .33298 .84146 .33087 .83878 .32698 Mtetra
.83878 .32698 .84146 .33087 .84797 .32876 .84529 .32485 Mtetra
.664 .741 .907 r
.84529 .32485 .84797 .32876 .85449 .32664 .85183 .32273 Mtetra
.85183 .32273 .85449 .32664 .86102 .32453 .85837 .3206 Mtetra
.664 .74 .907 r
.85837 .3206 .86102 .32453 .86757 .3224 .86493 .31846 Mtetra
.664 .741 .907 r
.86493 .31846 .86757 .3224 .87413 .32027 .87151 .31633 Mtetra
.664 .741 .908 r
.87151 .31633 .87413 .32027 .88071 .31813 .8781 .31418 Mtetra
.664 .741 .907 r
.8781 .31418 .88071 .31813 .88731 .316 .8847 .31203 Mtetra
.8847 .31203 .88731 .316 .89392 .31386 .89132 .30988 Mtetra
.2978 .49856 .30125 .50178 .30662 .50004 .30317 .49681 Mtetra
.30317 .49681 .30662 .50004 .31199 .49829 .30856 .49505 Mtetra
.30856 .49505 .31199 .49829 .31738 .49654 .31395 .49329 Mtetra
.31395 .49329 .31738 .49654 .32278 .49478 .31936 .49154 Mtetra
.664 .741 .908 r
.31936 .49154 .32278 .49478 .32819 .49302 .32477 .48977 Mtetra
.664 .741 .907 r
.32477 .48977 .32819 .49302 .33361 .49126 .3302 .48799 Mtetra
.3302 .48799 .33361 .49126 .33905 .4895 .33564 .48622 Mtetra
.33564 .48622 .33905 .4895 .34449 .48773 .34109 .48444 Mtetra
.34109 .48444 .34449 .48773 .34994 .48595 .34655 .48267 Mtetra
.664 .741 .908 r
.34655 .48267 .34994 .48595 .35541 .48417 .35202 .48089 Mtetra
.664 .741 .907 r
.35202 .48089 .35541 .48417 .36089 .48239 .35751 .47909 Mtetra
.35751 .47909 .36089 .48239 .36637 .48061 .363 .4773 Mtetra
.363 .4773 .36637 .48061 .37187 .47882 .36851 .4755 Mtetra
.36851 .4755 .37187 .47882 .37739 .47702 .37403 .47371 Mtetra
.663 .741 .908 r
.37403 .47371 .37739 .47702 .38291 .47523 .37956 .47191 Mtetra
.664 .741 .908 r
.37956 .47191 .38291 .47523 .38844 .47343 .3851 .4701 Mtetra
.664 .741 .907 r
.3851 .4701 .38844 .47343 .39399 .47163 .39065 .46829 Mtetra
.39065 .46829 .39399 .47163 .39954 .46982 .39621 .46647 Mtetra
.39621 .46647 .39954 .46982 .40511 .46801 .40179 .46465 Mtetra
.663 .741 .907 r
.40179 .46465 .40511 .46801 .41069 .46619 .40738 .46284 Mtetra
.664 .741 .908 r
.40738 .46284 .41069 .46619 .41628 .46437 .41297 .46101 Mtetra
.664 .741 .907 r
.41297 .46101 .41628 .46437 .42188 .46255 .41858 .45918 Mtetra
.41858 .45918 .42188 .46255 .4275 .46073 .42421 .45734 Mtetra
.42421 .45734 .4275 .46073 .43313 .4589 .42984 .45551 Mtetra
.663 .741 .907 r
.42984 .45551 .43313 .4589 .43876 .45706 .43549 .45367 Mtetra
.664 .741 .908 r
.43549 .45367 .43876 .45706 .44441 .45522 .44114 .45183 Mtetra
.664 .741 .907 r
.44114 .45183 .44441 .45522 .45007 .45339 .44681 .44997 Mtetra
.44681 .44997 .45007 .45339 .45575 .45154 .45249 .44812 Mtetra
.45249 .44812 .45575 .45154 .46143 .44969 .45819 .44627 Mtetra
.663 .741 .908 r
.45819 .44627 .46143 .44969 .46713 .44784 .46389 .44441 Mtetra
.664 .741 .908 r
.46389 .44441 .46713 .44784 .47284 .44598 .46961 .44255 Mtetra
.664 .741 .907 r
.46961 .44255 .47284 .44598 .47856 .44412 .47534 .44067 Mtetra
.664 .74 .907 r
.47534 .44067 .47856 .44412 .48429 .44226 .48108 .43881 Mtetra
.663 .74 .907 r
.48108 .43881 .48429 .44226 .49004 .4404 .48683 .43694 Mtetra
.663 .741 .908 r
.48683 .43694 .49004 .4404 .4958 .43853 .49259 .43507 Mtetra
.49259 .43507 .4958 .43853 .50157 .43667 .49837 .4332 Mtetra
.49837 .4332 .50157 .43667 .50735 .4348 .50416 .43133 Mtetra
.661 .74 .909 r
.50416 .43133 .50735 .4348 .51314 .43295 .50996 .42947 Mtetra
.659 .74 .91 r
.50996 .42947 .51314 .43295 .51895 .43111 .51578 .42765 Mtetra
.657 .74 .911 r
.51578 .42765 .51895 .43111 .52477 .42931 .5216 .42585 Mtetra
.653 .74 .913 r
.5216 .42585 .52477 .42931 .5306 .42755 .52744 .4241 Mtetra
.646 .739 .917 r
.52744 .4241 .5306 .42755 .53644 .42586 .5333 .42246 Mtetra
.633 .738 .924 r
.5333 .42246 .53644 .42586 .5423 .42432 .53916 .42099 Mtetra
.61 .735 .934 r
.53916 .42099 .5423 .42432 .54817 .42301 .54505 .41979 Mtetra
.568 .727 .949 r
.54505 .41979 .54817 .42301 .55407 .42207 .55095 .41903 Mtetra
.483 .704 .967 r
.55095 .41903 .55407 .42207 .55998 .42172 .55687 .41898 Mtetra
.289 .627 .962 r
.55687 .41898 .55998 .42172 .56593 .42231 .56283 .42006 Mtetra
0 .373 .788 r
.56283 .42006 .56593 .42231 .57191 .42439 .56884 .42287 Mtetra
.62 .064 0 r
.56884 .42287 .57191 .42439 .57797 .42867 .57491 .42821 Mtetra
.814 .335 .056 r
.57491 .42821 .57797 .42867 .58411 .43604 .58108 .43696 Mtetra
.862 .446 .233 r
.58108 .43696 .58411 .43604 .59038 .44725 .58739 .44971 Mtetra
.869 .485 .312 r
.58739 .44971 .59038 .44725 .59679 .46225 .59383 .46583 Mtetra
.858 .483 .336 r
.59383 .46583 .59679 .46225 .60332 .47911 .60036 .48239 Mtetra
.819 .418 .29 r
.60036 .48239 .60332 .47911 .60987 .49324 .60685 .49399 Mtetra
.355 0 0 r
.60685 .49399 .60987 .49324 .61626 .49881 .61313 .49525 Mtetra
.892 .782 .733 r
.61313 .49525 .61626 .49881 .62234 .49254 .61911 .48486 Mtetra
.876 .687 .643 r
.61911 .48486 .62234 .49254 .62811 .47656 .62483 .46673 Mtetra
.859 .659 .63 r
.62483 .46673 .62811 .47656 .63371 .4566 .63045 .4469 Mtetra
.844 .653 .644 r
.63045 .4469 .63371 .4566 .63931 .43799 .63612 .43004 Mtetra
.824 .664 .685 r
.63612 .43004 .63931 .43799 .64501 .42377 .64193 .41853 Mtetra
.763 .704 .795 r
.64193 .41853 .64501 .42377 .65091 .41522 .64798 .4136 Mtetra
0 .274 .662 r
.64798 .4136 .65091 .41522 .65706 .41328 .65435 .41681 Mtetra
.843 .449 .301 r
.65435 .41681 .65706 .41328 .66359 .41981 .66122 .43113 Mtetra
.846 .516 .428 r
.66122 .43113 .66359 .41981 .6707 .43826 .66882 .4604 Mtetra
.83 .523 .471 r
.66882 .4604 .6707 .43826 .67863 .47235 .67726 .50484 Mtetra
.793 .499 .49 r
.67726 .50484 .67863 .47235 .68737 .51999 .68598 .55121 Mtetra
.692 .408 .488 r
.68598 .55121 .68737 .51999 .69609 .5629 .69356 .5704 Mtetra
.897 .813 .338 r
.69356 .5704 .69609 .5629 .70316 .57091 .69892 .54488 Mtetra
.857 .607 .56 r
.69892 .54488 .70316 .57091 .70791 .53528 .70278 .49283 Mtetra
.792 .547 .567 r
.70278 .49283 .70791 .53528 .71149 .48106 .70658 .44291 Mtetra
.763 .528 .578 r
.70658 .44291 .71149 .48106 .71531 .43422 .71104 .40749 Mtetra
.749 .531 .599 r
.71104 .40749 .71531 .43422 .71988 .40264 .71618 .38556 Mtetra
.743 .551 .634 r
.71618 .38556 .71988 .40264 .72514 .38355 .72181 .37258 Mtetra
.738 .587 .687 r
.72181 .37258 .72514 .38355 .73084 .37228 .72773 .36475 Mtetra
.73 .632 .75 r
.72773 .36475 .73084 .37228 .73682 .36539 .73383 .3597 Mtetra
.715 .675 .809 r
.73383 .3597 .73682 .36539 .74294 .36084 .74003 .35609 Mtetra
.699 .705 .852 r
.74003 .35609 .74294 .36084 .74916 .35751 .74629 .35322 Mtetra
.685 .722 .878 r
.74629 .35322 .74916 .35751 .75543 .3548 .75259 .35074 Mtetra
.676 .731 .891 r
.75259 .35074 .75543 .3548 .76174 .35241 .75891 .34846 Mtetra
.67 .735 .899 r
.75891 .34846 .76174 .35241 .76807 .35017 .76526 .34628 Mtetra
.667 .738 .903 r
.76526 .34628 .76807 .35017 .77442 .348 .77162 .34415 Mtetra
.666 .74 .906 r
.77162 .34415 .77442 .348 .78079 .34588 .778 .34203 Mtetra
.665 .741 .907 r
.778 .34203 .78079 .34588 .78717 .34378 .7844 .33992 Mtetra
.7844 .33992 .78717 .34378 .79357 .34169 .79081 .33782 Mtetra
.664 .74 .907 r
.79081 .33782 .79357 .34169 .79999 .3396 .79723 .33572 Mtetra
.79723 .33572 .79999 .3396 .80642 .3375 .80367 .33363 Mtetra
.664 .741 .907 r
.80367 .33363 .80642 .3375 .81286 .3354 .81013 .33153 Mtetra
.664 .742 .908 r
.81013 .33153 .81286 .3354 .81932 .3333 .8166 .32941 Mtetra
.664 .741 .907 r
.8166 .32941 .81932 .3333 .82579 .33119 .82308 .32729 Mtetra
.82308 .32729 .82579 .33119 .83228 .32909 .82958 .32518 Mtetra
.664 .74 .907 r
.82958 .32518 .83228 .32909 .83878 .32698 .83609 .32305 Mtetra
.663 .74 .907 r
.83609 .32305 .83878 .32698 .84529 .32485 .84261 .32093 Mtetra
.664 .741 .908 r
.84261 .32093 .84529 .32485 .85183 .32273 .84916 .3188 Mtetra
.84916 .3188 .85183 .32273 .85837 .3206 .85571 .31665 Mtetra
.664 .741 .907 r
.85571 .31665 .85837 .3206 .86493 .31846 .86228 .31451 Mtetra
.86228 .31451 .86493 .31846 .87151 .31633 .86887 .31236 Mtetra
.664 .74 .907 r
.86887 .31236 .87151 .31633 .8781 .31418 .87547 .31021 Mtetra
.663 .741 .907 r
.87547 .31021 .8781 .31418 .8847 .31203 .88208 .30806 Mtetra
.664 .741 .908 r
.88208 .30806 .8847 .31203 .89132 .30988 .88871 .3059 Mtetra
.663 .74 .907 r
.29433 .49532 .2978 .49856 .30317 .49681 .29971 .49357 Mtetra
.664 .741 .908 r
.29971 .49357 .30317 .49681 .30856 .49505 .3051 .49181 Mtetra
.664 .741 .907 r
.3051 .49181 .30856 .49505 .31395 .49329 .3105 .49004 Mtetra
.3105 .49004 .31395 .49329 .31936 .49154 .31592 .48827 Mtetra
.31592 .48827 .31936 .49154 .32477 .48977 .32134 .48649 Mtetra
.664 .74 .907 r
.32134 .48649 .32477 .48977 .3302 .48799 .32677 .48472 Mtetra
.664 .741 .908 r
.32677 .48472 .3302 .48799 .33564 .48622 .33222 .48294 Mtetra
.664 .741 .907 r
.33222 .48294 .33564 .48622 .34109 .48444 .33768 .48115 Mtetra
.33768 .48115 .34109 .48444 .34655 .48267 .34315 .47937 Mtetra
.34315 .47937 .34655 .48267 .35202 .48089 .34863 .47758 Mtetra
.664 .74 .907 r
.34863 .47758 .35202 .48089 .35751 .47909 .35412 .47578 Mtetra
.663 .741 .907 r
.35412 .47578 .35751 .47909 .363 .4773 .35962 .47399 Mtetra
.664 .741 .908 r
.35962 .47399 .363 .4773 .36851 .4755 .36513 .47218 Mtetra
.664 .741 .907 r
.36513 .47218 .36851 .4755 .37403 .47371 .37066 .47037 Mtetra
.37066 .47037 .37403 .47371 .37956 .47191 .37619 .46856 Mtetra
.664 .74 .907 r
.37619 .46856 .37956 .47191 .3851 .4701 .38174 .46675 Mtetra
.663 .74 .907 r
.38174 .46675 .3851 .4701 .39065 .46829 .3873 .46494 Mtetra
.664 .741 .908 r
.3873 .46494 .39065 .46829 .39621 .46647 .39287 .46312 Mtetra
.664 .741 .907 r
.39287 .46312 .39621 .46647 .40179 .46465 .39845 .46129 Mtetra
.39845 .46129 .40179 .46465 .40738 .46284 .40405 .45946 Mtetra
.664 .74 .907 r
.40405 .45946 .40738 .46284 .41297 .46101 .40965 .45763 Mtetra
.40965 .45763 .41297 .46101 .41858 .45918 .41527 .4558 Mtetra
.664 .741 .908 r
.41527 .4558 .41858 .45918 .42421 .45734 .4209 .45396 Mtetra
.664 .741 .907 r
.4209 .45396 .42421 .45734 .42984 .45551 .42654 .45211 Mtetra
.42654 .45211 .42984 .45551 .43549 .45367 .4322 .45026 Mtetra
.664 .74 .907 r
.4322 .45026 .43549 .45367 .44114 .45183 .43786 .44841 Mtetra
.664 .741 .907 r
.43786 .44841 .44114 .45183 .44681 .44997 .44354 .44656 Mtetra
.664 .741 .908 r
.44354 .44656 .44681 .44997 .45249 .44812 .44922 .4447 Mtetra
.44922 .4447 .45249 .44812 .45819 .44627 .45493 .44283 Mtetra
.664 .741 .907 r
.45493 .44283 .45819 .44627 .46389 .44441 .46064 .44096 Mtetra
.664 .74 .907 r
.46064 .44096 .46389 .44441 .46961 .44255 .46636 .43909 Mtetra
.663 .74 .907 r
.46636 .43909 .46961 .44255 .47534 .44067 .4721 .43722 Mtetra
.663 .741 .908 r
.4721 .43722 .47534 .44067 .48108 .43881 .47785 .43535 Mtetra
.664 .742 .908 r
.47785 .43535 .48108 .43881 .48683 .43694 .48361 .43347 Mtetra
.664 .741 .907 r
.48361 .43347 .48683 .43694 .49259 .43507 .48938 .43159 Mtetra
.663 .74 .907 r
.48938 .43159 .49259 .43507 .49837 .4332 .49517 .42971 Mtetra
.662 .74 .908 r
.49517 .42971 .49837 .4332 .50416 .43133 .50096 .42785 Mtetra
.661 .741 .91 r
.50096 .42785 .50416 .43133 .50996 .42947 .50677 .426 Mtetra
.66 .741 .91 r
.50677 .426 .50996 .42947 .51578 .42765 .51259 .42416 Mtetra
.656 .74 .912 r
.51259 .42416 .51578 .42765 .5216 .42585 .51843 .42237 Mtetra
.65 .739 .914 r
.51843 .42237 .5216 .42585 .52744 .4241 .52428 .42066 Mtetra
.641 .738 .919 r
.52428 .42066 .52744 .4241 .5333 .42246 .53014 .41908 Mtetra
.626 .737 .927 r
.53014 .41908 .5333 .42246 .53916 .42099 .53601 .41769 Mtetra
.598 .733 .939 r
.53601 .41769 .53916 .42099 .54505 .41979 .5419 .41661 Mtetra
.544 .721 .955 r
.5419 .41661 .54505 .41979 .55095 .41903 .54782 .41608 Mtetra
.428 .684 .971 r
.54782 .41608 .55095 .41903 .55687 .41898 .55375 .41639 Mtetra
.158 .56 .93 r
.55375 .41639 .55687 .41898 .56283 .42006 .55972 .41805 Mtetra
0 .209 .629 r
.55972 .41805 .56283 .42006 .56884 .42287 .56575 .42171 Mtetra
.724 .193 0 r
.56575 .42171 .56884 .42287 .57491 .42821 .57184 .42823 Mtetra
.841 .39 .14 r
.57184 .42823 .57491 .42821 .58108 .43696 .57805 .43848 Mtetra
.868 .467 .272 r
.57805 .43848 .58108 .43696 .58739 .44971 .58438 .45272 Mtetra
.867 .489 .328 r
.58438 .45272 .58739 .44971 .59383 .46583 .59084 .46956 Mtetra
.849 .47 .332 r
.59084 .46956 .59383 .46583 .60036 .48239 .59735 .48503 Mtetra
.778 .344 .221 r
.59735 .48503 .60036 .48239 .60685 .49399 .60378 .49331 Mtetra
.688 .95 .956 r
.60378 .49331 .60685 .49399 .61313 .49525 .60995 .4901 Mtetra
.889 .733 .681 r
.60995 .4901 .61313 .49525 .61911 .48486 .61585 .47618 Mtetra
.87 .674 .635 r
.61585 .47618 .61911 .48486 .62483 .46673 .62155 .45684 Mtetra
.853 .656 .635 r
.62155 .45684 .62483 .46673 .63045 .4469 .62721 .43799 Mtetra
.837 .658 .66 r
.62721 .43799 .63045 .4469 .63612 .43004 .63297 .42352 Mtetra
.805 .683 .73 r
.63297 .42352 .63612 .43004 .64193 .41853 .63892 .41541 Mtetra
.495 .71 .966 r
.63892 .41541 .64193 .41853 .64798 .4136 .64516 .41524 Mtetra
.821 .381 .191 r
.64516 .41524 .64798 .4136 .65435 .41681 .65182 .42553 Mtetra
.848 .506 .406 r
.65182 .42553 .65435 .41681 .66122 .43113 .65912 .44994 Mtetra
.835 .524 .462 r
.65912 .44994 .66122 .43113 .66882 .4604 .66723 .49024 Mtetra
.805 .508 .486 r
.66723 .49024 .66882 .4604 .67726 .50484 .67583 .53768 Mtetra
.732 .445 .492 r
.67583 .53768 .67726 .50484 .68598 .55121 .68376 .56638 Mtetra
.076 0 .26 r
.68376 .56638 .68598 .55121 .69356 .5704 .68975 .55234 Mtetra
.886 .639 .559 r
.68975 .55234 .69356 .5704 .69892 .54488 .69399 .50472 Mtetra
.804 .557 .565 r
.69399 .50472 .69892 .54488 .70278 .49283 .69783 .45267 Mtetra
.769 .531 .575 r
.69783 .45267 .70278 .49283 .70658 .44291 .70219 .41334 Mtetra
.753 .529 .593 r
.70219 .41334 .70658 .44291 .71104 .40749 .70722 .38828 Mtetra
.745 .545 .624 r
.70722 .38828 .71104 .40749 .71618 .38556 .71277 .37332 Mtetra
.741 .577 .671 r
.71277 .37332 .71618 .38556 .72181 .37258 .71864 .36435 Mtetra
.734 .621 .733 r
.71864 .36435 .72181 .37258 .72773 .36475 .72471 .35866 Mtetra
.721 .665 .794 r
.72471 .35866 .72773 .36475 .73383 .3597 .73089 .35472 Mtetra
.703 .697 .841 r
.73089 .35472 .73383 .3597 .74003 .35609 .73714 .35168 Mtetra
.688 .718 .871 r
.73714 .35168 .74003 .35609 .74629 .35322 .74343 .34911 Mtetra
.678 .73 .889 r
.74343 .34911 .74629 .35322 .75259 .35074 .74974 .34678 Mtetra
.672 .736 .898 r
.74974 .34678 .75259 .35074 .75891 .34846 .75608 .34455 Mtetra
.669 .738 .902 r
.75608 .34455 .75891 .34846 .76526 .34628 .76244 .34239 Mtetra
.666 .739 .904 r
.76244 .34239 .76526 .34628 .77162 .34415 .76882 .34027 Mtetra
.665 .739 .905 r
.76882 .34027 .77162 .34415 .778 .34203 .77521 .33817 Mtetra
.664 .74 .907 r
.77521 .33817 .778 .34203 .7844 .33992 .78161 .33607 Mtetra
.664 .741 .907 r
.78161 .33607 .7844 .33992 .79081 .33782 .78803 .33396 Mtetra
.665 .742 .907 r
.78803 .33396 .79081 .33782 .79723 .33572 .79447 .33184 Mtetra
.664 .741 .907 r
.79447 .33184 .79723 .33572 .80367 .33363 .80092 .32973 Mtetra
.664 .74 .907 r
.80092 .32973 .80367 .33363 .81013 .33153 .80738 .32762 Mtetra
.663 .74 .907 r
.80738 .32762 .81013 .33153 .8166 .32941 .81386 .32551 Mtetra
.664 .741 .907 r
.81386 .32551 .8166 .32941 .82308 .32729 .82035 .32339 Mtetra
.664 .741 .908 r
.82035 .32339 .82308 .32729 .82958 .32518 .82686 .32125 Mtetra
.664 .741 .907 r
.82686 .32125 .82958 .32518 .83609 .32305 .83338 .31912 Mtetra
.83338 .31912 .83609 .32305 .84261 .32093 .83992 .31698 Mtetra
.664 .74 .907 r
.83992 .31698 .84261 .32093 .84916 .3188 .84647 .31484 Mtetra
.663 .74 .907 r
.84647 .31484 .84916 .3188 .85571 .31665 .85304 .3127 Mtetra
.664 .741 .908 r
.85304 .3127 .85571 .31665 .86228 .31451 .85962 .31055 Mtetra
.664 .741 .907 r
.85962 .31055 .86228 .31451 .86887 .31236 .86622 .30839 Mtetra
.86622 .30839 .86887 .31236 .87547 .31021 .87283 .30623 Mtetra
.87283 .30623 .87547 .31021 .88208 .30806 .87945 .30406 Mtetra
.664 .74 .907 r
.87945 .30406 .88208 .30806 .88871 .3059 .88609 .30189 Mtetra
.664 .741 .907 r
.29085 .49207 .29433 .49532 .29971 .49357 .29624 .49031 Mtetra
.664 .74 .907 r
.29624 .49031 .29971 .49357 .3051 .49181 .30164 .48854 Mtetra
.664 .741 .907 r
.30164 .48854 .3051 .49181 .3105 .49004 .30704 .48677 Mtetra
.30704 .48677 .3105 .49004 .31592 .48827 .31246 .48499 Mtetra
.31246 .48499 .31592 .48827 .32134 .48649 .31789 .48321 Mtetra
.31789 .48321 .32134 .48649 .32677 .48472 .32334 .48143 Mtetra
.32334 .48143 .32677 .48472 .33222 .48294 .32879 .47964 Mtetra
.664 .74 .907 r
.32879 .47964 .33222 .48294 .33768 .48115 .33425 .47785 Mtetra
.664 .741 .907 r
.33425 .47785 .33768 .48115 .34315 .47937 .33973 .47606 Mtetra
.33973 .47606 .34315 .47937 .34863 .47758 .34521 .47426 Mtetra
.34521 .47426 .34863 .47758 .35412 .47578 .35071 .47246 Mtetra
.35071 .47246 .35412 .47578 .35962 .47399 .35622 .47065 Mtetra
.664 .74 .907 r
.35622 .47065 .35962 .47399 .36513 .47218 .36174 .46884 Mtetra
.664 .741 .907 r
.36174 .46884 .36513 .47218 .37066 .47037 .36727 .46703 Mtetra
.36727 .46703 .37066 .47037 .37619 .46856 .37282 .46522 Mtetra
.37282 .46522 .37619 .46856 .38174 .46675 .37837 .46339 Mtetra
.37837 .46339 .38174 .46675 .3873 .46494 .38394 .46157 Mtetra
.664 .74 .907 r
.38394 .46157 .3873 .46494 .39287 .46312 .38952 .45974 Mtetra
.38952 .45974 .39287 .46312 .39845 .46129 .39511 .45791 Mtetra
.664 .741 .908 r
.39511 .45791 .39845 .46129 .40405 .45946 .40071 .45608 Mtetra
.664 .741 .907 r
.40071 .45608 .40405 .45946 .40965 .45763 .40632 .45423 Mtetra
.40632 .45423 .40965 .45763 .41527 .4558 .41195 .45239 Mtetra
.41195 .45239 .41527 .4558 .4209 .45396 .41758 .45054 Mtetra
.664 .74 .907 r
.41758 .45054 .4209 .45396 .42654 .45211 .42323 .44869 Mtetra
.664 .741 .908 r
.42323 .44869 .42654 .45211 .4322 .45026 .42889 .44684 Mtetra
.664 .741 .907 r
.42889 .44684 .4322 .45026 .43786 .44841 .43456 .44498 Mtetra
.43456 .44498 .43786 .44841 .44354 .44656 .44025 .44312 Mtetra
.44025 .44312 .44354 .44656 .44922 .4447 .44594 .44125 Mtetra
.664 .74 .907 r
.44594 .44125 .44922 .4447 .45493 .44283 .45165 .43938 Mtetra
.663 .741 .907 r
.45165 .43938 .45493 .44283 .46064 .44096 .45737 .43751 Mtetra
.664 .741 .908 r
.45737 .43751 .46064 .44096 .46636 .43909 .4631 .43563 Mtetra
.4631 .43563 .46636 .43909 .4721 .43722 .46885 .43375 Mtetra
.664 .741 .907 r
.46885 .43375 .4721 .43722 .47785 .43535 .47461 .43186 Mtetra
.663 .74 .907 r
.47461 .43186 .47785 .43535 .48361 .43347 .48037 .42998 Mtetra
.663 .74 .908 r
.48037 .42998 .48361 .43347 .48938 .43159 .48615 .42811 Mtetra
.663 .741 .909 r
.48615 .42811 .48938 .43159 .49517 .42971 .49195 .42623 Mtetra
.662 .741 .909 r
.49195 .42623 .49517 .42971 .50096 .42785 .49775 .42435 Mtetra
.661 .74 .909 r
.49775 .42435 .50096 .42785 .50677 .426 .50357 .4225 Mtetra
.658 .74 .91 r
.50357 .4225 .50677 .426 .51259 .42416 .5094 .42068 Mtetra
.654 .74 .913 r
.5094 .42068 .51259 .42416 .51843 .42237 .51524 .41891 Mtetra
.648 .74 .917 r
.51524 .41891 .51843 .42237 .52428 .42066 .5211 .41723 Mtetra
.637 .739 .922 r
.5211 .41723 .52428 .42066 .53014 .41908 .52697 .41569 Mtetra
.618 .736 .93 r
.52697 .41569 .53014 .41908 .53601 .41769 .53285 .4144 Mtetra
.582 .729 .944 r
.53285 .4144 .53601 .41769 .5419 .41661 .53875 .4135 Mtetra
.509 .711 .963 r
.53875 .4135 .5419 .41661 .54782 .41608 .54467 .41324 Mtetra
.35 .655 .97 r
.54467 .41324 .54782 .41608 .55375 .41639 .55062 .41399 Mtetra
0 .46 .861 r
.55062 .41399 .55375 .41639 .55972 .41805 .5566 .4163 Mtetra
.526 0 0 r
.5566 .4163 .55972 .41805 .56575 .42171 .56264 .42093 Mtetra
.789 .29 0 r
.56264 .42093 .56575 .42171 .57184 .42823 .56877 .4288 Mtetra
.857 .429 .205 r
.56877 .4288 .57184 .42823 .57805 .43848 .575 .44063 Mtetra
.869 .48 .302 r
.575 .44063 .57805 .43848 .58438 .45272 .58136 .45618 Mtetra
.862 .488 .338 r
.58136 .45618 .58438 .45272 .59084 .46956 .58783 .4732 Mtetra
.834 .447 .316 r
.58783 .4732 .59084 .46956 .59735 .48503 .59431 .48676 Mtetra
.661 .158 .041 r
.59431 .48676 .59735 .48503 .60378 .49331 .60065 .49108 Mtetra
.885 .851 .803 r
.60065 .49108 .60378 .49331 .60995 .4901 .60673 .4835 Mtetra
.883 .704 .655 r
.60673 .4835 .60995 .4901 .61585 .47618 .61257 .4669 Mtetra
.864 .666 .633 r
.61257 .4669 .61585 .47618 .62155 .45684 .61828 .44735 Mtetra
.848 .657 .644 r
.61828 .44735 .62155 .45684 .62721 .43799 .62401 .43027 Mtetra
.826 .669 .688 r
.62401 .43027 .62721 .43799 .63297 .42352 .62988 .41891 Mtetra
.734 .72 .838 r
.62988 .41891 .63297 .42352 .63892 .41541 .636 .41525 Mtetra
.719 .189 0 r
.636 .41525 .63892 .41541 .64516 .41524 .64248 .42152 Mtetra
.847 .488 .373 r
.64248 .42152 .64516 .41524 .65182 .42553 .64952 .4411 Mtetra
.839 .521 .451 r
.64952 .4411 .65182 .42553 .65912 .44994 .65729 .47663 Mtetra
.815 .514 .48 r
.65729 .47663 .65912 .44994 .66723 .49024 .66568 .52309 Mtetra
.76 .469 .492 r
.66568 .52309 .66723 .49024 .67583 .53768 .67382 .55898 Mtetra
.504 .229 .431 r
.67382 .55898 .67583 .53768 .68376 .56638 .68037 .55692 Mtetra
.928 .689 .557 r
.68037 .55692 .68376 .56638 .68975 .55234 .68508 .51615 Mtetra
.819 .571 .564 r
.68508 .51615 .68975 .55234 .69399 .50472 .68905 .46341 Mtetra
.777 .537 .572 r
.68905 .46341 .69399 .50472 .69783 .45267 .69334 .42033 Mtetra
.757 .529 .587 r
.69334 .42033 .69783 .45267 .70219 .41334 .69826 .39182 Mtetra
.748 .54 .614 r
.69826 .39182 .70219 .41334 .70722 .38828 .70372 .37455 Mtetra
.743 .568 .657 r
.70372 .37455 .70722 .38828 .71277 .37332 .70954 .36423 Mtetra
.737 .609 .715 r
.70954 .36423 .71277 .37332 .71864 .36435 .71558 .3578 Mtetra
.726 .654 .778 r
.71558 .3578 .71864 .36435 .72471 .35866 .72173 .35345 Mtetra
.709 .691 .83 r
.72173 .35345 .72471 .35866 .73089 .35472 .72797 .35019 Mtetra
.693 .714 .865 r
.72797 .35019 .73089 .35472 .73714 .35168 .73424 .34749 Mtetra
.681 .727 .885 r
.73424 .34749 .73714 .35168 .74343 .34911 .74055 .34509 Mtetra
.674 .733 .895 r
.74055 .34509 .74343 .34911 .74974 .34678 .74689 .34284 Mtetra
.669 .737 .901 r
.74689 .34284 .74974 .34678 .75608 .34455 .75324 .34066 Mtetra
.667 .739 .904 r
.75324 .34066 .75608 .34455 .76244 .34239 .75961 .33852 Mtetra
.666 .741 .906 r
.75961 .33852 .76244 .34239 .76882 .34027 .766 .3364 Mtetra
.665 .741 .907 r
.766 .3364 .76882 .34027 .77521 .33817 .7724 .33428 Mtetra
.664 .74 .907 r
.7724 .33428 .77521 .33817 .78161 .33607 .77882 .33217 Mtetra
.77882 .33217 .78161 .33607 .78803 .33396 .78525 .33006 Mtetra
.78525 .33006 .78803 .33396 .79447 .33184 .79169 .32795 Mtetra
.664 .741 .908 r
.79169 .32795 .79447 .33184 .80092 .32973 .79815 .32583 Mtetra
.664 .741 .907 r
.79815 .32583 .80092 .32973 .80738 .32762 .80463 .32371 Mtetra
.80463 .32371 .80738 .32762 .81386 .32551 .81111 .32158 Mtetra
.664 .74 .907 r
.81111 .32158 .81386 .32551 .82035 .32339 .81762 .31945 Mtetra
.81762 .31945 .82035 .32339 .82686 .32125 .82414 .31732 Mtetra
.664 .741 .907 r
.82414 .31732 .82686 .32125 .83338 .31912 .83067 .31518 Mtetra
.664 .741 .908 r
.83067 .31518 .83338 .31912 .83992 .31698 .83722 .31303 Mtetra
.664 .741 .907 r
.83722 .31303 .83992 .31698 .84647 .31484 .84378 .31088 Mtetra
.84378 .31088 .84647 .31484 .85304 .3127 .85036 .30872 Mtetra
.664 .74 .907 r
.85036 .30872 .85304 .3127 .85962 .31055 .85695 .30656 Mtetra
.85695 .30656 .85962 .31055 .86622 .30839 .86356 .3044 Mtetra
.664 .741 .908 r
.86356 .3044 .86622 .30839 .87283 .30623 .87018 .30223 Mtetra
.664 .741 .907 r
.87018 .30223 .87283 .30623 .87945 .30406 .87681 .30005 Mtetra
.87681 .30005 .87945 .30406 .88609 .30189 .88347 .29787 Mtetra
.28736 .48882 .29085 .49207 .29624 .49031 .29275 .48704 Mtetra
.29275 .48704 .29624 .49031 .30164 .48854 .29816 .48527 Mtetra
.29816 .48527 .30164 .48854 .30704 .48677 .30357 .48349 Mtetra
.664 .74 .907 r
.30357 .48349 .30704 .48677 .31246 .48499 .309 .48171 Mtetra
.664 .741 .907 r
.309 .48171 .31246 .48499 .31789 .48321 .31444 .47992 Mtetra
.31444 .47992 .31789 .48321 .32334 .48143 .31988 .47813 Mtetra
.31988 .47813 .32334 .48143 .32879 .47964 .32534 .47633 Mtetra
.32534 .47633 .32879 .47964 .33425 .47785 .33081 .47454 Mtetra
.33081 .47454 .33425 .47785 .33973 .47606 .3363 .47274 Mtetra
.664 .74 .907 r
.3363 .47274 .33973 .47606 .34521 .47426 .34179 .47093 Mtetra
.664 .741 .908 r
.34179 .47093 .34521 .47426 .35071 .47246 .34729 .46913 Mtetra
.664 .741 .907 r
.34729 .46913 .35071 .47246 .35622 .47065 .35281 .46731 Mtetra
.35281 .46731 .35622 .47065 .36174 .46884 .35834 .46549 Mtetra
.35834 .46549 .36174 .46884 .36727 .46703 .36388 .46367 Mtetra
.36388 .46367 .36727 .46703 .37282 .46522 .36943 .46185 Mtetra
.36943 .46185 .37282 .46522 .37837 .46339 .37499 .46003 Mtetra
.37499 .46003 .37837 .46339 .38394 .46157 .38056 .45819 Mtetra
.38056 .45819 .38394 .46157 .38952 .45974 .38615 .45636 Mtetra
.38615 .45636 .38952 .45974 .39511 .45791 .39175 .45452 Mtetra
.39175 .45452 .39511 .45791 .40071 .45608 .39736 .45267 Mtetra
.664 .74 .907 r
.39736 .45267 .40071 .45608 .40632 .45423 .40298 .45083 Mtetra
.664 .741 .908 r
.40298 .45083 .40632 .45423 .41195 .45239 .40861 .44898 Mtetra
.664 .741 .907 r
.40861 .44898 .41195 .45239 .41758 .45054 .41425 .44712 Mtetra
.41425 .44712 .41758 .45054 .42323 .44869 .41991 .44526 Mtetra
.41991 .44526 .42323 .44869 .42889 .44684 .42558 .4434 Mtetra
.664 .74 .907 r
.42558 .4434 .42889 .44684 .43456 .44498 .43126 .44154 Mtetra
.664 .741 .907 r
.43126 .44154 .43456 .44498 .44025 .44312 .43695 .43967 Mtetra
.43695 .43967 .44025 .44312 .44594 .44125 .44265 .43779 Mtetra
.44265 .43779 .44594 .44125 .45165 .43938 .44837 .43591 Mtetra
.44837 .43591 .45165 .43938 .45737 .43751 .45409 .43403 Mtetra
.664 .74 .907 r
.45409 .43403 .45737 .43751 .4631 .43563 .45983 .43215 Mtetra
.663 .74 .907 r
.45983 .43215 .4631 .43563 .46885 .43375 .46559 .43027 Mtetra
.664 .741 .908 r
.46559 .43027 .46885 .43375 .47461 .43186 .47135 .42838 Mtetra
.47135 .42838 .47461 .43186 .48037 .42998 .47713 .42649 Mtetra
.663 .741 .908 r
.47713 .42649 .48037 .42998 .48615 .42811 .48292 .4246 Mtetra
.662 .74 .908 r
.48292 .4246 .48615 .42811 .49195 .42623 .48872 .42272 Mtetra
.661 .74 .909 r
.48872 .42272 .49195 .42623 .49775 .42435 .49453 .42085 Mtetra
.66 .741 .91 r
.49453 .42085 .49775 .42435 .50357 .4225 .50035 .419 Mtetra
.657 .741 .912 r
.50035 .419 .50357 .4225 .5094 .42068 .50619 .41718 Mtetra
.652 .74 .914 r
.50619 .41718 .5094 .42068 .51524 .41891 .51204 .41544 Mtetra
.644 .739 .918 r
.51204 .41544 .51524 .41891 .5211 .41723 .51791 .4138 Mtetra
.631 .737 .925 r
.51791 .4138 .5211 .41723 .52697 .41569 .52378 .41234 Mtetra
.606 .734 .935 r
.52378 .41234 .52697 .41569 .53285 .4144 .52967 .41117 Mtetra
.56 .725 .951 r
.52967 .41117 .53285 .4144 .53875 .4135 .53558 .41047 Mtetra
.465 .698 .969 r
.53558 .41047 .53875 .4135 .54467 .41324 .54151 .41053 Mtetra
.246 .607 .954 r
.54151 .41053 .54467 .41324 .55062 .41399 .54747 .41179 Mtetra
0 .316 .736 r
.54747 .41179 .55062 .41399 .5566 .4163 .55347 .41488 Mtetra
.665 .117 0 r
.55347 .41488 .5566 .4163 .56264 .42093 .55953 .42065 Mtetra
.827 .36 .094 r
.55953 .42065 .56264 .42093 .56877 .4288 .56568 .42997 Mtetra
.865 .456 .252 r
.56568 .42997 .56877 .4288 .575 .44063 .57193 .44336 Mtetra
.868 .488 .322 r
.57193 .44336 .575 .44063 .58136 .45618 .57832 .45998 Mtetra
.855 .481 .34 r
.57832 .45998 .58136 .45618 .58783 .4732 .58478 .47651 Mtetra
.808 .402 .281 r
.58478 .47651 .58783 .4732 .59431 .48676 .59121 .4873 Mtetra
.094 0 0 r
.59121 .4873 .59431 .48676 .60065 .49108 .59747 .48724 Mtetra
.896 .771 .716 r
.59747 .48724 .60065 .49108 .60673 .4835 .60347 .47576 Mtetra
.876 .687 .642 r
.60347 .47576 .60673 .4835 .61257 .4669 .60928 .45747 Mtetra
.859 .663 .636 r
.60928 .45747 .61257 .4669 .61828 .44735 .61503 .4387 Mtetra
.84 .663 .662 r
.61503 .4387 .61828 .44735 .62401 .43027 .62085 .42425 Mtetra
.8 .694 .748 r
.62085 .42425 .62401 .43027 .62988 .41891 .62687 .41698 Mtetra
0 .456 .83 r
.62687 .41698 .62988 .41891 .636 .41525 .63319 .4192 Mtetra
.841 .453 .315 r
.63319 .4192 .636 .41525 .64248 .42152 .63999 .43397 Mtetra
.842 .516 .436 r
.63999 .43397 .64248 .42152 .64952 .4411 .64745 .46433 Mtetra
.823 .518 .474 r
.64745 .46433 .64952 .4411 .65729 .47663 .65558 .50812 Mtetra
.78 .486 .489 r
.65558 .50812 .65729 .47663 .66568 .52309 .66377 .54875 Mtetra
.64 .354 .47 r
.66377 .54875 .66568 .52309 .67382 .55898 .6708 .55824 Mtetra
.986 .779 .541 r
.6708 .55824 .67382 .55898 .68037 .55692 .67602 .52642 Mtetra
.837 .589 .563 r
.67602 .52642 .68037 .55692 .68508 .51615 .68021 .47481 Mtetra
.786 .543 .569 r
.68021 .47481 .68508 .51615 .68905 .46341 .68448 .42845 Mtetra
.762 .53 .582 r
.68448 .42845 .68905 .46341 .69334 .42033 .68931 .39628 Mtetra
.751 .537 .605 r
.68931 .39628 .69334 .42033 .69826 .39182 .69468 .37639 Mtetra
.746 .56 .644 r
.69468 .37639 .69826 .39182 .70372 .37455 .70044 .36448 Mtetra
.741 .599 .698 r
.70044 .36448 .70372 .37455 .70954 .36423 .70643 .35714 Mtetra
.731 .644 .761 r
.70643 .35714 .70954 .36423 .71558 .3578 .71256 .35229 Mtetra
.715 .682 .817 r
.71256 .35229 .71558 .3578 .72173 .35345 .71878 .34876 Mtetra
.698 .709 .856 r
.71878 .34876 .72173 .35345 .72797 .35019 .72505 .34592 Mtetra
.685 .724 .88 r
.72505 .34592 .72797 .35019 .73424 .34749 .73135 .34343 Mtetra
.676 .733 .893 r
.73135 .34343 .73424 .34749 .74055 .34509 .73768 .34113 Mtetra
.671 .737 .9 r
.73768 .34113 .74055 .34509 .74689 .34284 .74403 .33892 Mtetra
.668 .739 .903 r
.74403 .33892 .74689 .34284 .75324 .34066 .75039 .33676 Mtetra
.666 .739 .905 r
.75039 .33676 .75324 .34066 .75961 .33852 .75677 .33463 Mtetra
.665 .74 .906 r
.75677 .33463 .75961 .33852 .766 .3364 .76317 .33252 Mtetra
.664 .741 .907 r
.76317 .33252 .766 .3364 .7724 .33428 .76958 .3304 Mtetra
.76958 .3304 .7724 .33428 .77882 .33217 .77601 .32828 Mtetra
.77601 .32828 .77882 .33217 .78525 .33006 .78245 .32615 Mtetra
.664 .74 .907 r
.78245 .32615 .78525 .33006 .79169 .32795 .7889 .32403 Mtetra
.7889 .32403 .79169 .32795 .79815 .32583 .79537 .32191 Mtetra
.664 .741 .907 r
.79537 .32191 .79815 .32583 .80463 .32371 .80186 .31978 Mtetra
.664 .741 .908 r
.80186 .31978 .80463 .32371 .81111 .32158 .80836 .31764 Mtetra
.664 .741 .907 r
.80836 .31764 .81111 .32158 .81762 .31945 .81487 .3155 Mtetra
.81487 .3155 .81762 .31945 .82414 .31732 .8214 .31336 Mtetra
.664 .74 .907 r
.8214 .31336 .82414 .31732 .83067 .31518 .82794 .31121 Mtetra
.82794 .31121 .83067 .31518 .83722 .31303 .8345 .30906 Mtetra
.664 .741 .907 r
.8345 .30906 .83722 .31303 .84378 .31088 .84108 .3069 Mtetra
.84108 .3069 .84378 .31088 .85036 .30872 .84766 .30473 Mtetra
.84766 .30473 .85036 .30872 .85695 .30656 .85427 .30256 Mtetra
.85427 .30256 .85695 .30656 .86356 .3044 .86088 .30038 Mtetra
.664 .74 .907 r
.86088 .30038 .86356 .3044 .87018 .30223 .86752 .29821 Mtetra
.86752 .29821 .87018 .30223 .87681 .30005 .87416 .29603 Mtetra
.664 .741 .908 r
.87416 .29603 .87681 .30005 .88347 .29787 .88083 .29383 Mtetra
.663 .741 .907 r
.28386 .48554 .28736 .48882 .29275 .48704 .28926 .48377 Mtetra
.664 .741 .908 r
.28926 .48377 .29275 .48704 .29816 .48527 .29467 .48198 Mtetra
.664 .741 .907 r
.29467 .48198 .29816 .48527 .30357 .48349 .30009 .48019 Mtetra
.30009 .48019 .30357 .48349 .309 .48171 .30552 .4784 Mtetra
.30552 .4784 .309 .48171 .31444 .47992 .31096 .47661 Mtetra
.664 .74 .907 r
.31096 .47661 .31444 .47992 .31988 .47813 .31642 .47482 Mtetra
.664 .741 .908 r
.31642 .47482 .31988 .47813 .32534 .47633 .32189 .47302 Mtetra
.664 .741 .907 r
.32189 .47302 .32534 .47633 .33081 .47454 .32736 .47121 Mtetra
.32736 .47121 .33081 .47454 .3363 .47274 .33285 .4694 Mtetra
.33285 .4694 .3363 .47274 .34179 .47093 .33835 .46759 Mtetra
.33835 .46759 .34179 .47093 .34729 .46913 .34386 .46577 Mtetra
.664 .74 .907 r
.34386 .46577 .34729 .46913 .35281 .46731 .34939 .46396 Mtetra
.664 .741 .908 r
.34939 .46396 .35281 .46731 .35834 .46549 .35492 .46214 Mtetra
.664 .741 .907 r
.35492 .46214 .35834 .46549 .36388 .46367 .36047 .4603 Mtetra
.36047 .4603 .36388 .46367 .36943 .46185 .36603 .45847 Mtetra
.36603 .45847 .36943 .46185 .37499 .46003 .3716 .45664 Mtetra
.3716 .45664 .37499 .46003 .38056 .45819 .37718 .4548 Mtetra
.37718 .4548 .38056 .45819 .38615 .45636 .38277 .45296 Mtetra
.664 .741 .908 r
.38277 .45296 .38615 .45636 .39175 .45452 .38837 .45112 Mtetra
.664 .741 .907 r
.38837 .45112 .39175 .45452 .39736 .45267 .39399 .44926 Mtetra
.39399 .44926 .39736 .45267 .40298 .45083 .39962 .44741 Mtetra
.39962 .44741 .40298 .45083 .40861 .44898 .40526 .44555 Mtetra
.664 .74 .907 r
.40526 .44555 .40861 .44898 .41425 .44712 .41091 .44369 Mtetra
.664 .741 .908 r
.41091 .44369 .41425 .44712 .41991 .44526 .41657 .44183 Mtetra
.664 .741 .907 r
.41657 .44183 .41991 .44526 .42558 .4434 .42225 .43996 Mtetra
.42225 .43996 .42558 .4434 .43126 .44154 .42793 .43808 Mtetra
.42793 .43808 .43126 .44154 .43695 .43967 .43363 .4362 Mtetra
.664 .74 .907 r
.43363 .4362 .43695 .43967 .44265 .43779 .43934 .43432 Mtetra
.663 .741 .907 r
.43934 .43432 .44265 .43779 .44837 .43591 .44507 .43245 Mtetra
.664 .741 .908 r
.44507 .43245 .44837 .43591 .45409 .43403 .4508 .43056 Mtetra
.4508 .43056 .45409 .43403 .45983 .43215 .45655 .42866 Mtetra
.664 .741 .907 r
.45655 .42866 .45983 .43215 .46559 .43027 .46231 .42676 Mtetra
.663 .74 .907 r
.46231 .42676 .46559 .43027 .47135 .42838 .46808 .42487 Mtetra
.663 .74 .908 r
.46808 .42487 .47135 .42838 .47713 .42649 .47387 .42299 Mtetra
.663 .741 .908 r
.47387 .42299 .47713 .42649 .48292 .4246 .47966 .4211 Mtetra
.663 .742 .909 r
.47966 .4211 .48292 .4246 .48872 .42272 .48547 .4192 Mtetra
.661 .741 .909 r
.48547 .4192 .48872 .42272 .49453 .42085 .49129 .41732 Mtetra
.659 .74 .91 r
.49129 .41732 .49453 .42085 .50035 .419 .49713 .41548 Mtetra
.655 .739 .912 r
.49713 .41548 .50035 .419 .50619 .41718 .50297 .4137 Mtetra
.649 .74 .916 r
.50297 .4137 .50619 .41718 .51204 .41544 .50883 .41198 Mtetra
.64 .74 .921 r
.50883 .41198 .51204 .41544 .51791 .4138 .5147 .41038 Mtetra
.624 .737 .928 r
.5147 .41038 .51791 .4138 .52378 .41234 .52059 .409 Mtetra
.593 .731 .94 r
.52059 .409 .52378 .41234 .52967 .41117 .52649 .40798 Mtetra
.532 .717 .958 r
.52649 .40798 .52967 .41117 .53558 .41047 .5324 .40753 Mtetra
.401 .675 .972 r
.5324 .40753 .53558 .41047 .54151 .41053 .53834 .40799 Mtetra
.1 .528 .91 r
.53834 .40799 .54151 .41053 .54747 .41179 .54431 .40985 Mtetra
.418 0 0 r
.54431 .40985 .54747 .41179 .55347 .41488 .55032 .41384 Mtetra
.754 .236 0 r
.55032 .41384 .55347 .41488 .55953 .42065 .5564 .42088 Mtetra
.849 .409 .171 r
.5564 .42088 .55953 .42065 .56568 .42997 .56257 .43179 Mtetra
.869 .474 .289 r
.56257 .43179 .56568 .42997 .57193 .44336 .56885 .4467 Mtetra
.865 .491 .337 r
.56885 .4467 .57193 .44336 .57832 .45998 .57525 .46394 Mtetra
.844 .466 .335 r
.57525 .46394 .57832 .45998 .58478 .47651 .5817 .47917 Mtetra
.755 .313 .2 r
.5817 .47917 .58478 .47651 .59121 .4873 .58807 .48644 Mtetra
.798 .953 .919 r
.58807 .48644 .59121 .4873 .59747 .48724 .59425 .48194 Mtetra
.892 .73 .674 r
.59425 .48194 .59747 .48724 .60347 .47576 .6002 .4673 Mtetra
.87 .677 .638 r
.6002 .4673 .60347 .47576 .60928 .45747 .606 .44841 Mtetra
.852 .663 .646 r
.606 .44841 .60928 .45747 .61503 .4387 .61181 .43145 Mtetra
.828 .678 .696 r
.61181 .43145 .61503 .4387 .62085 .42425 .61775 .42061 Mtetra
.655 .744 .915 r
.61775 .42061 .62085 .42425 .62687 .41698 .62395 .41871 Mtetra
.815 .373 .192 r
.62395 .41871 .62687 .41698 .63319 .4192 .63054 .42865 Mtetra
.843 .505 .413 r
.63054 .42865 .63319 .4192 .63999 .43397 .63771 .4536 Mtetra
.829 .519 .465 r
.63771 .4536 .63999 .43397 .64745 .46433 .64554 .49344 Mtetra
.796 .498 .485 r
.64554 .49344 .64745 .46433 .65558 .50812 .65367 .53635 Mtetra
.704 .414 .481 r
.65367 .53635 .65558 .50812 .66377 .54875 .66105 .55606 Mtetra
.849 .817 .334 r
.66105 .55606 .66377 .54875 .6708 .55824 .6668 .53474 Mtetra
.86 .613 .564 r
.6668 .53474 .6708 .55824 .67602 .52642 .67129 .48641 Mtetra
.796 .552 .568 r
.67129 .48641 .67602 .52642 .68021 .47481 .67559 .43768 Mtetra
.768 .533 .578 r
.67559 .43768 .68021 .47481 .68448 .42845 .68035 .4018 Mtetra
.755 .535 .598 r
.68035 .4018 .68448 .42845 .68931 .39628 .68564 .37897 Mtetra
.749 .554 .632 r
.68564 .37897 .68931 .39628 .69468 .37639 .69133 .36517 Mtetra
.745 .589 .682 r
.69133 .36517 .69468 .37639 .70044 .36448 .69728 .35674 Mtetra
.736 .632 .743 r
.69728 .35674 .70044 .36448 .70643 .35714 .70338 .35129 Mtetra
.721 .673 .802 r
.70338 .35129 .70643 .35714 .71256 .35229 .70958 .34742 Mtetra
.704 .703 .846 r
.70958 .34742 .71256 .35229 .71878 .34876 .71584 .34439 Mtetra
.689 .721 .874 r
.71584 .34439 .71878 .34876 .72505 .34592 .72213 .3418 Mtetra
.679 .731 .889 r
.72213 .3418 .72505 .34592 .73135 .34343 .72845 .33943 Mtetra
.672 .735 .898 r
.72845 .33943 .73135 .34343 .73768 .34113 .73479 .33719 Mtetra
.669 .738 .902 r
.73479 .33719 .73768 .34113 .74403 .33892 .74115 .33502 Mtetra
.666 .74 .905 r
.74115 .33502 .74403 .33892 .75039 .33676 .74753 .33287 Mtetra
.665 .74 .906 r
.74753 .33287 .75039 .33676 .75677 .33463 .75392 .33074 Mtetra
.665 .741 .907 r
.75392 .33074 .75677 .33463 .76317 .33252 .76033 .32861 Mtetra
.664 .74 .907 r
.76033 .32861 .76317 .33252 .76958 .3304 .76675 .32649 Mtetra
.76675 .32649 .76958 .3304 .77601 .32828 .77319 .32437 Mtetra
.664 .741 .907 r
.77319 .32437 .77601 .32828 .78245 .32615 .77964 .32224 Mtetra
.664 .741 .908 r
.77964 .32224 .78245 .32615 .7889 .32403 .7861 .32011 Mtetra
.664 .741 .907 r
.7861 .32011 .7889 .32403 .79537 .32191 .79258 .31797 Mtetra
.79258 .31797 .79537 .32191 .80186 .31978 .79908 .31583 Mtetra
.664 .74 .907 r
.79908 .31583 .80186 .31978 .80836 .31764 .80559 .31369 Mtetra
.664 .741 .907 r
.80559 .31369 .80836 .31764 .81487 .3155 .81211 .31154 Mtetra
.664 .741 .908 r
.81211 .31154 .81487 .3155 .8214 .31336 .81865 .30939 Mtetra
.664 .741 .907 r
.81865 .30939 .8214 .31336 .82794 .31121 .82521 .30722 Mtetra
.82521 .30722 .82794 .31121 .8345 .30906 .83178 .30506 Mtetra
.664 .74 .907 r
.83178 .30506 .8345 .30906 .84108 .3069 .83836 .30289 Mtetra
.83836 .30289 .84108 .3069 .84766 .30473 .84496 .30072 Mtetra
.664 .741 .908 r
.84496 .30072 .84766 .30473 .85427 .30256 .85157 .29855 Mtetra
.85157 .29855 .85427 .30256 .86088 .30038 .8582 .29636 Mtetra
.664 .741 .907 r
.8582 .29636 .86088 .30038 .86752 .29821 .86484 .29417 Mtetra
.86484 .29417 .86752 .29821 .87416 .29603 .8715 .29198 Mtetra
.664 .74 .907 r
.8715 .29198 .87416 .29603 .88083 .29383 .87818 .28978 Mtetra
.664 .741 .907 r
.28034 .48225 .28386 .48554 .28926 .48377 .28574 .48047 Mtetra
.664 .74 .907 r
.28574 .48047 .28926 .48377 .29467 .48198 .29116 .47868 Mtetra
.664 .741 .907 r
.29116 .47868 .29467 .48198 .30009 .48019 .29659 .47689 Mtetra
.29659 .47689 .30009 .48019 .30552 .4784 .30203 .47509 Mtetra
.30203 .47509 .30552 .4784 .31096 .47661 .30748 .47329 Mtetra
.30748 .47329 .31096 .47661 .31642 .47482 .31294 .47149 Mtetra
.31294 .47149 .31642 .47482 .32189 .47302 .31841 .46968 Mtetra
.664 .74 .907 r
.31841 .46968 .32189 .47302 .32736 .47121 .3239 .46787 Mtetra
.664 .741 .908 r
.3239 .46787 .32736 .47121 .33285 .4694 .32939 .46606 Mtetra
.664 .741 .907 r
.32939 .46606 .33285 .4694 .33835 .46759 .3349 .46423 Mtetra
.3349 .46423 .33835 .46759 .34386 .46577 .34042 .46241 Mtetra
.34042 .46241 .34386 .46577 .34939 .46396 .34595 .46059 Mtetra
.664 .74 .907 r
.34595 .46059 .34939 .46396 .35492 .46214 .35149 .45875 Mtetra
.663 .74 .907 r
.35149 .45875 .35492 .46214 .36047 .4603 .35705 .45693 Mtetra
.664 .741 .908 r
.35705 .45693 .36047 .4603 .36603 .45847 .36261 .45509 Mtetra
.664 .741 .907 r
.36261 .45509 .36603 .45847 .3716 .45664 .36819 .45324 Mtetra
.36819 .45324 .3716 .45664 .37718 .4548 .37378 .4514 Mtetra
.37378 .4514 .37718 .4548 .38277 .45296 .37938 .44955 Mtetra
.664 .74 .907 r
.37938 .44955 .38277 .45296 .38837 .45112 .38499 .4477 Mtetra
.664 .741 .907 r
.38499 .4477 .38837 .45112 .39399 .44926 .39061 .44584 Mtetra
.39061 .44584 .39399 .44926 .39962 .44741 .39625 .44398 Mtetra
.39625 .44398 .39962 .44741 .40526 .44555 .40189 .44211 Mtetra
.40189 .44211 .40526 .44555 .41091 .44369 .40755 .44024 Mtetra
.40755 .44024 .41091 .44369 .41657 .44183 .41322 .43837 Mtetra
.664 .74 .907 r
.41322 .43837 .41657 .44183 .42225 .43996 .41891 .4365 Mtetra
.664 .741 .907 r
.41891 .4365 .42225 .43996 .42793 .43808 .4246 .43462 Mtetra
.4246 .43462 .42793 .43808 .43363 .4362 .43031 .43273 Mtetra
.43031 .43273 .43363 .4362 .43934 .43432 .43603 .43084 Mtetra
.43603 .43084 .43934 .43432 .44507 .43245 .44176 .42895 Mtetra
.664 .74 .907 r
.44176 .42895 .44507 .43245 .4508 .43056 .4475 .42705 Mtetra
.663 .74 .907 r
.4475 .42705 .4508 .43056 .45655 .42866 .45326 .42516 Mtetra
.664 .741 .908 r
.45326 .42516 .45655 .42866 .46231 .42676 .45902 .42326 Mtetra
.664 .742 .908 r
.45902 .42326 .46231 .42676 .46808 .42487 .4648 .42135 Mtetra
.663 .741 .908 r
.4648 .42135 .46808 .42487 .47387 .42299 .47059 .41945 Mtetra
.662 .74 .908 r
.47059 .41945 .47387 .42299 .47966 .4211 .4764 .41756 Mtetra
.661 .74 .908 r
.4764 .41756 .47966 .4211 .48547 .4192 .48222 .41568 Mtetra
.66 .741 .91 r
.48222 .41568 .48547 .4192 .49129 .41732 .48804 .41381 Mtetra
.658 .741 .911 r
.48804 .41381 .49129 .41732 .49713 .41548 .49389 .41197 Mtetra
.654 .741 .913 r
.49389 .41197 .49713 .41548 .50297 .4137 .49974 .41019 Mtetra
.647 .739 .916 r
.49974 .41019 .50297 .4137 .50883 .41198 .50561 .4085 Mtetra
.635 .737 .922 r
.50561 .4085 .50883 .41198 .5147 .41038 .51148 .40698 Mtetra
.613 .735 .932 r
.51148 .40698 .5147 .41038 .52059 .409 .51738 .40572 Mtetra
.574 .729 .947 r
.51738 .40572 .52059 .409 .52649 .40798 .52328 .40488 Mtetra
.495 .709 .966 r
.52328 .40488 .52649 .40798 .5324 .40753 .52921 .4047 Mtetra
.317 .641 .966 r
.52921 .4047 .5324 .40753 .53834 .40799 .53516 .40561 Mtetra
0 .409 .82 r
.53516 .40561 .53834 .40799 .54431 .40985 .54114 .40821 Mtetra
.59 .03 0 r
.54114 .40821 .54431 .40985 .55032 .41384 .54716 .41327 Mtetra
.808 .323 .04 r
.54716 .41327 .55032 .41384 .5564 .42088 .55326 .42173 Mtetra
.861 .443 .23 r
.55326 .42173 .5564 .42088 .56257 .43179 .55945 .43427 Mtetra
.869 .486 .315 r
.55945 .43427 .56257 .43179 .56885 .4467 .56575 .45053 Mtetra
.859 .488 .346 r
.56575 .45053 .56885 .4467 .57525 .46394 .57216 .46785 Mtetra
.826 .438 .318 r
.57216 .46785 .57525 .46394 .5817 .47917 .57858 .48094 Mtetra
.595 .075 0 r
.57858 .48094 .5817 .47917 .58807 .48644 .58489 .4841 Mtetra
.899 .839 .777 r
.58489 .4841 .58807 .48644 .59425 .48194 .59099 .47542 Mtetra
.885 .706 .654 r
.59099 .47542 .59425 .48194 .6002 .4673 .59691 .45861 Mtetra
.865 .673 .64 r
.59691 .45861 .6002 .4673 .606 .44841 .60275 .44029 Mtetra
.845 .671 .667 r
.60275 .44029 .606 .44841 .61181 .43145 .60864 .42621 Mtetra
.79 .715 .781 r
.60864 .42621 .61181 .43145 .61775 .42061 .61473 .4202 Mtetra
.649 .091 0 r
.61473 .4202 .61775 .42061 .62395 .41871 .62115 .42533 Mtetra
.842 .485 .378 r
.62115 .42533 .62395 .41871 .63054 .42865 .62806 .44476 Mtetra
.834 .517 .453 r
.62806 .44476 .63054 .42865 .63771 .4536 .63559 .4797 Mtetra
.807 .506 .48 r
.63559 .4797 .63771 .4536 .64554 .49344 .64355 .5224 Mtetra
.742 .449 .484 r
.64355 .5224 .64554 .49344 .65367 .53635 .65114 .55016 Mtetra
.192 0 .275 r
.65114 .55016 .65367 .53635 .66105 .55606 .65739 .54033 Mtetra
.889 .647 .566 r
.65739 .54033 .66105 .55606 .6668 .53474 .66226 .49779 Mtetra
.809 .563 .567 r
.66226 .49779 .6668 .53474 .67129 .48641 .66668 .44798 Mtetra
.775 .537 .575 r
.66668 .44798 .67129 .48641 .67559 .43768 .67138 .40848 Mtetra
.759 .534 .591 r
.67138 .40848 .67559 .43768 .68035 .4018 .67659 .38239 Mtetra
.752 .549 .621 r
.67659 .38239 .68035 .4018 .68564 .37897 .68221 .36641 Mtetra
.748 .579 .666 r
.68221 .36641 .68564 .37897 .69133 .36517 .68812 .35667 Mtetra
.741 .621 .725 r
.68812 .35667 .69133 .36517 .69728 .35674 .69419 .35046 Mtetra
.728 .664 .786 r
.69419 .35046 .69728 .35674 .70338 .35129 .70037 .34618 Mtetra
.711 .696 .835 r
.70037 .34618 .70338 .35129 .70958 .34742 .70661 .34291 Mtetra
.694 .717 .867 r
.70661 .34291 .70958 .34742 .71584 .34439 .71289 .34019 Mtetra
.682 .728 .885 r
.71289 .34019 .71584 .34439 .72213 .3418 .71921 .33776 Mtetra
.674 .735 .895 r
.71921 .33776 .72213 .3418 .72845 .33943 .72554 .33547 Mtetra
.67 .738 .901 r
.72554 .33547 .72845 .33943 .73479 .33719 .7319 .33327 Mtetra
.667 .739 .904 r
.7319 .33327 .73479 .33719 .74115 .33502 .73827 .33111 Mtetra
.666 .74 .905 r
.73827 .33111 .74115 .33502 .74753 .33287 .74466 .32896 Mtetra
.665 .74 .906 r
.74466 .32896 .74753 .33287 .75392 .33074 .75106 .32683 Mtetra
.664 .74 .907 r
.75106 .32683 .75392 .33074 .76033 .32861 .75748 .3247 Mtetra
.664 .741 .907 r
.75748 .3247 .76033 .32861 .76675 .32649 .76391 .32257 Mtetra
.76391 .32257 .76675 .32649 .77319 .32437 .77036 .32044 Mtetra
.77036 .32044 .77319 .32437 .77964 .32224 .77682 .3183 Mtetra
.77682 .3183 .77964 .32224 .7861 .32011 .78329 .31616 Mtetra
.78329 .31616 .7861 .32011 .79258 .31797 .78978 .31402 Mtetra
.78978 .31402 .79258 .31797 .79908 .31583 .79629 .31187 Mtetra
.79629 .31187 .79908 .31583 .80559 .31369 .80281 .30972 Mtetra
.80281 .30972 .80559 .31369 .81211 .31154 .80934 .30756 Mtetra
.664 .74 .907 r
.80934 .30756 .81211 .31154 .81865 .30939 .81589 .30539 Mtetra
.81589 .30539 .81865 .30939 .82521 .30722 .82246 .30323 Mtetra
.664 .741 .907 r
.82246 .30323 .82521 .30722 .83178 .30506 .82904 .30106 Mtetra
.82904 .30106 .83178 .30506 .83836 .30289 .83563 .29888 Mtetra
.83563 .29888 .83836 .30289 .84496 .30072 .84224 .29669 Mtetra
.84224 .29669 .84496 .30072 .85157 .29855 .84887 .29451 Mtetra
.664 .74 .907 r
.84887 .29451 .85157 .29855 .8582 .29636 .8555 .29231 Mtetra
.664 .741 .907 r
.8555 .29231 .8582 .29636 .86484 .29417 .86216 .29012 Mtetra
.86216 .29012 .86484 .29417 .8715 .29198 .86883 .28791 Mtetra
.86883 .28791 .8715 .29198 .87818 .28978 .87551 .28571 Mtetra
.27681 .47896 .28034 .48225 .28574 .48047 .28222 .47716 Mtetra
.28222 .47716 .28574 .48047 .29116 .47868 .28764 .47537 Mtetra
.28764 .47537 .29116 .47868 .29659 .47689 .29308 .47357 Mtetra
.29308 .47357 .29659 .47689 .30203 .47509 .29852 .47176 Mtetra
.29852 .47176 .30203 .47509 .30748 .47329 .30398 .46996 Mtetra
.30398 .46996 .30748 .47329 .31294 .47149 .30945 .46815 Mtetra
.30945 .46815 .31294 .47149 .31841 .46968 .31493 .46633 Mtetra
.31493 .46633 .31841 .46968 .3239 .46787 .32042 .46451 Mtetra
.32042 .46451 .3239 .46787 .32939 .46606 .32592 .46269 Mtetra
.664 .74 .907 r
.32592 .46269 .32939 .46606 .3349 .46423 .33144 .46087 Mtetra
.664 .741 .907 r
.33144 .46087 .3349 .46423 .34042 .46241 .33696 .45904 Mtetra
.33696 .45904 .34042 .46241 .34595 .46059 .3425 .4572 Mtetra
.3425 .4572 .34595 .46059 .35149 .45875 .34805 .45537 Mtetra
.34805 .45537 .35149 .45875 .35705 .45693 .35361 .45353 Mtetra
.664 .74 .907 r
.35361 .45353 .35705 .45693 .36261 .45509 .35918 .45168 Mtetra
.664 .741 .907 r
.35918 .45168 .36261 .45509 .36819 .45324 .36477 .44984 Mtetra
.36477 .44984 .36819 .45324 .37378 .4514 .37036 .44798 Mtetra
.37036 .44798 .37378 .4514 .37938 .44955 .37597 .44612 Mtetra
.37597 .44612 .37938 .44955 .38499 .4477 .38159 .44426 Mtetra
.38159 .44426 .38499 .4477 .39061 .44584 .38722 .4424 Mtetra
.664 .74 .907 r
.38722 .4424 .39061 .44584 .39625 .44398 .39286 .44053 Mtetra
.664 .741 .907 r
.39286 .44053 .39625 .44398 .40189 .44211 .39852 .43866 Mtetra
.39852 .43866 .40189 .44211 .40755 .44024 .40418 .43679 Mtetra
.40418 .43679 .40755 .44024 .41322 .43837 .40986 .4349 Mtetra
.40986 .4349 .41322 .43837 .41891 .4365 .41555 .43302 Mtetra
.41555 .43302 .41891 .4365 .4246 .43462 .42125 .43113 Mtetra
.664 .74 .907 r
.42125 .43113 .4246 .43462 .43031 .43273 .42697 .42924 Mtetra
.664 .741 .907 r
.42697 .42924 .43031 .43273 .43603 .43084 .43269 .42735 Mtetra
.664 .741 .908 r
.43269 .42735 .43603 .43084 .44176 .42895 .43843 .42545 Mtetra
.664 .741 .907 r
.43843 .42545 .44176 .42895 .4475 .42705 .44418 .42354 Mtetra
.664 .74 .907 r
.44418 .42354 .4475 .42705 .45326 .42516 .44995 .42164 Mtetra
.663 .74 .907 r
.44995 .42164 .45326 .42516 .45902 .42326 .45572 .41974 Mtetra
.663 .741 .908 r
.45572 .41974 .45902 .42326 .4648 .42135 .46151 .41783 Mtetra
.46151 .41783 .4648 .42135 .47059 .41945 .46731 .41592 Mtetra
.662 .741 .908 r
.46731 .41592 .47059 .41945 .4764 .41756 .47312 .41402 Mtetra
.661 .74 .909 r
.47312 .41402 .4764 .41756 .48222 .41568 .47895 .41213 Mtetra
.659 .74 .91 r
.47895 .41213 .48222 .41568 .48804 .41381 .48478 .41027 Mtetra
.656 .74 .911 r
.48478 .41027 .48804 .41381 .49389 .41197 .49063 .40845 Mtetra
.651 .74 .914 r
.49063 .40845 .49389 .41197 .49974 .41019 .49649 .4067 Mtetra
.643 .739 .919 r
.49649 .4067 .49974 .41019 .50561 .4085 .50237 .40506 Mtetra
.629 .738 .926 r
.50237 .40506 .50561 .4085 .51148 .40698 .50825 .4036 Mtetra
.602 .733 .937 r
.50825 .4036 .51148 .40698 .51738 .40572 .51415 .40246 Mtetra
.55 .722 .953 r
.51415 .40246 .51738 .40572 .52328 .40488 .52007 .40184 Mtetra
.442 .69 .97 r
.52007 .40184 .52328 .40488 .52921 .4047 .526 .40204 Mtetra
.193 .581 .941 r
.526 .40204 .52921 .4047 .53516 .40561 .53196 .40351 Mtetra
0 .248 .667 r
.53196 .40351 .53516 .40561 .54114 .40821 .53795 .40692 Mtetra
.709 .173 0 r
.53795 .40692 .54114 .40821 .54716 .41327 .54399 .4132 Mtetra
.839 .385 .133 r
.54399 .4132 .54716 .41327 .55326 .42173 .5501 .42325 Mtetra
.867 .467 .274 r
.5501 .42325 .55326 .42173 .55945 .43427 .55631 .43748 Mtetra
.866 .492 .336 r
.55631 .43748 .55945 .43427 .56575 .45053 .56263 .45477 Mtetra
.85 .479 .349 r
.56263 .45477 .56575 .45053 .57216 .46785 .56903 .47144 Mtetra
.795 .389 .281 r
.56903 .47144 .57216 .46785 .57858 .48094 .57541 .48158 Mtetra
0 0 0 r
.57541 .48158 .57858 .48094 .58489 .4841 .58166 .48034 Mtetra
.904 .773 .707 r
.58166 .48034 .58489 .4841 .59099 .47542 .58771 .46807 Mtetra
.879 .693 .646 r
.58771 .46807 .59099 .47542 .59691 .45861 .59363 .45026 Mtetra
.859 .674 .651 r
.59363 .45026 .59691 .45861 .60275 .44029 .59952 .43376 Mtetra
.83 .693 .712 r
.59952 .43376 .60275 .44029 .60864 .42621 .60554 .4238 Mtetra
.364 .704 .985 r
.60554 .4238 .60864 .42621 .61473 .4202 .61181 .42412 Mtetra
.833 .442 .31 r
.61181 .42412 .61473 .4202 .62115 .42533 .6185 .43797 Mtetra
.837 .511 .437 r
.6185 .43797 .62115 .42533 .62806 .44476 .62573 .46734 Mtetra
.816 .511 .472 r
.62573 .46734 .62806 .44476 .63559 .4797 .63347 .50775 Mtetra
.769 .472 .483 r
.63347 .50775 .63559 .4797 .64355 .5224 .64113 .54102 Mtetra
.557 .263 .424 r
.64113 .54102 .64355 .5224 .65114 .55016 .6478 .54262 Mtetra
.932 .704 .571 r
.6478 .54262 .65114 .55016 .65739 .54033 .6531 .50814 Mtetra
.825 .578 .567 r
.6531 .50814 .65739 .54033 .66226 .49779 .6577 .45903 Mtetra
.784 .543 .572 r
.6577 .45903 .66226 .49779 .66668 .44798 .6624 .41635 Mtetra
.764 .535 .586 r
.6624 .41635 .66668 .44798 .67138 .40848 .66754 .3868 Mtetra
.756 .545 .611 r
.66754 .3868 .67138 .40848 .67659 .38239 .67309 .3683 Mtetra
.751 .571 .652 r
.67309 .3683 .67659 .38239 .68221 .36641 .67895 .357 Mtetra
.746 .61 .707 r
.67895 .357 .68221 .36641 .68812 .35667 .68499 .34988 Mtetra
.735 .653 .769 r
.68499 .34988 .68812 .35667 .69419 .35046 .69114 .34507 Mtetra
.718 .689 .822 r
.69114 .34507 .69419 .35046 .70037 .34618 .69737 .34152 Mtetra
.7 .713 .858 r
.69737 .34152 .70037 .34618 .70661 .34291 .70364 .33863 Mtetra
.686 .726 .88 r
.70364 .33863 .70661 .34291 .71289 .34019 .70995 .3361 Mtetra
.677 .733 .893 r
.70995 .3361 .71289 .34019 .71921 .33776 .71628 .33376 Mtetra
.672 .737 .899 r
.71628 .33376 .71921 .33776 .72554 .33547 .72262 .33153 Mtetra
.668 .739 .903 r
.72262 .33153 .72554 .33547 .7319 .33327 .72899 .32934 Mtetra
.666 .74 .905 r
.72899 .32934 .7319 .33327 .73827 .33111 .73537 .32719 Mtetra
.665 .74 .906 r
.73537 .32719 .73827 .33111 .74466 .32896 .74177 .32505 Mtetra
.665 .741 .907 r
.74177 .32505 .74466 .32896 .75106 .32683 .74818 .32291 Mtetra
.664 .741 .907 r
.74818 .32291 .75106 .32683 .75748 .3247 .75461 .32077 Mtetra
.75461 .32077 .75748 .3247 .76391 .32257 .76106 .31863 Mtetra
.76106 .31863 .76391 .32257 .77036 .32044 .76751 .31649 Mtetra
.76751 .31649 .77036 .32044 .77682 .3183 .77398 .31435 Mtetra
.77398 .31435 .77682 .3183 .78329 .31616 .78047 .3122 Mtetra
.78047 .3122 .78329 .31616 .78978 .31402 .78697 .31005 Mtetra
.78697 .31005 .78978 .31402 .79629 .31187 .79349 .30789 Mtetra
.79349 .30789 .79629 .31187 .80281 .30972 .80002 .30573 Mtetra
.80002 .30573 .80281 .30972 .80934 .30756 .80656 .30356 Mtetra
.80656 .30356 .80934 .30756 .81589 .30539 .81312 .30139 Mtetra
.81312 .30139 .81589 .30539 .82246 .30323 .8197 .29921 Mtetra
.8197 .29921 .82246 .30323 .82904 .30106 .82629 .29703 Mtetra
.82629 .29703 .82904 .30106 .83563 .29888 .83289 .29485 Mtetra
.83289 .29485 .83563 .29888 .84224 .29669 .83951 .29265 Mtetra
.83951 .29265 .84224 .29669 .84887 .29451 .84615 .29045 Mtetra
.84615 .29045 .84887 .29451 .8555 .29231 .8528 .28825 Mtetra
.8528 .28825 .8555 .29231 .86216 .29012 .85946 .28605 Mtetra
.85946 .28605 .86216 .29012 .86883 .28791 .86615 .28384 Mtetra
.86615 .28384 .86883 .28791 .87551 .28571 .87284 .28162 Mtetra
.27326 .47564 .27681 .47896 .28222 .47716 .27868 .47384 Mtetra
.27868 .47384 .28222 .47716 .28764 .47537 .28411 .47204 Mtetra
.28411 .47204 .28764 .47537 .29308 .47357 .28955 .47024 Mtetra
.28955 .47024 .29308 .47357 .29852 .47176 .29501 .46843 Mtetra
.29501 .46843 .29852 .47176 .30398 .46996 .30047 .46661 Mtetra
.30047 .46661 .30398 .46996 .30945 .46815 .30594 .46479 Mtetra
.30594 .46479 .30945 .46815 .31493 .46633 .31143 .46297 Mtetra
.31143 .46297 .31493 .46633 .32042 .46451 .31693 .46115 Mtetra
.31693 .46115 .32042 .46451 .32592 .46269 .32244 .45932 Mtetra
.32244 .45932 .32592 .46269 .33144 .46087 .32796 .45749 Mtetra
.32796 .45749 .33144 .46087 .33696 .45904 .33349 .45565 Mtetra
.33349 .45565 .33696 .45904 .3425 .4572 .33904 .45381 Mtetra
.33904 .45381 .3425 .4572 .34805 .45537 .34459 .45197 Mtetra
.34459 .45197 .34805 .45537 .35361 .45353 .35016 .45012 Mtetra
.35016 .45012 .35361 .45353 .35918 .45168 .35574 .44826 Mtetra
.35574 .44826 .35918 .45168 .36477 .44984 .36133 .44641 Mtetra
.36133 .44641 .36477 .44984 .37036 .44798 .36693 .44455 Mtetra
.663 .741 .907 r
.36693 .44455 .37036 .44798 .37597 .44612 .37255 .44269 Mtetra
.664 .741 .908 r
.37255 .44269 .37597 .44612 .38159 .44426 .37817 .44082 Mtetra
.664 .741 .907 r
.37817 .44082 .38159 .44426 .38722 .4424 .38381 .43895 Mtetra
.38381 .43895 .38722 .4424 .39286 .44053 .38946 .43707 Mtetra
.38946 .43707 .39286 .44053 .39852 .43866 .39512 .43519 Mtetra
.663 .74 .907 r
.39512 .43519 .39852 .43866 .40418 .43679 .4008 .43331 Mtetra
.664 .741 .908 r
.4008 .43331 .40418 .43679 .40986 .4349 .40648 .43143 Mtetra
.664 .742 .908 r
.40648 .43143 .40986 .4349 .41555 .43302 .41218 .42953 Mtetra
.664 .741 .907 r
.41218 .42953 .41555 .43302 .42125 .43113 .41789 .42763 Mtetra
.41789 .42763 .42125 .43113 .42697 .42924 .42361 .42573 Mtetra
.664 .74 .907 r
.42361 .42573 .42697 .42924 .43269 .42735 .42935 .42383 Mtetra
.663 .74 .907 r
.42935 .42383 .43269 .42735 .43843 .42545 .43509 .42194 Mtetra
.664 .741 .908 r
.43509 .42194 .43843 .42545 .44418 .42354 .44085 .42002 Mtetra
.664 .742 .908 r
.44085 .42002 .44418 .42354 .44995 .42164 .44662 .41811 Mtetra
.664 .741 .908 r
.44662 .41811 .44995 .42164 .45572 .41974 .45241 .41619 Mtetra
.663 .74 .907 r
.45241 .41619 .45572 .41974 .46151 .41783 .4582 .41428 Mtetra
.662 .74 .908 r
.4582 .41428 .46151 .41783 .46731 .41592 .46401 .41237 Mtetra
.662 .741 .909 r
.46401 .41237 .46731 .41592 .47312 .41402 .46983 .41048 Mtetra
.661 .741 .91 r
.46983 .41048 .47312 .41402 .47895 .41213 .47566 .40859 Mtetra
.659 .741 .911 r
.47566 .40859 .47895 .41213 .48478 .41027 .48151 .40673 Mtetra
.655 .74 .912 r
.48151 .40673 .48478 .41027 .49063 .40845 .48736 .40492 Mtetra
.649 .739 .915 r
.48736 .40492 .49063 .40845 .49649 .4067 .49323 .40319 Mtetra
.638 .738 .921 r
.49323 .40319 .49649 .4067 .50237 .40506 .49911 .40162 Mtetra
.62 .736 .93 r
.49911 .40162 .50237 .40506 .50825 .4036 .50501 .40027 Mtetra
.586 .731 .943 r
.50501 .40027 .50825 .4036 .51415 .40246 .51092 .39929 Mtetra
.52 .715 .961 r
.51092 .39929 .51415 .40246 .52007 .40184 .51684 .39891 Mtetra
.371 .664 .971 r
.51684 .39891 .52007 .40184 .526 .40204 .52278 .39953 Mtetra
.028 .484 .879 r
.52278 .39953 .526 .40204 .53196 .40351 .52874 .40167 Mtetra
.5 0 0 r
.52874 .40167 .53196 .40351 .53795 .40692 .53474 .4061 Mtetra
.783 .281 0 r
.53474 .4061 .53795 .40692 .54399 .4132 .54079 .41376 Mtetra
.856 .428 .206 r
.54079 .41376 .54399 .4132 .5501 .42325 .54692 .42551 Mtetra
.869 .483 .308 r
.54692 .42551 .5501 .42325 .55631 .43748 .55315 .44135 Mtetra
.862 .494 .35 r
.55315 .44135 .55631 .43748 .56263 .45477 .55948 .45929 Mtetra
.836 .462 .345 r
.55948 .45929 .56263 .45477 .56903 .47144 .56587 .47451 Mtetra
.729 .286 .2 r
.56587 .47451 .56903 .47144 .57541 .48158 .57221 .48093 Mtetra
.848 .958 .881 r
.57221 .48093 .57541 .48158 .58166 .48034 .5784 .47534 Mtetra
.898 .737 .674 r
.5784 .47534 .58166 .48034 .58771 .46807 .58442 .46043 Mtetra
.874 .688 .648 r
.58442 .46043 .58771 .46807 .59363 .45026 .59036 .44294 Mtetra
.851 .685 .676 r
.59036 .44294 .59363 .45026 .59952 .43376 .59634 .42956 Mtetra
.766 .75 .838 r
.59634 .42956 .59952 .43376 .60554 .4238 .6025 .42514 Mtetra
.785 .319 .133 r
.6025 .42514 .60554 .4238 .61181 .42412 .609 .43333 Mtetra
.838 .497 .41 r
.609 .43333 .61181 .42412 .6185 .43797 .61597 .45669 Mtetra
.824 .512 .462 r
.61597 .45669 .6185 .43797 .62573 .46734 .62344 .49327 Mtetra
.788 .487 .479 r
.62344 .49327 .62573 .46734 .63347 .50775 .63107 .52951 Mtetra
.672 .373 .458 r
.63107 .52951 .63347 .50775 .64113 .54102 .63805 .54131 Mtetra
.992 .817 .568 r
.63805 .54131 .64113 .54102 .6478 .54262 .64378 .5165 Mtetra
.843 .598 .568 r
.64378 .5165 .6478 .54262 .6531 .50814 .64864 .47027 Mtetra
.793 .551 .571 r
.64864 .47027 .6531 .50814 .6577 .45903 .65339 .42537 Mtetra
.77 .537 .582 r
.65339 .42537 .6577 .45903 .6624 .41635 .65848 .39234 Mtetra
.76 .543 .603 r
.65848 .39234 .6624 .41635 .66754 .3868 .66397 .37101 Mtetra
.755 .565 .638 r
.66397 .37101 .66754 .3868 .67309 .3683 .66977 .35784 Mtetra
.751 .6 .69 r
.66977 .35784 .67309 .3683 .67895 .357 .67577 .34961 Mtetra
.741 .642 .75 r
.67577 .34961 .67895 .357 .68499 .34988 .6819 .34415 Mtetra
.725 .68 .806 r
.6819 .34415 .68499 .34988 .69114 .34507 .68811 .34023 Mtetra
.707 .707 .848 r
.68811 .34023 .69114 .34507 .69737 .34152 .69437 .33714 Mtetra
.691 .723 .874 r
.69437 .33714 .69737 .34152 .70364 .33863 .70067 .33449 Mtetra
.681 .732 .889 r
.70067 .33449 .70364 .33863 .70995 .3361 .70699 .33208 Mtetra
.674 .736 .897 r
.70699 .33208 .70995 .3361 .71628 .33376 .71334 .3298 Mtetra
.67 .738 .902 r
.71334 .3298 .71628 .33376 .72262 .33153 .7197 .32759 Mtetra
.667 .74 .904 r
.7197 .32759 .72262 .33153 .72899 .32934 .72607 .32541 Mtetra
.666 .74 .906 r
.72607 .32541 .72899 .32934 .73537 .32719 .73247 .32326 Mtetra
.665 .74 .906 r
.73247 .32326 .73537 .32719 .74177 .32505 .73888 .32111 Mtetra
.665 .741 .907 r
.73888 .32111 .74177 .32505 .74818 .32291 .7453 .31897 Mtetra
.664 .741 .907 r
.7453 .31897 .74818 .32291 .75461 .32077 .75174 .31683 Mtetra
.75174 .31683 .75461 .32077 .76106 .31863 .75819 .31468 Mtetra
.75819 .31468 .76106 .31863 .76751 .31649 .76466 .31253 Mtetra
.76466 .31253 .76751 .31649 .77398 .31435 .77114 .31038 Mtetra
.77114 .31038 .77398 .31435 .78047 .3122 .77764 .30822 Mtetra
.77764 .30822 .78047 .3122 .78697 .31005 .78415 .30606 Mtetra
.78415 .30606 .78697 .31005 .79349 .30789 .79067 .3039 Mtetra
.79067 .3039 .79349 .30789 .80002 .30573 .79721 .30172 Mtetra
.79721 .30172 .80002 .30573 .80656 .30356 .80377 .29955 Mtetra
.80377 .29955 .80656 .30356 .81312 .30139 .81034 .29737 Mtetra
.81034 .29737 .81312 .30139 .8197 .29921 .81693 .29518 Mtetra
.81693 .29518 .8197 .29921 .82629 .29703 .82353 .29299 Mtetra
.82353 .29299 .82629 .29703 .83289 .29485 .83014 .29079 Mtetra
.83014 .29079 .83289 .29485 .83951 .29265 .83677 .28859 Mtetra
.83677 .28859 .83951 .29265 .84615 .29045 .84342 .28639 Mtetra
.84342 .28639 .84615 .29045 .8528 .28825 .85008 .28418 Mtetra
.85008 .28418 .8528 .28825 .85946 .28605 .85676 .28196 Mtetra
.85676 .28196 .85946 .28605 .86615 .28384 .86345 .27974 Mtetra
.86345 .27974 .86615 .28384 .87284 .28162 .87016 .27751 Mtetra
.2697 .47232 .27326 .47564 .27868 .47384 .27513 .47051 Mtetra
.27513 .47051 .27868 .47384 .28411 .47204 .28057 .4687 Mtetra
.28057 .4687 .28411 .47204 .28955 .47024 .28601 .46689 Mtetra
.28601 .46689 .28955 .47024 .29501 .46843 .29147 .46507 Mtetra
.29147 .46507 .29501 .46843 .30047 .46661 .29694 .46325 Mtetra
.29694 .46325 .30047 .46661 .30594 .46479 .30243 .46143 Mtetra
.30243 .46143 .30594 .46479 .31143 .46297 .30792 .4596 Mtetra
.30792 .4596 .31143 .46297 .31693 .46115 .31343 .45777 Mtetra
.31343 .45777 .31693 .46115 .32244 .45932 .31894 .45593 Mtetra
.31894 .45593 .32244 .45932 .32796 .45749 .32447 .45409 Mtetra
.32447 .45409 .32796 .45749 .33349 .45565 .33001 .45225 Mtetra
.33001 .45225 .33349 .45565 .33904 .45381 .33556 .4504 Mtetra
.33556 .4504 .33904 .45381 .34459 .45197 .34112 .44855 Mtetra
.664 .74 .907 r
.34112 .44855 .34459 .45197 .35016 .45012 .3467 .4467 Mtetra
.664 .741 .907 r
.3467 .4467 .35016 .45012 .35574 .44826 .35229 .44484 Mtetra
.35229 .44484 .35574 .44826 .36133 .44641 .35788 .44297 Mtetra
.35788 .44297 .36133 .44641 .36693 .44455 .36349 .44111 Mtetra
.36349 .44111 .36693 .44455 .37255 .44269 .36912 .43923 Mtetra
.664 .74 .907 r
.36912 .43923 .37255 .44269 .37817 .44082 .37475 .43736 Mtetra
.664 .741 .907 r
.37475 .43736 .37817 .44082 .38381 .43895 .38039 .43548 Mtetra
.38039 .43548 .38381 .43895 .38946 .43707 .38605 .4336 Mtetra
.38605 .4336 .38946 .43707 .39512 .43519 .39172 .43171 Mtetra
.39172 .43171 .39512 .43519 .4008 .43331 .3974 .42982 Mtetra
.664 .74 .907 r
.3974 .42982 .4008 .43331 .40648 .43143 .4031 .42793 Mtetra
.4031 .42793 .40648 .43143 .41218 .42953 .4088 .42603 Mtetra
.664 .741 .907 r
.4088 .42603 .41218 .42953 .41789 .42763 .41452 .42413 Mtetra
.41452 .42413 .41789 .42763 .42361 .42573 .42025 .42222 Mtetra
.42025 .42222 .42361 .42573 .42935 .42383 .42599 .42031 Mtetra
.42599 .42031 .42935 .42383 .43509 .42194 .43174 .4184 Mtetra
.664 .74 .907 r
.43174 .4184 .43509 .42194 .44085 .42002 .43751 .41648 Mtetra
.664 .741 .907 r
.43751 .41648 .44085 .42002 .44662 .41811 .44329 .41456 Mtetra
.663 .741 .908 r
.44329 .41456 .44662 .41811 .45241 .41619 .44908 .41264 Mtetra
.44908 .41264 .45241 .41619 .4582 .41428 .45488 .41073 Mtetra
.45488 .41073 .4582 .41428 .46401 .41237 .4607 .40881 Mtetra
.662 .741 .909 r
.4607 .40881 .46401 .41237 .46983 .41048 .46653 .40691 Mtetra
.66 .74 .909 r
.46653 .40691 .46983 .41048 .47566 .40859 .47237 .40502 Mtetra
.657 .74 .911 r
.47237 .40502 .47566 .40859 .48151 .40673 .47822 .40318 Mtetra
.653 .74 .914 r
.47822 .40318 .48151 .40673 .48736 .40492 .48408 .4014 Mtetra
.646 .74 .918 r
.48408 .4014 .48736 .40492 .49323 .40319 .48996 .39971 Mtetra
.633 .738 .924 r
.48996 .39971 .49323 .40319 .49911 .40162 .49585 .39819 Mtetra
.609 .734 .934 r
.49585 .39819 .49911 .40162 .50501 .40027 .50175 .39695 Mtetra
.565 .725 .949 r
.50175 .39695 .50501 .40027 .51092 .39929 .50766 .39618 Mtetra
.475 .702 .968 r
.50766 .39618 .51092 .39929 .51684 .39891 .51359 .39614 Mtetra
.269 .62 .959 r
.51359 .39614 .51684 .39891 .52278 .39953 .51954 .39725 Mtetra
0 .342 .759 r
.51954 .39725 .52278 .39953 .52874 .40167 .52551 .40017 Mtetra
.654 .103 0 r
.52551 .40017 .52874 .40167 .53474 .4061 .53152 .40578 Mtetra
.826 .359 .094 r
.53152 .40578 .53474 .4061 .54079 .41376 .53758 .41504 Mtetra
.864 .458 .261 r
.53758 .41504 .54079 .41376 .54692 .42551 .54373 .42861 Mtetra
.867 .493 .335 r
.54373 .42861 .54692 .42551 .55315 .44135 .54997 .44591 Mtetra
.854 .49 .36 r
.54997 .44591 .55315 .44135 .55948 .45929 .55631 .46388 Mtetra
.815 .432 .331 r
.55631 .46388 .55948 .45929 .56587 .47451 .56268 .47679 Mtetra
.537 .023 0 r
.56268 .47679 .56587 .47451 .57221 .48093 .56897 .47899 Mtetra
.917 .851 .763 r
.56897 .47899 .57221 .48093 .5784 .47534 .57512 .46946 Mtetra
.892 .719 .66 r
.57512 .46946 .5784 .47534 .58442 .46043 .58113 .45311 Mtetra
.868 .691 .66 r
.58113 .45311 .58442 .46043 .59036 .44294 .58712 .43736 Mtetra
.833 .717 .736 r
.58712 .43736 .59036 .44294 .59634 .42956 .59321 .42854 Mtetra
.318 0 0 r
.59321 .42854 .59634 .42956 .6025 .42514 .59956 .43117 Mtetra
.833 .468 .364 r
.59956 .43117 .6025 .42514 .609 .43333 .60629 .44831 Mtetra
.828 .509 .448 r
.60629 .44831 .609 .43333 .61597 .45669 .6135 .47971 Mtetra
.801 .496 .473 r
.6135 .47971 .61597 .45669 .62344 .49327 .62099 .5159 Mtetra
.729 .426 .467 r
.62099 .5159 .62344 .49327 .63107 .52951 .62814 .53584 Mtetra
.665 .778 .307 r
.62814 .53584 .63107 .52951 .63805 .54131 .6343 .52214 Mtetra
.864 .624 .573 r
.6343 .52214 .63805 .54131 .64378 .5165 .63949 .48142 Mtetra
.806 .562 .57 r
.63949 .48142 .64378 .5165 .64864 .47027 .64435 .43556 Mtetra
.779 .542 .578 r
.64435 .43556 .64864 .47027 .65339 .42537 .64942 .39913 Mtetra
.765 .543 .596 r
.64942 .39913 .65339 .42537 .65848 .39234 .65485 .37465 Mtetra
.759 .559 .626 r
.65485 .37465 .65848 .39234 .66397 .37101 .66059 .3593 Mtetra
.755 .591 .673 r
.66059 .3593 .66397 .37101 .66977 .35784 .66655 .34971 Mtetra
.747 .631 .731 r
.66655 .34971 .66977 .35784 .67577 .34961 .67265 .34346 Mtetra
.733 .671 .789 r
.67265 .34346 .67577 .34961 .6819 .34415 .67884 .33908 Mtetra
.715 .701 .836 r
.67884 .33908 .6819 .34415 .68811 .34023 .68509 .33572 Mtetra
.697 .719 .866 r
.68509 .33572 .68811 .34023 .69437 .33714 .69138 .33291 Mtetra
.685 .73 .884 r
.69138 .33291 .69437 .33714 .70067 .33449 .69769 .33041 Mtetra
.676 .735 .895 r
.69769 .33041 .70067 .33449 .70699 .33208 .70403 .32808 Mtetra
.671 .738 .9 r
.70403 .32808 .70699 .33208 .71334 .3298 .71038 .32584 Mtetra
.668 .739 .903 r
.71038 .32584 .71334 .3298 .7197 .32759 .71676 .32364 Mtetra
.666 .74 .905 r
.71676 .32364 .7197 .32759 .72607 .32541 .72314 .32147 Mtetra
.665 .74 .906 r
.72314 .32147 .72607 .32541 .73247 .32326 .72955 .31932 Mtetra
.665 .741 .907 r
.72955 .31932 .73247 .32326 .73888 .32111 .73597 .31717 Mtetra
.664 .741 .907 r
.73597 .31717 .73888 .32111 .7453 .31897 .7424 .31502 Mtetra
.7424 .31502 .7453 .31897 .75174 .31683 .74885 .31287 Mtetra
.74885 .31287 .75174 .31683 .75819 .31468 .75531 .31071 Mtetra
.75531 .31071 .75819 .31468 .76466 .31253 .76179 .30856 Mtetra
.76179 .30856 .76466 .31253 .77114 .31038 .76828 .30639 Mtetra
.76828 .30639 .77114 .31038 .77764 .30822 .77479 .30423 Mtetra
.77479 .30423 .77764 .30822 .78415 .30606 .78131 .30206 Mtetra
.78131 .30206 .78415 .30606 .79067 .3039 .78785 .29988 Mtetra
.78785 .29988 .79067 .3039 .79721 .30172 .7944 .2977 Mtetra
.7944 .2977 .79721 .30172 .80377 .29955 .80097 .29552 Mtetra
.80097 .29552 .80377 .29955 .81034 .29737 .80755 .29333 Mtetra
.80755 .29333 .81034 .29737 .81693 .29518 .81414 .29113 Mtetra
.81414 .29113 .81693 .29518 .82353 .29299 .82075 .28893 Mtetra
.82075 .28893 .82353 .29299 .83014 .29079 .82738 .28673 Mtetra
.82738 .28673 .83014 .29079 .83677 .28859 .83402 .28451 Mtetra
.83402 .28451 .83677 .28859 .84342 .28639 .84068 .2823 Mtetra
.84068 .2823 .84342 .28639 .85008 .28418 .84735 .28008 Mtetra
.84735 .28008 .85008 .28418 .85676 .28196 .85404 .27785 Mtetra
.85404 .27785 .85676 .28196 .86345 .27974 .86074 .27562 Mtetra
.86074 .27562 .86345 .27974 .87016 .27751 .86746 .27339 Mtetra
.26613 .46898 .2697 .47232 .27513 .47051 .27156 .46717 Mtetra
.27156 .46717 .27513 .47051 .28057 .4687 .27701 .46535 Mtetra
.27701 .46535 .28057 .4687 .28601 .46689 .28246 .46353 Mtetra
.28246 .46353 .28601 .46689 .29147 .46507 .28793 .46171 Mtetra
.28793 .46171 .29147 .46507 .29694 .46325 .29341 .45988 Mtetra
.29341 .45988 .29694 .46325 .30243 .46143 .29889 .45805 Mtetra
.29889 .45805 .30243 .46143 .30792 .4596 .3044 .45621 Mtetra
.3044 .45621 .30792 .4596 .31343 .45777 .30991 .45438 Mtetra
.30991 .45438 .31343 .45777 .31894 .45593 .31543 .45253 Mtetra
.31543 .45253 .31894 .45593 .32447 .45409 .32097 .45069 Mtetra
.32097 .45069 .32447 .45409 .33001 .45225 .32651 .44883 Mtetra
.32651 .44883 .33001 .45225 .33556 .4504 .33207 .44698 Mtetra
.33207 .44698 .33556 .4504 .34112 .44855 .33764 .44512 Mtetra
.33764 .44512 .34112 .44855 .3467 .4467 .34322 .44326 Mtetra
.34322 .44326 .3467 .4467 .35229 .44484 .34882 .44139 Mtetra
.34882 .44139 .35229 .44484 .35788 .44297 .35442 .43952 Mtetra
.35442 .43952 .35788 .44297 .36349 .44111 .36004 .43765 Mtetra
.36004 .43765 .36349 .44111 .36912 .43923 .36567 .43577 Mtetra
.36567 .43577 .36912 .43923 .37475 .43736 .37131 .43389 Mtetra
.37131 .43389 .37475 .43736 .38039 .43548 .37696 .432 Mtetra
.37696 .432 .38039 .43548 .38605 .4336 .38263 .43011 Mtetra
.38263 .43011 .38605 .4336 .39172 .43171 .3883 .42822 Mtetra
.664 .741 .908 r
.3883 .42822 .39172 .43171 .3974 .42982 .39399 .42632 Mtetra
.664 .741 .907 r
.39399 .42632 .3974 .42982 .4031 .42793 .39969 .42442 Mtetra
.39969 .42442 .4031 .42793 .4088 .42603 .40541 .42251 Mtetra
.40541 .42251 .4088 .42603 .41452 .42413 .41113 .4206 Mtetra
.41113 .4206 .41452 .42413 .42025 .42222 .41687 .41869 Mtetra
.663 .741 .908 r
.41687 .41869 .42025 .42222 .42599 .42031 .42262 .41678 Mtetra
.664 .742 .908 r
.42262 .41678 .42599 .42031 .43174 .4184 .42838 .41486 Mtetra
.664 .741 .907 r
.42838 .41486 .43174 .4184 .43751 .41648 .43416 .41292 Mtetra
.664 .74 .907 r
.43416 .41292 .43751 .41648 .44329 .41456 .43994 .41099 Mtetra
.663 .74 .907 r
.43994 .41099 .44329 .41456 .44908 .41264 .44574 .40908 Mtetra
.662 .74 .908 r
.44574 .40908 .44908 .41264 .45488 .41073 .45155 .40717 Mtetra
.662 .741 .909 r
.45155 .40717 .45488 .41073 .4607 .40881 .45737 .40525 Mtetra
.45737 .40525 .4607 .40881 .46653 .40691 .46321 .40334 Mtetra
.66 .741 .91 r
.46321 .40334 .46653 .40691 .47237 .40502 .46906 .40145 Mtetra
.656 .74 .912 r
.46906 .40145 .47237 .40502 .47822 .40318 .47492 .39962 Mtetra
.65 .739 .915 r
.47492 .39962 .47822 .40318 .48408 .4014 .48079 .39787 Mtetra
.641 .739 .92 r
.48079 .39787 .48408 .4014 .48996 .39971 .48667 .39624 Mtetra
.626 .738 .928 r
.48667 .39624 .48996 .39971 .49585 .39819 .49257 .3948 Mtetra
.597 .733 .94 r
.49257 .3948 .49585 .39819 .50175 .39695 .49848 .3937 Mtetra
.539 .72 .957 r
.49848 .3937 .50175 .39695 .50766 .39618 .5044 .39316 Mtetra
.415 .68 .971 r
.5044 .39316 .50766 .39618 .51359 .39614 .51033 .39352 Mtetra
.123 .542 .918 r
.51033 .39352 .51359 .39614 .51954 .39725 .51628 .39526 Mtetra
.404 0 0 r
.51628 .39526 .51954 .39725 .52551 .40017 .52226 .39914 Mtetra
.753 .236 0 r
.52226 .39914 .52551 .40017 .53152 .40578 .52828 .4061 Mtetra
.85 .413 .182 r
.52828 .4061 .53152 .40578 .53758 .41504 .53435 .41714 Mtetra
.868 .48 .303 r
.53435 .41714 .53758 .41504 .54373 .42861 .54051 .43261 Mtetra
.863 .498 .356 r
.54051 .43261 .54373 .42861 .54997 .44591 .54676 .45111 Mtetra
.842 .479 .366 r
.54676 .45111 .54997 .44591 .55631 .46388 .5531 .46838 Mtetra
.777 .379 .3 r
.5531 .46838 .55631 .46388 .56268 .47679 .55945 .4781 Mtetra
0 0 0 r
.55945 .4781 .56268 .47679 .56897 .47899 .5657 .47587 Mtetra
.918 .792 .705 r
.5657 .47587 .56897 .47899 .57512 .46946 .57182 .46319 Mtetra
.887 .712 .659 r
.57182 .46319 .57512 .46946 .58113 .45311 .57785 .44678 Mtetra
.86 .706 .69 r
.57785 .44678 .58113 .45311 .58712 .43736 .58392 .43426 Mtetra
.71 .799 .92 r
.58392 .43426 .58712 .43736 .59321 .42854 .59015 .43143 Mtetra
.811 .392 .252 r
.59015 .43143 .59321 .42854 .59956 .43117 .59668 .44214 Mtetra
.832 .499 .425 r
.59668 .44214 .59956 .43117 .60629 .44831 .60364 .46751 Mtetra
.814 .502 .463 r
.60364 .46751 .60629 .44831 .6135 .47971 .61094 .50174 Mtetra
.763 .457 .468 r
.61094 .50174 .6135 .47971 .62099 .5159 .61816 .52745 Mtetra
.409 .088 .306 r
.61816 .52745 .62099 .5159 .62814 .53584 .62465 .52439 Mtetra
.897 .668 .584 r
.62465 .52439 .62814 .53584 .6343 .52214 .63019 .4911 Mtetra
.818 .575 .571 r
.63019 .4911 .6343 .52214 .63949 .48142 .63523 .44624 Mtetra
.786 .547 .576 r
.63523 .44624 .63949 .48142 .64435 .43556 .64032 .40713 Mtetra
.77 .543 .59 r
.64032 .40713 .64435 .43556 .64942 .39913 .64571 .37942 Mtetra
.764 .556 .616 r
.64571 .37942 .64942 .39913 .65485 .37465 .6514 .36156 Mtetra
.76 .583 .657 r
.6514 .36156 .65485 .37465 .66059 .3593 .65732 .35033 Mtetra
.754 .621 .712 r
.65732 .35033 .66059 .3593 .66655 .34971 .66339 .34308 Mtetra
.742 .661 .771 r
.66339 .34308 .66655 .34971 .67265 .34346 .66956 .33811 Mtetra
.723 .694 .822 r
.66956 .33811 .67265 .34346 .67884 .33908 .6758 .33441 Mtetra
.705 .715 .857 r
.6758 .33441 .67884 .33908 .68509 .33572 .68207 .3314 Mtetra
.69 .727 .879 r
.68207 .3314 .68509 .33572 .69138 .33291 .68838 .32879 Mtetra
.68 .734 .891 r
.68838 .32879 .69138 .33291 .69769 .33041 .69471 .32638 Mtetra
.673 .737 .898 r
.69471 .32638 .69769 .33041 .70403 .32808 .70105 .3241 Mtetra
.669 .739 .902 r
.70105 .3241 .70403 .32808 .71038 .32584 .70742 .32188 Mtetra
.667 .74 .904 r
.70742 .32188 .71038 .32584 .71676 .32364 .7138 .31969 Mtetra
.666 .74 .906 r
.7138 .31969 .71676 .32364 .72314 .32147 .7202 .31752 Mtetra
.665 .741 .906 r
.7202 .31752 .72314 .32147 .72955 .31932 .72662 .31536 Mtetra
.665 .741 .907 r
.72662 .31536 .72955 .31932 .73597 .31717 .73305 .31321 Mtetra
.664 .741 .907 r
.73305 .31321 .73597 .31717 .7424 .31502 .73949 .31105 Mtetra
.73949 .31105 .7424 .31502 .74885 .31287 .74595 .30889 Mtetra
.74595 .30889 .74885 .31287 .75531 .31071 .75242 .30673 Mtetra
.75242 .30673 .75531 .31071 .76179 .30856 .75891 .30456 Mtetra
.75891 .30456 .76179 .30856 .76828 .30639 .76541 .30239 Mtetra
.76541 .30239 .76828 .30639 .77479 .30423 .77193 .30022 Mtetra
.77193 .30022 .77479 .30423 .78131 .30206 .77846 .29804 Mtetra
.77846 .29804 .78131 .30206 .78785 .29988 .78501 .29585 Mtetra
.78501 .29585 .78785 .29988 .7944 .2977 .79157 .29366 Mtetra
.79157 .29366 .7944 .2977 .80097 .29552 .79815 .29147 Mtetra
.79815 .29147 .80097 .29552 .80755 .29333 .80474 .28927 Mtetra
.80474 .28927 .80755 .29333 .81414 .29113 .81135 .28707 Mtetra
.81135 .28707 .81414 .29113 .82075 .28893 .81797 .28486 Mtetra
.81797 .28486 .82075 .28893 .82738 .28673 .82461 .28264 Mtetra
.82461 .28264 .82738 .28673 .83402 .28451 .83126 .28042 Mtetra
.83126 .28042 .83402 .28451 .84068 .2823 .83793 .2782 Mtetra
.83793 .2782 .84068 .2823 .84735 .28008 .84461 .27597 Mtetra
.84461 .27597 .84735 .28008 .85404 .27785 .85131 .27373 Mtetra
.85131 .27373 .85404 .27785 .86074 .27562 .85802 .27149 Mtetra
.85802 .27149 .86074 .27562 .86746 .27339 .86475 .26925 Mtetra
.26254 .46563 .26613 .46898 .27156 .46717 .26798 .46381 Mtetra
.26798 .46381 .27156 .46717 .27701 .46535 .27343 .46199 Mtetra
.27343 .46199 .27701 .46535 .28246 .46353 .2789 .46016 Mtetra
.2789 .46016 .28246 .46353 .28793 .46171 .28437 .45833 Mtetra
.28437 .45833 .28793 .46171 .29341 .45988 .28985 .4565 Mtetra
.28985 .4565 .29341 .45988 .29889 .45805 .29535 .45466 Mtetra
.29535 .45466 .29889 .45805 .3044 .45621 .30086 .45282 Mtetra
.30086 .45282 .3044 .45621 .30991 .45438 .30638 .45097 Mtetra
.30638 .45097 .30991 .45438 .31543 .45253 .31191 .44912 Mtetra
.31191 .44912 .31543 .45253 .32097 .45069 .31745 .44727 Mtetra
.31745 .44727 .32097 .45069 .32651 .44883 .323 .44541 Mtetra
.323 .44541 .32651 .44883 .33207 .44698 .32857 .44355 Mtetra
.32857 .44355 .33207 .44698 .33764 .44512 .33415 .44168 Mtetra
.33415 .44168 .33764 .44512 .34322 .44326 .33973 .43981 Mtetra
.33973 .43981 .34322 .44326 .34882 .44139 .34534 .43794 Mtetra
.34534 .43794 .34882 .44139 .35442 .43952 .35095 .43606 Mtetra
.35095 .43606 .35442 .43952 .36004 .43765 .35657 .43418 Mtetra
.35657 .43418 .36004 .43765 .36567 .43577 .36221 .4323 Mtetra
.36221 .4323 .36567 .43577 .37131 .43389 .36786 .4304 Mtetra
.36786 .4304 .37131 .43389 .37696 .432 .37352 .42851 Mtetra
.37352 .42851 .37696 .432 .38263 .43011 .37919 .42661 Mtetra
.37919 .42661 .38263 .43011 .3883 .42822 .38487 .42471 Mtetra
.38487 .42471 .3883 .42822 .39399 .42632 .39057 .42281 Mtetra
.39057 .42281 .39399 .42632 .39969 .42442 .39628 .4209 Mtetra
.39628 .4209 .39969 .42442 .40541 .42251 .402 .41898 Mtetra
.402 .41898 .40541 .42251 .41113 .4206 .40773 .41706 Mtetra
.40773 .41706 .41113 .4206 .41687 .41869 .41348 .41514 Mtetra
.663 .74 .907 r
.41348 .41514 .41687 .41869 .42262 .41678 .41923 .41322 Mtetra
.664 .741 .907 r
.41923 .41322 .42262 .41678 .42838 .41486 .425 .4113 Mtetra
.425 .4113 .42838 .41486 .43416 .41292 .43079 .40936 Mtetra
.664 .741 .908 r
.43079 .40936 .43416 .41292 .43994 .41099 .43658 .40742 Mtetra
.663 .741 .908 r
.43658 .40742 .43994 .41099 .44574 .40908 .44239 .4055 Mtetra
.662 .74 .908 r
.44239 .4055 .44574 .40908 .45155 .40717 .44821 .40358 Mtetra
.661 .74 .908 r
.44821 .40358 .45155 .40717 .45737 .40525 .45404 .40167 Mtetra
.661 .741 .909 r
.45404 .40167 .45737 .40525 .46321 .40334 .45988 .39976 Mtetra
.659 .741 .911 r
.45988 .39976 .46321 .40334 .46906 .40145 .46574 .39788 Mtetra
.654 .741 .913 r
.46574 .39788 .46906 .40145 .47492 .39962 .4716 .39606 Mtetra
.647 .739 .917 r
.4716 .39606 .47492 .39962 .48079 .39787 .47748 .39434 Mtetra
.636 .738 .922 r
.47748 .39434 .48079 .39787 .48667 .39624 .48337 .39278 Mtetra
.616 .735 .931 r
.48337 .39278 .48667 .39624 .49257 .3948 .48928 .39145 Mtetra
.579 .729 .946 r
.48928 .39145 .49257 .3948 .49848 .3937 .49519 .39053 Mtetra
.502 .711 .965 r
.49519 .39053 .49848 .3937 .5044 .39316 .50112 .39028 Mtetra
.327 .646 .968 r
.50112 .39028 .5044 .39316 .51033 .39352 .50705 .3911 Mtetra
0 .418 .826 r
.50705 .3911 .51033 .39352 .51628 .39526 .51301 .39361 Mtetra
.592 .031 0 r
.51301 .39361 .51628 .39526 .52226 .39914 .51899 .39863 Mtetra
.811 .331 .056 r
.51899 .39863 .52226 .39914 .52828 .4061 .52501 .4072 Mtetra
.862 .451 .249 r
.52501 .4072 .52828 .4061 .53435 .41714 .5311 .42023 Mtetra
.868 .494 .336 r
.5311 .42023 .53435 .41714 .54051 .43261 .53726 .4376 Mtetra
.856 .498 .372 r
.53726 .4376 .54051 .43261 .54676 .45111 .54353 .45686 Mtetra
.825 .46 .366 r
.54353 .45686 .54676 .45111 .5531 .46838 .54986 .47256 Mtetra
.7 .274 .233 r
.54986 .47256 .5531 .46838 .55945 .4781 .55618 .47834 Mtetra
.868 .986 .836 r
.55618 .47834 .55945 .4781 .5657 .47587 .56241 .4718 Mtetra
.912 .76 .679 r
.56241 .4718 .5657 .47587 .57182 .46319 .56852 .4571 Mtetra
.881 .714 .671 r
.56852 .4571 .57182 .46319 .57785 .44678 .57459 .44218 Mtetra
.837 .749 .766 r
.57459 .44218 .57785 .44678 .58392 .43426 .58075 .43439 Mtetra
.621 .061 0 r
.58075 .43439 .58392 .43426 .59015 .43143 .58714 .43875 Mtetra
.83 .475 .384 r
.58714 .43875 .59015 .43143 .59668 .44214 .59386 .45749 Mtetra
.82 .501 .449 r
.59386 .45749 .59668 .44214 .60364 .46751 .60094 .48745 Mtetra
.786 .475 .463 r
.60094 .48745 .60364 .46751 .61094 .50174 .60812 .51564 Mtetra
.648 .322 .405 r
.60812 .51564 .61094 .50174 .61816 .52745 .61485 .52242 Mtetra
.935 .738 .612 r
.61485 .52242 .61816 .52745 .62465 .52439 .62076 .49891 Mtetra
.833 .592 .575 r
.62076 .49891 .62465 .52439 .63019 .4911 .62604 .45741 Mtetra
.797 .557 .574 r
.62604 .45741 .63019 .4911 .63523 .44624 .6312 .41646 Mtetra
.779 .547 .585 r
.6312 .41646 .63523 .44624 .64032 .40713 .63657 .38543 Mtetra
.77 .554 .607 r
.63657 .38543 .64032 .40713 .64571 .37942 .64221 .36473 Mtetra
.765 .576 .643 r
.64221 .36473 .64571 .37942 .6514 .36156 .64809 .35155 Mtetra
.76 .611 .693 r
.64809 .35155 .6514 .36156 .65732 .35033 .65412 .34308 Mtetra
.749 .65 .751 r
.65412 .34308 .65732 .35033 .66339 .34308 .66027 .33737 Mtetra
.732 .685 .805 r
.66027 .33737 .66339 .34308 .66956 .33811 .66648 .33323 Mtetra
.713 .709 .845 r
.66648 .33323 .66956 .33811 .6758 .33441 .67275 .32997 Mtetra
.696 .724 .871 r
.67275 .32997 .6758 .33441 .68207 .3314 .67904 .32721 Mtetra
.684 .732 .887 r
.67904 .32721 .68207 .3314 .68838 .32879 .68537 .32471 Mtetra
.676 .736 .896 r
.68537 .32471 .68838 .32879 .69471 .32638 .69171 .32237 Mtetra
.671 .738 .901 r
.69171 .32237 .69471 .32638 .70105 .3241 .69807 .32012 Mtetra
.668 .74 .904 r
.69807 .32012 .70105 .3241 .70742 .32188 .70445 .31791 Mtetra
.666 .74 .905 r
.70445 .31791 .70742 .32188 .7138 .31969 .71084 .31573 Mtetra
.665 .74 .906 r
.71084 .31573 .7138 .31969 .7202 .31752 .71725 .31356 Mtetra
.665 .741 .907 r
.71725 .31356 .7202 .31752 .72662 .31536 .72368 .31139 Mtetra
.664 .741 .907 r
.72368 .31139 .72662 .31536 .73305 .31321 .73011 .30923 Mtetra
.73011 .30923 .73305 .31321 .73949 .31105 .73657 .30707 Mtetra
.73657 .30707 .73949 .31105 .74595 .30889 .74304 .3049 Mtetra
.74304 .3049 .74595 .30889 .75242 .30673 .74952 .30273 Mtetra
.74952 .30273 .75242 .30673 .75891 .30456 .75602 .30055 Mtetra
.75602 .30055 .75891 .30456 .76541 .30239 .76253 .29837 Mtetra
.76253 .29837 .76541 .30239 .77193 .30022 .76906 .29619 Mtetra
.76906 .29619 .77193 .30022 .77846 .29804 .7756 .294 Mtetra
.7756 .294 .77846 .29804 .78501 .29585 .78216 .29181 Mtetra
.78216 .29181 .78501 .29585 .79157 .29366 .78873 .28961 Mtetra
.78873 .28961 .79157 .29366 .79815 .29147 .79532 .2874 Mtetra
.79532 .2874 .79815 .29147 .80474 .28927 .80192 .2852 Mtetra
.80192 .2852 .80474 .28927 .81135 .28707 .80854 .28298 Mtetra
.80854 .28298 .81135 .28707 .81797 .28486 .81517 .28076 Mtetra
.81517 .28076 .81797 .28486 .82461 .28264 .82182 .27854 Mtetra
.82182 .27854 .82461 .28264 .83126 .28042 .82849 .27631 Mtetra
.82849 .27631 .83126 .28042 .83793 .2782 .83516 .27408 Mtetra
.83516 .27408 .83793 .2782 .84461 .27597 .84186 .27184 Mtetra
.84186 .27184 .84461 .27597 .85131 .27373 .84857 .26959 Mtetra
.84857 .26959 .85131 .27373 .85802 .27149 .85529 .26734 Mtetra
.85529 .26734 .85802 .27149 .86475 .26925 .86203 .26509 Mtetra
.25894 .46227 .26254 .46563 .26798 .46381 .26439 .46044 Mtetra
.26439 .46044 .26798 .46381 .27343 .46199 .26985 .45861 Mtetra
.26985 .45861 .27343 .46199 .2789 .46016 .27532 .45678 Mtetra
.27532 .45678 .2789 .46016 .28437 .45833 .2808 .45494 Mtetra
.2808 .45494 .28437 .45833 .28985 .4565 .28629 .4531 Mtetra
.28629 .4531 .28985 .4565 .29535 .45466 .29179 .45125 Mtetra
.29179 .45125 .29535 .45466 .30086 .45282 .2973 .4494 Mtetra
.2973 .4494 .30086 .45282 .30638 .45097 .30283 .44755 Mtetra
.30283 .44755 .30638 .45097 .31191 .44912 .30837 .44569 Mtetra
.30837 .44569 .31191 .44912 .31745 .44727 .31392 .44383 Mtetra
.31392 .44383 .31745 .44727 .323 .44541 .31948 .44197 Mtetra
.31948 .44197 .323 .44541 .32857 .44355 .32505 .4401 Mtetra
.32505 .4401 .32857 .44355 .33415 .44168 .33064 .43823 Mtetra
.33064 .43823 .33415 .44168 .33973 .43981 .33623 .43635 Mtetra
.33623 .43635 .33973 .43981 .34534 .43794 .34184 .43447 Mtetra
.34184 .43447 .34534 .43794 .35095 .43606 .34746 .43258 Mtetra
.34746 .43258 .35095 .43606 .35657 .43418 .35309 .43069 Mtetra
.35309 .43069 .35657 .43418 .36221 .4323 .35873 .4288 Mtetra
.35873 .4288 .36221 .4323 .36786 .4304 .36439 .4269 Mtetra
.36439 .4269 .36786 .4304 .37352 .42851 .37006 .425 Mtetra
.37006 .425 .37352 .42851 .37919 .42661 .37574 .4231 Mtetra
.37574 .4231 .37919 .42661 .38487 .42471 .38143 .42119 Mtetra
.38143 .42119 .38487 .42471 .39057 .42281 .38713 .41928 Mtetra
.38713 .41928 .39057 .42281 .39628 .4209 .39285 .41736 Mtetra
.39285 .41736 .39628 .4209 .402 .41898 .39858 .41544 Mtetra
.39858 .41544 .402 .41898 .40773 .41706 .40432 .41351 Mtetra
.40432 .41351 .40773 .41706 .41348 .41514 .41007 .41159 Mtetra
.664 .741 .908 r
.41007 .41159 .41348 .41514 .41923 .41322 .41584 .40966 Mtetra
.664 .741 .907 r
.41584 .40966 .41923 .41322 .425 .4113 .42161 .40772 Mtetra
.42161 .40772 .425 .4113 .43079 .40936 .4274 .40578 Mtetra
.663 .741 .907 r
.4274 .40578 .43079 .40936 .43658 .40742 .43321 .40384 Mtetra
.663 .741 .908 r
.43321 .40384 .43658 .40742 .44239 .4055 .43902 .40191 Mtetra
.662 .741 .909 r
.43902 .40191 .44239 .4055 .44821 .40358 .44485 .39999 Mtetra
.44485 .39999 .44821 .40358 .45404 .40167 .45069 .39806 Mtetra
.66 .74 .909 r
.45069 .39806 .45404 .40167 .45988 .39976 .45654 .39616 Mtetra
.657 .74 .911 r
.45654 .39616 .45988 .39976 .46574 .39788 .4624 .3943 Mtetra
.651 .74 .914 r
.4624 .3943 .46574 .39788 .4716 .39606 .46827 .39252 Mtetra
.643 .74 .919 r
.46827 .39252 .4716 .39606 .47748 .39434 .47416 .39084 Mtetra
.63 .738 .926 r
.47416 .39084 .47748 .39434 .48337 .39278 .48006 .38934 Mtetra
.605 .734 .936 r
.48006 .38934 .48337 .39278 .48928 .39145 .48597 .38813 Mtetra
.555 .724 .952 r
.48597 .38813 .48928 .39145 .49519 .39053 .49189 .38744 Mtetra
.448 .693 .97 r
.49189 .38744 .49519 .39053 .50112 .39028 .49782 .38756 Mtetra
.196 .584 .942 r
.49782 .38756 .50112 .39028 .50705 .3911 .50376 .38898 Mtetra
0 .24 .657 r
.50376 .38898 .50705 .3911 .51301 .39361 .50972 .3924 Mtetra
.722 .191 0 r
.50972 .3924 .51301 .39361 .51899 .39863 .5157 .39879 Mtetra
.844 .399 .163 r
.5157 .39879 .51899 .39863 .52501 .4072 .52173 .40926 Mtetra
.867 .478 .301 r
.52173 .40926 .52501 .4072 .5311 .42023 .52781 .4245 Mtetra
.864 .502 .363 r
.52781 .4245 .5311 .42023 .53726 .4376 .53399 .44366 Mtetra
.845 .492 .384 r
.53399 .44366 .53726 .4376 .54353 .45686 .54026 .46305 Mtetra
.797 .428 .358 r
.54026 .46305 .54353 .45686 .54986 .47256 .54659 .47618 Mtetra
.499 .025 .062 r
.54659 .47618 .54986 .47256 .55618 .47834 .55289 .47745 Mtetra
.942 .888 .749 r
.55289 .47745 .55618 .47834 .56241 .4718 .55909 .46711 Mtetra
.906 .745 .671 r
.55909 .46711 .56241 .4718 .56852 .4571 .56522 .45174 Mtetra
.871 .73 .703 r
.56522 .45174 .56852 .4571 .57459 .44218 .57135 .43983 Mtetra
.628 .829 .978 r
.57135 .43983 .57459 .44218 .58075 .43439 .57763 .43797 Mtetra
.814 .41 .284 r
.57763 .43797 .58075 .43439 .58714 .43875 .58416 .44973 Mtetra
.828 .494 .423 r
.58416 .44973 .58714 .43875 .59386 .45749 .59102 .47427 Mtetra
.804 .487 .453 r
.59102 .47427 .59386 .45749 .60094 .48745 .59808 .50255 Mtetra
.728 .404 .431 r
.59808 .50255 .60094 .48745 .60812 .51564 .60494 .51682 Mtetra
.975 .924 .661 r
.60494 .51682 .60812 .51564 .61485 .52242 .61116 .50341 Mtetra
.851 .616 .582 r
.61116 .50341 .61485 .52242 .62076 .49891 .61673 .46757 Mtetra
.806 .566 .575 r
.61673 .46757 .62076 .49891 .62604 .45741 .62202 .42659 Mtetra
.785 .551 .582 r
.62202 .42659 .62604 .45741 .6312 .41646 .6274 .39277 Mtetra
.775 .554 .599 r
.6274 .39277 .6312 .41646 .63657 .38543 .63301 .36906 Mtetra
.771 .572 .63 r
.63301 .36906 .63657 .38543 .64221 .36473 .63884 .35358 Mtetra
.767 .602 .675 r
.63884 .35358 .64221 .36473 .64809 .35155 .64485 .3436 Mtetra
.758 .64 .731 r
.64485 .3436 .64809 .35155 .65412 .34308 .65097 .33696 Mtetra
.742 .676 .786 r
.65097 .33696 .65412 .34308 .66027 .33737 .65716 .33225 Mtetra
.723 .704 .832 r
.65716 .33225 .66027 .33737 .66648 .33323 .66341 .32866 Mtetra
.704 .721 .863 r
.66341 .32866 .66648 .33323 .67275 .32997 .6697 .3257 Mtetra
.689 .73 .882 r
.6697 .3257 .67275 .32997 .67904 .32721 .67601 .32308 Mtetra
.68 .735 .893 r
.67601 .32308 .67904 .32721 .68537 .32471 .68234 .32067 Mtetra
.673 .738 .899 r
.68234 .32067 .68537 .32471 .69171 .32237 .6887 .31837 Mtetra
.67 .739 .902 r
.6887 .31837 .69171 .32237 .69807 .32012 .69507 .31614 Mtetra
.667 .74 .905 r
.69507 .31614 .69807 .32012 .70445 .31791 .70146 .31394 Mtetra
.666 .74 .906 r
.70146 .31394 .70445 .31791 .71084 .31573 .70787 .31175 Mtetra
.665 .741 .906 r
.70787 .31175 .71084 .31573 .71725 .31356 .71429 .30958 Mtetra
.665 .741 .907 r
.71429 .30958 .71725 .31356 .72368 .31139 .72072 .30741 Mtetra
.664 .741 .907 r
.72072 .30741 .72368 .31139 .73011 .30923 .72717 .30524 Mtetra
.72717 .30524 .73011 .30923 .73657 .30707 .73363 .30307 Mtetra
.73363 .30307 .73657 .30707 .74304 .3049 .74011 .30089 Mtetra
.74011 .30089 .74304 .3049 .74952 .30273 .74661 .29871 Mtetra
.74661 .29871 .74952 .30273 .75602 .30055 .75312 .29653 Mtetra
.75312 .29653 .75602 .30055 .76253 .29837 .75964 .29434 Mtetra
.75964 .29434 .76253 .29837 .76906 .29619 .76618 .29214 Mtetra
.76618 .29214 .76906 .29619 .7756 .294 .77273 .28995 Mtetra
.77273 .28995 .7756 .294 .78216 .29181 .7793 .28774 Mtetra
.7793 .28774 .78216 .29181 .78873 .28961 .78588 .28554 Mtetra
.78588 .28554 .78873 .28961 .79532 .2874 .79248 .28332 Mtetra
.79248 .28332 .79532 .2874 .80192 .2852 .79909 .2811 Mtetra
.79909 .2811 .80192 .2852 .80854 .28298 .80572 .27888 Mtetra
.80572 .27888 .80854 .28298 .81517 .28076 .81237 .27665 Mtetra
.81237 .27665 .81517 .28076 .82182 .27854 .81903 .27442 Mtetra
.81903 .27442 .82182 .27854 .82849 .27631 .8257 .27218 Mtetra
.8257 .27218 .82849 .27631 .83516 .27408 .83239 .26994 Mtetra
.83239 .26994 .83516 .27408 .84186 .27184 .83909 .26769 Mtetra
.83909 .26769 .84186 .27184 .84857 .26959 .84582 .26543 Mtetra
.84582 .26543 .84857 .26959 .85529 .26734 .85255 .26317 Mtetra
.85255 .26317 .85529 .26734 .86203 .26509 .8593 .26091 Mtetra
.25533 .4589 .25894 .46227 .26439 .46044 .26078 .45706 Mtetra
.26078 .45706 .26439 .46044 .26985 .45861 .26625 .45522 Mtetra
.26625 .45522 .26985 .45861 .27532 .45678 .27172 .45338 Mtetra
.27172 .45338 .27532 .45678 .2808 .45494 .27721 .45154 Mtetra
.27721 .45154 .2808 .45494 .28629 .4531 .28271 .44969 Mtetra
.28271 .44969 .28629 .4531 .29179 .45125 .28822 .44784 Mtetra
.28822 .44784 .29179 .45125 .2973 .4494 .29374 .44598 Mtetra
.29374 .44598 .2973 .4494 .30283 .44755 .29927 .44412 Mtetra
.29927 .44412 .30283 .44755 .30837 .44569 .30482 .44225 Mtetra
.30482 .44225 .30837 .44569 .31392 .44383 .31037 .44039 Mtetra
.31037 .44039 .31392 .44383 .31948 .44197 .31594 .43851 Mtetra
.31594 .43851 .31948 .44197 .32505 .4401 .32152 .43664 Mtetra
.32152 .43664 .32505 .4401 .33064 .43823 .32711 .43476 Mtetra
.32711 .43476 .33064 .43823 .33623 .43635 .33272 .43287 Mtetra
.33272 .43287 .33623 .43635 .34184 .43447 .33833 .43098 Mtetra
.33833 .43098 .34184 .43447 .34746 .43258 .34396 .42909 Mtetra
.34396 .42909 .34746 .43258 .35309 .43069 .3496 .4272 Mtetra
.3496 .4272 .35309 .43069 .35873 .4288 .35525 .4253 Mtetra
.35525 .4253 .35873 .4288 .36439 .4269 .36091 .42339 Mtetra
.36091 .42339 .36439 .4269 .37006 .425 .36659 .42148 Mtetra
.36659 .42148 .37006 .425 .37574 .4231 .37227 .41957 Mtetra
.37227 .41957 .37574 .4231 .38143 .42119 .37797 .41765 Mtetra
.37797 .41765 .38143 .42119 .38713 .41928 .38368 .41574 Mtetra
.38368 .41574 .38713 .41928 .39285 .41736 .38941 .41381 Mtetra
.38941 .41381 .39285 .41736 .39858 .41544 .39514 .41188 Mtetra
.39514 .41188 .39858 .41544 .40432 .41351 .40089 .40995 Mtetra
.40089 .40995 .40432 .41351 .41007 .41159 .40665 .40801 Mtetra
.40665 .40801 .41007 .41159 .41584 .40966 .41242 .40608 Mtetra
.41242 .40608 .41584 .40966 .42161 .40772 .41821 .40414 Mtetra
.664 .741 .908 r
.41821 .40414 .42161 .40772 .4274 .40578 .42401 .40219 Mtetra
.663 .741 .908 r
.42401 .40219 .4274 .40578 .43321 .40384 .42982 .40024 Mtetra
.42982 .40024 .43321 .40384 .43902 .40191 .43564 .39831 Mtetra
.662 .74 .908 r
.43564 .39831 .43902 .40191 .44485 .39999 .44147 .39638 Mtetra
.661 .74 .909 r
.44147 .39638 .44485 .39999 .45069 .39806 .44732 .39446 Mtetra
.659 .741 .91 r
.44732 .39446 .45069 .39806 .45654 .39616 .45318 .39257 Mtetra
.655 .741 .912 r
.45318 .39257 .45654 .39616 .4624 .3943 .45905 .39072 Mtetra
.649 .74 .916 r
.45905 .39072 .4624 .3943 .46827 .39252 .46493 .38896 Mtetra
.639 .738 .921 r
.46493 .38896 .46827 .39252 .47416 .39084 .47083 .38733 Mtetra
.621 .736 .929 r
.47083 .38733 .47416 .39084 .48006 .38934 .47673 .38594 Mtetra
.589 .731 .942 r
.47673 .38594 .48006 .38934 .48597 .38813 .48264 .3849 Mtetra
.522 .717 .961 r
.48264 .3849 .48597 .38813 .49189 .38744 .48857 .38448 Mtetra
.372 .666 .972 r
.48857 .38448 .49189 .38744 .49782 .38756 .4945 .38505 Mtetra
.013 .477 .872 r
.4945 .38505 .49782 .38756 .50376 .38898 .50045 .38719 Mtetra
.533 0 0 r
.50045 .38719 .50376 .38898 .50972 .3924 .5064 .39176 Mtetra
.799 .309 .026 r
.5064 .39176 .50972 .3924 .5157 .39879 .51239 .39983 Mtetra
.859 .446 .244 r
.51239 .39983 .5157 .39879 .52173 .40926 .51841 .41251 Mtetra
.867 .496 .341 r
.51841 .41251 .52173 .40926 .52781 .4245 .5245 .43013 Mtetra
.857 .505 .385 r
.5245 .43013 .52781 .4245 .53399 .44366 .53069 .45086 Mtetra
.829 .48 .393 r
.53069 .45086 .53399 .44366 .54026 .46305 .53697 .4695 Mtetra
.749 .371 .338 r
.53697 .4695 .54026 .46305 .54659 .47618 .54329 .47898 Mtetra
0 0 0 r
.54329 .47898 .54659 .47618 .55289 .47745 .54957 .47541 Mtetra
.941 .822 .7 r
.54957 .47541 .55289 .47745 .55909 .46711 .55576 .46215 Mtetra
.897 .74 .679 r
.55576 .46215 .55909 .46711 .56522 .45174 .56192 .44764 Mtetra
.843 .769 .78 r
.56192 .44764 .56522 .45174 .57135 .43983 .56813 .44011 Mtetra
.647 .098 0 r
.56813 .44011 .57135 .43983 .57763 .43797 .57452 .44478 Mtetra
.829 .47 .375 r
.57452 .44478 .57763 .43797 .58416 .44973 .58118 .4627 Mtetra
.818 .49 .435 r
.58118 .4627 .58416 .44973 .59102 .47427 .58808 .4883 Mtetra
.773 .446 .432 r
.58808 .4883 .59102 .47427 .59808 .50255 .59496 .5074 Mtetra
.156 0 0 r
.59496 .5074 .59808 .50255 .60494 .51682 .60143 .50418 Mtetra
.87 .649 .601 r
.60143 .50418 .60494 .51682 .61116 .50341 .60729 .47636 Mtetra
.819 .58 .578 r
.60729 .47636 .61116 .50341 .61673 .46757 .61277 .43733 Mtetra
.795 .559 .58 r
.61277 .43733 .61673 .46757 .62202 .42659 .6182 .40143 Mtetra
.782 .556 .593 r
.6182 .40143 .62202 .42659 .6274 .39277 .62379 .37463 Mtetra
.777 .569 .619 r
.62379 .37463 .6274 .39277 .63301 .36906 .62959 .35655 Mtetra
.773 .595 .658 r
.62959 .35655 .63301 .36906 .63884 .35358 .63556 .34474 Mtetra
.766 .629 .71 r
.63556 .34474 .63884 .35358 .64485 .3436 .64165 .33694 Mtetra
.752 .666 .766 r
.64165 .33694 .64485 .3436 .65097 .33696 .64782 .33152 Mtetra
.733 .696 .815 r
.64782 .33152 .65097 .33696 .65716 .33225 .65406 .3275 Mtetra
.713 .716 .851 r
.65406 .3275 .65716 .33225 .66341 .32866 .66033 .32427 Mtetra
.696 .727 .874 r
.66033 .32427 .66341 .32866 .6697 .3257 .66664 .32151 Mtetra
.684 .734 .888 r
.66664 .32151 .6697 .3257 .67601 .32308 .67296 .319 Mtetra
.676 .737 .896 r
.67296 .319 .67601 .32308 .68234 .32067 .67931 .31664 Mtetra
.671 .739 .901 r
.67931 .31664 .68234 .32067 .6887 .31837 .68568 .31437 Mtetra
.668 .74 .904 r
.68568 .31437 .6887 .31837 .69507 .31614 .69206 .31215 Mtetra
.667 .74 .905 r
.69206 .31215 .69507 .31614 .70146 .31394 .69846 .30995 Mtetra
.666 .741 .906 r
.69846 .30995 .70146 .31394 .70787 .31175 .70488 .30776 Mtetra
.665 .741 .907 r
.70488 .30776 .70787 .31175 .71429 .30958 .71131 .30559 Mtetra
.664 .741 .907 r
.71131 .30559 .71429 .30958 .72072 .30741 .71775 .30341 Mtetra
.71775 .30341 .72072 .30741 .72717 .30524 .72421 .30123 Mtetra
.72421 .30123 .72717 .30524 .73363 .30307 .73069 .29905 Mtetra
.73069 .29905 .73363 .30307 .74011 .30089 .73718 .29686 Mtetra
.73718 .29686 .74011 .30089 .74661 .29871 .74368 .29468 Mtetra
.74368 .29468 .74661 .29871 .75312 .29653 .7502 .29248 Mtetra
.7502 .29248 .75312 .29653 .75964 .29434 .75673 .29029 Mtetra
.75673 .29029 .75964 .29434 .76618 .29214 .76328 .28808 Mtetra
.76328 .28808 .76618 .29214 .77273 .28995 .76985 .28588 Mtetra
.76985 .28588 .77273 .28995 .7793 .28774 .77642 .28366 Mtetra
.77642 .28366 .7793 .28774 .78588 .28554 .78302 .28145 Mtetra
.78302 .28145 .78588 .28554 .79248 .28332 .78963 .27922 Mtetra
.78963 .27922 .79248 .28332 .79909 .2811 .79625 .277 Mtetra
.79625 .277 .79909 .2811 .80572 .27888 .80289 .27476 Mtetra
.80289 .27476 .80572 .27888 .81237 .27665 .80955 .27253 Mtetra
.80955 .27253 .81237 .27665 .81903 .27442 .81622 .27028 Mtetra
.81622 .27028 .81903 .27442 .8257 .27218 .8229 .26803 Mtetra
.8229 .26803 .8257 .27218 .83239 .26994 .8296 .26578 Mtetra
.8296 .26578 .83239 .26994 .83909 .26769 .83632 .26352 Mtetra
.83632 .26352 .83909 .26769 .84582 .26543 .84305 .26126 Mtetra
.84305 .26126 .84582 .26543 .85255 .26317 .8498 .25899 Mtetra
.8498 .25899 .85255 .26317 .8593 .26091 .85656 .25671 Mtetra
.2517 .45551 .25533 .4589 .26078 .45706 .25716 .45367 Mtetra
.25716 .45367 .26078 .45706 .26625 .45522 .26263 .45182 Mtetra
.26263 .45182 .26625 .45522 .27172 .45338 .26811 .44997 Mtetra
.26811 .44997 .27172 .45338 .27721 .45154 .27361 .44812 Mtetra
.27361 .44812 .27721 .45154 .28271 .44969 .27911 .44627 Mtetra
.27911 .44627 .28271 .44969 .28822 .44784 .28463 .44441 Mtetra
.28463 .44441 .28822 .44784 .29374 .44598 .29016 .44254 Mtetra
.29016 .44254 .29374 .44598 .29927 .44412 .2957 .44067 Mtetra
.2957 .44067 .29927 .44412 .30482 .44225 .30125 .4388 Mtetra
.30125 .4388 .30482 .44225 .31037 .44039 .30681 .43693 Mtetra
.30681 .43693 .31037 .44039 .31594 .43851 .31239 .43505 Mtetra
.31239 .43505 .31594 .43851 .32152 .43664 .31798 .43316 Mtetra
.31798 .43316 .32152 .43664 .32711 .43476 .32357 .43128 Mtetra
.32357 .43128 .32711 .43476 .33272 .43287 .32918 .42938 Mtetra
.32918 .42938 .33272 .43287 .33833 .43098 .33481 .42749 Mtetra
.33481 .42749 .33833 .43098 .34396 .42909 .34044 .42559 Mtetra
.34044 .42559 .34396 .42909 .3496 .4272 .34609 .42368 Mtetra
.34609 .42368 .3496 .4272 .35525 .4253 .35175 .42178 Mtetra
.35175 .42178 .35525 .4253 .36091 .42339 .35742 .41987 Mtetra
.35742 .41987 .36091 .42339 .36659 .42148 .3631 .41795 Mtetra
.3631 .41795 .36659 .42148 .37227 .41957 .36879 .41603 Mtetra
.36879 .41603 .37227 .41957 .37797 .41765 .3745 .41411 Mtetra
.3745 .41411 .37797 .41765 .38368 .41574 .38022 .41218 Mtetra
.38022 .41218 .38368 .41574 .38941 .41381 .38595 .41025 Mtetra
.38595 .41025 .38941 .41381 .39514 .41188 .39169 .40831 Mtetra
.39169 .40831 .39514 .41188 .40089 .40995 .39745 .40637 Mtetra
.39745 .40637 .40089 .40995 .40665 .40801 .40322 .40443 Mtetra
.664 .741 .908 r
.40322 .40443 .40665 .40801 .41242 .40608 .409 .40248 Mtetra
.664 .741 .907 r
.409 .40248 .41242 .40608 .41821 .40414 .41479 .40053 Mtetra
.41479 .40053 .41821 .40414 .42401 .40219 .4206 .39858 Mtetra
.663 .741 .908 r
.4206 .39858 .42401 .40219 .42982 .40024 .42641 .39663 Mtetra
.662 .741 .908 r
.42641 .39663 .42982 .40024 .43564 .39831 .43224 .39469 Mtetra
.661 .741 .909 r
.43224 .39469 .43564 .39831 .44147 .39638 .43809 .39276 Mtetra
.66 .741 .909 r
.43809 .39276 .44147 .39638 .44732 .39446 .44394 .39084 Mtetra
.658 .74 .911 r
.44394 .39084 .44732 .39446 .45318 .39257 .44981 .38896 Mtetra
.653 .74 .913 r
.44981 .38896 .45318 .39257 .45905 .39072 .45569 .38713 Mtetra
.646 .739 .917 r
.45569 .38713 .45905 .39072 .46493 .38896 .46158 .38542 Mtetra
.633 .738 .924 r
.46158 .38542 .46493 .38896 .47083 .38733 .46748 .38386 Mtetra
.611 .735 .934 r
.46748 .38386 .47083 .38733 .47673 .38594 .47339 .38257 Mtetra
.568 .727 .949 r
.47339 .38257 .47673 .38594 .48264 .3849 .47931 .38175 Mtetra
.475 .702 .968 r
.47931 .38175 .48264 .3849 .48857 .38448 .48523 .38168 Mtetra
.253 .613 .956 r
.48523 .38168 .48857 .38448 .4945 .38505 .49117 .38283 Mtetra
0 .303 .718 r
.49117 .38283 .4945 .38505 .50045 .38719 .49711 .38589 Mtetra
.696 .155 0 r
.49711 .38589 .50045 .38719 .5064 .39176 .50306 .39187 Mtetra
.839 .39 .153 r
.50306 .39187 .5064 .39176 .51239 .39983 .50904 .40199 Mtetra
.866 .478 .305 r
.50904 .40199 .51239 .39983 .51841 .41251 .51506 .41727 Mtetra
.863 .506 .374 r
.51506 .41727 .51841 .41251 .5245 .43013 .52116 .4374 Mtetra
.846 .502 .403 r
.52116 .4374 .5245 .43013 .53069 .45086 .52735 .45916 Mtetra
.805 .457 .398 r
.52735 .45916 .53069 .45086 .53697 .4695 .53363 .47585 Mtetra
.652 .257 .284 r
.53363 .47585 .53697 .4695 .54329 .47898 .53995 .48057 Mtetra
.883 .989 .736 r
.53995 .48057 .54329 .47898 .54957 .47541 .54622 .47219 Mtetra
.928 .782 .679 r
.54622 .47219 .54957 .47541 .55576 .46215 .55242 .4572 Mtetra
.881 .742 .703 r
.55242 .4572 .55576 .46215 .56192 .44764 .55862 .44499 Mtetra
.666 .821 .958 r
.55862 .44499 .56192 .44764 .56813 .44011 .56492 .44274 Mtetra
.813 .39 .242 r
.56492 .44274 .56813 .44011 .57452 .44478 .57141 .45344 Mtetra
.83 .484 .401 r
.57141 .45344 .57452 .44478 .58118 .4627 .57813 .47449 Mtetra
.802 .467 .422 r
.57813 .47449 .58118 .4627 .58808 .4883 .58496 .49541 Mtetra
.659 .271 .299 r
.58496 .49541 .58808 .4883 .59496 .5074 .59157 .50072 Mtetra
.896 .712 .646 r
.59157 .50072 .59496 .5074 .60143 .50418 .59771 .48228 Mtetra
.831 .597 .585 r
.59771 .48228 .60143 .50418 .60729 .47636 .60341 .44769 Mtetra
.804 .567 .58 r
.60341 .44769 .60729 .47636 .61277 .43733 .60895 .41118 Mtetra
.79 .56 .589 r
.60895 .41118 .61277 .43733 .6182 .40143 .61456 .3816 Mtetra
.783 .568 .609 r
.61456 .3816 .6182 .40143 .62379 .37463 .62033 .36067 Mtetra
.779 .589 .643 r
.62033 .36067 .62379 .37463 .62959 .35655 .62626 .34671 Mtetra
.774 .62 .689 r
.62626 .34671 .62959 .35655 .63556 .34474 .63232 .33745 Mtetra
.762 .656 .744 r
.63232 .33745 .63556 .34474 .64165 .33694 .63848 .33112 Mtetra
.744 .687 .796 r
.63848 .33112 .64165 .33694 .64782 .33152 .64469 .32654 Mtetra
.723 .71 .838 r
.64469 .32654 .64782 .33152 .65406 .3275 .65095 .32297 Mtetra
.704 .724 .865 r
.65095 .32297 .65406 .3275 .66033 .32427 .65725 .32 Mtetra
.69 .732 .883 r
.65725 .32 .66033 .32427 .66664 .32151 .66357 .31737 Mtetra
.68 .736 .893 r
.66357 .31737 .66664 .32151 .67296 .319 .66991 .31494 Mtetra
.674 .738 .899 r
.66991 .31494 .67296 .319 .67931 .31664 .67627 .31262 Mtetra
.67 .739 .902 r
.67627 .31262 .67931 .31664 .68568 .31437 .68265 .31037 Mtetra
.668 .74 .904 r
.68265 .31037 .68568 .31437 .69206 .31215 .68904 .30815 Mtetra
.666 .74 .906 r
.68904 .30815 .69206 .31215 .69846 .30995 .69545 .30595 Mtetra
.665 .741 .906 r
.69545 .30595 .69846 .30995 .70488 .30776 .70188 .30376 Mtetra
.665 .741 .907 r
.70188 .30376 .70488 .30776 .71131 .30559 .70832 .30158 Mtetra
.664 .741 .907 r
.70832 .30158 .71131 .30559 .71775 .30341 .71477 .29939 Mtetra
.71477 .29939 .71775 .30341 .72421 .30123 .72124 .2972 Mtetra
.72124 .2972 .72421 .30123 .73069 .29905 .72773 .29502 Mtetra
.72773 .29502 .73069 .29905 .73718 .29686 .73423 .29282 Mtetra
.73423 .29282 .73718 .29686 .74368 .29468 .74074 .29062 Mtetra
.74074 .29062 .74368 .29468 .7502 .29248 .74727 .28842 Mtetra
.74727 .28842 .7502 .29248 .75673 .29029 .75382 .28622 Mtetra
.75382 .28622 .75673 .29029 .76328 .28808 .76037 .284 Mtetra
.76037 .284 .76328 .28808 .76985 .28588 .76695 .28179 Mtetra
.76695 .28179 .76985 .28588 .77642 .28366 .77354 .27957 Mtetra
.77354 .27957 .77642 .28366 .78302 .28145 .78014 .27734 Mtetra
.78014 .27734 .78302 .28145 .78963 .27922 .78676 .27511 Mtetra
.78676 .27511 .78963 .27922 .79625 .277 .7934 .27287 Mtetra
.7934 .27287 .79625 .277 .80289 .27476 .80005 .27063 Mtetra
.80005 .27063 .80289 .27476 .80955 .27253 .80671 .26838 Mtetra
.80671 .26838 .80955 .27253 .81622 .27028 .8134 .26613 Mtetra
.8134 .26613 .81622 .27028 .8229 .26803 .82009 .26387 Mtetra
.82009 .26387 .8229 .26803 .8296 .26578 .8268 .26161 Mtetra
.8268 .26161 .8296 .26578 .83632 .26352 .83353 .25934 Mtetra
.83353 .25934 .83632 .26352 .84305 .26126 .84027 .25706 Mtetra
.84027 .25706 .84305 .26126 .8498 .25899 .84703 .25479 Mtetra
.84703 .25479 .8498 .25899 .85656 .25671 .85381 .2525 Mtetra
.24806 .45211 .2517 .45551 .25716 .45367 .25353 .45026 Mtetra
.25353 .45026 .25716 .45367 .26263 .45182 .259 .44841 Mtetra
.259 .44841 .26263 .45182 .26811 .44997 .26449 .44655 Mtetra
.26449 .44655 .26811 .44997 .27361 .44812 .26999 .44469 Mtetra
.26999 .44469 .27361 .44812 .27911 .44627 .27551 .44283 Mtetra
.27551 .44283 .27911 .44627 .28463 .44441 .28103 .44096 Mtetra
.28103 .44096 .28463 .44441 .29016 .44254 .28656 .43909 Mtetra
.28656 .43909 .29016 .44254 .2957 .44067 .29211 .43722 Mtetra
.29211 .43722 .2957 .44067 .30125 .4388 .29767 .43534 Mtetra
.29767 .43534 .30125 .4388 .30681 .43693 .30324 .43345 Mtetra
.30324 .43345 .30681 .43693 .31239 .43505 .30882 .43157 Mtetra
.30882 .43157 .31239 .43505 .31798 .43316 .31442 .42968 Mtetra
.31442 .42968 .31798 .43316 .32357 .43128 .32002 .42778 Mtetra
.32002 .42778 .32357 .43128 .32918 .42938 .32564 .42588 Mtetra
.32564 .42588 .32918 .42938 .33481 .42749 .33127 .42398 Mtetra
.33127 .42398 .33481 .42749 .34044 .42559 .33691 .42207 Mtetra
.33691 .42207 .34044 .42559 .34609 .42368 .34257 .42016 Mtetra
.34257 .42016 .34609 .42368 .35175 .42178 .34823 .41824 Mtetra
.34823 .41824 .35175 .42178 .35742 .41987 .35391 .41632 Mtetra
.35391 .41632 .35742 .41987 .3631 .41795 .3596 .4144 Mtetra
.3596 .4144 .3631 .41795 .36879 .41603 .3653 .41247 Mtetra
.3653 .41247 .36879 .41603 .3745 .41411 .37102 .41054 Mtetra
.37102 .41054 .3745 .41411 .38022 .41218 .37674 .40861 Mtetra
.37674 .40861 .38022 .41218 .38595 .41025 .38248 .40667 Mtetra
.38248 .40667 .38595 .41025 .39169 .40831 .38823 .40472 Mtetra
.38823 .40472 .39169 .40831 .39745 .40637 .394 .40277 Mtetra
.394 .40277 .39745 .40637 .40322 .40443 .39977 .40083 Mtetra
.663 .741 .907 r
.39977 .40083 .40322 .40443 .409 .40248 .40556 .39888 Mtetra
.663 .741 .908 r
.40556 .39888 .409 .40248 .41479 .40053 .41136 .39692 Mtetra
.664 .741 .908 r
.41136 .39692 .41479 .40053 .4206 .39858 .41717 .39496 Mtetra
.663 .741 .908 r
.41717 .39496 .4206 .39858 .42641 .39663 .423 .39301 Mtetra
.662 .741 .908 r
.423 .39301 .42641 .39663 .43224 .39469 .42884 .39106 Mtetra
.661 .74 .909 r
.42884 .39106 .43224 .39469 .43809 .39276 .43469 .38913 Mtetra
.659 .741 .91 r
.43469 .38913 .43809 .39276 .44394 .39084 .44055 .38722 Mtetra
.656 .741 .912 r
.44055 .38722 .44394 .39084 .44981 .38896 .44642 .38535 Mtetra
.651 .74 .915 r
.44642 .38535 .44981 .38896 .45569 .38713 .45231 .38355 Mtetra
.642 .739 .919 r
.45231 .38355 .45569 .38713 .46158 .38542 .45821 .38188 Mtetra
.626 .737 .927 r
.45821 .38188 .46158 .38542 .46748 .38386 .46411 .38041 Mtetra
.597 .733 .939 r
.46411 .38041 .46748 .38386 .47339 .38257 .47003 .37929 Mtetra
.537 .721 .958 r
.47003 .37929 .47339 .38257 .47931 .38175 .47595 .37872 Mtetra
.404 .679 .973 r
.47595 .37872 .47931 .38175 .48523 .38168 .48188 .37909 Mtetra
.075 .517 .9 r
.48188 .37909 .48523 .38168 .49117 .38283 .48781 .38097 Mtetra
.489 0 0 r
.48781 .38097 .49117 .38283 .49711 .38589 .49375 .38521 Mtetra
.791 .296 .011 r
.49375 .38521 .49711 .38589 .50306 .39187 .4997 .393 Mtetra
.858 .445 .248 r
.4997 .393 .50306 .39187 .50904 .40199 .50566 .40564 Mtetra
.866 .499 .352 r
.50566 .40564 .50904 .40199 .51506 .41727 .51168 .42391 Mtetra
.855 .511 .401 r
.51168 .42391 .51506 .41727 .52116 .4374 .51777 .44651 Mtetra
.829 .492 .417 r
.51777 .44651 .52116 .4374 .52735 .45916 .52397 .46838 Mtetra
.765 .416 .394 r
.52397 .46838 .52735 .45916 .53363 .47585 .53027 .48152 Mtetra
.38 0 .113 r
.53027 .48152 .53363 .47585 .53995 .48057 .53658 .48043 Mtetra
.966 .887 .702 r
.53658 .48043 .53995 .48057 .54622 .47219 .54285 .46769 Mtetra
.908 .75 .674 r
.54285 .46769 .54622 .47219 .55242 .4572 .54907 .45239 Mtetra
.846 .745 .751 r
.54907 .45239 .55242 .4572 .55862 .44499 .55532 .44373 Mtetra
.374 0 0 r
.55532 .44373 .55862 .44499 .56492 .44274 .56169 .4469 Mtetra
.837 .451 .321 r
.56169 .4469 .56492 .44274 .57141 .45344 .56825 .46181 Mtetra
.825 .476 .394 r
.56825 .46181 .57141 .45344 .57813 .47449 .57497 .48164 Mtetra
.766 .393 .348 r
.57497 .48164 .57813 .47449 .58496 .49541 .58164 .49314 Mtetra
.899 .855 .79 r
.58164 .49314 .58496 .49541 .59157 .50072 .588 .4846 Mtetra
.842 .619 .6 r
.588 .4846 .59157 .50072 .59771 .48228 .59394 .45685 Mtetra
.814 .579 .583 r
.59394 .45685 .59771 .48228 .60341 .44769 .59963 .42165 Mtetra
.799 .567 .586 r
.59963 .42165 .60341 .44769 .60895 .41118 .60528 .38996 Mtetra
.79 .57 .602 r
.60528 .38996 .60895 .41118 .61456 .3816 .61105 .3661 Mtetra
.786 .585 .629 r
.61105 .3661 .61456 .3816 .62033 .36067 .61696 .34965 Mtetra
.781 .612 .67 r
.61696 .34965 .62033 .36067 .62626 .34671 .62299 .33863 Mtetra
.772 .645 .722 r
.62299 .33863 .62626 .34671 .63232 .33745 .62912 .33115 Mtetra
.756 .677 .775 r
.62912 .33115 .63232 .33745 .63848 .33112 .63531 .32584 Mtetra
.735 .703 .821 r
.63531 .32584 .63848 .33112 .64469 .32654 .64156 .32184 Mtetra
.714 .72 .854 r
.64156 .32184 .64469 .32654 .65095 .32297 .64784 .3186 Mtetra
.697 .73 .876 r
.64784 .3186 .65095 .32297 .65725 .32 .65415 .3158 Mtetra
.685 .735 .889 r
.65415 .3158 .65725 .32 .66357 .31737 .66049 .31327 Mtetra
.677 .738 .896 r
.66049 .31327 .66357 .31737 .66991 .31494 .66684 .31089 Mtetra
.672 .739 .901 r
.66684 .31089 .66991 .31494 .67627 .31262 .67322 .30859 Mtetra
.669 .74 .903 r
.67322 .30859 .67627 .31262 .68265 .31037 .67961 .30635 Mtetra
.667 .74 .905 r
.67961 .30635 .68265 .31037 .68904 .30815 .68601 .30414 Mtetra
.666 .741 .906 r
.68601 .30414 .68904 .30815 .69545 .30595 .69243 .30194 Mtetra
.665 .741 .907 r
.69243 .30194 .69545 .30595 .70188 .30376 .69887 .29974 Mtetra
.69887 .29974 .70188 .30376 .70832 .30158 .70532 .29755 Mtetra
.664 .741 .907 r
.70532 .29755 .70832 .30158 .71477 .29939 .71178 .29536 Mtetra
.71178 .29536 .71477 .29939 .72124 .2972 .71826 .29316 Mtetra
.71826 .29316 .72124 .2972 .72773 .29502 .72476 .29096 Mtetra
.72476 .29096 .72773 .29502 .73423 .29282 .73127 .28876 Mtetra
.73127 .28876 .73423 .29282 .74074 .29062 .73779 .28656 Mtetra
.73779 .28656 .74074 .29062 .74727 .28842 .74433 .28434 Mtetra
.74433 .28434 .74727 .28842 .75382 .28622 .75089 .28213 Mtetra
.75089 .28213 .75382 .28622 .76037 .284 .75746 .27991 Mtetra
.75746 .27991 .76037 .284 .76695 .28179 .76404 .27768 Mtetra
.76404 .27768 .76695 .28179 .77354 .27957 .77064 .27545 Mtetra
.77064 .27545 .77354 .27957 .78014 .27734 .77726 .27321 Mtetra
.77726 .27321 .78014 .27734 .78676 .27511 .78389 .27097 Mtetra
.78389 .27097 .78676 .27511 .7934 .27287 .79053 .26873 Mtetra
.79053 .26873 .7934 .27287 .80005 .27063 .79719 .26648 Mtetra
.79719 .26648 .80005 .27063 .80671 .26838 .80387 .26422 Mtetra
.80387 .26422 .80671 .26838 .8134 .26613 .81056 .26196 Mtetra
.81056 .26196 .8134 .26613 .82009 .26387 .81727 .25969 Mtetra
.81727 .25969 .82009 .26387 .8268 .26161 .82399 .25742 Mtetra
.82399 .25742 .8268 .26161 .83353 .25934 .83073 .25514 Mtetra
.83073 .25514 .83353 .25934 .84027 .25706 .83749 .25285 Mtetra
.83749 .25285 .84027 .25706 .84703 .25479 .84426 .25057 Mtetra
.84426 .25057 .84703 .25479 .85381 .2525 .85104 .24827 Mtetra
.2444 .44869 .24806 .45211 .25353 .45026 .24988 .44684 Mtetra
.24988 .44684 .25353 .45026 .259 .44841 .25536 .44498 Mtetra
.25536 .44498 .259 .44841 .26449 .44655 .26086 .44312 Mtetra
.26086 .44312 .26449 .44655 .26999 .44469 .26637 .44125 Mtetra
.26637 .44125 .26999 .44469 .27551 .44283 .27188 .43938 Mtetra
.27188 .43938 .27551 .44283 .28103 .44096 .27741 .4375 Mtetra
.27741 .4375 .28103 .44096 .28656 .43909 .28296 .43563 Mtetra
.28296 .43563 .28656 .43909 .29211 .43722 .28851 .43374 Mtetra
.28851 .43374 .29211 .43722 .29767 .43534 .29408 .43186 Mtetra
.29408 .43186 .29767 .43534 .30324 .43345 .29965 .42997 Mtetra
.29965 .42997 .30324 .43345 .30882 .43157 .30524 .42807 Mtetra
.30524 .42807 .30882 .43157 .31442 .42968 .31084 .42617 Mtetra
.31084 .42617 .31442 .42968 .32002 .42778 .31646 .42427 Mtetra
.31646 .42427 .32002 .42778 .32564 .42588 .32208 .42236 Mtetra
.32208 .42236 .32564 .42588 .33127 .42398 .32772 .42045 Mtetra
.32772 .42045 .33127 .42398 .33691 .42207 .33337 .41854 Mtetra
.33337 .41854 .33691 .42207 .34257 .42016 .33903 .41662 Mtetra
.33903 .41662 .34257 .42016 .34823 .41824 .3447 .4147 Mtetra
.3447 .4147 .34823 .41824 .35391 .41632 .35039 .41277 Mtetra
.35039 .41277 .35391 .41632 .3596 .4144 .35609 .41084 Mtetra
.35609 .41084 .3596 .4144 .3653 .41247 .3618 .4089 Mtetra
.3618 .4089 .3653 .41247 .37102 .41054 .36752 .40696 Mtetra
.36752 .40696 .37102 .41054 .37674 .40861 .37325 .40502 Mtetra
.37325 .40502 .37674 .40861 .38248 .40667 .379 .40308 Mtetra
.379 .40308 .38248 .40667 .38823 .40472 .38476 .40112 Mtetra
.38476 .40112 .38823 .40472 .394 .40277 .39053 .39917 Mtetra
.39053 .39917 .394 .40277 .39977 .40083 .39631 .39721 Mtetra
.663 .741 .908 r
.39631 .39721 .39977 .40083 .40556 .39888 .40211 .39525 Mtetra
.40211 .39525 .40556 .39888 .41136 .39692 .40792 .39329 Mtetra
.40792 .39329 .41136 .39692 .41717 .39496 .41374 .39133 Mtetra
.41374 .39133 .41717 .39496 .423 .39301 .41957 .38937 Mtetra
.662 .741 .909 r
.41957 .38937 .423 .39301 .42884 .39106 .42542 .38742 Mtetra
.66 .741 .909 r
.42542 .38742 .42884 .39106 .43469 .38913 .43127 .38549 Mtetra
.658 .74 .911 r
.43127 .38549 .43469 .38913 .44055 .38722 .43714 .38359 Mtetra
.655 .74 .913 r
.43714 .38359 .44055 .38722 .44642 .38535 .44302 .38173 Mtetra
.648 .74 .916 r
.44302 .38173 .44642 .38535 .45231 .38355 .44892 .37997 Mtetra
.636 .738 .922 r
.44892 .37997 .45231 .38355 .45821 .38188 .45482 .37837 Mtetra
.616 .736 .932 r
.45482 .37837 .45821 .38188 .46411 .38041 .46073 .37702 Mtetra
.577 .73 .947 r
.46073 .37702 .46411 .38041 .47003 .37929 .46665 .37609 Mtetra
.493 .709 .967 r
.46665 .37609 .47003 .37929 .47595 .37872 .47258 .37587 Mtetra
.291 .633 .964 r
.47258 .37587 .47595 .37872 .48188 .37909 .4785 .37682 Mtetra
0 .343 .754 r
.4785 .37682 .48188 .37909 .48781 .38097 .48443 .37965 Mtetra
.684 .139 0 r
.48443 .37965 .48781 .38097 .49375 .38521 .49036 .38542 Mtetra
.838 .39 .159 r
.49036 .38542 .49375 .38521 .4997 .393 .49629 .3955 Mtetra
.864 .482 .317 r
.49629 .3955 .4997 .393 .50566 .40564 .50224 .41125 Mtetra
.861 .512 .389 r
.50224 .41125 .50566 .40564 .51168 .42391 .50824 .43287 Mtetra
.843 .509 .422 r
.50824 .43287 .51168 .42391 .51777 .44651 .51434 .45748 Mtetra
.805 .473 .426 r
.51434 .45748 .51777 .44651 .52397 .46838 .52056 .47786 Mtetra
.69 .335 .368 r
.52056 .47786 .52397 .46838 .53027 .48152 .52686 .4855 Mtetra
.562 .828 .469 r
.52686 .4855 .53027 .48152 .53658 .48043 .53319 .47789 Mtetra
.943 .795 .668 r
.53319 .47789 .53658 .48043 .54285 .46769 .53946 .46176 Mtetra
.878 .719 .68 r
.53946 .46176 .54285 .46769 .54907 .45239 .54571 .44766 Mtetra
.753 .73 .831 r
.54571 .44766 .54907 .45239 .55532 .44373 .55201 .44334 Mtetra
.775 .272 0 r
.55201 .44334 .55532 .44373 .56169 .4469 .55844 .45121 Mtetra
.846 .466 .331 r
.55844 .45121 .56169 .4469 .56825 .46181 .56503 .4676 Mtetra
.815 .439 .344 r
.56503 .4676 .56825 .46181 .57497 .48164 .57167 .48227 Mtetra
.163 0 0 r
.57167 .48227 .57497 .48164 .58164 .49314 .57817 .48255 Mtetra
.851 .654 .635 r
.57817 .48255 .58164 .49314 .588 .4846 .58434 .46341 Mtetra
.824 .593 .59 r
.58434 .46341 .588 .4846 .59394 .45685 .59021 .43195 Mtetra
.807 .575 .586 r
.59021 .43195 .59394 .45685 .59963 .42165 .59596 .39951 Mtetra
.798 .573 .596 r
.59596 .39951 .59963 .42165 .60528 .38996 .60174 .37299 Mtetra
.793 .584 .618 r
.60174 .37299 .60528 .38996 .61105 .3661 .60763 .3538 Mtetra
.789 .606 .653 r
.60763 .3538 .61105 .3661 .61696 .34965 .61364 .34067 Mtetra
.781 .635 .7 r
.61364 .34067 .61696 .34965 .62299 .33863 .61974 .33175 Mtetra
.767 .667 .753 r
.61974 .33175 .62299 .33863 .62912 .33115 .62592 .32551 Mtetra
.747 .695 .802 r
.62592 .32551 .62912 .33115 .63531 .32584 .63215 .32092 Mtetra
.725 .715 .84 r
.63215 .32092 .63531 .32584 .64156 .32184 .63842 .31733 Mtetra
.706 .727 .866 r
.63842 .31733 .64156 .32184 .64784 .3186 .64473 .31431 Mtetra
.691 .733 .883 r
.64473 .31431 .64784 .3186 .65415 .3158 .65105 .31165 Mtetra
.681 .737 .893 r
.65105 .31165 .65415 .3158 .66049 .31327 .6574 .30918 Mtetra
.674 .739 .899 r
.6574 .30918 .66049 .31327 .66684 .31089 .66377 .30684 Mtetra
.67 .74 .902 r
.66377 .30684 .66684 .31089 .67322 .30859 .67015 .30456 Mtetra
.668 .74 .904 r
.67015 .30456 .67322 .30859 .67961 .30635 .67655 .30233 Mtetra
.666 .74 .905 r
.67655 .30233 .67961 .30635 .68601 .30414 .68296 .30011 Mtetra
.665 .741 .906 r
.68296 .30011 .68601 .30414 .69243 .30194 .6894 .29791 Mtetra
.665 .741 .907 r
.6894 .29791 .69243 .30194 .69887 .29974 .69584 .29571 Mtetra
.664 .741 .907 r
.69584 .29571 .69887 .29974 .70532 .29755 .7023 .29351 Mtetra
.7023 .29351 .70532 .29755 .71178 .29536 .70878 .29131 Mtetra
.70878 .29131 .71178 .29536 .71826 .29316 .71527 .2891 Mtetra
.71527 .2891 .71826 .29316 .72476 .29096 .72177 .2869 Mtetra
.72177 .2869 .72476 .29096 .73127 .28876 .72829 .28469 Mtetra
.72829 .28469 .73127 .28876 .73779 .28656 .73483 .28247 Mtetra
.73483 .28247 .73779 .28656 .74433 .28434 .74138 .28025 Mtetra
.74138 .28025 .74433 .28434 .75089 .28213 .74794 .27802 Mtetra
.74794 .27802 .75089 .28213 .75746 .27991 .75452 .27579 Mtetra
.75452 .27579 .75746 .27991 .76404 .27768 .76112 .27356 Mtetra
.76112 .27356 .76404 .27768 .77064 .27545 .76773 .27132 Mtetra
.76773 .27132 .77064 .27545 .77726 .27321 .77436 .26907 Mtetra
.77436 .26907 .77726 .27321 .78389 .27097 .781 .26682 Mtetra
.781 .26682 .78389 .27097 .79053 .26873 .78765 .26457 Mtetra
.78765 .26457 .79053 .26873 .79719 .26648 .79433 .2623 Mtetra
.79433 .2623 .79719 .26648 .80387 .26422 .80101 .26004 Mtetra
.80101 .26004 .80387 .26422 .81056 .26196 .80772 .25777 Mtetra
.80772 .25777 .81056 .26196 .81727 .25969 .81444 .25549 Mtetra
.81444 .25549 .81727 .25969 .82399 .25742 .82117 .25321 Mtetra
.82117 .25321 .82399 .25742 .83073 .25514 .82792 .25092 Mtetra
.82792 .25092 .83073 .25514 .83749 .25285 .83469 .24862 Mtetra
.83469 .24862 .83749 .25285 .84426 .25057 .84147 .24633 Mtetra
.84147 .24633 .84426 .25057 .85104 .24827 .84826 .24402 Mtetra
.24073 .44526 .2444 .44869 .24988 .44684 .24621 .4434 Mtetra
.24621 .4434 .24988 .44684 .25536 .44498 .25171 .44154 Mtetra
.25171 .44154 .25536 .44498 .26086 .44312 .25721 .43967 Mtetra
.25721 .43967 .26086 .44312 .26637 .44125 .26272 .43779 Mtetra
.26272 .43779 .26637 .44125 .27188 .43938 .26825 .43591 Mtetra
.26825 .43591 .27188 .43938 .27741 .4375 .27379 .43403 Mtetra
.27379 .43403 .27741 .4375 .28296 .43563 .27934 .43215 Mtetra
.27934 .43215 .28296 .43563 .28851 .43374 .2849 .43026 Mtetra
.2849 .43026 .28851 .43374 .29408 .43186 .29047 .42836 Mtetra
.29047 .42836 .29408 .43186 .29965 .42997 .29605 .42647 Mtetra
.29605 .42647 .29965 .42997 .30524 .42807 .30165 .42456 Mtetra
.30165 .42456 .30524 .42807 .31084 .42617 .30726 .42266 Mtetra
.30726 .42266 .31084 .42617 .31646 .42427 .31288 .42075 Mtetra
.31288 .42075 .31646 .42427 .32208 .42236 .31851 .41883 Mtetra
.31851 .41883 .32208 .42236 .32772 .42045 .32416 .41692 Mtetra
.32416 .41692 .32772 .42045 .33337 .41854 .32981 .41499 Mtetra
.32981 .41499 .33337 .41854 .33903 .41662 .33548 .41307 Mtetra
.33548 .41307 .33903 .41662 .3447 .4147 .34116 .41114 Mtetra
.34116 .41114 .3447 .4147 .35039 .41277 .34685 .4092 Mtetra
.34685 .4092 .35039 .41277 .35609 .41084 .35256 .40726 Mtetra
.35256 .40726 .35609 .41084 .3618 .4089 .35828 .40532 Mtetra
.35828 .40532 .3618 .4089 .36752 .40696 .364 .40337 Mtetra
.364 .40337 .36752 .40696 .37325 .40502 .36975 .40142 Mtetra
.36975 .40142 .37325 .40502 .379 .40308 .3755 .39947 Mtetra
.3755 .39947 .379 .40308 .38476 .40112 .38127 .39751 Mtetra
.38127 .39751 .38476 .40112 .39053 .39917 .38705 .39555 Mtetra
.38705 .39555 .39053 .39917 .39631 .39721 .39284 .39358 Mtetra
.664 .741 .908 r
.39284 .39358 .39631 .39721 .40211 .39525 .39864 .39162 Mtetra
.663 .741 .908 r
.39864 .39162 .40211 .39525 .40792 .39329 .40446 .38965 Mtetra
.40446 .38965 .40792 .39329 .41374 .39133 .41029 .38768 Mtetra
.41029 .38768 .41374 .39133 .41957 .38937 .41613 .38572 Mtetra
.661 .741 .909 r
.41613 .38572 .41957 .38937 .42542 .38742 .42198 .38377 Mtetra
.659 .74 .91 r
.42198 .38377 .42542 .38742 .43127 .38549 .42785 .38184 Mtetra
.657 .74 .911 r
.42785 .38184 .43127 .38549 .43714 .38359 .43372 .37995 Mtetra
.653 .74 .914 r
.43372 .37995 .43714 .38359 .44302 .38173 .43961 .37812 Mtetra
.644 .739 .918 r
.43961 .37812 .44302 .38173 .44892 .37997 .44551 .3764 Mtetra
.629 .738 .926 r
.44551 .3764 .44892 .37997 .45482 .37837 .45142 .37488 Mtetra
.602 .734 .938 r
.45142 .37488 .45482 .37837 .46073 .37702 .45734 .37369 Mtetra
.548 .724 .956 r
.45734 .37369 .46073 .37702 .46665 .37609 .46326 .37302 Mtetra
.425 .688 .973 r
.46326 .37302 .46665 .37609 .47258 .37587 .46918 .37325 Mtetra
.108 .539 .914 r
.46918 .37325 .47258 .37587 .4785 .37682 .47511 .37496 Mtetra
.475 0 0 r
.47511 .37496 .4785 .37682 .48443 .37965 .48102 .37907 Mtetra
.792 .299 .023 r
.48102 .37907 .48443 .37965 .49036 .38542 .48693 .38685 Mtetra
.858 .451 .265 r
.48693 .38685 .49036 .38542 .49629 .3955 .49284 .39989 Mtetra
.864 .505 .369 r
.49284 .39989 .49629 .3955 .50224 .41125 .49877 .41941 Mtetra
.852 .517 .418 r
.49877 .41941 .50224 .41125 .50824 .43287 .50475 .44453 Mtetra
.826 .5 .438 r
.50475 .44453 .50824 .43287 .51434 .45748 .51086 .47001 Mtetra
.765 .435 .427 r
.51086 .47001 .51434 .45748 .52056 .47786 .5171 .48641 Mtetra
.486 .117 .264 r
.5171 .48641 .52056 .47786 .52686 .4855 .52343 .4864 Mtetra
.978 .899 .67 r
.52343 .4864 .52686 .4855 .53319 .47789 .52977 .47223 Mtetra
.903 .725 .651 r
.52977 .47223 .53319 .47789 .53946 .46176 .53606 .45428 Mtetra
.831 .68 .695 r
.53606 .45428 .53946 .46176 .54571 .44766 .54234 .44289 Mtetra
.493 .624 .908 r
.54234 .44289 .54571 .44766 .55201 .44334 .54868 .44316 Mtetra
.843 .387 .12 r
.54868 .44316 .55201 .44334 .55844 .45121 .55514 .45423 Mtetra
.849 .453 .293 r
.55514 .45423 .55844 .45121 .56503 .4676 .56172 .46909 Mtetra
.75 .269 .099 r
.56172 .46909 .56503 .4676 .57167 .48227 .56827 .47616 Mtetra
.837 .712 .726 r
.56827 .47616 .57167 .48227 .57817 .48255 .57462 .46642 Mtetra
.832 .613 .606 r
.57462 .46642 .57817 .48255 .58434 .46341 .58069 .44114 Mtetra
.817 .586 .589 r
.58069 .44114 .58434 .46341 .59021 .43195 .58656 .40983 Mtetra
.807 .579 .593 r
.58656 .40983 .59021 .43195 .59596 .39951 .5924 .38131 Mtetra
.801 .585 .609 r
.5924 .38131 .59596 .39951 .60174 .37299 .59829 .35932 Mtetra
.796 .601 .638 r
.59829 .35932 .60174 .37299 .60763 .3538 .60428 .34375 Mtetra
.79 .626 .679 r
.60428 .34375 .60763 .3538 .61364 .34067 .61036 .33306 Mtetra
.778 .657 .729 r
.61036 .33306 .61364 .34067 .61974 .33175 .61652 .32564 Mtetra
.76 .685 .78 r
.61652 .32564 .61974 .33175 .62592 .32551 .62273 .3203 Mtetra
.738 .708 .823 r
.62273 .3203 .62592 .32551 .63215 .32092 .62899 .31623 Mtetra
.716 .722 .854 r
.62899 .31623 .63215 .32092 .63842 .31733 .63528 .31293 Mtetra
.699 .731 .875 r
.63528 .31293 .63842 .31733 .64473 .31431 .6416 .31009 Mtetra
.686 .735 .888 r
.6416 .31009 .64473 .31431 .65105 .31165 .64794 .30752 Mtetra
.678 .738 .896 r
.64794 .30752 .65105 .31165 .6574 .30918 .6543 .30511 Mtetra
.673 .739 .9 r
.6543 .30511 .6574 .30918 .66377 .30684 .66068 .30279 Mtetra
.669 .74 .903 r
.66068 .30279 .66377 .30684 .67015 .30456 .66707 .30052 Mtetra
.667 .74 .905 r
.66707 .30052 .67015 .30456 .67655 .30233 .67348 .29829 Mtetra
.666 .741 .906 r
.67348 .29829 .67655 .30233 .68296 .30011 .67991 .29607 Mtetra
.665 .741 .906 r
.67991 .29607 .68296 .30011 .6894 .29791 .68635 .29386 Mtetra
.665 .741 .907 r
.68635 .29386 .6894 .29791 .69584 .29571 .6928 .29166 Mtetra
.664 .741 .907 r
.6928 .29166 .69584 .29571 .7023 .29351 .69927 .28945 Mtetra
.69927 .28945 .7023 .29351 .70878 .29131 .70576 .28724 Mtetra
.70576 .28724 .70878 .29131 .71527 .2891 .71226 .28503 Mtetra
.71226 .28503 .71527 .2891 .72177 .2869 .71878 .28281 Mtetra
.71878 .28281 .72177 .2869 .72829 .28469 .72531 .28059 Mtetra
.72531 .28059 .72829 .28469 .73483 .28247 .73185 .27837 Mtetra
.73185 .27837 .73483 .28247 .74138 .28025 .73841 .27614 Mtetra
.73841 .27614 .74138 .28025 .74794 .27802 .74499 .2739 Mtetra
.74499 .2739 .74794 .27802 .75452 .27579 .75158 .27166 Mtetra
.75158 .27166 .75452 .27579 .76112 .27356 .75819 .26942 Mtetra
.75819 .26942 .76112 .27356 .76773 .27132 .76481 .26717 Mtetra
.76481 .26717 .76773 .27132 .77436 .26907 .77144 .26491 Mtetra
.77144 .26491 .77436 .26907 .781 .26682 .7781 .26265 Mtetra
.7781 .26265 .781 .26682 .78765 .26457 .78476 .26039 Mtetra
.78476 .26039 .78765 .26457 .79433 .2623 .79145 .25812 Mtetra
.79145 .25812 .79433 .2623 .80101 .26004 .79815 .25584 Mtetra
.79815 .25584 .80101 .26004 .80772 .25777 .80486 .25356 Mtetra
.80486 .25356 .80772 .25777 .81444 .25549 .81159 .25127 Mtetra
.81159 .25127 .81444 .25549 .82117 .25321 .81833 .24898 Mtetra
.81833 .24898 .82117 .25321 .82792 .25092 .8251 .24668 Mtetra
.8251 .24668 .82792 .25092 .83469 .24862 .83187 .24438 Mtetra
.83187 .24438 .83469 .24862 .84147 .24633 .83867 .24207 Mtetra
.83867 .24207 .84147 .24633 .84826 .24402 .84547 .23975 Mtetra
.23705 .44182 .24073 .44526 .24621 .4434 .24254 .43995 Mtetra
.24254 .43995 .24621 .4434 .25171 .44154 .24803 .43808 Mtetra
.24803 .43808 .25171 .44154 .25721 .43967 .25354 .4362 Mtetra
.25354 .4362 .25721 .43967 .26272 .43779 .25907 .43432 Mtetra
.25907 .43432 .26272 .43779 .26825 .43591 .2646 .43244 Mtetra
.2646 .43244 .26825 .43591 .27379 .43403 .27014 .43055 Mtetra
.27014 .43055 .27379 .43403 .27934 .43215 .2757 .42866 Mtetra
.2757 .42866 .27934 .43215 .2849 .43026 .28127 .42676 Mtetra
.28127 .42676 .2849 .43026 .29047 .42836 .28685 .42486 Mtetra
.28685 .42486 .29047 .42836 .29605 .42647 .29244 .42295 Mtetra
.29244 .42295 .29605 .42647 .30165 .42456 .29804 .42104 Mtetra
.29804 .42104 .30165 .42456 .30726 .42266 .30366 .41913 Mtetra
.30366 .41913 .30726 .42266 .31288 .42075 .30929 .41721 Mtetra
.30929 .41721 .31288 .42075 .31851 .41883 .31492 .41529 Mtetra
.31492 .41529 .31851 .41883 .32416 .41692 .32058 .41336 Mtetra
.32058 .41336 .32416 .41692 .32981 .41499 .32624 .41143 Mtetra
.32624 .41143 .32981 .41499 .33548 .41307 .33192 .4095 Mtetra
.33192 .4095 .33548 .41307 .34116 .41114 .3376 .40756 Mtetra
.3376 .40756 .34116 .41114 .34685 .4092 .3433 .40562 Mtetra
.3433 .40562 .34685 .4092 .35256 .40726 .34902 .40367 Mtetra
.34902 .40367 .35256 .40726 .35828 .40532 .35474 .40172 Mtetra
.35474 .40172 .35828 .40532 .364 .40337 .36048 .39977 Mtetra
.36048 .39977 .364 .40337 .36975 .40142 .36623 .39781 Mtetra
.36623 .39781 .36975 .40142 .3755 .39947 .37199 .39585 Mtetra
.37199 .39585 .3755 .39947 .38127 .39751 .37776 .39388 Mtetra
.37776 .39388 .38127 .39751 .38705 .39555 .38355 .39191 Mtetra
.38355 .39191 .38705 .39555 .39284 .39358 .38935 .38994 Mtetra
.664 .741 .908 r
.38935 .38994 .39284 .39358 .39864 .39162 .39516 .38797 Mtetra
.663 .741 .908 r
.39516 .38797 .39864 .39162 .40446 .38965 .40099 .38599 Mtetra
.40099 .38599 .40446 .38965 .41029 .38768 .40682 .38402 Mtetra
.662 .741 .908 r
.40682 .38402 .41029 .38768 .41613 .38572 .41267 .38206 Mtetra
.661 .741 .909 r
.41267 .38206 .41613 .38572 .42198 .38377 .41853 .38011 Mtetra
.659 .741 .91 r
.41853 .38011 .42198 .38377 .42785 .38184 .4244 .37818 Mtetra
.655 .74 .912 r
.4244 .37818 .42785 .38184 .43372 .37995 .43029 .37631 Mtetra
.649 .74 .915 r
.43029 .37631 .43372 .37995 .43961 .37812 .43618 .37452 Mtetra
.639 .739 .921 r
.43618 .37452 .43961 .37812 .44551 .3764 .44209 .37286 Mtetra
.62 .737 .93 r
.44209 .37286 .44551 .3764 .45142 .37488 .448 .37145 Mtetra
.582 .731 .945 r
.448 .37145 .45142 .37488 .45734 .37369 .45392 .37046 Mtetra
.503 .713 .965 r
.45392 .37046 .45734 .37369 .46326 .37302 .45985 .37015 Mtetra
.309 .643 .967 r
.45985 .37015 .46326 .37302 .46918 .37325 .46577 .37099 Mtetra
0 .353 .76 r
.46577 .37099 .46918 .37325 .47511 .37496 .47168 .37373 Mtetra
.693 .15 0 r
.47168 .37373 .47511 .37496 .48102 .37907 .47758 .37954 Mtetra
.841 .402 .185 r
.47758 .37954 .48102 .37907 .48693 .38685 .48346 .39001 Mtetra
.863 .49 .339 r
.48346 .39001 .48693 .38685 .49284 .39989 .48933 .40687 Mtetra
.857 .517 .408 r
.48933 .40687 .49284 .39989 .49877 .41941 .49522 .43076 Mtetra
.839 .514 .44 r
.49522 .43076 .49877 .41941 .50475 .44453 .5012 .45886 Mtetra
.799 .479 .447 r
.5012 .45886 .50475 .44453 .51086 .47001 .50732 .48279 Mtetra
.688 .355 .406 r
.50732 .48279 .51086 .47001 .5171 .48641 .51361 .49192 Mtetra
0 0 0 r
.51361 .49192 .5171 .48641 .52343 .4864 .51998 .48271 Mtetra
.935 .76 .641 r
.51998 .48271 .52343 .4864 .52977 .47223 .52634 .46312 Mtetra
.857 .668 .646 r
.52634 .46312 .52977 .47223 .53606 .45428 .53265 .4455 Mtetra
.759 .63 .717 r
.53265 .4455 .53606 .45428 .54234 .44289 .53895 .43805 Mtetra
0 .302 .797 r
.53895 .43805 .54234 .44289 .54868 .44316 .54533 .4426 Mtetra
.861 .416 .133 r
.54533 .4426 .54868 .44316 .55514 .45423 .5518 .45505 Mtetra
.834 .387 .165 r
.5518 .45505 .55514 .45423 .56172 .46909 .55834 .46605 Mtetra
.561 .764 .973 r
.55834 .46605 .56172 .46909 .56827 .47616 .5648 .465 Mtetra
.833 .64 .643 r
.5648 .465 .56827 .47616 .57462 .46642 .57104 .44781 Mtetra
.825 .601 .598 r
.57104 .44781 .57462 .46642 .58069 .44114 .57707 .42003 Mtetra
.816 .588 .593 r
.57707 .42003 .58069 .44114 .58656 .40983 .58299 .39086 Mtetra
.809 .588 .603 r
.58299 .39086 .58656 .40983 .5924 .38131 .58891 .36635 Mtetra
.804 .599 .625 r
.58891 .36635 .5924 .38131 .59829 .35932 .5949 .3481 Mtetra
.798 .62 .66 r
.5949 .3481 .59829 .35932 .60428 .34375 .60096 .33528 Mtetra
.788 .647 .705 r
.60096 .33528 .60428 .34375 .61036 .33306 .6071 .32638 Mtetra
.773 .675 .756 r
.6071 .32638 .61036 .33306 .61652 .32564 .61329 .32007 Mtetra
.751 .7 .803 r
.61329 .32007 .61652 .32564 .62273 .3203 .61954 .31539 Mtetra
.728 .717 .84 r
.61954 .31539 .62273 .3203 .62899 .31623 .62582 .3117 Mtetra
.708 .728 .865 r
.62582 .3117 .62899 .31623 .63528 .31293 .63213 .30862 Mtetra
.693 .734 .882 r
.63213 .30862 .63528 .31293 .6416 .31009 .63846 .30591 Mtetra
.682 .737 .892 r
.63846 .30591 .6416 .31009 .64794 .30752 .64481 .3034 Mtetra
.675 .739 .898 r
.64481 .3034 .64794 .30752 .6543 .30511 .65118 .30103 Mtetra
.671 .74 .902 r
.65118 .30103 .6543 .30511 .66068 .30279 .65757 .29873 Mtetra
.668 .74 .904 r
.65757 .29873 .66068 .30279 .66707 .30052 .66398 .29647 Mtetra
.667 .74 .905 r
.66398 .29647 .66707 .30052 .67348 .29829 .6704 .29424 Mtetra
.665 .741 .906 r
.6704 .29424 .67348 .29829 .67991 .29607 .67684 .29202 Mtetra
.665 .741 .907 r
.67684 .29202 .67991 .29607 .68635 .29386 .68329 .2898 Mtetra
.664 .741 .907 r
.68329 .2898 .68635 .29386 .6928 .29166 .68975 .28759 Mtetra
.68975 .28759 .6928 .29166 .69927 .28945 .69623 .28537 Mtetra
.69623 .28537 .69927 .28945 .70576 .28724 .70273 .28316 Mtetra
.70273 .28316 .70576 .28724 .71226 .28503 .70924 .28094 Mtetra
.70924 .28094 .71226 .28503 .71878 .28281 .71577 .27871 Mtetra
.71577 .27871 .71878 .28281 .72531 .28059 .72231 .27648 Mtetra
.72231 .27648 .72531 .28059 .73185 .27837 .72886 .27425 Mtetra
.72886 .27425 .73185 .27837 .73841 .27614 .73543 .27201 Mtetra
.73543 .27201 .73841 .27614 .74499 .2739 .74202 .26976 Mtetra
.74202 .26976 .74499 .2739 .75158 .27166 .74862 .26751 Mtetra
.74862 .26751 .75158 .27166 .75819 .26942 .75524 .26526 Mtetra
.75524 .26526 .75819 .26942 .76481 .26717 .76187 .263 Mtetra
.76187 .263 .76481 .26717 .77144 .26491 .76852 .26074 Mtetra
.76852 .26074 .77144 .26491 .7781 .26265 .77518 .25847 Mtetra
.77518 .25847 .7781 .26265 .78476 .26039 .78186 .25619 Mtetra
.78186 .25619 .78476 .26039 .79145 .25812 .78855 .25391 Mtetra
.78855 .25391 .79145 .25812 .79815 .25584 .79526 .25162 Mtetra
.79526 .25162 .79815 .25584 .80486 .25356 .80199 .24933 Mtetra
.80199 .24933 .80486 .25356 .81159 .25127 .80873 .24703 Mtetra
.80873 .24703 .81159 .25127 .81833 .24898 .81549 .24473 Mtetra
.81549 .24473 .81833 .24898 .8251 .24668 .82226 .24242 Mtetra
.82226 .24242 .8251 .24668 .83187 .24438 .82905 .24011 Mtetra
.82905 .24011 .83187 .24438 .83867 .24207 .83585 .23779 Mtetra
.83585 .23779 .83867 .24207 .84547 .23975 .84267 .23547 Mtetra
.23335 .43837 .23705 .44182 .24254 .43995 .23885 .43649 Mtetra
.23885 .43649 .24254 .43995 .24803 .43808 .24435 .43461 Mtetra
.24435 .43461 .24803 .43808 .25354 .4362 .24987 .43273 Mtetra
.24987 .43273 .25354 .4362 .25907 .43432 .25539 .43084 Mtetra
.25539 .43084 .25907 .43432 .2646 .43244 .26093 .42895 Mtetra
.26093 .42895 .2646 .43244 .27014 .43055 .26649 .42705 Mtetra
.26649 .42705 .27014 .43055 .2757 .42866 .27205 .42515 Mtetra
.27205 .42515 .2757 .42866 .28127 .42676 .27762 .42324 Mtetra
.27762 .42324 .28127 .42676 .28685 .42486 .28321 .42134 Mtetra
.28321 .42134 .28685 .42486 .29244 .42295 .28881 .41942 Mtetra
.28881 .41942 .29244 .42295 .29804 .42104 .29442 .41751 Mtetra
.29442 .41751 .29804 .42104 .30366 .41913 .30004 .41559 Mtetra
.30004 .41559 .30366 .41913 .30929 .41721 .30568 .41366 Mtetra
.30568 .41366 .30929 .41721 .31492 .41529 .31132 .41173 Mtetra
.31132 .41173 .31492 .41529 .32058 .41336 .31698 .4098 Mtetra
.31698 .4098 .32058 .41336 .32624 .41143 .32265 .40786 Mtetra
.32265 .40786 .32624 .41143 .33192 .4095 .32834 .40592 Mtetra
.32834 .40592 .33192 .4095 .3376 .40756 .33403 .40397 Mtetra
.33403 .40397 .3376 .40756 .3433 .40562 .33974 .40202 Mtetra
.33974 .40202 .3433 .40562 .34902 .40367 .34546 .40007 Mtetra
.34546 .40007 .34902 .40367 .35474 .40172 .35119 .39811 Mtetra
.35119 .39811 .35474 .40172 .36048 .39977 .35694 .39615 Mtetra
.35694 .39615 .36048 .39977 .36623 .39781 .36269 .39418 Mtetra
.36269 .39418 .36623 .39781 .37199 .39585 .36846 .39221 Mtetra
.36846 .39221 .37199 .39585 .37776 .39388 .37425 .39024 Mtetra
.37425 .39024 .37776 .39388 .38355 .39191 .38004 .38826 Mtetra
.38004 .38826 .38355 .39191 .38935 .38994 .38585 .38628 Mtetra
.663 .741 .908 r
.38585 .38628 .38935 .38994 .39516 .38797 .39167 .3843 Mtetra
.39167 .3843 .39516 .38797 .40099 .38599 .3975 .38232 Mtetra
.662 .741 .908 r
.3975 .38232 .40099 .38599 .40682 .38402 .40334 .38035 Mtetra
.662 .741 .909 r
.40334 .38035 .40682 .38402 .41267 .38206 .4092 .37838 Mtetra
.66 .741 .91 r
.4092 .37838 .41267 .38206 .41853 .38011 .41507 .37643 Mtetra
.657 .74 .911 r
.41507 .37643 .41853 .38011 .4244 .37818 .42095 .37452 Mtetra
.653 .74 .913 r
.42095 .37452 .4244 .37818 .43029 .37631 .42684 .37267 Mtetra
.646 .74 .918 r
.42684 .37267 .43029 .37631 .43618 .37452 .43274 .37092 Mtetra
.632 .738 .925 r
.43274 .37092 .43618 .37452 .44209 .37286 .43865 .36936 Mtetra
.606 .735 .936 r
.43865 .36936 .44209 .37286 .448 .37145 .44457 .3681 Mtetra
.553 .726 .955 r
.44457 .3681 .448 .37145 .45392 .37046 .45049 .36737 Mtetra
.431 .691 .974 r
.45049 .36737 .45392 .37046 .45985 .37015 .45641 .36754 Mtetra
.107 .541 .914 r
.45641 .36754 .45985 .37015 .46577 .37099 .46232 .36922 Mtetra
.501 0 0 r
.46232 .36922 .46577 .37099 .47168 .37373 .46822 .3734 Mtetra
.804 .323 .065 r
.46822 .3734 .47168 .37373 .47758 .37954 .47408 .38156 Mtetra
.858 .464 .294 r
.47408 .38156 .47758 .37954 .48346 .39001 .47992 .39563 Mtetra
.86 .512 .391 r
.47992 .39563 .48346 .39001 .48933 .40687 .48574 .41724 Mtetra
.847 .521 .436 r
.48574 .41724 .48933 .40687 .49522 .43076 .49159 .44573 Mtetra
.819 .503 .455 r
.49159 .44573 .49522 .43076 .5012 .45886 .49757 .47501 Mtetra
.754 .437 .447 r
.49757 .47501 .5012 .45886 .50732 .48279 .50375 .49345 Mtetra
.439 .097 .287 r
.50375 .49345 .50732 .48279 .51361 .49192 .51011 .49185 Mtetra
.978 .838 .636 r
.51011 .49185 .51361 .49192 .51998 .48271 .51653 .47341 Mtetra
.877 .674 .624 r
.51653 .47341 .51998 .48271 .52634 .46312 .52291 .45097 Mtetra
.804 .617 .649 r
.52291 .45097 .52634 .46312 .53265 .4455 .52923 .43603 Mtetra
.646 .56 .744 r
.52923 .43603 .53265 .4455 .53895 .43805 .53555 .43334 Mtetra
0 0 .49 r
.53555 .43334 .53895 .43805 .54533 .4426 .54195 .44135 Mtetra
.854 .398 .079 r
.54195 .44135 .54533 .4426 .5518 .45505 .54842 .45331 Mtetra
.611 .055 0 r
.54842 .45331 .5518 .45505 .55834 .46605 .55491 .45909 Mtetra
.802 .683 .734 r
.55491 .45909 .55834 .46605 .5648 .465 .56129 .45083 Mtetra
.831 .621 .618 r
.56129 .45083 .5648 .465 .57104 .44781 .56748 .429 Mtetra
.825 .599 .597 r
.56748 .429 .57104 .44781 .57707 .42003 .57352 .40112 Mtetra
.817 .594 .6 r
.57352 .40112 .57707 .42003 .58299 .39086 .57949 .37483 Mtetra
.812 .599 .615 r
.57949 .37483 .58299 .39086 .58891 .36635 .58549 .35389 Mtetra
.806 .615 .643 r
.58549 .35389 .58891 .36635 .5949 .3481 .59154 .33862 Mtetra
.798 .638 .683 r
.59154 .33862 .5949 .3481 .60096 .33528 .59766 .3279 Mtetra
.784 .665 .731 r
.59766 .3279 .60096 .33528 .6071 .32638 .60384 .32035 Mtetra
.765 .69 .78 r
.60384 .32035 .6071 .32638 .61329 .32007 .61007 .31486 Mtetra
.742 .71 .822 r
.61007 .31486 .61329 .32007 .61954 .31539 .61634 .31068 Mtetra
.72 .724 .853 r
.61634 .31068 .61954 .31539 .62582 .3117 .62264 .30728 Mtetra
.702 .731 .874 r
.62264 .30728 .62582 .3117 .63213 .30862 .62896 .30437 Mtetra
.688 .736 .887 r
.62896 .30437 .63213 .30862 .63846 .30591 .63531 .30174 Mtetra
.679 .738 .895 r
.63531 .30174 .63846 .30591 .64481 .3034 .64168 .29929 Mtetra
.673 .739 .9 r
.64168 .29929 .64481 .3034 .65118 .30103 .64806 .29695 Mtetra
.67 .74 .903 r
.64806 .29695 .65118 .30103 .65757 .29873 .65446 .29466 Mtetra
.667 .74 .905 r
.65446 .29466 .65757 .29873 .66398 .29647 .66087 .29241 Mtetra
.666 .741 .906 r
.66087 .29241 .66398 .29647 .6704 .29424 .66731 .29017 Mtetra
.665 .741 .906 r
.66731 .29017 .6704 .29424 .67684 .29202 .67375 .28795 Mtetra
.665 .741 .907 r
.67375 .28795 .67684 .29202 .68329 .2898 .68021 .28573 Mtetra
.664 .741 .907 r
.68021 .28573 .68329 .2898 .68975 .28759 .68669 .28351 Mtetra
.68669 .28351 .68975 .28759 .69623 .28537 .69318 .28128 Mtetra
.69318 .28128 .69623 .28537 .70273 .28316 .69969 .27906 Mtetra
.69969 .27906 .70273 .28316 .70924 .28094 .70621 .27683 Mtetra
.70621 .27683 .70924 .28094 .71577 .27871 .71274 .27459 Mtetra
.71274 .27459 .71577 .27871 .72231 .27648 .7193 .27235 Mtetra
.7193 .27235 .72231 .27648 .72886 .27425 .72586 .27011 Mtetra
.72586 .27011 .72886 .27425 .73543 .27201 .73244 .26786 Mtetra
.73244 .26786 .73543 .27201 .74202 .26976 .73904 .26561 Mtetra
.73904 .26561 .74202 .26976 .74862 .26751 .74565 .26335 Mtetra
.74565 .26335 .74862 .26751 .75524 .26526 .75228 .26108 Mtetra
.75228 .26108 .75524 .26526 .76187 .263 .75892 .25881 Mtetra
.75892 .25881 .76187 .263 .76852 .26074 .76558 .25654 Mtetra
.76558 .25654 .76852 .26074 .77518 .25847 .77226 .25426 Mtetra
.77226 .25426 .77518 .25847 .78186 .25619 .77895 .25197 Mtetra
.77895 .25197 .78186 .25619 .78855 .25391 .78565 .24968 Mtetra
.78565 .24968 .78855 .25391 .79526 .25162 .79237 .24739 Mtetra
.79237 .24739 .79526 .25162 .80199 .24933 .79911 .24509 Mtetra
.79911 .24509 .80199 .24933 .80873 .24703 .80586 .24278 Mtetra
.80586 .24278 .80873 .24703 .81549 .24473 .81263 .24047 Mtetra
.81263 .24047 .81549 .24473 .82226 .24242 .81941 .23815 Mtetra
.81941 .23815 .82226 .24242 .82905 .24011 .82621 .23583 Mtetra
.82621 .23583 .82905 .24011 .83585 .23779 .83303 .2335 Mtetra
.83303 .2335 .83585 .23779 .84267 .23547 .83986 .23116 Mtetra
.22964 .4349 .23335 .43837 .23885 .43649 .23514 .43302 Mtetra
.23514 .43302 .23885 .43649 .24435 .43461 .24065 .43113 Mtetra
.24065 .43113 .24435 .43461 .24987 .43273 .24617 .42924 Mtetra
.24617 .42924 .24987 .43273 .25539 .43084 .25171 .42734 Mtetra
.25171 .42734 .25539 .43084 .26093 .42895 .25726 .42544 Mtetra
.25726 .42544 .26093 .42895 .26649 .42705 .26281 .42354 Mtetra
.26281 .42354 .26649 .42705 .27205 .42515 .26838 .42163 Mtetra
.26838 .42163 .27205 .42515 .27762 .42324 .27397 .41972 Mtetra
.27397 .41972 .27762 .42324 .28321 .42134 .27956 .4178 Mtetra
.27956 .4178 .28321 .42134 .28881 .41942 .28517 .41588 Mtetra
.28517 .41588 .28881 .41942 .29442 .41751 .29078 .41396 Mtetra
.29078 .41396 .29442 .41751 .30004 .41559 .29641 .41203 Mtetra
.29641 .41203 .30004 .41559 .30568 .41366 .30206 .4101 Mtetra
.30206 .4101 .30568 .41366 .31132 .41173 .30771 .40816 Mtetra
.30771 .40816 .31132 .41173 .31698 .4098 .31338 .40622 Mtetra
.31338 .40622 .31698 .4098 .32265 .40786 .31905 .40427 Mtetra
.31905 .40427 .32265 .40786 .32834 .40592 .32475 .40232 Mtetra
.32475 .40232 .32834 .40592 .33403 .40397 .33045 .40037 Mtetra
.33045 .40037 .33403 .40397 .33974 .40202 .33616 .39841 Mtetra
.33616 .39841 .33974 .40202 .34546 .40007 .34189 .39645 Mtetra
.34189 .39645 .34546 .40007 .35119 .39811 .34763 .39448 Mtetra
.34763 .39448 .35119 .39811 .35694 .39615 .35338 .39252 Mtetra
.35338 .39252 .35694 .39615 .36269 .39418 .35915 .39054 Mtetra
.35915 .39054 .36269 .39418 .36846 .39221 .36492 .38856 Mtetra
.36492 .38856 .36846 .39221 .37425 .39024 .37071 .38658 Mtetra
.37071 .38658 .37425 .39024 .38004 .38826 .37652 .3846 Mtetra
.37652 .3846 .38004 .38826 .38585 .38628 .38233 .38261 Mtetra
.663 .741 .908 r
.38233 .38261 .38585 .38628 .39167 .3843 .38816 .38062 Mtetra
.38816 .38062 .39167 .3843 .3975 .38232 .394 .37864 Mtetra
.662 .741 .908 r
.394 .37864 .3975 .38232 .40334 .38035 .39985 .37666 Mtetra
.661 .741 .909 r
.39985 .37666 .40334 .38035 .4092 .37838 .40571 .37469 Mtetra
.659 .741 .91 r
.40571 .37469 .4092 .37838 .41507 .37643 .41159 .37275 Mtetra
.656 .74 .912 r
.41159 .37275 .41507 .37643 .42095 .37452 .41748 .37086 Mtetra
.65 .74 .915 r
.41748 .37086 .42095 .37452 .42684 .37267 .42338 .36904 Mtetra
.64 .739 .92 r
.42338 .36904 .42684 .37267 .43274 .37092 .42928 .36736 Mtetra
.622 .737 .929 r
.42928 .36736 .43274 .37092 .43865 .36936 .4352 .3659 Mtetra
.585 .732 .944 r
.4352 .3659 .43865 .36936 .44457 .3681 .44112 .36486 Mtetra
.506 .715 .966 r
.44112 .36486 .44457 .3681 .45049 .36737 .44704 .36451 Mtetra
.302 .642 .967 r
.44704 .36451 .45049 .36737 .45641 .36754 .45295 .36535 Mtetra
0 .322 .726 r
.45295 .36535 .45641 .36754 .46232 .36922 .45885 .36821 Mtetra
.725 .195 0 r
.45885 .36821 .46232 .36922 .46822 .3734 .46471 .37441 Mtetra
.847 .425 .229 r
.46471 .37441 .46822 .3734 .47408 .38156 .47053 .38583 Mtetra
.861 .501 .367 r
.47053 .38583 .47408 .38156 .47992 .39563 .4763 .40464 Mtetra
.853 .523 .428 r
.4763 .40464 .47992 .39563 .48574 .41724 .48205 .43182 Mtetra
.831 .516 .456 r
.48205 .43182 .48574 .41724 .49159 .44573 .48788 .46398 Mtetra
.787 .477 .463 r
.48788 .46398 .49159 .44573 .49757 .47501 .49389 .49058 Mtetra
.654 .334 .418 r
.49389 .49058 .49757 .47501 .50375 .49345 .50018 .49838 Mtetra
.89 .919 .524 r
.50018 .49838 .50375 .49345 .51011 .49185 .50663 .48413 Mtetra
.903 .696 .614 r
.50663 .48413 .51011 .49185 .51653 .47341 .5131 .45888 Mtetra
.826 .616 .62 r
.5131 .45888 .51653 .47341 .52291 .45097 .51948 .4371 Mtetra
.742 .569 .661 r
.51948 .4371 .52291 .45097 .52923 .43603 .52581 .42687 Mtetra
.442 .448 .77 r
.52581 .42687 .52923 .43603 .53555 .43334 .53214 .42908 Mtetra
.712 .253 0 r
.53214 .42908 .53555 .43334 .54195 .44135 .53854 .43937 Mtetra
.804 .317 0 r
.53854 .43937 .54195 .44135 .54842 .45331 .54501 .44927 Mtetra
.48 .664 .943 r
.54501 .44927 .54842 .45331 .55491 .45909 .55145 .44937 Mtetra
.826 .65 .665 r
.55145 .44937 .55491 .45909 .56129 .45083 .55778 .43538 Mtetra
.833 .616 .609 r
.55778 .43538 .56129 .45083 .56748 .429 .56394 .41117 Mtetra
.826 .603 .6 r
.56394 .41117 .56748 .429 .57352 .40112 .57001 .38452 Mtetra
.82 .603 .609 r
.57001 .38452 .57352 .40112 .57949 .37483 .57604 .36121 Mtetra
.814 .612 .63 r
.57604 .36121 .57949 .37483 .58549 .35389 .5821 .3433 Mtetra
.807 .63 .663 r
.5821 .3433 .58549 .35389 .59154 .33862 .58821 .3304 Mtetra
.795 .654 .707 r
.58821 .3304 .59154 .33862 .59766 .3279 .59438 .32129 Mtetra
.778 .68 .755 r
.59438 .32129 .59766 .3279 .60384 .32035 .60059 .31477 Mtetra
.756 .702 .801 r
.60059 .31477 .60384 .32035 .61007 .31486 .60685 .30992 Mtetra
.733 .718 .837 r
.60685 .30992 .61007 .31486 .61634 .31068 .61314 .3061 Mtetra
.712 .728 .863 r
.61314 .3061 .61634 .31068 .62264 .30728 .61945 .30293 Mtetra
.696 .734 .88 r
.61945 .30293 .62264 .30728 .62896 .30437 .62579 .30015 Mtetra
.684 .737 .891 r
.62579 .30015 .62896 .30437 .63531 .30174 .63215 .2976 Mtetra
.677 .739 .897 r
.63215 .2976 .63531 .30174 .64168 .29929 .63853 .29519 Mtetra
.672 .74 .901 r
.63853 .29519 .64168 .29929 .64806 .29695 .64492 .29286 Mtetra
.669 .74 .904 r
.64492 .29286 .64806 .29695 .65446 .29466 .65133 .29058 Mtetra
.667 .74 .905 r
.65133 .29058 .65446 .29466 .66087 .29241 .65776 .28833 Mtetra
.666 .741 .906 r
.65776 .28833 .66087 .29241 .66731 .29017 .6642 .28609 Mtetra
.665 .741 .907 r
.6642 .28609 .66731 .29017 .67375 .28795 .67065 .28386 Mtetra
.67065 .28386 .67375 .28795 .68021 .28573 .67713 .28163 Mtetra
.664 .741 .907 r
.67713 .28163 .68021 .28573 .68669 .28351 .68361 .27941 Mtetra
.68361 .27941 .68669 .28351 .69318 .28128 .69011 .27717 Mtetra
.69011 .27717 .69318 .28128 .69969 .27906 .69663 .27494 Mtetra
.69663 .27494 .69969 .27906 .70621 .27683 .70316 .2727 Mtetra
.70316 .2727 .70621 .27683 .71274 .27459 .70971 .27046 Mtetra
.70971 .27046 .71274 .27459 .7193 .27235 .71627 .26821 Mtetra
.71627 .26821 .7193 .27235 .72586 .27011 .72285 .26595 Mtetra
.72285 .26595 .72586 .27011 .73244 .26786 .72944 .2637 Mtetra
.72944 .2637 .73244 .26786 .73904 .26561 .73605 .26143 Mtetra
.73605 .26143 .73904 .26561 .74565 .26335 .74267 .25916 Mtetra
.74267 .25916 .74565 .26335 .75228 .26108 .74931 .25689 Mtetra
.74931 .25689 .75228 .26108 .75892 .25881 .75596 .25461 Mtetra
.75596 .25461 .75892 .25881 .76558 .25654 .76263 .25233 Mtetra
.76263 .25233 .76558 .25654 .77226 .25426 .76932 .25004 Mtetra
.76932 .25004 .77226 .25426 .77895 .25197 .77602 .24774 Mtetra
.77602 .24774 .77895 .25197 .78565 .24968 .78273 .24544 Mtetra
.78273 .24544 .78565 .24968 .79237 .24739 .78947 .24314 Mtetra
.78947 .24314 .79237 .24739 .79911 .24509 .79621 .24082 Mtetra
.79621 .24082 .79911 .24509 .80586 .24278 .80298 .23851 Mtetra
.80298 .23851 .80586 .24278 .81263 .24047 .80976 .23618 Mtetra
.80976 .23618 .81263 .24047 .81941 .23815 .81655 .23386 Mtetra
.81655 .23386 .81941 .23815 .82621 .23583 .82336 .23152 Mtetra
.82336 .23152 .82621 .23583 .83303 .2335 .83019 .22918 Mtetra
.83019 .22918 .83303 .2335 .83986 .23116 .83703 .22684 Mtetra
.22591 .43142 .22964 .4349 .23514 .43302 .23142 .42953 Mtetra
.23142 .42953 .23514 .43302 .24065 .43113 .23694 .42763 Mtetra
.23694 .42763 .24065 .43113 .24617 .42924 .24247 .42573 Mtetra
.24247 .42573 .24617 .42924 .25171 .42734 .24801 .42383 Mtetra
.24801 .42383 .25171 .42734 .25726 .42544 .25356 .42192 Mtetra
.25356 .42192 .25726 .42544 .26281 .42354 .25913 .42001 Mtetra
.25913 .42001 .26281 .42354 .26838 .42163 .26471 .4181 Mtetra
.26471 .4181 .26838 .42163 .27397 .41972 .27029 .41618 Mtetra
.27029 .41618 .27397 .41972 .27956 .4178 .2759 .41425 Mtetra
.2759 .41425 .27956 .4178 .28517 .41588 .28151 .41233 Mtetra
.28151 .41233 .28517 .41588 .29078 .41396 .28713 .41039 Mtetra
.28713 .41039 .29078 .41396 .29641 .41203 .29277 .40846 Mtetra
.29277 .40846 .29641 .41203 .30206 .4101 .29842 .40652 Mtetra
.29842 .40652 .30206 .4101 .30771 .40816 .30408 .40457 Mtetra
.30408 .40457 .30771 .40816 .31338 .40622 .30976 .40262 Mtetra
.30976 .40262 .31338 .40622 .31905 .40427 .31544 .40067 Mtetra
.31544 .40067 .31905 .40427 .32475 .40232 .32114 .39871 Mtetra
.32114 .39871 .32475 .40232 .33045 .40037 .32685 .39675 Mtetra
.32685 .39675 .33045 .40037 .33616 .39841 .33257 .39479 Mtetra
.33257 .39479 .33616 .39841 .34189 .39645 .33831 .39282 Mtetra
.33831 .39282 .34189 .39645 .34763 .39448 .34405 .39084 Mtetra
.34405 .39084 .34763 .39448 .35338 .39252 .34981 .38887 Mtetra
.34981 .38887 .35338 .39252 .35915 .39054 .35559 .38688 Mtetra
.35559 .38688 .35915 .39054 .36492 .38856 .36137 .3849 Mtetra
.36137 .3849 .36492 .38856 .37071 .38658 .36717 .38291 Mtetra
.36717 .38291 .37071 .38658 .37652 .3846 .37298 .38092 Mtetra
.664 .741 .908 r
.37298 .38092 .37652 .3846 .38233 .38261 .3788 .37893 Mtetra
.663 .741 .908 r
.3788 .37893 .38233 .38261 .38816 .38062 .38464 .37693 Mtetra
.38464 .37693 .38816 .38062 .394 .37864 .39048 .37495 Mtetra
.662 .741 .909 r
.39048 .37495 .394 .37864 .39985 .37666 .39634 .37296 Mtetra
.661 .741 .909 r
.39634 .37296 .39985 .37666 .40571 .37469 .40221 .371 Mtetra
.658 .74 .911 r
.40221 .371 .40571 .37469 .41159 .37275 .4081 .36907 Mtetra
.654 .74 .913 r
.4081 .36907 .41159 .37275 .41748 .37086 .41399 .3672 Mtetra
.646 .74 .917 r
.41399 .3672 .41748 .37086 .42338 .36904 .4199 .36542 Mtetra
.633 .739 .924 r
.4199 .36542 .42338 .36904 .42928 .36736 .42581 .36383 Mtetra
.607 .736 .936 r
.42581 .36383 .42928 .36736 .4352 .3659 .43173 .36254 Mtetra
.553 .727 .955 r
.43173 .36254 .4352 .3659 .44112 .36486 .43765 .3618 Mtetra
.423 .691 .975 r
.43765 .3618 .44112 .36486 .44704 .36451 .44356 .36199 Mtetra
.06 .517 .895 r
.44356 .36199 .44704 .36451 .45295 .36535 .44946 .3638 Mtetra
.572 .002 0 r
.44946 .3638 .45295 .36535 .45885 .36821 .45532 .36835 Mtetra
.821 .362 .133 r
.45532 .36835 .45885 .36821 .46471 .37441 .46113 .37741 Mtetra
.859 .482 .332 r
.46113 .37741 .46471 .37441 .47053 .38583 .46688 .3933 Mtetra
.856 .52 .415 r
.46688 .3933 .47053 .38583 .4763 .40464 .47256 .41809 Mtetra
.84 .524 .453 r
.47256 .41809 .4763 .40464 .48205 .43182 .47825 .45086 Mtetra
.808 .5 .469 r
.47825 .45086 .48205 .43182 .48788 .46398 .48408 .48355 Mtetra
.729 .42 .457 r
.48408 .48355 .48788 .46398 .49389 .49058 .49021 .50129 Mtetra
.14 0 .158 r
.49021 .50129 .49389 .49058 .50018 .49838 .49665 .4941 Mtetra
.938 .741 .61 r
.49665 .4941 .50018 .49838 .50663 .48413 .5032 .46861 Mtetra
.843 .623 .604 r
.5032 .46861 .50663 .48413 .5131 .45888 .50969 .44109 Mtetra
.776 .572 .624 r
.50969 .44109 .5131 .45888 .51948 .4371 .51606 .42338 Mtetra
.656 .518 .683 r
.51606 .42338 .51948 .4371 .52581 .42687 .52238 .41898 Mtetra
.034 .22 .724 r
.52238 .41898 .52581 .42687 .53214 .42908 .52872 .42556 Mtetra
.791 .327 0 r
.52872 .42556 .53214 .42908 .53854 .43937 .53512 .4367 Mtetra
.602 .074 0 r
.53512 .4367 .53854 .43937 .54501 .44927 .54157 .44331 Mtetra
.762 .695 .788 r
.54157 .44331 .54501 .44927 .55145 .44937 .54797 .43791 Mtetra
.836 .64 .637 r
.54797 .43791 .55145 .44937 .55778 .43538 .55427 .41977 Mtetra
.835 .616 .607 r
.55427 .41977 .55778 .43538 .56394 .41117 .56044 .39478 Mtetra
.828 .609 .605 r
.56044 .39478 .56394 .41117 .57001 .38452 .56654 .37 Mtetra
.822 .612 .619 r
.56654 .37 .57001 .38452 .57604 .36121 .57262 .34948 Mtetra
.815 .625 .646 r
.57262 .34948 .57604 .36121 .5821 .3433 .57873 .3341 Mtetra
.805 .645 .683 r
.57873 .3341 .5821 .3433 .58821 .3304 .58489 .32309 Mtetra
.791 .669 .729 r
.58489 .32309 .58821 .3304 .59438 .32129 .5911 .31524 Mtetra
.77 .693 .777 r
.5911 .31524 .59438 .32129 .60059 .31477 .59734 .30952 Mtetra
.747 .711 .818 r
.59734 .30952 .60059 .31477 .60685 .30992 .60362 .30515 Mtetra
.724 .724 .85 r
.60362 .30515 .60685 .30992 .61314 .3061 .60992 .30163 Mtetra
.705 .731 .871 r
.60992 .30163 .61314 .3061 .61945 .30293 .61625 .29863 Mtetra
.691 .736 .885 r
.61625 .29863 .61945 .30293 .62579 .30015 .62261 .29595 Mtetra
.681 .738 .894 r
.62261 .29595 .62579 .30015 .63215 .2976 .62898 .29346 Mtetra
.674 .739 .899 r
.62898 .29346 .63215 .2976 .63853 .29519 .63536 .29108 Mtetra
.67 .74 .902 r
.63536 .29108 .63853 .29519 .64492 .29286 .64177 .28876 Mtetra
.668 .74 .904 r
.64177 .28876 .64492 .29286 .65133 .29058 .64819 .28649 Mtetra
.666 .741 .906 r
.64819 .28649 .65133 .29058 .65776 .28833 .65463 .28424 Mtetra
.665 .741 .906 r
.65463 .28424 .65776 .28833 .6642 .28609 .66108 .282 Mtetra
.665 .741 .907 r
.66108 .282 .6642 .28609 .67065 .28386 .66754 .27976 Mtetra
.664 .741 .907 r
.66754 .27976 .67065 .28386 .67713 .28163 .67403 .27752 Mtetra
.67403 .27752 .67713 .28163 .68361 .27941 .68052 .27529 Mtetra
.68052 .27529 .68361 .27941 .69011 .27717 .68704 .27305 Mtetra
.68704 .27305 .69011 .27717 .69663 .27494 .69356 .2708 Mtetra
.69356 .2708 .69663 .27494 .70316 .2727 .7001 .26855 Mtetra
.7001 .26855 .70316 .2727 .70971 .27046 .70666 .2663 Mtetra
.70666 .2663 .70971 .27046 .71627 .26821 .71323 .26404 Mtetra
.71323 .26404 .71627 .26821 .72285 .26595 .71982 .26178 Mtetra
.71982 .26178 .72285 .26595 .72944 .2637 .72642 .25951 Mtetra
.72642 .25951 .72944 .2637 .73605 .26143 .73304 .25724 Mtetra
.73304 .25724 .73605 .26143 .74267 .25916 .73968 .25496 Mtetra
.73968 .25496 .74267 .25916 .74931 .25689 .74633 .25268 Mtetra
.74633 .25268 .74931 .25689 .75596 .25461 .75299 .25039 Mtetra
.75299 .25039 .75596 .25461 .76263 .25233 .75967 .24809 Mtetra
.75967 .24809 .76263 .25233 .76932 .25004 .76637 .2458 Mtetra
.76637 .2458 .76932 .25004 .77602 .24774 .77308 .24349 Mtetra
.77308 .24349 .77602 .24774 .78273 .24544 .7798 .24118 Mtetra
.7798 .24118 .78273 .24544 .78947 .24314 .78655 .23886 Mtetra
.78655 .23886 .78947 .24314 .79621 .24082 .79331 .23654 Mtetra
.79331 .23654 .79621 .24082 .80298 .23851 .80008 .23422 Mtetra
.80008 .23422 .80298 .23851 .80976 .23618 .80687 .23188 Mtetra
.80687 .23188 .80976 .23618 .81655 .23386 .81368 .22955 Mtetra
.81368 .22955 .81655 .23386 .82336 .23152 .8205 .2272 Mtetra
.8205 .2272 .82336 .23152 .83019 .22918 .82734 .22485 Mtetra
.82734 .22485 .83019 .22918 .83703 .22684 .83419 .2225 Mtetra
.22217 .42793 .22591 .43142 .23142 .42953 .22768 .42603 Mtetra
.22768 .42603 .23142 .42953 .23694 .42763 .23321 .42412 Mtetra
.23321 .42412 .23694 .42763 .24247 .42573 .23875 .42222 Mtetra
.23875 .42222 .24247 .42573 .24801 .42383 .24429 .42031 Mtetra
.24429 .42031 .24801 .42383 .25356 .42192 .24985 .41839 Mtetra
.24985 .41839 .25356 .42192 .25913 .42001 .25543 .41647 Mtetra
.25543 .41647 .25913 .42001 .26471 .4181 .26101 .41455 Mtetra
.26101 .41455 .26471 .4181 .27029 .41618 .26661 .41262 Mtetra
.26661 .41262 .27029 .41618 .2759 .41425 .27222 .41069 Mtetra
.27222 .41069 .2759 .41425 .28151 .41233 .27784 .40876 Mtetra
.27784 .40876 .28151 .41233 .28713 .41039 .28347 .40682 Mtetra
.28347 .40682 .28713 .41039 .29277 .40846 .28911 .40487 Mtetra
.28911 .40487 .29277 .40846 .29842 .40652 .29477 .40292 Mtetra
.29477 .40292 .29842 .40652 .30408 .40457 .30044 .40097 Mtetra
.30044 .40097 .30408 .40457 .30976 .40262 .30612 .39902 Mtetra
.30612 .39902 .30976 .40262 .31544 .40067 .31181 .39705 Mtetra
.31181 .39705 .31544 .40067 .32114 .39871 .31752 .39509 Mtetra
.31752 .39509 .32114 .39871 .32685 .39675 .32324 .39312 Mtetra
.32324 .39312 .32685 .39675 .33257 .39479 .32897 .39115 Mtetra
.32897 .39115 .33257 .39479 .33831 .39282 .33471 .38917 Mtetra
.33471 .38917 .33831 .39282 .34405 .39084 .34046 .38719 Mtetra
.34046 .38719 .34405 .39084 .34981 .38887 .34623 .3852 Mtetra
.34623 .3852 .34981 .38887 .35559 .38688 .35201 .38321 Mtetra
.35201 .38321 .35559 .38688 .36137 .3849 .3578 .38122 Mtetra
.3578 .38122 .36137 .3849 .36717 .38291 .36361 .37923 Mtetra
.36361 .37923 .36717 .38291 .37298 .38092 .36943 .37723 Mtetra
.663 .741 .908 r
.36943 .37723 .37298 .38092 .3788 .37893 .37526 .37523 Mtetra
.37526 .37523 .3788 .37893 .38464 .37693 .3811 .37323 Mtetra
.662 .741 .908 r
.3811 .37323 .38464 .37693 .39048 .37495 .38695 .37124 Mtetra
.661 .741 .909 r
.38695 .37124 .39048 .37495 .39634 .37296 .39282 .36926 Mtetra
.66 .741 .91 r
.39282 .36926 .39634 .37296 .40221 .371 .3987 .3673 Mtetra
.656 .74 .912 r
.3987 .3673 .40221 .371 .4081 .36907 .40459 .36538 Mtetra
.651 .74 .915 r
.40459 .36538 .4081 .36907 .41399 .3672 .41049 .36354 Mtetra
.641 .74 .92 r
.41049 .36354 .41399 .3672 .4199 .36542 .4164 .36184 Mtetra
.623 .738 .929 r
.4164 .36184 .4199 .36542 .42581 .36383 .42232 .36037 Mtetra
.585 .733 .945 r
.42232 .36037 .42581 .36383 .43173 .36254 .42824 .35932 Mtetra
.498 .714 .968 r
.42824 .35932 .43173 .36254 .43765 .3618 .43415 .35901 Mtetra
.264 .627 .961 r
.43415 .35901 .43765 .3618 .44356 .36199 .44005 .35998 Mtetra
0 .237 .634 r
.44005 .35998 .44356 .36199 .44946 .3638 .44592 .3632 Mtetra
.77 .265 0 r
.44592 .3632 .44946 .3638 .45532 .36835 .45174 .37023 Mtetra
.852 .452 .283 r
.45174 .37023 .45532 .36835 .46113 .37741 .45747 .38335 Mtetra
.858 .512 .397 r
.45747 .38335 .46113 .37741 .46688 .3933 .46311 .4052 Mtetra
.846 .527 .447 r
.46311 .4052 .46688 .3933 .47256 .41809 .46868 .43679 Mtetra
.821 .514 .47 r
.46868 .43679 .47256 .41809 .47825 .45086 .47432 .47311 Mtetra
.768 .464 .472 r
.47432 .47311 .47825 .45086 .48408 .48355 .48025 .50002 Mtetra
.557 .245 .395 r
.48025 .50002 .48408 .48355 .49021 .50129 .4866 .50212 Mtetra
.986 .827 .601 r
.4866 .50212 .49021 .50129 .49665 .4941 .49321 .47935 Mtetra
.863 .637 .595 r
.49321 .47935 .49665 .4941 .5032 .46861 .49982 .4477 Mtetra
.796 .576 .604 r
.49982 .4477 .5032 .46861 .50969 .44109 .5063 .42289 Mtetra
.721 .534 .637 r
.5063 .42289 .50969 .44109 .51606 .42338 .51265 .4115 Mtetra
.499 .438 .72 r
.51265 .4115 .51606 .42338 .52238 .41898 .51895 .413 Mtetra
0 0 .442 r
.51895 .413 .52238 .41898 .52872 .42556 .52528 .42283 Mtetra
.803 .325 0 r
.52528 .42283 .52872 .42556 .53512 .4367 .53168 .43333 Mtetra
.08 .477 .892 r
.53168 .43333 .53512 .4367 .54157 .44331 .53811 .43583 Mtetra
.822 .68 .707 r
.53811 .43583 .54157 .44331 .54797 .43791 .5445 .42548 Mtetra
.842 .636 .624 r
.5445 .42548 .54797 .43791 .55427 .41977 .55078 .40458 Mtetra
.837 .619 .607 r
.55078 .40458 .55427 .41977 .56044 .39478 .55696 .37988 Mtetra
.83 .616 .613 r
.55696 .37988 .56044 .39478 .56654 .37 .5631 .35722 Mtetra
.823 .622 .632 r
.5631 .35722 .56654 .37 .57262 .34948 .56923 .33921 Mtetra
.814 .637 .663 r
.56923 .33921 .57262 .34948 .57873 .3341 .57538 .32594 Mtetra
.802 .659 .704 r
.57538 .32594 .57873 .3341 .58489 .32309 .58158 .31644 Mtetra
.784 .682 .751 r
.58158 .31644 .58489 .32309 .5911 .31524 .58781 .30959 Mtetra
.762 .703 .796 r
.58781 .30959 .5911 .31524 .59734 .30952 .59408 .3045 Mtetra
.737 .718 .833 r
.59408 .3045 .59734 .30952 .60362 .30515 .60038 .30052 Mtetra
.716 .728 .86 r
.60038 .30052 .60362 .30515 .60992 .30163 .6067 .29723 Mtetra
.699 .734 .878 r
.6067 .29723 .60992 .30163 .61625 .29863 .61304 .29437 Mtetra
.686 .737 .889 r
.61304 .29437 .61625 .29863 .62261 .29595 .61941 .29177 Mtetra
.678 .739 .896 r
.61941 .29177 .62261 .29595 .62898 .29346 .62579 .28932 Mtetra
.673 .74 .901 r
.62579 .28932 .62898 .29346 .63536 .29108 .63219 .28696 Mtetra
.669 .74 .903 r
.63219 .28696 .63536 .29108 .64177 .28876 .6386 .28466 Mtetra
.667 .74 .905 r
.6386 .28466 .64177 .28876 .64819 .28649 .64504 .28239 Mtetra
.666 .741 .906 r
.64504 .28239 .64819 .28649 .65463 .28424 .65148 .28013 Mtetra
.665 .741 .906 r
.65148 .28013 .65463 .28424 .66108 .282 .65794 .27789 Mtetra
.665 .741 .907 r
.65794 .27789 .66108 .282 .66754 .27976 .66442 .27564 Mtetra
.664 .741 .907 r
.66442 .27564 .66754 .27976 .67403 .27752 .67091 .2734 Mtetra
.67091 .2734 .67403 .27752 .68052 .27529 .67742 .27115 Mtetra
.67742 .27115 .68052 .27529 .68704 .27305 .68394 .2689 Mtetra
.68394 .2689 .68704 .27305 .69356 .2708 .69048 .26665 Mtetra
.69048 .26665 .69356 .2708 .7001 .26855 .69703 .26439 Mtetra
.69703 .26439 .7001 .26855 .70666 .2663 .7036 .26213 Mtetra
.7036 .26213 .70666 .2663 .71323 .26404 .71018 .25986 Mtetra
.71018 .25986 .71323 .26404 .71982 .26178 .71678 .25759 Mtetra
.71678 .25759 .71982 .26178 .72642 .25951 .7234 .25531 Mtetra
.7234 .25531 .72642 .25951 .73304 .25724 .73002 .25303 Mtetra
.73002 .25303 .73304 .25724 .73968 .25496 .73667 .25074 Mtetra
.73667 .25074 .73968 .25496 .74633 .25268 .74333 .24845 Mtetra
.74333 .24845 .74633 .25268 .75299 .25039 .75 .24615 Mtetra
.75 .24615 .75299 .25039 .75967 .24809 .75669 .24384 Mtetra
.75669 .24384 .75967 .24809 .76637 .2458 .7634 .24154 Mtetra
.7634 .24154 .76637 .2458 .77308 .24349 .77012 .23922 Mtetra
.77012 .23922 .77308 .24349 .7798 .24118 .77686 .2369 Mtetra
.77686 .2369 .7798 .24118 .78655 .23886 .78362 .23457 Mtetra
.78362 .23457 .78655 .23886 .79331 .23654 .79039 .23224 Mtetra
.79039 .23224 .79331 .23654 .80008 .23422 .79717 .22991 Mtetra
.79717 .22991 .80008 .23422 .80687 .23188 .80397 .22756 Mtetra
.80397 .22756 .80687 .23188 .81368 .22955 .81079 .22521 Mtetra
.81079 .22521 .81368 .22955 .8205 .2272 .81763 .22286 Mtetra
.81763 .22286 .8205 .2272 .82734 .22485 .82448 .2205 Mtetra
.82448 .2205 .82734 .22485 .83419 .2225 .83134 .21814 Mtetra
.21841 .42442 .22217 .42793 .22768 .42603 .22393 .42251 Mtetra
.22393 .42251 .22768 .42603 .23321 .42412 .22947 .4206 Mtetra
.22947 .4206 .23321 .42412 .23875 .42222 .23501 .41869 Mtetra
.23501 .41869 .23875 .42222 .24429 .42031 .24056 .41677 Mtetra
.24056 .41677 .24429 .42031 .24985 .41839 .24613 .41485 Mtetra
.24613 .41485 .24985 .41839 .25543 .41647 .25171 .41292 Mtetra
.25171 .41292 .25543 .41647 .26101 .41455 .2573 .41099 Mtetra
.2573 .41099 .26101 .41455 .26661 .41262 .26291 .40905 Mtetra
.26291 .40905 .26661 .41262 .27222 .41069 .26852 .40711 Mtetra
.26852 .40711 .27222 .41069 .27784 .40876 .27415 .40517 Mtetra
.27415 .40517 .27784 .40876 .28347 .40682 .27979 .40322 Mtetra
.27979 .40322 .28347 .40682 .28911 .40487 .28544 .40127 Mtetra
.28544 .40127 .28911 .40487 .29477 .40292 .2911 .39932 Mtetra
.2911 .39932 .29477 .40292 .30044 .40097 .29678 .39736 Mtetra
.29678 .39736 .30044 .40097 .30612 .39902 .30247 .39539 Mtetra
.30247 .39539 .30612 .39902 .31181 .39705 .30817 .39342 Mtetra
.30817 .39342 .31181 .39705 .31752 .39509 .31388 .39145 Mtetra
.31388 .39145 .31752 .39509 .32324 .39312 .31961 .38947 Mtetra
.31961 .38947 .32324 .39312 .32897 .39115 .32535 .38749 Mtetra
.32535 .38749 .32897 .39115 .33471 .38917 .3311 .38551 Mtetra
.3311 .38551 .33471 .38917 .34046 .38719 .33686 .38352 Mtetra
.33686 .38352 .34046 .38719 .34623 .3852 .34263 .38152 Mtetra
.34263 .38152 .34623 .3852 .35201 .38321 .34842 .37953 Mtetra
.34842 .37953 .35201 .38321 .3578 .38122 .35422 .37753 Mtetra
.664 .741 .908 r
.35422 .37753 .3578 .38122 .36361 .37923 .36003 .37552 Mtetra
.36003 .37552 .36361 .37923 .36943 .37723 .36586 .37352 Mtetra
.663 .741 .908 r
.36586 .37352 .36943 .37723 .37526 .37523 .3717 .37151 Mtetra
.3717 .37151 .37526 .37523 .3811 .37323 .37755 .36951 Mtetra
.662 .741 .909 r
.37755 .36951 .3811 .37323 .38695 .37124 .38341 .36752 Mtetra
.661 .741 .909 r
.38341 .36752 .38695 .37124 .39282 .36926 .38929 .36554 Mtetra
.658 .741 .911 r
.38929 .36554 .39282 .36926 .3987 .3673 .39517 .36359 Mtetra
.654 .74 .913 r
.39517 .36359 .3987 .3673 .40459 .36538 .40107 .3617 Mtetra
.647 .74 .917 r
.40107 .3617 .40459 .36538 .41049 .36354 .40698 .35991 Mtetra
.633 .739 .924 r
.40698 .35991 .41049 .36354 .4164 .36184 .41289 .3583 Mtetra
.606 .736 .937 r
.41289 .3583 .4164 .36184 .42232 .36037 .41881 .35702 Mtetra
.547 .726 .958 r
.41881 .35702 .42232 .36037 .42824 .35932 .42472 .35632 Mtetra
.395 .683 .976 r
.42472 .35632 .42824 .35932 .43415 .35901 .43063 .35664 Mtetra
0 .45 .839 r
.43063 .35664 .43415 .35901 .44005 .35998 .4365 .35879 Mtetra
.668 .116 0 r
.4365 .35879 .44005 .35998 .44592 .3632 .44232 .36411 Mtetra
.838 .409 .213 r
.44232 .36411 .44592 .3632 .45174 .37023 .44806 .37473 Mtetra
.858 .499 .371 r
.44806 .37473 .45174 .37023 .45747 .38335 .45368 .3935 Mtetra
.851 .526 .438 r
.45368 .3935 .45747 .38335 .46311 .4052 .45917 .42271 Mtetra
.831 .523 .468 r
.45917 .42271 .46311 .4052 .46868 .43679 .46465 .46029 Mtetra
.791 .49 .479 r
.46465 .46029 .46868 .43679 .47432 .47311 .47034 .49459 Mtetra
.678 .375 .453 r
.47034 .49459 .47432 .47311 .48025 .50002 .47651 .50711 Mtetra
.854 .874 .433 r
.47651 .50711 .48025 .50002 .4866 .50212 .48312 .49008 Mtetra
.887 .661 .591 r
.48312 .49008 .4866 .50212 .49321 .47935 .48986 .45646 Mtetra
.811 .583 .592 r
.48986 .45646 .49321 .47935 .49982 .4477 .49647 .42528 Mtetra
.751 .542 .612 r
.49647 .42528 .49982 .4477 .5063 .42289 .5029 .40681 Mtetra
.642 .492 .665 r
.5029 .40681 .5063 .42289 .51265 .4115 .50922 .40244 Mtetra
.111 .239 .717 r
.50922 .40244 .51265 .4115 .51895 .413 .5155 .40904 Mtetra
.792 .338 0 r
.5155 .40904 .51895 .413 .52528 .42283 .52183 .42066 Mtetra
.753 .245 0 r
.52183 .42066 .52528 .42283 .53168 .43333 .52822 .42915 Mtetra
.654 .732 .907 r
.52822 .42915 .53168 .43333 .53811 .43583 .53464 .4271 Mtetra
.844 .669 .666 r
.53464 .4271 .53811 .43583 .5445 .42548 .54102 .41258 Mtetra
.846 .636 .617 r
.54102 .41258 .5445 .42548 .55078 .40458 .5473 .39011 Mtetra
.839 .623 .61 r
.5473 .39011 .55078 .40458 .55696 .37988 .5535 .36637 Mtetra
.831 .623 .621 r
.5535 .36637 .55696 .37988 .5631 .35722 .55967 .34588 Mtetra
.823 .632 .645 r
.55967 .34588 .5631 .35722 .56923 .33921 .56584 .33008 Mtetra
.812 .649 .681 r
.56584 .33008 .56923 .33921 .57538 .32594 .57204 .31856 Mtetra
.797 .671 .725 r
.57204 .31856 .57538 .32594 .58158 .31644 .57827 .31029 Mtetra
.776 .693 .771 r
.57827 .31029 .58158 .31644 .58781 .30959 .58452 .30425 Mtetra
.752 .711 .813 r
.58452 .30425 .58781 .30959 .59408 .3045 .59081 .29966 Mtetra
.729 .723 .846 r
.59081 .29966 .59408 .3045 .60038 .30052 .59713 .29599 Mtetra
.708 .731 .868 r
.59713 .29599 .60038 .30052 .6067 .29723 .60346 .29289 Mtetra
.693 .735 .883 r
.60346 .29289 .6067 .29723 .61304 .29437 .60982 .29013 Mtetra
.683 .738 .893 r
.60982 .29013 .61304 .29437 .61941 .29177 .6162 .28759 Mtetra
.676 .739 .898 r
.6162 .28759 .61941 .29177 .62579 .28932 .62259 .28518 Mtetra
.671 .74 .902 r
.62259 .28518 .62579 .28932 .63219 .28696 .629 .28284 Mtetra
.668 .74 .904 r
.629 .28284 .63219 .28696 .6386 .28466 .63543 .28054 Mtetra
.667 .74 .905 r
.63543 .28054 .6386 .28466 .64504 .28239 .64187 .27827 Mtetra
.666 .741 .906 r
.64187 .27827 .64504 .28239 .65148 .28013 .64833 .27601 Mtetra
.665 .741 .907 r
.64833 .27601 .65148 .28013 .65794 .27789 .6548 .27376 Mtetra
.6548 .27376 .65794 .27789 .66442 .27564 .66128 .27151 Mtetra
.664 .741 .907 r
.66128 .27151 .66442 .27564 .67091 .2734 .66779 .26926 Mtetra
.66779 .26926 .67091 .2734 .67742 .27115 .6743 .267 Mtetra
.6743 .267 .67742 .27115 .68394 .2689 .68084 .26474 Mtetra
.68084 .26474 .68394 .2689 .69048 .26665 .68739 .26248 Mtetra
.68739 .26248 .69048 .26665 .69703 .26439 .69395 .26021 Mtetra
.69395 .26021 .69703 .26439 .7036 .26213 .70053 .25794 Mtetra
.70053 .25794 .7036 .26213 .71018 .25986 .70712 .25566 Mtetra
.70712 .25566 .71018 .25986 .71678 .25759 .71373 .25338 Mtetra
.71373 .25338 .71678 .25759 .7234 .25531 .72035 .25109 Mtetra
.72035 .25109 .7234 .25531 .73002 .25303 .72699 .2488 Mtetra
.72699 .2488 .73002 .25303 .73667 .25074 .73365 .2465 Mtetra
.73365 .2465 .73667 .25074 .74333 .24845 .74032 .2442 Mtetra
.74032 .2442 .74333 .24845 .75 .24615 .747 .24189 Mtetra
.747 .24189 .75 .24615 .75669 .24384 .75371 .23958 Mtetra
.75371 .23958 .75669 .24384 .7634 .24154 .76042 .23726 Mtetra
.76042 .23726 .7634 .24154 .77012 .23922 .76716 .23493 Mtetra
.76716 .23493 .77012 .23922 .77686 .2369 .77391 .2326 Mtetra
.77391 .2326 .77686 .2369 .78362 .23457 .78067 .23027 Mtetra
.78067 .23027 .78362 .23457 .79039 .23224 .78745 .22792 Mtetra
.78745 .22792 .79039 .23224 .79717 .22991 .79425 .22558 Mtetra
.79425 .22558 .79717 .22991 .80397 .22756 .80106 .22322 Mtetra
.80106 .22322 .80397 .22756 .81079 .22521 .80789 .22087 Mtetra
.80789 .22087 .81079 .22521 .81763 .22286 .81474 .2185 Mtetra
.81474 .2185 .81763 .22286 .82448 .2205 .8216 .21613 Mtetra
.8216 .21613 .82448 .2205 .83134 .21814 .82848 .21376 Mtetra
.21464 .4209 .21841 .42442 .22393 .42251 .22017 .41898 Mtetra
.22017 .41898 .22393 .42251 .22947 .4206 .22571 .41706 Mtetra
.22571 .41706 .22947 .4206 .23501 .41869 .23126 .41514 Mtetra
.23126 .41514 .23501 .41869 .24056 .41677 .23682 .41322 Mtetra
.23682 .41322 .24056 .41677 .24613 .41485 .2424 .41129 Mtetra
.2424 .41129 .24613 .41485 .25171 .41292 .24798 .40935 Mtetra
.24798 .40935 .25171 .41292 .2573 .41099 .25358 .40741 Mtetra
.25358 .40741 .2573 .41099 .26291 .40905 .25919 .40547 Mtetra
.25919 .40547 .26291 .40905 .26852 .40711 .26481 .40352 Mtetra
.26481 .40352 .26852 .40711 .27415 .40517 .27045 .40157 Mtetra
.27045 .40157 .27415 .40517 .27979 .40322 .2761 .39962 Mtetra
.2761 .39962 .27979 .40322 .28544 .40127 .28175 .39766 Mtetra
.28175 .39766 .28544 .40127 .2911 .39932 .28743 .39569 Mtetra
.28743 .39569 .2911 .39932 .29678 .39736 .29311 .39373 Mtetra
.29311 .39373 .29678 .39736 .30247 .39539 .2988 .39175 Mtetra
.2988 .39175 .30247 .39539 .30817 .39342 .30451 .38978 Mtetra
.30451 .38978 .30817 .39342 .31388 .39145 .31023 .3878 Mtetra
.31023 .3878 .31388 .39145 .31961 .38947 .31597 .38581 Mtetra
.31597 .38581 .31961 .38947 .32535 .38749 .32171 .38382 Mtetra
.32171 .38382 .32535 .38749 .3311 .38551 .32747 .38183 Mtetra
.32747 .38183 .3311 .38551 .33686 .38352 .33324 .37983 Mtetra
.33324 .37983 .33686 .38352 .34263 .38152 .33902 .37783 Mtetra
.33902 .37783 .34263 .38152 .34842 .37953 .34482 .37583 Mtetra
.34482 .37583 .34842 .37953 .35422 .37753 .35062 .37382 Mtetra
.35062 .37382 .35422 .37753 .36003 .37552 .35645 .37181 Mtetra
.663 .741 .908 r
.35645 .37181 .36003 .37552 .36586 .37352 .36228 .3698 Mtetra
.36228 .3698 .36586 .37352 .3717 .37151 .36812 .36779 Mtetra
.662 .741 .908 r
.36812 .36779 .3717 .37151 .37755 .36951 .37398 .36578 Mtetra
.661 .741 .909 r
.37398 .36578 .37755 .36951 .38341 .36752 .37985 .36378 Mtetra
.66 .741 .91 r
.37985 .36378 .38341 .36752 .38929 .36554 .38574 .36181 Mtetra
.657 .74 .912 r
.38574 .36181 .38929 .36554 .39517 .36359 .39163 .35988 Mtetra
.651 .74 .915 r
.39163 .35988 .39517 .36359 .40107 .3617 .39753 .35803 Mtetra
.641 .74 .921 r
.39753 .35803 .40107 .3617 .40698 .35991 .40344 .35632 Mtetra
.621 .738 .931 r
.40344 .35632 .40698 .35991 .41289 .3583 .40936 .35486 Mtetra
.579 .733 .948 r
.40936 .35486 .41289 .3583 .41881 .35702 .41528 .35385 Mtetra
.477 .71 .972 r
.41528 .35385 .41881 .35702 .42472 .35632 .42118 .35367 Mtetra
.179 .588 .94 r
.42118 .35367 .42472 .35632 .43063 .35664 .42706 .35496 Mtetra
.489 0 0 r
.42706 .35496 .43063 .35664 .4365 .35879 .4329 .35887 Mtetra
.81 .343 .113 r
.4329 .35887 .4365 .35879 .44232 .36411 .43864 .36732 Mtetra
.855 .48 .337 r
.43864 .36732 .44232 .36411 .44806 .37473 .44425 .38311 Mtetra
.854 .522 .425 r
.44425 .38311 .44806 .37473 .45368 .3935 .4497 .40928 Mtetra
.838 .528 .464 r
.4497 .40928 .45368 .3935 .45917 .42271 .45505 .44617 Mtetra
.807 .507 .48 r
.45505 .44617 .45917 .42271 .46465 .46029 .46051 .4855 Mtetra
.734 .435 .474 r
.46051 .4855 .46465 .46029 .47034 .49459 .46643 .50837 Mtetra
.164 0 .216 r
.46643 .50837 .47034 .49459 .47651 .50711 .47295 .49972 Mtetra
.921 .702 .589 r
.47295 .49972 .47651 .50711 .48312 .49008 .4798 .46675 Mtetra
.827 .593 .585 r
.4798 .46675 .48312 .49008 .48986 .45646 .48658 .43034 Mtetra
.77 .548 .597 r
.48658 .43034 .48986 .45646 .49647 .42528 .49313 .40495 Mtetra
.7 .512 .631 r
.49313 .40495 .49647 .42528 .5029 .40681 .4995 .39431 Mtetra
.477 .416 .71 r
.4995 .39431 .5029 .40681 .50922 .40244 .50576 .39643 Mtetra
0 0 .392 r
.50576 .39643 .50922 .40244 .5155 .40904 .51203 .4068 Mtetra
.848 .388 .021 r
.51203 .4068 .5155 .40904 .52183 .42066 .51836 .41866 Mtetra
.557 0 0 r
.51836 .41866 .52183 .42066 .52822 .42915 .52475 .42398 Mtetra
.806 .734 .784 r
.52475 .42398 .52822 .42915 .53464 .4271 .53117 .41732 Mtetra
.853 .662 .643 r
.53117 .41732 .53464 .4271 .54102 .41258 .53754 .39952 Mtetra
.848 .636 .615 r
.53754 .39952 .54102 .41258 .5473 .39011 .54383 .37644 Mtetra
.839 .627 .615 r
.54383 .37644 .5473 .39011 .5535 .36637 .55006 .3541 Mtetra
.831 .63 .632 r
.55006 .3541 .5535 .36637 .55967 .34588 .55627 .3357 Mtetra
.821 .642 .66 r
.55627 .3357 .55967 .34588 .56584 .33008 .56247 .32184 Mtetra
.808 .66 .699 r
.56247 .32184 .56584 .33008 .57204 .31856 .5687 .31179 Mtetra
.79 .682 .745 r
.5687 .31179 .57204 .31856 .57827 .31029 .57495 .30453 Mtetra
.768 .702 .79 r
.57495 .30453 .57827 .31029 .58452 .30425 .58123 .29914 Mtetra
.743 .717 .828 r
.58123 .29914 .58452 .30425 .59081 .29966 .58754 .29495 Mtetra
.72 .727 .856 r
.58754 .29495 .59081 .29966 .59713 .29599 .59387 .29153 Mtetra
.702 .733 .875 r
.59387 .29153 .59713 .29599 .60346 .29289 .60022 .28858 Mtetra
.689 .737 .887 r
.60022 .28858 .60346 .29289 .60982 .29013 .60659 .28591 Mtetra
.68 .738 .895 r
.60659 .28591 .60982 .29013 .6162 .28759 .61298 .28342 Mtetra
.674 .739 .9 r
.61298 .28342 .6162 .28759 .62259 .28518 .61938 .28103 Mtetra
.67 .74 .903 r
.61938 .28103 .62259 .28518 .629 .28284 .6258 .2787 Mtetra
.668 .74 .905 r
.6258 .2787 .629 .28284 .63543 .28054 .63224 .27641 Mtetra
.666 .741 .906 r
.63224 .27641 .63543 .28054 .64187 .27827 .63869 .27414 Mtetra
.665 .741 .906 r
.63869 .27414 .64187 .27827 .64833 .27601 .64516 .27187 Mtetra
.665 .741 .907 r
.64516 .27187 .64833 .27601 .6548 .27376 .65164 .26961 Mtetra
.664 .741 .907 r
.65164 .26961 .6548 .27376 .66128 .27151 .65814 .26736 Mtetra
.65814 .26736 .66128 .27151 .66779 .26926 .66465 .26509 Mtetra
.66465 .26509 .66779 .26926 .6743 .267 .67118 .26283 Mtetra
.67118 .26283 .6743 .267 .68084 .26474 .67772 .26056 Mtetra
.67772 .26056 .68084 .26474 .68739 .26248 .68428 .25829 Mtetra
.68428 .25829 .68739 .26248 .69395 .26021 .69085 .25601 Mtetra
.69085 .25601 .69395 .26021 .70053 .25794 .69744 .25373 Mtetra
.69744 .25373 .70053 .25794 .70712 .25566 .70404 .25145 Mtetra
.70404 .25145 .70712 .25566 .71373 .25338 .71066 .24915 Mtetra
.71066 .24915 .71373 .25338 .72035 .25109 .7173 .24686 Mtetra
.7173 .24686 .72035 .25109 .72699 .2488 .72395 .24455 Mtetra
.72395 .24455 .72699 .2488 .73365 .2465 .73061 .24225 Mtetra
.73061 .24225 .73365 .2465 .74032 .2442 .7373 .23993 Mtetra
.7373 .23993 .74032 .2442 .747 .24189 .74399 .23761 Mtetra
.74399 .23761 .747 .24189 .75371 .23958 .75071 .23529 Mtetra
.75071 .23529 .75371 .23958 .76042 .23726 .75743 .23296 Mtetra
.75743 .23296 .76042 .23726 .76716 .23493 .76418 .23063 Mtetra
.76418 .23063 .76716 .23493 .77391 .2326 .77094 .22828 Mtetra
.77094 .22828 .77391 .2326 .78067 .23027 .77772 .22594 Mtetra
.77772 .22594 .78067 .23027 .78745 .22792 .78451 .22359 Mtetra
.78451 .22359 .78745 .22792 .79425 .22558 .79132 .22123 Mtetra
.79132 .22123 .79425 .22558 .80106 .22322 .79814 .21887 Mtetra
.79814 .21887 .80106 .22322 .80789 .22087 .80498 .2165 Mtetra
.80498 .2165 .80789 .22087 .81474 .2185 .81184 .21412 Mtetra
.81184 .21412 .81474 .2185 .8216 .21613 .81871 .21174 Mtetra
.81871 .21174 .8216 .21613 .82848 .21376 .8256 .20936 Mtetra
.21086 .41736 .21464 .4209 .22017 .41898 .21639 .41544 Mtetra
.21639 .41544 .22017 .41898 .22571 .41706 .22194 .41351 Mtetra
.22194 .41351 .22571 .41706 .23126 .41514 .22749 .41158 Mtetra
.22749 .41158 .23126 .41514 .23682 .41322 .23306 .40965 Mtetra
.23306 .40965 .23682 .41322 .2424 .41129 .23864 .40771 Mtetra
.23864 .40771 .2424 .41129 .24798 .40935 .24424 .40577 Mtetra
.24424 .40577 .24798 .40935 .25358 .40741 .24984 .40382 Mtetra
.24984 .40382 .25358 .40741 .25919 .40547 .25546 .40187 Mtetra
.25546 .40187 .25919 .40547 .26481 .40352 .26109 .39992 Mtetra
.26109 .39992 .26481 .40352 .27045 .40157 .26673 .39796 Mtetra
.26673 .39796 .27045 .40157 .2761 .39962 .27239 .396 Mtetra
.27239 .396 .2761 .39962 .28175 .39766 .27805 .39403 Mtetra
.27805 .39403 .28175 .39766 .28743 .39569 .28373 .39206 Mtetra
.28373 .39206 .28743 .39569 .29311 .39373 .28942 .39008 Mtetra
.28942 .39008 .29311 .39373 .2988 .39175 .29512 .3881 Mtetra
.29512 .3881 .2988 .39175 .30451 .38978 .30084 .38612 Mtetra
.30084 .38612 .30451 .38978 .31023 .3878 .30657 .38413 Mtetra
.30657 .38413 .31023 .3878 .31597 .38581 .31231 .38214 Mtetra
.31231 .38214 .31597 .38581 .32171 .38382 .31806 .38014 Mtetra
.31806 .38014 .32171 .38382 .32747 .38183 .32383 .37814 Mtetra
.32383 .37814 .32747 .38183 .33324 .37983 .3296 .37613 Mtetra
.3296 .37613 .33324 .37983 .33902 .37783 .33539 .37412 Mtetra
.33539 .37412 .33902 .37783 .34482 .37583 .3412 .37211 Mtetra
.3412 .37211 .34482 .37583 .35062 .37382 .34701 .3701 Mtetra
.34701 .3701 .35062 .37382 .35645 .37181 .35284 .36808 Mtetra
.663 .741 .908 r
.35284 .36808 .35645 .37181 .36228 .3698 .35868 .36606 Mtetra
.35868 .36606 .36228 .3698 .36812 .36779 .36454 .36405 Mtetra
.662 .741 .908 r
.36454 .36405 .36812 .36779 .37398 .36578 .3704 .36204 Mtetra
.661 .741 .909 r
.3704 .36204 .37398 .36578 .37985 .36378 .37628 .36004 Mtetra
.658 .741 .911 r
.37628 .36004 .37985 .36378 .38574 .36181 .38217 .35809 Mtetra
.654 .741 .913 r
.38217 .35809 .38574 .36181 .39163 .35988 .38807 .35618 Mtetra
.646 .74 .918 r
.38807 .35618 .39163 .35988 .39753 .35803 .39398 .35439 Mtetra
.631 .739 .926 r
.39398 .35439 .39753 .35803 .40344 .35632 .39989 .35279 Mtetra
.601 .736 .94 r
.39989 .35279 .40344 .35632 .40936 .35486 .40581 .35155 Mtetra
.53 .724 .963 r
.40581 .35155 .40936 .35486 .41528 .35385 .41172 .35097 Mtetra
.334 .662 .973 r
.41172 .35097 .41528 .35385 .42118 .35367 .41761 .35158 Mtetra
0 .315 .708 r
.41761 .35158 .42118 .35367 .42706 .35496 .42345 .35435 Mtetra
.755 .243 0 r
.42345 .35435 .42706 .35496 .4329 .35887 .4292 .36095 Mtetra
.849 .451 .29 r
.4292 .36095 .4329 .35887 .43864 .36732 .43483 .374 Mtetra
.855 .514 .407 r
.43483 .374 .43864 .36732 .44425 .38311 .44026 .39689 Mtetra
.844 .53 .457 r
.44026 .39689 .44425 .38311 .4497 .40928 .44551 .43168 Mtetra
.819 .518 .48 r
.44551 .43168 .4497 .40928 .45505 .44617 .45076 .47359 Mtetra
.766 .469 .483 r
.45076 .47359 .45505 .44617 .46051 .4855 .45639 .50559 Mtetra
.546 .247 .411 r
.45639 .50559 .46051 .4855 .46643 .50837 .46273 .50723 Mtetra
.969 .773 .585 r
.46273 .50723 .46643 .50837 .47295 .49972 .46963 .4778 Mtetra
.844 .608 .581 r
.46963 .4778 .47295 .49972 .4798 .46675 .47659 .43772 Mtetra
.785 .554 .587 r
.47659 .43772 .4798 .46675 .48658 .43034 .48331 .4058 Mtetra
.731 .522 .61 r
.48331 .4058 .48658 .43034 .49313 .40495 .48977 .38876 Mtetra
.616 .475 .666 r
.48977 .38876 .49313 .40495 .4995 .39431 .49606 .38571 Mtetra
0 .17 .689 r
.49606 .38571 .4995 .39431 .50576 .39643 .50228 .39311 Mtetra
.844 .395 0 r
.50228 .39311 .50576 .39643 .51203 .4068 .50853 .40572 Mtetra
.835 .366 .056 r
.50853 .40572 .51203 .4068 .51836 .41866 .51486 .41634 Mtetra
.128 .584 .923 r
.51486 .41634 .51836 .41866 .52475 .42398 .52127 .41768 Mtetra
.849 .711 .711 r
.52127 .41768 .52475 .42398 .53117 .41732 .52769 .40668 Mtetra
.857 .656 .63 r
.52769 .40668 .53117 .41732 .53754 .39952 .53407 .38655 Mtetra
.848 .636 .615 r
.53407 .38655 .53754 .39952 .54383 .37644 .54038 .36362 Mtetra
.839 .631 .622 r
.54038 .36362 .54383 .37644 .55006 .3541 .54663 .34291 Mtetra
.829 .637 .643 r
.54663 .34291 .55006 .3541 .55627 .3357 .55286 .32648 Mtetra
.818 .651 .676 r
.55286 .32648 .55627 .3357 .56247 .32184 .5591 .3143 Mtetra
.803 .671 .718 r
.5591 .3143 .56247 .32184 .5687 .31179 .56535 .30549 Mtetra
.782 .691 .764 r
.56535 .30549 .5687 .31179 .57495 .30453 .57163 .29906 Mtetra
.758 .709 .806 r
.57163 .29906 .57495 .30453 .58123 .29914 .57793 .2942 Mtetra
.734 .722 .84 r
.57793 .2942 .58123 .29914 .58754 .29495 .58425 .29035 Mtetra
.713 .73 .864 r
.58425 .29035 .58754 .29495 .59387 .29153 .5906 .28713 Mtetra
.696 .735 .881 r
.5906 .28713 .59387 .29153 .60022 .28858 .59696 .28429 Mtetra
.685 .737 .891 r
.59696 .28429 .60022 .28858 .60659 .28591 .60334 .2817 Mtetra
.677 .739 .897 r
.60334 .2817 .60659 .28591 .61298 .28342 .60974 .27924 Mtetra
.672 .74 .901 r
.60974 .27924 .61298 .28342 .61938 .28103 .61615 .27687 Mtetra
.669 .74 .904 r
.61615 .27687 .61938 .28103 .6258 .2787 .62259 .27455 Mtetra
.667 .74 .905 r
.62259 .27455 .6258 .2787 .63224 .27641 .62903 .27226 Mtetra
.666 .741 .906 r
.62903 .27226 .63224 .27641 .63869 .27414 .63549 .26999 Mtetra
.665 .741 .906 r
.63549 .26999 .63869 .27414 .64516 .27187 .64197 .26772 Mtetra
.665 .741 .907 r
.64197 .26772 .64516 .27187 .65164 .26961 .64846 .26545 Mtetra
.664 .741 .907 r
.64846 .26545 .65164 .26961 .65814 .26736 .65497 .26319 Mtetra
.65497 .26319 .65814 .26736 .66465 .26509 .6615 .26092 Mtetra
.6615 .26092 .66465 .26509 .67118 .26283 .66803 .25864 Mtetra
.66803 .25864 .67118 .26283 .67772 .26056 .67459 .25637 Mtetra
.67459 .25637 .67772 .26056 .68428 .25829 .68116 .25409 Mtetra
.68116 .25409 .68428 .25829 .69085 .25601 .68774 .2518 Mtetra
.68774 .2518 .69085 .25601 .69744 .25373 .69434 .24951 Mtetra
.69434 .24951 .69744 .25373 .70404 .25145 .70095 .24721 Mtetra
.70095 .24721 .70404 .25145 .71066 .24915 .70758 .24491 Mtetra
.70758 .24491 .71066 .24915 .7173 .24686 .71423 .2426 Mtetra
.71423 .2426 .7173 .24686 .72395 .24455 .72089 .24029 Mtetra
.72089 .24029 .72395 .24455 .73061 .24225 .72757 .23797 Mtetra
.72757 .23797 .73061 .24225 .7373 .23993 .73426 .23565 Mtetra
.73426 .23565 .7373 .23993 .74399 .23761 .74097 .23332 Mtetra
.74097 .23332 .74399 .23761 .75071 .23529 .74769 .23098 Mtetra
.74769 .23098 .75071 .23529 .75743 .23296 .75443 .22864 Mtetra
.75443 .22864 .75743 .23296 .76418 .23063 .76119 .2263 Mtetra
.76119 .2263 .76418 .23063 .77094 .22828 .76796 .22395 Mtetra
.76796 .22395 .77094 .22828 .77772 .22594 .77475 .22159 Mtetra
.77475 .22159 .77772 .22594 .78451 .22359 .78155 .21923 Mtetra
.78155 .21923 .78451 .22359 .79132 .22123 .78837 .21686 Mtetra
.78837 .21686 .79132 .22123 .79814 .21887 .79521 .21449 Mtetra
.79521 .21449 .79814 .21887 .80498 .2165 .80206 .21211 Mtetra
.80206 .21211 .80498 .2165 .81184 .21412 .80893 .20972 Mtetra
.80893 .20972 .81184 .21412 .81871 .21174 .81581 .20733 Mtetra
.81581 .20733 .81871 .21174 .8256 .20936 .82271 .20494 Mtetra
.20705 .41381 .21086 .41736 .21639 .41544 .21259 .41188 Mtetra
.21259 .41188 .21639 .41544 .22194 .41351 .21815 .40995 Mtetra
.21815 .40995 .22194 .41351 .22749 .41158 .22371 .40801 Mtetra
.22371 .40801 .22749 .41158 .23306 .40965 .22929 .40607 Mtetra
.22929 .40607 .23306 .40965 .23864 .40771 .23488 .40412 Mtetra
.23488 .40412 .23864 .40771 .24424 .40577 .24048 .40217 Mtetra
.24048 .40217 .24424 .40577 .24984 .40382 .24609 .40022 Mtetra
.24609 .40022 .24984 .40382 .25546 .40187 .25172 .39826 Mtetra
.25172 .39826 .25546 .40187 .26109 .39992 .25735 .3963 Mtetra
.25735 .3963 .26109 .39992 .26673 .39796 .263 .39433 Mtetra
.263 .39433 .26673 .39796 .27239 .396 .26866 .39236 Mtetra
.26866 .39236 .27239 .396 .27805 .39403 .27434 .39039 Mtetra
.27434 .39039 .27805 .39403 .28373 .39206 .28002 .38841 Mtetra
.28002 .38841 .28373 .39206 .28942 .39008 .28572 .38642 Mtetra
.28572 .38642 .28942 .39008 .29512 .3881 .29143 .38444 Mtetra
.29143 .38444 .29512 .3881 .30084 .38612 .29715 .38244 Mtetra
.29715 .38244 .30084 .38612 .30657 .38413 .30289 .38045 Mtetra
.30289 .38045 .30657 .38413 .31231 .38214 .30864 .37845 Mtetra
.30864 .37845 .31231 .38214 .31806 .38014 .3144 .37644 Mtetra
.3144 .37644 .31806 .38014 .32383 .37814 .32017 .37443 Mtetra
.32017 .37443 .32383 .37814 .3296 .37613 .32596 .37242 Mtetra
.32596 .37242 .3296 .37613 .33539 .37412 .33175 .3704 Mtetra
.33175 .3704 .33539 .37412 .3412 .37211 .33756 .36838 Mtetra
.33756 .36838 .3412 .37211 .34701 .3701 .34339 .36636 Mtetra
.663 .741 .908 r
.34339 .36636 .34701 .3701 .35284 .36808 .34922 .36433 Mtetra
.34922 .36433 .35284 .36808 .35868 .36606 .35507 .36231 Mtetra
.662 .741 .908 r
.35507 .36231 .35868 .36606 .36454 .36405 .36093 .36029 Mtetra
.662 .741 .909 r
.36093 .36029 .36454 .36405 .3704 .36204 .36681 .35828 Mtetra
.66 .741 .91 r
.36681 .35828 .3704 .36204 .37628 .36004 .37269 .3563 Mtetra
.656 .741 .912 r
.37269 .3563 .37628 .36004 .38217 .35809 .37859 .35436 Mtetra
.651 .741 .915 r
.37859 .35436 .38217 .35809 .38807 .35618 .38449 .3525 Mtetra
.639 .74 .922 r
.38449 .3525 .38807 .35618 .39398 .35439 .39041 .3508 Mtetra
.616 .738 .933 r
.39041 .3508 .39398 .35439 .39989 .35279 .39632 .34938 Mtetra
.565 .732 .953 r
.39632 .34938 .39989 .35279 .40581 .35155 .40223 .34848 Mtetra
.433 .699 .977 r
.40223 .34848 .40581 .35155 .41172 .35097 .40812 .34855 Mtetra
.017 .497 .874 r
.40812 .34855 .41172 .35097 .41761 .35158 .41398 .3504 Mtetra
.653 .096 0 r
.41398 .3504 .41761 .35158 .42345 .35435 .41975 .35545 Mtetra
.836 .41 .225 r
.41975 .35545 .42345 .35435 .4292 .36095 .42539 .36609 Mtetra
.855 .502 .384 r
.42539 .36609 .4292 .36095 .43483 .374 .43083 .38572 Mtetra
.848 .529 .448 r
.43083 .38572 .43483 .374 .44026 .39689 .43602 .41752 Mtetra
.828 .525 .477 r
.43602 .41752 .44026 .39689 .44551 .43168 .4411 .45982 Mtetra
.787 .491 .487 r
.4411 .45982 .44551 .43168 .45076 .47359 .44643 .49894 Mtetra
.665 .369 .461 r
.44643 .49894 .45076 .47359 .45639 .50559 .4525 .51173 Mtetra
.98 .881 .517 r
.4525 .51173 .45639 .50559 .46273 .50723 .45936 .48873 Mtetra
.865 .629 .579 r
.45936 .48873 .46273 .50723 .46963 .4778 .46648 .447 Mtetra
.798 .562 .581 r
.46648 .447 .46963 .4778 .47659 .43772 .47341 .40921 Mtetra
.75 .529 .596 r
.47341 .40921 .47659 .43772 .48331 .4058 .48001 .38579 Mtetra
.679 .499 .635 r
.48001 .38579 .48331 .4058 .48977 .38876 .48636 .37724 Mtetra
.408 .385 .722 r
.48636 .37724 .48977 .38876 .49606 .38571 .49258 .38062 Mtetra
.721 .287 0 r
.49258 .38062 .49606 .38571 .50228 .39311 .49877 .39183 Mtetra
.874 .436 .128 r
.49877 .39183 .50228 .39311 .50853 .40572 .50501 .40515 Mtetra
.779 .277 0 r
.50501 .40515 .50853 .40572 .51486 .41634 .51136 .41324 Mtetra
.717 .814 .926 r
.51136 .41324 .51486 .41634 .52127 .41768 .51778 .41016 Mtetra
.863 .693 .67 r
.51778 .41016 .52127 .41768 .52769 .40668 .52422 .39538 Mtetra
.857 .651 .623 r
.52422 .39538 .52769 .40668 .53407 .38655 .53061 .37382 Mtetra
.847 .637 .618 r
.53061 .37382 .53407 .38655 .54038 .36362 .53693 .35163 Mtetra
.837 .636 .63 r
.53693 .35163 .54038 .36362 .54663 .34291 .54321 .33266 Mtetra
.827 .644 .656 r
.54321 .33266 .54663 .34291 .55286 .32648 .54947 .31805 Mtetra
.814 .66 .693 r
.54947 .31805 .55286 .32648 .5591 .3143 .55573 .30734 Mtetra
.796 .68 .737 r
.55573 .30734 .5591 .3143 .56535 .30549 .562 .29957 Mtetra
.774 .7 .782 r
.562 .29957 .56535 .30549 .57163 .29906 .5683 .29383 Mtetra
.749 .715 .821 r
.5683 .29383 .57163 .29906 .57793 .2942 .57462 .28941 Mtetra
.725 .726 .851 r
.57462 .28941 .57793 .2942 .58425 .29035 .58095 .28583 Mtetra
.706 .732 .872 r
.58095 .28583 .58425 .29035 .5906 .28713 .58731 .28277 Mtetra
.691 .736 .885 r
.58731 .28277 .5906 .28713 .59696 .28429 .59369 .28003 Mtetra
.681 .738 .894 r
.59369 .28003 .59696 .28429 .60334 .2817 .60008 .27749 Mtetra
.675 .739 .899 r
.60008 .27749 .60334 .2817 .60974 .27924 .60649 .27506 Mtetra
.671 .74 .902 r
.60649 .27506 .60974 .27924 .61615 .27687 .61292 .27271 Mtetra
.668 .74 .904 r
.61292 .27271 .61615 .27687 .62259 .27455 .61936 .27039 Mtetra
.666 .741 .905 r
.61936 .27039 .62259 .27455 .62903 .27226 .62581 .2681 Mtetra
.665 .741 .906 r
.62581 .2681 .62903 .27226 .63549 .26999 .63229 .26582 Mtetra
.665 .741 .907 r
.63229 .26582 .63549 .26999 .64197 .26772 .63877 .26355 Mtetra
.664 .741 .907 r
.63877 .26355 .64197 .26772 .64846 .26545 .64528 .26127 Mtetra
.64528 .26127 .64846 .26545 .65497 .26319 .6518 .259 Mtetra
.6518 .259 .65497 .26319 .6615 .26092 .65833 .25672 Mtetra
.65833 .25672 .6615 .26092 .66803 .25864 .66488 .25444 Mtetra
.66488 .25444 .66803 .25864 .67459 .25637 .67144 .25215 Mtetra
.67144 .25215 .67459 .25637 .68116 .25409 .67802 .24986 Mtetra
.67802 .24986 .68116 .25409 .68774 .2518 .68461 .24756 Mtetra
.68461 .24756 .68774 .2518 .69434 .24951 .69122 .24526 Mtetra
.69122 .24526 .69434 .24951 .70095 .24721 .69785 .24296 Mtetra
.69785 .24296 .70095 .24721 .70758 .24491 .70449 .24065 Mtetra
.70449 .24065 .70758 .24491 .71423 .2426 .71115 .23833 Mtetra
.71115 .23833 .71423 .2426 .72089 .24029 .71782 .23601 Mtetra
.71782 .23601 .72089 .24029 .72757 .23797 .72451 .23368 Mtetra
.72451 .23368 .72757 .23797 .73426 .23565 .73121 .23134 Mtetra
.73121 .23134 .73426 .23565 .74097 .23332 .73793 .229 Mtetra
.73793 .229 .74097 .23332 .74769 .23098 .74466 .22666 Mtetra
.74466 .22666 .74769 .23098 .75443 .22864 .75142 .22431 Mtetra
.75142 .22431 .75443 .22864 .76119 .2263 .75818 .22195 Mtetra
.75818 .22195 .76119 .2263 .76796 .22395 .76497 .21959 Mtetra
.76497 .21959 .76796 .22395 .77475 .22159 .77176 .21723 Mtetra
.77176 .21723 .77475 .22159 .78155 .21923 .77858 .21485 Mtetra
.77858 .21485 .78155 .21923 .78837 .21686 .78541 .21248 Mtetra
.78541 .21248 .78837 .21686 .79521 .21449 .79226 .21009 Mtetra
.79226 .21009 .79521 .21449 .80206 .21211 .79912 .2077 Mtetra
.79912 .2077 .80206 .21211 .80893 .20972 .806 .20531 Mtetra
.806 .20531 .80893 .20972 .81581 .20733 .8129 .20291 Mtetra
.8129 .20291 .81581 .20733 .82271 .20494 .81981 .2005 Mtetra
.20324 .41024 .20705 .41381 .21259 .41188 .20879 .40831 Mtetra
.20879 .40831 .21259 .41188 .21815 .40995 .21435 .40637 Mtetra
.21435 .40637 .21815 .40995 .22371 .40801 .21992 .40442 Mtetra
.21992 .40442 .22371 .40801 .22929 .40607 .2255 .40247 Mtetra
.2255 .40247 .22929 .40607 .23488 .40412 .2311 .40052 Mtetra
.2311 .40052 .23488 .40412 .24048 .40217 .2367 .39856 Mtetra
.2367 .39856 .24048 .40217 .24609 .40022 .24232 .3966 Mtetra
.24232 .3966 .24609 .40022 .25172 .39826 .24796 .39464 Mtetra
.24796 .39464 .25172 .39826 .25735 .3963 .2536 .39267 Mtetra
.2536 .39267 .25735 .3963 .263 .39433 .25926 .39069 Mtetra
.25926 .39069 .263 .39433 .26866 .39236 .26492 .38871 Mtetra
.26492 .38871 .26866 .39236 .27434 .39039 .2706 .38673 Mtetra
.2706 .38673 .27434 .39039 .28002 .38841 .2763 .38474 Mtetra
.2763 .38474 .28002 .38841 .28572 .38642 .282 .38275 Mtetra
.282 .38275 .28572 .38642 .29143 .38444 .28772 .38075 Mtetra
.28772 .38075 .29143 .38444 .29715 .38244 .29345 .37875 Mtetra
.29345 .37875 .29715 .38244 .30289 .38045 .29919 .37675 Mtetra
.29919 .37675 .30289 .38045 .30864 .37845 .30495 .37474 Mtetra
.30495 .37474 .30864 .37845 .3144 .37644 .31072 .37273 Mtetra
.31072 .37273 .3144 .37644 .32017 .37443 .3165 .37071 Mtetra
.3165 .37071 .32017 .37443 .32596 .37242 .32229 .36869 Mtetra
.32229 .36869 .32596 .37242 .33175 .3704 .3281 .36667 Mtetra
.3281 .36667 .33175 .3704 .33756 .36838 .33392 .36464 Mtetra
.33392 .36464 .33756 .36838 .34339 .36636 .33975 .36261 Mtetra
.663 .741 .908 r
.33975 .36261 .34339 .36636 .34922 .36433 .34559 .36058 Mtetra
.34559 .36058 .34922 .36433 .35507 .36231 .35145 .35855 Mtetra
.662 .741 .908 r
.35145 .35855 .35507 .36231 .36093 .36029 .35732 .35653 Mtetra
.661 .741 .909 r
.35732 .35653 .36093 .36029 .36681 .35828 .3632 .35452 Mtetra
.658 .741 .911 r
.3632 .35452 .36681 .35828 .37269 .3563 .36909 .35255 Mtetra
.653 .741 .914 r
.36909 .35255 .37269 .3563 .37859 .35436 .37499 .35065 Mtetra
.645 .74 .919 r
.37499 .35065 .37859 .35436 .38449 .3525 .3809 .34887 Mtetra
.628 .74 .928 r
.3809 .34887 .38449 .3525 .39041 .3508 .38681 .3473 Mtetra
.59 .736 .945 r
.38681 .3473 .39041 .3508 .39632 .34938 .39273 .34616 Mtetra
.498 .718 .97 r
.39273 .34616 .39632 .34938 .40223 .34848 .39862 .3458 Mtetra
.214 .61 .951 r
.39862 .3458 .40223 .34848 .40812 .34855 .40448 .3469 Mtetra
.48 0 0 r
.40448 .3469 .40812 .34855 .41398 .3504 .41027 .35067 Mtetra
.812 .35 .134 r
.41027 .35067 .41398 .3504 .41975 .35545 .41594 .35922 Mtetra
.853 .485 .353 r
.41594 .35922 .41975 .35545 .42539 .36609 .42139 .37581 Mtetra
.851 .525 .436 r
.42139 .37581 .42539 .36609 .43083 .38572 .42657 .40417 Mtetra
.835 .53 .473 r
.42657 .40417 .43083 .38572 .43602 .41752 .43152 .44512 Mtetra
.803 .507 .488 r
.43152 .44512 .43602 .41752 .4411 .45982 .43657 .48897 Mtetra
.722 .428 .48 r
.43657 .48897 .4411 .45982 .44643 .49894 .44231 .51261 Mtetra
0 0 .049 r
.44231 .51261 .44643 .49894 .4525 .51173 .44902 .49857 Mtetra
.893 .66 .579 r
.44902 .49857 .4525 .51173 .45936 .48873 .45627 .45766 Mtetra
.811 .572 .577 r
.45627 .45766 .45936 .48873 .46648 .447 .46341 .41495 Mtetra
.763 .535 .587 r
.46341 .41495 .46648 .447 .47341 .40921 .47019 .3853 Mtetra
.713 .511 .614 r
.47019 .3853 .47341 .40921 .48001 .38579 .47664 .37114 Mtetra
.58 .461 .682 r
.47664 .37114 .48001 .38579 .48636 .37724 .48289 .36995 Mtetra
0 .035 .606 r
.48289 .36995 .48636 .37724 .49258 .38062 .48905 .3783 Mtetra
.876 .437 .085 r
.48905 .3783 .49258 .38062 .49877 .39183 .49522 .39187 Mtetra
.86 .424 .173 r
.49522 .39187 .49877 .39183 .50501 .40515 .50147 .40446 Mtetra
.592 .018 0 r
.50147 .40446 .50501 .40515 .51136 .41324 .50784 .40901 Mtetra
.842 .773 .785 r
.50784 .40901 .51136 .41324 .51778 .41016 .51429 .40144 Mtetra
.866 .678 .646 r
.51429 .40144 .51778 .41016 .52422 .39538 .52074 .38364 Mtetra
.856 .648 .62 r
.52074 .38364 .52422 .39538 .53061 .37382 .52715 .36148 Mtetra
.845 .638 .622 r
.52715 .36148 .53061 .37382 .53693 .35163 .53349 .34044 Mtetra
.835 .64 .64 r
.53349 .34044 .53693 .35163 .54321 .33266 .53979 .32325 Mtetra
.823 .652 .67 r
.53979 .32325 .54321 .33266 .54947 .31805 .54607 .31029 Mtetra
.808 .669 .71 r
.54607 .31029 .54947 .31805 .55573 .30734 .55235 .30084 Mtetra
.788 .689 .755 r
.55235 .30084 .55573 .30734 .562 .29957 .55865 .29395 Mtetra
.764 .707 .798 r
.55865 .29395 .562 .29957 .5683 .29383 .56496 .28878 Mtetra
.739 .72 .834 r
.56496 .28878 .5683 .29383 .57462 .28941 .57129 .28472 Mtetra
.717 .729 .86 r
.57129 .28472 .57462 .28941 .58095 .28583 .57765 .28136 Mtetra
.7 .734 .878 r
.57765 .28136 .58095 .28583 .58731 .28277 .58402 .27844 Mtetra
.687 .737 .889 r
.58402 .27844 .58731 .28277 .59369 .28003 .5904 .27578 Mtetra
.679 .739 .896 r
.5904 .27578 .59369 .28003 .60008 .27749 .59681 .27328 Mtetra
.673 .74 .9 r
.59681 .27328 .60008 .27749 .60649 .27506 .60323 .27088 Mtetra
.67 .74 .903 r
.60323 .27088 .60649 .27506 .61292 .27271 .60966 .26853 Mtetra
.667 .74 .905 r
.60966 .26853 .61292 .27271 .61936 .27039 .61612 .26622 Mtetra
.666 .741 .906 r
.61612 .26622 .61936 .27039 .62581 .2681 .62258 .26393 Mtetra
.665 .741 .906 r
.62258 .26393 .62581 .2681 .63229 .26582 .62907 .26164 Mtetra
.665 .741 .907 r
.62907 .26164 .63229 .26582 .63877 .26355 .63556 .25936 Mtetra
.664 .741 .907 r
.63556 .25936 .63877 .26355 .64528 .26127 .64208 .25708 Mtetra
.64208 .25708 .64528 .26127 .6518 .259 .64861 .25479 Mtetra
.64861 .25479 .6518 .259 .65833 .25672 .65515 .25251 Mtetra
.65515 .25251 .65833 .25672 .66488 .25444 .66171 .25022 Mtetra
.66171 .25022 .66488 .25444 .67144 .25215 .66828 .24792 Mtetra
.66828 .24792 .67144 .25215 .67802 .24986 .67487 .24562 Mtetra
.67487 .24562 .67802 .24986 .68461 .24756 .68148 .24331 Mtetra
.68148 .24331 .68461 .24756 .69122 .24526 .6881 .241 Mtetra
.6881 .241 .69122 .24526 .69785 .24296 .69473 .23869 Mtetra
.69473 .23869 .69785 .24296 .70449 .24065 .70138 .23636 Mtetra
.70138 .23636 .70449 .24065 .71115 .23833 .70805 .23404 Mtetra
.70805 .23404 .71115 .23833 .71782 .23601 .71473 .2317 Mtetra
.71473 .2317 .71782 .23601 .72451 .23368 .72143 .22936 Mtetra
.72143 .22936 .72451 .23368 .73121 .23134 .72815 .22702 Mtetra
.72815 .22702 .73121 .23134 .73793 .229 .73488 .22467 Mtetra
.73488 .22467 .73793 .229 .74466 .22666 .74162 .22232 Mtetra
.74162 .22232 .74466 .22666 .75142 .22431 .74839 .21996 Mtetra
.74839 .21996 .75142 .22431 .75818 .22195 .75516 .21759 Mtetra
.75516 .21759 .75818 .22195 .76497 .21959 .76196 .21522 Mtetra
.76196 .21522 .76497 .21959 .77176 .21723 .76877 .21284 Mtetra
.76877 .21284 .77176 .21723 .77858 .21485 .7756 .21046 Mtetra
.7756 .21046 .77858 .21485 .78541 .21248 .78244 .20807 Mtetra
.78244 .20807 .78541 .21248 .79226 .21009 .7893 .20568 Mtetra
.7893 .20568 .79226 .21009 .79912 .2077 .79617 .20328 Mtetra
.79617 .20328 .79912 .2077 .806 .20531 .80306 .20087 Mtetra
.80306 .20087 .806 .20531 .8129 .20291 .80997 .19846 Mtetra
.80997 .19846 .8129 .20291 .81981 .2005 .8169 .19604 Mtetra
.19941 .40667 .20324 .41024 .20879 .40831 .20496 .40472 Mtetra
.20496 .40472 .20879 .40831 .21435 .40637 .21053 .40277 Mtetra
.21053 .40277 .21435 .40637 .21992 .40442 .21611 .40082 Mtetra
.21611 .40082 .21992 .40442 .2255 .40247 .2217 .39886 Mtetra
.2217 .39886 .2255 .40247 .2311 .40052 .2273 .3969 Mtetra
.2273 .3969 .2311 .40052 .2367 .39856 .23291 .39494 Mtetra
.23291 .39494 .2367 .39856 .24232 .3966 .23854 .39297 Mtetra
.23854 .39297 .24232 .3966 .24796 .39464 .24418 .391 Mtetra
.24418 .391 .24796 .39464 .2536 .39267 .24983 .38902 Mtetra
.24983 .38902 .2536 .39267 .25926 .39069 .25549 .38703 Mtetra
.25549 .38703 .25926 .39069 .26492 .38871 .26117 .38505 Mtetra
.26117 .38505 .26492 .38871 .2706 .38673 .26686 .38306 Mtetra
.26686 .38306 .2706 .38673 .2763 .38474 .27256 .38106 Mtetra
.27256 .38106 .2763 .38474 .282 .38275 .27827 .37906 Mtetra
.27827 .37906 .282 .38275 .28772 .38075 .284 .37706 Mtetra
.284 .37706 .28772 .38075 .29345 .37875 .28974 .37505 Mtetra
.28974 .37505 .29345 .37875 .29919 .37675 .29549 .37304 Mtetra
.29549 .37304 .29919 .37675 .30495 .37474 .30125 .37102 Mtetra
.30125 .37102 .30495 .37474 .31072 .37273 .30702 .369 Mtetra
.30702 .369 .31072 .37273 .3165 .37071 .31281 .36697 Mtetra
.31281 .36697 .3165 .37071 .32229 .36869 .31861 .36495 Mtetra
.31861 .36495 .32229 .36869 .3281 .36667 .32443 .36291 Mtetra
.32443 .36291 .3281 .36667 .33392 .36464 .33025 .36088 Mtetra
.663 .741 .908 r
.33025 .36088 .33392 .36464 .33975 .36261 .33609 .35884 Mtetra
.33609 .35884 .33975 .36261 .34559 .36058 .34194 .35681 Mtetra
.662 .741 .908 r
.34194 .35681 .34559 .36058 .35145 .35855 .34781 .35478 Mtetra
.662 .741 .909 r
.34781 .35478 .35145 .35855 .35732 .35653 .35368 .35276 Mtetra
.659 .741 .91 r
.35368 .35276 .35732 .35653 .3632 .35452 .35957 .35076 Mtetra
.656 .741 .912 r
.35957 .35076 .3632 .35452 .36909 .35255 .36547 .34882 Mtetra
.649 .741 .916 r
.36547 .34882 .36909 .35255 .37499 .35065 .37138 .34697 Mtetra
.636 .74 .924 r
.37138 .34697 .37499 .35065 .3809 .34887 .37729 .3453 Mtetra
.608 .738 .937 r
.37729 .3453 .3809 .34887 .38681 .3473 .3832 .34396 Mtetra
.541 .729 .961 r
.3832 .34396 .38681 .3473 .39273 .34616 .3891 .34326 Mtetra
.349 .671 .976 r
.3891 .34326 .39273 .34616 .39862 .3458 .39497 .34376 Mtetra
0 .313 .7 r
.39497 .34376 .39862 .3458 .40448 .3469 .40078 .34647 Mtetra
.765 .262 .006 r
.40078 .34647 .40448 .3469 .41027 .35067 .40646 .35325 Mtetra
.848 .461 .312 r
.40646 .35325 .41027 .35067 .41594 .35922 .41194 .36707 Mtetra
.852 .519 .421 r
.41194 .36707 .41594 .35922 .42139 .37581 .41713 .3919 Mtetra
.84 .532 .467 r
.41713 .3919 .42139 .37581 .42657 .40417 .422 .43028 Mtetra
.814 .517 .487 r
.422 .43028 .42657 .40417 .43152 .44512 .42681 .47645 Mtetra
.755 .463 .488 r
.42681 .47645 .43152 .44512 .43657 .48897 .43218 .50965 Mtetra
.447 .158 .38 r
.43218 .50965 .43657 .48897 .44231 .51261 .43865 .50642 Mtetra
.933 .711 .579 r
.43865 .50642 .44231 .51261 .44902 .49857 .44594 .46903 Mtetra
.826 .584 .574 r
.44594 .46903 .44902 .49857 .45627 .45766 .45331 .42274 Mtetra
.775 .541 .581 r
.45331 .42274 .45627 .45766 .46341 .41495 .4603 .38715 Mtetra
.733 .518 .6 r
.4603 .38715 .46341 .41495 .47019 .3853 .4669 .36736 Mtetra
.656 .491 .649 r
.4669 .36736 .47019 .3853 .47664 .37114 .47321 .36139 Mtetra
.283 .336 .741 r
.47321 .36139 .47664 .37114 .48289 .36995 .47937 .36605 Mtetra
.818 .368 0 r
.47937 .36605 .48289 .36995 .48905 .3783 .48549 .37798 Mtetra
.881 .461 .198 r
.48549 .37798 .48905 .3783 .49522 .39187 .49164 .39252 Mtetra
.829 .379 .156 r
.49164 .39252 .49522 .39187 .50147 .40446 .49792 .40308 Mtetra
.174 .672 .915 r
.49792 .40308 .50147 .40446 .50784 .40901 .50432 .40341 Mtetra
.869 .732 .708 r
.50432 .40341 .50784 .40901 .51429 .40144 .5108 .39166 Mtetra
.866 .667 .632 r
.5108 .39166 .51429 .40144 .52074 .38364 .51727 .37169 Mtetra
.854 .645 .619 r
.51727 .37169 .52074 .38364 .52715 .36148 .52369 .34965 Mtetra
.843 .64 .628 r
.52369 .34965 .52715 .36148 .53349 .34044 .53005 .33003 Mtetra
.832 .645 .651 r
.53005 .33003 .53349 .34044 .53979 .32325 .53637 .31456 Mtetra
.819 .659 .685 r
.53637 .31456 .53979 .32325 .54607 .31029 .54267 .30308 Mtetra
.802 .678 .728 r
.54267 .30308 .54607 .31029 .55235 .30084 .54897 .29472 Mtetra
.78 .697 .772 r
.54897 .29472 .55235 .30084 .55865 .29395 .55528 .28857 Mtetra
.755 .713 .813 r
.55528 .28857 .55865 .29395 .56496 .28878 .56161 .28388 Mtetra
.731 .724 .845 r
.56161 .28388 .56496 .28878 .57129 .28472 .56796 .28012 Mtetra
.71 .732 .868 r
.56796 .28012 .57129 .28472 .57765 .28136 .57432 .27694 Mtetra
.694 .736 .883 r
.57432 .27694 .57765 .28136 .58402 .27844 .58071 .27413 Mtetra
.683 .738 .892 r
.58071 .27413 .58402 .27844 .5904 .27578 .58711 .27153 Mtetra
.676 .739 .898 r
.58711 .27153 .5904 .27578 .59681 .27328 .59352 .26907 Mtetra
.672 .74 .902 r
.59352 .26907 .59681 .27328 .60323 .27088 .59995 .26668 Mtetra
.669 .74 .904 r
.59995 .26668 .60323 .27088 .60966 .26853 .6064 .26434 Mtetra
.667 .74 .905 r
.6064 .26434 .60966 .26853 .61612 .26622 .61286 .26203 Mtetra
.666 .741 .906 r
.61286 .26203 .61612 .26622 .62258 .26393 .61934 .25973 Mtetra
.665 .741 .907 r
.61934 .25973 .62258 .26393 .62907 .26164 .62583 .25744 Mtetra
.62583 .25744 .62907 .26164 .63556 .25936 .63234 .25515 Mtetra
.664 .741 .907 r
.63234 .25515 .63556 .25936 .64208 .25708 .63886 .25286 Mtetra
.63886 .25286 .64208 .25708 .64861 .25479 .6454 .25057 Mtetra
.6454 .25057 .64861 .25479 .65515 .25251 .65196 .24828 Mtetra
.65196 .24828 .65515 .25251 .66171 .25022 .65852 .24597 Mtetra
.65852 .24597 .66171 .25022 .66828 .24792 .66511 .24367 Mtetra
.66511 .24367 .66828 .24792 .67487 .24562 .67171 .24136 Mtetra
.67171 .24136 .67487 .24562 .68148 .24331 .67832 .23904 Mtetra
.67832 .23904 .68148 .24331 .6881 .241 .68496 .23672 Mtetra
.68496 .23672 .6881 .241 .69473 .23869 .6916 .23439 Mtetra
.6916 .23439 .69473 .23869 .70138 .23636 .69827 .23206 Mtetra
.69827 .23206 .70138 .23636 .70805 .23404 .70494 .22973 Mtetra
.70494 .22973 .70805 .23404 .71473 .2317 .71164 .22738 Mtetra
.71164 .22738 .71473 .2317 .72143 .22936 .71835 .22503 Mtetra
.71835 .22503 .72143 .22936 .72815 .22702 .72507 .22268 Mtetra
.72507 .22268 .72815 .22702 .73488 .22467 .73181 .22032 Mtetra
.73181 .22032 .73488 .22467 .74162 .22232 .73857 .21796 Mtetra
.73857 .21796 .74162 .22232 .74839 .21996 .74534 .21558 Mtetra
.74534 .21558 .74839 .21996 .75516 .21759 .75213 .21321 Mtetra
.75213 .21321 .75516 .21759 .76196 .21522 .75894 .21083 Mtetra
.75894 .21083 .76196 .21522 .76877 .21284 .76576 .20844 Mtetra
.76576 .20844 .76877 .21284 .7756 .21046 .7726 .20605 Mtetra
.7726 .20605 .7756 .21046 .78244 .20807 .77945 .20365 Mtetra
.77945 .20365 .78244 .20807 .7893 .20568 .78632 .20124 Mtetra
.78632 .20124 .7893 .20568 .79617 .20328 .79321 .19883 Mtetra
.79321 .19883 .79617 .20328 .80306 .20087 .80011 .19641 Mtetra
.80011 .19641 .80306 .20087 .80997 .19846 .80703 .19399 Mtetra
.80703 .19399 .80997 .19846 .8169 .19604 .81397 .19156 Mtetra
.19556 .40307 .19941 .40667 .20496 .40472 .20112 .40112 Mtetra
.20112 .40112 .20496 .40472 .21053 .40277 .20669 .39917 Mtetra
.20669 .39917 .21053 .40277 .21611 .40082 .21228 .39721 Mtetra
.21228 .39721 .21611 .40082 .2217 .39886 .21788 .39524 Mtetra
.21788 .39524 .2217 .39886 .2273 .3969 .22349 .39327 Mtetra
.22349 .39327 .2273 .3969 .23291 .39494 .22911 .3913 Mtetra
.22911 .3913 .23291 .39494 .23854 .39297 .23474 .38932 Mtetra
.23474 .38932 .23854 .39297 .24418 .391 .24039 .38734 Mtetra
.24039 .38734 .24418 .391 .24983 .38902 .24605 .38535 Mtetra
.24605 .38535 .24983 .38902 .25549 .38703 .25172 .38336 Mtetra
.25172 .38336 .25549 .38703 .26117 .38505 .2574 .38137 Mtetra
.2574 .38137 .26117 .38505 .26686 .38306 .2631 .37937 Mtetra
.2631 .37937 .26686 .38306 .27256 .38106 .26881 .37737 Mtetra
.26881 .37737 .27256 .38106 .27827 .37906 .27453 .37536 Mtetra
.27453 .37536 .27827 .37906 .284 .37706 .28026 .37335 Mtetra
.28026 .37335 .284 .37706 .28974 .37505 .286 .37133 Mtetra
.286 .37133 .28974 .37505 .29549 .37304 .29176 .36931 Mtetra
.29176 .36931 .29549 .37304 .30125 .37102 .29753 .36729 Mtetra
.29753 .36729 .30125 .37102 .30702 .369 .30332 .36526 Mtetra
.30332 .36526 .30702 .369 .31281 .36697 .30911 .36322 Mtetra
.30911 .36322 .31281 .36697 .31861 .36495 .31492 .36119 Mtetra
.31492 .36119 .31861 .36495 .32443 .36291 .32074 .35915 Mtetra
.32074 .35915 .32443 .36291 .33025 .36088 .32657 .3571 Mtetra
.663 .741 .908 r
.32657 .3571 .33025 .36088 .33609 .35884 .33242 .35506 Mtetra
.33242 .35506 .33609 .35884 .34194 .35681 .33828 .35302 Mtetra
.662 .741 .908 r
.33828 .35302 .34194 .35681 .34781 .35478 .34415 .35099 Mtetra
.66 .741 .909 r
.34415 .35099 .34781 .35478 .35368 .35276 .35004 .34898 Mtetra
.657 .741 .911 r
.35004 .34898 .35368 .35276 .35957 .35076 .35593 .34701 Mtetra
.652 .741 .915 r
.35593 .34701 .35957 .35076 .36547 .34882 .36183 .3451 Mtetra
.642 .741 .92 r
.36183 .3451 .36547 .34882 .37138 .34697 .36774 .34334 Mtetra
.62 .739 .932 r
.36774 .34334 .37138 .34697 .37729 .3453 .37365 .34186 Mtetra
.571 .734 .952 r
.37365 .34186 .37729 .3453 .3832 .34396 .37956 .34089 Mtetra
.438 .703 .978 r
.37956 .34089 .3832 .34396 .3891 .34326 .38543 .34089 Mtetra
0 .488 .862 r
.38543 .34089 .3891 .34326 .39497 .34376 .39125 .34275 Mtetra
.681 .133 0 r
.39125 .34275 .39497 .34376 .40078 .34647 .39696 .34803 Mtetra
.839 .426 .257 r
.39696 .34803 .40078 .34647 .40646 .35325 .40248 .35941 Mtetra
.853 .509 .401 r
.40248 .35941 .40646 .35325 .41194 .36707 .40769 .38081 Mtetra
.844 .531 .459 r
.40769 .38081 .41194 .36707 .41713 .3919 .41253 .41586 Mtetra
.824 .525 .484 r
.41253 .41586 .41713 .3919 .422 .43028 .41716 .46225 Mtetra
.778 .486 .492 r
.41716 .46225 .422 .43028 .42681 .47645 .42216 .50304 Mtetra
.621 .329 .453 r
.42216 .50304 .42681 .47645 .43218 .50965 .42827 .51148 Mtetra
.987 .801 .567 r
.42827 .51148 .43218 .50965 .43865 .50642 .43551 .48037 Mtetra
.844 .602 .573 r
.43551 .48037 .43865 .50642 .44594 .46903 .44308 .43224 Mtetra
.786 .547 .576 r
.44308 .43224 .44594 .46903 .45331 .42274 .45032 .39117 Mtetra
.747 .522 .591 r
.45032 .39117 .45331 .42274 .4603 .38715 .45709 .36578 Mtetra
.696 .505 .626 r
.45709 .36578 .4603 .38715 .4669 .36736 .46351 .35499 Mtetra
.527 .449 .711 r
.46351 .35499 .4669 .36736 .47321 .36139 .46971 .3556 Mtetra
0 0 .444 r
.46971 .3556 .47321 .36139 .47937 .36605 .4758 .36469 Mtetra
.885 .457 .154 r
.4758 .36469 .47937 .36605 .48549 .37798 .48188 .37892 Mtetra
.867 .453 .236 r
.48188 .37892 .48549 .37798 .49164 .39252 .48804 .39312 Mtetra
.764 .272 .057 r
.48804 .39312 .49164 .39252 .49792 .40308 .49435 .40058 Mtetra
.777 .861 .912 r
.49435 .40058 .49792 .40308 .50432 .40341 .50079 .39638 Mtetra
.874 .703 .668 r
.50079 .39638 .50432 .40341 .5108 .39166 .5073 .38102 Mtetra
.863 .659 .625 r
.5073 .38102 .5108 .39166 .51727 .37169 .5138 .35975 Mtetra
.851 .644 .622 r
.5138 .35975 .51727 .37169 .52369 .34965 .52023 .33839 Mtetra
.84 .642 .636 r
.52023 .33839 .52369 .34965 .53005 .33003 .52661 .32035 Mtetra
.828 .651 .663 r
.52661 .32035 .53005 .33003 .53637 .31456 .53294 .3065 Mtetra
.813 .667 .701 r
.53294 .3065 .53637 .31456 .54267 .30308 .53926 .29634 Mtetra
.794 .686 .745 r
.53926 .29634 .54267 .30308 .54897 .29472 .54558 .28892 Mtetra
.771 .704 .789 r
.54558 .28892 .54897 .29472 .55528 .28857 .55191 .28339 Mtetra
.745 .718 .826 r
.55191 .28339 .55528 .28857 .56161 .28388 .55825 .2791 Mtetra
.722 .728 .855 r
.55825 .2791 .56161 .28388 .56796 .28012 .56461 .27558 Mtetra
.704 .733 .874 r
.56461 .27558 .56796 .28012 .57432 .27694 .57099 .27256 Mtetra
.69 .737 .887 r
.57099 .27256 .57432 .27694 .58071 .27413 .57738 .26983 Mtetra
.68 .738 .895 r
.57738 .26983 .58071 .27413 .58711 .27153 .58379 .26728 Mtetra
.674 .739 .9 r
.58379 .26728 .58711 .27153 .59352 .26907 .59022 .26485 Mtetra
.67 .74 .903 r
.59022 .26485 .59352 .26907 .59995 .26668 .59666 .26248 Mtetra
.668 .74 .904 r
.59666 .26248 .59995 .26668 .6064 .26434 .60312 .26014 Mtetra
.666 .741 .906 r
.60312 .26014 .6064 .26434 .61286 .26203 .60959 .25783 Mtetra
.665 .741 .906 r
.60959 .25783 .61286 .26203 .61934 .25973 .61608 .25553 Mtetra
.665 .741 .907 r
.61608 .25553 .61934 .25973 .62583 .25744 .62258 .25323 Mtetra
.664 .741 .907 r
.62258 .25323 .62583 .25744 .63234 .25515 .6291 .25093 Mtetra
.6291 .25093 .63234 .25515 .63886 .25286 .63563 .24863 Mtetra
.63563 .24863 .63886 .25286 .6454 .25057 .64218 .24633 Mtetra
.64218 .24633 .6454 .25057 .65196 .24828 .64875 .24403 Mtetra
.64875 .24403 .65196 .24828 .65852 .24597 .65533 .24172 Mtetra
.65533 .24172 .65852 .24597 .66511 .24367 .66192 .2394 Mtetra
.66192 .2394 .66511 .24367 .67171 .24136 .66853 .23708 Mtetra
.66853 .23708 .67171 .24136 .67832 .23904 .67516 .23475 Mtetra
.67516 .23475 .67832 .23904 .68496 .23672 .6818 .23242 Mtetra
.6818 .23242 .68496 .23672 .6916 .23439 .68846 .23008 Mtetra
.68846 .23008 .6916 .23439 .69827 .23206 .69513 .22774 Mtetra
.69513 .22774 .69827 .23206 .70494 .22973 .70182 .2254 Mtetra
.70182 .2254 .70494 .22973 .71164 .22738 .70853 .22304 Mtetra
.70853 .22304 .71164 .22738 .71835 .22503 .71525 .22068 Mtetra
.71525 .22068 .71835 .22503 .72507 .22268 .72198 .21832 Mtetra
.72198 .21832 .72507 .22268 .73181 .22032 .72873 .21595 Mtetra
.72873 .21595 .73181 .22032 .73857 .21796 .7355 .21357 Mtetra
.7355 .21357 .73857 .21796 .74534 .21558 .74229 .21119 Mtetra
.74229 .21119 .74534 .21558 .75213 .21321 .74909 .20881 Mtetra
.74909 .20881 .75213 .21321 .75894 .21083 .75591 .20641 Mtetra
.75591 .20641 .75894 .21083 .76576 .20844 .76274 .20402 Mtetra
.76274 .20402 .76576 .20844 .7726 .20605 .76959 .20161 Mtetra
.76959 .20161 .7726 .20605 .77945 .20365 .77645 .1992 Mtetra
.77645 .1992 .77945 .20365 .78632 .20124 .78334 .19679 Mtetra
.78334 .19679 .78632 .20124 .79321 .19883 .79023 .19437 Mtetra
.79023 .19437 .79321 .19883 .80011 .19641 .79715 .19194 Mtetra
.79715 .19194 .80011 .19641 .80703 .19399 .80408 .18951 Mtetra
.80408 .18951 .80703 .19399 .81397 .19156 .81103 .18707 Mtetra
.1917 .39947 .19556 .40307 .20112 .40112 .19727 .39751 Mtetra
.19727 .39751 .20112 .40112 .20669 .39917 .20285 .39554 Mtetra
.20285 .39554 .20669 .39917 .21228 .39721 .20844 .39358 Mtetra
.20844 .39358 .21228 .39721 .21788 .39524 .21404 .3916 Mtetra
.21404 .3916 .21788 .39524 .22349 .39327 .21966 .38963 Mtetra
.21966 .38963 .22349 .39327 .22911 .3913 .22529 .38765 Mtetra
.22529 .38765 .22911 .3913 .23474 .38932 .23093 .38566 Mtetra
.23093 .38566 .23474 .38932 .24039 .38734 .23658 .38367 Mtetra
.23658 .38367 .24039 .38734 .24605 .38535 .24225 .38168 Mtetra
.24225 .38168 .24605 .38535 .25172 .38336 .24793 .37968 Mtetra
.24793 .37968 .25172 .38336 .2574 .38137 .25362 .37768 Mtetra
.25362 .37768 .2574 .38137 .2631 .37937 .25932 .37567 Mtetra
.25932 .37567 .2631 .37937 .26881 .37737 .26504 .37366 Mtetra
.26504 .37366 .26881 .37737 .27453 .37536 .27076 .37164 Mtetra
.27076 .37164 .27453 .37536 .28026 .37335 .2765 .36962 Mtetra
.2765 .36962 .28026 .37335 .286 .37133 .28226 .3676 Mtetra
.28226 .3676 .286 .37133 .29176 .36931 .28802 .36557 Mtetra
.28802 .36557 .29176 .36931 .29753 .36729 .2938 .36354 Mtetra
.2938 .36354 .29753 .36729 .30332 .36526 .29959 .3615 Mtetra
.29959 .3615 .30332 .36526 .30911 .36322 .30539 .35946 Mtetra
.30539 .35946 .30911 .36322 .31492 .36119 .31121 .35741 Mtetra
.31121 .35741 .31492 .36119 .32074 .35915 .31704 .35537 Mtetra
.663 .741 .908 r
.31704 .35537 .32074 .35915 .32657 .3571 .32288 .35332 Mtetra
.32288 .35332 .32657 .3571 .33242 .35506 .32874 .35127 Mtetra
.662 .741 .908 r
.32874 .35127 .33242 .35506 .33828 .35302 .3346 .34923 Mtetra
.661 .741 .909 r
.3346 .34923 .33828 .35302 .34415 .35099 .34048 .3472 Mtetra
.659 .741 .91 r
.34048 .3472 .34415 .35099 .35004 .34898 .34637 .3452 Mtetra
.655 .741 .913 r
.34637 .3452 .35004 .34898 .35593 .34701 .35227 .34326 Mtetra
.647 .741 .918 r
.35227 .34326 .35593 .34701 .36183 .3451 .35818 .34143 Mtetra
.63 .74 .927 r
.35818 .34143 .36183 .3451 .36774 .34334 .36409 .33982 Mtetra
.593 .737 .944 r
.36409 .33982 .36774 .34334 .37365 .34186 .36999 .33863 Mtetra
.497 .72 .971 r
.36999 .33863 .37365 .34186 .37956 .34089 .37587 .33825 Mtetra
.189 .6 .944 r
.37587 .33825 .37956 .34089 .38543 .34089 .38171 .3394 Mtetra
.537 0 0 r
.38171 .3394 .38543 .34089 .39125 .34275 .38744 .34342 Mtetra
.821 .377 .181 r
.38744 .34342 .39125 .34275 .39696 .34803 .39299 .35269 Mtetra
.852 .495 .375 r
.39299 .35269 .39696 .34803 .40248 .35941 .39825 .3709 Mtetra
.847 .529 .448 r
.39825 .3709 .40248 .35941 .40769 .38081 .40309 .40226 Mtetra
.831 .529 .48 r
.40309 .40226 .40769 .38081 .41253 .41586 .40759 .44718 Mtetra
.795 .502 .492 r
.40759 .44718 .41253 .41586 .41716 .46225 .41225 .4932 Mtetra
.695 .404 .478 r
.41225 .4932 .41716 .46225 .42216 .50304 .41794 .5132 Mtetra
.866 .847 .385 r
.41794 .5132 .42216 .50304 .42827 .51148 .425 .49087 Mtetra
.866 .626 .573 r
.425 .49087 .42827 .51148 .43551 .48037 .43273 .44304 Mtetra
.797 .556 .573 r
.43273 .44304 .43551 .48037 .44308 .43224 .44023 .39719 Mtetra
.757 .527 .583 r
.44023 .39719 .44308 .43224 .45032 .39117 .44722 .36627 Mtetra
.719 .512 .61 r
.44722 .36627 .45032 .39117 .45709 .36578 .45377 .35066 Mtetra
.629 .489 .673 r
.45377 .35066 .45709 .36578 .46351 .35499 .46004 .34713 Mtetra
.083 .256 .743 r
.46004 .34713 .46351 .35499 .46971 .3556 .46614 .35278 Mtetra
.857 .407 .024 r
.46614 .35278 .46971 .3556 .4758 .36469 .47218 .3651 Mtetra
.881 .472 .238 r
.47218 .3651 .4758 .36469 .48188 .37892 .47824 .38046 Mtetra
.846 .425 .232 r
.47824 .38046 .48188 .37892 .48804 .39312 .48442 .39312 Mtetra
.542 0 0 r
.48442 .39312 .48804 .39312 .49435 .40058 .49077 .39665 Mtetra
.866 .786 .77 r
.49077 .39665 .49435 .40058 .50079 .39638 .49727 .38798 Mtetra
.873 .684 .645 r
.49727 .38798 .50079 .39638 .5073 .38102 .50382 .36979 Mtetra
.86 .653 .622 r
.50382 .36979 .5073 .38102 .5138 .35975 .51033 .34802 Mtetra
.848 .643 .626 r
.51033 .34802 .5138 .35975 .52023 .33839 .51678 .32775 Mtetra
.836 .646 .646 r
.51678 .32775 .52023 .33839 .52661 .32035 .52316 .31134 Mtetra
.823 .657 .677 r
.52316 .31134 .52661 .32035 .53294 .3065 .52951 .299 Mtetra
.807 .674 .718 r
.52951 .299 .53294 .3065 .53926 .29634 .53585 .28999 Mtetra
.786 .693 .762 r
.53585 .28999 .53926 .29634 .54558 .28892 .54218 .28338 Mtetra
.761 .71 .804 r
.54218 .28338 .54558 .28892 .55191 .28339 .54853 .27838 Mtetra
.736 .723 .838 r
.54853 .27838 .55191 .28339 .55825 .2791 .55488 .27441 Mtetra
.715 .73 .863 r
.55488 .27441 .55825 .2791 .56461 .27558 .56126 .2711 Mtetra
.698 .735 .88 r
.56126 .2711 .56461 .27558 .57099 .27256 .56764 .2682 Mtetra
.686 .737 .89 r
.56764 .2682 .57099 .27256 .57738 .26983 .57405 .26554 Mtetra
.678 .739 .897 r
.57405 .26554 .57738 .26983 .58379 .26728 .58047 .26304 Mtetra
.673 .74 .901 r
.58047 .26304 .58379 .26728 .59022 .26485 .58691 .26062 Mtetra
.669 .74 .903 r
.58691 .26062 .59022 .26485 .59666 .26248 .59336 .25826 Mtetra
.667 .74 .905 r
.59336 .25826 .59666 .26248 .60312 .26014 .59983 .25593 Mtetra
.666 .741 .906 r
.59983 .25593 .60312 .26014 .60959 .25783 .60631 .25361 Mtetra
.665 .741 .906 r
.60631 .25361 .60959 .25783 .61608 .25553 .61281 .2513 Mtetra
.665 .741 .907 r
.61281 .2513 .61608 .25553 .62258 .25323 .61932 .249 Mtetra
.664 .741 .907 r
.61932 .249 .62258 .25323 .6291 .25093 .62585 .24669 Mtetra
.62585 .24669 .6291 .25093 .63563 .24863 .63239 .24438 Mtetra
.63239 .24438 .63563 .24863 .64218 .24633 .63895 .24207 Mtetra
.63895 .24207 .64218 .24633 .64875 .24403 .64553 .23976 Mtetra
.64553 .23976 .64875 .24403 .65533 .24172 .65212 .23744 Mtetra
.65212 .23744 .65533 .24172 .66192 .2394 .65872 .23511 Mtetra
.65872 .23511 .66192 .2394 .66853 .23708 .66534 .23278 Mtetra
.66534 .23278 .66853 .23708 .67516 .23475 .67198 .23045 Mtetra
.67198 .23045 .67516 .23475 .6818 .23242 .67863 .2281 Mtetra
.67863 .2281 .6818 .23242 .68846 .23008 .6853 .22576 Mtetra
.6853 .22576 .68846 .23008 .69513 .22774 .69199 .2234 Mtetra
.69199 .2234 .69513 .22774 .70182 .2254 .69869 .22105 Mtetra
.69869 .22105 .70182 .2254 .70853 .22304 .7054 .21868 Mtetra
.7054 .21868 .70853 .22304 .71525 .22068 .71213 .21631 Mtetra
.71213 .21631 .71525 .22068 .72198 .21832 .71888 .21394 Mtetra
.71888 .21394 .72198 .21832 .72873 .21595 .72564 .21156 Mtetra
.72564 .21156 .72873 .21595 .7355 .21357 .73242 .20917 Mtetra
.73242 .20917 .7355 .21357 .74229 .21119 .73922 .20678 Mtetra
.73922 .20678 .74229 .21119 .74909 .20881 .74603 .20439 Mtetra
.74603 .20439 .74909 .20881 .75591 .20641 .75286 .20198 Mtetra
.75286 .20198 .75591 .20641 .76274 .20402 .7597 .19957 Mtetra
.7597 .19957 .76274 .20402 .76959 .20161 .76656 .19716 Mtetra
.76656 .19716 .76959 .20161 .77645 .1992 .77344 .19474 Mtetra
.77344 .19474 .77645 .1992 .78334 .19679 .78034 .19231 Mtetra
.78034 .19231 .78334 .19679 .79023 .19437 .78725 .18988 Mtetra
.78725 .18988 .79023 .19437 .79715 .19194 .79417 .18744 Mtetra
.79417 .18744 .79715 .19194 .80408 .18951 .80112 .185 Mtetra
.80112 .185 .80408 .18951 .81103 .18707 .80808 .18255 Mtetra
.18782 .39585 .1917 .39947 .19727 .39751 .1934 .39388 Mtetra
.1934 .39388 .19727 .39751 .20285 .39554 .19898 .39191 Mtetra
.19898 .39191 .20285 .39554 .20844 .39358 .20458 .38993 Mtetra
.20458 .38993 .20844 .39358 .21404 .3916 .21019 .38795 Mtetra
.21019 .38795 .21404 .3916 .21966 .38963 .21582 .38597 Mtetra
.21582 .38597 .21966 .38963 .22529 .38765 .22145 .38398 Mtetra
.22145 .38398 .22529 .38765 .23093 .38566 .2271 .38198 Mtetra
.2271 .38198 .23093 .38566 .23658 .38367 .23276 .37999 Mtetra
.23276 .37999 .23658 .38367 .24225 .38168 .23844 .37798 Mtetra
.23844 .37798 .24225 .38168 .24793 .37968 .24412 .37598 Mtetra
.24412 .37598 .24793 .37968 .25362 .37768 .24982 .37397 Mtetra
.24982 .37397 .25362 .37768 .25932 .37567 .25553 .37195 Mtetra
.25553 .37195 .25932 .37567 .26504 .37366 .26125 .36993 Mtetra
.26125 .36993 .26504 .37366 .27076 .37164 .26699 .36791 Mtetra
.26699 .36791 .27076 .37164 .2765 .36962 .27273 .36588 Mtetra
.27273 .36588 .2765 .36962 .28226 .3676 .2785 .36385 Mtetra
.2785 .36385 .28226 .3676 .28802 .36557 .28427 .36181 Mtetra
.28427 .36181 .28802 .36557 .2938 .36354 .29005 .35977 Mtetra
.29005 .35977 .2938 .36354 .29959 .3615 .29585 .35772 Mtetra
.29585 .35772 .29959 .3615 .30539 .35946 .30166 .35568 Mtetra
.30166 .35568 .30539 .35946 .31121 .35741 .30749 .35362 Mtetra
.30749 .35362 .31121 .35741 .31704 .35537 .31332 .35157 Mtetra
.663 .741 .908 r
.31332 .35157 .31704 .35537 .32288 .35332 .31917 .34952 Mtetra
.31917 .34952 .32288 .35332 .32874 .35127 .32503 .34746 Mtetra
.662 .741 .909 r
.32503 .34746 .32874 .35127 .3346 .34923 .33091 .34542 Mtetra
.66 .741 .91 r
.33091 .34542 .3346 .34923 .34048 .3472 .33679 .3434 Mtetra
.657 .741 .912 r
.33679 .3434 .34048 .3472 .34637 .3452 .34269 .34143 Mtetra
.65 .741 .916 r
.34269 .34143 .34637 .3452 .35227 .34326 .34859 .33955 Mtetra
.637 .741 .923 r
.34859 .33955 .35227 .34326 .35818 .34143 .3545 .33784 Mtetra
.609 .739 .938 r
.3545 .33784 .35818 .34143 .36409 .33982 .36041 .33648 Mtetra
.539 .73 .963 r
.36041 .33648 .36409 .33982 .36999 .33863 .36629 .33578 Mtetra
.325 .664 .974 r
.36629 .33578 .36999 .33863 .37587 .33825 .37214 .33635 Mtetra
.33 0 0 r
.37214 .33635 .37587 .33825 .38171 .3394 .37789 .33933 Mtetra
.788 .306 .076 r
.37789 .33933 .38171 .3394 .38744 .34342 .38348 .34679 Mtetra
.849 .475 .342 r
.38348 .34679 .38744 .34342 .39299 .35269 .38878 .3621 Mtetra
.85 .524 .435 r
.38878 .3621 .39299 .35269 .39825 .3709 .39366 .3897 Mtetra
.836 .532 .475 r
.39366 .3897 .39825 .3709 .40309 .40226 .3981 .43195 Mtetra
.807 .513 .492 r
.3981 .43195 .40309 .40226 .40759 .44718 .40247 .48081 Mtetra
.737 .446 .488 r
.40247 .48081 .40759 .44718 .41225 .4932 .40769 .51128 Mtetra
.127 0 .234 r
.40769 .51128 .41225 .4932 .41794 .5132 .41446 .49971 Mtetra
.897 .662 .574 r
.41446 .49971 .41794 .5132 .425 .49087 .42225 .45464 Mtetra
.81 .567 .571 r
.42225 .45464 .425 .49087 .43273 .44304 .43002 .40501 Mtetra
.767 .532 .578 r
.43002 .40501 .43273 .44304 .44023 .39719 .43726 .36868 Mtetra
.733 .517 .598 r
.43726 .36868 .44023 .39719 .44722 .36627 .44398 .34826 Mtetra
.679 .506 .645 r
.44398 .34826 .44722 .36627 .45377 .35066 .45034 .34062 Mtetra
.449 .435 .751 r
.45034 .34062 .45377 .35066 .46004 .34713 .45648 .34264 Mtetra
.695 .236 0 r
.45648 .34264 .46004 .34713 .46614 .35278 .46251 .35212 Mtetra
.884 .464 .193 r
.46251 .35212 .46614 .35278 .47218 .3651 .4685 .36665 Mtetra
.869 .468 .269 r
.4685 .36665 .47218 .3651 .47824 .38046 .47457 .38203 Mtetra
.812 .368 .186 r
.47457 .38203 .47824 .38046 .48442 .39312 .48079 .39205 Mtetra
.367 .806 .96 r
.48079 .39205 .48442 .39312 .49077 .39665 .48721 .39114 Mtetra
.879 .735 .699 r
.48721 .39114 .49077 .39665 .49727 .38798 .49375 .37841 Mtetra
.869 .671 .632 r
.49375 .37841 .49727 .38798 .50382 .36979 .50033 .35824 Mtetra
.856 .649 .622 r
.50033 .35824 .50382 .36979 .51033 .34802 .50686 .33666 Mtetra
.844 .644 .632 r
.50686 .33666 .51033 .34802 .51678 .32775 .51332 .31775 Mtetra
.832 .65 .657 r
.51332 .31775 .51678 .32775 .52316 .31134 .51972 .30295 Mtetra
.818 .664 .692 r
.51972 .30295 .52316 .31134 .52951 .299 .52608 .29199 Mtetra
.8 .682 .735 r
.52608 .29199 .52951 .299 .53585 .28999 .53243 .28399 Mtetra
.777 .701 .779 r
.53243 .28399 .53585 .28999 .54218 .28338 .53877 .27805 Mtetra
.752 .716 .818 r
.53877 .27805 .54218 .28338 .54853 .27838 .54513 .27349 Mtetra
.728 .726 .849 r
.54513 .27349 .54853 .27838 .55488 .27441 .5515 .2698 Mtetra
.708 .732 .87 r
.5515 .2698 .55488 .27441 .56126 .2711 .55789 .26666 Mtetra
.693 .736 .884 r
.55789 .26666 .56126 .2711 .56764 .2682 .56428 .26386 Mtetra
.682 .738 .893 r
.56428 .26386 .56764 .2682 .57405 .26554 .5707 .26126 Mtetra
.675 .739 .899 r
.5707 .26126 .57405 .26554 .58047 .26304 .57713 .25878 Mtetra
.671 .74 .902 r
.57713 .25878 .58047 .26304 .58691 .26062 .58358 .25638 Mtetra
.668 .74 .904 r
.58358 .25638 .58691 .26062 .59336 .25826 .59004 .25403 Mtetra
.667 .741 .905 r
.59004 .25403 .59336 .25826 .59983 .25593 .59652 .25169 Mtetra
.666 .741 .906 r
.59652 .25169 .59983 .25593 .60631 .25361 .60301 .24937 Mtetra
.665 .741 .907 r
.60301 .24937 .60631 .25361 .61281 .2513 .60952 .24706 Mtetra
.60952 .24706 .61281 .2513 .61932 .249 .61604 .24475 Mtetra
.664 .741 .907 r
.61604 .24475 .61932 .249 .62585 .24669 .62258 .24243 Mtetra
.62258 .24243 .62585 .24669 .63239 .24438 .62914 .24012 Mtetra
.62914 .24012 .63239 .24438 .63895 .24207 .63571 .2378 Mtetra
.63571 .2378 .63895 .24207 .64553 .23976 .64229 .23547 Mtetra
.64229 .23547 .64553 .23976 .65212 .23744 .64889 .23314 Mtetra
.64889 .23314 .65212 .23744 .65872 .23511 .65551 .23081 Mtetra
.65551 .23081 .65872 .23511 .66534 .23278 .66214 .22847 Mtetra
.66214 .22847 .66534 .23278 .67198 .23045 .66879 .22612 Mtetra
.66879 .22612 .67198 .23045 .67863 .2281 .67545 .22377 Mtetra
.67545 .22377 .67863 .2281 .6853 .22576 .68213 .22141 Mtetra
.68213 .22141 .6853 .22576 .69199 .2234 .68882 .21905 Mtetra
.68882 .21905 .69199 .2234 .69869 .22105 .69554 .21668 Mtetra
.69554 .21668 .69869 .22105 .7054 .21868 .70226 .21431 Mtetra
.70226 .21431 .7054 .21868 .71213 .21631 .709 .21193 Mtetra
.709 .21193 .71213 .21631 .71888 .21394 .71576 .20954 Mtetra
.71576 .20954 .71888 .21394 .72564 .21156 .72254 .20715 Mtetra
.72254 .20715 .72564 .21156 .73242 .20917 .72933 .20475 Mtetra
.72933 .20475 .73242 .20917 .73922 .20678 .73614 .20235 Mtetra
.73614 .20235 .73922 .20678 .74603 .20439 .74296 .19994 Mtetra
.74296 .19994 .74603 .20439 .75286 .20198 .7498 .19753 Mtetra
.7498 .19753 .75286 .20198 .7597 .19957 .75665 .19511 Mtetra
.75665 .19511 .7597 .19957 .76656 .19716 .76353 .19269 Mtetra
.76353 .19269 .76656 .19716 .77344 .19474 .77042 .19026 Mtetra
.77042 .19026 .77344 .19474 .78034 .19231 .77732 .18782 Mtetra
.77732 .18782 .78034 .19231 .78725 .18988 .78424 .18538 Mtetra
.78424 .18538 .78725 .18988 .79417 .18744 .79118 .18293 Mtetra
.79118 .18293 .79417 .18744 .80112 .185 .79814 .18047 Mtetra
.79814 .18047 .80112 .185 .80808 .18255 .80511 .17801 Mtetra
.18393 .39221 .18782 .39585 .1934 .39388 .18951 .39023 Mtetra
.18951 .39023 .1934 .39388 .19898 .39191 .1951 .38826 Mtetra
.1951 .38826 .19898 .39191 .20458 .38993 .20071 .38627 Mtetra
.20071 .38627 .20458 .38993 .21019 .38795 .20633 .38428 Mtetra
.20633 .38428 .21019 .38795 .21582 .38597 .21196 .38229 Mtetra
.21196 .38229 .21582 .38597 .22145 .38398 .2176 .38029 Mtetra
.2176 .38029 .22145 .38398 .2271 .38198 .22326 .37829 Mtetra
.22326 .37829 .2271 .38198 .23276 .37999 .22893 .37629 Mtetra
.22893 .37629 .23276 .37999 .23844 .37798 .23461 .37428 Mtetra
.23461 .37428 .23844 .37798 .24412 .37598 .2403 .37226 Mtetra
.2403 .37226 .24412 .37598 .24982 .37397 .246 .37024 Mtetra
.246 .37024 .24982 .37397 .25553 .37195 .25172 .36822 Mtetra
.25172 .36822 .25553 .37195 .26125 .36993 .25745 .36619 Mtetra
.25745 .36619 .26125 .36993 .26699 .36791 .26319 .36416 Mtetra
.26319 .36416 .26699 .36791 .27273 .36588 .26895 .36212 Mtetra
.26895 .36212 .27273 .36588 .2785 .36385 .27472 .36008 Mtetra
.27472 .36008 .2785 .36385 .28427 .36181 .2805 .35804 Mtetra
.2805 .35804 .28427 .36181 .29005 .35977 .28629 .35599 Mtetra
.28629 .35599 .29005 .35977 .29585 .35772 .2921 .35394 Mtetra
.2921 .35394 .29585 .35772 .30166 .35568 .29792 .35188 Mtetra
.29792 .35188 .30166 .35568 .30749 .35362 .30375 .34982 Mtetra
.663 .741 .908 r
.30375 .34982 .30749 .35362 .31332 .35157 .30959 .34776 Mtetra
.30959 .34776 .31332 .35157 .31917 .34952 .31545 .3457 Mtetra
.662 .741 .908 r
.31545 .3457 .31917 .34952 .32503 .34746 .32132 .34365 Mtetra
.661 .741 .909 r
.32132 .34365 .32503 .34746 .33091 .34542 .3272 .34161 Mtetra
.658 .741 .911 r
.3272 .34161 .33091 .34542 .33679 .3434 .33309 .33962 Mtetra
.653 .741 .914 r
.33309 .33962 .33679 .3434 .34269 .34143 .33899 .33769 Mtetra
.643 .741 .92 r
.33899 .33769 .34269 .34143 .34859 .33955 .3449 .33591 Mtetra
.62 .74 .932 r
.3449 .33591 .34859 .33955 .3545 .33784 .3508 .3344 Mtetra
.568 .735 .954 r
.3508 .3344 .3545 .33784 .36041 .33648 .35669 .33344 Mtetra
.418 .699 .979 r
.35669 .33344 .36041 .33648 .36629 .33578 .36255 .33354 Mtetra
0 .429 .807 r
.36255 .33354 .36629 .33578 .37214 .33635 .36832 .33565 Mtetra
.729 .204 0 r
.36832 .33565 .37214 .33635 .37789 .33933 .37395 .34157 Mtetra
.843 .448 .297 r
.37395 .34157 .37789 .33933 .38348 .34679 .3793 .35432 Mtetra
.851 .516 .419 r
.3793 .35432 .38348 .34679 .38878 .3621 .38423 .37826 Mtetra
.841 .533 .468 r
.38423 .37826 .38878 .3621 .39366 .3897 .38865 .41708 Mtetra
.817 .522 .489 r
.38865 .41708 .39366 .3897 .3981 .43195 .3928 .46665 Mtetra
.764 .473 .493 r
.3928 .46665 .3981 .43195 .40247 .48081 .39757 .50578 Mtetra
.52 .232 .418 r
.39757 .50578 .40247 .48081 .40769 .51128 .40391 .50615 Mtetra
.941 .719 .574 r
.40391 .50615 .40769 .51128 .41446 .49971 .41166 .46643 Mtetra
.825 .581 .57 r
.41166 .46643 .41446 .49971 .42225 .45464 .41968 .4144 Mtetra
.776 .537 .574 r
.41968 .4144 .42225 .45464 .43002 .40501 .4272 .3729 Mtetra
.744 .52 .59 r
.4272 .3729 .43002 .40501 .43726 .36868 .43412 .34763 Mtetra
.706 .513 .625 r
.43412 .34763 .43726 .36868 .44398 .34826 .4406 .33595 Mtetra
.594 .492 .707 r
.4406 .33595 .44398 .34826 .45034 .34062 .44681 .33438 Mtetra
0 .146 .69 r
.44681 .33438 .45034 .34062 .45648 .34264 .45286 .34063 Mtetra
.867 .419 .082 r
.45286 .34063 .45648 .34264 .46251 .35212 .45882 .35299 Mtetra
.88 .477 .259 r
.45882 .35299 .46251 .35212 .4685 .36665 .4648 .36879 Mtetra
.854 .45 .271 r
.4648 .36879 .4685 .36665 .47457 .38203 .47088 .3831 Mtetra
.732 .234 .051 r
.47088 .3831 .47457 .38203 .48079 .39205 .47716 .38957 Mtetra
.828 .863 .872 r
.47716 .38957 .48079 .39205 .48721 .39114 .48364 .38407 Mtetra
.878 .704 .662 r
.48364 .38407 .48721 .39114 .49375 .37841 .49025 .36791 Mtetra
.865 .661 .625 r
.49025 .36791 .49375 .37841 .50033 .35824 .49685 .34662 Mtetra
.852 .647 .624 r
.49685 .34662 .50033 .35824 .50686 .33666 .50339 .32577 Mtetra
.84 .646 .64 r
.50339 .32577 .50686 .33666 .51332 .31775 .50986 .30839 Mtetra
.827 .655 .669 r
.50986 .30839 .51332 .31775 .51972 .30295 .51626 .29513 Mtetra
.812 .671 .708 r
.51626 .29513 .51972 .30295 .52608 .29199 .52263 .28539 Mtetra
.792 .69 .752 r
.52263 .28539 .52608 .29199 .53243 .28399 .52899 .27826 Mtetra
.767 .707 .795 r
.52899 .27826 .53243 .28399 .53877 .27805 .53535 .2729 Mtetra
.742 .72 .831 r
.53535 .2729 .53877 .27805 .54513 .27349 .54172 .26871 Mtetra
.72 .729 .858 r
.54172 .26871 .54513 .27349 .5515 .2698 .5481 .26525 Mtetra
.701 .734 .876 r
.5481 .26525 .5515 .2698 .55789 .26666 .5545 .26225 Mtetra
.688 .737 .888 r
.5545 .26225 .55789 .26666 .56428 .26386 .56091 .25953 Mtetra
.679 .739 .895 r
.56091 .25953 .56428 .26386 .5707 .26126 .56734 .25697 Mtetra
.674 .74 .9 r
.56734 .25697 .5707 .26126 .57713 .25878 .57378 .25452 Mtetra
.67 .74 .903 r
.57378 .25452 .57713 .25878 .58358 .25638 .58024 .25214 Mtetra
.668 .74 .905 r
.58024 .25214 .58358 .25638 .59004 .25403 .58671 .24978 Mtetra
.666 .741 .906 r
.58671 .24978 .59004 .25403 .59652 .25169 .5932 .24745 Mtetra
.665 .741 .906 r
.5932 .24745 .59652 .25169 .60301 .24937 .5997 .24512 Mtetra
.665 .741 .907 r
.5997 .24512 .60301 .24937 .60952 .24706 .60622 .2428 Mtetra
.664 .741 .907 r
.60622 .2428 .60952 .24706 .61604 .24475 .61275 .24048 Mtetra
.61275 .24048 .61604 .24475 .62258 .24243 .6193 .23816 Mtetra
.6193 .23816 .62258 .24243 .62914 .24012 .62587 .23583 Mtetra
.62587 .23583 .62914 .24012 .63571 .2378 .63245 .2335 Mtetra
.63245 .2335 .63571 .2378 .64229 .23547 .63904 .23117 Mtetra
.63904 .23117 .64229 .23547 .64889 .23314 .64565 .22883 Mtetra
.64565 .22883 .64889 .23314 .65551 .23081 .65228 .22648 Mtetra
.65228 .22648 .65551 .23081 .66214 .22847 .65892 .22413 Mtetra
.65892 .22413 .66214 .22847 .66879 .22612 .66558 .22177 Mtetra
.66558 .22177 .66879 .22612 .67545 .22377 .67226 .21941 Mtetra
.67226 .21941 .67545 .22377 .68213 .22141 .67894 .21704 Mtetra
.67894 .21704 .68213 .22141 .68882 .21905 .68565 .21467 Mtetra
.68565 .21467 .68882 .21905 .69554 .21668 .69237 .21229 Mtetra
.69237 .21229 .69554 .21668 .70226 .21431 .69911 .20991 Mtetra
.69911 .20991 .70226 .21431 .709 .21193 .70586 .20752 Mtetra
.70586 .20752 .709 .21193 .71576 .20954 .71263 .20512 Mtetra
.71263 .20512 .71576 .20954 .72254 .20715 .71942 .20272 Mtetra
.71942 .20272 .72254 .20715 .72933 .20475 .72622 .20032 Mtetra
.72622 .20032 .72933 .20475 .73614 .20235 .73304 .1979 Mtetra
.73304 .1979 .73614 .20235 .74296 .19994 .73987 .19548 Mtetra
.73987 .19548 .74296 .19994 .7498 .19753 .74673 .19306 Mtetra
.74673 .19306 .7498 .19753 .75665 .19511 .75359 .19063 Mtetra
.75359 .19063 .75665 .19511 .76353 .19269 .76048 .18819 Mtetra
.76048 .18819 .76353 .19269 .77042 .19026 .76738 .18575 Mtetra
.76738 .18575 .77042 .19026 .77732 .18782 .77429 .1833 Mtetra
.77429 .1833 .77732 .18782 .78424 .18538 .78123 .18085 Mtetra
.78123 .18085 .78424 .18538 .79118 .18293 .78818 .17839 Mtetra
.78818 .17839 .79118 .18293 .79814 .18047 .79515 .17593 Mtetra
.79515 .17593 .79814 .18047 .80511 .17801 .80213 .17345 Mtetra
.18002 .38856 .18393 .39221 .18951 .39023 .18561 .38658 Mtetra
.18561 .38658 .18951 .39023 .1951 .38826 .19121 .38459 Mtetra
.19121 .38459 .1951 .38826 .20071 .38627 .19682 .3826 Mtetra
.19682 .3826 .20071 .38627 .20633 .38428 .20245 .3806 Mtetra
.20245 .3806 .20633 .38428 .21196 .38229 .20809 .3786 Mtetra
.20809 .3786 .21196 .38229 .2176 .38029 .21374 .3766 Mtetra
.21374 .3766 .2176 .38029 .22326 .37829 .2194 .37459 Mtetra
.2194 .37459 .22326 .37829 .22893 .37629 .22508 .37257 Mtetra
.22508 .37257 .22893 .37629 .23461 .37428 .23076 .37055 Mtetra
.23076 .37055 .23461 .37428 .2403 .37226 .23646 .36853 Mtetra
.23646 .36853 .2403 .37226 .246 .37024 .24217 .36651 Mtetra
.24217 .36651 .246 .37024 .25172 .36822 .2479 .36447 Mtetra
.2479 .36447 .25172 .36822 .25745 .36619 .25364 .36244 Mtetra
.25364 .36244 .25745 .36619 .26319 .36416 .25939 .3604 Mtetra
.25939 .3604 .26319 .36416 .26895 .36212 .26515 .35835 Mtetra
.26515 .35835 .26895 .36212 .27472 .36008 .27093 .3563 Mtetra
.27093 .3563 .27472 .36008 .2805 .35804 .27671 .35425 Mtetra
.27671 .35425 .2805 .35804 .28629 .35599 .28251 .35219 Mtetra
.28251 .35219 .28629 .35599 .2921 .35394 .28833 .35013 Mtetra
.28833 .35013 .2921 .35394 .29792 .35188 .29415 .34807 Mtetra
.664 .741 .908 r
.29415 .34807 .29792 .35188 .30375 .34982 .29999 .346 Mtetra
.663 .741 .908 r
.29999 .346 .30375 .34982 .30959 .34776 .30585 .34394 Mtetra
.30585 .34394 .30959 .34776 .31545 .3457 .31171 .34188 Mtetra
.662 .741 .909 r
.31171 .34188 .31545 .3457 .32132 .34365 .31759 .33983 Mtetra
.659 .741 .91 r
.31759 .33983 .32132 .34365 .3272 .34161 .32347 .33781 Mtetra
.655 .741 .913 r
.32347 .33781 .3272 .34161 .33309 .33962 .32937 .33585 Mtetra
.647 .741 .918 r
.32937 .33585 .33309 .33962 .33899 .33769 .33527 .334 Mtetra
.629 .741 .928 r
.33527 .334 .33899 .33769 .3449 .33591 .34118 .33238 Mtetra
.589 .738 .946 r
.34118 .33238 .3449 .33591 .3508 .3344 .34707 .33121 Mtetra
.481 .718 .975 r
.34707 .33121 .3508 .3344 .35669 .33344 .35293 .33092 Mtetra
.11 .56 .916 r
.35293 .33092 .35669 .33344 .36255 .33354 .35873 .33231 Mtetra
.625 .06 0 r
.35873 .33231 .36255 .33354 .36832 .33565 .36438 .33692 Mtetra
.832 .41 .237 r
.36438 .33692 .36832 .33565 .37395 .34157 .36979 .34743 Mtetra
.851 .505 .398 r
.36979 .34743 .37395 .34157 .3793 .35432 .37478 .36797 Mtetra
.844 .532 .46 r
.37478 .36797 .3793 .35432 .38423 .37826 .37923 .40295 Mtetra
.825 .528 .486 r
.37923 .40295 .38423 .37826 .38865 .41708 .38324 .45145 Mtetra
.783 .492 .495 r
.38324 .45145 .38865 .41708 .3928 .46665 .38758 .497 Mtetra
.646 .357 .465 r
.38758 .497 .3928 .46665 .39757 .50578 .39341 .50956 Mtetra
.995 .818 .555 r
.39341 .50956 .39757 .50578 .40391 .50615 .40099 .47774 Mtetra
.843 .599 .57 r
.40099 .47774 .40391 .50615 .41166 .46643 .40921 .42508 Mtetra
.786 .544 .571 r
.40921 .42508 .41166 .46643 .41968 .4144 .41703 .37883 Mtetra
.753 .523 .583 r
.41703 .37883 .41968 .4144 .4272 .3729 .42419 .34867 Mtetra
.723 .516 .611 r
.42419 .34867 .4272 .3729 .43412 .34763 .43082 .33296 Mtetra
.66 .512 .672 r
.43082 .33296 .43412 .34763 .4406 .33595 .43711 .32792 Mtetra
.337 .415 .794 r
.43711 .32792 .4406 .33595 .44681 .33438 .4432 .33089 Mtetra
.767 .288 0 r
.4432 .33089 .44681 .33438 .45286 .34063 .44917 .34042 Mtetra
.881 .464 .211 r
.44917 .34042 .45286 .34063 .45882 .35299 .45509 .35489 Mtetra
.87 .476 .286 r
.45509 .35489 .45882 .35299 .4648 .36879 .46105 .37103 Mtetra
.832 .415 .247 r
.46105 .37103 .4648 .36879 .47088 .3831 .46718 .38322 Mtetra
.407 0 0 r
.46718 .38322 .47088 .3831 .47716 .38957 .47353 .38547 Mtetra
.878 .779 .747 r
.47353 .38547 .47716 .38957 .48364 .38407 .48009 .37556 Mtetra
.874 .684 .642 r
.48009 .37556 .48364 .38407 .49025 .36791 .48674 .35678 Mtetra
.86 .655 .623 r
.48674 .35678 .49025 .36791 .49685 .34662 .49337 .33517 Mtetra
.848 .646 .629 r
.49337 .33517 .49685 .34662 .50339 .32577 .49992 .31544 Mtetra
.836 .649 .65 r
.49992 .31544 .50339 .32577 .50986 .30839 .50639 .29964 Mtetra
.822 .661 .683 r
.50639 .29964 .50986 .30839 .51626 .29513 .5128 .2878 Mtetra
.805 .678 .724 r
.5128 .2878 .51626 .29513 .52263 .28539 .51918 .27915 Mtetra
.783 .697 .769 r
.51918 .27915 .52263 .28539 .52899 .27826 .52555 .27277 Mtetra
.758 .713 .81 r
.52555 .27277 .52899 .27826 .53535 .2729 .53192 .2679 Mtetra
.733 .724 .842 r
.53192 .2679 .53535 .2729 .54172 .26871 .5383 .26402 Mtetra
.712 .731 .866 r
.5383 .26402 .54172 .26871 .5481 .26525 .5447 .26075 Mtetra
.696 .735 .881 r
.5447 .26075 .5481 .26525 .5545 .26225 .5511 .25786 Mtetra
.685 .738 .891 r
.5511 .25786 .5545 .26225 .56091 .25953 .55752 .2552 Mtetra
.677 .739 .897 r
.55752 .2552 .56091 .25953 .56734 .25697 .56396 .25269 Mtetra
.672 .74 .901 r
.56396 .25269 .56734 .25697 .57378 .25452 .57041 .25026 Mtetra
.669 .74 .904 r
.57041 .25026 .57378 .25452 .58024 .25214 .57688 .24788 Mtetra
.667 .74 .905 r
.57688 .24788 .58024 .25214 .58671 .24978 .58336 .24552 Mtetra
.666 .741 .906 r
.58336 .24552 .58671 .24978 .5932 .24745 .58986 .24318 Mtetra
.665 .741 .906 r
.58986 .24318 .5932 .24745 .5997 .24512 .59637 .24085 Mtetra
.665 .741 .907 r
.59637 .24085 .5997 .24512 .60622 .2428 .6029 .23853 Mtetra
.664 .741 .907 r
.6029 .23853 .60622 .2428 .61275 .24048 .60945 .2362 Mtetra
.60945 .2362 .61275 .24048 .6193 .23816 .61601 .23386 Mtetra
.61601 .23386 .6193 .23816 .62587 .23583 .62258 .23153 Mtetra
.62258 .23153 .62587 .23583 .63245 .2335 .62917 .22919 Mtetra
.62917 .22919 .63245 .2335 .63904 .23117 .63578 .22684 Mtetra
.63578 .22684 .63904 .23117 .64565 .22883 .6424 .22449 Mtetra
.6424 .22449 .64565 .22883 .65228 .22648 .64904 .22214 Mtetra
.64904 .22214 .65228 .22648 .65892 .22413 .65569 .21978 Mtetra
.65569 .21978 .65892 .22413 .66558 .22177 .66236 .21741 Mtetra
.66236 .21741 .66558 .22177 .67226 .21941 .66905 .21504 Mtetra
.66905 .21504 .67226 .21941 .67894 .21704 .67575 .21266 Mtetra
.67575 .21266 .67894 .21704 .68565 .21467 .68246 .21028 Mtetra
.68246 .21028 .68565 .21467 .69237 .21229 .68919 .20789 Mtetra
.68919 .20789 .69237 .21229 .69911 .20991 .69594 .20549 Mtetra
.69594 .20549 .69911 .20991 .70586 .20752 .70271 .20309 Mtetra
.70271 .20309 .70586 .20752 .71263 .20512 .70949 .20069 Mtetra
.70949 .20069 .71263 .20512 .71942 .20272 .71629 .19827 Mtetra
.71629 .19827 .71942 .20272 .72622 .20032 .7231 .19586 Mtetra
.7231 .19586 .72622 .20032 .73304 .1979 .72993 .19343 Mtetra
.72993 .19343 .73304 .1979 .73987 .19548 .73678 .191 Mtetra
.73678 .191 .73987 .19548 .74673 .19306 .74364 .18857 Mtetra
.74364 .18857 .74673 .19306 .75359 .19063 .75052 .18613 Mtetra
.75052 .18613 .75359 .19063 .76048 .18819 .75741 .18368 Mtetra
.75741 .18368 .76048 .18819 .76738 .18575 .76432 .18123 Mtetra
.76432 .18123 .76738 .18575 .77429 .1833 .77125 .17877 Mtetra
.77125 .17877 .77429 .1833 .78123 .18085 .7782 .17631 Mtetra
.7782 .17631 .78123 .18085 .78818 .17839 .78516 .17383 Mtetra
.78516 .17383 .78818 .17839 .79515 .17593 .79214 .17136 Mtetra
.79214 .17136 .79515 .17593 .80213 .17345 .79914 .16888 Mtetra
.1761 .3849 .18002 .38856 .18561 .38658 .18169 .3829 Mtetra
.18169 .3829 .18561 .38658 .19121 .38459 .1873 .38091 Mtetra
.1873 .38091 .19121 .38459 .19682 .3826 .19292 .37891 Mtetra
.19292 .37891 .19682 .3826 .20245 .3806 .19855 .3769 Mtetra
.19855 .3769 .20245 .3806 .20809 .3786 .2042 .3749 Mtetra
.2042 .3749 .20809 .3786 .21374 .3766 .20986 .37288 Mtetra
.20986 .37288 .21374 .3766 .2194 .37459 .21553 .37087 Mtetra
.21553 .37087 .2194 .37459 .22508 .37257 .22121 .36884 Mtetra
.22121 .36884 .22508 .37257 .23076 .37055 .2269 .36682 Mtetra
.2269 .36682 .23076 .37055 .23646 .36853 .23261 .36479 Mtetra
.23261 .36479 .23646 .36853 .24217 .36651 .23833 .36275 Mtetra
.23833 .36275 .24217 .36651 .2479 .36447 .24406 .36071 Mtetra
.24406 .36071 .2479 .36447 .25364 .36244 .24981 .35867 Mtetra
.24981 .35867 .25364 .36244 .25939 .3604 .25556 .35662 Mtetra
.25556 .35662 .25939 .3604 .26515 .35835 .26133 .35457 Mtetra
.26133 .35457 .26515 .35835 .27093 .3563 .26712 .35251 Mtetra
.26712 .35251 .27093 .3563 .27671 .35425 .27291 .35045 Mtetra
.27291 .35045 .27671 .35425 .28251 .35219 .27872 .34838 Mtetra
.27872 .34838 .28251 .35219 .28833 .35013 .28454 .34631 Mtetra
.28454 .34631 .28833 .35013 .29415 .34807 .29038 .34424 Mtetra
.663 .741 .908 r
.29038 .34424 .29415 .34807 .29999 .346 .29622 .34217 Mtetra
.29622 .34217 .29999 .346 .30585 .34394 .30208 .3401 Mtetra
.662 .741 .908 r
.30208 .3401 .30585 .34394 .31171 .34188 .30795 .33804 Mtetra
.66 .741 .91 r
.30795 .33804 .31171 .34188 .31759 .33983 .31384 .336 Mtetra
.657 .741 .912 r
.31384 .336 .31759 .33983 .32347 .33781 .31973 .33401 Mtetra
.65 .741 .916 r
.31973 .33401 .32347 .33781 .32937 .33585 .32563 .33212 Mtetra
.636 .741 .924 r
.32563 .33212 .32937 .33585 .33527 .334 .33153 .3304 Mtetra
.605 .739 .94 r
.33153 .3304 .33527 .334 .34118 .33238 .33743 .32907 Mtetra
.525 .728 .967 r
.33743 .32907 .34118 .33238 .34707 .33121 .3433 .32845 Mtetra
.265 .64 .964 r
.3433 .32845 .34707 .33121 .35293 .33092 .34911 .32925 Mtetra
.46 0 0 r
.34911 .32925 .35293 .33092 .35873 .33231 .35479 .33276 Mtetra
.811 .357 .155 r
.35479 .33276 .35873 .33231 .36438 .33692 .36025 .34133 Mtetra
.85 .49 .371 r
.36025 .34133 .36438 .33692 .36979 .34743 .36532 .35877 Mtetra
.847 .528 .449 r
.36532 .35877 .36979 .34743 .37478 .36797 .36981 .38978 Mtetra
.831 .531 .482 r
.36981 .38978 .37478 .36797 .37923 .40295 .37375 .43589 Mtetra
.798 .506 .495 r
.37375 .43589 .37923 .40295 .38324 .45145 .37773 .48549 Mtetra
.707 .417 .483 r
.37773 .48549 .38324 .45145 .38758 .497 .38301 .50959 Mtetra
.746 .782 .287 r
.38301 .50959 .38758 .497 .39341 .50956 .39026 .48784 Mtetra
.867 .625 .571 r
.39026 .48784 .39341 .50956 .40099 .47774 .3986 .43667 Mtetra
.796 .553 .57 r
.3986 .43667 .40099 .47774 .40921 .42508 .40673 .38634 Mtetra
.76 .526 .578 r
.40673 .38634 .40921 .42508 .41703 .37883 .41416 .35126 Mtetra
.734 .518 .6 r
.41416 .35126 .41703 .37883 .42419 .34867 .42097 .33149 Mtetra
.694 .519 .647 r
.42097 .33149 .42419 .34867 .43082 .33296 .42737 .32309 Mtetra
.549 .499 .752 r
.42737 .32309 .43082 .33296 .43711 .32792 .43352 .32293 Mtetra
0 .042 .59 r
.43352 .32293 .43711 .32792 .4432 .33089 .43952 .32941 Mtetra
.865 .419 .108 r
.43952 .32941 .4432 .33089 .44917 .34042 .44542 .34151 Mtetra
.878 .478 .267 r
.44542 .34151 .44917 .34042 .45509 .35489 .45131 .35737 Mtetra
.859 .465 .292 r
.45131 .35737 .45509 .35489 .46105 .37103 .45729 .3729 Mtetra
.792 .343 .178 r
.45729 .3729 .46105 .37103 .46718 .38322 .46348 .38201 Mtetra
.598 .903 .985 r
.46348 .38201 .46718 .38322 .47353 .38547 .46992 .37969 Mtetra
.883 .73 .687 r
.46992 .37969 .47353 .38547 .48009 .37556 .47656 .36585 Mtetra
.87 .67 .631 r
.47656 .36585 .48009 .37556 .48674 .35678 .48324 .34534 Mtetra
.856 .65 .623 r
.48324 .34534 .48674 .35678 .49337 .33517 .48988 .32405 Mtetra
.844 .646 .636 r
.48988 .32405 .49337 .33517 .49992 .31544 .49643 .30571 Mtetra
.831 .653 .661 r
.49643 .30571 .49992 .31544 .50639 .29964 .50291 .29146 Mtetra
.816 .667 .698 r
.50291 .29146 .50639 .29964 .5128 .2878 .50932 .28092 Mtetra
.797 .685 .741 r
.50932 .28092 .5128 .2878 .51918 .27915 .51571 .27321 Mtetra
.774 .703 .785 r
.51571 .27321 .51918 .27915 .52555 .27277 .5221 .26747 Mtetra
.748 .718 .823 r
.5221 .26747 .52555 .27277 .53192 .2679 .52848 .26302 Mtetra
.725 .727 .852 r
.52848 .26302 .53192 .2679 .5383 .26402 .53487 .25939 Mtetra
.705 .733 .872 r
.53487 .25939 .5383 .26402 .5447 .26075 .54127 .25628 Mtetra
.691 .736 .886 r
.54127 .25628 .5447 .26075 .5511 .25786 .54769 .25348 Mtetra
.681 .738 .894 r
.54769 .25348 .5511 .25786 .55752 .2552 .55412 .25088 Mtetra
.675 .739 .899 r
.55412 .25088 .55752 .2552 .56396 .25269 .56057 .24839 Mtetra
.671 .74 .902 r
.56057 .24839 .56396 .25269 .57041 .25026 .56703 .24598 Mtetra
.668 .74 .904 r
.56703 .24598 .57041 .25026 .57688 .24788 .57351 .2436 Mtetra
.666 .741 .905 r
.57351 .2436 .57688 .24788 .58336 .24552 .58 .24125 Mtetra
.665 .741 .906 r
.58 .24125 .58336 .24552 .58986 .24318 .58651 .2389 Mtetra
.665 .741 .907 r
.58651 .2389 .58986 .24318 .59637 .24085 .59303 .23657 Mtetra
.664 .741 .907 r
.59303 .23657 .59637 .24085 .6029 .23853 .59957 .23423 Mtetra
.59957 .23423 .6029 .23853 .60945 .2362 .60613 .23189 Mtetra
.60613 .23189 .60945 .2362 .61601 .23386 .6127 .22955 Mtetra
.6127 .22955 .61601 .23386 .62258 .23153 .61928 .22721 Mtetra
.61928 .22721 .62258 .23153 .62917 .22919 .62588 .22486 Mtetra
.62588 .22486 .62917 .22919 .63578 .22684 .6325 .2225 Mtetra
.6325 .2225 .63578 .22684 .6424 .22449 .63913 .22014 Mtetra
.63913 .22014 .6424 .22449 .64904 .22214 .64578 .21777 Mtetra
.64578 .21777 .64904 .22214 .65569 .21978 .65245 .2154 Mtetra
.65245 .2154 .65569 .21978 .66236 .21741 .65913 .21303 Mtetra
.65913 .21303 .66236 .21741 .66905 .21504 .66582 .21064 Mtetra
.66582 .21064 .66905 .21504 .67575 .21266 .67253 .20825 Mtetra
.67253 .20825 .67575 .21266 .68246 .21028 .67926 .20586 Mtetra
.67926 .20586 .68246 .21028 .68919 .20789 .686 .20346 Mtetra
.686 .20346 .68919 .20789 .69594 .20549 .69276 .20106 Mtetra
.69276 .20106 .69594 .20549 .70271 .20309 .69954 .19865 Mtetra
.69954 .19865 .70271 .20309 .70949 .20069 .70633 .19623 Mtetra
.70633 .19623 .70949 .20069 .71629 .19827 .71314 .19381 Mtetra
.71314 .19381 .71629 .19827 .7231 .19586 .71996 .19138 Mtetra
.71996 .19138 .7231 .19586 .72993 .19343 .72681 .18894 Mtetra
.72681 .18894 .72993 .19343 .73678 .191 .73366 .1865 Mtetra
.73366 .1865 .73678 .191 .74364 .18857 .74054 .18406 Mtetra
.74054 .18406 .74364 .18857 .75052 .18613 .74743 .18161 Mtetra
.74743 .18161 .75052 .18613 .75741 .18368 .75433 .17915 Mtetra
.75433 .17915 .75741 .18368 .76432 .18123 .76126 .17669 Mtetra
.76126 .17669 .76432 .18123 .77125 .17877 .7682 .17422 Mtetra
.7682 .17422 .77125 .17877 .7782 .17631 .77516 .17174 Mtetra
.77516 .17174 .7782 .17631 .78516 .17383 .78213 .16926 Mtetra
.78213 .16926 .78516 .17383 .79214 .17136 .78912 .16677 Mtetra
.78912 .16677 .79214 .17136 .79914 .16888 .79613 .16428 Mtetra
.17216 .38122 .1761 .3849 .18169 .3829 .17776 .37922 Mtetra
.17776 .37922 .18169 .3829 .1873 .38091 .18337 .37721 Mtetra
.18337 .37721 .1873 .38091 .19292 .37891 .189 .37521 Mtetra
.189 .37521 .19292 .37891 .19855 .3769 .19464 .37319 Mtetra
.19464 .37319 .19855 .3769 .2042 .3749 .20029 .37118 Mtetra
.20029 .37118 .2042 .3749 .20986 .37288 .20596 .36915 Mtetra
.20596 .36915 .20986 .37288 .21553 .37087 .21164 .36713 Mtetra
.21164 .36713 .21553 .37087 .22121 .36884 .21733 .3651 Mtetra
.21733 .3651 .22121 .36884 .2269 .36682 .22303 .36306 Mtetra
.22303 .36306 .2269 .36682 .23261 .36479 .22874 .36103 Mtetra
.22874 .36103 .23261 .36479 .23833 .36275 .23447 .35898 Mtetra
.23447 .35898 .23833 .36275 .24406 .36071 .24021 .35693 Mtetra
.24021 .35693 .24406 .36071 .24981 .35867 .24596 .35488 Mtetra
.24596 .35488 .24981 .35867 .25556 .35662 .25173 .35282 Mtetra
.25173 .35282 .25556 .35662 .26133 .35457 .2575 .35076 Mtetra
.2575 .35076 .26133 .35457 .26712 .35251 .26329 .3487 Mtetra
.26329 .3487 .26712 .35251 .27291 .35045 .2691 .34663 Mtetra
.2691 .34663 .27291 .35045 .27872 .34838 .27491 .34456 Mtetra
.27491 .34456 .27872 .34838 .28454 .34631 .28074 .34248 Mtetra
.663 .741 .908 r
.28074 .34248 .28454 .34631 .29038 .34424 .28658 .3404 Mtetra
.28658 .3404 .29038 .34424 .29622 .34217 .29244 .33833 Mtetra
.662 .741 .908 r
.29244 .33833 .29622 .34217 .30208 .3401 .2983 .33626 Mtetra
.661 .741 .909 r
.2983 .33626 .30208 .3401 .30795 .33804 .30418 .3342 Mtetra
.658 .741 .911 r
.30418 .3342 .30795 .33804 .31384 .336 .31007 .33219 Mtetra
.653 .741 .915 r
.31007 .33219 .31384 .336 .31973 .33401 .31597 .33025 Mtetra
.642 .741 .921 r
.31597 .33025 .31973 .33401 .32563 .33212 .32187 .32846 Mtetra
.617 .74 .934 r
.32187 .32846 .32563 .33212 .33153 .3304 .32776 .32698 Mtetra
.556 .734 .958 r
.32776 .32698 .33153 .3304 .33743 .32907 .33364 .32611 Mtetra
.373 .684 .979 r
.33364 .32611 .33743 .32907 .3433 .32845 .33946 .32641 Mtetra
0 .318 .697 r
.33946 .32641 .3433 .32845 .34911 .32925 .34518 .329 Mtetra
.774 .28 .043 r
.34518 .329 .34911 .32925 .35479 .33276 .35068 .3359 Mtetra
.847 .47 .336 r
.35068 .3359 .35479 .33276 .36025 .34133 .35582 .35056 Mtetra
.849 .523 .436 r
.35582 .35056 .36025 .34133 .36532 .35877 .3604 .37771 Mtetra
.836 .533 .476 r
.3604 .37771 .36532 .35877 .36981 .38978 .36432 .42051 Mtetra
.809 .516 .493 r
.36432 .42051 .36981 .38978 .37375 .43589 .36803 .4719 Mtetra
.743 .453 .491 r
.36803 .4719 .37375 .43589 .37773 .48549 .37273 .50608 Mtetra
.229 0 .287 r
.37273 .50608 .37773 .48549 .38301 .50959 .37953 .496 Mtetra
.899 .663 .573 r
.37953 .496 .38301 .50959 .39026 .48784 .38787 .44872 Mtetra
.809 .564 .568 r
.38787 .44872 .39026 .48784 .3986 .43667 .39629 .39531 Mtetra
.768 .53 .574 r
.39629 .39531 .3986 .43667 .40673 .38634 .40403 .35535 Mtetra
.742 .519 .591 r
.40403 .35535 .40673 .38634 .41416 .35126 .41105 .33142 Mtetra
.713 .522 .629 r
.41105 .33142 .41416 .35126 .42097 .33149 .41758 .31971 Mtetra
.637 .524 .708 r
.41758 .31971 .42097 .33149 .42737 .32309 .42381 .31661 Mtetra
.197 .385 .823 r
.42381 .31661 .42737 .32309 .43352 .32293 .42986 .32013 Mtetra
.789 .302 0 r
.42986 .32013 .43352 .32293 .43952 .32941 .43577 .3294 Mtetra
.877 .459 .216 r
.43577 .3294 .43952 .32941 .44542 .34151 .44162 .34353 Mtetra
.871 .48 .294 r
.44162 .34353 .44542 .34151 .45131 .35737 .4475 .36003 Mtetra
.844 .442 .28 r
.4475 .36003 .45131 .35737 .45729 .3729 .45351 .37398 Mtetra
.682 .164 0 r
.45351 .37398 .45729 .3729 .46348 .38201 .45979 .37922 Mtetra
.859 .842 .827 r
.45979 .37922 .46348 .38201 .46992 .37969 .46633 .37229 Mtetra
.879 .7 .655 r
.46633 .37229 .46992 .37969 .47656 .36585 .47303 .35525 Mtetra
.865 .661 .625 r
.47303 .35525 .47656 .36585 .48324 .34534 .47975 .33385 Mtetra
.851 .648 .626 r
.47975 .33385 .48324 .34534 .48988 .32405 .48639 .31339 Mtetra
.839 .648 .644 r
.48639 .31339 .48988 .32405 .49643 .30571 .49294 .29656 Mtetra
.826 .658 .674 r
.49294 .29656 .49643 .30571 .50291 .29146 .49942 .28379 Mtetra
.81 .674 .714 r
.49942 .28379 .50291 .29146 .50932 .28092 .50584 .27442 Mtetra
.789 .693 .758 r
.50584 .27442 .50932 .28092 .51571 .27321 .51224 .26754 Mtetra
.764 .709 .8 r
.51224 .26754 .51571 .27321 .5221 .26747 .51863 .26234 Mtetra
.739 .722 .835 r
.51863 .26234 .5221 .26747 .52848 .26302 .52502 .25823 Mtetra
.717 .73 .861 r
.52502 .25823 .52848 .26302 .53487 .25939 .53142 .25482 Mtetra
.699 .735 .878 r
.53142 .25482 .53487 .25939 .54127 .25628 .53784 .25184 Mtetra
.687 .737 .889 r
.53784 .25184 .54127 .25628 .54769 .25348 .54426 .24912 Mtetra
.678 .739 .896 r
.54426 .24912 .54769 .25348 .55412 .25088 .55071 .24656 Mtetra
.673 .74 .901 r
.55071 .24656 .55412 .25088 .56057 .24839 .55716 .24409 Mtetra
.67 .74 .903 r
.55716 .24409 .56057 .24839 .56703 .24598 .56364 .24169 Mtetra
.667 .74 .905 r
.56364 .24169 .56703 .24598 .57351 .2436 .57012 .23931 Mtetra
.666 .741 .906 r
.57012 .23931 .57351 .2436 .58 .24125 .57663 .23696 Mtetra
.665 .741 .906 r
.57663 .23696 .58 .24125 .58651 .2389 .58315 .23461 Mtetra
.665 .741 .907 r
.58315 .23461 .58651 .2389 .59303 .23657 .58968 .23226 Mtetra
.664 .741 .907 r
.58968 .23226 .59303 .23657 .59957 .23423 .59623 .22992 Mtetra
.59623 .22992 .59957 .23423 .60613 .23189 .60279 .22757 Mtetra
.60279 .22757 .60613 .23189 .6127 .22955 .60937 .22522 Mtetra
.60937 .22522 .6127 .22955 .61928 .22721 .61597 .22286 Mtetra
.61597 .22286 .61928 .22721 .62588 .22486 .62258 .2205 Mtetra
.62258 .2205 .62588 .22486 .6325 .2225 .62921 .21814 Mtetra
.62921 .21814 .6325 .2225 .63913 .22014 .63585 .21577 Mtetra
.63585 .21577 .63913 .22014 .64578 .21777 .64251 .21339 Mtetra
.64251 .21339 .64578 .21777 .65245 .2154 .64919 .21101 Mtetra
.64919 .21101 .65245 .2154 .65913 .21303 .65588 .20862 Mtetra
.65588 .20862 .65913 .21303 .66582 .21064 .66258 .20623 Mtetra
.66258 .20623 .66582 .21064 .67253 .20825 .66931 .20383 Mtetra
.66931 .20383 .67253 .20825 .67926 .20586 .67604 .20143 Mtetra
.67604 .20143 .67926 .20586 .686 .20346 .6828 .19902 Mtetra
.6828 .19902 .686 .20346 .69276 .20106 .68957 .1966 Mtetra
.68957 .1966 .69276 .20106 .69954 .19865 .69636 .19418 Mtetra
.69636 .19418 .69954 .19865 .70633 .19623 .70316 .19175 Mtetra
.70316 .19175 .70633 .19623 .71314 .19381 .70998 .18932 Mtetra
.70998 .18932 .71314 .19381 .71996 .19138 .71681 .18688 Mtetra
.71681 .18688 .71996 .19138 .72681 .18894 .72367 .18443 Mtetra
.72367 .18443 .72681 .18894 .73366 .1865 .73054 .18198 Mtetra
.73054 .18198 .73366 .1865 .74054 .18406 .73742 .17953 Mtetra
.73742 .17953 .74054 .18406 .74743 .18161 .74432 .17706 Mtetra
.74432 .17706 .74743 .18161 .75433 .17915 .75124 .1746 Mtetra
.75124 .1746 .75433 .17915 .76126 .17669 .75818 .17212 Mtetra
.75818 .17212 .76126 .17669 .7682 .17422 .76513 .16964 Mtetra
.76513 .16964 .7682 .17422 .77516 .17174 .7721 .16715 Mtetra
.7721 .16715 .77516 .17174 .78213 .16926 .77909 .16466 Mtetra
.77909 .16466 .78213 .16926 .78912 .16677 .78609 .16216 Mtetra
.78609 .16216 .78912 .16677 .79613 .16428 .79311 .15966 Mtetra
.1682 .37752 .17216 .38122 .17776 .37922 .17381 .37551 Mtetra
.17381 .37551 .17776 .37922 .18337 .37721 .17943 .3735 Mtetra
.17943 .3735 .18337 .37721 .189 .37521 .18507 .37149 Mtetra
.18507 .37149 .189 .37521 .19464 .37319 .19071 .36947 Mtetra
.19071 .36947 .19464 .37319 .20029 .37118 .19637 .36744 Mtetra
.19637 .36744 .20029 .37118 .20596 .36915 .20205 .36541 Mtetra
.20205 .36541 .20596 .36915 .21164 .36713 .20773 .36338 Mtetra
.20773 .36338 .21164 .36713 .21733 .3651 .21343 .36134 Mtetra
.21343 .36134 .21733 .3651 .22303 .36306 .21914 .3593 Mtetra
.21914 .3593 .22303 .36306 .22874 .36103 .22486 .35725 Mtetra
.22486 .35725 .22874 .36103 .23447 .35898 .23059 .3552 Mtetra
.23059 .3552 .23447 .35898 .24021 .35693 .23634 .35314 Mtetra
.23634 .35314 .24021 .35693 .24596 .35488 .2421 .35108 Mtetra
.2421 .35108 .24596 .35488 .25173 .35282 .24787 .34902 Mtetra
.24787 .34902 .25173 .35282 .2575 .35076 .25366 .34695 Mtetra
.25366 .34695 .2575 .35076 .26329 .3487 .25945 .34487 Mtetra
.25945 .34487 .26329 .3487 .2691 .34663 .26527 .34279 Mtetra
.26527 .34279 .2691 .34663 .27491 .34456 .27109 .34071 Mtetra
.663 .741 .907 r
.27109 .34071 .27491 .34456 .28074 .34248 .27693 .33863 Mtetra
.663 .741 .908 r
.27693 .33863 .28074 .34248 .28658 .3404 .28278 .33655 Mtetra
.28278 .33655 .28658 .3404 .29244 .33833 .28864 .33447 Mtetra
.662 .741 .909 r
.28864 .33447 .29244 .33833 .2983 .33626 .29451 .3324 Mtetra
.659 .741 .91 r
.29451 .3324 .2983 .33626 .30418 .3342 .30039 .33037 Mtetra
.655 .741 .913 r
.30039 .33037 .30418 .3342 .31007 .33219 .30629 .3284 Mtetra
.646 .741 .919 r
.30629 .3284 .31007 .33219 .31597 .33025 .31219 .32655 Mtetra
.626 .741 .93 r
.31219 .32655 .31597 .33025 .32187 .32846 .31808 .32495 Mtetra
.58 .737 .95 r
.31808 .32495 .32187 .32846 .32776 .32698 .32396 .32386 Mtetra
.447 .71 .979 r
.32396 .32386 .32776 .32698 .33364 .32611 .32979 .32375 Mtetra
0 .481 .851 r
.32979 .32375 .33364 .32611 .33946 .32641 .33553 .32556 Mtetra
.707 .17 0 r
.33553 .32556 .33946 .32641 .34518 .329 .34109 .33105 Mtetra
.84 .441 .289 r
.34109 .33105 .34518 .329 .35068 .3359 .3463 .34326 Mtetra
.85 .515 .419 r
.3463 .34326 .35068 .3359 .35582 .35056 .35097 .36674 Mtetra
.841 .533 .469 r
.35097 .36674 .35582 .35056 .3604 .37771 .35493 .40571 Mtetra
.818 .524 .491 r
.35493 .40571 .3604 .37771 .36432 .42051 .35844 .45695 Mtetra
.767 .478 .495 r
.35844 .45695 .36432 .42051 .36803 .4719 .36261 .4992 Mtetra
.546 .258 .429 r
.36261 .4992 .36803 .4719 .37273 .50608 .36883 .50159 Mtetra
.944 .723 .573 r
.36883 .50159 .37273 .50608 .37953 .496 .37703 .46068 Mtetra
.824 .579 .568 r
.37703 .46068 .37953 .496 .38787 .44872 .38571 .40555 Mtetra
.776 .536 .571 r
.38571 .40555 .38787 .44872 .39629 .39531 .39378 .36089 Mtetra
.749 .521 .585 r
.39378 .36089 .39629 .39531 .40403 .35535 .40104 .33266 Mtetra
.726 .522 .615 r
.40104 .33266 .40403 .35535 .41105 .33142 .40773 .31763 Mtetra
.681 .532 .676 r
.40773 .31763 .41105 .33142 .41758 .31971 .41406 .31175 Mtetra
.49 .508 .803 r
.41406 .31175 .41758 .31971 .42381 .31661 .42017 .31252 Mtetra
0 0 .5 r
.42017 .31252 .42381 .31661 .42986 .32013 .42612 .31893 Mtetra
.859 .409 .113 r
.42612 .31893 .42986 .32013 .43577 .3294 .43197 .33052 Mtetra
.876 .475 .267 r
.43197 .33052 .43577 .3294 .44162 .34353 .43778 .34614 Mtetra
.863 .474 .303 r
.43778 .34614 .44162 .34353 .4475 .36003 .44365 .36248 Mtetra
.82 .398 .241 r
.44365 .36248 .4475 .36003 .45351 .37398 .44973 .37387 Mtetra
.15 0 0 r
.44973 .37387 .45351 .37398 .45979 .37922 .45611 .3747 Mtetra
.884 .764 .725 r
.45611 .3747 .45979 .37922 .46633 .37229 .46275 .36347 Mtetra
.874 .681 .638 r
.46275 .36347 .46633 .37229 .47303 .35525 .46951 .34407 Mtetra
.86 .654 .623 r
.46951 .34407 .47303 .35525 .47975 .33385 .47625 .32254 Mtetra
.847 .647 .632 r
.47625 .32254 .47975 .33385 .48639 .31339 .4829 .30327 Mtetra
.835 .651 .654 r
.4829 .30327 .48639 .31339 .49294 .29656 .48944 .288 Mtetra
.821 .664 .688 r
.48944 .288 .49294 .29656 .49942 .28379 .49591 .2766 Mtetra
.802 .681 .73 r
.49591 .2766 .49942 .28379 .50584 .27442 .50234 .26826 Mtetra
.78 .699 .775 r
.50234 .26826 .50584 .27442 .51224 .26754 .50875 .26208 Mtetra
.755 .715 .815 r
.50875 .26208 .51224 .26754 .51863 .26234 .51515 .25734 Mtetra
.73 .725 .846 r
.51515 .25734 .51863 .26234 .52502 .25823 .52155 .25353 Mtetra
.71 .732 .868 r
.52155 .25353 .52502 .25823 .53142 .25482 .52796 .25029 Mtetra
.694 .736 .883 r
.52796 .25029 .53142 .25482 .53784 .25184 .53438 .24741 Mtetra
.683 .738 .892 r
.53438 .24741 .53784 .25184 .54426 .24912 .54082 .24476 Mtetra
.676 .739 .898 r
.54082 .24476 .54426 .24912 .55071 .24656 .54728 .24223 Mtetra
.671 .74 .902 r
.54728 .24223 .55071 .24656 .55716 .24409 .55374 .23978 Mtetra
.669 .74 .904 r
.55374 .23978 .55716 .24409 .56364 .24169 .56023 .23738 Mtetra
.667 .74 .905 r
.56023 .23738 .56364 .24169 .57012 .23931 .56672 .23501 Mtetra
.666 .741 .906 r
.56672 .23501 .57012 .23931 .57663 .23696 .57324 .23265 Mtetra
.665 .741 .907 r
.57324 .23265 .57663 .23696 .58315 .23461 .57977 .23029 Mtetra
.57977 .23029 .58315 .23461 .58968 .23226 .58631 .22794 Mtetra
.664 .741 .907 r
.58631 .22794 .58968 .23226 .59623 .22992 .59287 .22559 Mtetra
.59287 .22559 .59623 .22992 .60279 .22757 .59945 .22323 Mtetra
.59945 .22323 .60279 .22757 .60937 .22522 .60604 .22087 Mtetra
.60604 .22087 .60937 .22522 .61597 .22286 .61264 .2185 Mtetra
.61264 .2185 .61597 .22286 .62258 .2205 .61926 .21613 Mtetra
.61926 .21613 .62258 .2205 .62921 .21814 .6259 .21376 Mtetra
.6259 .21376 .62921 .21814 .63585 .21577 .63256 .21138 Mtetra
.63256 .21138 .63585 .21577 .64251 .21339 .63923 .20899 Mtetra
.63923 .20899 .64251 .21339 .64919 .21101 .64591 .2066 Mtetra
.64591 .2066 .64919 .21101 .65588 .20862 .65261 .2042 Mtetra
.65261 .2042 .65588 .20862 .66258 .20623 .65933 .2018 Mtetra
.65933 .2018 .66258 .20623 .66931 .20383 .66606 .19939 Mtetra
.66606 .19939 .66931 .20383 .67604 .20143 .67281 .19697 Mtetra
.67281 .19697 .67604 .20143 .6828 .19902 .67958 .19455 Mtetra
.67958 .19455 .6828 .19902 .68957 .1966 .68636 .19213 Mtetra
.68636 .19213 .68957 .1966 .69636 .19418 .69316 .18969 Mtetra
.69316 .18969 .69636 .19418 .70316 .19175 .69997 .18725 Mtetra
.69997 .18725 .70316 .19175 .70998 .18932 .7068 .18481 Mtetra
.7068 .18481 .70998 .18932 .71681 .18688 .71365 .18236 Mtetra
.71365 .18236 .71681 .18688 .72367 .18443 .72052 .17991 Mtetra
.72052 .17991 .72367 .18443 .73054 .18198 .7274 .17744 Mtetra
.7274 .17744 .73054 .18198 .73742 .17953 .73429 .17498 Mtetra
.73429 .17498 .73742 .17953 .74432 .17706 .74121 .1725 Mtetra
.74121 .1725 .74432 .17706 .75124 .1746 .74814 .17002 Mtetra
.74814 .17002 .75124 .1746 .75818 .17212 .75509 .16754 Mtetra
.75509 .16754 .75818 .17212 .76513 .16964 .76205 .16504 Mtetra
.76205 .16504 .76513 .16964 .7721 .16715 .76903 .16255 Mtetra
.76903 .16255 .7721 .16715 .77909 .16466 .77603 .16004 Mtetra
.77603 .16004 .77909 .16466 .78609 .16216 .78304 .15753 Mtetra
.78304 .15753 .78609 .16216 .79311 .15966 .79008 .15502 Mtetra
.16423 .37381 .1682 .37752 .17381 .37551 .16985 .3718 Mtetra
.16985 .3718 .17381 .37551 .17943 .3735 .17548 .36978 Mtetra
.17548 .36978 .17943 .3735 .18507 .37149 .18112 .36775 Mtetra
.18112 .36775 .18507 .37149 .19071 .36947 .18677 .36572 Mtetra
.18677 .36572 .19071 .36947 .19637 .36744 .19244 .36369 Mtetra
.19244 .36369 .19637 .36744 .20205 .36541 .19812 .36165 Mtetra
.19812 .36165 .20205 .36541 .20773 .36338 .20381 .35961 Mtetra
.20381 .35961 .20773 .36338 .21343 .36134 .20951 .35757 Mtetra
.20951 .35757 .21343 .36134 .21914 .3593 .21523 .35551 Mtetra
.21523 .35551 .21914 .3593 .22486 .35725 .22096 .35346 Mtetra
.22096 .35346 .22486 .35725 .23059 .3552 .2267 .3514 Mtetra
.2267 .3514 .23059 .3552 .23634 .35314 .23245 .34933 Mtetra
.23245 .34933 .23634 .35314 .2421 .35108 .23822 .34726 Mtetra
.23822 .34726 .2421 .35108 .24787 .34902 .244 .34519 Mtetra
.244 .34519 .24787 .34902 .25366 .34695 .24979 .34311 Mtetra
.24979 .34311 .25366 .34695 .25945 .34487 .2556 .34103 Mtetra
.2556 .34103 .25945 .34487 .26527 .34279 .26142 .33895 Mtetra
.26142 .33895 .26527 .34279 .27109 .34071 .26725 .33686 Mtetra
.663 .741 .908 r
.26725 .33686 .27109 .34071 .27693 .33863 .27309 .33477 Mtetra
.27309 .33477 .27693 .33863 .28278 .33655 .27895 .33268 Mtetra
.662 .741 .909 r
.27895 .33268 .28278 .33655 .28864 .33447 .28482 .33061 Mtetra
.66 .741 .91 r
.28482 .33061 .28864 .33447 .29451 .3324 .2907 .32855 Mtetra
.656 .741 .912 r
.2907 .32855 .29451 .3324 .30039 .33037 .29659 .32655 Mtetra
.649 .741 .917 r
.29659 .32655 .30039 .33037 .30629 .3284 .30248 .32466 Mtetra
.634 .741 .926 r
.30248 .32466 .30629 .3284 .31219 .32655 .30838 .32296 Mtetra
.597 .739 .944 r
.30838 .32296 .31219 .32655 .31808 .32495 .31426 .32169 Mtetra
.499 .723 .972 r
.31426 .32169 .31808 .32495 .32396 .32386 .3201 .32124 Mtetra
.162 .59 .935 r
.3201 .32124 .32396 .32386 .32979 .32375 .32586 .32241 Mtetra
.592 .02 0 r
.32586 .32241 .32979 .32375 .33553 .32556 .33146 .32668 Mtetra
.828 .402 .227 r
.33146 .32668 .33553 .32556 .34109 .33105 .33675 .33676 Mtetra
.85 .504 .397 r
.33675 .33676 .34109 .33105 .3463 .34326 .34151 .35686 Mtetra
.844 .532 .461 r
.34151 .35686 .3463 .34326 .35097 .36674 .34555 .39177 Mtetra
.826 .529 .487 r
.34555 .39177 .35097 .36674 .35493 .40571 .34896 .4413 Mtetra
.785 .495 .496 r
.34896 .4413 .35493 .40571 .35844 .45695 .35265 .4893 Mtetra
.656 .367 .469 r
.35265 .4893 .35844 .45695 .36261 .4992 .35822 .50408 Mtetra
.997 .826 .552 r
.35822 .50408 .36261 .4992 .36883 .50159 .36612 .47192 Mtetra
.843 .598 .569 r
.36612 .47192 .36883 .50159 .37703 .46068 .37499 .41684 Mtetra
.785 .543 .569 r
.37499 .41684 .37703 .46068 .38571 .40555 .3834 .36784 Mtetra
.755 .522 .58 r
.3834 .36784 .38571 .40555 .39378 .36089 .39095 .33515 Mtetra
.734 .521 .604 r
.39095 .33515 .39378 .36089 .40104 .33266 .39782 .31672 Mtetra
.705 .533 .653 r
.39782 .31672 .40104 .33266 .40773 .31763 .40426 .30815 Mtetra
.61 .541 .753 r
.40426 .30815 .40773 .31763 .41406 .31175 .41044 .30641 Mtetra
.059 .352 .826 r
.41044 .30641 .41406 .31175 .42017 .31252 .41644 .31013 Mtetra
.789 .294 0 r
.41644 .31013 .42017 .31252 .42612 .31893 .42232 .31895 Mtetra
.872 .45 .209 r
.42232 .31895 .42612 .31893 .43197 .33052 .42811 .33249 Mtetra
.872 .481 .294 r
.42811 .33249 .43197 .33052 .43778 .34614 .43389 .34902 Mtetra
.853 .459 .298 r
.43389 .34902 .43778 .34614 .44365 .36248 .4398 .36431 Mtetra
.769 .306 .148 r
.4398 .36431 .44365 .36248 .44973 .37387 .44597 .37228 Mtetra
.75 .917 .947 r
.44597 .37228 .44973 .37387 .45611 .3747 .45246 .36846 Mtetra
.883 .721 .676 r
.45246 .36846 .45611 .3747 .46275 .36347 .45919 .3535 Mtetra
.869 .668 .629 r
.45919 .3535 .46275 .36347 .46951 .34407 .466 .33263 Mtetra
.855 .65 .625 r
.466 .33263 .46951 .34407 .47625 .32254 .47275 .31158 Mtetra
.843 .647 .639 r
.47275 .31158 .47625 .32254 .4829 .30327 .47939 .29373 Mtetra
.83 .655 .666 r
.47939 .29373 .4829 .30327 .48944 .288 .48593 .27997 Mtetra
.814 .67 .704 r
.48593 .27997 .48944 .288 .49591 .2766 .4924 .26982 Mtetra
.795 .688 .747 r
.4924 .26982 .49591 .2766 .50234 .26826 .49883 .26238 Mtetra
.771 .706 .791 r
.49883 .26238 .50234 .26826 .50875 .26208 .50524 .25681 Mtetra
.745 .719 .828 r
.50524 .25681 .50875 .26208 .51515 .25734 .51165 .25246 Mtetra
.722 .728 .855 r
.51165 .25246 .51515 .25734 .52155 .25353 .51806 .24888 Mtetra
.703 .734 .874 r
.51806 .24888 .52155 .25353 .52796 .25029 .52449 .24579 Mtetra
.69 .737 .887 r
.52449 .24579 .52796 .25029 .53438 .24741 .53092 .243 Mtetra
.68 .739 .895 r
.53092 .243 .53438 .24741 .54082 .24476 .53737 .2404 Mtetra
.674 .74 .9 r
.53737 .2404 .54082 .24476 .54728 .24223 .54383 .2379 Mtetra
.67 .74 .903 r
.54383 .2379 .54728 .24223 .55374 .23978 .55031 .23546 Mtetra
.668 .74 .904 r
.55031 .23546 .55374 .23978 .56023 .23738 .5568 .23307 Mtetra
.666 .741 .906 r
.5568 .23307 .56023 .23738 .56672 .23501 .56331 .23069 Mtetra
.665 .741 .906 r
.56331 .23069 .56672 .23501 .57324 .23265 .56983 .22832 Mtetra
.665 .741 .907 r
.56983 .22832 .57324 .23265 .57977 .23029 .57637 .22596 Mtetra
.664 .741 .907 r
.57637 .22596 .57977 .23029 .58631 .22794 .58293 .2236 Mtetra
.58293 .2236 .58631 .22794 .59287 .22559 .5895 .22124 Mtetra
.5895 .22124 .59287 .22559 .59945 .22323 .59608 .21887 Mtetra
.59608 .21887 .59945 .22323 .60604 .22087 .60268 .2165 Mtetra
.60268 .2165 .60604 .22087 .61264 .2185 .6093 .21412 Mtetra
.6093 .21412 .61264 .2185 .61926 .21613 .61593 .21174 Mtetra
.61593 .21174 .61926 .21613 .6259 .21376 .62258 .20936 Mtetra
.62258 .20936 .6259 .21376 .63256 .21138 .62925 .20697 Mtetra
.62925 .20697 .63256 .21138 .63923 .20899 .63593 .20457 Mtetra
.63593 .20457 .63923 .20899 .64591 .2066 .64262 .20217 Mtetra
.64262 .20217 .64591 .2066 .65261 .2042 .64934 .19976 Mtetra
.64934 .19976 .65261 .2042 .65933 .2018 .65606 .19734 Mtetra
.65606 .19734 .65933 .2018 .66606 .19939 .66281 .19492 Mtetra
.66281 .19492 .66606 .19939 .67281 .19697 .66957 .1925 Mtetra
.66957 .1925 .67281 .19697 .67958 .19455 .67634 .19007 Mtetra
.67634 .19007 .67958 .19455 .68636 .19213 .68314 .18763 Mtetra
.68314 .18763 .68636 .19213 .69316 .18969 .68995 .18519 Mtetra
.68995 .18519 .69316 .18969 .69997 .18725 .69677 .18274 Mtetra
.69677 .18274 .69997 .18725 .7068 .18481 .70362 .18028 Mtetra
.70362 .18028 .7068 .18481 .71365 .18236 .71047 .17782 Mtetra
.71047 .17782 .71365 .18236 .72052 .17991 .71735 .17536 Mtetra
.71735 .17536 .72052 .17991 .7274 .17744 .72424 .17288 Mtetra
.72424 .17288 .7274 .17744 .73429 .17498 .73115 .1704 Mtetra
.73115 .1704 .73429 .17498 .74121 .1725 .73808 .16792 Mtetra
.73808 .16792 .74121 .1725 .74814 .17002 .74502 .16543 Mtetra
.74502 .16543 .74814 .17002 .75509 .16754 .75198 .16293 Mtetra
.75198 .16293 .75509 .16754 .76205 .16504 .75895 .16043 Mtetra
.75895 .16043 .76205 .16504 .76903 .16255 .76595 .15792 Mtetra
.76595 .15792 .76903 .16255 .77603 .16004 .77296 .1554 Mtetra
.77296 .1554 .77603 .16004 .78304 .15753 .77999 .15288 Mtetra
.77999 .15288 .78304 .15753 .79008 .15502 .78703 .15035 Mtetra
.16024 .37009 .16423 .37381 .16985 .3718 .16587 .36806 Mtetra
.16587 .36806 .16985 .3718 .17548 .36978 .1715 .36604 Mtetra
.1715 .36604 .17548 .36978 .18112 .36775 .17715 .364 Mtetra
.17715 .364 .18112 .36775 .18677 .36572 .18281 .36197 Mtetra
.18281 .36197 .18677 .36572 .19244 .36369 .18849 .35993 Mtetra
.18849 .35993 .19244 .36369 .19812 .36165 .19417 .35788 Mtetra
.19417 .35788 .19812 .36165 .20381 .35961 .19987 .35583 Mtetra
.19987 .35583 .20381 .35961 .20951 .35757 .20558 .35377 Mtetra
.20558 .35377 .20951 .35757 .21523 .35551 .21131 .35172 Mtetra
.21131 .35172 .21523 .35551 .22096 .35346 .21704 .34965 Mtetra
.21704 .34965 .22096 .35346 .2267 .3514 .22279 .34758 Mtetra
.22279 .34758 .2267 .3514 .23245 .34933 .22855 .34551 Mtetra
.22855 .34551 .23245 .34933 .23822 .34726 .23433 .34343 Mtetra
.23433 .34343 .23822 .34726 .244 .34519 .24012 .34135 Mtetra
.24012 .34135 .244 .34519 .24979 .34311 .24592 .33926 Mtetra
.24592 .33926 .24979 .34311 .2556 .34103 .25173 .33717 Mtetra
.25173 .33717 .2556 .34103 .26142 .33895 .25756 .33508 Mtetra
.663 .741 .908 r
.25756 .33508 .26142 .33895 .26725 .33686 .26339 .33299 Mtetra
.26339 .33299 .26725 .33686 .27309 .33477 .26925 .3309 Mtetra
.662 .741 .908 r
.26925 .3309 .27309 .33477 .27895 .33268 .27511 .32881 Mtetra
.661 .741 .909 r
.27511 .32881 .27895 .33268 .28482 .33061 .28098 .32674 Mtetra
.658 .741 .911 r
.28098 .32674 .28482 .33061 .2907 .32855 .28687 .32472 Mtetra
.652 .742 .915 r
.28687 .32472 .2907 .32855 .29659 .32655 .29276 .32277 Mtetra
.639 .741 .923 r
.29276 .32277 .29659 .32655 .30248 .32466 .29865 .321 Mtetra
.61 .74 .938 r
.29865 .321 .30248 .32466 .30838 .32296 .30454 .31958 Mtetra
.537 .731 .964 r
.30454 .31958 .30838 .32296 .31426 .32169 .31039 .31885 Mtetra
.298 .656 .971 r
.31039 .31885 .31426 .32169 .3201 .32124 .31617 .31947 Mtetra
.419 0 0 r
.31617 .31947 .3201 .32124 .32586 .32241 .3218 .32273 Mtetra
.806 .346 .143 r
.3218 .32273 .32586 .32241 .33146 .32668 .32716 .33095 Mtetra
.849 .488 .37 r
.32716 .33095 .33146 .32668 .33675 .33676 .33203 .34801 Mtetra
.846 .528 .45 r
.33203 .34801 .33675 .33676 .34151 .35686 .33617 .37885 Mtetra
.832 .532 .483 r
.33617 .37885 .34151 .35686 .34555 .39177 .33955 .42553 Mtetra
.799 .508 .496 r
.33955 .42553 .34555 .39177 .34896 .4413 .34286 .47694 Mtetra
.712 .422 .485 r
.34286 .47694 .34896 .4413 .35265 .4893 .34774 .50319 Mtetra
.685 .747 .247 r
.34774 .50319 .35265 .4893 .35822 .50408 .35518 .48177 Mtetra
.867 .625 .57 r
.35518 .48177 .35822 .50408 .36612 .47192 .36413 .42883 Mtetra
.796 .552 .568 r
.36413 .42883 .36612 .47192 .37499 .41684 .37288 .37614 Mtetra
.762 .525 .576 r
.37288 .37614 .37499 .41684 .3834 .36784 .38075 .33889 Mtetra
.741 .521 .595 r
.38075 .33889 .3834 .36784 .39095 .33515 .38783 .31689 Mtetra
.719 .531 .635 r
.38783 .31689 .39095 .33515 .39782 .31672 .3944 .30566 Mtetra
.666 .55 .713 r
.3944 .30566 .39782 .31672 .40426 .30815 .40067 .3016 Mtetra
.422 .518 .851 r
.40067 .3016 .40426 .30815 .41044 .30641 .40673 .30291 Mtetra
.545 .036 0 r
.40673 .30291 .41044 .30641 .41644 .31013 .41266 .30903 Mtetra
.85 .394 .102 r
.41266 .30903 .41644 .31013 .42232 .31895 .41846 .31996 Mtetra
.873 .47 .26 r
.41846 .31996 .42232 .31895 .42811 .33249 .4242 .33507 Mtetra
.866 .479 .307 r
.4242 .33507 .42811 .33249 .43389 .34902 .42998 .35183 Mtetra
.836 .431 .276 r
.42998 .35183 .43389 .34902 .4398 .36431 .43594 .36514 Mtetra
.599 .048 0 r
.43594 .36514 .4398 .36431 .44597 .37228 .44222 .369 Mtetra
.875 .815 .787 r
.44222 .369 .44597 .37228 .45246 .36846 .44884 .36061 Mtetra
.878 .694 .649 r
.44884 .36061 .45246 .36846 .45919 .3535 .45565 .3427 Mtetra
.863 .659 .624 r
.45565 .3427 .45919 .3535 .466 .33263 .46249 .32118 Mtetra
.85 .648 .628 r
.46249 .32118 .466 .33263 .47275 .31158 .46924 .30109 Mtetra
.838 .649 .648 r
.46924 .30109 .47275 .31158 .47939 .29373 .47587 .28476 Mtetra
.825 .66 .679 r
.47587 .28476 .47939 .29373 .48593 .27997 .4824 .27244 Mtetra
.808 .677 .72 r
.4824 .27244 .48593 .27997 .4924 .26982 .48887 .2634 Mtetra
.786 .695 .764 r
.48887 .2634 .4924 .26982 .49883 .26238 .49531 .25675 Mtetra
.761 .711 .806 r
.49531 .25675 .49883 .26238 .50524 .25681 .50173 .25169 Mtetra
.736 .723 .839 r
.50173 .25169 .50524 .25681 .51165 .25246 .50814 .24766 Mtetra
.714 .731 .863 r
.50814 .24766 .51165 .25246 .51806 .24888 .51456 .24429 Mtetra
.698 .735 .88 r
.51456 .24429 .51806 .24888 .52449 .24579 .521 .24132 Mtetra
.686 .738 .89 r
.521 .24132 .52449 .24579 .53092 .243 .52744 .2386 Mtetra
.678 .739 .897 r
.52744 .2386 .53092 .243 .53737 .2404 .5339 .23603 Mtetra
.672 .74 .901 r
.5339 .23603 .53737 .2404 .54383 .2379 .54037 .23355 Mtetra
.669 .74 .903 r
.54037 .23355 .54383 .2379 .55031 .23546 .54686 .23113 Mtetra
.667 .74 .905 r
.54686 .23113 .55031 .23546 .5568 .23307 .55336 .22873 Mtetra
.666 .741 .906 r
.55336 .22873 .5568 .23307 .56331 .23069 .55988 .22635 Mtetra
.665 .741 .906 r
.55988 .22635 .56331 .23069 .56983 .22832 .56641 .22398 Mtetra
.665 .741 .907 r
.56641 .22398 .56983 .22832 .57637 .22596 .57296 .22161 Mtetra
.664 .741 .907 r
.57296 .22161 .57637 .22596 .58293 .2236 .57953 .21924 Mtetra
.57953 .21924 .58293 .2236 .5895 .22124 .58611 .21687 Mtetra
.58611 .21687 .5895 .22124 .59608 .21887 .5927 .21449 Mtetra
.5927 .21449 .59608 .21887 .60268 .2165 .59932 .21211 Mtetra
.59932 .21211 .60268 .2165 .6093 .21412 .60594 .20973 Mtetra
.60594 .20973 .6093 .21412 .61593 .21174 .61259 .20734 Mtetra
.61259 .20734 .61593 .21174 .62258 .20936 .61925 .20494 Mtetra
.61925 .20494 .62258 .20936 .62925 .20697 .62592 .20254 Mtetra
.62592 .20254 .62925 .20697 .63593 .20457 .63261 .20013 Mtetra
.63261 .20013 .63593 .20457 .64262 .20217 .63932 .19772 Mtetra
.63932 .19772 .64262 .20217 .64934 .19976 .64604 .1953 Mtetra
.64604 .1953 .64934 .19976 .65606 .19734 .65278 .19287 Mtetra
.65278 .19287 .65606 .19734 .66281 .19492 .65954 .19044 Mtetra
.65954 .19044 .66281 .19492 .66957 .1925 .66631 .18801 Mtetra
.66631 .18801 .66957 .1925 .67634 .19007 .6731 .18556 Mtetra
.6731 .18556 .67634 .19007 .68314 .18763 .6799 .18312 Mtetra
.6799 .18312 .68314 .18763 .68995 .18519 .68672 .18066 Mtetra
.68672 .18066 .68995 .18519 .69677 .18274 .69356 .1782 Mtetra
.69356 .1782 .69677 .18274 .70362 .18028 .70041 .17574 Mtetra
.70041 .17574 .70362 .18028 .71047 .17782 .70728 .17326 Mtetra
.70728 .17326 .71047 .17782 .71735 .17536 .71417 .17079 Mtetra
.71417 .17079 .71735 .17536 .72424 .17288 .72107 .1683 Mtetra
.72107 .1683 .72424 .17288 .73115 .1704 .72799 .16581 Mtetra
.72799 .16581 .73115 .1704 .73808 .16792 .73493 .16332 Mtetra
.73493 .16332 .73808 .16792 .74502 .16543 .74189 .16081 Mtetra
.74189 .16081 .74502 .16543 .75198 .16293 .74886 .15831 Mtetra
.74886 .15831 .75198 .16293 .75895 .16043 .75584 .15579 Mtetra
.75584 .15579 .75895 .16043 .76595 .15792 .76285 .15327 Mtetra
.76285 .15327 .76595 .15792 .77296 .1554 .76987 .15074 Mtetra
.76987 .15074 .77296 .1554 .77999 .15288 .77691 .14821 Mtetra
.77691 .14821 .77999 .15288 .78703 .15035 .78397 .14567 Mtetra
.15624 .36635 .16024 .37009 .16587 .36806 .16187 .36432 Mtetra
.16187 .36432 .16587 .36806 .1715 .36604 .16751 .36228 Mtetra
.16751 .36228 .1715 .36604 .17715 .364 .17317 .36024 Mtetra
.17317 .36024 .17715 .364 .18281 .36197 .17884 .3582 Mtetra
.17884 .3582 .18281 .36197 .18849 .35993 .18452 .35615 Mtetra
.18452 .35615 .18849 .35993 .19417 .35788 .19021 .35409 Mtetra
.19021 .35409 .19417 .35788 .19987 .35583 .19592 .35203 Mtetra
.19592 .35203 .19987 .35583 .20558 .35377 .20163 .34997 Mtetra
.20163 .34997 .20558 .35377 .21131 .35172 .20737 .3479 Mtetra
.20737 .3479 .21131 .35172 .21704 .34965 .21311 .34583 Mtetra
.21311 .34583 .21704 .34965 .22279 .34758 .21887 .34375 Mtetra
.21887 .34375 .22279 .34758 .22855 .34551 .22464 .34167 Mtetra
.22464 .34167 .22855 .34551 .23433 .34343 .23042 .33958 Mtetra
.23042 .33958 .23433 .34343 .24012 .34135 .23621 .33749 Mtetra
.23621 .33749 .24012 .34135 .24592 .33926 .24202 .3354 Mtetra
.24202 .3354 .24592 .33926 .25173 .33717 .24784 .3333 Mtetra
.664 .741 .908 r
.24784 .3333 .25173 .33717 .25756 .33508 .25368 .3312 Mtetra
.663 .741 .908 r
.25368 .3312 .25756 .33508 .26339 .33299 .25952 .3291 Mtetra
.25952 .3291 .26339 .33299 .26925 .3309 .26538 .32701 Mtetra
.662 .741 .909 r
.26538 .32701 .26925 .3309 .27511 .32881 .27125 .32493 Mtetra
.659 .741 .911 r
.27125 .32493 .27511 .32881 .28098 .32674 .27713 .32288 Mtetra
.654 .741 .914 r
.27713 .32288 .28098 .32674 .28687 .32472 .28302 .32091 Mtetra
.644 .741 .92 r
.28302 .32091 .28687 .32472 .29276 .32277 .28891 .31907 Mtetra
.621 .741 .933 r
.28891 .31907 .29276 .32277 .29865 .321 .29479 .31752 Mtetra
.564 .736 .956 r
.29479 .31752 .29865 .321 .30454 .31958 .30065 .31655 Mtetra
.393 .693 .98 r
.30065 .31655 .30454 .31958 .31039 .31885 .30645 .31672 Mtetra
0 .352 .729 r
.30645 .31672 .31039 .31885 .31617 .31947 .31212 .31911 Mtetra
.766 .267 .028 r
.31212 .31911 .31617 .31947 .3218 .32273 .31753 .32575 Mtetra
.845 .467 .334 r
.31753 .32575 .3218 .32273 .32716 .33095 .32251 .34009 Mtetra
.848 .523 .436 r
.32251 .34009 .32716 .33095 .33203 .34801 .32677 .36701 Mtetra
.836 .534 .477 r
.32677 .36701 .33203 .34801 .33617 .37885 .33019 .41009 Mtetra
.81 .518 .494 r
.33019 .41009 .33617 .37885 .33955 .42553 .33323 .46276 Mtetra
.746 .457 .492 r
.33323 .46276 .33955 .42553 .34286 .47694 .33743 .49885 Mtetra
.264 0 .302 r
.33743 .49885 .34286 .47694 .34774 .50319 .34426 .48956 Mtetra
.899 .663 .573 r
.34426 .48956 .34774 .50319 .35518 .48177 .35314 .4411 Mtetra
.809 .563 .567 r
.35314 .4411 .35518 .48177 .36413 .42883 .36222 .3857 Mtetra
.769 .529 .572 r
.36222 .3857 .36413 .42883 .37288 .37614 .37044 .34386 Mtetra
.746 .52 .588 r
.37044 .34386 .37288 .37614 .38075 .33889 .37777 .31809 Mtetra
.728 .529 .621 r
.37777 .31809 .38075 .33889 .38783 .31689 .38449 .30414 Mtetra
.695 .549 .684 r
.38449 .30414 .38783 .31689 .3944 .30566 .39084 .29791 Mtetra
.577 .562 .801 r
.39084 .29791 .3944 .30566 .40067 .3016 .39698 .29705 Mtetra
0 .33 .813 r
.39698 .29705 .40067 .3016 .40673 .30291 .40296 .30074 Mtetra
.775 .272 0 r
.40296 .30074 .40673 .30291 .41266 .30903 .40881 .30896 Mtetra
.866 .438 .195 r
.40881 .30896 .41266 .30903 .41846 .31996 .41455 .32175 Mtetra
.872 .479 .29 r
.41455 .32175 .41846 .31996 .4242 .33507 .42025 .338 Mtetra
.858 .47 .308 r
.42025 .338 .4242 .33507 .42998 .35183 .42604 .35423 Mtetra
.807 .376 .223 r
.42604 .35423 .42998 .35183 .43594 .36514 .43209 .36464 Mtetra
.231 .743 .874 r
.43209 .36464 .43594 .36514 .44222 .369 .43851 .36395 Mtetra
.885 .749 .706 r
.43851 .36395 .44222 .369 .44884 .36061 .44524 .3514 Mtetra
.873 .677 .635 r
.44524 .3514 .44884 .36061 .45565 .3427 .45212 .33141 Mtetra
.858 .653 .624 r
.45212 .33141 .45565 .3427 .46249 .32118 .45897 .30996 Mtetra
.846 .647 .634 r
.45897 .30996 .46249 .32118 .46924 .30109 .46572 .29113 Mtetra
.833 .653 .658 r
.46572 .29113 .46924 .30109 .47587 .28476 .47234 .27634 Mtetra
.819 .666 .693 r
.47234 .27634 .47587 .28476 .4824 .27244 .47886 .26535 Mtetra
.8 .684 .736 r
.47886 .26535 .4824 .27244 .48887 .2634 .48533 .2573 Mtetra
.777 .702 .78 r
.48533 .2573 .48887 .2634 .49531 .25675 .49177 .25131 Mtetra
.752 .716 .819 r
.49177 .25131 .49531 .25675 .50173 .25169 .49819 .24669 Mtetra
.727 .726 .849 r
.49819 .24669 .50173 .25169 .50814 .24766 .50462 .24294 Mtetra
.708 .733 .87 r
.50462 .24294 .50814 .24766 .51456 .24429 .51105 .23973 Mtetra
.693 .736 .884 r
.51105 .23973 .51456 .24429 .521 .24132 .51749 .23686 Mtetra
.682 .738 .893 r
.51749 .23686 .521 .24132 .52744 .2386 .52394 .2342 Mtetra
.675 .739 .899 r
.52394 .2342 .52744 .2386 .5339 .23603 .53041 .23166 Mtetra
.671 .74 .902 r
.53041 .23166 .5339 .23603 .54037 .23355 .5369 .2292 Mtetra
.668 .74 .904 r
.5369 .2292 .54037 .23355 .54686 .23113 .54339 .22678 Mtetra
.667 .741 .905 r
.54339 .22678 .54686 .23113 .55336 .22873 .54991 .22438 Mtetra
.666 .741 .906 r
.54991 .22438 .55336 .22873 .55988 .22635 .55644 .222 Mtetra
.665 .741 .907 r
.55644 .222 .55988 .22635 .56641 .22398 .56298 .21962 Mtetra
.56298 .21962 .56641 .22398 .57296 .22161 .56954 .21724 Mtetra
.664 .741 .907 r
.56954 .21724 .57296 .22161 .57953 .21924 .57611 .21486 Mtetra
.57611 .21486 .57953 .21924 .58611 .21687 .58271 .21248 Mtetra
.58271 .21248 .58611 .21687 .5927 .21449 .58931 .2101 Mtetra
.58931 .2101 .5927 .21449 .59932 .21211 .59593 .2077 Mtetra
.59593 .2077 .59932 .21211 .60594 .20973 .60257 .20531 Mtetra
.60257 .20531 .60594 .20973 .61259 .20734 .60923 .20291 Mtetra
.60923 .20291 .61259 .20734 .61925 .20494 .6159 .2005 Mtetra
.6159 .2005 .61925 .20494 .62592 .20254 .62258 .19809 Mtetra
.62258 .19809 .62592 .20254 .63261 .20013 .62928 .19567 Mtetra
.62928 .19567 .63261 .20013 .63932 .19772 .636 .19325 Mtetra
.636 .19325 .63932 .19772 .64604 .1953 .64274 .19082 Mtetra
.64274 .19082 .64604 .1953 .65278 .19287 .64949 .18838 Mtetra
.64949 .18838 .65278 .19287 .65954 .19044 .65625 .18594 Mtetra
.65625 .18594 .65954 .19044 .66631 .18801 .66304 .18349 Mtetra
.66304 .18349 .66631 .18801 .6731 .18556 .66983 .18104 Mtetra
.66983 .18104 .6731 .18556 .6799 .18312 .67665 .17858 Mtetra
.67665 .17858 .6799 .18312 .68672 .18066 .68348 .17612 Mtetra
.68348 .17612 .68672 .18066 .69356 .1782 .69033 .17364 Mtetra
.69033 .17364 .69356 .1782 .70041 .17574 .6972 .17117 Mtetra
.6972 .17117 .70041 .17574 .70728 .17326 .70408 .16868 Mtetra
.70408 .16868 .70728 .17326 .71417 .17079 .71098 .1662 Mtetra
.71098 .1662 .71417 .17079 .72107 .1683 .71789 .1637 Mtetra
.71789 .1637 .72107 .1683 .72799 .16581 .72482 .1612 Mtetra
.72482 .1612 .72799 .16581 .73493 .16332 .73177 .15869 Mtetra
.73177 .15869 .73493 .16332 .74189 .16081 .73874 .15618 Mtetra
.73874 .15618 .74189 .16081 .74886 .15831 .74572 .15366 Mtetra
.74572 .15366 .74886 .15831 .75584 .15579 .75272 .15113 Mtetra
.75272 .15113 .75584 .15579 .76285 .15327 .75974 .1486 Mtetra
.75974 .1486 .76285 .15327 .76987 .15074 .76677 .14606 Mtetra
.76677 .14606 .76987 .15074 .77691 .14821 .77382 .14352 Mtetra
.77382 .14352 .77691 .14821 .78397 .14567 .78089 .14097 Mtetra
.15222 .36259 .15624 .36635 .16187 .36432 .15786 .36055 Mtetra
.15786 .36055 .16187 .36432 .16751 .36228 .16351 .35851 Mtetra
.16351 .35851 .16751 .36228 .17317 .36024 .16917 .35646 Mtetra
.16917 .35646 .17317 .36024 .17884 .3582 .17484 .35441 Mtetra
.17484 .35441 .17884 .3582 .18452 .35615 .18053 .35235 Mtetra
.18053 .35235 .18452 .35615 .19021 .35409 .18623 .35029 Mtetra
.18623 .35029 .19021 .35409 .19592 .35203 .19195 .34822 Mtetra
.19195 .34822 .19592 .35203 .20163 .34997 .19767 .34615 Mtetra
.19767 .34615 .20163 .34997 .20737 .3479 .20341 .34407 Mtetra
.20341 .34407 .20737 .3479 .21311 .34583 .20916 .34199 Mtetra
.20916 .34199 .21311 .34583 .21887 .34375 .21493 .33991 Mtetra
.21493 .33991 .21887 .34375 .22464 .34167 .2207 .33782 Mtetra
.2207 .33782 .22464 .34167 .23042 .33958 .22649 .33572 Mtetra
.22649 .33572 .23042 .33958 .23621 .33749 .2323 .33362 Mtetra
.2323 .33362 .23621 .33749 .24202 .3354 .23811 .33152 Mtetra
.663 .741 .907 r
.23811 .33152 .24202 .3354 .24784 .3333 .24394 .32942 Mtetra
.663 .741 .908 r
.24394 .32942 .24784 .3333 .25368 .3312 .24978 .32731 Mtetra
.24978 .32731 .25368 .3312 .25952 .3291 .25563 .32521 Mtetra
.662 .741 .909 r
.25563 .32521 .25952 .3291 .26538 .32701 .2615 .32312 Mtetra
.66 .741 .91 r
.2615 .32312 .26538 .32701 .27125 .32493 .26737 .32106 Mtetra
.656 .741 .913 r
.26737 .32106 .27125 .32493 .27713 .32288 .27326 .31905 Mtetra
.647 .742 .918 r
.27326 .31905 .27713 .32288 .28302 .32091 .27915 .31716 Mtetra
.629 .741 .928 r
.27915 .31716 .28302 .32091 .28891 .31907 .28503 .31551 Mtetra
.585 .738 .949 r
.28503 .31551 .28891 .31907 .29479 .31752 .2909 .31434 Mtetra
.46 .714 .978 r
.2909 .31434 .29479 .31752 .30065 .31655 .29671 .31413 Mtetra
.011 .503 .869 r
.29671 .31413 .30065 .31655 .30645 .31672 .3024 .31579 Mtetra
.696 .155 0 r
.3024 .31579 .30645 .31672 .31212 .31911 .30788 .32106 Mtetra
.839 .439 .287 r
.30788 .32106 .31212 .31911 .31753 .32575 .31295 .33301 Mtetra
.849 .515 .419 r
.31295 .33301 .31753 .32575 .32251 .34009 .31734 .35627 Mtetra
.84 .534 .47 r
.31734 .35627 .32251 .34009 .32677 .36701 .32085 .39533 Mtetra
.819 .525 .492 r
.32085 .39533 .32677 .36701 .33019 .41009 .32372 .44742 Mtetra
.769 .48 .496 r
.32372 .44742 .33019 .41009 .33323 .46276 .3273 .49126 Mtetra
.556 .267 .431 r
.3273 .49126 .33323 .46276 .33743 .49885 .33341 .49468 Mtetra
.944 .724 .575 r
.33341 .49468 .33743 .49885 .34426 .48956 .34206 .45314 Mtetra
.824 .578 .568 r
.34206 .45314 .34426 .48956 .35314 .4411 .3514 .39638 Mtetra
.776 .535 .57 r
.3514 .39638 .35314 .4411 .36222 .3857 .35999 .35008 Mtetra
.751 .521 .583 r
.35999 .35008 .36222 .3857 .37044 .34386 .36761 .32031 Mtetra
.735 .526 .61 r
.36761 .32031 .37044 .34386 .37777 .31809 .37451 .3035 Mtetra
.712 .546 .662 r
.37451 .3035 .37777 .31809 .38449 .30414 .38097 .29515 Mtetra
.648 .572 .756 r
.38097 .29515 .38449 .30414 .39084 .29791 .38718 .29237 Mtetra
.357 .527 .887 r
.38718 .29237 .39084 .29791 .39698 .29705 .39322 .29391 Mtetra
.545 .019 0 r
.39322 .29391 .39698 .29705 .40296 .30074 .39912 .29961 Mtetra
.837 .371 .077 r
.39912 .29961 .40296 .30074 .40881 .30896 .4049 .30975 Mtetra
.871 .462 .248 r
.4049 .30975 .40881 .30896 .41455 .32175 .41058 .32417 Mtetra
.868 .481 .306 r
.41058 .32417 .41455 .32175 .42025 .338 .41626 .34102 Mtetra
.847 .452 .296 r
.41626 .34102 .42025 .338 .42604 .35423 .4221 .35583 Mtetra
.736 .252 .094 r
.4221 .35583 .42604 .35423 .43209 .36464 .42826 .36253 Mtetra
.825 .887 .887 r
.42826 .36253 .43209 .36464 .43851 .36395 .43482 .35717 Mtetra
.882 .711 .666 r
.43482 .35717 .43851 .36395 .44524 .3514 .44167 .34112 Mtetra
.867 .665 .627 r
.44167 .34112 .44524 .3514 .45212 .33141 .4486 .31993 Mtetra
.854 .65 .626 r
.4486 .31993 .45212 .33141 .45897 .30996 .45545 .29913 Mtetra
.841 .648 .642 r
.45545 .29913 .45897 .30996 .46572 .29113 .46218 .28175 Mtetra
.828 .657 .67 r
.46218 .28175 .46572 .29113 .47234 .27634 .46879 .26845 Mtetra
.812 .672 .709 r
.46879 .26845 .47234 .27634 .47886 .26535 .47531 .25866 Mtetra
.792 .691 .753 r
.47531 .25866 .47886 .26535 .48533 .2573 .48177 .25147 Mtetra
.767 .708 .796 r
.48177 .25147 .48533 .2573 .49177 .25131 .48821 .24606 Mtetra
.742 .721 .832 r
.48821 .24606 .49177 .25131 .49819 .24669 .49465 .2418 Mtetra
.719 .729 .858 r
.49465 .2418 .49819 .24669 .50462 .24294 .50108 .23827 Mtetra
.701 .734 .876 r
.50108 .23827 .50462 .24294 .51105 .23973 .50752 .2352 Mtetra
.688 .737 .888 r
.50752 .2352 .51105 .23973 .51749 .23686 .51397 .23242 Mtetra
.679 .739 .896 r
.51397 .23242 .51749 .23686 .52394 .2342 .52043 .2298 Mtetra
.674 .74 .9 r
.52043 .2298 .52394 .2342 .53041 .23166 .52691 .22729 Mtetra
.67 .74 .903 r
.52691 .22729 .53041 .23166 .5369 .2292 .53341 .22483 Mtetra
.668 .74 .905 r
.53341 .22483 .5369 .2292 .54339 .22678 .53991 .22242 Mtetra
.666 .741 .906 r
.53991 .22242 .54339 .22678 .54991 .22438 .54644 .22002 Mtetra
.665 .741 .906 r
.54644 .22002 .54991 .22438 .55644 .222 .55298 .21763 Mtetra
.665 .741 .907 r
.55298 .21763 .55644 .222 .56298 .21962 .55953 .21524 Mtetra
.664 .741 .907 r
.55953 .21524 .56298 .21962 .56954 .21724 .5661 .21286 Mtetra
.5661 .21286 .56954 .21724 .57611 .21486 .57269 .21047 Mtetra
.57269 .21047 .57611 .21486 .58271 .21248 .57929 .20808 Mtetra
.57929 .20808 .58271 .21248 .58931 .2101 .5859 .20568 Mtetra
.5859 .20568 .58931 .2101 .59593 .2077 .59254 .20328 Mtetra
.59254 .20328 .59593 .2077 .60257 .20531 .59919 .20087 Mtetra
.59919 .20087 .60257 .20531 .60923 .20291 .60585 .19846 Mtetra
.60585 .19846 .60923 .20291 .6159 .2005 .61253 .19604 Mtetra
.61253 .19604 .6159 .2005 .62258 .19809 .61923 .19362 Mtetra
.61923 .19362 .62258 .19809 .62928 .19567 .62594 .19119 Mtetra
.62594 .19119 .62928 .19567 .636 .19325 .63267 .18876 Mtetra
.63267 .18876 .636 .19325 .64274 .19082 .63941 .18632 Mtetra
.63941 .18632 .64274 .19082 .64949 .18838 .64618 .18387 Mtetra
.64618 .18387 .64949 .18838 .65625 .18594 .65295 .18142 Mtetra
.65295 .18142 .65625 .18594 .66304 .18349 .65975 .17896 Mtetra
.65975 .17896 .66304 .18349 .66983 .18104 .66656 .17649 Mtetra
.66656 .17649 .66983 .18104 .67665 .17858 .67338 .17402 Mtetra
.67338 .17402 .67665 .17858 .68348 .17612 .68023 .17155 Mtetra
.68023 .17155 .68348 .17612 .69033 .17364 .68709 .16907 Mtetra
.68709 .16907 .69033 .17364 .6972 .17117 .69396 .16658 Mtetra
.69396 .16658 .6972 .17117 .70408 .16868 .70086 .16408 Mtetra
.70086 .16408 .70408 .16868 .71098 .1662 .70777 .16158 Mtetra
.70777 .16158 .71098 .1662 .71789 .1637 .71469 .15908 Mtetra
.71469 .15908 .71789 .1637 .72482 .1612 .72164 .15657 Mtetra
.72164 .15657 .72482 .1612 .73177 .15869 .7286 .15405 Mtetra
.7286 .15405 .73177 .15869 .73874 .15618 .73558 .15152 Mtetra
.73558 .15152 .73874 .15618 .74572 .15366 .74257 .14899 Mtetra
.74257 .14899 .74572 .15366 .75272 .15113 .74958 .14645 Mtetra
.74958 .14645 .75272 .15113 .75974 .1486 .75661 .14391 Mtetra
.75661 .14391 .75974 .1486 .76677 .14606 .76366 .14136 Mtetra
.76366 .14136 .76677 .14606 .77382 .14352 .77072 .13881 Mtetra
.77072 .13881 .77382 .14352 .78089 .14097 .7778 .13624 Mtetra
.14818 .35883 .15222 .36259 .15786 .36055 .15383 .35678 Mtetra
.15383 .35678 .15786 .36055 .16351 .35851 .15948 .35472 Mtetra
.15948 .35472 .16351 .35851 .16917 .35646 .16515 .35267 Mtetra
.16515 .35267 .16917 .35646 .17484 .35441 .17084 .3506 Mtetra
.17084 .3506 .17484 .35441 .18053 .35235 .17653 .34854 Mtetra
.17653 .34854 .18053 .35235 .18623 .35029 .18224 .34647 Mtetra
.18224 .34647 .18623 .35029 .19195 .34822 .18796 .34439 Mtetra
.18796 .34439 .19195 .34822 .19767 .34615 .19369 .34231 Mtetra
.19369 .34231 .19767 .34615 .20341 .34407 .19944 .34023 Mtetra
.19944 .34023 .20341 .34407 .20916 .34199 .2052 .33814 Mtetra
.2052 .33814 .20916 .34199 .21493 .33991 .21097 .33604 Mtetra
.21097 .33604 .21493 .33991 .2207 .33782 .21675 .33394 Mtetra
.21675 .33394 .2207 .33782 .22649 .33572 .22255 .33184 Mtetra
.22255 .33184 .22649 .33572 .2323 .33362 .22836 .32974 Mtetra
.22836 .32974 .2323 .33362 .23811 .33152 .23418 .32762 Mtetra
.663 .741 .908 r
.23418 .32762 .23811 .33152 .24394 .32942 .24002 .32551 Mtetra
.24002 .32551 .24394 .32942 .24978 .32731 .24587 .32341 Mtetra
.662 .741 .908 r
.24587 .32341 .24978 .32731 .25563 .32521 .25173 .32131 Mtetra
.661 .741 .91 r
.25173 .32131 .25563 .32521 .2615 .32312 .2576 .31923 Mtetra
.657 .741 .912 r
.2576 .31923 .2615 .32312 .26737 .32106 .26348 .3172 Mtetra
.65 .741 .916 r
.26348 .3172 .26737 .32106 .27326 .31905 .26937 .31526 Mtetra
.635 .742 .925 r
.26937 .31526 .27326 .31905 .27915 .31716 .27525 .31352 Mtetra
.601 .74 .942 r
.27525 .31352 .27915 .31716 .28503 .31551 .28112 .31219 Mtetra
.508 .726 .971 r
.28112 .31219 .28503 .31551 .2909 .31434 .28694 .31166 Mtetra
.185 .603 .943 r
.28694 .31166 .2909 .31434 .29671 .31413 .29266 .31271 Mtetra
.577 .002 0 r
.29266 .31271 .29671 .31413 .3024 .31579 .29819 .31682 Mtetra
.826 .399 .224 r
.29819 .31682 .3024 .31579 .30788 .32106 .30335 .32668 Mtetra
.849 .503 .398 r
.30335 .32668 .30788 .32106 .31295 .33301 .30788 .34658 Mtetra
.843 .532 .462 r
.30788 .34658 .31295 .33301 .31734 .35627 .31151 .38147 Mtetra
.826 .53 .488 r
.31151 .38147 .31734 .35627 .32085 .39533 .31431 .43154 Mtetra
.787 .497 .497 r
.31431 .43154 .32085 .39533 .32372 .44742 .31738 .48079 Mtetra
.661 .37 .469 r
.31738 .48079 .32372 .44742 .3273 .49126 .32268 .4967 Mtetra
.997 .829 .554 r
.32268 .4967 .3273 .49126 .33341 .49468 .33092 .46434 Mtetra
.843 .598 .569 r
.33092 .46434 .33341 .49468 .34206 .45314 .34042 .40797 Mtetra
.785 .542 .568 r
.34042 .40797 .34206 .45314 .3514 .39638 .34941 .35755 Mtetra
.756 .522 .578 r
.34941 .35755 .3514 .39638 .35999 .35008 .35735 .32356 Mtetra
.74 .523 .601 r
.35735 .32356 .35999 .35008 .36761 .32031 .36446 .3037 Mtetra
.723 .541 .644 r
.36446 .3037 .36761 .32031 .37451 .3035 .37105 .2932 Mtetra
.684 .571 .721 r
.37105 .2932 .37451 .3035 .38097 .29515 .37734 .28865 Mtetra
.542 .585 .847 r
.37734 .28865 .38097 .29515 .38718 .29237 .38344 .28834 Mtetra
0 .331 .805 r
.38344 .28834 .38718 .29237 .39322 .29391 .3894 .29181 Mtetra
.751 .236 0 r
.3894 .29181 .39322 .29391 .39912 .29961 .39522 .29935 Mtetra
.858 .421 .172 r
.39522 .29935 .39912 .29961 .4049 .30975 .40093 .31129 Mtetra
.871 .475 .281 r
.40093 .31129 .4049 .30975 .41058 .32417 .40656 .32702 Mtetra
.863 .477 .312 r
.40656 .32702 .41058 .32417 .41626 .34102 .41224 .3438 Mtetra
.828 .417 .265 r
.41224 .3438 .41626 .34102 .4221 .35583 .41816 .35629 Mtetra
.448 0 0 r
.41816 .35629 .4221 .35583 .42826 .36253 .42447 .35868 Mtetra
.882 .789 .754 r
.42447 .35868 .42826 .36253 .43482 .35717 .43118 .34883 Mtetra
.877 .688 .644 r
.43118 .34883 .43482 .35717 .44167 .34112 .43811 .33011 Mtetra
.862 .657 .624 r
.43811 .33011 .44167 .34112 .4486 .31993 .44507 .30851 Mtetra
.849 .648 .63 r
.44507 .30851 .4486 .31993 .45545 .29913 .45192 .28878 Mtetra
.837 .651 .651 r
.45192 .28878 .45545 .29913 .46218 .28175 .45863 .27293 Mtetra
.823 .662 .684 r
.45863 .27293 .46218 .28175 .46879 .26845 .46522 .26104 Mtetra
.805 .679 .725 r
.46522 .26104 .46879 .26845 .47531 .25866 .47173 .25232 Mtetra
.783 .698 .77 r
.47173 .25232 .47531 .25866 .48177 .25147 .4782 .24587 Mtetra
.758 .713 .81 r
.4782 .24587 .48177 .25147 .48821 .24606 .48465 .24094 Mtetra
.733 .724 .843 r
.48465 .24094 .48821 .24606 .49465 .2418 .49108 .23699 Mtetra
.712 .731 .866 r
.49108 .23699 .49465 .2418 .50108 .23827 .49753 .23365 Mtetra
.696 .736 .881 r
.49753 .23365 .50108 .23827 .50752 .2352 .50397 .2307 Mtetra
.684 .738 .891 r
.50397 .2307 .50752 .2352 .51397 .23242 .51044 .22798 Mtetra
.677 .739 .898 r
.51044 .22798 .51397 .23242 .52043 .2298 .51691 .2254 Mtetra
.672 .74 .901 r
.51691 .2254 .52043 .2298 .52691 .22729 .5234 .2229 Mtetra
.669 .74 .904 r
.5234 .2229 .52691 .22729 .53341 .22483 .5299 .22046 Mtetra
.667 .74 .905 r
.5299 .22046 .53341 .22483 .53991 .22242 .53642 .21804 Mtetra
.666 .741 .906 r
.53642 .21804 .53991 .22242 .54644 .22002 .54295 .21564 Mtetra
.665 .741 .906 r
.54295 .21564 .54644 .22002 .55298 .21763 .5495 .21324 Mtetra
.665 .741 .907 r
.5495 .21324 .55298 .21763 .55953 .21524 .55607 .21084 Mtetra
.664 .741 .907 r
.55607 .21084 .55953 .21524 .5661 .21286 .56265 .20845 Mtetra
.56265 .20845 .5661 .21286 .57269 .21047 .56924 .20605 Mtetra
.56924 .20605 .57269 .21047 .57929 .20808 .57585 .20365 Mtetra
.57585 .20365 .57929 .20808 .5859 .20568 .58248 .20124 Mtetra
.58248 .20124 .5859 .20568 .59254 .20328 .58913 .19883 Mtetra
.58913 .19883 .59254 .20328 .59919 .20087 .59578 .19642 Mtetra
.59578 .19642 .59919 .20087 .60585 .19846 .60246 .19399 Mtetra
.60246 .19399 .60585 .19846 .61253 .19604 .60915 .19156 Mtetra
.60915 .19156 .61253 .19604 .61923 .19362 .61586 .18913 Mtetra
.61586 .18913 .61923 .19362 .62594 .19119 .62258 .18669 Mtetra
.62258 .18669 .62594 .19119 .63267 .18876 .62932 .18425 Mtetra
.62932 .18425 .63267 .18876 .63941 .18632 .63608 .18179 Mtetra
.63608 .18179 .63941 .18632 .64618 .18387 .64285 .17934 Mtetra
.64285 .17934 .64618 .18387 .65295 .18142 .64964 .17687 Mtetra
.64964 .17687 .65295 .18142 .65975 .17896 .65644 .17441 Mtetra
.65644 .17441 .65975 .17896 .66656 .17649 .66327 .17193 Mtetra
.66327 .17193 .66656 .17649 .67338 .17402 .6701 .16945 Mtetra
.6701 .16945 .67338 .17402 .68023 .17155 .67696 .16696 Mtetra
.67696 .16696 .68023 .17155 .68709 .16907 .68383 .16447 Mtetra
.68383 .16447 .68709 .16907 .69396 .16658 .69072 .16197 Mtetra
.69072 .16197 .69396 .16658 .70086 .16408 .69762 .15946 Mtetra
.69762 .15946 .70086 .16408 .70777 .16158 .70454 .15695 Mtetra
.70454 .15695 .70777 .16158 .71469 .15908 .71148 .15443 Mtetra
.71148 .15443 .71469 .15908 .72164 .15657 .71844 .15191 Mtetra
.71844 .15191 .72164 .15657 .7286 .15405 .72541 .14938 Mtetra
.72541 .14938 .7286 .15405 .73558 .15152 .7324 .14684 Mtetra
.7324 .14684 .73558 .15152 .74257 .14899 .73941 .1443 Mtetra
.73941 .1443 .74257 .14899 .74958 .14645 .74643 .14175 Mtetra
.74643 .14175 .74958 .14645 .75661 .14391 .75347 .1392 Mtetra
.75347 .1392 .75661 .14391 .76366 .14136 .76053 .13664 Mtetra
.76053 .13664 .76366 .14136 .77072 .13881 .76761 .13407 Mtetra
.76761 .13407 .77072 .13881 .7778 .13624 .7747 .1315 Mtetra
.14413 .35504 .14818 .35883 .15383 .35678 .14978 .35298 Mtetra
.14978 .35298 .15383 .35678 .15948 .35472 .15545 .35092 Mtetra
.15545 .35092 .15948 .35472 .16515 .35267 .16112 .34886 Mtetra
.16112 .34886 .16515 .35267 .17084 .3506 .16681 .34679 Mtetra
.16681 .34679 .17084 .3506 .17653 .34854 .17251 .34471 Mtetra
.17251 .34471 .17653 .34854 .18224 .34647 .17823 .34263 Mtetra
.17823 .34263 .18224 .34647 .18796 .34439 .18396 .34055 Mtetra
.18396 .34055 .18796 .34439 .19369 .34231 .1897 .33846 Mtetra
.1897 .33846 .19369 .34231 .19944 .34023 .19545 .33637 Mtetra
.19545 .33637 .19944 .34023 .2052 .33814 .20122 .33427 Mtetra
.20122 .33427 .2052 .33814 .21097 .33604 .207 .33216 Mtetra
.207 .33216 .21097 .33604 .21675 .33394 .21279 .33006 Mtetra
.21279 .33006 .21675 .33394 .22255 .33184 .21859 .32795 Mtetra
.21859 .32795 .22255 .33184 .22836 .32974 .22441 .32583 Mtetra
.663 .741 .908 r
.22441 .32583 .22836 .32974 .23418 .32762 .23024 .32372 Mtetra
.23024 .32372 .23418 .32762 .24002 .32551 .23608 .3216 Mtetra
.23608 .3216 .24002 .32551 .24587 .32341 .24194 .31949 Mtetra
.661 .741 .909 r
.24194 .31949 .24587 .32341 .25173 .32131 .24781 .3174 Mtetra
.658 .741 .911 r
.24781 .3174 .25173 .32131 .2576 .31923 .25368 .31535 Mtetra
.653 .742 .915 r
.25368 .31535 .2576 .31923 .26348 .3172 .25956 .31337 Mtetra
.641 .742 .922 r
.25956 .31337 .26348 .3172 .26937 .31526 .26545 .31156 Mtetra
.613 .741 .937 r
.26545 .31156 .26937 .31526 .27525 .31352 .27132 .31009 Mtetra
.542 .733 .963 r
.27132 .31009 .27525 .31352 .28112 .31219 .27715 .30929 Mtetra
.313 .663 .973 r
.27715 .30929 .28112 .31219 .28694 .31166 .2829 .30982 Mtetra
.401 0 0 r
.2829 .30982 .28694 .31166 .29266 .31271 .28847 .31295 Mtetra
.804 .342 .139 r
.28847 .31295 .29266 .31271 .29819 .31682 .29371 .32101 Mtetra
.848 .488 .37 r
.29371 .32101 .29819 .31682 .30335 .32668 .29838 .33788 Mtetra
.846 .529 .451 r
.29838 .33788 .30335 .32668 .30788 .34658 .30216 .36865 Mtetra
.832 .533 .484 r
.30216 .36865 .30788 .34658 .31151 .38147 .30497 .41565 Mtetra
.8 .509 .496 r
.30497 .41565 .31151 .38147 .31431 .43154 .30764 .46799 Mtetra
.714 .424 .485 r
.30764 .46799 .31431 .43154 .31738 .48079 .31212 .49534 Mtetra
.672 .743 .244 r
.31212 .49534 .31738 .48079 .32268 .4967 .31976 .47405 Mtetra
.866 .624 .571 r
.31976 .47405 .32268 .4967 .33092 .46434 .32931 .42016 Mtetra
.796 .551 .567 r
.32931 .42016 .33092 .46434 .34042 .40797 .33868 .36624 Mtetra
.762 .525 .574 r
.33868 .36624 .34042 .40797 .34941 .35755 .34698 .32787 Mtetra
.744 .522 .593 r
.34698 .32787 .34941 .35755 .35735 .32356 .35433 .30471 Mtetra
.73 .536 .63 r
.35433 .30471 .35735 .32356 .36446 .3037 .36106 .29199 Mtetra
.705 .565 .694 r
.36106 .29199 .36446 .3037 .37105 .2932 .36744 .28574 Mtetra
.627 .597 .8 r
.36744 .28574 .37105 .2932 .37734 .28865 .37361 .2838 Mtetra
.309 .539 .911 r
.37361 .2838 .37734 .28865 .38344 .28834 .37963 .28538 Mtetra
.514 0 0 r
.37963 .28538 .38344 .28834 .3894 .29181 .38551 .29057 Mtetra
.821 .342 .039 r
.38551 .29057 .3894 .29181 .39522 .29935 .39126 .29987 Mtetra
.867 .45 .23 r
.39126 .29987 .39522 .29935 .40093 .31129 .3969 .31345 Mtetra
.87 .481 .301 r
.3969 .31345 .40093 .31129 .40656 .32702 .4025 .33009 Mtetra
.854 .466 .308 r
.4025 .33009 .40656 .32702 .41224 .3438 .40821 .34601 Mtetra
.79 .347 .195 r
.40821 .34601 .41224 .3438 .41816 .35629 .41425 .35529 Mtetra
.567 .903 .978 r
.41425 .35529 .41816 .35629 .42447 .35868 .42072 .35303 Mtetra
.885 .735 .69 r
.42072 .35303 .42447 .35868 .43118 .34883 .42756 .33921 Mtetra
.871 .673 .632 r
.42756 .33921 .43118 .34883 .43811 .33011 .43457 .31869 Mtetra
.857 .652 .624 r
.43457 .31869 .43811 .33011 .44507 .30851 .44154 .29737 Mtetra
.845 .648 .636 r
.44154 .29737 .44507 .30851 .45192 .28878 .44837 .27897 Mtetra
.832 .654 .662 r
.44837 .27897 .45192 .28878 .45863 .27293 .45506 .26466 Mtetra
.817 .668 .699 r
.45506 .26466 .45863 .27293 .46522 .26104 .46164 .25405 Mtetra
.797 .686 .742 r
.46164 .25405 .46522 .26104 .47173 .25232 .46815 .24627 Mtetra
.774 .704 .786 r
.46815 .24627 .47173 .25232 .4782 .24587 .47461 .24046 Mtetra
.748 .718 .824 r
.47461 .24046 .4782 .24587 .48465 .24094 .48106 .23594 Mtetra
.725 .728 .853 r
.48106 .23594 .48465 .24094 .49108 .23699 .48751 .23225 Mtetra
.705 .733 .873 r
.48751 .23225 .49108 .23699 .49753 .23365 .49396 .22907 Mtetra
.691 .737 .886 r
.49396 .22907 .49753 .23365 .50397 .2307 .50042 .2262 Mtetra
.681 .738 .894 r
.50042 .2262 .50397 .2307 .51044 .22798 .50689 .22354 Mtetra
.675 .739 .899 r
.50689 .22354 .51044 .22798 .51691 .2254 .51337 .22099 Mtetra
.671 .74 .902 r
.51337 .22099 .51691 .2254 .5234 .2229 .51987 .2185 Mtetra
.668 .74 .904 r
.51987 .2185 .5234 .2229 .5299 .22046 .52638 .21606 Mtetra
.666 .741 .905 r
.52638 .21606 .5299 .22046 .53642 .21804 .53291 .21364 Mtetra
.665 .741 .906 r
.53291 .21364 .53642 .21804 .54295 .21564 .53945 .21123 Mtetra
.665 .741 .907 r
.53945 .21123 .54295 .21564 .5495 .21324 .54601 .20883 Mtetra
.664 .741 .907 r
.54601 .20883 .5495 .21324 .55607 .21084 .55259 .20643 Mtetra
.55259 .20643 .55607 .21084 .56265 .20845 .55918 .20403 Mtetra
.55918 .20403 .56265 .20845 .56924 .20605 .56578 .20162 Mtetra
.56578 .20162 .56924 .20605 .57585 .20365 .57241 .19921 Mtetra
.57241 .19921 .57585 .20365 .58248 .20124 .57904 .19679 Mtetra
.57904 .19679 .58248 .20124 .58913 .19883 .5857 .19437 Mtetra
.5857 .19437 .58913 .19883 .59578 .19642 .59237 .19194 Mtetra
.59237 .19194 .59578 .19642 .60246 .19399 .59905 .18951 Mtetra
.59905 .18951 .60246 .19399 .60915 .19156 .60576 .18707 Mtetra
.60576 .18707 .60915 .19156 .61586 .18913 .61247 .18462 Mtetra
.61247 .18462 .61586 .18913 .62258 .18669 .61921 .18217 Mtetra
.61921 .18217 .62258 .18669 .62932 .18425 .62596 .17972 Mtetra
.62596 .17972 .62932 .18425 .63608 .18179 .63273 .17725 Mtetra
.63273 .17725 .63608 .18179 .64285 .17934 .63951 .17479 Mtetra
.63951 .17479 .64285 .17934 .64964 .17687 .64631 .17231 Mtetra
.64631 .17231 .64964 .17687 .65644 .17441 .65313 .16983 Mtetra
.65313 .16983 .65644 .17441 .66327 .17193 .65996 .16734 Mtetra
.65996 .16734 .66327 .17193 .6701 .16945 .66681 .16485 Mtetra
.66681 .16485 .6701 .16945 .67696 .16696 .67367 .16235 Mtetra
.67367 .16235 .67696 .16696 .68383 .16447 .68056 .15985 Mtetra
.68056 .15985 .68383 .16447 .69072 .16197 .68746 .15734 Mtetra
.68746 .15734 .69072 .16197 .69762 .15946 .69437 .15482 Mtetra
.69437 .15482 .69762 .15946 .70454 .15695 .70131 .1523 Mtetra
.70131 .1523 .70454 .15695 .71148 .15443 .70826 .14977 Mtetra
.70826 .14977 .71148 .15443 .71844 .15191 .71522 .14724 Mtetra
.71522 .14724 .71844 .15191 .72541 .14938 .72221 .14469 Mtetra
.72221 .14469 .72541 .14938 .7324 .14684 .72921 .14215 Mtetra
.72921 .14215 .7324 .14684 .73941 .1443 .73623 .13959 Mtetra
.73623 .13959 .73941 .1443 .74643 .14175 .74326 .13703 Mtetra
.74326 .13703 .74643 .14175 .75347 .1392 .75032 .13447 Mtetra
.75032 .13447 .75347 .1392 .76053 .13664 .75739 .13189 Mtetra
.75739 .13189 .76053 .13664 .76761 .13407 .76448 .12931 Mtetra
.76448 .12931 .76761 .13407 .7747 .1315 .77158 .12673 Mtetra
.14006 .35124 .14413 .35504 .14978 .35298 .14572 .34917 Mtetra
.14572 .34917 .14978 .35298 .15545 .35092 .15139 .3471 Mtetra
.15139 .3471 .15545 .35092 .16112 .34886 .15707 .34503 Mtetra
.15707 .34503 .16112 .34886 .16681 .34679 .16277 .34295 Mtetra
.16277 .34295 .16681 .34679 .17251 .34471 .16848 .34087 Mtetra
.16848 .34087 .17251 .34471 .17823 .34263 .1742 .33878 Mtetra
.1742 .33878 .17823 .34263 .18396 .34055 .17994 .33669 Mtetra
.17994 .33669 .18396 .34055 .1897 .33846 .18569 .33459 Mtetra
.18569 .33459 .1897 .33846 .19545 .33637 .19145 .33249 Mtetra
.19145 .33249 .19545 .33637 .20122 .33427 .19722 .33038 Mtetra
.19722 .33038 .20122 .33427 .207 .33216 .20301 .32827 Mtetra
.20301 .32827 .207 .33216 .21279 .33006 .20881 .32616 Mtetra
.20881 .32616 .21279 .33006 .21859 .32795 .21462 .32404 Mtetra
.664 .741 .908 r
.21462 .32404 .21859 .32795 .22441 .32583 .22044 .32191 Mtetra
.663 .741 .908 r
.22044 .32191 .22441 .32583 .23024 .32372 .22628 .3198 Mtetra
.22628 .3198 .23024 .32372 .23608 .3216 .23213 .31768 Mtetra
.662 .741 .909 r
.23213 .31768 .23608 .3216 .24194 .31949 .23799 .31557 Mtetra
.659 .741 .91 r
.23799 .31557 .24194 .31949 .24781 .3174 .24386 .3135 Mtetra
.654 .741 .914 r
.24386 .3135 .24781 .3174 .25368 .31535 .24974 .3115 Mtetra
.645 .742 .92 r
.24974 .3115 .25368 .31535 .25956 .31337 .25562 .30963 Mtetra
.623 .741 .932 r
.25562 .30963 .25956 .31337 .26545 .31156 .2615 .30804 Mtetra
.568 .737 .955 r
.2615 .30804 .26545 .31156 .27132 .31009 .26733 .30701 Mtetra
.402 .697 .981 r
.26733 .30701 .27132 .31009 .27715 .30929 .2731 .30711 Mtetra
0 .367 .742 r
.2731 .30711 .27715 .30929 .2829 .30982 .27872 .3094 Mtetra
.763 .262 .023 r
.27872 .3094 .2829 .30982 .28847 .31295 .28404 .3159 Mtetra
.845 .467 .335 r
.28404 .3159 .28847 .31295 .29371 .32101 .28883 .33009 Mtetra
.848 .523 .438 r
.28883 .33009 .29371 .32101 .29838 .33788 .29278 .35692 Mtetra
.836 .534 .478 r
.29278 .35692 .29838 .33788 .30216 .36865 .29568 .40016 Mtetra
.81 .518 .495 r
.29568 .40016 .30216 .36865 .30497 .41565 .29806 .4535 Mtetra
.747 .458 .492 r
.29806 .4535 .30497 .41565 .30764 .46799 .30177 .49057 Mtetra
.272 0 .301 r
.30177 .49057 .30764 .46799 .31212 .49534 .30865 .48165 Mtetra
.898 .663 .574 r
.30865 .48165 .31212 .49534 .31976 .47405 .31807 .43255 Mtetra
.809 .563 .567 r
.31807 .43255 .31976 .47405 .32931 .42016 .32778 .3761 Mtetra
.769 .529 .571 r
.32778 .3761 .32931 .42016 .33868 .36624 .33648 .33328 Mtetra
.748 .521 .587 r
.33648 .33328 .33868 .36624 .34698 .32787 .34412 .30656 Mtetra
.735 .532 .618 r
.34412 .30656 .34698 .32787 .35433 .30471 .35102 .29144 Mtetra
.718 .559 .673 r
.35102 .29144 .35433 .30471 .36106 .29199 .3575 .28352 Mtetra
.672 .595 .762 r
.3575 .28352 .36106 .29199 .36744 .28574 .36373 .28013 Mtetra
.51 .606 .885 r
.36373 .28013 .36744 .28574 .37361 .2838 .36981 .28009 Mtetra
0 .354 .813 r
.36981 .28009 .37361 .2838 .37963 .28538 .37575 .28326 Mtetra
.716 .187 0 r
.37575 .28326 .37963 .28538 .38551 .29057 .38157 .29008 Mtetra
.849 .4 .141 r
.38157 .29008 .38551 .29057 .39126 .29987 .38725 .30108 Mtetra
.87 .468 .267 r
.38725 .30108 .39126 .29987 .3969 .31345 .39282 .31612 Mtetra
.866 .481 .312 r
.39282 .31612 .3969 .31345 .4025 .33009 .3984 .3331 Mtetra
.841 .443 .29 r
.3984 .3331 .4025 .33009 .40821 .34601 .40419 .34728 Mtetra
.685 .172 .011 r
.40419 .34728 .40821 .34601 .41425 .35529 .41037 .35261 Mtetra
.859 .85 .832 r
.41037 .35261 .41425 .35529 .42072 .35303 .41701 .34569 Mtetra
.88 .703 .657 r
.41701 .34569 .42072 .35303 .42756 .33921 .42398 .32863 Mtetra
.866 .662 .626 r
.42398 .32863 .42756 .33921 .43457 .31869 .43103 .30717 Mtetra
.852 .649 .627 r
.43103 .30717 .43457 .31869 .44154 .29737 .43799 .28665 Mtetra
.84 .649 .645 r
.43799 .28665 .44154 .29737 .44837 .27897 .4448 .26974 Mtetra
.827 .659 .675 r
.4448 .26974 .44837 .27897 .45506 .26466 .45147 .25689 Mtetra
.81 .675 .714 r
.45147 .25689 .45506 .26466 .46164 .25405 .45804 .24744 Mtetra
.789 .693 .759 r
.45804 .24744 .46164 .25405 .46815 .24627 .46454 .24048 Mtetra
.764 .71 .801 r
.46454 .24048 .46815 .24627 .47461 .24046 .47101 .23521 Mtetra
.739 .722 .836 r
.47101 .23521 .47461 .24046 .48106 .23594 .47746 .23104 Mtetra
.717 .73 .861 r
.47746 .23104 .48106 .23594 .48751 .23225 .48391 .22756 Mtetra
.699 .735 .878 r
.48391 .22756 .48751 .23225 .49396 .22907 .49037 .22451 Mtetra
.687 .737 .889 r
.49037 .22451 .49396 .22907 .50042 .2262 .49684 .22172 Mtetra
.678 .739 .896 r
.49684 .22172 .50042 .2262 .50689 .22354 .50332 .21909 Mtetra
.673 .74 .901 r
.50332 .21909 .50689 .22354 .51337 .22099 .50981 .21657 Mtetra
.67 .74 .903 r
.50981 .21657 .51337 .22099 .51987 .2185 .51632 .21409 Mtetra
.667 .74 .905 r
.51632 .21409 .51987 .2185 .52638 .21606 .52285 .21165 Mtetra
.666 .741 .906 r
.52285 .21165 .52638 .21606 .53291 .21364 .52938 .20923 Mtetra
.665 .741 .906 r
.52938 .20923 .53291 .21364 .53945 .21123 .53594 .20682 Mtetra
.665 .741 .907 r
.53594 .20682 .53945 .21123 .54601 .20883 .54251 .20441 Mtetra
.664 .741 .907 r
.54251 .20441 .54601 .20883 .55259 .20643 .54909 .202 Mtetra
.54909 .202 .55259 .20643 .55918 .20403 .55569 .19958 Mtetra
.55569 .19958 .55918 .20403 .56578 .20162 .56231 .19716 Mtetra
.56231 .19716 .56578 .20162 .57241 .19921 .56894 .19474 Mtetra
.56894 .19474 .57241 .19921 .57904 .19679 .57559 .19231 Mtetra
.57559 .19231 .57904 .19679 .5857 .19437 .58226 .18988 Mtetra
.58226 .18988 .5857 .19437 .59237 .19194 .58894 .18744 Mtetra
.58894 .18744 .59237 .19194 .59905 .18951 .59563 .185 Mtetra
.59563 .185 .59905 .18951 .60576 .18707 .60235 .18255 Mtetra
.60235 .18255 .60576 .18707 .61247 .18462 .60908 .18009 Mtetra
.60908 .18009 .61247 .18462 .61921 .18217 .61582 .17763 Mtetra
.61582 .17763 .61921 .18217 .62596 .17972 .62258 .17517 Mtetra
.62258 .17517 .62596 .17972 .63273 .17725 .62936 .17269 Mtetra
.62936 .17269 .63273 .17725 .63951 .17479 .63615 .17021 Mtetra
.63615 .17021 .63951 .17479 .64631 .17231 .64297 .16773 Mtetra
.64297 .16773 .64631 .17231 .65313 .16983 .64979 .16524 Mtetra
.64979 .16524 .65313 .16983 .65996 .16734 .65664 .16274 Mtetra
.65664 .16274 .65996 .16734 .66681 .16485 .6635 .16024 Mtetra
.6635 .16024 .66681 .16485 .67367 .16235 .67038 .15773 Mtetra
.67038 .15773 .67367 .16235 .68056 .15985 .67727 .15521 Mtetra
.67727 .15521 .68056 .15985 .68746 .15734 .68418 .15269 Mtetra
.68418 .15269 .68746 .15734 .69437 .15482 .69111 .15016 Mtetra
.69111 .15016 .69437 .15482 .70131 .1523 .69805 .14763 Mtetra
.69805 .14763 .70131 .1523 .70826 .14977 .70502 .14509 Mtetra
.70502 .14509 .70826 .14977 .71522 .14724 .71199 .14254 Mtetra
.71199 .14254 .71522 .14724 .72221 .14469 .71899 .13999 Mtetra
.71899 .13999 .72221 .14469 .72921 .14215 .72601 .13743 Mtetra
.72601 .13743 .72921 .14215 .73623 .13959 .73304 .13486 Mtetra
.73304 .13486 .73623 .13959 .74326 .13703 .74008 .13229 Mtetra
.74008 .13229 .74326 .13703 .75032 .13447 .74715 .12971 Mtetra
.74715 .12971 .75032 .13447 .75739 .13189 .75423 .12713 Mtetra
.75423 .12713 .75739 .13189 .76448 .12931 .76133 .12453 Mtetra
.76133 .12453 .76448 .12931 .77158 .12673 .76845 .12194 Mtetra
.13597 .34742 .14006 .35124 .14572 .34917 .14164 .34535 Mtetra
.14164 .34535 .14572 .34917 .15139 .3471 .14732 .34327 Mtetra
.14732 .34327 .15139 .3471 .15707 .34503 .15301 .34119 Mtetra
.15301 .34119 .15707 .34503 .16277 .34295 .15871 .3391 Mtetra
.15871 .3391 .16277 .34295 .16848 .34087 .16443 .33701 Mtetra
.16443 .33701 .16848 .34087 .1742 .33878 .17016 .33491 Mtetra
.17016 .33491 .1742 .33878 .17994 .33669 .1759 .33281 Mtetra
.1759 .33281 .17994 .33669 .18569 .33459 .18166 .33071 Mtetra
.18166 .33071 .18569 .33459 .19145 .33249 .18743 .3286 Mtetra
.18743 .3286 .19145 .33249 .19722 .33038 .19321 .32648 Mtetra
.19321 .32648 .19722 .33038 .20301 .32827 .199 .32436 Mtetra
.199 .32436 .20301 .32827 .20881 .32616 .20481 .32224 Mtetra
.20481 .32224 .20881 .32616 .21462 .32404 .21063 .32011 Mtetra
.663 .741 .908 r
.21063 .32011 .21462 .32404 .22044 .32191 .21646 .31799 Mtetra
.21646 .31799 .22044 .32191 .22628 .3198 .2223 .31586 Mtetra
.662 .741 .909 r
.2223 .31586 .22628 .3198 .23213 .31768 .22816 .31374 Mtetra
.66 .741 .91 r
.22816 .31374 .23213 .31768 .23799 .31557 .23403 .31166 Mtetra
.656 .741 .913 r
.23403 .31166 .23799 .31557 .24386 .3135 .2399 .30963 Mtetra
.648 .742 .918 r
.2399 .30963 .24386 .3135 .24974 .3115 .24578 .3077 Mtetra
.63 .741 .928 r
.24578 .3077 .24974 .3115 .25562 .30963 .25165 .30602 Mtetra
.587 .739 .948 r
.25165 .30602 .25562 .30963 .2615 .30804 .2575 .30481 Mtetra
.466 .716 .978 r
.2575 .30481 .2615 .30804 .26733 .30701 .26328 .30453 Mtetra
.024 .512 .876 r
.26328 .30453 .26733 .30701 .2731 .30711 .26894 .30611 Mtetra
.692 .149 0 r
.26894 .30611 .2731 .30711 .27872 .3094 .27433 .31128 Mtetra
.838 .438 .288 r
.27433 .31128 .27872 .3094 .28404 .3159 .27924 .32311 Mtetra
.849 .515 .421 r
.27924 .32311 .28404 .3159 .28883 .33009 .28336 .34627 Mtetra
.84 .534 .472 r
.28336 .34627 .28883 .33009 .29278 .35692 .28639 .3854 Mtetra
.819 .525 .493 r
.28639 .3854 .29278 .35692 .29568 .40016 .28863 .43795 Mtetra
.77 .481 .496 r
.28863 .43795 .29568 .40016 .29806 .4535 .29164 .48261 Mtetra
.559 .268 .43 r
.29164 .48261 .29806 .4535 .30177 .49057 .29764 .48654 Mtetra
.943 .724 .577 r
.29764 .48654 .30177 .49057 .30865 .48165 .30674 .44462 Mtetra
.824 .578 .568 r
.30674 .44462 .30865 .48165 .31807 .43255 .31672 .387 Mtetra
.776 .534 .569 r
.31672 .387 .31807 .43255 .32778 .3761 .32585 .33984 Mtetra
.752 .521 .581 r
.32585 .33984 .32778 .3761 .33648 .33328 .3338 .30927 Mtetra
.739 .528 .608 r
.3338 .30927 .33648 .33328 .34412 .30656 .34091 .29154 Mtetra
.726 .552 .655 r
.34091 .29154 .34412 .30656 .35102 .29144 .3475 .28189 Mtetra
.697 .589 .731 r
.3475 .28189 .35102 .29144 .3575 .28352 .35381 .27715 Mtetra
.606 .622 .84 r
.35381 .27715 .3575 .28352 .36373 .28013 .35994 .27574 Mtetra
.285 .554 .926 r
.35994 .27574 .36373 .28013 .36981 .28009 .36595 .27721 Mtetra
.457 0 0 r
.36595 .27721 .36981 .28009 .37575 .28326 .37182 .28185 Mtetra
.798 .304 0 r
.37182 .28185 .37575 .28326 .38157 .29008 .37756 .29027 Mtetra
.862 .436 .206 r
.37756 .29027 .38157 .29008 .38725 .30108 .38317 .30293 Mtetra
.87 .478 .292 r
.38317 .30293 .38725 .30108 .39282 .31612 .38869 .31911 Mtetra
.86 .474 .313 r
.38869 .31911 .39282 .31612 .3984 .3331 .39429 .33574 Mtetra
.818 .399 .248 r
.39429 .33574 .3984 .3331 .40419 .34728 .40018 .34727 Mtetra
.171 0 0 r
.40018 .34727 .40419 .34728 .41037 .35261 .40653 .34813 Mtetra
.885 .768 .728 r
.40653 .34813 .41037 .35261 .41701 .34569 .41334 .33687 Mtetra
.875 .683 .639 r
.41334 .33687 .41701 .34569 .42398 .32863 .42041 .31741 Mtetra
.86 .655 .624 r
.42041 .31741 .42398 .32863 .43103 .30717 .42749 .29579 Mtetra
.848 .648 .632 r
.42749 .29579 .43103 .30717 .43799 .28665 .43443 .27643 Mtetra
.835 .652 .655 r
.43443 .27643 .43799 .28665 .4448 .26974 .44122 .26106 Mtetra
.821 .664 .689 r
.44122 .26106 .4448 .26974 .45147 .25689 .44786 .24958 Mtetra
.803 .682 .731 r
.44786 .24958 .45147 .25689 .45804 .24744 .45442 .24116 Mtetra
.78 .7 .775 r
.45442 .24116 .45804 .24744 .46454 .24048 .46092 .23491 Mtetra
.755 .715 .815 r
.46092 .23491 .46454 .24048 .47101 .23521 .46739 .2301 Mtetra
.73 .726 .846 r
.46739 .2301 .47101 .23521 .47746 .23104 .47385 .22621 Mtetra
.71 .732 .868 r
.47385 .22621 .47746 .23104 .48391 .22756 .48031 .22291 Mtetra
.694 .736 .883 r
.48031 .22291 .48391 .22756 .49037 .22451 .48677 .21996 Mtetra
.683 .738 .892 r
.48677 .21996 .49037 .22451 .49684 .22172 .49325 .21724 Mtetra
.676 .739 .898 r
.49325 .21724 .49684 .22172 .50332 .21909 .49974 .21465 Mtetra
.671 .74 .902 r
.49974 .21465 .50332 .21909 .50981 .21657 .50624 .21213 Mtetra
.669 .74 .904 r
.50624 .21213 .50981 .21657 .51632 .21409 .51276 .20967 Mtetra
.667 .741 .905 r
.51276 .20967 .51632 .21409 .52285 .21165 .51929 .20723 Mtetra
.666 .741 .906 r
.51929 .20723 .52285 .21165 .52938 .20923 .52584 .2048 Mtetra
.665 .741 .907 r
.52584 .2048 .52938 .20923 .53594 .20682 .53241 .20238 Mtetra
.53241 .20238 .53594 .20682 .54251 .20441 .53899 .19996 Mtetra
.664 .741 .907 r
.53899 .19996 .54251 .20441 .54909 .202 .54558 .19754 Mtetra
.54558 .19754 .54909 .202 .55569 .19958 .55219 .19512 Mtetra
.55219 .19512 .55569 .19958 .56231 .19716 .55882 .19269 Mtetra
.55882 .19269 .56231 .19716 .56894 .19474 .56546 .19026 Mtetra
.56546 .19026 .56894 .19474 .57559 .19231 .57212 .18782 Mtetra
.57212 .18782 .57559 .19231 .58226 .18988 .5788 .18538 Mtetra
.5788 .18538 .58226 .18988 .58894 .18744 .58549 .18293 Mtetra
.58549 .18293 .58894 .18744 .59563 .185 .5922 .18047 Mtetra
.5922 .18047 .59563 .185 .60235 .18255 .59892 .17801 Mtetra
.59892 .17801 .60235 .18255 .60908 .18009 .60566 .17555 Mtetra
.60566 .17555 .60908 .18009 .61582 .17763 .61242 .17307 Mtetra
.61242 .17307 .61582 .17763 .62258 .17517 .61919 .17059 Mtetra
.61919 .17059 .62258 .17517 .62936 .17269 .62598 .16811 Mtetra
.62598 .16811 .62936 .17269 .63615 .17021 .63278 .16562 Mtetra
.63278 .16562 .63615 .17021 .64297 .16773 .63961 .16312 Mtetra
.63961 .16312 .64297 .16773 .64979 .16524 .64645 .16062 Mtetra
.64645 .16062 .64979 .16524 .65664 .16274 .6533 .15811 Mtetra
.6533 .15811 .65664 .16274 .6635 .16024 .66017 .1556 Mtetra
.66017 .1556 .6635 .16024 .67038 .15773 .66706 .15308 Mtetra
.66706 .15308 .67038 .15773 .67727 .15521 .67397 .15055 Mtetra
.67397 .15055 .67727 .15521 .68418 .15269 .68089 .14802 Mtetra
.68089 .14802 .68418 .15269 .69111 .15016 .68783 .14548 Mtetra
.68783 .14548 .69111 .15016 .69805 .14763 .69479 .14293 Mtetra
.69479 .14293 .69805 .14763 .70502 .14509 .70176 .14038 Mtetra
.70176 .14038 .70502 .14509 .71199 .14254 .70875 .13782 Mtetra
.70875 .13782 .71199 .14254 .71899 .13999 .71576 .13526 Mtetra
.71576 .13526 .71899 .13999 .72601 .13743 .72279 .13268 Mtetra
.72279 .13268 .72601 .13743 .73304 .13486 .72983 .13011 Mtetra
.72983 .13011 .73304 .13486 .74008 .13229 .73689 .12752 Mtetra
.73689 .12752 .74008 .13229 .74715 .12971 .74397 .12493 Mtetra
.74397 .12493 .74715 .12971 .75423 .12713 .75106 .12234 Mtetra
.75106 .12234 .75423 .12713 .76133 .12453 .75818 .11973 Mtetra
.75818 .11973 .76133 .12453 .76845 .12194 .76531 .11712 Mtetra
.13187 .34359 .13597 .34742 .14164 .34535 .13754 .34151 Mtetra
.13754 .34151 .14164 .34535 .14732 .34327 .14323 .33942 Mtetra
.14323 .33942 .14732 .34327 .15301 .34119 .14893 .33733 Mtetra
.14893 .33733 .15301 .34119 .15871 .3391 .15464 .33524 Mtetra
.15464 .33524 .15871 .3391 .16443 .33701 .16036 .33314 Mtetra
.16036 .33314 .16443 .33701 .17016 .33491 .1661 .33103 Mtetra
.1661 .33103 .17016 .33491 .1759 .33281 .17185 .32892 Mtetra
.17185 .32892 .1759 .33281 .18166 .33071 .17761 .32681 Mtetra
.17761 .32681 .18166 .33071 .18743 .3286 .18339 .32469 Mtetra
.18339 .32469 .18743 .3286 .19321 .32648 .18918 .32256 Mtetra
.18918 .32256 .19321 .32648 .199 .32436 .19498 .32043 Mtetra
.19498 .32043 .199 .32436 .20481 .32224 .20079 .3183 Mtetra
.663 .741 .908 r
.20079 .3183 .20481 .32224 .21063 .32011 .20662 .31617 Mtetra
.20662 .31617 .21063 .32011 .21646 .31799 .21246 .31404 Mtetra
.662 .741 .908 r
.21246 .31404 .21646 .31799 .2223 .31586 .21831 .31192 Mtetra
.661 .741 .909 r
.21831 .31192 .2223 .31586 .22816 .31374 .22417 .30981 Mtetra
.657 .741 .912 r
.22417 .30981 .22816 .31374 .23403 .31166 .23004 .30776 Mtetra
.651 .741 .916 r
.23004 .30776 .23403 .31166 .2399 .30963 .23592 .3058 Mtetra
.636 .742 .925 r
.23592 .3058 .2399 .30963 .24578 .3077 .24179 .30403 Mtetra
.602 .74 .942 r
.24179 .30403 .24578 .3077 .25165 .30602 .24764 .30265 Mtetra
.511 .727 .971 r
.24764 .30265 .25165 .30602 .2575 .30481 .25344 .30207 Mtetra
.194 .609 .946 r
.25344 .30207 .2575 .30481 .26328 .30453 .25912 .30305 Mtetra
.572 0 0 r
.25912 .30305 .26328 .30453 .26894 .30611 .26458 .30708 Mtetra
.826 .398 .225 r
.26458 .30708 .26894 .30611 .27433 .31128 .26961 .31685 Mtetra
.849 .503 .399 r
.26961 .31685 .27433 .31128 .27924 .32311 .27389 .33666 Mtetra
.843 .532 .463 r
.27389 .33666 .27924 .32311 .28336 .34627 .2771 .37157 Mtetra
.826 .53 .489 r
.2771 .37157 .28336 .34627 .28639 .3854 .27929 .42194 Mtetra
.787 .497 .497 r
.27929 .42194 .28639 .3854 .28863 .43795 .28173 .47184 Mtetra
.662 .371 .468 r
.28173 .47184 .28863 .43795 .29164 .48261 .28679 .48831 Mtetra
.996 .83 .56 r
.28679 .48831 .29164 .48261 .29764 .48654 .29536 .45581 Mtetra
.842 .598 .569 r
.29536 .45581 .29764 .48654 .30674 .44462 .3055 .39874 Mtetra
.785 .542 .568 r
.3055 .39874 .30674 .44462 .31672 .387 .31506 .34756 Mtetra
.757 .522 .577 r
.31506 .34756 .31672 .387 .32585 .33984 .32339 .31288 Mtetra
.742 .524 .599 r
.32339 .31288 .32585 .33984 .3338 .30927 .33072 .29229 Mtetra
.731 .545 .64 r
.33072 .29229 .3338 .30927 .34091 .29154 .33745 .2808 Mtetra
.712 .581 .706 r
.33745 .2808 .34091 .29154 .3475 .28189 .34384 .27475 Mtetra
.657 .621 .802 r
.34384 .27475 .3475 .28189 .35381 .27715 .35003 .27214 Mtetra
.486 .625 .912 r
.35003 .27214 .35381 .27715 .35994 .27574 .35609 .27221 Mtetra
0 .394 .836 r
.35609 .27221 .35994 .27574 .36595 .27721 .36203 .275 Mtetra
.667 .125 0 r
.36203 .275 .36595 .27721 .37182 .28185 .36784 .28108 Mtetra
.836 .373 .101 r
.36784 .28108 .37182 .28185 .37756 .29027 .3735 .29113 Mtetra
.868 .458 .25 r
.3735 .29113 .37756 .29027 .38317 .30293 .37903 .30532 Mtetra
.868 .482 .307 r
.37903 .30532 .38317 .30293 .38869 .31911 .38453 .3222 Mtetra
.85 .459 .304 r
.38453 .3222 .38869 .31911 .39429 .33574 .39017 .33767 Mtetra
.767 .307 .153 r
.39017 .33767 .39429 .33574 .40018 .34727 .3962 .34572 Mtetra
.746 .92 .95 r
.3962 .34572 .40018 .34727 .40653 .34813 .40275 .34188 Mtetra
.884 .722 .677 r
.40275 .34188 .40653 .34813 .41334 .33687 .40972 .32686 Mtetra
.869 .669 .629 r
.40972 .32686 .41334 .33687 .42041 .31741 .41685 .30589 Mtetra
.856 .651 .625 r
.41685 .30589 .42041 .31741 .42749 .29579 .42393 .28473 Mtetra
.843 .648 .639 r
.42393 .28473 .42749 .29579 .43443 .27643 .43085 .26678 Mtetra
.83 .656 .666 r
.43085 .26678 .43443 .27643 .44122 .26106 .43761 .25292 Mtetra
.815 .671 .704 r
.43761 .25292 .44122 .26106 .44786 .24958 .44424 .24268 Mtetra
.795 .689 .748 r
.44424 .24268 .44786 .24958 .45442 .24116 .45078 .23516 Mtetra
.771 .706 .791 r
.45078 .23516 .45442 .24116 .46092 .23491 .45728 .22951 Mtetra
.745 .72 .828 r
.45728 .22951 .46092 .23491 .46739 .2301 .46375 .22509 Mtetra
.722 .728 .856 r
.46375 .22509 .46739 .2301 .47385 .22621 .47021 .22145 Mtetra
.703 .734 .875 r
.47021 .22145 .47385 .22621 .48031 .22291 .47668 .21829 Mtetra
.69 .737 .887 r
.47668 .21829 .48031 .22291 .48677 .21996 .48316 .21543 Mtetra
.68 .739 .895 r
.48316 .21543 .48677 .21996 .49325 .21724 .48964 .21276 Mtetra
.674 .74 .9 r
.48964 .21276 .49325 .21724 .49974 .21465 .49614 .21019 Mtetra
.67 .74 .903 r
.49614 .21019 .49974 .21465 .50624 .21213 .50266 .20769 Mtetra
.668 .74 .904 r
.50266 .20769 .50624 .21213 .51276 .20967 .50918 .20523 Mtetra
.666 .741 .906 r
.50918 .20523 .51276 .20967 .51929 .20723 .51573 .20279 Mtetra
.665 .741 .906 r
.51573 .20279 .51929 .20723 .52584 .2048 .52229 .20035 Mtetra
.665 .741 .907 r
.52229 .20035 .52584 .2048 .53241 .20238 .52886 .19793 Mtetra
.664 .741 .907 r
.52886 .19793 .53241 .20238 .53899 .19996 .53545 .1955 Mtetra
.53545 .1955 .53899 .19996 .54558 .19754 .54206 .19307 Mtetra
.54206 .19307 .54558 .19754 .55219 .19512 .54868 .19063 Mtetra
.54868 .19063 .55219 .19512 .55882 .19269 .55532 .1882 Mtetra
.55532 .1882 .55882 .19269 .56546 .19026 .56197 .18575 Mtetra
.56197 .18575 .56546 .19026 .57212 .18782 .56864 .1833 Mtetra
.56864 .1833 .57212 .18782 .5788 .18538 .57533 .18085 Mtetra
.57533 .18085 .5788 .18538 .58549 .18293 .58203 .17839 Mtetra
.58203 .17839 .58549 .18293 .5922 .18047 .58875 .17593 Mtetra
.58875 .17593 .5922 .18047 .59892 .17801 .59548 .17345 Mtetra
.59548 .17345 .59892 .17801 .60566 .17555 .60223 .17098 Mtetra
.60223 .17098 .60566 .17555 .61242 .17307 .609 .16849 Mtetra
.609 .16849 .61242 .17307 .61919 .17059 .61578 .166 Mtetra
.61578 .166 .61919 .17059 .62598 .16811 .62258 .16351 Mtetra
.62258 .16351 .62598 .16811 .63278 .16562 .6294 .16101 Mtetra
.6294 .16101 .63278 .16562 .63961 .16312 .63623 .1585 Mtetra
.63623 .1585 .63961 .16312 .64645 .16062 .64308 .15598 Mtetra
.64308 .15598 .64645 .16062 .6533 .15811 .64995 .15346 Mtetra
.64995 .15346 .6533 .15811 .66017 .1556 .65683 .15094 Mtetra
.65683 .15094 .66017 .1556 .66706 .15308 .66373 .14841 Mtetra
.66373 .14841 .66706 .15308 .67397 .15055 .67065 .14587 Mtetra
.67065 .14587 .67397 .15055 .68089 .14802 .67758 .14332 Mtetra
.67758 .14332 .68089 .14802 .68783 .14548 .68454 .14077 Mtetra
.68454 .14077 .68783 .14548 .69479 .14293 .6915 .13821 Mtetra
.6915 .13821 .69479 .14293 .70176 .14038 .69849 .13565 Mtetra
.69849 .13565 .70176 .14038 .70875 .13782 .70549 .13308 Mtetra
.70549 .13308 .70875 .13782 .71576 .13526 .71251 .1305 Mtetra
.71251 .1305 .71576 .13526 .72279 .13268 .71955 .12792 Mtetra
.71955 .12792 .72279 .13268 .72983 .13011 .72661 .12533 Mtetra
.72661 .12533 .72983 .13011 .73689 .12752 .73368 .12274 Mtetra
.73368 .12274 .73689 .12752 .74397 .12493 .74077 .12014 Mtetra
.74077 .12014 .74397 .12493 .75106 .12234 .74788 .11753 Mtetra
.74788 .11753 .75106 .12234 .75818 .11973 .755 .11491 Mtetra
.755 .11491 .75818 .11973 .76531 .11712 .76215 .11229 Mtetra
.12775 .33974 .13187 .34359 .13754 .34151 .13343 .33765 Mtetra
.13343 .33765 .13754 .34151 .14323 .33942 .13913 .33556 Mtetra
.13913 .33556 .14323 .33942 .14893 .33733 .14483 .33346 Mtetra
.14483 .33346 .14893 .33733 .15464 .33524 .15055 .33135 Mtetra
.15055 .33135 .15464 .33524 .16036 .33314 .15628 .32924 Mtetra
.15628 .32924 .16036 .33314 .1661 .33103 .16202 .32713 Mtetra
.16202 .32713 .1661 .33103 .17185 .32892 .16778 .32501 Mtetra
.16778 .32501 .17185 .32892 .17761 .32681 .17355 .32289 Mtetra
.17355 .32289 .17761 .32681 .18339 .32469 .17933 .32076 Mtetra
.17933 .32076 .18339 .32469 .18918 .32256 .18513 .31863 Mtetra
.18513 .31863 .18918 .32256 .19498 .32043 .19094 .31649 Mtetra
.663 .741 .908 r
.19094 .31649 .19498 .32043 .20079 .3183 .19676 .31436 Mtetra
.19676 .31436 .20079 .3183 .20662 .31617 .20259 .31222 Mtetra
.20259 .31222 .20662 .31617 .21246 .31404 .20844 .31009 Mtetra
.661 .741 .909 r
.20844 .31009 .21246 .31404 .21831 .31192 .2143 .30797 Mtetra
.658 .741 .911 r
.2143 .30797 .21831 .31192 .22417 .30981 .22016 .3059 Mtetra
.653 .742 .915 r
.22016 .3059 .22417 .30981 .23004 .30776 .22604 .3039 Mtetra
.641 .742 .922 r
.22604 .3039 .23004 .30776 .23592 .3058 .23191 .30206 Mtetra
.614 .741 .936 r
.23191 .30206 .23592 .3058 .24179 .30403 .23776 .30055 Mtetra
.545 .734 .963 r
.23776 .30055 .24179 .30403 .24764 .30265 .24357 .29971 Mtetra
.318 .666 .974 r
.24357 .29971 .24764 .30265 .25344 .30207 .24928 .30018 Mtetra
.396 0 0 r
.24928 .30018 .25344 .30207 .25912 .30305 .2548 .30324 Mtetra
.803 .342 .139 r
.2548 .30324 .25912 .30305 .26458 .30708 .25992 .31122 Mtetra
.848 .488 .372 r
.25992 .31122 .26458 .30708 .26961 .31685 .26437 .32802 Mtetra
.846 .529 .452 r
.26437 .32802 .26961 .31685 .27389 .33666 .26778 .35878 Mtetra
.831 .533 .485 r
.26778 .35878 .27389 .33666 .2771 .37157 .27003 .40596 Mtetra
.8 .509 .497 r
.27003 .40596 .2771 .37157 .27929 .42194 .27204 .45882 Mtetra
.715 .425 .484 r
.27204 .45882 .27929 .42194 .28173 .47184 .27615 .48672 Mtetra
.683 .755 .261 r
.27615 .48672 .28173 .47184 .28679 .48831 .28399 .46546 Mtetra
.866 .624 .571 r
.28399 .46546 .28679 .48831 .29536 .45581 .29414 .41103 Mtetra
.796 .551 .567 r
.29414 .41103 .29536 .45581 .3055 .39874 .30411 .35645 Mtetra
.763 .525 .573 r
.30411 .35645 .3055 .39874 .31506 .34756 .31285 .31747 Mtetra
.745 .522 .592 r
.31285 .31747 .31506 .34756 .32339 .31288 .32045 .29372 Mtetra
.735 .539 .627 r
.32045 .29372 .32339 .31288 .33072 .29229 .32734 .28023 Mtetra
.721 .572 .685 r
.32734 .28023 .33072 .29229 .33745 .2808 .33382 .27284 Mtetra
.687 .614 .77 r
.33382 .27284 .33745 .2808 .34384 .27475 .34007 .26914 Mtetra
.587 .644 .874 r
.34007 .26914 .34384 .27475 .35003 .27214 .34619 .26804 Mtetra
.286 .574 .938 r
.34619 .26804 .35003 .27214 .35609 .27221 .35218 .26933 Mtetra
0 .16 .606 r
.35218 .26933 .35609 .27221 .36203 .275 .35806 .27339 Mtetra
.767 .256 0 r
.35806 .27339 .36203 .275 .36784 .28108 .36379 .28094 Mtetra
.854 .417 .175 r
.36379 .28094 .36784 .28108 .3735 .29113 .36937 .29262 Mtetra
.87 .472 .28 r
.36937 .29262 .3735 .29113 .37903 .30532 .37484 .30813 Mtetra
.864 .48 .314 r
.37484 .30813 .37903 .30532 .38453 .3222 .38033 .32513 Mtetra
.835 .431 .28 r
.38033 .32513 .38453 .3222 .39017 .33767 .38606 .33854 Mtetra
.599 .048 0 r
.38606 .33854 .39017 .33767 .3962 .34572 .39228 .34243 Mtetra
.875 .816 .788 r
.39228 .34243 .3962 .34572 .40275 .34188 .39902 .33399 Mtetra
.879 .695 .65 r
.39902 .33399 .40275 .34188 .40972 .32686 .40612 .31598 Mtetra
.864 .66 .625 r
.40612 .31598 .40972 .32686 .41685 .30589 .4133 .29434 Mtetra
.851 .648 .628 r
.4133 .29434 .41685 .30589 .42393 .28473 .42036 .27412 Mtetra
.838 .65 .648 r
.42036 .27412 .42393 .28473 .43085 .26678 .42725 .25769 Mtetra
.825 .661 .679 r
.42725 .25769 .43085 .26678 .43761 .25292 .43398 .24527 Mtetra
.808 .677 .72 r
.43398 .24527 .43761 .25292 .44424 .24268 .44059 .23614 Mtetra
.786 .696 .764 r
.44059 .23614 .44424 .24268 .45078 .23516 .44712 .2294 Mtetra
.761 .712 .806 r
.44712 .2294 .45078 .23516 .45728 .22951 .45362 .22427 Mtetra
.736 .723 .839 r
.45362 .22427 .45728 .22951 .46375 .22509 .46009 .22017 Mtetra
.714 .731 .864 r
.46009 .22017 .46375 .22509 .47021 .22145 .46657 .21673 Mtetra
.698 .735 .88 r
.46657 .21673 .47021 .22145 .47668 .21829 .47304 .2137 Mtetra
.686 .738 .89 r
.47304 .2137 .47668 .21829 .48316 .21543 .47953 .21091 Mtetra
.678 .739 .897 r
.47953 .21091 .48316 .21543 .48964 .21276 .48602 .20827 Mtetra
.672 .74 .901 r
.48602 .20827 .48964 .21276 .49614 .21019 .49253 .20573 Mtetra
.669 .74 .903 r
.49253 .20573 .49614 .21019 .50266 .20769 .49905 .20324 Mtetra
.667 .74 .905 r
.49905 .20324 .50266 .20769 .50918 .20523 .50559 .20077 Mtetra
.666 .741 .906 r
.50559 .20077 .50918 .20523 .51573 .20279 .51214 .19833 Mtetra
.665 .741 .906 r
.51214 .19833 .51573 .20279 .52229 .20035 .51871 .19589 Mtetra
.665 .741 .907 r
.51871 .19589 .52229 .20035 .52886 .19793 .5253 .19345 Mtetra
.664 .741 .907 r
.5253 .19345 .52886 .19793 .53545 .1955 .5319 .19102 Mtetra
.5319 .19102 .53545 .1955 .54206 .19307 .53852 .18858 Mtetra
.53852 .18858 .54206 .19307 .54868 .19063 .54515 .18613 Mtetra
.54515 .18613 .54868 .19063 .55532 .1882 .5518 .18368 Mtetra
.5518 .18368 .55532 .1882 .56197 .18575 .55846 .18123 Mtetra
.55846 .18123 .56197 .18575 .56864 .1833 .56514 .17877 Mtetra
.56514 .17877 .56864 .1833 .57533 .18085 .57184 .17631 Mtetra
.57184 .17631 .57533 .18085 .58203 .17839 .57855 .17383 Mtetra
.57855 .17383 .58203 .17839 .58875 .17593 .58528 .17136 Mtetra
.58528 .17136 .58875 .17593 .59548 .17345 .59202 .16888 Mtetra
.59202 .16888 .59548 .17345 .60223 .17098 .59879 .16639 Mtetra
.59879 .16639 .60223 .17098 .609 .16849 .60556 .16389 Mtetra
.60556 .16389 .609 .16849 .61578 .166 .61236 .16139 Mtetra
.61236 .16139 .61578 .166 .62258 .16351 .61917 .15888 Mtetra
.61917 .15888 .62258 .16351 .6294 .16101 .626 .15637 Mtetra
.626 .15637 .6294 .16101 .63623 .1585 .63284 .15385 Mtetra
.63284 .15385 .63623 .1585 .64308 .15598 .6397 .15133 Mtetra
.6397 .15133 .64308 .15598 .64995 .15346 .64658 .1488 Mtetra
.64658 .1488 .64995 .15346 .65683 .15094 .65348 .14626 Mtetra
.65348 .14626 .65683 .15094 .66373 .14841 .66039 .14371 Mtetra
.66039 .14371 .66373 .14841 .67065 .14587 .66732 .14116 Mtetra
.66732 .14116 .67065 .14587 .67758 .14332 .67426 .13861 Mtetra
.67426 .13861 .67758 .14332 .68454 .14077 .68123 .13605 Mtetra
.68123 .13605 .68454 .14077 .6915 .13821 .68821 .13348 Mtetra
.68821 .13348 .6915 .13821 .69849 .13565 .69521 .1309 Mtetra
.69521 .1309 .69849 .13565 .70549 .13308 .70222 .12832 Mtetra
.70222 .12832 .70549 .13308 .71251 .1305 .70925 .12573 Mtetra
.70925 .12573 .71251 .1305 .71955 .12792 .7163 .12314 Mtetra
.7163 .12314 .71955 .12792 .72661 .12533 .72337 .12054 Mtetra
.72337 .12054 .72661 .12533 .73368 .12274 .73045 .11793 Mtetra
.73045 .11793 .73368 .12274 .74077 .12014 .73756 .11531 Mtetra
.73756 .11531 .74077 .12014 .74788 .11753 .74468 .1127 Mtetra
.74468 .1127 .74788 .11753 .755 .11491 .75181 .11007 Mtetra
.75181 .11007 .755 .11491 .76215 .11229 .75897 .10743 Mtetra
.12362 .33588 .12775 .33974 .13343 .33765 .1293 .33378 Mtetra
.1293 .33378 .13343 .33765 .13913 .33556 .135 .33168 Mtetra
.135 .33168 .13913 .33556 .14483 .33346 .14072 .32957 Mtetra
.14072 .32957 .14483 .33346 .15055 .33135 .14644 .32746 Mtetra
.14644 .32746 .15055 .33135 .15628 .32924 .15218 .32534 Mtetra
.15218 .32534 .15628 .32924 .16202 .32713 .15793 .32322 Mtetra
.15793 .32322 .16202 .32713 .16778 .32501 .1637 .32109 Mtetra
.1637 .32109 .16778 .32501 .17355 .32289 .16947 .31896 Mtetra
.16947 .31896 .17355 .32289 .17933 .32076 .17526 .31682 Mtetra
.17526 .31682 .17933 .32076 .18513 .31863 .18107 .31468 Mtetra
.18107 .31468 .18513 .31863 .19094 .31649 .18688 .31254 Mtetra
.663 .741 .908 r
.18688 .31254 .19094 .31649 .19676 .31436 .19271 .31039 Mtetra
.19271 .31039 .19676 .31436 .20259 .31222 .19855 .30826 Mtetra
.662 .741 .909 r
.19855 .30826 .20259 .31222 .20844 .31009 .2044 .30613 Mtetra
.659 .741 .91 r
.2044 .30613 .20844 .31009 .2143 .30797 .21027 .30403 Mtetra
.655 .741 .913 r
.21027 .30403 .2143 .30797 .22016 .3059 .21614 .302 Mtetra
.645 .742 .919 r
.21614 .302 .22016 .3059 .22604 .3039 .222 .30011 Mtetra
.623 .742 .932 r
.222 .30011 .22604 .3039 .23191 .30206 .22786 .29848 Mtetra
.569 .737 .955 r
.22786 .29848 .23191 .30206 .23776 .30055 .23368 .29742 Mtetra
.406 .698 .981 r
.23368 .29742 .23776 .30055 .24357 .29971 .23942 .29747 Mtetra
0 .371 .745 r
.23942 .29747 .24357 .29971 .24928 .30018 .24498 .29971 Mtetra
.763 .262 .024 r
.24498 .29971 .24928 .30018 .2548 .30324 .2502 .30614 Mtetra
.844 .467 .336 r
.2502 .30614 .2548 .30324 .25992 .31122 .25481 .32027 Mtetra
.847 .523 .439 r
.25481 .32027 .25992 .31122 .26437 .32802 .25842 .34707 Mtetra
.836 .535 .479 r
.25842 .34707 .26437 .32802 .26778 .35878 .2608 .39044 Mtetra
.81 .519 .495 r
.2608 .39044 .26778 .35878 .27003 .40596 .26253 .44415 Mtetra
.748 .458 .492 r
.26253 .44415 .27003 .40596 .27204 .45882 .26575 .48173 Mtetra
.269 0 .293 r
.26575 .48173 .27204 .45882 .27615 .48672 .27268 .47296 Mtetra
.897 .663 .575 r
.27268 .47296 .27615 .48672 .28399 .46546 .28264 .42348 Mtetra
.808 .563 .567 r
.28264 .42348 .28399 .46546 .29414 .41103 .29299 .36645 Mtetra
.769 .529 .571 r
.29299 .36645 .29414 .41103 .30411 .35645 .30217 .3231 Mtetra
.749 .521 .585 r
.30217 .3231 .30411 .35645 .31285 .31747 .3101 .29588 Mtetra
.738 .533 .616 r
.3101 .29588 .31285 .31747 .32045 .29372 .31717 .28016 Mtetra
.728 .563 .667 r
.31717 .28016 .32045 .29372 .32734 .28023 .32376 .27137 Mtetra
.704 .605 .743 r
.32376 .27137 .32734 .28023 .33382 .27284 .33007 .26664 Mtetra
.642 .645 .838 r
.33007 .26664 .33382 .27284 .34007 .26914 .33624 .26453 Mtetra
.473 .642 .931 r
.33624 .26453 .34007 .26914 .34619 .26804 .34229 .26459 Mtetra
.009 .443 .866 r
.34229 .26459 .34619 .26804 .35218 .26933 .34822 .26699 Mtetra
.601 .048 0 r
.34822 .26699 .35218 .26933 .35806 .27339 .35403 .27234 Mtetra
.817 .339 .05 r
.35403 .27234 .35806 .27339 .36379 .28094 .35969 .28142 Mtetra
.864 .445 .227 r
.35969 .28142 .36379 .28094 .36937 .29262 .36519 .29468 Mtetra
.869 .48 .3 r
.36519 .29468 .36937 .29262 .37484 .30813 .3706 .31119 Mtetra
.857 .47 .312 r
.3706 .31119 .37484 .30813 .38033 .32513 .37612 .32756 Mtetra
.806 .376 .225 r
.37612 .32756 .38033 .32513 .38606 .33854 .38199 .33803 Mtetra
.231 .743 .874 r
.38199 .33803 .38606 .33854 .39228 .34243 .38841 .33732 Mtetra
.885 .75 .707 r
.38841 .33732 .39228 .34243 .39902 .33399 .39534 .32469 Mtetra
.873 .678 .635 r
.39534 .32469 .39902 .33399 .40612 .31598 .40254 .30458 Mtetra
.859 .654 .624 r
.40254 .30458 .40612 .31598 .4133 .29434 .40974 .283 Mtetra
.846 .648 .634 r
.40974 .283 .4133 .29434 .42036 .27412 .41678 .26405 Mtetra
.834 .653 .658 r
.41678 .26405 .42036 .27412 .42725 .25769 .42363 .24915 Mtetra
.819 .666 .694 r
.42363 .24915 .42725 .25769 .43398 .24527 .43033 .23806 Mtetra
.8 .684 .736 r
.43033 .23806 .43398 .24527 .44059 .23614 .43692 .22992 Mtetra
.777 .702 .781 r
.43692 .22992 .44059 .23614 .44712 .2294 .44345 .22385 Mtetra
.752 .717 .819 r
.44345 .22385 .44712 .2294 .45362 .22427 .44994 .21915 Mtetra
.727 .727 .85 r
.44994 .21915 .45362 .22427 .46009 .22017 .45642 .21533 Mtetra
.707 .733 .871 r
.45642 .21533 .46009 .22017 .46657 .21673 .4629 .21205 Mtetra
.693 .736 .884 r
.4629 .21205 .46657 .21673 .47304 .2137 .46938 .20912 Mtetra
.682 .738 .893 r
.46938 .20912 .47304 .2137 .47953 .21091 .47588 .20639 Mtetra
.675 .739 .899 r
.47588 .20639 .47953 .21091 .48602 .20827 .48238 .20378 Mtetra
.671 .74 .902 r
.48238 .20378 .48602 .20827 .49253 .20573 .4889 .20125 Mtetra
.668 .74 .904 r
.4889 .20125 .49253 .20573 .49905 .20324 .49543 .19877 Mtetra
.667 .741 .905 r
.49543 .19877 .49905 .20324 .50559 .20077 .50198 .1963 Mtetra
.666 .741 .906 r
.50198 .1963 .50559 .20077 .51214 .19833 .50855 .19385 Mtetra
.665 .741 .907 r
.50855 .19385 .51214 .19833 .51871 .19589 .51513 .19141 Mtetra
.51513 .19141 .51871 .19589 .5253 .19345 .52172 .18896 Mtetra
.664 .741 .907 r
.52172 .18896 .5253 .19345 .5319 .19102 .52833 .18651 Mtetra
.52833 .18651 .5319 .19102 .53852 .18858 .53496 .18406 Mtetra
.53496 .18406 .53852 .18858 .54515 .18613 .5416 .18161 Mtetra
.5416 .18161 .54515 .18613 .5518 .18368 .54826 .17915 Mtetra
.54826 .17915 .5518 .18368 .55846 .18123 .55494 .17669 Mtetra
.55494 .17669 .55846 .18123 .56514 .17877 .56163 .17422 Mtetra
.56163 .17422 .56514 .17877 .57184 .17631 .56833 .17174 Mtetra
.56833 .17174 .57184 .17631 .57855 .17383 .57506 .16926 Mtetra
.57506 .16926 .57855 .17383 .58528 .17136 .5818 .16677 Mtetra
.5818 .16677 .58528 .17136 .59202 .16888 .58855 .16428 Mtetra
.58855 .16428 .59202 .16888 .59879 .16639 .59533 .16178 Mtetra
.59533 .16178 .59879 .16639 .60556 .16389 .60212 .15927 Mtetra
.60212 .15927 .60556 .16389 .61236 .16139 .60892 .15676 Mtetra
.60892 .15676 .61236 .16139 .61917 .15888 .61574 .15424 Mtetra
.61574 .15424 .61917 .15888 .626 .15637 .62258 .15172 Mtetra
.62258 .15172 .626 .15637 .63284 .15385 .62944 .14919 Mtetra
.62944 .14919 .63284 .15385 .6397 .15133 .63631 .14665 Mtetra
.63631 .14665 .6397 .15133 .64658 .1488 .6432 .14411 Mtetra
.6432 .14411 .64658 .1488 .65348 .14626 .65011 .14156 Mtetra
.65011 .14156 .65348 .14626 .66039 .14371 .65703 .139 Mtetra
.65703 .139 .66039 .14371 .66732 .14116 .66397 .13644 Mtetra
.66397 .13644 .66732 .14116 .67426 .13861 .67093 .13387 Mtetra
.67093 .13387 .67426 .13861 .68123 .13605 .6779 .1313 Mtetra
.6779 .1313 .68123 .13605 .68821 .13348 .6849 .12872 Mtetra
.6849 .12872 .68821 .13348 .69521 .1309 .69191 .12613 Mtetra
.69191 .12613 .69521 .1309 .70222 .12832 .69893 .12354 Mtetra
.69893 .12354 .70222 .12832 .70925 .12573 .70598 .12094 Mtetra
.70598 .12094 .70925 .12573 .7163 .12314 .71304 .11833 Mtetra
.71304 .11833 .7163 .12314 .72337 .12054 .72012 .11572 Mtetra
.72012 .11572 .72337 .12054 .73045 .11793 .72721 .1131 Mtetra
.72721 .1131 .73045 .11793 .73756 .11531 .73433 .11047 Mtetra
.73433 .11047 .73756 .11531 .74468 .1127 .74146 .10784 Mtetra
.74146 .10784 .74468 .1127 .75181 .11007 .74861 .1052 Mtetra
.74861 .1052 .75181 .11007 .75897 .10743 .75578 .10255 Mtetra
.11946 .332 .12362 .33588 .1293 .33378 .12516 .32989 Mtetra
.12516 .32989 .1293 .33378 .135 .33168 .13086 .32778 Mtetra
.13086 .32778 .135 .33168 .14072 .32957 .13658 .32566 Mtetra
.13658 .32566 .14072 .32957 .14644 .32746 .14232 .32354 Mtetra
.14232 .32354 .14644 .32746 .15218 .32534 .14806 .32142 Mtetra
.14806 .32142 .15218 .32534 .15793 .32322 .15382 .31928 Mtetra
.15382 .31928 .15793 .32322 .1637 .32109 .15959 .31715 Mtetra
.15959 .31715 .1637 .32109 .16947 .31896 .16538 .31501 Mtetra
.16538 .31501 .16947 .31896 .17526 .31682 .17118 .31286 Mtetra
.17118 .31286 .17526 .31682 .18107 .31468 .17699 .31071 Mtetra
.663 .741 .908 r
.17699 .31071 .18107 .31468 .18688 .31254 .18281 .30857 Mtetra
.18281 .30857 .18688 .31254 .19271 .31039 .18864 .30642 Mtetra
.662 .741 .908 r
.18864 .30642 .19271 .31039 .19855 .30826 .19449 .30428 Mtetra
.66 .741 .91 r
.19449 .30428 .19855 .30826 .2044 .30613 .20035 .30217 Mtetra
.656 .741 .913 r
.20035 .30217 .2044 .30613 .21027 .30403 .20621 .30012 Mtetra
.648 .742 .918 r
.20621 .30012 .21027 .30403 .21614 .302 .21208 .29817 Mtetra
.631 .742 .928 r
.21208 .29817 .21614 .302 .222 .30011 .21794 .29645 Mtetra
.588 .739 .948 r
.21794 .29645 .222 .30011 .22786 .29848 .22377 .29521 Mtetra
.468 .717 .978 r
.22377 .29521 .22786 .29848 .23368 .29742 .22952 .2949 Mtetra
.028 .516 .878 r
.22952 .2949 .23368 .29742 .23942 .29747 .23513 .29643 Mtetra
.691 .149 0 r
.23513 .29643 .23942 .29747 .24498 .29971 .24043 .30155 Mtetra
.838 .438 .289 r
.24043 .30155 .24498 .29971 .2502 .30614 .24518 .31332 Mtetra
.848 .515 .422 r
.24518 .31332 .2502 .30614 .25481 .32027 .24901 .33645 Mtetra
.84 .535 .473 r
.24901 .33645 .25481 .32027 .25842 .34707 .25157 .37565 Mtetra
.819 .526 .493 r
.25157 .37565 .25842 .34707 .2608 .39044 .25316 .42848 Mtetra
.77 .481 .495 r
.25316 .42848 .2608 .39044 .26253 .44415 .2556 .47358 Mtetra
.559 .266 .426 r
.2556 .47358 .26253 .44415 .26575 .48173 .26151 .47775 Mtetra
.942 .724 .579 r
.26151 .47775 .26575 .48173 .27268 .47296 .27106 .43558 Mtetra
.823 .578 .568 r
.27106 .43558 .27268 .47296 .28264 .42348 .28169 .37746 Mtetra
.777 .534 .569 r
.28169 .37746 .28264 .42348 .29299 .36645 .29134 .32982 Mtetra
.753 .521 .58 r
.29134 .32982 .29299 .36645 .30217 .3231 .29963 .29882 Mtetra
.741 .528 .606 r
.29963 .29882 .30217 .3231 .3101 .29588 .30693 .28062 Mtetra
.732 .554 .652 r
.30693 .28062 .3101 .29588 .31717 .28016 .31364 .27031 Mtetra
.716 .595 .72 r
.31364 .27031 .31717 .28016 .32376 .27137 .32003 .26455 Mtetra
.675 .639 .806 r
.32003 .26455 .32376 .27137 .33007 .26664 .32624 .26156 Mtetra
.572 .663 .899 r
.32624 .26156 .33007 .26664 .33624 .26453 .33234 .26061 Mtetra
.304 .598 .948 r
.33234 .26061 .33624 .26453 .34229 .26459 .33833 .26165 Mtetra
0 .245 .686 r
.33833 .26165 .34229 .26459 .34822 .26699 .34421 .26515 Mtetra
.725 .196 0 r
.34421 .26515 .34822 .26699 .35403 .27234 .34995 .27185 Mtetra
.844 .392 .137 r
.34995 .27185 .35403 .27234 .35969 .28142 .35552 .28252 Mtetra
.868 .464 .263 r
.35552 .28252 .35969 .28142 .36519 .29468 .36094 .29723 Mtetra
.867 .482 .311 r
.36094 .29723 .36519 .29468 .3706 .31119 .36633 .31425 Mtetra
.846 .452 .298 r
.36633 .31425 .3706 .31119 .37612 .32756 .37191 .32916 Mtetra
.734 .25 .093 r
.37191 .32916 .37612 .32756 .38199 .33803 .37796 .33588 Mtetra
.824 .887 .888 r
.37796 .33588 .38199 .33803 .38841 .33732 .3846 .33046 Mtetra
.882 .712 .666 r
.3846 .33046 .38841 .33732 .39534 .32469 .3917 .3143 Mtetra
.867 .666 .628 r
.3917 .3143 .39534 .32469 .40254 .30458 .39897 .29297 Mtetra
.854 .65 .626 r
.39897 .29297 .40254 .30458 .40974 .283 .40616 .27203 Mtetra
.842 .649 .642 r
.40616 .27203 .40974 .283 .41678 .26405 .41316 .25453 Mtetra
.829 .657 .67 r
.41316 .25453 .41678 .26405 .42363 .24915 .41998 .24113 Mtetra
.813 .673 .709 r
.41998 .24113 .42363 .24915 .43033 .23806 .42665 .23124 Mtetra
.792 .691 .753 r
.42665 .23124 .43033 .23806 .43692 .22992 .43323 .22396 Mtetra
.768 .708 .796 r
.43323 .22396 .43692 .22992 .44345 .22385 .43976 .21847 Mtetra
.742 .721 .832 r
.43976 .21847 .44345 .22385 .44994 .21915 .44625 .21414 Mtetra
.719 .729 .858 r
.44625 .21414 .44994 .21915 .45642 .21533 .45274 .21054 Mtetra
.701 .734 .877 r
.45274 .21054 .45642 .21533 .4629 .21205 .45922 .2074 Mtetra
.688 .737 .888 r
.45922 .2074 .4629 .21205 .46938 .20912 .46571 .20455 Mtetra
.679 .739 .896 r
.46571 .20455 .46938 .20912 .47588 .20639 .47221 .20186 Mtetra
.674 .74 .9 r
.47221 .20186 .47588 .20639 .48238 .20378 .47873 .19928 Mtetra
.67 .74 .903 r
.47873 .19928 .48238 .20378 .4889 .20125 .48526 .19676 Mtetra
.668 .74 .905 r
.48526 .19676 .4889 .20125 .49543 .19877 .4918 .19428 Mtetra
.666 .741 .906 r
.4918 .19428 .49543 .19877 .50198 .1963 .49836 .19181 Mtetra
.665 .741 .906 r
.49836 .19181 .50198 .1963 .50855 .19385 .50493 .18936 Mtetra
.665 .741 .907 r
.50493 .18936 .50855 .19385 .51513 .19141 .51152 .1869 Mtetra
.664 .741 .907 r
.51152 .1869 .51513 .19141 .52172 .18896 .51813 .18445 Mtetra
.51813 .18445 .52172 .18896 .52833 .18651 .52475 .18199 Mtetra
.52475 .18199 .52833 .18651 .53496 .18406 .53139 .17953 Mtetra
.53139 .17953 .53496 .18406 .5416 .18161 .53804 .17707 Mtetra
.53804 .17707 .5416 .18161 .54826 .17915 .54471 .1746 Mtetra
.54471 .1746 .54826 .17915 .55494 .17669 .55139 .17212 Mtetra
.55139 .17212 .55494 .17669 .56163 .17422 .5581 .16964 Mtetra
.5581 .16964 .56163 .17422 .56833 .17174 .56481 .16715 Mtetra
.56481 .16715 .56833 .17174 .57506 .16926 .57155 .16466 Mtetra
.57155 .16466 .57506 .16926 .5818 .16677 .5783 .16216 Mtetra
.5783 .16216 .5818 .16677 .58855 .16428 .58507 .15966 Mtetra
.58507 .15966 .58855 .16428 .59533 .16178 .59185 .15715 Mtetra
.59185 .15715 .59533 .16178 .60212 .15927 .59865 .15463 Mtetra
.59865 .15463 .60212 .15927 .60892 .15676 .60547 .15211 Mtetra
.60547 .15211 .60892 .15676 .61574 .15424 .6123 .14958 Mtetra
.6123 .14958 .61574 .15424 .62258 .15172 .61915 .14704 Mtetra
.61915 .14704 .62258 .15172 .62944 .14919 .62602 .1445 Mtetra
.62602 .1445 .62944 .14919 .63631 .14665 .6329 .14195 Mtetra
.6329 .14195 .63631 .14665 .6432 .14411 .6398 .1394 Mtetra
.6398 .1394 .6432 .14411 .65011 .14156 .64672 .13683 Mtetra
.64672 .13683 .65011 .14156 .65703 .139 .65366 .13427 Mtetra
.65366 .13427 .65703 .139 .66397 .13644 .66061 .13169 Mtetra
.66061 .13169 .66397 .13644 .67093 .13387 .66758 .12911 Mtetra
.66758 .12911 .67093 .13387 .6779 .1313 .67456 .12653 Mtetra
.67456 .12653 .6779 .1313 .6849 .12872 .68157 .12394 Mtetra
.68157 .12394 .6849 .12872 .69191 .12613 .68859 .12134 Mtetra
.68859 .12134 .69191 .12613 .69893 .12354 .69563 .11873 Mtetra
.69563 .11873 .69893 .12354 .70598 .12094 .70269 .11612 Mtetra
.70269 .11612 .70598 .12094 .71304 .11833 .70976 .1135 Mtetra
.70976 .1135 .71304 .11833 .72012 .11572 .71685 .11088 Mtetra
.71685 .11088 .72012 .11572 .72721 .1131 .72396 .10825 Mtetra
.72396 .10825 .72721 .1131 .73433 .11047 .73109 .10561 Mtetra
.73109 .10561 .73433 .11047 .74146 .10784 .73823 .10296 Mtetra
.73823 .10296 .74146 .10784 .74861 .1052 .7454 .10031 Mtetra
.7454 .10031 .74861 .1052 .75578 .10255 .75258 .09765 Mtetra
.11529 .32811 .11946 .332 .12516 .32989 .12099 .32599 Mtetra
.12099 .32599 .12516 .32989 .13086 .32778 .12671 .32387 Mtetra
.12671 .32387 .13086 .32778 .13658 .32566 .13243 .32174 Mtetra
.13243 .32174 .13658 .32566 .14232 .32354 .13817 .31961 Mtetra
.13817 .31961 .14232 .32354 .14806 .32142 .14393 .31748 Mtetra
.14393 .31748 .14806 .32142 .15382 .31928 .14969 .31534 Mtetra
.14969 .31534 .15382 .31928 .15959 .31715 .15547 .31319 Mtetra
.15547 .31319 .15959 .31715 .16538 .31501 .16126 .31104 Mtetra
.16126 .31104 .16538 .31501 .17118 .31286 .16707 .30889 Mtetra
.663 .741 .908 r
.16707 .30889 .17118 .31286 .17699 .31071 .17289 .30674 Mtetra
.17289 .30674 .17699 .31071 .18281 .30857 .17872 .30458 Mtetra
.662 .741 .908 r
.17872 .30458 .18281 .30857 .18864 .30642 .18456 .30244 Mtetra
.661 .741 .909 r
.18456 .30244 .18864 .30642 .19449 .30428 .19041 .30031 Mtetra
.657 .741 .912 r
.19041 .30031 .19449 .30428 .20035 .30217 .19627 .29823 Mtetra
.651 .741 .916 r
.19627 .29823 .20035 .30217 .20621 .30012 .20214 .29625 Mtetra
.637 .742 .924 r
.20214 .29625 .20621 .30012 .21208 .29817 .208 .29445 Mtetra
.603 .741 .941 r
.208 .29445 .21208 .29817 .21794 .29645 .21383 .29305 Mtetra
.513 .728 .971 r
.21383 .29305 .21794 .29645 .22377 .29521 .2196 .29243 Mtetra
.196 .61 .947 r
.2196 .29243 .22377 .29521 .22952 .2949 .22524 .29337 Mtetra
.572 0 0 r
.22524 .29337 .22952 .2949 .23513 .29643 .23062 .29736 Mtetra
.825 .399 .227 r
.23062 .29736 .23513 .29643 .24043 .30155 .23551 .30707 Mtetra
.848 .504 .401 r
.23551 .30707 .24043 .30155 .24518 .31332 .23954 .32686 Mtetra
.843 .533 .464 r
.23954 .32686 .24518 .31332 .24901 .33645 .24232 .36181 Mtetra
.826 .53 .49 r
.24232 .36181 .24901 .33645 .25157 .37565 .2439 .41237 Mtetra
.787 .497 .497 r
.2439 .41237 .25157 .37565 .25316 .42848 .24572 .46264 Mtetra
.662 .37 .466 r
.24572 .46264 .25316 .42848 .2556 .47358 .25053 .47939 Mtetra
.995 .83 .566 r
.25053 .47939 .2556 .47358 .26151 .47775 .25944 .44676 Mtetra
.842 .598 .569 r
.25944 .44676 .26151 .47775 .27106 .43558 .27022 .38928 Mtetra
.785 .541 .567 r
.27022 .38928 .27106 .43558 .28169 .37746 .28035 .33766 Mtetra
.757 .522 .576 r
.28035 .33766 .28169 .37746 .29134 .32982 .28905 .30261 Mtetra
.743 .525 .598 r
.28905 .30261 .29134 .32982 .29963 .29882 .29661 .28164 Mtetra
.735 .546 .638 r
.29661 .28164 .29963 .29882 .30693 .28062 .30347 .26964 Mtetra
.723 .585 .7 r
.30347 .26964 .30693 .28062 .31364 .27031 .30994 .26282 Mtetra
.695 .63 .78 r
.30994 .26282 .31364 .27031 .32003 .26455 .31621 .25901 Mtetra
.629 .666 .867 r
.31621 .25901 .32003 .26455 .32624 .26156 .32235 .25721 Mtetra
.472 .658 .942 r
.32235 .25721 .32624 .26156 .33234 .26061 .32839 .25717 Mtetra
.08 .494 .898 r
.32839 .25717 .33234 .26061 .33833 .26165 .33433 .25916 Mtetra
.516 0 0 r
.33433 .25916 .33833 .26165 .34421 .26515 .34015 .26381 Mtetra
.792 .295 0 r
.34015 .26381 .34421 .26515 .34995 .27185 .3458 .27195 Mtetra
.858 .429 .198 r
.3458 .27195 .34995 .27185 .35552 .28252 .35128 .28421 Mtetra
.87 .476 .289 r
.35128 .28421 .35552 .28252 .36094 .29723 .35664 .30014 Mtetra
.862 .477 .315 r
.35664 .30014 .36094 .29723 .36633 .31425 .36203 .31704 Mtetra
.827 .416 .266 r
.36203 .31704 .36633 .31425 .37191 .32916 .36773 .32958 Mtetra
.441 0 0 r
.36773 .32958 .37191 .32916 .37796 .33588 .37399 .33195 Mtetra
.881 .789 .754 r
.37399 .33195 .37796 .33588 .3846 .33046 .38086 .32203 Mtetra
.877 .688 .644 r
.38086 .32203 .3846 .33046 .3917 .3143 .38809 .30317 Mtetra
.862 .657 .624 r
.38809 .30317 .3917 .3143 .39897 .29297 .3954 .28142 Mtetra
.849 .648 .63 r
.3954 .28142 .39897 .29297 .40616 .27203 .40257 .26155 Mtetra
.837 .651 .651 r
.40257 .26155 .40616 .27203 .41316 .25453 .40953 .24558 Mtetra
.823 .663 .684 r
.40953 .24558 .41316 .25453 .41998 .24113 .41631 .23358 Mtetra
.805 .68 .725 r
.41631 .23358 .41998 .24113 .42665 .23124 .42296 .22477 Mtetra
.783 .698 .77 r
.42296 .22477 .42665 .23124 .43323 .22396 .42952 .21824 Mtetra
.758 .713 .811 r
.42952 .21824 .43323 .22396 .43976 .21847 .43604 .21323 Mtetra
.733 .725 .843 r
.43604 .21323 .43976 .21847 .44625 .21414 .44254 .2092 Mtetra
.712 .732 .866 r
.44254 .2092 .44625 .21414 .45274 .21054 .44903 .2058 Mtetra
.696 .736 .882 r
.44903 .2058 .45274 .21054 .45922 .2074 .45552 .20277 Mtetra
.684 .738 .891 r
.45552 .20277 .45922 .2074 .46571 .20455 .46202 .19998 Mtetra
.677 .739 .898 r
.46202 .19998 .46571 .20455 .47221 .20186 .46853 .19734 Mtetra
.672 .74 .901 r
.46853 .19734 .47221 .20186 .47873 .19928 .47506 .19477 Mtetra
.669 .74 .904 r
.47506 .19477 .47873 .19928 .48526 .19676 .4816 .19226 Mtetra
.667 .74 .905 r
.4816 .19226 .48526 .19676 .4918 .19428 .48815 .18978 Mtetra
.666 .741 .906 r
.48815 .18978 .4918 .19428 .49836 .19181 .49472 .18731 Mtetra
.665 .741 .906 r
.49472 .18731 .49836 .19181 .50493 .18936 .5013 .18484 Mtetra
.665 .741 .907 r
.5013 .18484 .50493 .18936 .51152 .1869 .5079 .18238 Mtetra
.664 .741 .907 r
.5079 .18238 .51152 .1869 .51813 .18445 .51452 .17992 Mtetra
.51452 .17992 .51813 .18445 .52475 .18199 .52115 .17745 Mtetra
.52115 .17745 .52475 .18199 .53139 .17953 .5278 .17498 Mtetra
.5278 .17498 .53139 .17953 .53804 .17707 .53446 .1725 Mtetra
.53446 .1725 .53804 .17707 .54471 .1746 .54114 .17002 Mtetra
.54114 .17002 .54471 .1746 .55139 .17212 .54784 .16754 Mtetra
.54784 .16754 .55139 .17212 .5581 .16964 .55455 .16504 Mtetra
.55455 .16504 .5581 .16964 .56481 .16715 .56128 .16255 Mtetra
.56128 .16255 .56481 .16715 .57155 .16466 .56802 .16004 Mtetra
.56802 .16004 .57155 .16466 .5783 .16216 .57479 .15753 Mtetra
.57479 .15753 .5783 .16216 .58507 .15966 .58156 .15502 Mtetra
.58156 .15502 .58507 .15966 .59185 .15715 .58836 .15249 Mtetra
.58836 .15249 .59185 .15715 .59865 .15463 .59517 .14997 Mtetra
.59517 .14997 .59865 .15463 .60547 .15211 .602 .14743 Mtetra
.602 .14743 .60547 .15211 .6123 .14958 .60884 .14489 Mtetra
.60884 .14489 .6123 .14958 .61915 .14704 .6157 .14234 Mtetra
.6157 .14234 .61915 .14704 .62602 .1445 .62258 .13979 Mtetra
.62258 .13979 .62602 .1445 .6329 .14195 .62948 .13723 Mtetra
.62948 .13723 .6329 .14195 .6398 .1394 .63639 .13466 Mtetra
.63639 .13466 .6398 .1394 .64672 .13683 .64332 .13209 Mtetra
.64332 .13209 .64672 .13683 .65366 .13427 .65027 .12951 Mtetra
.65027 .12951 .65366 .13427 .66061 .13169 .65723 .12693 Mtetra
.65723 .12693 .66061 .13169 .66758 .12911 .66421 .12433 Mtetra
.66421 .12433 .66758 .12911 .67456 .12653 .67121 .12174 Mtetra
.67121 .12174 .67456 .12653 .68157 .12394 .67823 .11913 Mtetra
.67823 .11913 .68157 .12394 .68859 .12134 .68526 .11652 Mtetra
.68526 .11652 .68859 .12134 .69563 .11873 .69231 .1139 Mtetra
.69231 .1139 .69563 .11873 .70269 .11612 .69938 .11128 Mtetra
.69938 .11128 .70269 .11612 .70976 .1135 .70647 .10865 Mtetra
.70647 .10865 .70976 .1135 .71685 .11088 .71357 .10601 Mtetra
.71357 .10601 .71685 .11088 .72396 .10825 .72069 .10337 Mtetra
.72069 .10337 .72396 .10825 .73109 .10561 .72783 .10072 Mtetra
.72783 .10072 .73109 .10561 .73823 .10296 .73499 .09806 Mtetra
.73499 .09806 .73823 .10296 .7454 .10031 .74216 .0954 Mtetra
.74216 .0954 .7454 .10031 .75258 .09765 .74936 .09273 Mtetra
.1111 .3242 .11529 .32811 .12099 .32599 .11681 .32207 Mtetra
.11681 .32207 .12099 .32599 .12671 .32387 .12253 .31994 Mtetra
.12253 .31994 .12671 .32387 .13243 .32174 .12827 .31781 Mtetra
.12827 .31781 .13243 .32174 .13817 .31961 .13402 .31567 Mtetra
.13402 .31567 .13817 .31961 .14393 .31748 .13978 .31352 Mtetra
.13978 .31352 .14393 .31748 .14969 .31534 .14555 .31137 Mtetra
.14555 .31137 .14969 .31534 .15547 .31319 .15134 .30922 Mtetra
.15134 .30922 .15547 .31319 .16126 .31104 .15713 .30706 Mtetra
.663 .741 .908 r
.15713 .30706 .16126 .31104 .16707 .30889 .16295 .3049 Mtetra
.16295 .3049 .16707 .30889 .17289 .30674 .16877 .30275 Mtetra
.16877 .30275 .17289 .30674 .17872 .30458 .17461 .30059 Mtetra
.661 .741 .909 r
.17461 .30059 .17872 .30458 .18456 .30244 .18046 .29845 Mtetra
.658 .741 .911 r
.18046 .29845 .18456 .30244 .19041 .30031 .18631 .29635 Mtetra
.653 .742 .915 r
.18631 .29635 .19041 .30031 .19627 .29823 .19217 .29433 Mtetra
.641 .742 .922 r
.19217 .29433 .19627 .29823 .20214 .29625 .19803 .29246 Mtetra
.614 .741 .936 r
.19803 .29246 .20214 .29625 .208 .29445 .20387 .29093 Mtetra
.545 .734 .963 r
.20387 .29093 .208 .29445 .21383 .29305 .20966 .29006 Mtetra
.32 .667 .975 r
.20966 .29006 .21383 .29305 .2196 .29243 .21533 .2905 Mtetra
.396 0 0 r
.21533 .2905 .2196 .29243 .22524 .29337 .22078 .29352 Mtetra
.803 .343 .142 r
.22078 .29352 .22524 .29337 .23062 .29736 .22579 .30146 Mtetra
.847 .488 .374 r
.22579 .30146 .23062 .29736 .23551 .30707 .23001 .31823 Mtetra
.845 .529 .454 r
.23001 .31823 .23551 .30707 .23954 .32686 .23304 .34901 Mtetra
.831 .534 .486 r
.23304 .34901 .23954 .32686 .24232 .36181 .23471 .39633 Mtetra
.8 .51 .497 r
.23471 .39633 .24232 .36181 .2439 .41237 .23606 .44948 Mtetra
.715 .424 .483 r
.23606 .44948 .2439 .41237 .24572 .46264 .2398 .47767 Mtetra
.706 .775 .286 r
.2398 .47767 .24572 .46264 .25053 .47939 .24784 .45639 Mtetra
.865 .624 .572 r
.24784 .45639 .25053 .47939 .25944 .44676 .2586 .40163 Mtetra
.796 .551 .567 r
.2586 .40163 .25944 .44676 .27022 .38928 .26918 .34665 Mtetra
.763 .524 .573 r
.26918 .34665 .27022 .38928 .28035 .33766 .27834 .30734 Mtetra
.746 .522 .591 r
.27834 .30734 .28035 .33766 .28905 .30261 .28621 .28327 Mtetra
.737 .54 .625 r
.28621 .28327 .28905 .30261 .29661 .28164 .29324 .26937 Mtetra
.729 .574 .681 r
.29324 .26937 .29661 .28164 .30347 .26964 .29981 .2614 Mtetra
.709 .62 .756 r
.29981 .2614 .30347 .26964 .30994 .26282 .30613 .2568 Mtetra
.663 .662 .838 r
.30613 .2568 .30994 .26282 .31621 .25901 .31231 .25427 Mtetra
.564 .679 .916 r
.31231 .25427 .31621 .25901 .32235 .25721 .3184 .25337 Mtetra
.334 .622 .956 r
.3184 .25337 .32235 .25721 .32839 .25717 .3244 .25415 Mtetra
0 .333 .764 r
.3244 .25415 .32839 .25717 .33433 .25916 .33028 .2571 Mtetra
.668 .122 0 r
.33028 .2571 .33433 .25916 .34015 .26381 .33602 .26299 Mtetra
.829 .362 .09 r
.33602 .26299 .34015 .26381 .3458 .27195 .34159 .27265 Mtetra
.866 .453 .242 r
.34159 .27265 .3458 .27195 .35128 .28421 .34698 .28645 Mtetra
.869 .481 .305 r
.34698 .28645 .35128 .28421 .35664 .30014 .35229 .30321 Mtetra
.854 .465 .309 r
.35229 .30321 .35664 .30014 .36203 .31704 .35772 .31921 Mtetra
.789 .345 .193 r
.35772 .31921 .36203 .31704 .36773 .32958 .36359 .32852 Mtetra
.572 .903 .98 r
.36359 .32852 .36773 .32958 .37399 .33195 .3701 .32621 Mtetra
.884 .735 .691 r
.3701 .32621 .37399 .33195 .38086 .32203 .37716 .31228 Mtetra
.871 .673 .632 r
.37716 .31228 .38086 .32203 .38809 .30317 .3845 .29162 Mtetra
.857 .652 .624 r
.3845 .29162 .38809 .30317 .3954 .28142 .39182 .27014 Mtetra
.845 .648 .636 r
.39182 .27014 .3954 .28142 .40257 .26155 .39895 .25161 Mtetra
.832 .655 .662 r
.39895 .25161 .40257 .26155 .40953 .24558 .40587 .23717 Mtetra
.817 .669 .699 r
.40587 .23717 .40953 .24558 .41631 .23358 .41261 .22646 Mtetra
.798 .687 .742 r
.41261 .22646 .41631 .23358 .42296 .22477 .41924 .2186 Mtetra
.774 .704 .786 r
.41924 .2186 .42296 .22477 .42952 .21824 .4258 .2127 Mtetra
.748 .718 .824 r
.4258 .2127 .42952 .21824 .43604 .21323 .43231 .2081 Mtetra
.725 .728 .853 r
.43231 .2081 .43604 .21323 .44254 .2092 .43881 .20434 Mtetra
.705 .733 .873 r
.43881 .20434 .44254 .2092 .44903 .2058 .44531 .20109 Mtetra
.691 .737 .886 r
.44531 .20109 .44903 .2058 .45552 .20277 .45181 .19816 Mtetra
.681 .738 .894 r
.45181 .19816 .45552 .20277 .46202 .19998 .45832 .19542 Mtetra
.675 .739 .899 r
.45832 .19542 .46202 .19998 .46853 .19734 .46484 .1928 Mtetra
.671 .74 .902 r
.46484 .1928 .46853 .19734 .47506 .19477 .47137 .19025 Mtetra
.668 .74 .904 r
.47137 .19025 .47506 .19477 .4816 .19226 .47792 .18774 Mtetra
.666 .741 .905 r
.47792 .18774 .4816 .19226 .48815 .18978 .48448 .18526 Mtetra
.665 .741 .906 r
.48448 .18526 .48815 .18978 .49472 .18731 .49106 .18278 Mtetra
.665 .741 .907 r
.49106 .18278 .49472 .18731 .5013 .18484 .49766 .18031 Mtetra
.664 .741 .907 r
.49766 .18031 .5013 .18484 .5079 .18238 .50427 .17784 Mtetra
.50427 .17784 .5079 .18238 .51452 .17992 .51089 .17537 Mtetra
.51089 .17537 .51452 .17992 .52115 .17745 .51753 .17289 Mtetra
.51753 .17289 .52115 .17745 .5278 .17498 .52419 .17041 Mtetra
.52419 .17041 .5278 .17498 .53446 .1725 .53087 .16792 Mtetra
.53087 .16792 .53446 .1725 .54114 .17002 .53756 .16543 Mtetra
.53756 .16543 .54114 .17002 .54784 .16754 .54426 .16293 Mtetra
.54426 .16293 .54784 .16754 .55455 .16504 .55099 .16043 Mtetra
.55099 .16043 .55455 .16504 .56128 .16255 .55773 .15792 Mtetra
.55773 .15792 .56128 .16255 .56802 .16004 .56448 .1554 Mtetra
.56448 .1554 .56802 .16004 .57479 .15753 .57126 .15288 Mtetra
.57126 .15288 .57479 .15753 .58156 .15502 .57804 .15035 Mtetra
.57804 .15035 .58156 .15502 .58836 .15249 .58485 .14782 Mtetra
.58485 .14782 .58836 .15249 .59517 .14997 .59167 .14528 Mtetra
.59167 .14528 .59517 .14997 .602 .14743 .59851 .14273 Mtetra
.59851 .14273 .602 .14743 .60884 .14489 .60537 .14018 Mtetra
.60537 .14018 .60884 .14489 .6157 .14234 .61224 .13762 Mtetra
.61224 .13762 .6157 .14234 .62258 .13979 .61913 .13506 Mtetra
.61913 .13506 .62258 .13979 .62948 .13723 .62604 .13249 Mtetra
.62604 .13249 .62948 .13723 .63639 .13466 .63296 .12991 Mtetra
.63296 .12991 .63639 .13466 .64332 .13209 .6399 .12732 Mtetra
.6399 .12732 .64332 .13209 .65027 .12951 .64686 .12473 Mtetra
.64686 .12473 .65027 .12951 .65723 .12693 .65384 .12214 Mtetra
.65384 .12214 .65723 .12693 .66421 .12433 .66083 .11953 Mtetra
.66083 .11953 .66421 .12433 .67121 .12174 .66784 .11692 Mtetra
.66784 .11692 .67121 .12174 .67823 .11913 .67487 .11431 Mtetra
.67487 .11431 .67823 .11913 .68526 .11652 .68191 .11168 Mtetra
.68191 .11168 .68526 .11652 .69231 .1139 .68898 .10906 Mtetra
.68898 .10906 .69231 .1139 .69938 .11128 .69606 .10642 Mtetra
.69606 .10642 .69938 .11128 .70647 .10865 .70316 .10378 Mtetra
.70316 .10378 .70647 .10865 .71357 .10601 .71027 .10113 Mtetra
.71027 .10113 .71357 .10601 .72069 .10337 .71741 .09847 Mtetra
.71741 .09847 .72069 .10337 .72783 .10072 .72456 .09581 Mtetra
.72456 .09581 .72783 .10072 .73499 .09806 .73173 .09314 Mtetra
.73173 .09314 .73499 .09806 .74216 .0954 .73892 .09046 Mtetra
.73892 .09046 .74216 .0954 .74936 .09273 .74612 .08778 Mtetra
.1069 .32027 .1111 .3242 .11681 .32207 .11261 .31813 Mtetra
.11261 .31813 .11681 .32207 .12253 .31994 .11834 .316 Mtetra
.11834 .316 .12253 .31994 .12827 .31781 .12408 .31385 Mtetra
.12408 .31385 .12827 .31781 .13402 .31567 .12984 .3117 Mtetra
.12984 .3117 .13402 .31567 .13978 .31352 .13561 .30955 Mtetra
.13561 .30955 .13978 .31352 .14555 .31137 .14139 .30739 Mtetra
.14139 .30739 .14555 .31137 .15134 .30922 .14718 .30523 Mtetra
.14718 .30523 .15134 .30922 .15713 .30706 .15299 .30307 Mtetra
.663 .741 .908 r
.15299 .30307 .15713 .30706 .16295 .3049 .15881 .3009 Mtetra
.15881 .3009 .16295 .3049 .16877 .30275 .16464 .29874 Mtetra
.662 .741 .909 r
.16464 .29874 .16877 .30275 .17461 .30059 .17048 .29659 Mtetra
.659 .741 .91 r
.17048 .29659 .17461 .30059 .18046 .29845 .17633 .29447 Mtetra
.655 .741 .913 r
.17633 .29447 .18046 .29845 .18631 .29635 .18219 .29242 Mtetra
.645 .742 .919 r
.18219 .29242 .18631 .29635 .19217 .29433 .18805 .2905 Mtetra
.624 .742 .932 r
.18805 .2905 .19217 .29433 .19803 .29246 .19389 .28885 Mtetra
.57 .737 .955 r
.19389 .28885 .19803 .29246 .20387 .29093 .19969 .28776 Mtetra
.407 .699 .981 r
.19969 .28776 .20387 .29093 .20966 .29006 .20539 .28778 Mtetra
0 .371 .745 r
.20539 .28778 .20966 .29006 .21533 .2905 .21089 .28998 Mtetra
.763 .263 .027 r
.21089 .28998 .21533 .2905 .22078 .29352 .21601 .29638 Mtetra
.844 .468 .338 r
.21601 .29638 .22078 .29352 .22579 .30146 .22042 .31048 Mtetra
.847 .524 .44 r
.22042 .31048 .22579 .30146 .23001 .31823 .2237 .3373 Mtetra
.836 .535 .48 r
.2237 .3373 .23001 .31823 .23304 .34901 .22554 .38076 Mtetra
.81 .519 .496 r
.22554 .38076 .23304 .34901 .23471 .39633 .22661 .43471 Mtetra
.748 .458 .491 r
.22661 .43471 .23471 .39633 .23606 .44948 .22935 .47257 Mtetra
.259 0 .282 r
.22935 .47257 .23606 .44948 .2398 .47767 .23634 .46385 Mtetra
.896 .662 .577 r
.23634 .46385 .2398 .47767 .24784 .45639 .24685 .41411 Mtetra
.808 .563 .567 r
.24685 .41411 .24784 .45639 .2586 .40163 .25783 .35672 Mtetra
.769 .528 .57 r
.25783 .35672 .2586 .40163 .26918 .34665 .26749 .31306 Mtetra
.749 .521 .585 r
.26749 .31306 .26918 .34665 .27834 .30734 .27571 .28557 Mtetra
.74 .534 .615 r
.27571 .28557 .27834 .30734 .28621 .28327 .28295 .26953 Mtetra
.732 .565 .665 r
.28295 .26953 .28621 .28327 .29324 .26937 .28963 .2603 Mtetra
.718 .609 .734 r
.28963 .2603 .29324 .26937 .29981 .2614 .29601 .25488 Mtetra
.685 .654 .813 r
.29601 .25488 .29981 .2614 .30613 .2568 .30224 .25171 Mtetra
.618 .683 .889 r
.30224 .25171 .30613 .2568 .31231 .25427 .30837 .25008 Mtetra
.479 .673 .949 r
.30837 .25008 .31231 .25427 .3184 .25337 .31441 .24991 Mtetra
.154 .543 .925 r
.31441 .24991 .3184 .25337 .3244 .25415 .32036 .2515 Mtetra
.412 0 0 r
.32036 .2515 .3244 .25415 .33028 .2571 .32618 .25548 Mtetra
.757 .241 0 r
.32618 .25548 .33028 .2571 .33602 .26299 .33184 .26271 Mtetra
.85 .407 .163 r
.33184 .26271 .33602 .26299 .34159 .27265 .33731 .27395 Mtetra
.869 .469 .274 r
.33731 .27395 .34159 .27265 .34698 .28645 .34262 .28912 Mtetra
.865 .481 .314 r
.34262 .28912 .34698 .28645 .35229 .30321 .3479 .3062 Mtetra
.841 .442 .29 r
.3479 .3062 .35229 .30321 .35772 .31921 .35344 .32043 Mtetra
.682 .167 .004 r
.35344 .32043 .35772 .31921 .36359 .32852 .35952 .32575 Mtetra
.858 .848 .832 r
.35952 .32575 .36359 .32852 .3701 .32621 .36627 .31876 Mtetra
.88 .703 .658 r
.36627 .31876 .3701 .32621 .37716 .31228 .37352 .30156 Mtetra
.866 .663 .626 r
.37352 .30156 .37716 .31228 .3845 .29162 .38092 .27995 Mtetra
.852 .649 .627 r
.38092 .27995 .3845 .29162 .39182 .27014 .38822 .25927 Mtetra
.84 .649 .644 r
.38822 .25927 .39182 .27014 .39895 .25161 .3953 .24223 Mtetra
.827 .659 .675 r
.3953 .24223 .39895 .25161 .40587 .23717 .40217 .22927 Mtetra
.81 .675 .714 r
.40217 .22927 .40587 .23717 .41261 .22646 .40889 .21972 Mtetra
.789 .693 .759 r
.40889 .21972 .41261 .22646 .41924 .2186 .4155 .21268 Mtetra
.764 .71 .801 r
.4155 .21268 .41924 .2186 .4258 .2127 .42205 .20733 Mtetra
.739 .722 .836 r
.42205 .20733 .4258 .2127 .43231 .2081 .42857 .20308 Mtetra
.717 .73 .861 r
.42857 .20308 .43231 .2081 .43881 .20434 .43507 .19952 Mtetra
.699 .735 .878 r
.43507 .19952 .43881 .20434 .44531 .20109 .44157 .1964 Mtetra
.687 .737 .889 r
.44157 .1964 .44531 .20109 .45181 .19816 .44808 .19355 Mtetra
.678 .739 .896 r
.44808 .19355 .45181 .19816 .45832 .19542 .45459 .19085 Mtetra
.673 .74 .901 r
.45459 .19085 .45832 .19542 .46484 .1928 .46112 .18826 Mtetra
.67 .74 .903 r
.46112 .18826 .46484 .1928 .47137 .19025 .46767 .18572 Mtetra
.667 .74 .905 r
.46767 .18572 .47137 .19025 .47792 .18774 .47423 .18321 Mtetra
.666 .741 .906 r
.47423 .18321 .47792 .18774 .48448 .18526 .4808 .18072 Mtetra
.665 .741 .906 r
.4808 .18072 .48448 .18526 .49106 .18278 .48739 .17824 Mtetra
.665 .741 .907 r
.48739 .17824 .49106 .18278 .49766 .18031 .49399 .17576 Mtetra
.664 .741 .907 r
.49399 .17576 .49766 .18031 .50427 .17784 .50061 .17328 Mtetra
.50061 .17328 .50427 .17784 .51089 .17537 .50725 .17079 Mtetra
.50725 .17079 .51089 .17537 .51753 .17289 .5139 .16831 Mtetra
.5139 .16831 .51753 .17289 .52419 .17041 .52057 .16581 Mtetra
.52057 .16581 .52419 .17041 .53087 .16792 .52726 .16332 Mtetra
.52726 .16332 .53087 .16792 .53756 .16543 .53396 .16081 Mtetra
.53396 .16081 .53756 .16543 .54426 .16293 .54068 .15831 Mtetra
.54068 .15831 .54426 .16293 .55099 .16043 .54741 .15579 Mtetra
.54741 .15579 .55099 .16043 .55773 .15792 .55416 .15327 Mtetra
.55416 .15327 .55773 .15792 .56448 .1554 .56093 .15074 Mtetra
.56093 .15074 .56448 .1554 .57126 .15288 .56771 .14821 Mtetra
.56771 .14821 .57126 .15288 .57804 .15035 .57451 .14567 Mtetra
.57451 .14567 .57804 .15035 .58485 .14782 .58133 .14313 Mtetra
.58133 .14313 .58485 .14782 .59167 .14528 .58816 .14058 Mtetra
.58816 .14058 .59167 .14528 .59851 .14273 .59501 .13802 Mtetra
.59501 .13802 .59851 .14273 .60537 .14018 .60188 .13545 Mtetra
.60188 .13545 .60537 .14018 .61224 .13762 .60876 .13288 Mtetra
.60876 .13288 .61224 .13762 .61913 .13506 .61566 .13031 Mtetra
.61566 .13031 .61913 .13506 .62604 .13249 .62258 .12772 Mtetra
.62258 .12772 .62604 .13249 .63296 .12991 .62952 .12513 Mtetra
.62952 .12513 .63296 .12991 .6399 .12732 .63647 .12254 Mtetra
.63647 .12254 .6399 .12732 .64686 .12473 .64344 .11993 Mtetra
.64344 .11993 .64686 .12473 .65384 .12214 .65043 .11733 Mtetra
.65043 .11733 .65384 .12214 .66083 .11953 .65743 .11471 Mtetra
.65743 .11471 .66083 .11953 .66784 .11692 .66446 .11209 Mtetra
.66446 .11209 .66784 .11692 .67487 .11431 .6715 .10946 Mtetra
.6715 .10946 .67487 .11431 .68191 .11168 .67855 .10682 Mtetra
.67855 .10682 .68191 .11168 .68898 .10906 .68563 .10418 Mtetra
.68563 .10418 .68898 .10906 .69606 .10642 .69272 .10153 Mtetra
.69272 .10153 .69606 .10642 .70316 .10378 .69983 .09888 Mtetra
.69983 .09888 .70316 .10378 .71027 .10113 .70696 .09622 Mtetra
.70696 .09622 .71027 .10113 .71741 .09847 .71411 .09355 Mtetra
.71411 .09355 .71741 .09847 .72456 .09581 .72127 .09087 Mtetra
.72127 .09087 .72456 .09581 .73173 .09314 .72845 .08819 Mtetra
.72845 .08819 .73173 .09314 .73892 .09046 .73565 .08551 Mtetra
.73565 .08551 .73892 .09046 .74612 .08778 .74287 .08281 Mtetra
.10268 .31633 .1069 .32027 .11261 .31813 .1084 .31418 Mtetra
.1084 .31418 .11261 .31813 .11834 .316 .11413 .31203 Mtetra
.11413 .31203 .11834 .316 .12408 .31385 .11988 .30988 Mtetra
.11988 .30988 .12408 .31385 .12984 .3117 .12564 .30772 Mtetra
.12564 .30772 .12984 .3117 .13561 .30955 .13142 .30556 Mtetra
.13142 .30556 .13561 .30955 .14139 .30739 .13721 .30339 Mtetra
.13721 .30339 .14139 .30739 .14718 .30523 .14301 .30123 Mtetra
.663 .741 .908 r
.14301 .30123 .14718 .30523 .15299 .30307 .14882 .29906 Mtetra
.14882 .29906 .15299 .30307 .15881 .3009 .15465 .29689 Mtetra
.662 .741 .908 r
.15465 .29689 .15881 .3009 .16464 .29874 .16049 .29473 Mtetra
.66 .741 .91 r
.16049 .29473 .16464 .29874 .17048 .29659 .16633 .2926 Mtetra
.656 .741 .913 r
.16633 .2926 .17048 .29659 .17633 .29447 .17219 .29052 Mtetra
.649 .742 .918 r
.17219 .29052 .17633 .29447 .18219 .29242 .17804 .28854 Mtetra
.631 .742 .928 r
.17804 .28854 .18219 .29242 .18805 .2905 .18389 .2868 Mtetra
.589 .739 .948 r
.18389 .2868 .18805 .2905 .19389 .28885 .1897 .28553 Mtetra
.469 .718 .978 r
.1897 .28553 .19389 .28885 .19969 .28776 .19542 .28519 Mtetra
.027 .516 .877 r
.19542 .28519 .19969 .28776 .20539 .28778 .20097 .2867 Mtetra
.693 .151 0 r
.20097 .2867 .20539 .28778 .21089 .28998 .20619 .29178 Mtetra
.837 .439 .292 r
.20619 .29178 .21089 .28998 .21601 .29638 .21077 .30353 Mtetra
.848 .516 .424 r
.21077 .30353 .21601 .29638 .22042 .31048 .2143 .32666 Mtetra
.839 .535 .474 r
.2143 .32666 .22042 .31048 .2237 .3373 .21638 .36594 Mtetra
.819 .526 .494 r
.21638 .36594 .2237 .3373 .22554 .38076 .21731 .41895 Mtetra
.771 .481 .495 r
.21731 .41895 .22554 .38076 .22661 .43471 .21919 .4643 Mtetra
.557 .262 .422 r
.21919 .4643 .22661 .43471 .22935 .47257 .225 .46858 Mtetra
.94 .723 .582 r
.225 .46858 .22935 .47257 .23634 .46385 .23501 .42623 Mtetra
.823 .578 .568 r
.23501 .42623 .23634 .46385 .24685 .41411 .24629 .36779 Mtetra
.777 .534 .568 r
.24629 .36779 .24685 .41411 .25783 .35672 .25647 .31986 Mtetra
.753 .521 .58 r
.25647 .31986 .25783 .35672 .26749 .31306 .2651 .28861 Mtetra
.742 .529 .605 r
.2651 .28861 .26749 .31306 .27571 .28557 .27258 .27015 Mtetra
.735 .555 .65 r
.27258 .27015 .27571 .28557 .28295 .26953 .2794 .2595 Mtetra
.724 .598 .715 r
.2794 .2595 .28295 .26953 .28963 .2603 .28586 .25323 Mtetra
.7 .645 .791 r
.28586 .25323 .28963 .2603 .29601 .25488 .29213 .24943 Mtetra
.652 .681 .864 r
.29213 .24943 .29601 .25488 .30224 .25171 .29829 .2472 Mtetra
.561 .691 .927 r
.29829 .2472 .30224 .25171 .30837 .25008 .30437 .24627 Mtetra
.369 .644 .962 r
.30437 .24627 .30837 .25008 .31441 .24991 .31037 .24678 Mtetra
0 .415 .833 r
.31037 .24678 .31441 .24991 .32036 .2515 .31627 .24922 Mtetra
.592 .034 0 r
.31627 .24922 .32036 .2515 .32618 .25548 .32202 .25433 Mtetra
.808 .323 .032 r
.32202 .25433 .32618 .25548 .33184 .26271 .32759 .26301 Mtetra
.861 .439 .216 r
.32759 .26301 .33184 .26271 .33731 .27395 .33296 .27581 Mtetra
.869 .478 .296 r
.33296 .27581 .33731 .27395 .34262 .28912 .3382 .29209 Mtetra
.859 .474 .314 r
.3382 .29209 .34262 .28912 .3479 .3062 .3435 .3088 Mtetra
.818 .398 .247 r
.3435 .3088 .3479 .3062 .35344 .32043 .34919 .32036 Mtetra
.155 0 0 r
.34919 .32036 .35344 .32043 .35952 .32575 .35552 .32118 Mtetra
.884 .767 .728 r
.35552 .32118 .35952 .32575 .36627 .31876 .36251 .30981 Mtetra
.875 .683 .64 r
.36251 .30981 .36627 .31876 .37352 .30156 .3699 .2902 Mtetra
.86 .655 .624 r
.3699 .2902 .37352 .30156 .38092 .27995 .37733 .26842 Mtetra
.848 .648 .632 r
.37733 .26842 .38092 .27995 .38822 .25927 .38459 .24892 Mtetra
.835 .652 .654 r
.38459 .24892 .38822 .25927 .3953 .24223 .39163 .23342 Mtetra
.821 .665 .689 r
.39163 .23342 .3953 .24223 .40217 .22927 .39846 .22183 Mtetra
.803 .682 .731 r
.39846 .22183 .40217 .22927 .40889 .21972 .40514 .21331 Mtetra
.78 .7 .775 r
.40514 .21331 .40889 .21972 .4155 .21268 .41174 .20697 Mtetra
.755 .715 .815 r
.41174 .20697 .4155 .21268 .42205 .20733 .41828 .20208 Mtetra
.73 .726 .846 r
.41828 .20208 .42205 .20733 .42857 .20308 .4248 .19813 Mtetra
.71 .732 .868 r
.4248 .19813 .42857 .20308 .43507 .19952 .43131 .19475 Mtetra
.694 .736 .883 r
.43131 .19475 .43507 .19952 .44157 .1964 .43781 .19174 Mtetra
.683 .738 .892 r
.43781 .19174 .44157 .1964 .44808 .19355 .44433 .18894 Mtetra
.676 .739 .898 r
.44433 .18894 .44808 .19355 .45459 .19085 .45086 .18628 Mtetra
.672 .74 .902 r
.45086 .18628 .45459 .19085 .46112 .18826 .4574 .1837 Mtetra
.669 .74 .904 r
.4574 .1837 .46112 .18826 .46767 .18572 .46395 .18117 Mtetra
.667 .74 .905 r
.46395 .18117 .46767 .18572 .47423 .18321 .47052 .17866 Mtetra
.666 .741 .906 r
.47052 .17866 .47423 .18321 .4808 .18072 .4771 .17616 Mtetra
.665 .741 .907 r
.4771 .17616 .4808 .18072 .48739 .17824 .4837 .17367 Mtetra
.4837 .17367 .48739 .17824 .49399 .17576 .49031 .17118 Mtetra
.664 .741 .907 r
.49031 .17118 .49399 .17576 .50061 .17328 .49694 .1687 Mtetra
.49694 .1687 .50061 .17328 .50725 .17079 .50359 .1662 Mtetra
.50359 .1662 .50725 .17079 .5139 .16831 .51025 .1637 Mtetra
.51025 .1637 .5139 .16831 .52057 .16581 .51693 .1612 Mtetra
.51693 .1612 .52057 .16581 .52726 .16332 .52363 .15869 Mtetra
.52363 .15869 .52726 .16332 .53396 .16081 .53034 .15618 Mtetra
.53034 .15618 .53396 .16081 .54068 .15831 .53707 .15366 Mtetra
.53707 .15366 .54068 .15831 .54741 .15579 .54381 .15113 Mtetra
.54381 .15113 .54741 .15579 .55416 .15327 .55058 .1486 Mtetra
.55058 .1486 .55416 .15327 .56093 .15074 .55735 .14606 Mtetra
.55735 .14606 .56093 .15074 .56771 .14821 .56415 .14352 Mtetra
.56415 .14352 .56771 .14821 .57451 .14567 .57096 .14097 Mtetra
.57096 .14097 .57451 .14567 .58133 .14313 .57779 .13841 Mtetra
.57779 .13841 .58133 .14313 .58816 .14058 .58463 .13585 Mtetra
.58463 .13585 .58816 .14058 .59501 .13802 .59149 .13328 Mtetra
.59149 .13328 .59501 .13802 .60188 .13545 .59837 .1307 Mtetra
.59837 .1307 .60188 .13545 .60876 .13288 .60527 .12812 Mtetra
.60527 .12812 .60876 .13288 .61566 .13031 .61218 .12553 Mtetra
.61218 .12553 .61566 .13031 .62258 .12772 .61911 .12294 Mtetra
.61911 .12294 .62258 .12772 .62952 .12513 .62606 .12034 Mtetra
.62606 .12034 .62952 .12513 .63647 .12254 .63302 .11773 Mtetra
.63302 .11773 .63647 .12254 .64344 .11993 .64 .11511 Mtetra
.64 .11511 .64344 .11993 .65043 .11733 .647 .11249 Mtetra
.647 .11249 .65043 .11733 .65743 .11471 .65402 .10986 Mtetra
.65402 .10986 .65743 .11471 .66446 .11209 .66105 .10723 Mtetra
.66105 .10723 .66446 .11209 .6715 .10946 .66811 .10459 Mtetra
.66811 .10459 .6715 .10946 .67855 .10682 .67518 .10194 Mtetra
.67518 .10194 .67855 .10682 .68563 .10418 .68226 .09929 Mtetra
.68226 .09929 .68563 .10418 .69272 .10153 .68937 .09663 Mtetra
.68937 .09663 .69272 .10153 .69983 .09888 .69649 .09396 Mtetra
.69649 .09396 .69983 .09888 .70696 .09622 .70363 .09129 Mtetra
.70363 .09129 .70696 .09622 .71411 .09355 .71079 .08861 Mtetra
.71079 .08861 .71411 .09355 .72127 .09087 .71797 .08592 Mtetra
.71797 .08592 .72127 .09087 .72845 .08819 .72516 .08322 Mtetra
.72516 .08322 .72845 .08819 .73565 .08551 .73238 .08052 Mtetra
.73238 .08052 .73565 .08551 .74287 .08281 .73961 .07782 Mtetra
.09843 .31236 .10268 .31633 .1084 .31418 .10417 .31021 Mtetra
.10417 .31021 .1084 .31418 .11413 .31203 .10991 .30806 Mtetra
.10991 .30806 .11413 .31203 .11988 .30988 .11566 .30589 Mtetra
.11566 .30589 .11988 .30988 .12564 .30772 .12143 .30373 Mtetra
.12143 .30373 .12564 .30772 .13142 .30556 .12722 .30156 Mtetra
.12722 .30156 .13142 .30556 .13721 .30339 .13301 .29938 Mtetra
.663 .741 .908 r
.13301 .29938 .13721 .30339 .14301 .30123 .13882 .29721 Mtetra
.13882 .29721 .14301 .30123 .14882 .29906 .14464 .29503 Mtetra
.662 .741 .908 r
.14464 .29503 .14882 .29906 .15465 .29689 .15047 .29287 Mtetra
.661 .741 .909 r
.15047 .29287 .15465 .29689 .16049 .29473 .15631 .29072 Mtetra
.657 .741 .912 r
.15631 .29072 .16049 .29473 .16633 .2926 .16216 .28861 Mtetra
.651 .742 .916 r
.16216 .28861 .16633 .2926 .17219 .29052 .16802 .2866 Mtetra
.637 .742 .924 r
.16802 .2866 .17219 .29052 .17804 .28854 .17386 .28478 Mtetra
.603 .741 .941 r
.17386 .28478 .17804 .28854 .18389 .2868 .17968 .28336 Mtetra
.513 .728 .971 r
.17968 .28336 .18389 .2868 .1897 .28553 .18542 .28271 Mtetra
.196 .611 .947 r
.18542 .28271 .1897 .28553 .19542 .28519 .19102 .28363 Mtetra
.575 0 0 r
.19102 .28363 .19542 .28519 .20097 .2867 .19632 .28759 Mtetra
.825 .4 .23 r
.19632 .28759 .20097 .2867 .20619 .29178 .20106 .29728 Mtetra
.848 .504 .403 r
.20106 .29728 .20619 .29178 .21077 .30353 .20483 .31706 Mtetra
.842 .533 .465 r
.20483 .31706 .21077 .30353 .2143 .32666 .20718 .35206 Mtetra
.825 .531 .491 r
.20718 .35206 .2143 .32666 .21638 .36594 .20813 .40277 Mtetra
.787 .497 .497 r
.20813 .40277 .21638 .36594 .21731 .41895 .20932 .45327 Mtetra
.662 .368 .464 r
.20932 .45327 .21731 .41895 .21919 .4643 .21389 .47016 Mtetra
.994 .828 .572 r
.21389 .47016 .21919 .4643 .225 .46858 .22314 .43742 Mtetra
.841 .598 .57 r
.22314 .43742 .225 .46858 .23501 .42623 .23457 .37965 Mtetra
.785 .541 .567 r
.23457 .37965 .23501 .42623 .24629 .36779 .24527 .32776 Mtetra
.758 .522 .576 r
.24527 .32776 .24629 .36779 .25647 .31986 .25436 .29249 Mtetra
.744 .525 .597 r
.25436 .29249 .25647 .31986 .2651 .28861 .26214 .27129 Mtetra
.737 .547 .637 r
.26214 .27129 .2651 .28861 .27258 .27015 .26911 .25903 Mtetra
.729 .587 .696 r
.26911 .25903 .27258 .27015 .2794 .2595 .27566 .25181 Mtetra
.711 .634 .769 r
.27566 .25181 .2794 .2595 .28586 .25323 .28198 .24739 Mtetra
.675 .675 .842 r
.28198 .24739 .28586 .25323 .29213 .24943 .28817 .24464 Mtetra
.611 .696 .904 r
.28817 .24464 .29213 .24943 .29829 .2472 .29429 .2431 Mtetra
.492 .685 .953 r
.29429 .2431 .29829 .2472 .30437 .24627 .30033 .24276 Mtetra
.226 .585 .946 r
.30033 .24276 .30437 .24627 .31037 .24678 .30629 .24397 Mtetra
0 .247 .676 r
.30629 .24397 .31037 .24678 .31627 .24922 .31213 .24733 Mtetra
.709 .173 0 r
.31213 .24733 .31627 .24922 .32202 .25433 .3178 .25368 Mtetra
.838 .38 .12 r
.3178 .25368 .32202 .25433 .32759 .26301 .32327 .26389 Mtetra
.867 .46 .255 r
.32327 .26389 .32759 .26301 .33296 .27581 .32854 .27818 Mtetra
.868 .482 .309 r
.32854 .27818 .33296 .27581 .3382 .29209 .33374 .29514 Mtetra
.85 .459 .304 r
.33374 .29514 .3382 .29209 .3435 .3088 .33911 .31066 Mtetra
.766 .304 .148 r
.33911 .31066 .3435 .3088 .34919 .32036 .345 .31871 Mtetra
.748 .917 .949 r
.345 .31871 .34919 .32036 .35552 .32118 .3516 .31481 Mtetra
.883 .722 .678 r
.3516 .31481 .35552 .32118 .36251 .30981 .35881 .29965 Mtetra
.869 .669 .63 r
.35881 .29965 .36251 .30981 .3699 .2902 .3663 .27852 Mtetra
.856 .651 .625 r
.3663 .27852 .3699 .2902 .37733 .26842 .37373 .25721 Mtetra
.843 .648 .639 r
.37373 .25721 .37733 .26842 .38459 .24892 .38094 .23911 Mtetra
.831 .656 .666 r
.38094 .23911 .38459 .24892 .39163 .23342 .38792 .22514 Mtetra
.815 .671 .704 r
.38792 .22514 .39163 .23342 .39846 .22183 .39471 .21479 Mtetra
.795 .689 .748 r
.39471 .21479 .39846 .22183 .40514 .21331 .40137 .20718 Mtetra
.771 .706 .791 r
.40137 .20718 .40514 .21331 .41174 .20697 .40796 .20145 Mtetra
.745 .72 .828 r
.40796 .20145 .41174 .20697 .41828 .20208 .41449 .19695 Mtetra
.722 .729 .856 r
.41449 .19695 .41828 .20208 .4248 .19813 .42101 .19324 Mtetra
.703 .734 .875 r
.42101 .19324 .4248 .19813 .43131 .19475 .42753 .19001 Mtetra
.69 .737 .887 r
.42753 .19001 .43131 .19475 .43781 .19174 .43404 .18708 Mtetra
.68 .739 .895 r
.43404 .18708 .43781 .19174 .44433 .18894 .44057 .18434 Mtetra
.674 .74 .9 r
.44057 .18434 .44433 .18894 .45086 .18628 .4471 .1817 Mtetra
.67 .74 .903 r
.4471 .1817 .45086 .18628 .4574 .1837 .45365 .17913 Mtetra
.668 .74 .904 r
.45365 .17913 .4574 .1837 .46395 .18117 .46021 .1766 Mtetra
.666 .741 .906 r
.46021 .1766 .46395 .18117 .47052 .17866 .46679 .17409 Mtetra
.665 .741 .906 r
.46679 .17409 .47052 .17866 .4771 .17616 .47338 .17159 Mtetra
.665 .741 .907 r
.47338 .17159 .4771 .17616 .4837 .17367 .47999 .16909 Mtetra
.664 .741 .907 r
.47999 .16909 .4837 .17367 .49031 .17118 .48662 .16659 Mtetra
.48662 .16659 .49031 .17118 .49694 .1687 .49326 .16409 Mtetra
.49326 .16409 .49694 .1687 .50359 .1662 .49992 .16159 Mtetra
.49992 .16159 .50359 .1662 .51025 .1637 .50659 .15908 Mtetra
.50659 .15908 .51025 .1637 .51693 .1612 .51328 .15657 Mtetra
.51328 .15657 .51693 .1612 .52363 .15869 .51999 .15405 Mtetra
.51999 .15405 .52363 .15869 .53034 .15618 .52671 .15152 Mtetra
.52671 .15152 .53034 .15618 .53707 .15366 .53345 .14899 Mtetra
.53345 .14899 .53707 .15366 .54381 .15113 .5402 .14645 Mtetra
.5402 .14645 .54381 .15113 .55058 .1486 .54698 .14391 Mtetra
.54698 .14391 .55058 .1486 .55735 .14606 .55376 .14136 Mtetra
.55376 .14136 .55735 .14606 .56415 .14352 .56057 .13881 Mtetra
.56057 .13881 .56415 .14352 .57096 .14097 .56739 .13624 Mtetra
.56739 .13624 .57096 .14097 .57779 .13841 .57423 .13367 Mtetra
.57423 .13367 .57779 .13841 .58463 .13585 .58109 .1311 Mtetra
.58109 .1311 .58463 .13585 .59149 .13328 .58796 .12852 Mtetra
.58796 .12852 .59149 .13328 .59837 .1307 .59485 .12593 Mtetra
.59485 .12593 .59837 .1307 .60527 .12812 .60176 .12334 Mtetra
.60176 .12334 .60527 .12812 .61218 .12553 .60868 .12074 Mtetra
.60868 .12074 .61218 .12553 .61911 .12294 .61562 .11813 Mtetra
.61562 .11813 .61911 .12294 .62606 .12034 .62258 .11552 Mtetra
.62258 .11552 .62606 .12034 .63302 .11773 .62956 .1129 Mtetra
.62956 .1129 .63302 .11773 .64 .11511 .63655 .11027 Mtetra
.63655 .11027 .64 .11511 .647 .11249 .64356 .10764 Mtetra
.64356 .10764 .647 .11249 .65402 .10986 .65059 .105 Mtetra
.65059 .105 .65402 .10986 .66105 .10723 .65764 .10235 Mtetra
.65764 .10235 .66105 .10723 .66811 .10459 .6647 .0997 Mtetra
.6647 .0997 .66811 .10459 .67518 .10194 .67178 .09704 Mtetra
.67178 .09704 .67518 .10194 .68226 .09929 .67888 .09437 Mtetra
.67888 .09437 .68226 .09929 .68937 .09663 .686 .0917 Mtetra
.686 .0917 .68937 .09663 .69649 .09396 .69314 .08902 Mtetra
.69314 .08902 .69649 .09396 .70363 .09129 .70029 .08633 Mtetra
.70029 .08633 .70363 .09129 .71079 .08861 .70746 .08364 Mtetra
.70746 .08364 .71079 .08861 .71797 .08592 .71465 .08094 Mtetra
.71465 .08094 .71797 .08592 .72516 .08322 .72186 .07823 Mtetra
.72186 .07823 .72516 .08322 .73238 .08052 .72908 .07552 Mtetra
.72908 .07552 .73238 .08052 .73961 .07782 .73633 .0728 Mtetra
.09418 .30839 .09843 .31236 .10417 .31021 .09991 .30623 Mtetra
.09991 .30623 .10417 .31021 .10991 .30806 .10566 .30406 Mtetra
.10566 .30406 .10991 .30806 .11566 .30589 .11143 .30189 Mtetra
.11143 .30189 .11566 .30589 .12143 .30373 .1172 .29972 Mtetra
.1172 .29972 .12143 .30373 .12722 .30156 .12299 .29754 Mtetra
.663 .741 .908 r
.12299 .29754 .12722 .30156 .13301 .29938 .1288 .29536 Mtetra
.1288 .29536 .13301 .29938 .13882 .29721 .13461 .29318 Mtetra
.13461 .29318 .13882 .29721 .14464 .29503 .14044 .291 Mtetra
.661 .741 .909 r
.14044 .291 .14464 .29503 .15047 .29287 .14628 .28884 Mtetra
.658 .741 .911 r
.14628 .28884 .15047 .29287 .15631 .29072 .15212 .28672 Mtetra
.653 .742 .915 r
.15212 .28672 .15631 .29072 .16216 .28861 .15797 .28467 Mtetra
.642 .742 .922 r
.15797 .28467 .16216 .28861 .16802 .2866 .16382 .28278 Mtetra
.614 .741 .936 r
.16382 .28278 .16802 .2866 .17386 .28478 .16964 .28122 Mtetra
.546 .734 .963 r
.16964 .28122 .17386 .28478 .17968 .28336 .1754 .28033 Mtetra
.319 .667 .975 r
.1754 .28033 .17968 .28336 .18542 .28271 .18104 .28074 Mtetra
.399 0 0 r
.18104 .28074 .18542 .28271 .19102 .28363 .18641 .28374 Mtetra
.804 .345 .146 r
.18641 .28374 .19102 .28363 .19632 .28759 .19129 .29166 Mtetra
.847 .489 .376 r
.19129 .29166 .19632 .28759 .20106 .29728 .1953 .30842 Mtetra
.845 .53 .455 r
.1953 .30842 .20106 .29728 .20483 .31706 .19793 .33923 Mtetra
.831 .534 .487 r
.19793 .33923 .20483 .31706 .20718 .35206 .19901 .38667 Mtetra
.8 .51 .497 r
.19901 .38667 .20718 .35206 .20813 .40277 .1997 .44002 Mtetra
.715 .423 .481 r
.1997 .44002 .20813 .40277 .20932 .45327 .20306 .46838 Mtetra
.733 .797 .316 r
.20306 .46838 .20932 .45327 .21389 .47016 .21132 .44704 Mtetra
.864 .624 .573 r
.21132 .44704 .21389 .47016 .22314 .43742 .22268 .39203 Mtetra
.796 .551 .567 r
.22268 .39203 .22314 .43742 .23457 .37965 .23388 .33679 Mtetra
.763 .524 .572 r
.23388 .33679 .23457 .37965 .24527 .32776 .24348 .29727 Mtetra
.747 .522 .59 r
.24348 .29727 .24527 .32776 .25436 .29249 .2516 .27301 Mtetra
.739 .54 .625 r
.2516 .27301 .25436 .29249 .26214 .27129 .25877 .2589 Mtetra
.732 .576 .679 r
.25877 .2589 .26214 .27129 .26911 .25903 .26542 .25063 Mtetra
.718 .622 .75 r
.26542 .25063 .26911 .25903 .27566 .25181 .27179 .24557 Mtetra
.691 .667 .821 r
.27179 .24557 .27566 .25181 .28198 .24739 .27802 .24232 Mtetra
.644 .695 .883 r
.27802 .24232 .28198 .24739 .28817 .24464 .28417 .24028 Mtetra
.564 .701 .934 r
.28417 .24028 .28817 .24464 .29429 .2431 .29025 .23928 Mtetra
.404 .663 .965 r
.29025 .23928 .29429 .2431 .30033 .24276 .29626 .23952 Mtetra
.045 .488 .886 r
.29626 .23952 .30033 .24276 .30629 .24397 .30217 .24147 Mtetra
.495 0 0 r
.30217 .24147 .30629 .24397 .31213 .24733 .30793 .24586 Mtetra
.779 .275 0 r
.30793 .24586 .31213 .24733 .3178 .25368 .31351 .25358 Mtetra
.854 .42 .185 r
.31351 .25358 .3178 .25368 .32327 .26389 .31888 .26536 Mtetra
.869 .473 .283 r
.31888 .26536 .32327 .26389 .32854 .27818 .32407 .28095 Mtetra
.864 .48 .315 r
.32407 .28095 .32854 .27818 .33374 .29514 .32925 .29801 Mtetra
.835 .43 .279 r
.32925 .29801 .33374 .29514 .33911 .31066 .33474 .31146 Mtetra
.593 .039 0 r
.33474 .31146 .33911 .31066 .345 .31871 .34088 .31532 Mtetra
.873 .815 .788 r
.34088 .31532 .345 .31871 .3516 .31481 .34776 .30678 Mtetra
.878 .695 .651 r
.34776 .30678 .3516 .31481 .35881 .29965 .35516 .28863 Mtetra
.864 .66 .625 r
.35516 .28863 .35881 .29965 .3663 .27852 .3627 .26683 Mtetra
.851 .649 .628 r
.3627 .26683 .3663 .27852 .37373 .25721 .3701 .24645 Mtetra
.839 .65 .648 r
.3701 .24645 .37373 .25721 .38094 .23911 .37726 .22988 Mtetra
.825 .661 .679 r
.37726 .22988 .38094 .23911 .38792 .22514 .38418 .21734 Mtetra
.808 .677 .72 r
.38418 .21734 .38792 .22514 .39471 .21479 .39094 .20812 Mtetra
.786 .696 .764 r
.39094 .20812 .39471 .21479 .40137 .20718 .39758 .2013 Mtetra
.761 .712 .806 r
.39758 .2013 .40137 .20718 .40796 .20145 .40415 .19608 Mtetra
.736 .724 .839 r
.40415 .19608 .40796 .20145 .41449 .19695 .41069 .19191 Mtetra
.714 .731 .864 r
.41069 .19191 .41449 .19695 .42101 .19324 .41721 .18839 Mtetra
.698 .735 .88 r
.41721 .18839 .42101 .19324 .42753 .19001 .42373 .18529 Mtetra
.686 .738 .89 r
.42373 .18529 .42753 .19001 .43404 .18708 .43025 .18243 Mtetra
.678 .739 .897 r
.43025 .18243 .43404 .18708 .44057 .18434 .43678 .17973 Mtetra
.672 .74 .901 r
.43678 .17973 .44057 .18434 .4471 .1817 .44333 .17711 Mtetra
.669 .74 .903 r
.44333 .17711 .4471 .1817 .45365 .17913 .44989 .17455 Mtetra
.667 .74 .905 r
.44989 .17455 .45365 .17913 .46021 .1766 .45646 .17202 Mtetra
.666 .741 .906 r
.45646 .17202 .46021 .1766 .46679 .17409 .46305 .1695 Mtetra
.665 .741 .906 r
.46305 .1695 .46679 .17409 .47338 .17159 .46965 .16699 Mtetra
.665 .741 .907 r
.46965 .16699 .47338 .17159 .47999 .16909 .47627 .16449 Mtetra
.664 .741 .907 r
.47627 .16449 .47999 .16909 .48662 .16659 .48291 .16198 Mtetra
.48291 .16198 .48662 .16659 .49326 .16409 .48956 .15947 Mtetra
.48956 .15947 .49326 .16409 .49992 .16159 .49623 .15696 Mtetra
.49623 .15696 .49992 .16159 .50659 .15908 .50291 .15444 Mtetra
.50291 .15444 .50659 .15908 .51328 .15657 .50961 .15191 Mtetra
.50961 .15191 .51328 .15657 .51999 .15405 .51633 .14938 Mtetra
.51633 .14938 .51999 .15405 .52671 .15152 .52306 .14685 Mtetra
.52306 .14685 .52671 .15152 .53345 .14899 .52981 .1443 Mtetra
.52981 .1443 .53345 .14899 .5402 .14645 .53658 .14175 Mtetra
.53658 .14175 .5402 .14645 .54698 .14391 .54336 .1392 Mtetra
.54336 .1392 .54698 .14391 .55376 .14136 .55016 .13664 Mtetra
.55016 .13664 .55376 .14136 .56057 .13881 .55698 .13407 Mtetra
.55698 .13407 .56057 .13881 .56739 .13624 .56381 .1315 Mtetra
.56381 .1315 .56739 .13624 .57423 .13367 .57066 .12892 Mtetra
.57066 .12892 .57423 .13367 .58109 .1311 .57753 .12633 Mtetra
.57753 .12633 .58109 .1311 .58796 .12852 .58441 .12374 Mtetra
.58441 .12374 .58796 .12852 .59485 .12593 .59131 .12114 Mtetra
.59131 .12114 .59485 .12593 .60176 .12334 .59823 .11853 Mtetra
.59823 .11853 .60176 .12334 .60868 .12074 .60517 .11592 Mtetra
.60517 .11592 .60868 .12074 .61562 .11813 .61212 .1133 Mtetra
.61212 .1133 .61562 .11813 .62258 .11552 .61909 .11067 Mtetra
.61909 .11067 .62258 .11552 .62956 .1129 .62608 .10804 Mtetra
.62608 .10804 .62956 .1129 .63655 .11027 .63308 .1054 Mtetra
.63308 .1054 .63655 .11027 .64356 .10764 .64011 .10276 Mtetra
.64011 .10276 .64356 .10764 .65059 .105 .64715 .10011 Mtetra
.64715 .10011 .65059 .105 .65764 .10235 .65421 .09745 Mtetra
.65421 .09745 .65764 .10235 .6647 .0997 .66128 .09478 Mtetra
.66128 .09478 .6647 .0997 .67178 .09704 .66838 .09211 Mtetra
.66838 .09211 .67178 .09704 .67888 .09437 .67549 .08943 Mtetra
.67549 .08943 .67888 .09437 .686 .0917 .68262 .08675 Mtetra
.68262 .08675 .686 .0917 .69314 .08902 .68976 .08405 Mtetra
.68976 .08405 .69314 .08902 .70029 .08633 .69693 .08136 Mtetra
.69693 .08136 .70029 .08633 .70746 .08364 .70411 .07865 Mtetra
.70411 .07865 .70746 .08364 .71465 .08094 .71132 .07594 Mtetra
.71132 .07594 .71465 .08094 .72186 .07823 .71854 .07322 Mtetra
.71854 .07322 .72186 .07823 .72908 .07552 .72578 .07049 Mtetra
.72578 .07049 .72908 .07552 .73633 .0728 .73303 .06776 Mtetra
.0899 .30439 .09418 .30839 .09991 .30623 .09565 .30222 Mtetra
.09565 .30222 .09991 .30623 .10566 .30406 .1014 .30005 Mtetra
.1014 .30005 .10566 .30406 .11143 .30189 .10717 .29787 Mtetra
.10717 .29787 .11143 .30189 .1172 .29972 .11296 .29569 Mtetra
.11296 .29569 .1172 .29972 .12299 .29754 .11875 .2935 Mtetra
.663 .741 .908 r
.11875 .2935 .12299 .29754 .1288 .29536 .12456 .29132 Mtetra
.12456 .29132 .1288 .29536 .13461 .29318 .13038 .28913 Mtetra
.662 .741 .909 r
.13038 .28913 .13461 .29318 .14044 .291 .13622 .28696 Mtetra
.659 .741 .91 r
.13622 .28696 .14044 .291 .14628 .28884 .14206 .28482 Mtetra
.655 .741 .913 r
.14206 .28482 .14628 .28884 .15212 .28672 .14791 .28274 Mtetra
.645 .742 .919 r
.14791 .28274 .15212 .28672 .15797 .28467 .15375 .2808 Mtetra
.624 .742 .932 r
.15375 .2808 .15797 .28467 .16382 .28278 .15958 .27913 Mtetra
.57 .738 .955 r
.15958 .27913 .16382 .28278 .16964 .28122 .16535 .27801 Mtetra
.406 .699 .981 r
.16535 .27801 .16964 .28122 .1754 .28033 .17102 .27801 Mtetra
0 .369 .742 r
.17102 .27801 .1754 .28033 .18104 .28074 .17646 .28019 Mtetra
.764 .266 .031 r
.17646 .28019 .18104 .28074 .18641 .28374 .18147 .28657 Mtetra
.844 .469 .341 r
.18147 .28657 .18641 .28374 .19129 .29166 .18569 .30066 Mtetra
.847 .524 .442 r
.18569 .30066 .19129 .29166 .1953 .30842 .18862 .3275 Mtetra
.835 .535 .481 r
.18862 .3275 .1953 .30842 .19793 .33923 .18992 .37105 Mtetra
.81 .519 .496 r
.18992 .37105 .19793 .33923 .19901 .38667 .19031 .42517 Mtetra
.748 .457 .49 r
.19031 .42517 .19901 .38667 .1997 .44002 .19256 .4632 Mtetra
.246 0 .269 r
.19256 .4632 .1997 .44002 .20306 .46838 .19961 .45448 Mtetra
.895 .662 .578 r
.19961 .45448 .20306 .46838 .21132 .44704 .21067 .40454 Mtetra
.808 .563 .567 r
.21067 .40454 .21132 .44704 .22268 .39203 .2223 .34691 Mtetra
.769 .528 .57 r
.2223 .34691 .22268 .39203 .23388 .33679 .23244 .30304 Mtetra
.75 .521 .584 r
.23244 .30304 .23388 .33679 .24348 .29727 .24095 .27537 Mtetra
.74 .534 .614 r
.24095 .27537 .24348 .29727 .2516 .27301 .24836 .25916 Mtetra
.734 .565 .664 r
.24836 .25916 .2516 .27301 .25877 .2589 .25513 .2497 Mtetra
.724 .611 .73 r
.25513 .2497 .25877 .2589 .26542 .25063 .26157 .24393 Mtetra
.702 .657 .802 r
.26157 .24393 .26542 .25063 .27179 .24557 .26783 .24021 Mtetra
.666 .691 .864 r
.26783 .24021 .27179 .24557 .27802 .24232 .27401 .23773 Mtetra
.608 .707 .914 r
.27401 .23773 .27802 .24232 .28417 .24028 .28012 .23621 Mtetra
.507 .696 .954 r
.28012 .23621 .28417 .24028 .29025 .23928 .28617 .2357 Mtetra
.291 .62 .959 r
.28617 .2357 .29025 .23928 .29626 .23952 .29214 .23654 Mtetra
0 .347 .77 r
.29214 .23654 .29626 .23952 .30217 .24147 .29799 .23932 Mtetra
.643 .091 0 r
.29799 .23932 .30217 .24147 .30793 .24586 .30368 .24486 Mtetra
.821 .346 .067 r
.30368 .24486 .30793 .24586 .31351 .25358 .30916 .25405 Mtetra
.864 .447 .232 r
.30916 .25405 .31351 .25358 .31888 .26536 .31441 .26738 Mtetra
.869 .48 .301 r
.31441 .26738 .31888 .26536 .32407 .28095 .31953 .28395 Mtetra
.857 .47 .312 r
.31953 .28395 .32407 .28095 .32925 .29801 .32475 .30037 Mtetra
.805 .374 .222 r
.32475 .30037 .32925 .29801 .33474 .31146 .33043 .31086 Mtetra
.25 .754 .887 r
.33043 .31086 .33474 .31146 .34088 .31532 .33686 .31009 Mtetra
.884 .749 .707 r
.33686 .31009 .34088 .31532 .34776 .30678 .344 .29734 Mtetra
.873 .677 .636 r
.344 .29734 .34776 .30678 .35516 .28863 .35153 .27707 Mtetra
.859 .654 .624 r
.35153 .27707 .35516 .28863 .3627 .26683 .35909 .25533 Mtetra
.846 .648 .634 r
.35909 .25533 .3627 .26683 .3701 .24645 .36644 .23622 Mtetra
.834 .653 .658 r
.36644 .23622 .3701 .24645 .37726 .22988 .37354 .2212 Mtetra
.819 .667 .694 r
.37354 .2212 .37726 .22988 .38418 .21734 .38042 .21 Mtetra
.8 .684 .737 r
.38042 .21 .38418 .21734 .39094 .20812 .38714 .20177 Mtetra
.777 .702 .781 r
.38714 .20177 .39094 .20812 .39758 .2013 .39376 .19561 Mtetra
.752 .717 .82 r
.39376 .19561 .39758 .2013 .40415 .19608 .40033 .19083 Mtetra
.727 .727 .85 r
.40033 .19083 .40415 .19608 .41069 .19191 .40686 .18694 Mtetra
.707 .733 .871 r
.40686 .18694 .41069 .19191 .41721 .18839 .41339 .18359 Mtetra
.693 .736 .885 r
.41339 .18359 .41721 .18839 .42373 .18529 .41991 .18058 Mtetra
.682 .738 .893 r
.41991 .18058 .42373 .18529 .43025 .18243 .42644 .17778 Mtetra
.675 .739 .899 r
.42644 .17778 .43025 .18243 .43678 .17973 .43298 .17511 Mtetra
.671 .74 .902 r
.43298 .17511 .43678 .17973 .44333 .17711 .43954 .17251 Mtetra
.668 .74 .904 r
.43954 .17251 .44333 .17711 .44989 .17455 .44611 .16995 Mtetra
.667 .741 .905 r
.44611 .16995 .44989 .17455 .45646 .17202 .45269 .16742 Mtetra
.666 .741 .906 r
.45269 .16742 .45646 .17202 .46305 .1695 .45929 .1649 Mtetra
.665 .741 .907 r
.45929 .1649 .46305 .1695 .46965 .16699 .4659 .16238 Mtetra
.664 .741 .907 r
.4659 .16238 .46965 .16699 .47627 .16449 .47253 .15987 Mtetra
.47253 .15987 .47627 .16449 .48291 .16198 .47918 .15735 Mtetra
.47918 .15735 .48291 .16198 .48956 .15947 .48584 .15483 Mtetra
.48584 .15483 .48956 .15947 .49623 .15696 .49252 .1523 Mtetra
.49252 .1523 .49623 .15696 .50291 .15444 .49921 .14977 Mtetra
.49921 .14977 .50291 .15444 .50961 .15191 .50592 .14724 Mtetra
.50592 .14724 .50961 .15191 .51633 .14938 .51265 .14469 Mtetra
.51265 .14469 .51633 .14938 .52306 .14685 .5194 .14215 Mtetra
.5194 .14215 .52306 .14685 .52981 .1443 .52616 .13959 Mtetra
.52616 .13959 .52981 .1443 .53658 .14175 .53293 .13703 Mtetra
.53293 .13703 .53658 .14175 .54336 .1392 .53973 .13447 Mtetra
.53973 .13447 .54336 .1392 .55016 .13664 .54654 .13189 Mtetra
.54654 .13189 .55016 .13664 .55698 .13407 .55337 .12931 Mtetra
.55337 .12931 .55698 .13407 .56381 .1315 .56021 .12673 Mtetra
.56021 .12673 .56381 .1315 .57066 .12892 .56707 .12414 Mtetra
.56707 .12414 .57066 .12892 .57753 .12633 .57395 .12154 Mtetra
.57395 .12154 .57753 .12633 .58441 .12374 .58085 .11893 Mtetra
.58085 .11893 .58441 .12374 .59131 .12114 .58776 .11632 Mtetra
.58776 .11632 .59131 .12114 .59823 .11853 .59469 .1137 Mtetra
.59469 .1137 .59823 .11853 .60517 .11592 .60164 .11108 Mtetra
.60164 .11108 .60517 .11592 .61212 .1133 .6086 .10845 Mtetra
.6086 .10845 .61212 .1133 .61909 .11067 .61558 .10581 Mtetra
.61558 .10581 .61909 .11067 .62608 .10804 .62258 .10317 Mtetra
.62258 .10317 .62608 .10804 .63308 .1054 .6296 .10051 Mtetra
.6296 .10051 .63308 .1054 .64011 .10276 .63664 .09786 Mtetra
.63664 .09786 .64011 .10276 .64715 .10011 .64369 .09519 Mtetra
.64369 .09519 .64715 .10011 .65421 .09745 .65076 .09252 Mtetra
.65076 .09252 .65421 .09745 .66128 .09478 .65785 .08984 Mtetra
.65785 .08984 .66128 .09478 .66838 .09211 .66495 .08716 Mtetra
.66495 .08716 .66838 .09211 .67549 .08943 .67208 .08447 Mtetra
.67208 .08447 .67549 .08943 .68262 .08675 .67922 .08177 Mtetra
.67922 .08177 .68262 .08675 .68976 .08405 .68638 .07907 Mtetra
.68638 .07907 .68976 .08405 .69693 .08136 .69356 .07635 Mtetra
.69356 .07635 .69693 .08136 .70411 .07865 .70075 .07364 Mtetra
.70075 .07364 .70411 .07865 .71132 .07594 .70797 .07091 Mtetra
.70797 .07091 .71132 .07594 .71854 .07322 .7152 .06818 Mtetra
.7152 .06818 .71854 .07322 .72578 .07049 .72245 .06544 Mtetra
.72245 .06544 .72578 .07049 .73303 .06776 .72972 .06269 Mtetra
.08561 .30038 .0899 .30439 .09565 .30222 .09136 .29821 Mtetra
.09136 .29821 .09565 .30222 .1014 .30005 .09712 .29602 Mtetra
.09712 .29602 .1014 .30005 .10717 .29787 .1029 .29383 Mtetra
.1029 .29383 .10717 .29787 .11296 .29569 .10869 .29164 Mtetra
.663 .741 .908 r
.10869 .29164 .11296 .29569 .11875 .2935 .1145 .28945 Mtetra
.1145 .28945 .11875 .2935 .12456 .29132 .12031 .28726 Mtetra
.662 .741 .908 r
.12031 .28726 .12456 .29132 .13038 .28913 .12614 .28508 Mtetra
.66 .741 .91 r
.12614 .28508 .13038 .28913 .13622 .28696 .13198 .28292 Mtetra
.656 .741 .912 r
.13198 .28292 .13622 .28696 .14206 .28482 .13782 .28082 Mtetra
.649 .742 .918 r
.13782 .28082 .14206 .28482 .14791 .28274 .14366 .27883 Mtetra
.631 .742 .928 r
.14366 .27883 .14791 .28274 .15375 .2808 .14949 .27706 Mtetra
.589 .739 .948 r
.14949 .27706 .15375 .2808 .15958 .27913 .15528 .27577 Mtetra
.468 .718 .978 r
.15528 .27577 .15958 .27913 .16535 .27801 .16097 .27541 Mtetra
.024 .514 .876 r
.16097 .27541 .16535 .27801 .17102 .27801 .16647 .27689 Mtetra
.695 .154 0 r
.16647 .27689 .17102 .27801 .17646 .28019 .17159 .28195 Mtetra
.837 .44 .295 r
.17159 .28195 .17646 .28019 .18147 .28657 .17601 .29369 Mtetra
.848 .516 .425 r
.17601 .29369 .18147 .28657 .18569 .30066 .17923 .31684 Mtetra
.839 .535 .475 r
.17923 .31684 .18569 .30066 .18862 .3275 .18081 .35618 Mtetra
.819 .526 .494 r
.18081 .35618 .18862 .3275 .18992 .37105 .18109 .40933 Mtetra
.771 .481 .495 r
.18109 .40933 .18992 .37105 .19031 .42517 .18238 .45486 Mtetra
.554 .257 .417 r
.18238 .45486 .19031 .42517 .19256 .4632 .1881 .45918 Mtetra
.938 .722 .584 r
.1881 .45918 .19256 .4632 .19961 .45448 .19858 .41668 Mtetra
.823 .578 .568 r
.19858 .41668 .19961 .45448 .21067 .40454 .21051 .358 Mtetra
.777 .534 .568 r
.21051 .358 .21067 .40454 .2223 .34691 .22123 .30987 Mtetra
.753 .52 .579 r
.22123 .30987 .2223 .34691 .23244 .30304 .23019 .27847 Mtetra
.742 .529 .605 r
.23019 .27847 .23244 .30304 .24095 .27537 .23787 .25986 Mtetra
.736 .556 .649 r
.23787 .25986 .24095 .27537 .24836 .25916 .24479 .24902 Mtetra
.728 .599 .712 r
.24479 .24902 .24836 .25916 .25513 .2497 .2513 .24248 Mtetra
.711 .647 .783 r
.2513 .24248 .25513 .2497 .26157 .24393 .25761 .23827 Mtetra
.681 .685 .847 r
.25761 .23827 .26157 .24393 .26783 .24021 .26381 .2354 Mtetra
.638 .707 .897 r
.26381 .2354 .26783 .24021 .27401 .23773 .26995 .23345 Mtetra
.569 .71 .937 r
.26995 .23345 .27401 .23773 .28012 .23621 .27604 .23236 Mtetra
.438 .679 .966 r
.27604 .23236 .28012 .23621 .28617 .2357 .28205 .23235 Mtetra
.144 .548 .924 r
.28205 .23235 .28617 .2357 .29214 .23654 .28797 .23385 Mtetra
0 .176 .599 r
.28797 .23385 .29214 .23654 .29799 .23932 .29376 .23756 Mtetra
.738 .214 0 r
.29376 .23756 .29799 .23932 .30368 .24486 .29936 .24437 Mtetra
.845 .396 .146 r
.29936 .24437 .30368 .24486 .30916 .25405 .30472 .25511 Mtetra
.868 .465 .266 r
.30472 .25511 .30916 .25405 .31441 .26738 .30988 .26987 Mtetra
.866 .482 .312 r
.30988 .26987 .31441 .26738 .31953 .28395 .31496 .28695 Mtetra
.846 .451 .298 r
.31496 .28695 .31953 .28395 .32475 .30037 .32027 .30189 Mtetra
.732 .246 .086 r
.32027 .30189 .32475 .30037 .33043 .31086 .3262 .30861 Mtetra
.824 .883 .887 r
.3262 .30861 .33043 .31086 .33686 .31009 .33292 .3031 Mtetra
.881 .711 .667 r
.33292 .3031 .33686 .31009 .344 .29734 .34029 .2868 Mtetra
.867 .666 .628 r
.34029 .2868 .344 .29734 .35153 .27707 .34792 .26531 Mtetra
.854 .65 .626 r
.34792 .26531 .35153 .27707 .35909 .25533 .35546 .24421 Mtetra
.842 .649 .641 r
.35546 .24421 .35909 .25533 .36644 .23622 .36275 .22656 Mtetra
.829 .658 .67 r
.36275 .22656 .36644 .23622 .37354 .2212 .36979 .21303 Mtetra
.813 .673 .709 r
.36979 .21303 .37354 .2212 .38042 .21 .37662 .20305 Mtetra
.792 .691 .753 r
.37662 .20305 .38042 .21 .38714 .20177 .38331 .19568 Mtetra
.768 .708 .796 r
.38331 .19568 .38714 .20177 .39376 .19561 .38992 .1901 Mtetra
.742 .721 .832 r
.38992 .1901 .39376 .19561 .40033 .19083 .39648 .18569 Mtetra
.719 .729 .859 r
.39648 .18569 .40033 .19083 .40686 .18694 .40302 .18202 Mtetra
.701 .734 .877 r
.40302 .18202 .40686 .18694 .41339 .18359 .40955 .17881 Mtetra
.688 .737 .888 r
.40955 .17881 .41339 .18359 .41991 .18058 .41608 .17589 Mtetra
.679 .739 .896 r
.41608 .17589 .41991 .18058 .42644 .17778 .42262 .17313 Mtetra
.674 .74 .9 r
.42262 .17313 .42644 .17778 .43298 .17511 .42917 .17048 Mtetra
.67 .74 .903 r
.42917 .17048 .43298 .17511 .43954 .17251 .43573 .16789 Mtetra
.668 .74 .905 r
.43573 .16789 .43954 .17251 .44611 .16995 .44231 .16534 Mtetra
.666 .741 .906 r
.44231 .16534 .44611 .16995 .45269 .16742 .4489 .1628 Mtetra
.665 .741 .906 r
.4489 .1628 .45269 .16742 .45929 .1649 .45551 .16027 Mtetra
.665 .741 .907 r
.45551 .16027 .45929 .1649 .4659 .16238 .46213 .15775 Mtetra
.664 .741 .907 r
.46213 .15775 .4659 .16238 .47253 .15987 .46878 .15522 Mtetra
.46878 .15522 .47253 .15987 .47918 .15735 .47543 .1527 Mtetra
.47543 .1527 .47918 .15735 .48584 .15483 .4821 .15017 Mtetra
.4821 .15017 .48584 .15483 .49252 .1523 .48879 .14763 Mtetra
.48879 .14763 .49252 .1523 .49921 .14977 .4955 .14509 Mtetra
.4955 .14509 .49921 .14977 .50592 .14724 .50222 .14254 Mtetra
.50222 .14254 .50592 .14724 .51265 .14469 .50896 .13999 Mtetra
.50896 .13999 .51265 .14469 .5194 .14215 .51571 .13743 Mtetra
.51571 .13743 .5194 .14215 .52616 .13959 .52248 .13486 Mtetra
.52248 .13486 .52616 .13959 .53293 .13703 .52927 .13229 Mtetra
.52927 .13229 .53293 .13703 .53973 .13447 .53608 .12971 Mtetra
.53608 .12971 .53973 .13447 .54654 .13189 .5429 .12713 Mtetra
.5429 .12713 .54654 .13189 .55337 .12931 .54974 .12453 Mtetra
.54974 .12453 .55337 .12931 .56021 .12673 .55659 .12194 Mtetra
.55659 .12194 .56021 .12673 .56707 .12414 .56347 .11933 Mtetra
.56347 .11933 .56707 .12414 .57395 .12154 .57036 .11672 Mtetra
.57036 .11672 .57395 .12154 .58085 .11893 .57726 .11411 Mtetra
.57726 .11411 .58085 .11893 .58776 .11632 .58419 .11148 Mtetra
.58419 .11148 .58776 .11632 .59469 .1137 .59113 .10885 Mtetra
.59113 .10885 .59469 .1137 .60164 .11108 .59809 .10622 Mtetra
.59809 .10622 .60164 .11108 .6086 .10845 .60507 .10357 Mtetra
.60507 .10357 .6086 .10845 .61558 .10581 .61206 .10092 Mtetra
.61206 .10092 .61558 .10581 .62258 .10317 .61907 .09827 Mtetra
.61907 .09827 .62258 .10317 .6296 .10051 .6261 .0956 Mtetra
.6261 .0956 .6296 .10051 .63664 .09786 .63315 .09293 Mtetra
.63315 .09293 .63664 .09786 .64369 .09519 .64021 .09026 Mtetra
.64021 .09026 .64369 .09519 .65076 .09252 .64729 .08757 Mtetra
.64729 .08757 .65076 .09252 .65785 .08984 .65439 .08488 Mtetra
.65439 .08488 .65785 .08984 .66495 .08716 .66151 .08219 Mtetra
.66151 .08219 .66495 .08716 .67208 .08447 .66865 .07948 Mtetra
.66865 .07948 .67208 .08447 .67922 .08177 .6758 .07677 Mtetra
.6758 .07677 .67922 .08177 .68638 .07907 .68297 .07406 Mtetra
.68297 .07406 .68638 .07907 .69356 .07635 .69017 .07133 Mtetra
.69017 .07133 .69356 .07635 .70075 .07364 .69737 .0686 Mtetra
.69737 .0686 .70075 .07364 .70797 .07091 .7046 .06586 Mtetra
.7046 .06586 .70797 .07091 .7152 .06818 .71185 .06312 Mtetra
.71185 .06312 .7152 .06818 .72245 .06544 .71911 .06036 Mtetra
.71911 .06036 .72245 .06544 .72972 .06269 .72639 .0576 Mtetra
.0813 .29636 .08561 .30038 .09136 .29821 .08705 .29417 Mtetra
.08705 .29417 .09136 .29821 .09712 .29602 .09283 .29198 Mtetra
.09283 .29198 .09712 .29602 .1029 .29383 .09861 .28978 Mtetra
.663 .741 .908 r
.09861 .28978 .1029 .29383 .10869 .29164 .10441 .28759 Mtetra
.10441 .28759 .10869 .29164 .1145 .28945 .11022 .28539 Mtetra
.662 .741 .908 r
.11022 .28539 .1145 .28945 .12031 .28726 .11604 .2832 Mtetra
.661 .741 .909 r
.11604 .2832 .12031 .28726 .12614 .28508 .12187 .28103 Mtetra
.658 .741 .912 r
.12187 .28103 .12614 .28508 .13198 .28292 .12771 .2789 Mtetra
.651 .742 .916 r
.12771 .2789 .13198 .28292 .13782 .28082 .13355 .27687 Mtetra
.637 .742 .924 r
.13355 .27687 .13782 .28082 .14366 .27883 .13938 .27502 Mtetra
.603 .741 .942 r
.13938 .27502 .14366 .27883 .14949 .27706 .14518 .27357 Mtetra
.513 .728 .971 r
.14518 .27357 .14949 .27706 .15528 .27577 .1509 .27291 Mtetra
.193 .61 .946 r
.1509 .27291 .15528 .27577 .16097 .27541 .15645 .2738 Mtetra
.578 .003 0 r
.15645 .2738 .16097 .27541 .16647 .27689 .16167 .27774 Mtetra
.826 .402 .233 r
.16167 .27774 .16647 .27689 .17159 .28195 .16626 .28743 Mtetra
.848 .505 .405 r
.16626 .28743 .17159 .28195 .17601 .29369 .16976 .30722 Mtetra
.842 .533 .467 r
.16976 .30722 .17601 .29369 .17923 .31684 .17166 .34227 Mtetra
.825 .531 .491 r
.17166 .34227 .17923 .31684 .18081 .35618 .17198 .3931 Mtetra
.787 .497 .497 r
.17198 .3931 .18081 .35618 .18109 .40933 .17252 .44376 Mtetra
.662 .366 .461 r
.17252 .44376 .18109 .40933 .18238 .45486 .17685 .46073 Mtetra
.992 .827 .579 r
.17685 .46073 .18238 .45486 .1881 .45918 .18646 .42787 Mtetra
.841 .598 .57 r
.18646 .42787 .1881 .45918 .19858 .41668 .19854 .36989 Mtetra
.786 .541 .567 r
.19854 .36989 .19858 .41668 .21051 .358 .20982 .3178 Mtetra
.758 .522 .575 r
.20982 .3178 .21051 .358 .22123 .30987 .21929 .28237 Mtetra
.744 .525 .597 r
.21929 .28237 .22123 .30987 .23019 .27847 .22729 .26105 Mtetra
.738 .547 .636 r
.22729 .26105 .23019 .27847 .23787 .25986 .23439 .24863 Mtetra
.731 .587 .695 r
.23439 .24863 .23787 .25986 .24479 .24902 .241 .24121 Mtetra
.718 .635 .765 r
.241 .24121 .24479 .24902 .2513 .24248 .24736 .23648 Mtetra
.693 .677 .83 r
.24736 .23648 .2513 .24248 .25761 .23827 .25359 .23324 Mtetra
.658 .704 .881 r
.25359 .23324 .25761 .23827 .26381 .2354 .25975 .23093 Mtetra
.608 .715 .92 r
.25975 .23093 .26381 .2354 .26995 .23345 .26586 .22939 Mtetra
.523 .705 .954 r
.26586 .22939 .26995 .23345 .27604 .23236 .27191 .22871 Mtetra
.348 .648 .967 r
.27191 .22871 .27604 .23236 .28205 .23235 .27789 .22921 Mtetra
0 .436 .845 r
.27789 .22921 .28205 .23235 .28797 .23385 .28376 .23145 Mtetra
.557 0 0 r
.28376 .23145 .28797 .23385 .29376 .23756 .28947 .23622 Mtetra
.796 .303 .003 r
.28947 .23622 .29376 .23756 .29936 .24437 .29496 .24443 Mtetra
.858 .43 .203 r
.29496 .24443 .29936 .24437 .30472 .25511 .30021 .25674 Mtetra
.869 .476 .29 r
.30021 .25674 .30472 .25511 .30988 .26987 .30528 .27271 Mtetra
.862 .477 .315 r
.30528 .27271 .30988 .26987 .31496 .28695 .31036 .28966 Mtetra
.827 .415 .264 r
.31036 .28966 .31496 .28695 .32027 .30189 .31584 .30222 Mtetra
.429 0 0 r
.31584 .30222 .32027 .30189 .3262 .30861 .32205 .30456 Mtetra
.88 .787 .754 r
.32205 .30456 .3262 .30861 .33292 .3031 .32907 .29452 Mtetra
.876 .688 .645 r
.32907 .29452 .33292 .3031 .34029 .2868 .33663 .27551 Mtetra
.862 .657 .624 r
.33663 .27551 .34029 .2868 .34792 .26531 .3443 .2536 Mtetra
.849 .648 .63 r
.3443 .2536 .34792 .26531 .35546 .24421 .3518 .23357 Mtetra
.837 .651 .651 r
.3518 .23357 .35546 .24421 .36275 .22656 .35903 .21746 Mtetra
.823 .663 .684 r
.35903 .21746 .36275 .22656 .36979 .21303 .36601 .20535 Mtetra
.806 .68 .725 r
.36601 .20535 .36979 .21303 .37662 .20305 .3728 .19644 Mtetra
.783 .698 .77 r
.3728 .19644 .37662 .20305 .38331 .19568 .37947 .18982 Mtetra
.758 .714 .811 r
.37947 .18982 .38331 .19568 .38992 .1901 .38606 .18473 Mtetra
.733 .725 .843 r
.38606 .18473 .38992 .1901 .39648 .18569 .39262 .18063 Mtetra
.712 .732 .866 r
.39262 .18063 .39648 .18569 .40302 .18202 .39916 .17715 Mtetra
.696 .736 .882 r
.39916 .17715 .40302 .18202 .40955 .17881 .40569 .17405 Mtetra
.684 .738 .891 r
.40569 .17405 .40955 .17881 .41608 .17589 .41223 .17119 Mtetra
.677 .739 .898 r
.41223 .17119 .41608 .17589 .42262 .17313 .41878 .16848 Mtetra
.672 .74 .901 r
.41878 .16848 .42262 .17313 .42917 .17048 .42534 .16584 Mtetra
.669 .74 .904 r
.42534 .16584 .42917 .17048 .43573 .16789 .43191 .16326 Mtetra
.667 .74 .905 r
.43191 .16326 .43573 .16789 .44231 .16534 .4385 .1607 Mtetra
.666 .741 .906 r
.4385 .1607 .44231 .16534 .4489 .1628 .4451 .15816 Mtetra
.665 .741 .906 r
.4451 .15816 .4489 .1628 .45551 .16027 .45172 .15563 Mtetra
.665 .741 .907 r
.45172 .15563 .45551 .16027 .46213 .15775 .45835 .1531 Mtetra
.664 .741 .907 r
.45835 .1531 .46213 .15775 .46878 .15522 .465 .15056 Mtetra
.465 .15056 .46878 .15522 .47543 .1527 .47167 .14802 Mtetra
.47167 .14802 .47543 .1527 .4821 .15017 .47835 .14548 Mtetra
.47835 .14548 .4821 .15017 .48879 .14763 .48505 .14293 Mtetra
.48505 .14293 .48879 .14763 .4955 .14509 .49177 .14038 Mtetra
.49177 .14038 .4955 .14509 .50222 .14254 .4985 .13782 Mtetra
.4985 .13782 .50222 .14254 .50896 .13999 .50525 .13526 Mtetra
.50525 .13526 .50896 .13999 .51571 .13743 .51201 .13269 Mtetra
.51201 .13269 .51571 .13743 .52248 .13486 .5188 .13011 Mtetra
.5188 .13011 .52248 .13486 .52927 .13229 .5256 .12752 Mtetra
.5256 .12752 .52927 .13229 .53608 .12971 .53241 .12493 Mtetra
.53241 .12493 .53608 .12971 .5429 .12713 .53924 .12234 Mtetra
.53924 .12234 .5429 .12713 .54974 .12453 .54609 .11973 Mtetra
.54609 .11973 .54974 .12453 .55659 .12194 .55296 .11712 Mtetra
.55296 .11712 .55659 .12194 .56347 .11933 .55985 .11451 Mtetra
.55985 .11451 .56347 .11933 .57036 .11672 .56675 .11189 Mtetra
.56675 .11189 .57036 .11672 .57726 .11411 .57367 .10926 Mtetra
.57367 .10926 .57726 .11411 .58419 .11148 .5806 .10662 Mtetra
.5806 .10662 .58419 .11148 .59113 .10885 .58755 .10398 Mtetra
.58755 .10398 .59113 .10885 .59809 .10622 .59453 .10133 Mtetra
.59453 .10133 .59809 .10622 .60507 .10357 .60151 .09868 Mtetra
.60151 .09868 .60507 .10357 .61206 .10092 .60852 .09601 Mtetra
.60852 .09601 .61206 .10092 .61907 .09827 .61554 .09334 Mtetra
.61554 .09334 .61907 .09827 .6261 .0956 .62258 .09067 Mtetra
.62258 .09067 .6261 .0956 .63315 .09293 .62964 .08799 Mtetra
.62964 .08799 .63315 .09293 .64021 .09026 .63672 .0853 Mtetra
.63672 .0853 .64021 .09026 .64729 .08757 .64381 .0826 Mtetra
.64381 .0826 .64729 .08757 .65439 .08488 .65093 .0799 Mtetra
.65093 .0799 .65439 .08488 .66151 .08219 .65806 .07719 Mtetra
.65806 .07719 .66151 .08219 .66865 .07948 .6652 .07447 Mtetra
.6652 .07447 .66865 .07948 .6758 .07677 .67237 .07175 Mtetra
.67237 .07175 .6758 .07677 .68297 .07406 .67956 .06902 Mtetra
.67956 .06902 .68297 .07406 .69017 .07133 .68676 .06628 Mtetra
.68676 .06628 .69017 .07133 .69737 .0686 .69398 .06354 Mtetra
.69398 .06354 .69737 .0686 .7046 .06586 .70122 .06079 Mtetra
.70122 .06079 .7046 .06586 .71185 .06312 .70848 .05803 Mtetra
.70848 .05803 .71185 .06312 .71911 .06036 .71576 .05526 Mtetra
.71576 .05526 .71911 .06036 .72639 .0576 .72305 .05249 Mtetra
.07697 .29232 .0813 .29636 .08705 .29417 .08273 .29012 Mtetra
.08273 .29012 .08705 .29417 .09283 .29198 .08851 .28792 Mtetra
.663 .741 .908 r
.08851 .28792 .09283 .29198 .09861 .28978 .0943 .28572 Mtetra
.0943 .28572 .09861 .28978 .10441 .28759 .10011 .28351 Mtetra
.10011 .28351 .10441 .28759 .11022 .28539 .10592 .28131 Mtetra
.661 .741 .909 r
.10592 .28131 .11022 .28539 .11604 .2832 .11175 .27913 Mtetra
.658 .741 .911 r
.11175 .27913 .11604 .2832 .12187 .28103 .11758 .27699 Mtetra
.653 .742 .915 r
.11758 .27699 .12187 .28103 .12771 .2789 .12342 .27492 Mtetra
.642 .742 .922 r
.12342 .27492 .12771 .2789 .13355 .27687 .12925 .273 Mtetra
.615 .741 .936 r
.12925 .273 .13355 .27687 .13938 .27502 .13506 .27142 Mtetra
.545 .734 .963 r
.13506 .27142 .13938 .27502 .14518 .27357 .1408 .2705 Mtetra
.318 .667 .975 r
.1408 .2705 .14518 .27357 .1509 .27291 .14639 .2709 Mtetra
.404 0 0 r
.14639 .2709 .1509 .27291 .15645 .2738 .1517 .27387 Mtetra
.804 .347 .15 r
.1517 .27387 .15645 .2738 .16167 .27774 .15645 .28178 Mtetra
.847 .49 .378 r
.15645 .28178 .16167 .27774 .16626 .28743 .16022 .29855 Mtetra
.844 .53 .456 r
.16022 .29855 .16626 .28743 .16976 .30722 .16245 .3294 Mtetra
.831 .534 .487 r
.16245 .3294 .16976 .30722 .17166 .34227 .16293 .37694 Mtetra
.8 .51 .497 r
.16293 .37694 .17166 .34227 .17198 .3931 .16295 .43044 Mtetra
.715 .423 .48 r
.16295 .43044 .17198 .3931 .17252 .44376 .16593 .4589 Mtetra
.761 .819 .347 r
.16593 .4589 .17252 .44376 .17685 .46073 .1744 .4375 Mtetra
.864 .624 .574 r
.1744 .4375 .17685 .46073 .18646 .42787 .18639 .38229 Mtetra
.796 .551 .567 r
.18639 .38229 .18646 .42787 .19854 .36989 .19821 .32685 Mtetra
.763 .524 .572 r
.19821 .32685 .19854 .36989 .20982 .3178 .20824 .28718 Mtetra
.747 .522 .59 r
.20824 .28718 .20982 .3178 .21929 .28237 .21662 .2628 Mtetra
.739 .54 .624 r
.21662 .2628 .21929 .28237 .22729 .26105 .22393 .24856 Mtetra
.734 .576 .678 r
.22393 .24856 .22729 .26105 .23439 .24863 .23065 .24013 Mtetra
.723 .624 .747 r
.23065 .24013 .23439 .24863 .241 .24121 .23706 .23483 Mtetra
.703 .668 .813 r
.23706 .23483 .241 .24121 .24736 .23648 .24333 .23122 Mtetra
.673 .7 .866 r
.24333 .23122 .24736 .23648 .25359 .23324 .24951 .2286 Mtetra
.634 .715 .906 r
.24951 .2286 .25359 .23324 .25975 .23093 .25564 .22669 Mtetra
.576 .716 .938 r
.25564 .22669 .25975 .23093 .26586 .22939 .26173 .2255 Mtetra
.468 .693 .965 r
.26173 .2255 .26586 .22939 .27191 .22871 .26776 .22523 Mtetra
.229 .595 .949 r
.26776 .22523 .27191 .22871 .27789 .22921 .27369 .22632 Mtetra
0 .285 .709 r
.27369 .22632 .27789 .22921 .28376 .23145 .2795 .22941 Mtetra
.682 .139 0 r
.2795 .22941 .28376 .23145 .28947 .23622 .28512 .23536 Mtetra
.83 .365 .098 r
.28512 .23536 .28947 .23622 .29496 .24443 .29049 .24507 Mtetra
.866 .454 .245 r
.29049 .24507 .29496 .24443 .30021 .25674 .29563 .2589 Mtetra
.868 .482 .306 r
.29563 .2589 .30021 .25674 .30528 .27271 .30063 .27571 Mtetra
.854 .465 .309 r
.30063 .27571 .30528 .27271 .31036 .28966 .30577 .29175 Mtetra
.789 .343 .189 r
.30577 .29175 .31036 .28966 .31584 .30222 .31147 .30106 Mtetra
.582 .903 .982 r
.31147 .30106 .31584 .30222 .32205 .30456 .318 .29869 Mtetra
.883 .734 .691 r
.318 .29869 .32205 .30456 .32907 .29452 .3253 .28463 Mtetra
.871 .673 .632 r
.3253 .28463 .32907 .29452 .33663 .27551 .33299 .2638 Mtetra
.857 .652 .624 r
.33299 .2638 .33663 .27551 .3443 .2536 .34067 .24216 Mtetra
.845 .648 .636 r
.34067 .24216 .3443 .2536 .3518 .23357 .34811 .22347 Mtetra
.832 .655 .662 r
.34811 .22347 .3518 .23357 .35903 .21746 .35527 .20891 Mtetra
.817 .669 .699 r
.35527 .20891 .35903 .21746 .36601 .20535 .36219 .19809 Mtetra
.798 .687 .742 r
.36219 .19809 .36601 .20535 .3728 .19644 .36894 .19013 Mtetra
.774 .704 .786 r
.36894 .19013 .3728 .19644 .37947 .18982 .37559 .18415 Mtetra
.748 .718 .824 r
.37559 .18415 .37947 .18982 .38606 .18473 .38218 .17948 Mtetra
.725 .728 .853 r
.38218 .17948 .38606 .18473 .39262 .18063 .38873 .17563 Mtetra
.705 .733 .873 r
.38873 .17563 .39262 .18063 .39916 .17715 .39527 .17231 Mtetra
.691 .737 .886 r
.39527 .17231 .39916 .17715 .40569 .17405 .40181 .16931 Mtetra
.681 .738 .894 r
.40181 .16931 .40569 .17405 .41223 .17119 .40836 .1665 Mtetra
.675 .739 .899 r
.40836 .1665 .41223 .17119 .41878 .16848 .41492 .16381 Mtetra
.671 .74 .902 r
.41492 .16381 .41878 .16848 .42534 .16584 .42148 .16119 Mtetra
.668 .74 .904 r
.42148 .16119 .42534 .16584 .43191 .16326 .42807 .15861 Mtetra
.666 .741 .905 r
.42807 .15861 .43191 .16326 .4385 .1607 .43466 .15605 Mtetra
.665 .741 .906 r
.43466 .15605 .4385 .1607 .4451 .15816 .44128 .15351 Mtetra
.665 .741 .907 r
.44128 .15351 .4451 .15816 .45172 .15563 .44791 .15096 Mtetra
.664 .741 .907 r
.44791 .15096 .45172 .15563 .45835 .1531 .45455 .14842 Mtetra
.45455 .14842 .45835 .1531 .465 .15056 .46121 .14588 Mtetra
.46121 .14588 .465 .15056 .47167 .14802 .46789 .14333 Mtetra
.46789 .14333 .47167 .14802 .47835 .14548 .47458 .14078 Mtetra
.47458 .14078 .47835 .14548 .48505 .14293 .48129 .13822 Mtetra
.48129 .13822 .48505 .14293 .49177 .14038 .48802 .13565 Mtetra
.48802 .13565 .49177 .14038 .4985 .13782 .49476 .13308 Mtetra
.49476 .13308 .4985 .13782 .50525 .13526 .50152 .1305 Mtetra
.50152 .1305 .50525 .13526 .51201 .13269 .5083 .12792 Mtetra
.5083 .12792 .51201 .13269 .5188 .13011 .51509 .12533 Mtetra
.51509 .12533 .5188 .13011 .5256 .12752 .5219 .12274 Mtetra
.5219 .12274 .5256 .12752 .53241 .12493 .52873 .12013 Mtetra
.52873 .12013 .53241 .12493 .53924 .12234 .53557 .11753 Mtetra
.53557 .11753 .53924 .12234 .54609 .11973 .54243 .11491 Mtetra
.54243 .11491 .54609 .11973 .55296 .11712 .54931 .11229 Mtetra
.54931 .11229 .55296 .11712 .55985 .11451 .55621 .10966 Mtetra
.55621 .10966 .55985 .11451 .56675 .11189 .56312 .10703 Mtetra
.56312 .10703 .56675 .11189 .57367 .10926 .57005 .10439 Mtetra
.57005 .10439 .57367 .10926 .5806 .10662 .577 .10174 Mtetra
.577 .10174 .5806 .10662 .58755 .10398 .58396 .09908 Mtetra
.58396 .09908 .58755 .10398 .59453 .10133 .59094 .09642 Mtetra
.59094 .09642 .59453 .10133 .60151 .09868 .59794 .09376 Mtetra
.59794 .09376 .60151 .09868 .60852 .09601 .60496 .09108 Mtetra
.60496 .09108 .60852 .09601 .61554 .09334 .612 .0884 Mtetra
.612 .0884 .61554 .09334 .62258 .09067 .61905 .08571 Mtetra
.61905 .08571 .62258 .09067 .62964 .08799 .62612 .08302 Mtetra
.62612 .08302 .62964 .08799 .63672 .0853 .63321 .08031 Mtetra
.63321 .08031 .63672 .0853 .64381 .0826 .64032 .07761 Mtetra
.64032 .07761 .64381 .0826 .65093 .0799 .64744 .07489 Mtetra
.64744 .07489 .65093 .0799 .65806 .07719 .65458 .07217 Mtetra
.65458 .07217 .65806 .07719 .6652 .07447 .66174 .06944 Mtetra
.66174 .06944 .6652 .07447 .67237 .07175 .66892 .0667 Mtetra
.66892 .0667 .67237 .07175 .67956 .06902 .67612 .06396 Mtetra
.67612 .06396 .67956 .06902 .68676 .06628 .68334 .06121 Mtetra
.68334 .06121 .68676 .06628 .69398 .06354 .69057 .05845 Mtetra
.69057 .05845 .69398 .06354 .70122 .06079 .69782 .05569 Mtetra
.69782 .05569 .70122 .06079 .70848 .05803 .70509 .05292 Mtetra
.70509 .05292 .70848 .05803 .71576 .05526 .71239 .05014 Mtetra
.71239 .05014 .71576 .05526 .72305 .05249 .71969 .04736 Mtetra
.07262 .28825 .07697 .29232 .08273 .29012 .07839 .28605 Mtetra
.07839 .28605 .08273 .29012 .08851 .28792 .08418 .28384 Mtetra
.663 .741 .908 r
.08418 .28384 .08851 .28792 .0943 .28572 .08997 .28163 Mtetra
.08997 .28163 .0943 .28572 .10011 .28351 .09579 .27943 Mtetra
.662 .741 .909 r
.09579 .27943 .10011 .28351 .10592 .28131 .10161 .27723 Mtetra
.659 .741 .91 r
.10161 .27723 .10592 .28131 .11175 .27913 .10744 .27507 Mtetra
.655 .741 .913 r
.10744 .27507 .11175 .27913 .11758 .27699 .11327 .27297 Mtetra
.645 .742 .919 r
.11327 .27297 .11758 .27699 .12342 .27492 .1191 .271 Mtetra
.624 .742 .932 r
.1191 .271 .12342 .27492 .12925 .273 .12491 .26931 Mtetra
.57 .738 .955 r
.12491 .26931 .12925 .273 .13506 .27142 .13067 .26817 Mtetra
.405 .699 .981 r
.13067 .26817 .13506 .27142 .1408 .2705 .1363 .26815 Mtetra
0 .365 .738 r
.1363 .26815 .1408 .2705 .14639 .2709 .14168 .27031 Mtetra
.766 .269 .036 r
.14168 .27031 .14639 .2709 .1517 .27387 .14658 .27668 Mtetra
.844 .47 .343 r
.14658 .27668 .1517 .27387 .15645 .28178 .15059 .29077 Mtetra
.846 .525 .443 r
.15059 .29077 .15645 .28178 .16022 .29855 .15316 .31764 Mtetra
.835 .536 .482 r
.15316 .31764 .16022 .29855 .16245 .3294 .15391 .36127 Mtetra
.81 .519 .496 r
.15391 .36127 .16245 .3294 .16293 .37694 .15362 .41552 Mtetra
.748 .457 .489 r
.15362 .41552 .16293 .37694 .16295 .43044 .15537 .45367 Mtetra
.23 0 .253 r
.15537 .45367 .16295 .43044 .16593 .4589 .16249 .44493 Mtetra
.894 .662 .58 r
.16249 .44493 .16593 .4589 .1744 .4375 .17411 .39482 Mtetra
.808 .563 .567 r
.17411 .39482 .1744 .4375 .18639 .38229 .18639 .33699 Mtetra
.769 .528 .569 r
.18639 .33699 .18639 .38229 .19821 .32685 .19702 .29297 Mtetra
.75 .521 .584 r
.19702 .29297 .19821 .32685 .20824 .28718 .20583 .26518 Mtetra
.741 .534 .613 r
.20583 .26518 .20824 .28718 .21662 .2628 .2134 .24886 Mtetra
.735 .566 .663 r
.2134 .24886 .21662 .2628 .22393 .24856 .22025 .23926 Mtetra
.727 .612 .729 r
.22025 .23926 .22393 .24856 .23065 .24013 .22674 .23332 Mtetra
.71 .658 .797 r
.22674 .23332 .23065 .24013 .23706 .23483 .23304 .22932 Mtetra
.685 .694 .853 r
.23304 .22932 .23706 .23483 .24333 .23122 .23924 .22641 Mtetra
.653 .714 .893 r
.23924 .22641 .24333 .23122 .24951 .2286 .24539 .2242 Mtetra
.61 .721 .924 r
.24539 .2242 .24951 .2286 .25564 .22669 .2515 .22261 Mtetra
.539 .712 .952 r
.2515 .22261 .25564 .22669 .26173 .2255 .25756 .22176 Mtetra
.397 .67 .97 r
.25756 .22176 .26173 .2255 .26776 .22523 .26356 .22195 Mtetra
.074 .51 .899 r
.26356 .22195 .26776 .22523 .27369 .22632 .26945 .2237 Mtetra
.449 0 0 r
.26945 .2237 .27369 .22632 .2795 .22941 .27518 .22776 Mtetra
.762 .248 0 r
.27518 .22776 .2795 .22941 .28512 .23536 .28069 .23502 Mtetra
.85 .409 .168 r
.28069 .23502 .28512 .23536 .29049 .24507 .28594 .24629 Mtetra
.869 .47 .276 r
.28594 .24629 .29049 .24507 .29563 .2589 .29097 .2615 Mtetra
.865 .481 .314 r
.29097 .2615 .29563 .2589 .30063 .27571 .29594 .27862 Mtetra
.841 .442 .289 r
.29594 .27862 .30063 .27571 .30577 .29175 .30121 .29288 Mtetra
.678 .16 0 r
.30121 .29288 .30577 .29175 .31147 .30106 .30719 .29818 Mtetra
.857 .845 .831 r
.30719 .29818 .31147 .30106 .318 .29869 .31406 .2911 Mtetra
.879 .702 .658 r
.31406 .2911 .318 .29869 .3253 .28463 .32159 .27375 Mtetra
.865 .662 .626 r
.32159 .27375 .3253 .28463 .33299 .2638 .32936 .25197 Mtetra
.853 .649 .627 r
.32936 .25197 .33299 .2638 .34067 .24216 .33701 .23113 Mtetra
.84 .649 .644 r
.33701 .23113 .34067 .24216 .34811 .22347 .34438 .21395 Mtetra
.827 .659 .675 r
.34438 .21395 .34811 .22347 .35527 .20891 .35147 .20086 Mtetra
.811 .675 .714 r
.35147 .20086 .35527 .20891 .36219 .19809 .35834 .19122 Mtetra
.789 .694 .759 r
.35834 .19122 .36219 .19809 .36894 .19013 .36506 .18408 Mtetra
.764 .71 .801 r
.36506 .18408 .36894 .19013 .37559 .18415 .37169 .17865 Mtetra
.739 .722 .836 r
.37169 .17865 .37559 .18415 .38218 .17948 .37827 .17432 Mtetra
.717 .73 .861 r
.37827 .17432 .38218 .17948 .38873 .17563 .38483 .17069 Mtetra
.699 .735 .878 r
.38483 .17069 .38873 .17563 .39527 .17231 .39137 .1675 Mtetra
.687 .737 .889 r
.39137 .1675 .39527 .17231 .40181 .16931 .39792 .16457 Mtetra
.678 .739 .896 r
.39792 .16457 .40181 .16931 .40836 .1665 .40447 .16181 Mtetra
.673 .74 .901 r
.40447 .16181 .40836 .1665 .41492 .16381 .41104 .15914 Mtetra
.67 .74 .903 r
.41104 .15914 .41492 .16381 .42148 .16119 .41762 .15653 Mtetra
.667 .74 .905 r
.41762 .15653 .42148 .16119 .42807 .15861 .42421 .15395 Mtetra
.666 .741 .906 r
.42421 .15395 .42807 .15861 .43466 .15605 .43082 .15138 Mtetra
.665 .741 .906 r
.43082 .15138 .43466 .15605 .44128 .15351 .43744 .14883 Mtetra
.665 .741 .907 r
.43744 .14883 .44128 .15351 .44791 .15096 .44408 .14628 Mtetra
.664 .741 .907 r
.44408 .14628 .44791 .15096 .45455 .14842 .45073 .14373 Mtetra
.45073 .14373 .45455 .14842 .46121 .14588 .4574 .14117 Mtetra
.4574 .14117 .46121 .14588 .46789 .14333 .46409 .13861 Mtetra
.46409 .13861 .46789 .14333 .47458 .14078 .4708 .13605 Mtetra
.4708 .13605 .47458 .14078 .48129 .13822 .47752 .13348 Mtetra
.47752 .13348 .48129 .13822 .48802 .13565 .48425 .1309 Mtetra
.48425 .1309 .48802 .13565 .49476 .13308 .49101 .12832 Mtetra
.49101 .12832 .49476 .13308 .50152 .1305 .49778 .12573 Mtetra
.49778 .12573 .50152 .1305 .5083 .12792 .50457 .12314 Mtetra
.50457 .12314 .5083 .12792 .51509 .12533 .51137 .12054 Mtetra
.51137 .12054 .51509 .12533 .5219 .12274 .51819 .11793 Mtetra
.51819 .11793 .5219 .12274 .52873 .12013 .52503 .11531 Mtetra
.52503 .11531 .52873 .12013 .53557 .11753 .53188 .11269 Mtetra
.53188 .11269 .53557 .11753 .54243 .11491 .53876 .11007 Mtetra
.53876 .11007 .54243 .11491 .54931 .11229 .54565 .10743 Mtetra
.54565 .10743 .54931 .11229 .55621 .10966 .55255 .10479 Mtetra
.55255 .10479 .55621 .10966 .56312 .10703 .55948 .10215 Mtetra
.55948 .10215 .56312 .10703 .57005 .10439 .56642 .09949 Mtetra
.56642 .09949 .57005 .10439 .577 .10174 .57338 .09683 Mtetra
.57338 .09683 .577 .10174 .58396 .09908 .58035 .09417 Mtetra
.58035 .09417 .58396 .09908 .59094 .09642 .58735 .09149 Mtetra
.58735 .09149 .59094 .09642 .59794 .09376 .59436 .08881 Mtetra
.59436 .08881 .59794 .09376 .60496 .09108 .60139 .08613 Mtetra
.60139 .08613 .60496 .09108 .612 .0884 .60844 .08343 Mtetra
.60844 .08343 .612 .0884 .61905 .08571 .6155 .08073 Mtetra
.6155 .08073 .61905 .08571 .62612 .08302 .62258 .07802 Mtetra
.62258 .07802 .62612 .08302 .63321 .08031 .62968 .07531 Mtetra
.62968 .07531 .63321 .08031 .64032 .07761 .6368 .07259 Mtetra
.6368 .07259 .64032 .07761 .64744 .07489 .64394 .06986 Mtetra
.64394 .06986 .64744 .07489 .65458 .07217 .65109 .06712 Mtetra
.65109 .06712 .65458 .07217 .66174 .06944 .65827 .06438 Mtetra
.65827 .06438 .66174 .06944 .66892 .0667 .66546 .06163 Mtetra
.66546 .06163 .66892 .0667 .67612 .06396 .67267 .05888 Mtetra
.67267 .05888 .67612 .06396 .68334 .06121 .6799 .05611 Mtetra
.6799 .05611 .68334 .06121 .69057 .05845 .68714 .05335 Mtetra
.68714 .05335 .69057 .05845 .69782 .05569 .69441 .05057 Mtetra
.69441 .05057 .69782 .05569 .70509 .05292 .70169 .04778 Mtetra
.70169 .04778 .70509 .05292 .71239 .05014 .709 .04499 Mtetra
.709 .04499 .71239 .05014 .71969 .04736 .71632 .04219 Mtetra
.06825 .28418 .07262 .28825 .07839 .28605 .07403 .28196 Mtetra
.663 .741 .908 r
.07403 .28196 .07839 .28605 .08418 .28384 .07982 .27975 Mtetra
.07982 .27975 .08418 .28384 .08997 .28163 .08563 .27754 Mtetra
.662 .741 .908 r
.08563 .27754 .08997 .28163 .09579 .27943 .09144 .27533 Mtetra
.66 .741 .91 r
.09144 .27533 .09579 .27943 .10161 .27723 .09727 .27315 Mtetra
.656 .741 .912 r
.09727 .27315 .10161 .27723 .10744 .27507 .1031 .27103 Mtetra
.649 .742 .918 r
.1031 .27103 .10744 .27507 .11327 .27297 .10893 .26901 Mtetra
.631 .742 .928 r
.10893 .26901 .11327 .27297 .1191 .271 .11475 .26723 Mtetra
.589 .74 .948 r
.11475 .26723 .1191 .271 .12491 .26931 .12051 .26591 Mtetra
.468 .718 .978 r
.12051 .26591 .12491 .26931 .13067 .26817 .12617 .26552 Mtetra
.02 .512 .873 r
.12617 .26552 .13067 .26817 .1363 .26815 .13162 .26699 Mtetra
.698 .158 0 r
.13162 .26699 .1363 .26815 .14168 .27031 .13665 .27204 Mtetra
.837 .442 .298 r
.13665 .27204 .14168 .27031 .14658 .27668 .14088 .28378 Mtetra
.847 .517 .427 r
.14088 .28378 .14658 .27668 .15059 .29077 .14379 .30695 Mtetra
.839 .536 .476 r
.14379 .30695 .15059 .29077 .15316 .31764 .14486 .34635 Mtetra
.819 .526 .495 r
.14486 .34635 .15316 .31764 .15391 .36127 .14447 .39963 Mtetra
.771 .48 .494 r
.14447 .39963 .15391 .36127 .15362 .41552 .14517 .44528 Mtetra
.552 .252 .412 r
.14517 .44528 .15362 .41552 .15537 .45367 .1508 .44962 Mtetra
.936 .721 .587 r
.1508 .44962 .15537 .45367 .16249 .44493 .16175 .40697 Mtetra
.823 .578 .569 r
.16175 .40697 .16249 .44493 .17411 .39482 .17436 .3481 Mtetra
.777 .534 .568 r
.17436 .3481 .17411 .39482 .18639 .33699 .18561 .29981 Mtetra
.754 .52 .579 r
.18561 .29981 .18639 .33699 .19702 .29297 .19492 .26829 Mtetra
.742 .528 .604 r
.19492 .26829 .19702 .29297 .20583 .26518 .20278 .24958 Mtetra
.737 .556 .648 r
.20278 .24958 .20583 .26518 .2134 .24886 .2098 .23864 Mtetra
.73 .6 .711 r
.2098 .23864 .2134 .24886 .22025 .23926 .21637 .23195 Mtetra
.716 .648 .78 r
.21637 .23195 .22025 .23926 .22674 .23332 .22271 .22753 Mtetra
.694 .686 .839 r
.22271 .22753 .22674 .23332 .23304 .22932 .22894 .22433 Mtetra
.666 .711 .881 r
.22894 .22433 .23304 .22932 .23924 .22641 .23511 .22187 Mtetra
.633 .722 .912 r
.23511 .22187 .23924 .22641 .24539 .2242 .24124 .21997 Mtetra
.584 .721 .938 r
.24124 .21997 .24539 .2242 .2515 .22261 .24733 .21867 Mtetra
.495 .703 .962 r
.24733 .21867 .2515 .22261 .25756 .22176 .25337 .21817 Mtetra
.302 .631 .963 r
.25337 .21817 .25756 .22176 .26356 .22195 .25932 .21888 Mtetra
0 .384 .8 r
.25932 .21888 .26356 .22195 .26945 .2237 .26515 .2214 Mtetra
.607 .05 0 r
.26515 .2214 .26945 .2237 .27518 .22776 .27079 .22655 Mtetra
.81 .327 .04 r
.27079 .22655 .27518 .22776 .28069 .23502 .27619 .23524 Mtetra
.861 .44 .219 r
.27619 .23524 .28069 .23502 .28594 .24629 .28131 .24807 Mtetra
.869 .479 .297 r
.28131 .24807 .28594 .24629 .29097 .2615 .28625 .26439 Mtetra
.859 .474 .314 r
.28625 .26439 .29097 .2615 .29594 .27862 .29124 .28114 Mtetra
.817 .397 .244 r
.29124 .28114 .29594 .27862 .30121 .29288 .29671 .29271 Mtetra
.134 0 0 r
.29671 .29271 .30121 .29288 .30719 .29818 .30302 .29348 Mtetra
.882 .765 .728 r
.30302 .29348 .30719 .29818 .31406 .2911 .3102 .282 Mtetra
.874 .682 .64 r
.3102 .282 .31406 .2911 .32159 .27375 .31792 .26222 Mtetra
.86 .655 .624 r
.31792 .26222 .32159 .27375 .32936 .25197 .32573 .24028 Mtetra
.848 .648 .632 r
.32573 .24028 .32936 .25197 .33701 .23113 .33332 .22062 Mtetra
.836 .652 .654 r
.33332 .22062 .33701 .23113 .34438 .21395 .34061 .20499 Mtetra
.821 .665 .689 r
.34061 .20499 .34438 .21395 .35147 .20086 .34764 .19328 Mtetra
.803 .682 .731 r
.34764 .19328 .35147 .20086 .35834 .19122 .35446 .18467 Mtetra
.78 .7 .775 r
.35446 .18467 .35834 .19122 .36506 .18408 .36116 .17824 Mtetra
.755 .715 .815 r
.36116 .17824 .36506 .18408 .37169 .17865 .36777 .17327 Mtetra
.73 .726 .846 r
.36777 .17327 .37169 .17865 .37827 .17432 .37435 .16924 Mtetra
.71 .732 .869 r
.37435 .16924 .37827 .17432 .38483 .17069 .3809 .16579 Mtetra
.694 .736 .883 r
.3809 .16579 .38483 .17069 .39137 .1675 .38745 .1627 Mtetra
.683 .738 .892 r
.38745 .1627 .39137 .1675 .39792 .16457 .39401 .15984 Mtetra
.676 .739 .898 r
.39401 .15984 .39792 .16457 .40447 .16181 .40057 .1571 Mtetra
.671 .74 .902 r
.40057 .1571 .40447 .16181 .41104 .15914 .40714 .15445 Mtetra
.669 .74 .904 r
.40714 .15445 .41104 .15914 .41762 .15653 .41373 .15184 Mtetra
.667 .74 .905 r
.41373 .15184 .41762 .15653 .42421 .15395 .42033 .14926 Mtetra
.666 .741 .906 r
.42033 .14926 .42421 .15395 .43082 .15138 .42695 .1467 Mtetra
.665 .741 .907 r
.42695 .1467 .43082 .15138 .43744 .14883 .43358 .14414 Mtetra
.43358 .14414 .43744 .14883 .44408 .14628 .44023 .14157 Mtetra
.664 .741 .907 r
.44023 .14157 .44408 .14628 .45073 .14373 .4469 .13901 Mtetra
.4469 .13901 .45073 .14373 .4574 .14117 .45358 .13645 Mtetra
.45358 .13645 .4574 .14117 .46409 .13861 .46028 .13388 Mtetra
.46028 .13388 .46409 .13861 .4708 .13605 .46699 .1313 Mtetra
.46699 .1313 .4708 .13605 .47752 .13348 .47372 .12872 Mtetra
.47372 .12872 .47752 .13348 .48425 .1309 .48047 .12613 Mtetra
.48047 .12613 .48425 .1309 .49101 .12832 .48724 .12354 Mtetra
.48724 .12354 .49101 .12832 .49778 .12573 .49402 .12094 Mtetra
.49402 .12094 .49778 .12573 .50457 .12314 .50082 .11833 Mtetra
.50082 .11833 .50457 .12314 .51137 .12054 .50763 .11572 Mtetra
.50763 .11572 .51137 .12054 .51819 .11793 .51446 .1131 Mtetra
.51446 .1131 .51819 .11793 .52503 .11531 .52131 .11047 Mtetra
.52131 .11047 .52503 .11531 .53188 .11269 .52818 .10784 Mtetra
.52818 .10784 .53188 .11269 .53876 .11007 .53506 .1052 Mtetra
.53506 .1052 .53876 .11007 .54565 .10743 .54196 .10255 Mtetra
.54196 .10255 .54565 .10743 .55255 .10479 .54888 .0999 Mtetra
.54888 .0999 .55255 .10479 .55948 .10215 .55582 .09724 Mtetra
.55582 .09724 .55948 .10215 .56642 .09949 .56277 .09458 Mtetra
.56277 .09458 .56642 .09949 .57338 .09683 .56974 .0919 Mtetra
.56974 .0919 .57338 .09683 .58035 .09417 .57673 .08923 Mtetra
.57673 .08923 .58035 .09417 .58735 .09149 .58373 .08654 Mtetra
.58373 .08654 .58735 .09149 .59436 .08881 .59076 .08385 Mtetra
.59076 .08385 .59436 .08881 .60139 .08613 .5978 .08115 Mtetra
.5978 .08115 .60139 .08613 .60844 .08343 .60486 .07844 Mtetra
.60486 .07844 .60844 .08343 .6155 .08073 .61193 .07573 Mtetra
.61193 .07573 .6155 .08073 .62258 .07802 .61903 .07301 Mtetra
.61903 .07301 .62258 .07802 .62968 .07531 .62614 .07028 Mtetra
.62614 .07028 .62968 .07531 .6368 .07259 .63327 .06755 Mtetra
.63327 .06755 .6368 .07259 .64394 .06986 .64042 .06481 Mtetra
.64042 .06481 .64394 .06986 .65109 .06712 .64759 .06206 Mtetra
.64759 .06206 .65109 .06712 .65827 .06438 .65478 .0593 Mtetra
.65478 .0593 .65827 .06438 .66546 .06163 .66198 .05654 Mtetra
.66198 .05654 .66546 .06163 .67267 .05888 .6692 .05377 Mtetra
.6692 .05377 .67267 .05888 .6799 .05611 .67644 .051 Mtetra
.67644 .051 .6799 .05611 .68714 .05335 .6837 .04821 Mtetra
.6837 .04821 .68714 .05335 .69441 .05057 .69098 .04542 Mtetra
.69098 .04542 .69441 .05057 .70169 .04778 .69828 .04262 Mtetra
.69828 .04262 .70169 .04778 .709 .04499 .70559 .03982 Mtetra
.70559 .03982 .709 .04499 .71632 .04219 .71293 .03701 Mtetra
.663 .741 .908 r
.06386 .28008 .06825 .28418 .07403 .28196 .06965 .27787 Mtetra
.06965 .27787 .07403 .28196 .07982 .27975 .07545 .27565 Mtetra
.662 .741 .908 r
.07545 .27565 .07982 .27975 .08563 .27754 .08126 .27343 Mtetra
.661 .741 .909 r
.08126 .27343 .08563 .27754 .09144 .27533 .08708 .27124 Mtetra
.658 .741 .912 r
.08708 .27124 .09144 .27533 .09727 .27315 .09291 .26909 Mtetra
.651 .742 .916 r
.09291 .26909 .09727 .27315 .1031 .27103 .09874 .26704 Mtetra
.637 .742 .924 r
.09874 .26704 .1031 .27103 .10893 .26901 .10455 .26517 Mtetra
.603 .741 .942 r
.10455 .26517 .10893 .26901 .11475 .26723 .11033 .2637 Mtetra
.512 .728 .971 r
.11033 .2637 .11475 .26723 .12051 .26591 .11602 .26301 Mtetra
.191 .609 .945 r
.11602 .26301 .12051 .26591 .12617 .26552 .12152 .26388 Mtetra
.582 .008 0 r
.12152 .26388 .12617 .26552 .13162 .26699 .12666 .26781 Mtetra
.826 .403 .237 r
.12666 .26781 .13162 .26699 .13665 .27204 .1311 .27749 Mtetra
.847 .506 .407 r
.1311 .27749 .13665 .27204 .14088 .28378 .13433 .29729 Mtetra
.842 .534 .468 r
.13433 .29729 .14088 .28378 .14379 .30695 .13577 .3324 Mtetra
.825 .531 .492 r
.13577 .3324 .14379 .30695 .14486 .34635 .13543 .38333 Mtetra
.787 .497 .497 r
.13543 .38333 .14486 .34635 .14447 .39963 .13533 .43412 Mtetra
.661 .364 .459 r
.13533 .43412 .14447 .39963 .14517 .44528 .13942 .45114 Mtetra
.99 .825 .585 r
.13942 .45114 .14517 .44528 .1508 .44962 .14938 .41818 Mtetra
.841 .597 .571 r
.14938 .41818 .1508 .44962 .16175 .40697 .16212 .36001 Mtetra
.786 .541 .567 r
.16212 .36001 .16175 .40697 .17436 .3481 .174 .30776 Mtetra
.758 .521 .575 r
.174 .30776 .17436 .3481 .18561 .29981 .18386 .27221 Mtetra
.745 .525 .596 r
.18386 .27221 .18561 .29981 .19492 .26829 .19208 .25079 Mtetra
.738 .548 .635 r
.19208 .25079 .19492 .26829 .20278 .24958 .19929 .23828 Mtetra
.732 .588 .694 r
.19929 .23828 .20278 .24958 .2098 .23864 .20596 .23074 Mtetra
.721 .636 .763 r
.20596 .23074 .2098 .23864 .21637 .23195 .21235 .22585 Mtetra
.701 .678 .825 r
.21235 .22585 .21637 .23195 .22271 .22753 .21861 .22236 Mtetra
.677 .706 .87 r
.21861 .22236 .22271 .22753 .22894 .22433 .22479 .21966 Mtetra
.649 .721 .901 r
.22479 .21966 .22894 .22433 .23511 .22187 .23094 .21751 Mtetra
.613 .725 .926 r
.23094 .21751 .23511 .22187 .24124 .21997 .23705 .21586 Mtetra
.554 .718 .949 r
.23705 .21586 .24124 .21997 .24733 .21867 .24312 .21485 Mtetra
.438 .686 .969 r
.24312 .21485 .24733 .21867 .25337 .21817 .24913 .21475 Mtetra
.174 .567 .935 r
.24913 .21475 .25337 .21817 .25932 .21888 .25504 .21605 Mtetra
0 .224 .647 r
.25504 .21605 .25932 .21888 .26515 .2214 .26079 .21945 Mtetra
.715 .181 0 r
.26079 .21945 .26515 .2214 .27079 .22655 .26633 .22582 Mtetra
.838 .382 .125 r
.26633 .22582 .27079 .22655 .27619 .23524 .2716 .23604 Mtetra
.867 .46 .257 r
.2716 .23604 .27619 .23524 .28131 .24807 .2766 .25037 Mtetra
.868 .482 .31 r
.2766 .25037 .28131 .24807 .28625 .26439 .28148 .26736 Mtetra
.85 .459 .304 r
.28148 .26736 .28625 .26439 .29124 .28114 .28656 .28292 Mtetra
.765 .301 .143 r
.28656 .28292 .29124 .28114 .29671 .29271 .29229 .29096 Mtetra
.75 .913 .947 r
.29229 .29096 .29671 .29271 .30302 .29348 .29896 .28698 Mtetra
.882 .721 .678 r
.29896 .28698 .30302 .29348 .3102 .282 .30643 .27168 Mtetra
.869 .669 .63 r
.30643 .27168 .3102 .282 .31792 .26222 .31427 .25039 Mtetra
.856 .651 .625 r
.31427 .25039 .31792 .26222 .32573 .24028 .32207 .2289 Mtetra
.844 .648 .639 r
.32207 .2289 .32573 .24028 .33332 .22062 .32959 .21066 Mtetra
.831 .656 .666 r
.32959 .21066 .33332 .22062 .34061 .20499 .33681 .19656 Mtetra
.815 .671 .704 r
.33681 .19656 .34061 .20499 .34764 .19328 .34377 .18611 Mtetra
.795 .689 .748 r
.34377 .18611 .34764 .19328 .35446 .18467 .35055 .1784 Mtetra
.771 .706 .791 r
.35055 .1784 .35446 .18467 .36116 .17824 .35722 .17259 Mtetra
.745 .72 .828 r
.35722 .17259 .36116 .17824 .36777 .17327 .36383 .16801 Mtetra
.722 .729 .856 r
.36383 .16801 .36777 .17327 .37435 .16924 .3704 .16422 Mtetra
.703 .734 .875 r
.3704 .16422 .37435 .16924 .3809 .16579 .37696 .16091 Mtetra
.69 .737 .887 r
.37696 .16091 .3809 .16579 .38745 .1627 .38352 .15791 Mtetra
.68 .739 .895 r
.38352 .15791 .38745 .1627 .39401 .15984 .39008 .1551 Mtetra
.674 .74 .9 r
.39008 .1551 .39401 .15984 .40057 .1571 .39665 .15239 Mtetra
.67 .74 .903 r
.39665 .15239 .40057 .1571 .40714 .15445 .40323 .14975 Mtetra
.668 .74 .904 r
.40323 .14975 .40714 .15445 .41373 .15184 .40983 .14715 Mtetra
.666 .741 .906 r
.40983 .14715 .41373 .15184 .42033 .14926 .41644 .14456 Mtetra
.665 .741 .906 r
.41644 .14456 .42033 .14926 .42695 .1467 .42307 .14199 Mtetra
.665 .741 .907 r
.42307 .14199 .42695 .1467 .43358 .14414 .42971 .13942 Mtetra
.664 .741 .907 r
.42971 .13942 .43358 .14414 .44023 .14157 .43637 .13685 Mtetra
.43637 .13685 .44023 .14157 .4469 .13901 .44305 .13428 Mtetra
.44305 .13428 .4469 .13901 .45358 .13645 .44974 .1317 Mtetra
.44974 .1317 .45358 .13645 .46028 .13388 .45645 .12912 Mtetra
.45645 .12912 .46028 .13388 .46699 .1313 .46317 .12653 Mtetra
.46317 .12653 .46699 .1313 .47372 .12872 .46991 .12394 Mtetra
.46991 .12394 .47372 .12872 .48047 .12613 .47667 .12134 Mtetra
.47667 .12134 .48047 .12613 .48724 .12354 .48345 .11873 Mtetra
.48345 .11873 .48724 .12354 .49402 .12094 .49024 .11612 Mtetra
.49024 .11612 .49402 .12094 .50082 .11833 .49705 .1135 Mtetra
.49705 .1135 .50082 .11833 .50763 .11572 .50388 .11088 Mtetra
.50388 .11088 .50763 .11572 .51446 .1131 .51072 .10824 Mtetra
.51072 .10824 .51446 .1131 .52131 .11047 .51758 .10561 Mtetra
.51758 .10561 .52131 .11047 .52818 .10784 .52446 .10296 Mtetra
.52446 .10296 .52818 .10784 .53506 .1052 .53135 .10031 Mtetra
.53135 .10031 .53506 .1052 .54196 .10255 .53826 .09765 Mtetra
.53826 .09765 .54196 .10255 .54888 .0999 .54519 .09499 Mtetra
.54519 .09499 .54888 .0999 .55582 .09724 .55214 .09232 Mtetra
.55214 .09232 .55582 .09724 .56277 .09458 .5591 .08964 Mtetra
.5591 .08964 .56277 .09458 .56974 .0919 .56609 .08695 Mtetra
.56609 .08695 .56974 .0919 .57673 .08923 .57309 .08426 Mtetra
.57309 .08426 .57673 .08923 .58373 .08654 .5801 .08156 Mtetra
.5801 .08156 .58373 .08654 .59076 .08385 .58714 .07886 Mtetra
.58714 .07886 .59076 .08385 .5978 .08115 .59419 .07615 Mtetra
.59419 .07615 .5978 .08115 .60486 .07844 .60126 .07343 Mtetra
.60126 .07343 .60486 .07844 .61193 .07573 .60835 .0707 Mtetra
.60835 .0707 .61193 .07573 .61903 .07301 .61546 .06797 Mtetra
.61546 .06797 .61903 .07301 .62614 .07028 .62258 .06523 Mtetra
.62258 .06523 .62614 .07028 .63327 .06755 .62973 .06248 Mtetra
.62973 .06248 .63327 .06755 .64042 .06481 .63689 .05973 Mtetra
.63689 .05973 .64042 .06481 .64759 .06206 .64407 .05697 Mtetra
.64407 .05697 .64759 .06206 .65478 .0593 .65127 .0542 Mtetra
.65127 .0542 .65478 .0593 .66198 .05654 .65848 .05142 Mtetra
.65848 .05142 .66198 .05654 .6692 .05377 .66572 .04864 Mtetra
.66572 .04864 .6692 .05377 .67644 .051 .67297 .04585 Mtetra
.67297 .04585 .67644 .051 .6837 .04821 .68024 .04305 Mtetra
.68024 .04305 .6837 .04821 .69098 .04542 .68754 .04025 Mtetra
.68754 .04025 .69098 .04542 .69828 .04262 .69485 .03744 Mtetra
.69485 .03744 .69828 .04262 .70559 .03982 .70217 .03462 Mtetra
.70217 .03462 .70559 .03982 .71293 .03701 .70952 .0318 Mtetra
.663 .741 .908 r
.05946 .27598 .06386 .28008 .06965 .27787 .06525 .27375 Mtetra
.06525 .27375 .06965 .27787 .07545 .27565 .07106 .27153 Mtetra
.661 .741 .909 r
.07106 .27153 .07545 .27565 .08126 .27343 .07688 .26932 Mtetra
.658 .741 .911 r
.07688 .26932 .08126 .27343 .08708 .27124 .0827 .26716 Mtetra
.653 .742 .915 r
.0827 .26716 .08708 .27124 .09291 .26909 .08852 .26507 Mtetra
.642 .742 .922 r
.08852 .26507 .09291 .26909 .09874 .26704 .09434 .26313 Mtetra
.615 .742 .936 r
.09434 .26313 .09874 .26704 .10455 .26517 .10013 .26153 Mtetra
.545 .734 .963 r
.10013 .26153 .10455 .26517 .11033 .2637 .10584 .26059 Mtetra
.316 .667 .974 r
.10584 .26059 .11033 .2637 .11602 .26301 .11139 .26096 Mtetra
.409 0 0 r
.11139 .26096 .11602 .26301 .12152 .26388 .11662 .26392 Mtetra
.805 .349 .154 r
.11662 .26392 .12152 .26388 .12666 .26781 .12124 .27182 Mtetra
.846 .491 .38 r
.12124 .27182 .12666 .26781 .1311 .27749 .12477 .2886 Mtetra
.844 .53 .458 r
.12477 .2886 .1311 .27749 .13433 .29729 .1266 .3195 Mtetra
.831 .534 .488 r
.1266 .3195 .13433 .29729 .13577 .3324 .12647 .36712 Mtetra
.8 .51 .497 r
.12647 .36712 .13577 .3324 .13543 .38333 .1258 .42075 Mtetra
.715 .422 .478 r
.1258 .42075 .13543 .38333 .13533 .43412 .1284 .44928 Mtetra
.788 .84 .378 r
.1284 .44928 .13533 .43412 .13942 .45114 .13709 .42781 Mtetra
.863 .624 .575 r
.13709 .42781 .13942 .45114 .14938 .41818 .14971 .37243 Mtetra
.796 .551 .567 r
.14971 .37243 .14938 .41818 .16212 .36001 .16216 .31682 Mtetra
.763 .524 .571 r
.16216 .31682 .16212 .36001 .174 .30776 .17264 .27702 Mtetra
.747 .522 .589 r
.17264 .27702 .174 .30776 .18386 .27221 .18127 .25255 Mtetra
.74 .54 .624 r
.18127 .25255 .18386 .27221 .19208 .25079 .18872 .23823 Mtetra
.734 .577 .678 r
.18872 .23823 .19208 .25079 .19929 .23828 .19551 .2297 Mtetra
.725 .624 .745 r
.19551 .2297 .19929 .23828 .20596 .23074 .20196 .22427 Mtetra
.708 .669 .81 r
.20196 .22427 .20596 .23074 .21235 .22585 .20825 .22047 Mtetra
.685 .701 .859 r
.20825 .22047 .21235 .22585 .21861 .22236 .21445 .21755 Mtetra
.661 .719 .891 r
.21445 .21755 .21861 .22236 .22479 .21966 .22061 .21519 Mtetra
.633 .726 .915 r
.22061 .21519 .22479 .21966 .23094 .21751 .22674 .21327 Mtetra
.592 .725 .937 r
.22674 .21327 .23094 .21751 .23705 .21586 .23283 .21186 Mtetra
.518 .711 .959 r
.23283 .21186 .23705 .21586 .24312 .21485 .23888 .21115 Mtetra
.362 .658 .969 r
.23888 .21115 .24312 .21485 .24913 .21475 .24485 .21152 Mtetra
.007 .47 .869 r
.24485 .21152 .24913 .21475 .25504 .21605 .2507 .21351 Mtetra
.51 0 0 r
.2507 .21351 .25504 .21605 .26079 .21945 .25637 .21791 Mtetra
.782 .279 0 r
.25637 .21791 .26079 .21945 .26633 .22582 .26179 .22563 Mtetra
.855 .421 .188 r
.26179 .22563 .26633 .22582 .2716 .23604 .26693 .23743 Mtetra
.869 .474 .284 r
.26693 .23743 .2716 .23604 .2766 .25037 .27182 .25305 Mtetra
.863 .48 .315 r
.27182 .25305 .2766 .25037 .28148 .26736 .27669 .27015 Mtetra
.834 .429 .277 r
.27669 .27015 .28148 .26736 .28656 .28292 .28193 .28362 Mtetra
.586 .029 0 r
.28193 .28362 .28656 .28292 .29229 .29096 .28798 .28744 Mtetra
.872 .812 .788 r
.28798 .28744 .29229 .29096 .29896 .28698 .295 .2788 Mtetra
.878 .695 .651 r
.295 .2788 .29896 .28698 .30643 .27168 .30271 .26049 Mtetra
.864 .66 .625 r
.30271 .26049 .30643 .27168 .31427 .25039 .31063 .23852 Mtetra
.851 .649 .628 r
.31063 .23852 .31427 .25039 .32207 .2289 .31838 .21799 Mtetra
.839 .65 .647 r
.31838 .21799 .32207 .2289 .32959 .21066 .32582 .20127 Mtetra
.825 .661 .679 r
.32582 .20127 .32959 .21066 .33681 .19656 .33296 .18862 Mtetra
.808 .678 .72 r
.33296 .18862 .33681 .19656 .34377 .18611 .33986 .1793 Mtetra
.786 .696 .765 r
.33986 .1793 .34377 .18611 .35055 .1784 .34661 .17238 Mtetra
.761 .712 .806 r
.34661 .17238 .35055 .1784 .35722 .17259 .35327 .16708 Mtetra
.736 .724 .84 r
.35327 .16708 .35722 .17259 .36383 .16801 .35986 .16283 Mtetra
.714 .731 .864 r
.35986 .16283 .36383 .16801 .3704 .16422 .36643 .15924 Mtetra
.698 .735 .88 r
.36643 .15924 .3704 .16422 .37696 .16091 .373 .15606 Mtetra
.686 .738 .89 r
.373 .15606 .37696 .16091 .38352 .15791 .37956 .15313 Mtetra
.678 .739 .897 r
.37956 .15313 .38352 .15791 .39008 .1551 .38613 .15036 Mtetra
.672 .74 .901 r
.38613 .15036 .39008 .1551 .39665 .15239 .39271 .14767 Mtetra
.669 .74 .903 r
.39271 .14767 .39665 .15239 .40323 .14975 .3993 .14503 Mtetra
.667 .74 .905 r
.3993 .14503 .40323 .14975 .40983 .14715 .40591 .14243 Mtetra
.666 .741 .906 r
.40591 .14243 .40983 .14715 .41644 .14456 .41253 .13984 Mtetra
.665 .741 .906 r
.41253 .13984 .41644 .14456 .42307 .14199 .41917 .13726 Mtetra
.665 .741 .907 r
.41917 .13726 .42307 .14199 .42971 .13942 .42582 .13468 Mtetra
.664 .741 .907 r
.42582 .13468 .42971 .13942 .43637 .13685 .43249 .1321 Mtetra
.43249 .1321 .43637 .13685 .44305 .13428 .43917 .12952 Mtetra
.43917 .12952 .44305 .13428 .44974 .1317 .44588 .12693 Mtetra
.44588 .12693 .44974 .1317 .45645 .12912 .4526 .12434 Mtetra
.4526 .12434 .45645 .12912 .46317 .12653 .45933 .12174 Mtetra
.45933 .12174 .46317 .12653 .46991 .12394 .46609 .11913 Mtetra
.46609 .11913 .46991 .12394 .47667 .12134 .47285 .11652 Mtetra
.47285 .11652 .47667 .12134 .48345 .11873 .47964 .1139 Mtetra
.47964 .1139 .48345 .11873 .49024 .11612 .48644 .11128 Mtetra
.48644 .11128 .49024 .11612 .49705 .1135 .49326 .10865 Mtetra
.49326 .10865 .49705 .1135 .50388 .11088 .5001 .10601 Mtetra
.5001 .10601 .50388 .11088 .51072 .10824 .50696 .10337 Mtetra
.50696 .10337 .51072 .10824 .51758 .10561 .51383 .10072 Mtetra
.51383 .10072 .51758 .10561 .52446 .10296 .52072 .09806 Mtetra
.52072 .09806 .52446 .10296 .53135 .10031 .52762 .0954 Mtetra
.52762 .0954 .53135 .10031 .53826 .09765 .53455 .09273 Mtetra
.53455 .09273 .53826 .09765 .54519 .09499 .54149 .09005 Mtetra
.54149 .09005 .54519 .09499 .55214 .09232 .54845 .08737 Mtetra
.54845 .08737 .55214 .09232 .5591 .08964 .55542 .08468 Mtetra
.55542 .08468 .5591 .08964 .56609 .08695 .56242 .08198 Mtetra
.56242 .08198 .56609 .08695 .57309 .08426 .56943 .07927 Mtetra
.56943 .07927 .57309 .08426 .5801 .08156 .57646 .07656 Mtetra
.57646 .07656 .5801 .08156 .58714 .07886 .5835 .07385 Mtetra
.5835 .07385 .58714 .07886 .59419 .07615 .59057 .07112 Mtetra
.59057 .07112 .59419 .07615 .60126 .07343 .59765 .06839 Mtetra
.59765 .06839 .60126 .07343 .60835 .0707 .60475 .06565 Mtetra
.60475 .06565 .60835 .0707 .61546 .06797 .61187 .0629 Mtetra
.61187 .0629 .61546 .06797 .62258 .06523 .61901 .06015 Mtetra
.61901 .06015 .62258 .06523 .62973 .06248 .62616 .05739 Mtetra
.62616 .05739 .62973 .06248 .63689 .05973 .63334 .05462 Mtetra
.63334 .05462 .63689 .05973 .64407 .05697 .64053 .05185 Mtetra
.64053 .05185 .64407 .05697 .65127 .0542 .64774 .04907 Mtetra
.64774 .04907 .65127 .0542 .65848 .05142 .65497 .04628 Mtetra
.65497 .04628 .65848 .05142 .66572 .04864 .66222 .04349 Mtetra
.66222 .04349 .66572 .04864 .67297 .04585 .66948 .04068 Mtetra
.66948 .04068 .67297 .04585 .68024 .04305 .67677 .03787 Mtetra
.67677 .03787 .68024 .04305 .68754 .04025 .68407 .03506 Mtetra
.68407 .03506 .68754 .04025 .69485 .03744 .6914 .03223 Mtetra
.6914 .03223 .69485 .03744 .70217 .03462 .69874 .0294 Mtetra
.69874 .0294 .70217 .03462 .70952 .0318 .7061 .02657 Mtetra
.663 .741 .908 r
.05504 .27185 .05946 .27598 .06525 .27375 .06084 .26962 Mtetra
.662 .741 .909 r
.06084 .26962 .06525 .27375 .07106 .27153 .06665 .26741 Mtetra
.659 .741 .91 r
.06665 .26741 .07106 .27153 .07688 .26932 .07247 .26522 Mtetra
.655 .742 .913 r
.07247 .26522 .07688 .26932 .0827 .26716 .07829 .2631 Mtetra
.645 .742 .919 r
.07829 .2631 .0827 .26716 .08852 .26507 .08411 .26111 Mtetra
.624 .742 .932 r
.08411 .26111 .08852 .26507 .09434 .26313 .0899 .2594 Mtetra
.57 .738 .955 r
.0899 .2594 .09434 .26313 .10013 .26153 .09563 .25824 Mtetra
.404 .699 .981 r
.09563 .25824 .10013 .26153 .10584 .26059 .10122 .25819 Mtetra
0 .361 .733 r
.10122 .25819 .10584 .26059 .11139 .26096 .10654 .26033 Mtetra
.767 .272 .042 r
.10654 .26033 .11139 .26096 .11662 .26392 .11132 .26669 Mtetra
.843 .471 .346 r
.11132 .26669 .11662 .26392 .12124 .27182 .11513 .28079 Mtetra
.846 .525 .445 r
.11513 .28079 .12124 .27182 .12477 .2886 .11734 .30769 Mtetra
.835 .536 .483 r
.11734 .30769 .12477 .2886 .1266 .3195 .11752 .3514 Mtetra
.81 .519 .497 r
.11752 .3514 .1266 .3195 .12647 .36712 .11653 .40578 Mtetra
.748 .456 .488 r
.11653 .40578 .12647 .36712 .1258 .42075 .11778 .44402 Mtetra
.213 0 .237 r
.11778 .44402 .1258 .42075 .1284 .44928 .12496 .43524 Mtetra
.893 .661 .581 r
.12496 .43524 .1284 .44928 .13709 .42781 .13716 .38497 Mtetra
.808 .563 .567 r
.13716 .38497 .13709 .42781 .14971 .37243 .1501 .32697 Mtetra
.77 .528 .569 r
.1501 .32697 .14971 .37243 .16216 .31682 .16123 .28282 Mtetra
.75 .52 .583 r
.16123 .28282 .16216 .31682 .17264 .27702 .17034 .25494 Mtetra
.741 .534 .613 r
.17034 .25494 .17264 .27702 .18127 .25255 .17807 .23854 Mtetra
.736 .566 .662 r
.17807 .23854 .18127 .25255 .18872 .23823 .18501 .22886 Mtetra
.728 .612 .728 r
.18501 .22886 .18872 .23823 .19551 .2297 .19153 .22281 Mtetra
.713 .659 .794 r
.19153 .22281 .19551 .2297 .20196 .22427 .19785 .21866 Mtetra
.693 .695 .847 r
.19785 .21866 .20196 .22427 .20825 .22047 .20407 .21553 Mtetra
.671 .716 .882 r
.20407 .21553 .20825 .22047 .21445 .21755 .21025 .21297 Mtetra
.647 .726 .906 r
.21025 .21297 .21445 .21755 .22061 .21519 .21639 .21084 Mtetra
.617 .729 .926 r
.21639 .21084 .22061 .21519 .22674 .21327 .22251 .20912 Mtetra
.568 .723 .946 r
.22251 .20912 .22674 .21327 .23283 .21186 .22859 .20795 Mtetra
.472 .698 .967 r
.22859 .20795 .23283 .21186 .23888 .21115 .23461 .2076 Mtetra
.258 .611 .956 r
.23461 .2076 .23888 .21115 .24485 .21152 .24053 .20849 Mtetra
0 .331 .752 r
.24053 .20849 .24485 .21152 .2507 .21351 .24631 .21128 Mtetra
.65 .099 0 r
.24631 .21128 .2507 .21351 .25637 .21791 .25188 .21682 Mtetra
.822 .348 .072 r
.25188 .21682 .25637 .21791 .26179 .22563 .25718 .22601 Mtetra
.864 .448 .234 r
.25718 .22601 .26179 .22563 .26693 .23743 .26217 .23936 Mtetra
.869 .481 .302 r
.26217 .23936 .26693 .23743 .27182 .25305 .26698 .25597 Mtetra
.857 .47 .312 r
.26698 .25597 .27182 .25305 .27669 .27015 .27189 .27242 Mtetra
.805 .372 .219 r
.27189 .27242 .27669 .27015 .28193 .28362 .27737 .28291 Mtetra
.271 .765 .901 r
.27737 .28291 .28193 .28362 .28798 .28744 .28379 .28209 Mtetra
.883 .748 .708 r
.28379 .28209 .28798 .28744 .295 .2788 .29115 .26921 Mtetra
.872 .677 .636 r
.29115 .26921 .295 .2788 .30271 .26049 .29904 .24877 Mtetra
.859 .654 .624 r
.29904 .24877 .30271 .26049 .31063 .23852 .30697 .22686 Mtetra
.847 .648 .634 r
.30697 .22686 .31063 .23852 .31838 .21799 .31465 .2076 Mtetra
.834 .653 .658 r
.31465 .2076 .31838 .21799 .32582 .20127 .32201 .19244 Mtetra
.819 .667 .694 r
.32201 .19244 .32582 .20127 .33296 .18862 .32907 .18113 Mtetra
.801 .685 .737 r
.32907 .18113 .33296 .18862 .33986 .1793 .33593 .1728 Mtetra
.777 .702 .781 r
.33593 .1728 .33986 .1793 .34661 .17238 .34265 .16656 Mtetra
.752 .717 .82 r
.34265 .16656 .34661 .17238 .35327 .16708 .34928 .1617 Mtetra
.727 .727 .85 r
.34928 .1617 .35327 .16708 .35986 .16283 .35588 .15773 Mtetra
.707 .733 .871 r
.35588 .15773 .35986 .16283 .36643 .15924 .36245 .15431 Mtetra
.693 .736 .885 r
.36245 .15431 .36643 .15924 .373 .15606 .36901 .15123 Mtetra
.682 .738 .893 r
.36901 .15123 .373 .15606 .37956 .15313 .37558 .14835 Mtetra
.675 .739 .899 r
.37558 .14835 .37956 .15313 .38613 .15036 .38216 .14561 Mtetra
.671 .74 .902 r
.38216 .14561 .38613 .15036 .39271 .14767 .38875 .14293 Mtetra
.668 .74 .904 r
.38875 .14293 .39271 .14767 .3993 .14503 .39535 .1403 Mtetra
.667 .741 .905 r
.39535 .1403 .3993 .14503 .40591 .14243 .40197 .1377 Mtetra
.666 .741 .906 r
.40197 .1377 .40591 .14243 .41253 .13984 .4086 .1351 Mtetra
.665 .741 .907 r
.4086 .1351 .41253 .13984 .41917 .13726 .41525 .13251 Mtetra
.41525 .13251 .41917 .13726 .42582 .13468 .42191 .12993 Mtetra
.664 .741 .907 r
.42191 .12993 .42582 .13468 .43249 .1321 .42859 .12734 Mtetra
.42859 .12734 .43249 .1321 .43917 .12952 .43529 .12474 Mtetra
.43529 .12474 .43917 .12952 .44588 .12693 .442 .12214 Mtetra
.442 .12214 .44588 .12693 .4526 .12434 .44873 .11954 Mtetra
.44873 .11954 .4526 .12434 .45933 .12174 .45548 .11693 Mtetra
.45548 .11693 .45933 .12174 .46609 .11913 .46224 .11431 Mtetra
.46224 .11431 .46609 .11913 .47285 .11652 .46902 .11168 Mtetra
.46902 .11168 .47285 .11652 .47964 .1139 .47582 .10905 Mtetra
.47582 .10905 .47964 .1139 .48644 .11128 .48263 .10642 Mtetra
.48263 .10642 .48644 .11128 .49326 .10865 .48946 .10378 Mtetra
.48946 .10378 .49326 .10865 .5001 .10601 .49631 .10113 Mtetra
.49631 .10113 .5001 .10601 .50696 .10337 .50318 .09847 Mtetra
.50318 .09847 .50696 .10337 .51383 .10072 .51006 .09581 Mtetra
.51006 .09581 .51383 .10072 .52072 .09806 .51696 .09314 Mtetra
.51696 .09314 .52072 .09806 .52762 .0954 .52388 .09046 Mtetra
.52388 .09046 .52762 .0954 .53455 .09273 .53081 .08778 Mtetra
.53081 .08778 .53455 .09273 .54149 .09005 .53776 .08509 Mtetra
.53776 .08509 .54149 .09005 .54845 .08737 .54473 .08239 Mtetra
.54473 .08239 .54845 .08737 .55542 .08468 .55172 .07969 Mtetra
.55172 .07969 .55542 .08468 .56242 .08198 .55873 .07698 Mtetra
.55873 .07698 .56242 .08198 .56943 .07927 .56575 .07426 Mtetra
.56575 .07426 .56943 .07927 .57646 .07656 .57279 .07154 Mtetra
.57279 .07154 .57646 .07656 .5835 .07385 .57985 .06881 Mtetra
.57985 .06881 .5835 .07385 .59057 .07112 .58693 .06607 Mtetra
.58693 .06607 .59057 .07112 .59765 .06839 .59402 .06333 Mtetra
.59402 .06333 .59765 .06839 .60475 .06565 .60113 .06057 Mtetra
.60113 .06057 .60475 .06565 .61187 .0629 .60827 .05782 Mtetra
.60827 .05782 .61187 .0629 .61901 .06015 .61542 .05505 Mtetra
.61542 .05505 .61901 .06015 .62616 .05739 .62258 .05228 Mtetra
.62258 .05228 .62616 .05739 .63334 .05462 .62977 .0495 Mtetra
.62977 .0495 .63334 .05462 .64053 .05185 .63697 .04671 Mtetra
.63697 .04671 .64053 .05185 .64774 .04907 .6442 .04392 Mtetra
.6442 .04392 .64774 .04907 .65497 .04628 .65144 .04111 Mtetra
.65144 .04111 .65497 .04628 .66222 .04349 .6587 .03831 Mtetra
.6587 .03831 .66222 .04349 .66948 .04068 .66598 .03549 Mtetra
.66598 .03549 .66948 .04068 .67677 .03787 .67328 .03267 Mtetra
.67328 .03267 .67677 .03787 .68407 .03506 .6806 .02984 Mtetra
.6806 .02984 .68407 .03506 .6914 .03223 .68793 .027 Mtetra
.68793 .027 .6914 .03223 .69874 .0294 .69529 .02416 Mtetra
.663 .741 .908 r
.69529 .02416 .69874 .0294 .7061 .02657 .70266 .02132 Mtetra
.662 .741 .909 r
.05059 .26772 .05504 .27185 .06084 .26962 .0564 .26549 Mtetra
.66 .741 .91 r
.0564 .26549 .06084 .26962 .06665 .26741 .06221 .26329 Mtetra
.656 .741 .912 r
.06221 .26329 .06665 .26741 .07247 .26522 .06803 .26114 Mtetra
.648 .742 .918 r
.06803 .26114 .07247 .26522 .07829 .2631 .07385 .2591 Mtetra
.631 .742 .928 r
.07385 .2591 .07829 .2631 .08411 .26111 .07965 .25729 Mtetra
.589 .74 .948 r
.07965 .25729 .08411 .26111 .0899 .2594 .08539 .25595 Mtetra
.467 .718 .978 r
.08539 .25595 .0899 .2594 .09563 .25824 .09102 .25555 Mtetra
.016 .51 .871 r
.09102 .25555 .09563 .25824 .10122 .25819 .09641 .25699 Mtetra
.7 .162 0 r
.09641 .25699 .10122 .25819 .10654 .26033 .10134 .26203 Mtetra
.837 .443 .301 r
.10134 .26203 .10654 .26033 .11132 .26669 .10539 .27377 Mtetra
.847 .517 .429 r
.10539 .27377 .11132 .26669 .11513 .28079 .10798 .29697 Mtetra
.839 .536 .477 r
.10798 .29697 .11513 .28079 .11734 .30769 .10854 .33644 Mtetra
.818 .526 .495 r
.10854 .33644 .11734 .30769 .11752 .3514 .10745 .38982 Mtetra
.771 .48 .494 r
.10745 .38982 .11752 .3514 .11653 .40578 .10756 .43559 Mtetra
.548 .246 .407 r
.10756 .43559 .11653 .40578 .11778 .44402 .1131 .43992 Mtetra
.934 .72 .589 r
.1131 .43992 .11778 .44402 .12496 .43524 .12453 .39714 Mtetra
.823 .578 .569 r
.12453 .39714 .12496 .43524 .13716 .38497 .13781 .3381 Mtetra
.777 .533 .567 r
.13781 .3381 .13716 .38497 .1501 .32697 .14962 .28967 Mtetra
.754 .52 .578 r
.14962 .28967 .1501 .32697 .16123 .28282 .15927 .25805 Mtetra
.743 .528 .604 r
.15927 .25805 .16123 .28282 .17034 .25494 .16733 .23927 Mtetra
.737 .556 .648 r
.16733 .23927 .17034 .25494 .17807 .23854 .17445 .22825 Mtetra
.731 .6 .711 r
.17445 .22825 .17807 .23854 .18501 .22886 .18106 .22148 Mtetra
.718 .648 .778 r
.18106 .22148 .18501 .22886 .19153 .22281 .18743 .21694 Mtetra
.699 .687 .835 r
.18743 .21694 .19153 .22281 .19785 .21866 .19367 .21357 Mtetra
.678 .712 .874 r
.19367 .21357 .19785 .21866 .20407 .21553 .19986 .21084 Mtetra
.658 .725 .899 r
.19986 .21084 .20407 .21553 .21025 .21297 .20601 .20853 Mtetra
.634 .73 .917 r
.20601 .20853 .21025 .21297 .21639 .21084 .21214 .20658 Mtetra
.6 .729 .935 r
.21214 .20658 .21639 .21084 .22251 .20912 .21825 .20506 Mtetra
.539 .717 .955 r
.21825 .20506 .22251 .20912 .22859 .20795 .22431 .20416 Mtetra
.411 .678 .971 r
.22431 .20416 .22859 .20795 .23461 .2076 .23029 .20421 Mtetra
.119 .537 .917 r
.23029 .20421 .23461 .2076 .24053 .20849 .23617 .20572 Mtetra
.393 0 0 r
.23617 .20572 .24053 .20849 .24631 .21128 .24186 .20943 Mtetra
.741 .218 0 r
.24186 .20943 .24631 .21128 .25188 .21682 .24732 .21623 Mtetra
.845 .397 .149 r
.24732 .21623 .25188 .21682 .25718 .22601 .25247 .22698 Mtetra
.868 .466 .268 r
.25247 .22698 .25718 .22601 .26217 .23936 .25734 .24177 Mtetra
.866 .482 .313 r
.25734 .24177 .26217 .23936 .26698 .25597 .26209 .25888 Mtetra
.846 .451 .297 r
.26209 .25888 .26698 .25597 .27189 .27242 .26712 .27385 Mtetra
.73 .241 .078 r
.26712 .27385 .27189 .27242 .27737 .28291 .27291 .28055 Mtetra
.823 .879 .885 r
.27291 .28055 .27737 .28291 .28379 .28209 .27972 .27495 Mtetra
.88 .711 .667 r
.27972 .27495 .28379 .28209 .29115 .26921 .28737 .25851 Mtetra
.867 .665 .628 r
.28737 .25851 .29115 .26921 .29904 .24877 .29538 .23684 Mtetra
.854 .65 .626 r
.29538 .23684 .29904 .24877 .30697 .22686 .30328 .21557 Mtetra
.842 .649 .641 r
.30328 .21557 .30697 .22686 .31465 .2076 .31088 .19778 Mtetra
.829 .658 .67 r
.31088 .19778 .31465 .2076 .32201 .19244 .31815 .18413 Mtetra
.813 .673 .709 r
.31815 .18413 .32201 .19244 .32907 .18113 .32515 .17404 Mtetra
.792 .692 .753 r
.32515 .17404 .32907 .18113 .33593 .1728 .33196 .16658 Mtetra
.768 .708 .796 r
.33196 .16658 .33593 .1728 .34265 .16656 .33865 .16092 Mtetra
.742 .721 .832 r
.33865 .16092 .34265 .16656 .34928 .1617 .34528 .15643 Mtetra
.719 .73 .859 r
.34528 .15643 .34928 .1617 .35588 .15773 .35187 .15268 Mtetra
.701 .735 .877 r
.35187 .15268 .35588 .15773 .36245 .15431 .35844 .1494 Mtetra
.688 .737 .888 r
.35844 .1494 .36245 .15431 .36901 .15123 .36501 .1464 Mtetra
.679 .739 .896 r
.36501 .1464 .36901 .15123 .37558 .14835 .37159 .14357 Mtetra
.674 .74 .9 r
.37159 .14357 .37558 .14835 .38216 .14561 .37817 .14085 Mtetra
.67 .74 .903 r
.37817 .14085 .38216 .14561 .38875 .14293 .38477 .13818 Mtetra
.668 .74 .905 r
.38477 .13818 .38875 .14293 .39535 .1403 .39138 .13555 Mtetra
.666 .741 .906 r
.39138 .13555 .39535 .1403 .40197 .1377 .39801 .13294 Mtetra
.665 .741 .906 r
.39801 .13294 .40197 .1377 .4086 .1351 .40465 .13034 Mtetra
.665 .741 .907 r
.40465 .13034 .4086 .1351 .41525 .13251 .41131 .12775 Mtetra
.664 .741 .907 r
.41131 .12775 .41525 .13251 .42191 .12993 .41798 .12515 Mtetra
.41798 .12515 .42191 .12993 .42859 .12734 .42467 .12255 Mtetra
.42467 .12255 .42859 .12734 .43529 .12474 .43138 .11994 Mtetra
.43138 .11994 .43529 .12474 .442 .12214 .4381 .11733 Mtetra
.4381 .11733 .442 .12214 .44873 .11954 .44485 .11471 Mtetra
.44485 .11471 .44873 .11954 .45548 .11693 .4516 .11209 Mtetra
.4516 .11209 .45548 .11693 .46224 .11431 .45838 .10946 Mtetra
.45838 .10946 .46224 .11431 .46902 .11168 .46517 .10682 Mtetra
.46517 .10682 .46902 .11168 .47582 .10905 .47198 .10418 Mtetra
.47198 .10418 .47582 .10905 .48263 .10642 .4788 .10153 Mtetra
.4788 .10153 .48263 .10642 .48946 .10378 .48564 .09888 Mtetra
.48564 .09888 .48946 .10378 .49631 .10113 .4925 .09622 Mtetra
.4925 .09622 .49631 .10113 .50318 .09847 .49938 .09355 Mtetra
.49938 .09355 .50318 .09847 .51006 .09581 .50627 .09087 Mtetra
.50627 .09087 .51006 .09581 .51696 .09314 .51318 .08819 Mtetra
.51318 .08819 .51696 .09314 .52388 .09046 .52011 .0855 Mtetra
.52011 .0855 .52388 .09046 .53081 .08778 .52706 .08281 Mtetra
.52706 .08281 .53081 .08778 .53776 .08509 .53402 .08011 Mtetra
.53402 .08011 .53776 .08509 .54473 .08239 .541 .0774 Mtetra
.541 .0774 .54473 .08239 .55172 .07969 .548 .07468 Mtetra
.548 .07468 .55172 .07969 .55873 .07698 .55502 .07196 Mtetra
.55502 .07196 .55873 .07698 .56575 .07426 .56206 .06923 Mtetra
.56206 .06923 .56575 .07426 .57279 .07154 .56911 .06649 Mtetra
.56911 .06649 .57279 .07154 .57985 .06881 .57618 .06375 Mtetra
.57618 .06375 .57985 .06881 .58693 .06607 .58327 .061 Mtetra
.58327 .061 .58693 .06607 .59402 .06333 .59038 .05824 Mtetra
.59038 .05824 .59402 .06333 .60113 .06057 .5975 .05548 Mtetra
.5975 .05548 .60113 .06057 .60827 .05782 .60464 .0527 Mtetra
.60464 .0527 .60827 .05782 .61542 .05505 .61181 .04993 Mtetra
.61181 .04993 .61542 .05505 .62258 .05228 .61899 .04714 Mtetra
.61899 .04714 .62258 .05228 .62977 .0495 .62619 .04435 Mtetra
.62619 .04435 .62977 .0495 .63697 .04671 .6334 .04155 Mtetra
.6334 .04155 .63697 .04671 .6442 .04392 .64064 .03874 Mtetra
.64064 .03874 .6442 .04392 .65144 .04111 .64789 .03592 Mtetra
.64789 .03592 .65144 .04111 .6587 .03831 .65517 .0331 Mtetra
.65517 .0331 .6587 .03831 .66598 .03549 .66246 .03027 Mtetra
.66246 .03027 .66598 .03549 .67328 .03267 .66977 .02744 Mtetra
.66977 .02744 .67328 .03267 .6806 .02984 .6771 .02459 Mtetra
.6771 .02459 .6806 .02984 .68793 .027 .68445 .02174 Mtetra
.663 .741 .908 r
.68445 .02174 .68793 .027 .69529 .02416 .69182 .01889 Mtetra
.69182 .01889 .69529 .02416 .70266 .02132 .69921 .01604 Mtetra
.661 .741 .909 r
.04613 .26357 .05059 .26772 .0564 .26549 .05194 .26135 Mtetra
.657 .741 .912 r
.05194 .26135 .0564 .26549 .06221 .26329 .05776 .25918 Mtetra
.651 .742 .916 r
.05776 .25918 .06221 .26329 .06803 .26114 .06357 .2571 Mtetra
.637 .742 .924 r
.06357 .2571 .06803 .26114 .07385 .2591 .06937 .25521 Mtetra
.603 .741 .942 r
.06937 .25521 .07385 .2591 .07965 .25729 .07513 .25372 Mtetra
.512 .729 .971 r
.07513 .25372 .07965 .25729 .08539 .25595 .08079 .25301 Mtetra
.187 .608 .944 r
.08079 .25301 .08539 .25595 .09102 .25555 .08624 .25387 Mtetra
.587 .013 0 r
.08624 .25387 .09102 .25555 .09641 .25699 .09129 .25778 Mtetra
.826 .405 .24 r
.09129 .25778 .09641 .25699 .10134 .26203 .09557 .26746 Mtetra
.847 .506 .408 r
.09557 .26746 .10134 .26203 .10539 .27377 .09852 .28728 Mtetra
.841 .534 .469 r
.09852 .28728 .10539 .27377 .10798 .29697 .09949 .32244 Mtetra
.825 .531 .493 r
.09949 .32244 .10798 .29697 .10854 .33644 .0985 .37347 Mtetra
.788 .497 .496 r
.0985 .37347 .10854 .33644 .10745 .38982 .09773 .42438 Mtetra
.66 .362 .456 r
.09773 .42438 .10745 .38982 .10756 .43559 .10157 .44143 Mtetra
.988 .823 .591 r
.10157 .44143 .10756 .43559 .1131 .43992 .1119 .40835 Mtetra
.84 .597 .572 r
.1119 .40835 .1131 .43992 .12453 .39714 .12531 .35002 Mtetra
.786 .541 .567 r
.12531 .35002 .12453 .39714 .13781 .3381 .13779 .29762 Mtetra
.758 .521 .574 r
.13779 .29762 .13781 .3381 .14962 .28967 .14805 .26197 Mtetra
.745 .524 .595 r
.14805 .26197 .14962 .28967 .15927 .25805 .1565 .24047 Mtetra
.738 .547 .635 r
.1565 .24047 .15927 .25805 .16733 .23927 .16383 .22789 Mtetra
.733 .588 .694 r
.16383 .22789 .16733 .23927 .17445 .22825 .17055 .22028 Mtetra
.722 .637 .762 r
.17055 .22028 .17445 .22825 .18106 .22148 .17697 .2153 Mtetra
.705 .679 .822 r
.17697 .2153 .18106 .22148 .18743 .21694 .18324 .21167 Mtetra
.685 .707 .865 r
.18324 .21167 .18743 .21694 .19367 .21357 .18944 .20878 Mtetra
.666 .723 .891 r
.18944 .20878 .19367 .21357 .19986 .21084 .1956 .20631 Mtetra
.646 .73 .91 r
.1956 .20631 .19986 .21084 .20601 .20853 .20175 .20418 Mtetra
.621 .731 .926 r
.20175 .20418 .20601 .20853 .21214 .20658 .20787 .20239 Mtetra
.58 .727 .943 r
.20787 .20239 .21214 .20658 .21825 .20506 .21396 .20108 Mtetra
.501 .708 .963 r
.21396 .20108 .21825 .20506 .22431 .20416 .21999 .20048 Mtetra
.327 .644 .967 r
.21999 .20048 .22431 .20416 .23029 .20421 .22594 .20101 Mtetra
0 .426 .835 r
.22594 .20101 .23029 .20421 .23617 .20572 .23174 .20324 Mtetra
.564 .002 0 r
.23174 .20324 .23617 .20572 .24186 .20943 .23734 .208 Mtetra
.798 .305 .008 r
.23734 .208 .24186 .20943 .24732 .21623 .24267 .2162 Mtetra
.858 .431 .205 r
.24267 .2162 .24732 .21623 .25247 .22698 .24767 .22852 Mtetra
.869 .477 .291 r
.24767 .22852 .25247 .22698 .25734 .24177 .25243 .24452 Mtetra
.862 .477 .315 r
.25243 .24452 .25734 .24177 .26209 .25888 .25719 .2615 Mtetra
.827 .414 .262 r
.25719 .2615 .26209 .25888 .26712 .27385 .26242 .27408 Mtetra
.416 0 0 r
.26242 .27408 .26712 .27385 .27291 .28055 .26857 .27637 Mtetra
.878 .786 .754 r
.26857 .27637 .27291 .28055 .27972 .27495 .27577 .26622 Mtetra
.876 .688 .645 r
.27577 .26622 .27972 .27495 .28737 .25851 .28365 .24705 Mtetra
.862 .657 .624 r
.28365 .24705 .28737 .25851 .29538 .23684 .29171 .22497 Mtetra
.85 .648 .63 r
.29171 .22497 .29538 .23684 .30328 .21557 .29956 .20477 Mtetra
.837 .651 .651 r
.29956 .20477 .30328 .21557 .31088 .19778 .30707 .18853 Mtetra
.824 .663 .684 r
.30707 .18853 .31088 .19778 .31815 .18413 .31425 .1763 Mtetra
.806 .68 .725 r
.31425 .1763 .31815 .18413 .32515 .17404 .32119 .16729 Mtetra
.783 .698 .77 r
.32119 .16729 .32515 .17404 .33196 .16658 .32796 .16058 Mtetra
.758 .714 .811 r
.32796 .16058 .33196 .16658 .33865 .16092 .33464 .15541 Mtetra
.733 .725 .843 r
.33464 .15541 .33865 .16092 .34528 .15643 .34125 .15123 Mtetra
.712 .732 .866 r
.34125 .15123 .34528 .15643 .35187 .15268 .34784 .14767 Mtetra
.696 .736 .882 r
.34784 .14767 .35187 .15268 .35844 .1494 .35442 .1445 Mtetra
.684 .738 .891 r
.35442 .1445 .35844 .1494 .36501 .1464 .36099 .14157 Mtetra
.677 .739 .898 r
.36099 .14157 .36501 .1464 .37159 .14357 .36758 .13878 Mtetra
.672 .74 .901 r
.36758 .13878 .37159 .14357 .37817 .14085 .37417 .13607 Mtetra
.669 .74 .904 r
.37417 .13607 .37817 .14085 .38477 .13818 .38078 .13342 Mtetra
.667 .74 .905 r
.38078 .13342 .38477 .13818 .39138 .13555 .3874 .13079 Mtetra
.666 .741 .906 r
.3874 .13079 .39138 .13555 .39801 .13294 .39403 .12817 Mtetra
.665 .741 .906 r
.39403 .12817 .39801 .13294 .40465 .13034 .40069 .12556 Mtetra
.665 .741 .907 r
.40069 .12556 .40465 .13034 .41131 .12775 .40735 .12296 Mtetra
.664 .741 .907 r
.40735 .12296 .41131 .12775 .41798 .12515 .41404 .12035 Mtetra
.41404 .12035 .41798 .12515 .42467 .12255 .42074 .11773 Mtetra
.42074 .11773 .42467 .12255 .43138 .11994 .42746 .11512 Mtetra
.42746 .11512 .43138 .11994 .4381 .11733 .43419 .11249 Mtetra
.43419 .11249 .4381 .11733 .44485 .11471 .44094 .10987 Mtetra
.44094 .10987 .44485 .11471 .4516 .11209 .44771 .10723 Mtetra
.44771 .10723 .4516 .11209 .45838 .10946 .4545 .10459 Mtetra
.4545 .10459 .45838 .10946 .46517 .10682 .4613 .10194 Mtetra
.4613 .10194 .46517 .10682 .47198 .10418 .46812 .09929 Mtetra
.46812 .09929 .47198 .10418 .4788 .10153 .47495 .09663 Mtetra
.47495 .09663 .4788 .10153 .48564 .09888 .48181 .09396 Mtetra
.48181 .09396 .48564 .09888 .4925 .09622 .48868 .09129 Mtetra
.48868 .09129 .4925 .09622 .49938 .09355 .49556 .08861 Mtetra
.49556 .08861 .49938 .09355 .50627 .09087 .50247 .08592 Mtetra
.50247 .08592 .50627 .09087 .51318 .08819 .50939 .08322 Mtetra
.50939 .08322 .51318 .08819 .52011 .0855 .51633 .08052 Mtetra
.51633 .08052 .52011 .0855 .52706 .08281 .52329 .07782 Mtetra
.52329 .07782 .52706 .08281 .53402 .08011 .53027 .0751 Mtetra
.53027 .0751 .53402 .08011 .541 .0774 .53726 .07238 Mtetra
.53726 .07238 .541 .0774 .548 .07468 .54427 .06965 Mtetra
.54427 .06965 .548 .07468 .55502 .07196 .5513 .06691 Mtetra
.5513 .06691 .55502 .07196 .56206 .06923 .55834 .06417 Mtetra
.55834 .06417 .56206 .06923 .56911 .06649 .56541 .06142 Mtetra
.56541 .06142 .56911 .06649 .57618 .06375 .57249 .05867 Mtetra
.57249 .05867 .57618 .06375 .58327 .061 .57959 .0559 Mtetra
.57959 .0559 .58327 .061 .59038 .05824 .58671 .05313 Mtetra
.58671 .05313 .59038 .05824 .5975 .05548 .59385 .05035 Mtetra
.59385 .05035 .5975 .05548 .60464 .0527 .60101 .04757 Mtetra
.60101 .04757 .60464 .0527 .61181 .04993 .60818 .04478 Mtetra
.60818 .04478 .61181 .04993 .61899 .04714 .61537 .04198 Mtetra
.61537 .04198 .61899 .04714 .62619 .04435 .62258 .03917 Mtetra
.62258 .03917 .62619 .04435 .6334 .04155 .62981 .03636 Mtetra
.62981 .03636 .6334 .04155 .64064 .03874 .63706 .03354 Mtetra
.63706 .03354 .64064 .03874 .64789 .03592 .64433 .03071 Mtetra
.64433 .03071 .64789 .03592 .65517 .0331 .65162 .02787 Mtetra
.65162 .02787 .65517 .0331 .66246 .03027 .65892 .02503 Mtetra
.65892 .02503 .66246 .03027 .66977 .02744 .66624 .02218 Mtetra
.66624 .02218 .66977 .02744 .6771 .02459 .67359 .01932 Mtetra
.67359 .01932 .6771 .02459 .68445 .02174 .68095 .01647 Mtetra
.663 .741 .908 r
.68095 .01647 .68445 .02174 .69182 .01889 .68833 .01361 Mtetra
.68833 .01361 .69182 .01889 .69921 .01604 .69574 .01075 Mtetra
.659 .741 .911 r
.04165 .25942 .04613 .26357 .05194 .26135 .04746 .25723 Mtetra
.653 .742 .915 r
.04746 .25723 .05194 .26135 .05776 .25918 .05327 .25511 Mtetra
.641 .742 .922 r
.05327 .25511 .05776 .25918 .06357 .2571 .05907 .25316 Mtetra
.615 .742 .936 r
.05907 .25316 .06357 .2571 .06937 .25521 .06484 .25153 Mtetra
.545 .735 .963 r
.06484 .25153 .06937 .25521 .07513 .25372 .07052 .25057 Mtetra
.313 .666 .974 r
.07052 .25057 .07513 .25372 .08079 .25301 .07603 .25092 Mtetra
.415 0 0 r
.07603 .25092 .08079 .25301 .08624 .25387 .08119 .25387 Mtetra
.806 .351 .159 r
.08119 .25387 .08624 .25387 .09129 .25778 .08568 .26176 Mtetra
.846 .492 .382 r
.08568 .26176 .09129 .25778 .09557 .26746 .08896 .27855 Mtetra
.844 .531 .459 r
.08896 .27855 .09557 .26746 .09852 .28728 .09037 .30949 Mtetra
.83 .535 .489 r
.09037 .30949 .09852 .28728 .09949 .32244 .08961 .35721 Mtetra
.8 .51 .497 r
.08961 .35721 .09949 .32244 .0985 .37347 .08824 .41095 Mtetra
.715 .42 .477 r
.08824 .41095 .0985 .37347 .09773 .42438 .09045 .43954 Mtetra
.813 .858 .407 r
.09045 .43954 .09773 .42438 .10157 .44143 .09937 .41799 Mtetra
.862 .624 .576 r
.09937 .41799 .10157 .44143 .1119 .40835 .11263 .36245 Mtetra
.796 .551 .567 r
.11263 .36245 .1119 .40835 .12531 .35002 .12573 .30669 Mtetra
.763 .524 .571 r
.12573 .30669 .12531 .35002 .13779 .29762 .13665 .26678 Mtetra
.747 .522 .588 r
.13665 .26678 .13779 .29762 .14805 .26197 .14555 .24223 Mtetra
.74 .54 .623 r
.14555 .24223 .14805 .26197 .1565 .24047 .15314 .22784 Mtetra
.735 .577 .677 r
.15314 .22784 .1565 .24047 .16383 .22789 .16 .21925 Mtetra
.726 .625 .745 r
.16 .21925 .16383 .22789 .17055 .22028 .16648 .21375 Mtetra
.71 .67 .808 r
.16648 .21375 .17055 .22028 .17697 .2153 .17278 .20984 Mtetra
.691 .701 .855 r
.17278 .20984 .17697 .2153 .18324 .21167 .17899 .20677 Mtetra
.673 .72 .885 r
.17899 .20677 .18324 .21167 .18944 .20878 .18517 .20416 Mtetra
.656 .729 .903 r
.18517 .20416 .18944 .20878 .1956 .20631 .19132 .20188 Mtetra
.636 .733 .918 r
.19132 .20188 .1956 .20631 .20175 .20418 .19745 .19989 Mtetra
.607 .731 .933 r
.19745 .19989 .20175 .20418 .20787 .20239 .20356 .19826 Mtetra
.556 .722 .951 r
.20356 .19826 .20787 .20239 .21396 .20108 .20963 .19718 Mtetra
.451 .693 .969 r
.20963 .19718 .21396 .20108 .21999 .20048 .21564 .19695 Mtetra
.213 .589 .946 r
.21564 .19695 .21999 .20048 .22594 .20101 .22153 .19803 Mtetra
0 .276 .699 r
.22153 .19803 .22594 .20101 .23174 .20324 .22726 .2011 Mtetra
.686 .144 0 r
.22726 .2011 .23174 .20324 .23734 .208 .23275 .20704 Mtetra
.831 .367 .101 r
.23275 .20704 .23734 .208 .24267 .2162 .23793 .21674 Mtetra
.866 .455 .247 r
.23793 .21674 .24267 .2162 .24767 .22852 .24279 .23059 Mtetra
.868 .482 .307 r
.24279 .23059 .24767 .22852 .25243 .24452 .24746 .24743 Mtetra
.854 .465 .308 r
.24746 .24743 .25243 .24452 .25719 .2615 .2523 .2635 Mtetra
.788 .34 .184 r
.2523 .2635 .25719 .2615 .26242 .27408 .25781 .2728 Mtetra
.591 .903 .984 r
.25781 .2728 .26242 .27408 .26857 .27637 .26437 .27037 Mtetra
.882 .733 .691 r
.26437 .27037 .26857 .27637 .27577 .26622 .27191 .25617 Mtetra
.87 .673 .633 r
.27191 .25617 .27577 .26622 .28365 .24705 .27997 .23517 Mtetra
.857 .652 .624 r
.27997 .23517 .28365 .24705 .29171 .22497 .28803 .21336 Mtetra
.845 .648 .636 r
.28803 .21336 .29171 .22497 .29956 .20477 .2958 .19452 Mtetra
.833 .655 .662 r
.2958 .19452 .29956 .20477 .30707 .18853 .30321 .17983 Mtetra
.817 .669 .699 r
.30321 .17983 .30707 .18853 .31425 .1763 .31031 .1689 Mtetra
.798 .687 .742 r
.31031 .1689 .31425 .1763 .32119 .16729 .31719 .16084 Mtetra
.774 .705 .786 r
.31719 .16084 .32119 .16729 .32796 .16058 .32393 .15478 Mtetra
.748 .719 .824 r
.32393 .15478 .32796 .16058 .33464 .15541 .33059 .15002 Mtetra
.725 .728 .853 r
.33059 .15002 .33464 .15541 .34125 .15123 .3372 .1461 Mtetra
.705 .734 .873 r
.3372 .1461 .34125 .15123 .34784 .14767 .34379 .1427 Mtetra
.691 .737 .886 r
.34379 .1427 .34784 .14767 .35442 .1445 .35037 .13962 Mtetra
.681 .739 .894 r
.35037 .13962 .35442 .1445 .36099 .14157 .35695 .13674 Mtetra
.675 .739 .899 r
.35695 .13674 .36099 .14157 .36758 .13878 .36354 .13398 Mtetra
.671 .74 .902 r
.36354 .13398 .36758 .13878 .37417 .13607 .37015 .13129 Mtetra
.668 .74 .904 r
.37015 .13129 .37417 .13607 .38078 .13342 .37676 .12863 Mtetra
.666 .741 .905 r
.37676 .12863 .38078 .13342 .3874 .13079 .38339 .126 Mtetra
.665 .741 .906 r
.38339 .126 .3874 .13079 .39403 .12817 .39004 .12338 Mtetra
.665 .741 .907 r
.39004 .12338 .39403 .12817 .40069 .12556 .3967 .12076 Mtetra
.664 .741 .907 r
.3967 .12076 .40069 .12556 .40735 .12296 .40338 .11814 Mtetra
.40338 .11814 .40735 .12296 .41404 .12035 .41008 .11553 Mtetra
.41008 .11553 .41404 .12035 .42074 .11773 .41679 .1129 Mtetra
.41679 .1129 .42074 .11773 .42746 .11512 .42352 .11027 Mtetra
.42352 .11027 .42746 .11512 .43419 .11249 .43026 .10764 Mtetra
.43026 .10764 .43419 .11249 .44094 .10987 .43702 .105 Mtetra
.43702 .105 .44094 .10987 .44771 .10723 .4438 .10235 Mtetra
.4438 .10235 .44771 .10723 .4545 .10459 .4506 .0997 Mtetra
.4506 .0997 .4545 .10459 .4613 .10194 .45741 .09704 Mtetra
.45741 .09704 .4613 .10194 .46812 .09929 .46424 .09437 Mtetra
.46424 .09437 .46812 .09929 .47495 .09663 .47109 .0917 Mtetra
.47109 .0917 .47495 .09663 .48181 .09396 .47795 .08902 Mtetra
.47795 .08902 .48181 .09396 .48868 .09129 .48483 .08633 Mtetra
.48483 .08633 .48868 .09129 .49556 .08861 .49173 .08364 Mtetra
.49173 .08364 .49556 .08861 .50247 .08592 .49865 .08094 Mtetra
.49865 .08094 .50247 .08592 .50939 .08322 .50558 .07823 Mtetra
.50558 .07823 .50939 .08322 .51633 .08052 .51253 .07552 Mtetra
.51253 .07552 .51633 .08052 .52329 .07782 .5195 .0728 Mtetra
.5195 .0728 .52329 .07782 .53027 .0751 .52649 .07007 Mtetra
.52649 .07007 .53027 .0751 .53726 .07238 .53349 .06734 Mtetra
.53349 .06734 .53726 .07238 .54427 .06965 .54052 .06459 Mtetra
.54052 .06459 .54427 .06965 .5513 .06691 .54756 .06185 Mtetra
.54756 .06185 .5513 .06691 .55834 .06417 .55462 .05909 Mtetra
.55462 .05909 .55834 .06417 .56541 .06142 .56169 .05633 Mtetra
.56169 .05633 .56541 .06142 .57249 .05867 .56879 .05356 Mtetra
.56879 .05356 .57249 .05867 .57959 .0559 .5759 .05078 Mtetra
.5759 .05078 .57959 .0559 .58671 .05313 .58303 .048 Mtetra
.58303 .048 .58671 .05313 .59385 .05035 .59018 .04521 Mtetra
.59018 .04521 .59385 .05035 .60101 .04757 .59735 .04241 Mtetra
.59735 .04241 .60101 .04757 .60818 .04478 .60454 .0396 Mtetra
.60454 .0396 .60818 .04478 .61537 .04198 .61174 .03679 Mtetra
.61174 .03679 .61537 .04198 .62258 .03917 .61896 .03397 Mtetra
.61896 .03397 .62258 .03917 .62981 .03636 .62621 .03114 Mtetra
.62621 .03114 .62981 .03636 .63706 .03354 .63347 .02831 Mtetra
.63347 .02831 .63706 .03354 .64433 .03071 .64075 .02547 Mtetra
.64075 .02547 .64433 .03071 .65162 .02787 .64805 .02262 Mtetra
.64805 .02262 .65162 .02787 .65892 .02503 .65537 .01976 Mtetra
.65537 .01976 .65892 .02503 .66624 .02218 .6627 .0169 Mtetra
.6627 .0169 .66624 .02218 .67359 .01932 .67006 .01403 Mtetra
.663 .741 .908 r
.67006 .01403 .67359 .01932 .68095 .01647 .67744 .01116 Mtetra
.67744 .01116 .68095 .01647 .68833 .01361 .68483 .0083 Mtetra
.662 .741 .909 r
.68483 .0083 .68833 .01361 .69574 .01075 .69225 .00545 Mtetra
.655 .741 .913 r
.03714 .25527 .04165 .25942 .04746 .25723 .04295 .25313 Mtetra
.645 .742 .92 r
.04295 .25313 .04746 .25723 .05327 .25511 .04875 .25112 Mtetra
.624 .742 .932 r
.04875 .25112 .05327 .25511 .05907 .25316 .05452 .24938 Mtetra
.57 .738 .955 r
.05452 .24938 .05907 .25316 .06484 .25153 .06023 .2482 Mtetra
.403 .699 .981 r
.06023 .2482 .06484 .25153 .07052 .25057 .06579 .24813 Mtetra
0 .357 .728 r
.06579 .24813 .07052 .25057 .07603 .25092 .07104 .25026 Mtetra
.769 .275 .047 r
.07104 .25026 .07603 .25092 .08119 .25387 .0757 .25661 Mtetra
.843 .472 .348 r
.0757 .25661 .08119 .25387 .08568 .26176 .0793 .27071 Mtetra
.846 .525 .446 r
.0793 .27071 .08568 .26176 .08896 .27855 .08114 .29765 Mtetra
.835 .536 .484 r
.08114 .29765 .08896 .27855 .09037 .30949 .08074 .34143 Mtetra
.81 .52 .497 r
.08074 .34143 .09037 .30949 .08961 .35721 .07904 .39592 Mtetra
.748 .456 .488 r
.07904 .39592 .08961 .35721 .08824 .41095 .07977 .43425 Mtetra
.195 0 .22 r
.07977 .43425 .08824 .41095 .09045 .43954 .08702 .42542 Mtetra
.891 .661 .583 r
.08702 .42542 .09045 .43954 .09937 .41799 .0998 .375 Mtetra
.808 .563 .567 r
.0998 .375 .09937 .41799 .11263 .36245 .11343 .31684 Mtetra
.77 .528 .569 r
.11343 .31684 .11263 .36245 .12573 .30669 .12506 .27258 Mtetra
.75 .52 .583 r
.12506 .27258 .12573 .30669 .13665 .26678 .13448 .24462 Mtetra
.741 .533 .613 r
.13448 .24462 .13665 .26678 .14555 .24223 .14237 .22815 Mtetra
.736 .566 .662 r
.14237 .22815 .14555 .24223 .15314 .22784 .14939 .21841 Mtetra
.729 .612 .727 r
.14939 .21841 .15314 .22784 .16 .21925 .15595 .2123 Mtetra
.715 .659 .793 r
.15595 .2123 .16 .21925 .16648 .21375 .16229 .20806 Mtetra
.697 .695 .845 r
.16229 .20806 .16648 .21375 .17278 .20984 .16852 .20481 Mtetra
.679 .717 .878 r
.16852 .20481 .17278 .20984 .17899 .20677 .1747 .20207 Mtetra
.663 .728 .898 r
.1747 .20207 .17899 .20677 .18517 .20416 .18086 .19966 Mtetra
.647 .733 .912 r
.18086 .19966 .18517 .20416 .19132 .20188 .187 .19751 Mtetra
.625 .733 .925 r
.187 .19751 .19132 .20188 .19745 .19989 .19313 .19565 Mtetra
.591 .729 .94 r
.19313 .19565 .19745 .19989 .20356 .19826 .19923 .19421 Mtetra
.525 .715 .959 r
.19923 .19421 .20356 .19826 .20963 .19718 .20528 .1934 Mtetra
.384 .668 .971 r
.20528 .1934 .20963 .19718 .21564 .19695 .21124 .19359 Mtetra
.061 .504 .894 r
.21124 .19359 .21564 .19695 .22153 .19803 .21707 .19532 Mtetra
.457 0 0 r
.21707 .19532 .22153 .19803 .22726 .2011 .22271 .19934 Mtetra
.764 .251 0 r
.22271 .19934 .22726 .2011 .23275 .20704 .22807 .20659 Mtetra
.85 .41 .17 r
.22807 .20659 .23275 .20704 .23793 .21674 .2331 .21786 Mtetra
.869 .47 .277 r
.2331 .21786 .23793 .21674 .24279 .23059 .23782 .2331 Mtetra
.865 .481 .315 r
.23782 .2331 .24279 .23059 .24746 .24743 .24246 .25025 Mtetra
.841 .441 .287 r
.24246 .25025 .24746 .24743 .2523 .2635 .24745 .26453 Mtetra
.675 .153 0 r
.24745 .26453 .2523 .2635 .25781 .2728 .25331 .26981 Mtetra
.856 .842 .83 r
.25331 .26981 .25781 .2728 .26437 .27037 .26029 .26263 Mtetra
.879 .702 .658 r
.26029 .26263 .26437 .27037 .27191 .25617 .26814 .24512 Mtetra
.865 .662 .626 r
.26814 .24512 .27191 .25617 .27997 .23517 .27629 .22317 Mtetra
.853 .649 .627 r
.27629 .22317 .27997 .23517 .28803 .21336 .28431 .20217 Mtetra
.841 .65 .644 r
.28431 .20217 .28803 .21336 .2958 .19452 .29198 .18484 Mtetra
.827 .659 .674 r
.29198 .18484 .2958 .19452 .30321 .17983 .2993 .17164 Mtetra
.811 .676 .714 r
.2993 .17164 .30321 .17983 .31031 .1689 .30633 .16188 Mtetra
.789 .694 .759 r
.30633 .16188 .31031 .1689 .31719 .16084 .31317 .15465 Mtetra
.765 .71 .801 r
.31317 .15465 .31719 .16084 .32393 .15478 .31988 .14913 Mtetra
.739 .723 .836 r
.31988 .14913 .32393 .15478 .33059 .15002 .32652 .14473 Mtetra
.717 .73 .861 r
.32652 .14473 .33059 .15002 .3372 .1461 .33313 .14102 Mtetra
.699 .735 .878 r
.33313 .14102 .3372 .1461 .34379 .1427 .33972 .13775 Mtetra
.687 .738 .889 r
.33972 .13775 .34379 .1427 .35037 .13962 .3463 .13475 Mtetra
.678 .739 .896 r
.3463 .13475 .35037 .13962 .35695 .13674 .35289 .13191 Mtetra
.673 .74 .901 r
.35289 .13191 .35695 .13674 .36354 .13398 .35949 .12917 Mtetra
.669 .74 .903 r
.35949 .12917 .36354 .13398 .37015 .13129 .36611 .12648 Mtetra
.667 .74 .905 r
.36611 .12648 .37015 .13129 .37676 .12863 .37273 .12383 Mtetra
.666 .741 .906 r
.37273 .12383 .37676 .12863 .38339 .126 .37937 .12119 Mtetra
.665 .741 .906 r
.37937 .12119 .38339 .126 .39004 .12338 .38603 .11857 Mtetra
.665 .741 .907 r
.38603 .11857 .39004 .12338 .3967 .12076 .3927 .11594 Mtetra
.664 .741 .907 r
.3927 .11594 .3967 .12076 .40338 .11814 .39939 .11331 Mtetra
.39939 .11331 .40338 .11814 .41008 .11553 .40609 .11068 Mtetra
.40609 .11068 .41008 .11553 .41679 .1129 .41282 .10805 Mtetra
.41282 .10805 .41679 .1129 .42352 .11027 .41956 .10541 Mtetra
.41956 .10541 .42352 .11027 .43026 .10764 .42631 .10276 Mtetra
.42631 .10276 .43026 .10764 .43702 .105 .43308 .10011 Mtetra
.43308 .10011 .43702 .105 .4438 .10235 .43987 .09745 Mtetra
.43987 .09745 .4438 .10235 .4506 .0997 .44668 .09478 Mtetra
.44668 .09478 .4506 .0997 .45741 .09704 .4535 .09211 Mtetra
.4535 .09211 .45741 .09704 .46424 .09437 .46034 .08943 Mtetra
.46034 .08943 .46424 .09437 .47109 .0917 .4672 .08675 Mtetra
.4672 .08675 .47109 .0917 .47795 .08902 .47408 .08405 Mtetra
.47408 .08405 .47795 .08902 .48483 .08633 .48097 .08135 Mtetra
.48097 .08135 .48483 .08633 .49173 .08364 .48788 .07865 Mtetra
.48788 .07865 .49173 .08364 .49865 .08094 .49481 .07594 Mtetra
.49481 .07594 .49865 .08094 .50558 .07823 .50175 .07322 Mtetra
.50175 .07322 .50558 .07823 .51253 .07552 .50872 .07049 Mtetra
.50872 .07049 .51253 .07552 .5195 .0728 .5157 .06776 Mtetra
.5157 .06776 .5195 .0728 .52649 .07007 .5227 .06502 Mtetra
.5227 .06502 .52649 .07007 .53349 .06734 .52971 .06227 Mtetra
.52971 .06227 .53349 .06734 .54052 .06459 .53675 .05951 Mtetra
.53675 .05951 .54052 .06459 .54756 .06185 .5438 .05675 Mtetra
.5438 .05675 .54756 .06185 .55462 .05909 .55087 .05398 Mtetra
.55087 .05398 .55462 .05909 .56169 .05633 .55796 .05121 Mtetra
.55796 .05121 .56169 .05633 .56879 .05356 .56507 .04843 Mtetra
.56507 .04843 .56879 .05356 .5759 .05078 .57219 .04564 Mtetra
.57219 .04564 .5759 .05078 .58303 .048 .57933 .04284 Mtetra
.57933 .04284 .58303 .048 .59018 .04521 .5865 .04003 Mtetra
.5865 .04003 .59018 .04521 .59735 .04241 .59368 .03722 Mtetra
.59368 .03722 .59735 .04241 .60454 .0396 .60087 .0344 Mtetra
.60087 .0344 .60454 .0396 .61174 .03679 .60809 .03158 Mtetra
.60809 .03158 .61174 .03679 .61896 .03397 .61533 .02874 Mtetra
.61533 .02874 .61896 .03397 .62621 .03114 .62258 .0259 Mtetra
.62258 .0259 .62621 .03114 .63347 .02831 .62986 .02306 Mtetra
.62986 .02306 .63347 .02831 .64075 .02547 .63715 .0202 Mtetra
.63715 .0202 .64075 .02547 .64805 .02262 .64446 .01734 Mtetra
.64446 .01734 .64805 .02262 .65537 .01976 .65179 .01447 Mtetra
.65179 .01447 .65537 .01976 .6627 .0169 .65914 .0116 Mtetra
.663 .741 .908 r
.65914 .0116 .6627 .0169 .67006 .01403 .66651 .00872 Mtetra
.66651 .00872 .67006 .01403 .67744 .01116 .6739 .00584 Mtetra
.662 .741 .908 r
.6739 .00584 .67744 .01116 .68483 .0083 .68131 .00298 Mtetra
.66 .741 .91 r
.68131 .00298 .68483 .0083 .69225 .00545 .68874 .00014 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -69.4375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -73.6592 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -72.9881 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -72.3171 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{268.5, 217.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0001AR000`400?l00000o`00003oo`3ooonC
0?ooo`00o`3ooonC0?ooo`00o`3ooonC0?ooo`00o`3ooonC0?ooo`00o`3ooonC0?ooo`00o`3ooonC
0?ooo`00o`3ooonC0?ooo`00o`3ooonC0?ooo`00o`3ooonC0?ooo`00o`3oool70?ooo`030?oog`2L
B000M;oo0080oooo00D0oono07@00000000004RL0=ooo`220?ooo`00o`3oool70?ooo`0:0?oog`2L
B000M;oo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_h80oooo003o0?ooo`@0oooo00<0gia80000
000000000`0000002018W=l0oono07@0M02oool0oooo0?oOW01807@0_oooP@3oool00?l0oooo103o
ool03P3ogi`0B4RL0=ooo`3ooml0W4P007Boo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo
P@3oool00?l0oooo1@3oool03@3OW4P0B9cO0?oog`2LB000M;oo0?ooo`3o_g@004RL0=ooo`3oool0
oono07@0B02Lgol0P@3oool00?l0oooo1@3oool03@3ooml0W4Q809cOg`2LB000M;oo0?ooo`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol0P@3oool00?l0oooo1P3oool0303ogi`0B4Qd07A8001d_ol0
oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oooh40oooo003o0?ooo`L0oooo00X0gia80000001d
_ol0oooo0?oog`2LB000M;oo0?ooo`3OW4P007BoPP3oool00?l0oooo1`3oool00`3ooml0W4P007Bo
o`020?ooo`050?oo_`1d000000000018W03Oool02`3oool01@3ookl0M00000000000B9`0gooo0780
oooo003o0?oooa/0oooo00H0oooO09a80018W=l0oooo0=nLB000M;mb0?ooo`00o`3ooolK0?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`1a0?ooo`00o`3ooolK0?ooo`070?oOW018B9`0gooo
0?ooo`3ookl0M01809cOo`1a0?ooo`00o`3ooolK0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M018
09cOo`1a0?ooo`00o`3ooolK0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`1a0?ooo`00
o`3ooolK0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`1a0?ooo`00o`3ooolK0?ooo`06
0?oog`2LB000M;oo0?ooo`3OW4P007BoLP3oool00?l0oooo4`3oool2000000L0oooo00D0oono07@0
0000000004RL0=ooo`1b0?ooo`00o`3ooolA0?ooo`80000000<0Z;gX000000000000O@3oool00?l0
oooo3P3oool3000000030:Vmj02X_NP0Z;gX00800000O@3oool00?l0oooo303oool2000000H0ZKgX
00<000000:Vmj0000000O03oool00?l0oooo2@3oool3000000P0ZKgX00@000000:Vmj03oool00000
N`3oool00?l0oooo1P3oool3000000/0ZKgX00@000000:Vmj02Y_NP00000N`3oool00?l0oooo103o
ool2000000030:Vmj0000000ZKgX00/0ZKgX00D000000:Vmj02Y_NP0ZKgX0000001j0?ooo`00o`3o
ool10?ooo`<00000402Y_NP00`000000ZKgX0:Vmj0020:Vmj0030000003oool0oooo07L0oooo003m
0?ooo`030:Vmj0000000000001<0ZKgX00<000000:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1g
0?ooo`00n`3oool3000001H0ZKgX00<000000:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1f0?oo
o`00`P3oool01@34Ga@000000000000001@0GlCo0080oooo00D0oon?03D00000000001AO0<Coo`0Z
0?ooo`<000006@2Y_NP00`000000ZKgX0:Vmj0020:Vmj0030000003oool0oooo07H0oooo00310?oo
o`0=0?n?=@0055l0a?oo0?ooo`3oohl0=@0D05o4o`3ool@0Ga@001AOa03oool0a5lD000eS`0W0?oo
o`030:Vmj00000000000008000006P2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo
07D0oooo00360?ooo`0908le000eSol0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo02@0oooo00<0
ZKgX0000000000007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo07@0oooo0035
0?ooo`0:0?ooS`0e01@0GlCo0?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4ob40oooo00@0ZKgX0000
000000000000802Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo07@0oooo00330?oo
o`0<0?o4G`0D0000000D05o4o`3oool0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo7`3oool30000
02<0ZKgX00<000000:Vmj02Y_NP01@2Y_NP00`000000oooo0?ooo`1c0?ooo`00a@3oool02P34Ga@0
03F?0?ooo`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?lL0?ooo`<000009P2Y_NP00`000000ZKgX
0:Vmj0060:Vmj0030000003oool0oooo0780oooo00350?ooo`0:0?o4G`0D03D0Sooo0?ooS`0e03D0
Sooo0?ooo`3oa5l0500e08oooaT0oooo00<0ZKgX0000000000000P00000W0:Vmj0030000002Y_NP0
ZKgX00H0ZKgX00<000000?ooo`3oool0LP3oool00<40oooo00d0olAO01@0=@2?ool0oooo0<AO5000
=Hl0oooo0?ooa01O5000=Hoo0?ooo`34Ga@003F?01P0oooo00<0ZKgX000000000000:`2Y_NP00`00
0000ZKgX0:Vmj0070:Vmj0030000003oool0oooo0740oooo00320?ooo`050?n?=@00000000000000
=@2?ool00P3oool01@3oohl0=@000000000055l0a?oo01D0oooo00@0ZKgX0000000000000000;@2Y
_NP00`000000ZKgX0:Vmj0080:Vmj0030000003oool0oooo0700oooo003Q0?ooo`030:Vmj0000000
00000300ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000oooo0?ooo`1`0?ooo`00gP3oool40000
0380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo0?ooo`1_0?ooo`00g03oool4000003@0
ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1^0?ooo`00fP3oool2000003P0ZKgX
00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1^0?ooo`00e`3oool3000003X0ZKgX00<0
00000:Vmj02Y_NP02`2Y_NP00`000000oooo0?ooo`1]0?ooo`00e@3oool2000003d0ZKgX00<00000
0:Vmj02Y_NP0302Y_NP00`000000oooo0?ooo`1/0?ooo`00dP3oool3000003l0ZKgX00<000000:Vm
j02Y_NP0302Y_NP00`000000oooo0?ooo`1/0?ooo`00d03oool300000440ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`000000oooo0?ooo`1[0?ooo`00c@3oool3000000<0ZKgX00<000000:Vmj02Y_NP0
?`2Y_NP00`000000ZKgX0:Vmj00=0:Vmj0030000003oool0oooo06X0oooo003;0?ooo`800000B02Y
_NP00`000000ZKgX0:Vmj00=0:Vmj0030000003oool0oooo06X0oooo00380?ooo`<00000BP2Y_NP0
0`000000ZKgX0:Vmj00>0:Vmj0030000003oool0oooo00X0oooo00<0gia80000000000000`000000
0`1d_ol0oooo0?ooo`1F0?ooo`00a03oool0102Y_NP0000000000000001=0:Vmj0030000002Y_NP0
ZKgX00h0ZKgX00<000000?ooo`3oool02P3oool00`3ogi`0B00007Boo`1L0?ooo`00`P3oool01@2Y
_NP000000000002Y_NP0000004h0ZKgX00<000000:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0:
0?ooo`030?oOW0180000M;oo05/0oooo002o0?ooo`040:Vmj0000000000000000580ZKgX00<00000
0:Vmj02Y_NP0402Y_NP00`000000oooo0?ooo`0:0?ooo`030?oo_`1d0000B9cO05X0oooo002m0?oo
o`030:Vmj0000000000005D0ZKgX00<000000:Vmj02Y_NP0402Y_NP00`000000oooo0?ooo`0;0?oo
o`030?oog`2LB000B9cO05T0oooo00230?ooo`030<AO50000000000000<0000000L0=Hoo0?ooo`3o
ohl0=@000000000055l0a?oo02X0oooo00@0ZKgX0000000000000000E`2Y_NP00`000000ZKgX0:Vm
j00A0:Vmj0030000003oool0oooo00/0oooo00<0oono07@0B02Lgol0F03oool008<0oooo00<0olAO
01@0000eSol0103oool01P3ool@0Ga@001AOa03oool0a5lD000eSbP0oooo00<0ZKgX000000000000
FP2Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00H0oooo00<0okmd001d_`3oool0
0P3oool00`2oM000M;oo0?ooo`1G0?ooo`00Q03oool00`3oa5l0500003F?o`030?ooo`070?ooS`0e
03D0Sooo0?ooo`3oa5l0500e08ooo`0U0?ooo`<0000000<0ZKgX0000002Y_NP0F@2Y_NP00`000000
ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00H0oooo00L0oono07@0B02Lgol0oooo0?oOW01804P0
W=oo05P0oooo00250?ooo`030?ooS`0e000055o40080oooo00L0olAO01@DG`34ool0oooo0?ooS`0e
01@0GlCo0280oooo00<0ZKgX000000000000G`2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030000003o
ool0oooo00H0oooo00D0omnL04P000000000000007Boo`1I0?ooo`00QP3oool02`3ool@0Ga@001AO
a03oool0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo0`00001Q0:Vmj0030000002Y_NP0
ZKgX01@0ZKgX00<000000?ooo`3oool0H`3oool008L0oooo00X0oon?03D0501Oa?l0olAO01@DG`34
ool0oooo0?ooS`0e01@0GlCo7@3oool3000006@0ZKgX00<000000:Vmj02Y_NP0502Y_NP00`000000
oooo0?ooo`1S0?ooo`00P`3oool00`3oScD003F?0?ooo`020?ooo`0908le000eSol0oon?03D0=@2?
ool0oooo0?o4G`0D03D0Sooo01/0oooo0P00001W0:Vmj0030000002Y_NP0ZKgX01D0ZKgX00<00000
0?ooo`3oool0HP3oool008<0oooo00d0oon?03D0501Oa?l0oooo0?o4G`0D01@0GlCo0?ooa01O5000
=Hoo0?ooo`34Ga@003F?01T0oooo0`0000020:Vmj0030000002Y_NP0ZKgX06@0ZKgX00<000000:Vm
j02Y_NP05P2Y_NP00`000000oooo0?ooo`1Q0?ooo`00Q03oool01@3oa5l05000000000000000=Hoo
0080oooo00D0oon?03D00000000001AO0<Coo`0G0?ooo`800000K02Y_NP00`000000ZKgX0:Vmj00F
0:Vmj0030000003oool0oooo0640oooo002T0?ooo`<0000000<0Z[gX0:Vmj02Y_NP0J`2Y_NP00`00
0000ZKgX0:Vmj00G0:Vmj0030000003oool0oooo0600oooo002R0?ooo`80000000@0Z[gW0:Zmj02Z
_NP0Z[gXK@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo05l0oooo002O0?ooo`<0
0000102Z_NL30:Zmj6d0ZKgX00<000000:Vmj02Y_NP05`2Y_NP00`000000oooo0?ooo`1O0?ooo`00
W@3oool200000080Z[gW00<000000:Zmi`2Z_NL00`2Z_NL70:Zmj6P0ZKgX00<000000:Vmj02Y_NP0
602Y_NP00`000000oooo0?ooo`1N0?ooo`00VP3oool3000000030:^mi`2Z_NL0Z[gW00/0Z[gW102Z
_NQW0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<000000?ooo`3oool0G@3oool009L0oooo0`000002
0:bmiPH0ZkgW2P2Z_NL60:Zmj6@0ZKgX00<000000:Vmj02Y_NP06@2Y_NP00`000000oooo0?ooo`1M
0?ooo`00U@3oool200000080[KgU0`2/_NH40:^miP80ZkgW2`2Z_NL60:Zmj6<0ZKgX00<000000:Vm
j02Y_NP06P2Y_NP00`000000oooo0?ooo`1L0?ooo`00TP3oool4000000040:nlh`2]_ND0[KgU0:fm
i@L0[;gV1P2[_NL70:Zmi`H0Z[gXHP2Y_NP00`000000ZKgX0:Vmj00J0:Vmj0030000003oool0oooo
05`0oooo002@0?ooo`8000000P2b_>020:nlh`030000002^_N@0[[gT0080[[gT102]_ND20:bmiPL0
ZkgW2@2Z_NL30:Zmj680ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`1K0?ooo`00
S@3oool300000080]k[L0`2b_>030;2lhP80[[gT0P2__>@30:fmi@<0[;gV1`2[_NL90:Zmi`L0Z[gX
G@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo05X0oooo002;0?ooo`8000000P3o
ool30;Njg0@0];_O0`2`_>840:nli0<0[KgU0`2/_NH30:^miP<0ZkgW2P2Z_NL70:Zmj5`0ZKgX00<0
00000:Vmj02Y_NP0702Y_NP00`000000oooo0?ooo`1J0?ooo`00R03oool3000000030?ooo`2m^MH0
_KWF0080_KWF00<0]k[L0;VjfP2i^]X00`2d^ml40;:lh@@0/;cS0`2]_ND30:bmiP<0ZkgV102[_NL9
0:Zmi`L0Z[gXF`2Y_NP00`000000ZKgX0:Vmj00M0:Vmj0030000003oool0oooo05T0oooo00250?oo
o`<000000P3oool00`000000`kG=0<>ec@030;fieP@0^K[J0`2f^md20;:lh@80/kcP0`2`_><40:jl
i0H0[;gV1P2[_NL:0:Zmi`<0Z[gXF`2Y_NP00`000000ZKgX0:Vmj00N0:Vmj0030000003oool0oooo
05P0oooo00230?ooo`8000001@3oool40<>ec@<0_kSB0P2i^]X20;^ie`<0][_M102c_>030;6lhP<0
[[cT102]_ND30:bmiPH0ZkgW2@2Z_NL40:Zmj5X0ZKgX00<000000:Vmj02Y_NP07P2Y_NP00`000000
oooo0?ooo`1H0?ooo`00B`3oool00`3oa5l0500e08ooo`020?ooo`050?ooS`0e00000000000DG`34
ool0:`3oool3000000H0oooo0P39/L820<>ec@80a[C90`2o^=830;^ie`@0^;[K102d^mh30;6lhP<0
[kcS102^_ND30:bmiP<0ZkgV0`2[_NL90:Zmi`L0Z[gXEP2Y_NP00`000000ZKgX0:Vmj00O0:Vmj003
0000003oool0oooo05L0oooo001;0?ooo`0:0?o4G`0D03D0Sooo0?ooo`3ool@0Ga@001AOa03oool0
a5lD000eSbP0oooo0`0000080?ooo`<0bK7200@0`kG=0<Jdb@36]<T0a[C91032]/l00`2k^ML0_KSD
0;fhe0020;Rjf`80^[[I0`2d^mh40;:lh@030:nlh`2`_><0/;cS00<0[[gU102]_ND20:^miP@0ZkgW
3@2Z_NL30:Zmj5D0ZKgX00<000000:Vmj02Y_NP0802Y_NP00`000000oooo0?ooo`1F0?ooo`00B`3o
ool02`3oa5l0500e08ooo`3oool0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo02D0oooo10000008
0?ooo`@0bK721036]<T01038//D0`[K?0<:fc`32]/l40;fhe0@0^[[I0`2f^md30;:lh@@0/;cS0`2^
_>@30:fmi@<0[;gV1`2[_NL:0:Zmi`80Z[gXE@2Y_NP00`000000ZKgX0:Vmj00P0:Vmj0030000003o
ool0oooo05H0oooo001;0?ooo`0;0?o4G`0D03D0Sooo0?ooo`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08`3oool2000000`0oooo00<0cjff0<Va`P39/L800P3<[kd20<Jdb@<0b;;500<0`[K?0<Be
b`34]L/00P2m^=@20<2gd@80^[[I0P2l^ML30;Jkg@<0/k_O102a_>830:jli0<0[KgU0`2/_NH40:^m
iP<0ZkgW2@2Z_NL30:Zmj5@0ZKgX00<000000:Vmj02Y_NP08@2Y_NP00`000000oooo0?ooo`1E0?oo
o`00B`3oool02`3oa5l0500e08ooo`3oool0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo
0`00000=0?ooo`<0cjff103<[kd40<Rba@<0a;G;1030]m440;bie`@0^;[K00<0/k_O0;FkgP2e^mh0
0`2a_>840:nlh`80[KgU202/_NH60:^mi`H0Z[gW1P2Z_NQ@0:Vmj0030000002Y_NP0ZKgX0280ZKgX
00<000000?ooo`3oool0E03oool004/0oooo00/0olAO01@0=@2?ool0oooo0?o4G`0D55l0a?oo0?oo
o`3oohl0=@0D05o4o`0N0?ooo`8000003`3oool40<n]]P030=6[/P3<[kd0c:nm0080cZji0P38//D2
0<Za`0030<Beb`36/lL0a[?70080`;OA0P32]/h20;bie`80_[SC0`2h^]/40;FkgP<0/[cP0`2__><4
0:jli0<0[KgU0`2/_NH60:^mi`X0Z[gW0`2Z_NQ?0:Vmj0030000002Y_NP0ZKgX0280ZKgX00<00000
0?ooo`3oool0E03oool004T0oooo00d0ScD00000501OSel0500e08ooo`3oool0oon?03D0=@2?ool0
oooo0?o4G`0D03D0Sooo01/0oooo0`00000A0?ooo`030=>X[03?[KH0cjff0080dJ^b00@0c:nm0<j^
^@3>[[T0cZji103:/L040<Jca`@0`[K>102n^=<30;Zif0@0]k[L0`2b_>040;2lhP<0[kcT0`2]_ND3
0:bmiPH0ZkgW2P2Z_NL60:Zmj4`0ZKgX00<000000:Vmj02Y_NP08P2Y_NP00`000000oooo0?ooo`0=
0?ooo`030?oog`2LB000M;oo04<0oooo001:0?ooo`0;0?n?=@000000000e08ooo`3oool0ooo405lD
000eSol0oooo0<AO5000=Hl06@3oool300000080oooo00<000000?ooo`3oool03P3oool20=>X[004
0<n]]P3AZk80dJ^b0=6[/P@0cZji00D0d:be0<Za`03:/L00b[700<f__0020<Jca`80bK;30P32]/h2
0<FdbP80_[SC0P31]m000`2j^MP0_KSF0;fheP030;Njg0@0];_O102b_>420:nli0@0[KgU0P2/_NH4
0:^miP<0ZkgW2P2Z_NL60:Zmj4/0ZKgX00<000000:Vmj02Y_NP08`2Y_NP00`000000oooo0?ooo`0<
0?ooo`030?oog`2LB000M;oo04<0oooo001;0?ooo`030?o4G`0D03D0Sooo0080oooo00D0oon?03D0
0000000001AO0<Coo`0G0?ooo`8000005P3oool20=>X[0@0dJ^b00<0dZV_0<j^^@3>[[T00`3@[;D0
0`3:/L00cJnl0<f__0040<Vb``@0aKC:1031]m040;fheP<0^K[J0P2d^ml20;Jkg@<0/[cQ0`2`_><3
0:fmi@L0[;gV1P2[_NL70:Zmi`H0Z[gXBP2Y_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0
oooo00T0oooo00<0gia80000000000000`0000000`18W=l0oooo0?ooo`100?ooo`00J@3oool30000
01L0oooo0`3CZ:`00`3EYjT0dJ^b0=6[/P030=:Y[`040<j^^@3@[;D0d:be0=2/]@<0cJnl00D0cZfh
0<Vb``39//<0bK;30<^`_`020<FdbP80ak?60P31]m020<>ec@80_KSF0P2o]m830;VjfP@0][_M0`2c
^n030;2lh`<0[[cT102]_ND30:bmiPH0ZkgW2@2Z_NL30:Zmj4X0ZKgX00<000000:Vmj02Y_NP0902Y
_NP00`000000oooo0?ooo`080?ooo`060?oOW018B9`0gooo0?oog`2LB000M;oo@`3oool006H0oooo
0`00000I0?ooo`<0djR/0P3EYjT20=6[/P<0dZV_103@[;D00`3AZ[40cJnl0<j]^0020<j]^0040<Vb
``3;/;l0bk2o0<^`_`@0ak?61033]Ld30;ngdP@0^kWG0P2f^md20;Rjf`80/k_P102a_>830:nlh`<0
[KgU102/_NH60:^mi`T0Z[gW1`2Z_NQ50:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3o
ool0203oool01@3OW4P0B9cO0?oog`2LB000M;oo04<0oooo001T0?ooo`@000006P3oool00`3GYZ@0
djR/0=>X[0020=FWZ@030=6[/P3BZJl0dZV_0080dZV_00<0e:R[0=2/]@3@[;D00P3AZ[40103=[k`0
cZfh0<j]^03>[KP30<^`_`80cJjk0P37/lH20<Va`P80`kG=0P36]<T00`2o]m80`[K?0<:fc`030;^i
e`@0^;[K0`2d^mh20;6lhP80/[cQ0`2__><30:jmi@H0[;gV0`2[_NL=0:Zmi`<0Z[gXA@2Y_NP00`00
0000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00P0oooo00D0oooO09a8B02Lgml0W4P007Boo`13
0?ooo`00HP3oool2000001h0oooo00<0ejJT0=>X[03EYjT00P3EYjT40=:Y[`80e:R[00@0d:be0=6Z
/@3AZ[40dJZa103>[KP00`3@Zk@0bk2o0<f^^`020<f^^`040<NcaP39/L80bK720<Va`P@0a[C91032
]/l40;fhe0<0^[[I0`2d^mh30;:lh@@0/;cS0`2^_ND30:fmi@<0[;gV1`2[_NL90:Zmi`<0Z[gXA02Y
_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00P0oooo00@0omnL04Q8M01dB000M;oo
@`3oool005l0oooo0`00000O0?ooo`80ejJT00D0djR/0=FWZ@3EYjT0eJNY0=JVYP030=:Y[`80e:R[
103AZ[400`3CZJd0cZfh0<j]^0020=2[]0@0cJjk1039/L800`3<[kd0a[C90<Jdb@020<Rba@80`[K?
0P34]L/20;fhe080`;OA0P2j^]T40;Jkg@<0/k_O0`2`_><40:jli0<0[KgU0`2/_NH30:^miP<0ZkgW
2P2Z_NL60:Zmj400ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`030=nL
B0000000M;oo04<0oooo001M0?ooo`80000000@0oooo08Jgm@26]oD0Q[Oe0P1RZoP200n1i1X0oooo
0P3GYZ@40=FWZ@80eZJV00D0dZV_0=BXZ`3DZ:/0e:R[0=FWZ0020=6Z/@80djV]00D0cZfh0=2[]03@
Zk@0d:^d0=:Z/0030<f^^`030<n/]P39/L80bK720080c:nm00@0a[C90<Rba@38//D0b;;51034]L/4
0<2gd@<0_;WF0P2f^md20;Rjf`<0/k_O0`2a_>820:jli080[kcS0`2]_ND30:bmiP<0ZkgV0`2[_NL9
0:Zmi`L0Z[gX?`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo00P0oooo00<0oooO
09a8001d_ol0@`3oool005X0oooo0`00000209nkk0<0Uk[`0P26]oD206:[n0803h7T603oool30=NV
Y0030=RUXP3EYjT0eJNY00<0eZJV0`3DZ:/20=FWZ0040=6Z/@3CZJd0djV]0=>Y[@@0d:^d0P3BZ[00
103=[[/0cjbf0<n/]P3?[;H30<b__@@0b;;500<0b[300<Beb`34]L/00P36/lL20<2gd@80`[K>0`2l
^MH30;Rjf`@0]K_N0`2a_>830:nlh`@0[[cT1P2/_NH60:^mi`X0Z[gW0P2Z_NPo0:Vmj0030000002Y
_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0C@3oool005L0oooo0`0000020:Fkj@80000000<0Wk_/
09^kkP2K^nh00P2K^nh208jhl`<0Lk7h00<0=YKb07@0003oool05@3oool30=NVY0030=RUXP3EYjT0
eJNY00<0eZJV00<0ejJT0=BXZ`3DZ:/00P3EYjP40=>Y[@030=BWZP3@Zk@0d:^d00<0dZZ`103?[;H0
103AZk80c:nm0<b__@3>[[T20<Rba@<0b[301036/lL30<:fcP@0_[SC00<0^;[K0;Zif02j^MP00`2e
^mh40;:lh0<0/;cR0`2^_>@40:fmi@80[;gV1`2[_NL90:Zmi`<0Z[gX?P2Y_NP00`000000ZKgX0:Vm
j00X0:Vmj0030000003oool0oooo04d0oooo001E0?ooo`800000102Y^^D20:Fkj@@0X[_[0P2K^nh3
09Bjl@<0P;Gf00<0DjCg0<=0002_90004`3oool40=NVY080f:FR00H0eJNY0=JVYP3FYZH0eZJV0=NV
Y03DZ:/30=FWZ0040=JVY@3CZJd0djV]0=>Y[@80e:NZ00D0d:^d0=:Z/03BZ[00dZZ`0=>X[0020<n/
]P80dJ^b00@0c:nm0<j^^@3>[[T0cZji0`3:/<020<b__080a[?70P39//<00`32]/h0aKC:0<FdbP03
0;jhd`@0^[WH102g^]`30;Bkg`<0/;cR0`2__>@40:fmi@<0[;gV0`2[_NH30:^mi`T0Z[gW1P2Z_NPj
0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0C03oool00580oooo0`0000040:fg
h0<0[;SR0`2W^^L30:Fjj0<0W[_]0P2D^_4308Vgm00406V]n033@000[b@009000140oooo00<0fZJP
0=NVY03GYZ@00`3HYJ830=JVYP80ejJT00D0e:R[0=FWZ03EYjP0eJNX0=JVY@020=>Y[@<0e:NZ0`3B
Z[020=>X[0040<n/]P3AZk80dJ^b0=6[/P@0cZji00<0d:be0<Z``03<[k`00P3<[k`01036/lL0bK;3
0<Vb``39//<40<FdbP<0`KO@102m^=H20;Njg080^K[J0P2d^ml40;:lh@030:nli02`_><0/;cS00<0
[KgU102/_NH20:^miP@0ZkgW202Z_NL70:Zmj3T0ZKgX00<000000:Vmj02Y_NP0:P2Y_NP00`000000
oooo0?ooo`1;0?ooo`00D03oool2000000040?ooo`2b/MP0/[7H0;:af0@0/;?J0`2/^>830:Zii0<0
YK[X0`2R^^X309Vjk`80RKOd00<0JJgh0=UX:`3DGAT00P2@000?0?ooo`030=ZVX03GYZ@0ejJT00<0
f:FR00<0fJFQ0=JVYP3FYZH00P3GYZ@30=FWZ0<0eZJU00D0djV]0=BWZP3DYjX0e:NZ0=JVY`020=:Z
/080djR/103AZk800`3BZJl0cZji0<j^^@020=2/]@@0c:nl0`39//<20<^`_`80aKC:0P37/lH00`31
]m00`kG=0<>ec@030;fheP@0^K[J0`2f^md30;:lh@@0/;cS0`2^_>@60:bmiPL0ZkgW2@2Z_NL30:Zm
j3P0ZKgX00<000000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`1;0?ooo`00C@3oool300000005
0;NXb`000000]jS;0;NXb`2b/MP00P2eZlh30;2cfP@0[kCM0P2Z^N@40:RiiP80X[[Z102M^^d2096i
lP030=UX:`3DGAT0e5dI0080c4h23@3oool30=ZVX0060=NVY03HYJ80f:FR0=RUXP3IYJ40eZJV0`3G
YZ@00`3HYJ80eJNX0=FWZ0030=JVY@<0e:NZ0P3FYZL01@3BZ[00djR/0=>X[03CZ:`0e:NY0080dJ^b
0P3BZJl01@3>[[T0d:be0=2/]@3@[;D0dJZa00<0c:nl00<0cZfh0<Vb``3;/;l00P3;/;l01035]<X0
ak?60<NcaP37/lH40<>ec@<0_kOB0P2i^]X20;^ie`<0][_M0`2c^n040;6lhP80[[cT102]_ND30:bm
iPL0ZkgW202Z_NL40:Zmj3L0ZKgX00<000000:Vmj02Y_NP0:`2Y_NP00`000000oooo0?ooo`1:0?oo
o`00B`3oool2000000<0oooo00@0^Ybj0;NXb`2gZ</0]jS;102eZlh30;B]dP<0[kCM102]]]l20:Ri
iP@0YKWW0P2M^^d209Nik`80fFP[0P3DGAT20<a>0P030:HI003oool0oooo00T0oooo0`3JYZ030=RU
XP80fJFQ00@0eZJV0=NVY03GYZ@0ejJT0P3HYJ801@3EYjP0eZJU0=JVY@3FYZD0f:FS0080e:NZ0P3F
YZL30=>X[080e:NY00@0dJ^b0=:Y[`3BZJl0dZV_103@[;D20=6Z/@030<b__03>[KP0cZfh00@0bk2o
1037/lH00`39/L80`kG=0<>ec@020<Jdb@<0_kOB0`2k^ML40;Rjf`<0];_N0`2a_>840:nlh`<0[[gU
0`2/_NH30:^miP<0ZkgW2@2Z_NL70:Zmj3<0ZKgX00<000000:Vmj02Y_NP0;02Y_NP00`000000oooo
0?ooo`190?ooo`006@3oool01@3oohl0=@000000000055l0a?oo02X0oooo0`0000040?ooo`<0^Ybj
00<0]jS;0;VO_P2iWkh00P2eZlh20;RS``<0]:gB0`2b[mD20:ffg`80/K7H0`2[]n430:Vhi0<0X[WZ
0P3IJ2/20=AM6@80c4h200<0_CL00:HI002V6@00203oool40=ZVX0030=^VW`3HYJ80f:FR0080fJFQ
0`3GYZ@30=RUXP<0eZJU0P3HYJ<01@3DYjX0eZJW0=JVY`3FYZL0ejJT0080djR/0P3DYjT40=:Y[`03
0=BXZ`3@[;D0d:be00<0dJZa0`3>[KP01@3@Zk@0bk2o0<^`_`3;/;l0cJjk0080ak?60P39/L801033
]Ld0a[C90<Jdb@36]<T40<:fc`030;^ie`2m^=@0_KSD0080^;[K0P2j^]T30;BkgP<0/[cQ102`_><2
0:jmi@@0[KgU0`2[_NH30:^mi``0Z[gW102Z_NPb0:Vmj0030000002Y_NP0ZKgX02`0ZKgX00<00000
0?ooo`3oool0B@3oool001P0oooo00H0ooo405lD000DGl@0oooo0<AO5000=HlW0?ooo`<000001P3o
ool40;ZL^P@0^Inn0`2hXl<20;B]dP80]jG70`2b[mD30;6af0@0[k?K0P2Y^>@40:JhiP80gWQ60P3M
M3l20=]^=0040=QU9P3BFA80dUTB0<Q700H0oooo103JYZ000`3KYYl0f:FR0=VUX@020=VUX@030=ZV
X03GYZ@0ejJT00<0f:FR00<0fJJP0=JVY@3FYZD00P3HYJ<30=JVY`80ejJT00D0djR/0=BWZ@3DYjT0
e:NY0=JVYP030=:Y[`80e:R[00H0d:be0=6Z/@3AZ[40dJZa0=>Y[@3>[KP30=2[]0040<^`_`3=[[/0
cJjk0<f^^`<0bK721036]<T01038//D0`[K?0<:fc`32]/l40;fhe0<0^[[I102f^md00`2b_>40/k_O
0;>kg`030;2lh`<0[[cT0`2]_ND40:bmiPH0ZkgW2@2Z_NL60:Zmj2l0ZKgX00<000000:Vmj02Y_NP0
;@2Y_NP00`000000oooo0?ooo`180?ooo`00603oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?
ool0903oool2000000030?ooo`000000oooo00D0oooo0P2lT:T20;ZL^P80_9>]0P2iWkh20;^F/@80
^:?3102gYLL40;JXb`030;6af02eZll0]J_?00<0[k?K0`2]]=h30:JhiP80gWQ60P3MM3l20=]^=080
f6DV0P3BFA800`38A`00oooo0?ooo`020?ooo`@0fZJP0P3KYYl01P3HYJ80fJFQ0=VUX@3IYJ40fZJP
0=NVY0@0f:FR00<0fJJP0=JVY@3HYJ<00P3HYJ<00`3IYJ40eZJW0=JVY`020=NVY0@0e:NY00<0eZJV
0=:Y[`3BZJl00`3DZ:/30=6Z/@80djV]00@0cZfh0=2[]03@Zk@0d:^d103=[[/0103?[;H0bK720<b_
_@3<[kd20<Jdb@<0b;;500<0`[K?0<Beb`34]L/00P2m^=@20<2gd@030;Zjf@2l^MH0_;WF00<0][_M
102c^ml30;6lhP<0[[cT0`2]_ND40:bmiP80ZkgV102[_NL90:Zmi`H0Z[gX;`2Y_NP00`000000ZKgX
0:Vmj00]0:Vmj0030000003oool0oooo04L0oooo000H0?ooo`070?o4G`0D55l0a?oo0?ooo`3oohl0
=@0D05o4o`0Q0?ooo`<000002@3oool30;b@Z@050;ZL^P2lTjd0_9>]0;bC[@2iWkh00`2kU[400`2h
Xl<0^iVf0;^I]P020;NUa`80^Ybj0`2fZ</40;F[c`<0/jgC0`2]]=h20:Zfh@<0gWQ60P3MM3l20=]^
=0030=QU9P3BFA80dUTB0080b4L00P2K30000`3oool0gJVP0=ZVX0020=ZVX080fjJO0`3IYJ420=ZV
X0040=NVY03HYJ80f:FR0=RUXP80fJJP00H0eZJU0=RUX`3HYJ<0f:FS0=VUX@3FYZL30=NVY0030=RU
XP3DYjT0e:NY00<0eZJV00D0dZV_0=BXZ`3DZ:/0e:R[0=FWZ0020=6Z/@80djV]103@Zk@00`3BZ[00
cJjk0<f^^`020<n/]P@0c:nm1038//D30<Beb`@0`;OA102l^MH30;Rjf`@0]K_N0P2a_>840:nlh`<0
[[cT1P2/_NH70:^mi`H0Z[gW1P2Z_NP^0:Vmj0030000002Y_NP0ZKgX02d0ZKgX00<000000?ooo`3o
ool0A`3oool001P0oooo00L0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo01l0oooo0P00000;0?oo
o`@0_92Y102lTjd40;^F/@@0^iVf102jW;X00`2fZ</0^Inn0;VO_P020;F[c`80^:;30`2c[M<30;6_
eP80Z[KQ0P3NN4H20=ed?`80ffhd0P3NMd@20=eb>`80fV/`0P2K3000103MZJ00fZJP0=ZVX03JYZ02
0=^VW`030=bXW`3IYJ40fJFQ0080fZJP103HYJ820=VVX0<0f:FS0P3IYJ401@3FYZL0ejJT0=NVY03G
YZ@0f:FR0080e:NY0`3FYZH30=BXZ`80eJNX00D0dJZa0=>Y[@3CZJd0djV]0=BWZP020=2[]080dZZ`
00D0cJjk0<n/]P3?[;H0cjbf0=6[/P020<b__@80cZji0P38//D20<Z``0030<Beb`36/lL0a[?70080
`;OA0P32]/h20;bieP80_[SC00<0^;[K0;Zif02j^MP00`2e^mh40;:lh0<0/;cR0`2^_>@30:fmi@<0
[;gV1P2[_NL90:Zmi`@0Z[gX;@2Y_NP00`000000ZKgX0:Vmj00^0:Vmj0030000003oool0oooo04H0
oooo000H0?ooo`070?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4o`0L0?ooo`<000003@3oool01@2m
R9`0_92Y0;b@Z@2lT:T0_HZO00<0_9>]00D0_8bR0;^F/@2kU[40^iJa0;b>Y@030;^I]P040;b@Z@2j
W;X0^Ybj0;ZL^P@0^Inn0`2hX/<40;NUa`80/JoF0P2_/MX20=ihAP<0gW]>0P3NNTX00`3NMd@0gG8k
0=eb>`020=Y[<0050=IQ7`3MZJ00gJVP0=fYX03JYZ000`3KYYl00`3LZ9l0fJFQ0=ZVX0020=ZVX004
0=^WW`3HYJ80f:FR0=RUXP80fJJP00<0fjJO0=RUX`3HYJ<00P3IYJ440=NVY080f:FR00D0e:NY0=JV
YP3FYZH0eZJV0=NVY0020=BXZ`80eJNX0`3CZJd20=BWZP040=2[]03BZ[00dZZ`0=:Z/0<0cjbf0P3A
Zk80103<[kd0cZji0<j^^@3>[[T40<Z``0@0a[?70`32]/h40;jhd`@0^[WH0`2g^]`20;:lh080];_O
0P2`_>840:nli080[KgU102/_NH30:^miP<0ZkgW2@2Z_NL60:Zmj2X0ZKgX00<000000:Vmj02Y_NP0
;`2Y_NP00`000000oooo0?ooo`150?ooo`00603oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?
ool06P3oool2000000l0oooo0P2mR9`20;b@Z@80_HZO0P2lTjd20;b<XP80^iJa0P2lSZD20;^I]P80
_92Y0P2jW;X20;^C[@80^Inn0P2kU[420;RR``040;ZI]P2gYLL0]jG70;NUa`<0]JS<00@0[k7J0=ek
D03MNe00gG]@0P3NNdh20=ijBP80gWM40P3MLS/20=Y[<0<0gJVP00<0fZJP0=^VW`3KYYl00P3LZ9l0
1@3IYJ40fZJP0=ZVX03JYZ00fjNO0080f:FR0`3IYZ000`3KYYl0f:FS0=RUX`020=VUX@030=ZVX03G
YZ@0ejJT00<0f:FR0`3FYZH20=NVY0050=BXZ`3EYjP0eJNX0=FWZ03FYZD00P3CZJd20=BWZP@0dZZ`
00<0djR/0<n/]P3?[;H00P3AZk840<j^^@050=2/]@3:/<00b[300<Z``03<[k`00P36/lL20<Vb``03
0<:fcP35]<X0aKC:0080_[SC0P31]m020;Zif080_KSF0P2g^]`40;Bkg`<0/[cQ0`2__>@40:fmi@<0
[;gV0`2[_NH30:^mi`T0Z[gW1P2Z_NPY0:Vmj0030000002Y_NP0ZKgX02l0ZKgX00<000000?ooo`3o
ool0A@3oool001P0oooo00H0ooo405lD000eSol0oooo0<AO5000=HlH0?ooo`<000000P3oool00`00
0000oooo0?ooo`0<0?ooo`80_HRL0P2lT:T20;f:W`80_9>]0P2lS:801@2kU[40_8jU0;b>Y@2lSZD0
^iVf00<0_92Y00D0^Ybj0;^C[@2kTjd0^i>]0;VO_P030;^F/@050;RR``2jVKH0^YVf0;ZI]P2gYLL0
0P2jW;X30;FXc0030;>[d03MNe00gG]@0080gW]>0P3NNTX20=igA080gG8k0P3JJc030=fYX0<0fjJO
0P3LZ9l40=ZVX080fjNO00<0f:FR0=VVX03IYZ000P3KYYl01@3HYJ<0fJFQ0=VUX@3IYJ40fZJP0080
ejJT0`3HYJ800`3IYJ40eZJV0=JVYP020=NVY0@0eJNX00<0eZJU0=>Y[@3DYjX00P3DYjX00`3EYZL0
dZZ`0=:Z/0030=>X[0<0dJ^b00<0dZV_0<j^^@3>[[T00`3@[;D00`3:/<00c:nl0<b__0040<Vb``@0
aKC:0`31]m040;fheP@0^K[J0`2f^md30;:lh@<0/;cS102^_>@60:bmiPH0ZkgW2@2Z_NL30:Zmj2P0
ZKgX00<000000:Vmj02Y_NP0<02Y_NP00`000000oooo0?ooo`140?ooo`006@3oool01@3oohl0=@00
0000000055l0a?oo01H0oooo0P00000C0?ooo`<0_HRL00D0_92Y0;f:W`2mRYl0_HZO0;bC[@030;b<
XP@0_8jU102lT:T40;^C[@@0^iJa102jVKH40;ZL^P<0^Ino0P3MNe030=ikCP030=ijBP3NMd@0gWM4
00<0gW]=103MZJ000`3N[:80fjJO0=^VW`020=bXW`030=fZX03JYZ00fZJP00<0fjNO0`3IYZ020=^V
W`040=RUX`3IYJ40fJFQ0=VUX@80fZJP00H0ejJT0=RUXP3HYJ80f:FR0=VUX@3FYZH30=NVY0030=RU
XP3EYjP0eJNX0080eZJU103DYjX20=FVY`060=:Z/03CZ:`0djR/0=>X[03DYjT0dJ^b0`3BZJl0103>
[[T0d:be0=2/]@3@[;D30<b__0030<j]^039//<0bK;30080bk2o0P35]<X20<NcaP030<6gd033]Ld0
`kG=0080_KSF0P2o]m820;VjfP80^kWG0P2f^md40;>kh0<0/KcR0`2^_>@30:fmi@<0[;gV1`2[_NL9
0:Zmi`<0Z[gX9`2Y_NP00`000000ZKgX0:Vmj00a0:Vmj0030000003oool0oooo04<0oooo000a0?oo
o`<000005@3oool30;f8W0@0_HZO102lS:801@2nQiX0_8jU0;b>Y@2lSZD0_HRL00<0_92Y00D0_HZO
0;^C[@2kTjd0^i>]0;b<XP030;^F/@050;b>Y@2jVKH0^YVf0;ZI]P2lT:T00`2jW;X00`2kTjd0^Ino
0;VO_`030=ekD080gW]>00@0gWY:0=ekD03MNe00gG]@0P3NNdd40=fYX0030=j/XP3KYYl0g:RO0080
g:RO00<0gJZP0=ZVX03JYZ000`3KYil00`3MZ9l0fJJP0=VVX0020=^VW`<0fJFQ0`3JYZ030=RUXP80
fJFQ00D0eZJV0=NVY03GYZ@0ejJT0=RUXP020=FWZ080eZJU00<0ejFS0=BWZP3DYjX00`3EYZL30=>X
[080e:NY00@0dJ^b0=:Y[`3BZJl0dZV_103@[;D00`3AZ[40c:nl0<j]^0020<j]^0<0bk2o1037/lH4
0<>ec@<0_kOB102k^ML30;Rjf`80/k_P0P2e^mh30;6lhP<0[kcS0`2]_ND30:bmiP@0ZkgV0P2[_NL:
0:Zmi`H0Z[gX8`2Y_NP00`000000ZKgX0:Vmj00a0:Vmj0030000003oool0oooo04<0oooo000^0?oo
o`<000005`3oool40;f8W0050;n5UP2mRYl0_HZO0;f:W`2nQYP00`2lS:801@2nQiX0_8jU0;b>Y@2l
SZD0_HRL00<0_92Y00<0_HZO0;^C[@2kTjd00P2lS:820;^F/@80_8jU0P2jVKH20;b@Z@80^Ybj0P2k
Tjd20;VO_`030;^F/@3MNe00gG]@0080gW]>0P3LNU020=ekD0030=ikC@3MZJ00gJVP0080gJVP0P3N
[:800`3KYYl0g:RO0=bXW`030=fZX0060=ZVX03KYil0fjNO0=^WW`3MZ9l0fJJP0`3KYYl00`3LYil0
fJFQ0=VUX@030=ZVX0030=^VW`3HYJ80f:FR0080fJFQ0`3GYZ@30=RUXP040=FWZ03FYZD0eZJU0=NU
X`80e:NZ0`3EYZL00`3GYZ@0djR/0=>X[0020=BWZ@@0dZV_00<0e:R[0=2/]@3@[;D00P3AZ[440<j]
^0040=2[]03;/;l0bk2o0<f^^`80ak?60P39/L820<>ec@80a[C900<0_kOB0<:fc`32]/l00P2k^ML2
0;fhe0<0^;[K0`2e^mh40;:lh@80[kcS102^_ND30:fmi@<0ZkgV0`2[_NL<0:Zmi`@0Z[gX8@2Y_NP2
000003@0ZKgX00<000000?ooo`3oool0@P3oool002`0oooo0P0000030?ooo`030000003oool0oooo
01@0oooo00D0_hFE0;f8W02mR9`0_HRL0;n5UP030;f:W`050;j6V02lS:80_8bR0;b<XP2nQiX00P2l
SZD30;f8W0040;b@Z@2mRYl0_HZO0;^C[@<0_8bR00D0^iJa0;b>Y@2lSZD0_8jU0;ZI]P030;b@Z@05
0;ZL^P2kTjd0^i>]0;^C[@2iWkl00P2kU[420=ekD0<0fWM>00D0g7Y@0=ekD03MNe00gW]=0>6cZ003
0=fYX080gZbR0`3LZ9l30=fZX0030=ZVX03KYil0fjNO0080gJRO00D0fJJP0=^VW`3KYYl0fjJO0=bW
W`020=VUX@<0fZJP00<0fjJO0=RUXP3IYJ400P3IYJ400`3JYZ00ejJT0=NVY0030=RUXP<0eZJU0P3G
YJ<00`3DYjX0eJJW0=FVY`020=NVY0050=>X[03DYjT0e:NY0=BWZ@3FYZH00P3BZJl20=BXZ`050=2/
]@3AZ[40dJZa0=6Z/@3CZJd00P3>[KP20=2[]0040<^`_`3=[[/0cJjk0<f^^`<0bK721036]<T40<:f
c`<0_KSD102j^MT30;Jkg0<0/[cQ0`2`_><40:jli080[KgU102/_NH60:^mi`T0Z[gW1P2Z_NPK0:Vm
j0<000000P2Y_NP00`000000ZKgX0:Vmj00a0:Vmj0030000003oool0oooo0480oooo000Y0?ooo`<0
00000P2A_?@306NbnaL0oooo00<0_hFE0;f8W02mR9`00P2oQIH20;f:W`80_XJH0P2lS:830;j7VP05
0;b>Y@2mR9`0_HRL0;f8W02lT:T00P2mRYl40;b<XP@0_8jU102lT:T40;^C[@<0^iJa0`3GL4T20=Yg
CP050=ajD03MNe00gG]@0=ekD03Q/jP00P3MZJ030=j/XP030>2`Y@3LZ9l0g:RO00<0gJZP0`3KYil2
0=fXW`<0fjJO0`3LYil00`3IYJ40fZJP0=ZVX0020=^VW`060=RUXP3IYJ40fJFQ0=VUX@3JYZ00ejJT
103HYJ800`3IYZ00eZJU0=NUX`020=NUX`<0eJJW0P3GYZ@00`3CZ:`0e:NY0=BWZ@020=JVYP80dZV_
0P3DZ:/30=6Z/@80djV]00@0cZfh0=2[]03@Zk@0d:^d103=[[/0103?[;H0bK720<Va`P3<[kd20<Jd
b@80b;;50P32]/l20<Beb`030;fhe030]m40`;OA0080^[WI0P2l^MH30;Jkg0<0/k_O0`2a_>830:jl
i0@0[KgU0`2/_NH30:^miP<0ZkgW2@2Z_NL60:Zmj1L0ZKgX0`0000050:Vmj0030000002Y_NP0ZKgX
0380ZKgX00<000000?ooo`3oool0@@3oool002L0oooo0P000000102U_N/0Wkg^09nmkP2O_Nh2096l
m0<0Rkcf0`34AP`C0?ooo`030;n5U@2mR9`0_HRL0080_hFF0P2mRYl30;j6V0050;b<XP2nQiX0_XNJ
0;j7VP2lSZD00`2mR9`30;f:W`050;j6V02lS:80_8bR0;b<XP2mQiX00`2lSZD01@2mR9`0_92Y0;b@
Z@2lT:T0_HZO00<0^i>]00@0_8bR0;^F/@2kU[40^iJa0P3GL4T20=YgCP80g7Y@00D0gG]@0>6cZ03Q
/jP0hK>X0=fYX0030=j/XP030>2`Y@3LZ9l0gJZP00<0gJZP00<0gjfR0=^WW`3KYil00P3MZ9l00`3N
Zj40fjJO0=^VW`030=bWW`<0fZJP0P3KYYl30=VUX@80fZJP00<0ejJT0=RUXP3HYJ800P3HYJ800`3I
YZ00eZJU0=NUX`020=NUX`030=VUX@3EYZL0ejJT0080ejJT0`3DYjT20=JVYP050=:Y[`3DZ:/0e:R[
0=BXZ`3EYjP00P3AZ[420=>Y[@@0d:^d00<0dZV`0<f^^`3=[[/00P3?[;H01039/L80c:nm0<b__@3<
[kd30<Rba@@0a;G;1030]m430;bieP@0^;[J0`2e^mh30;6lhP<0[kcS102^_>@60:bmiPH0ZkgW1P2Z
_NL60:Zmj1@0ZKgX0P0000090:Vmj0030000002Y_NP0ZKgX0380ZKgX00<000000?ooo`3oool0@03o
ool002D0oooo0P000000102W_NT0YKg[0:Fmj`2U_N/30:Bmk0<0WKg_0P2J_O430=MhF@80cUTX00<0
UP<00?ooo`3oool0303oool20;n5U@80_HRL0P2oQIH00`2mRYl0_XJH0;j6V0020;j6V0040;b<XP2n
QiX0_XNJ0;j7VP@0_HRL0`2mRYl01@2nQYP0_8bR0;b<XP2lS:80_HNJ00<0_8jU00<0_HRL0;b@Z@2l
T:T00P2mRYl20;^C[@80_8bR0P2kU[400`2lSZH0eg190=M`B@020=YgCP80g7Y@00@0gG]@0>6cZ03Q
/jP0hK>X0`3N[:820>2`Y@030=bXW`3MZZ00gJZP0080gJZP00<0gjfR0=^WW`3MZ9l00P3MZ9l00`3N
Zj40fjJO0=^VW`030=bWW`030=fYX03JYZ00fZJP0080fjJO00<0g:RO0=VUX@3IYJ400P3JYZ040=RU
XP80fJJP00H0eZJU0=NUX`3GYJ<0ejFS0=VUX@3EYZL30=NVY0030=RUXP3DYjT0eZJV0080eZJV103D
Z:/00`3EYjP0dJZa0=>Y[@020=>Y[@030=BWZP3@Zk@0d:^d0080dZV`00@0cJjk0<n/]P3?[;H0cjbf
0`3<[kd20<j]^@030<Rba@3:/<00b[300080a;G;0P36/lL20<2gd@80`[K>00<0_;WF0;jhd`2n^=<0
0P2h^]X20;Zif080]K_N102b_>030;2lhP<0[[cT0`2]_ND30:bmiPH0ZkgW2@2Z_NL40:Zmj100ZKgX
0`00000<0:Vmj0030000002Y_NP0ZKgX0340ZKgX00<000000?ooo`3oool0@03oool002D0oooo0P00
00020:Nmj@<0YkgZ0`2T_N`30:>mk080V[ga0`3GN5T20<iI:080UP<0303oool20;n5U@050;f8W02o
QIH0_hFF0;n5UP2mRYl0102nQYP40;j7VP@0_HRL0P2mRYl20;j6V0<0_8bR00<0_HNJ0;b>Y@2lSZD0
0P2mR9`20;b@Z@80_HZO00D0^i>]0;b<XP2lS:80_8bR0;^F/@030;b>YP030=M`B@3JMdh0fWM>0080
g7Y@103Q/jP00`3Q^k00gZbR0=j/XP020>2`Y@@0gJZP0P3O[J800`3KYil0gJRO0=fXW`020=j[X@03
0=^VW`3LYil0g:NO0080g:NO00<0gJVP0=ZVX03KYYl00P3KYYl00`3LZ9l0fJFQ0=VUX@020=ZVX004
0=^WW`3HYJ80f:FR0=RUXP80fJJP0`3GYJ<20=VUX@<0ejJT0P3HYJ801@3DYjT0eZJV0=JVYP3FYZH0
ejJT0080e:R[0P3EYjP40=>Y[@030=BWZP3@Zk@0dZV`0080dZV`103?[;H00`3AZk80c:nm0<j]^@02
0<j]^@@0b[300`36/lL40<:fcP<0_[SC102j^MP30;Njg080/[cP0P2d^ml30;2lhP<0[kcT0`2]_ND3
0:bmiP<0ZkgV0`2[_NL90:Zmi`H0Z[gX2P2Y_NP300000100ZKgX00<000000:Vmj02Y_NP0<@2Y_NP2
000000`0oooo00D0oono07@000000000001d0;ooo`0_0?ooo`00603oool01@3ookl0M00000000000
B9`0gooo00P0oooo00<000000?ooo`0000001@2X_NT30:JmjP<0YKg[00@0XKg]0=MhF@3GN5T0egQI
0`3HOF420==W?@80/bT02@3oool20;n5U@040;f8W02oQIH0_hFF0;n5UPD0_XJH102nQiX30;f8W003
0;n5UP2mRYl0_HZO00<0_XJH00D0_8bR0;f7VP2mQiX0_HNJ0;b>Y@020;f8W0040;b@Z@2mRYl0_HZO
0;f:W`@0_8bR102lSZH00`3GL4T0fWM>0=YgCP020==Y@`<0hK>X0P3Q^k001@3N[:80h;2U0>2`Y@3P
/:D0hKJZ00<0gJZP0P3O[J830=fXW`80gZ^Q00@0fjJO0=bWW`3LYil0g:NO0P3MZJ000`3JYZ00fjJO
0=^VW`020=bXW`050=VUX@3JYZ00fZJP0=ZVX03KYil00P3HYJ830=VVX0030=^VW`3GYJ<0ejFS0080
fJFQ00<0fZJP0=NVY03GYZ@00P3HYJ840=JVYP80ejJT00@0e:R[0=FWZ03EYjP0eZJU0P3CZJd20=BW
ZP@0dZV`00<0djR/0<n/]P3?[;H00P3AZk840<j]^@030<n/]@3:/<00b[300080c:nl00<0a[?70<Va
``39/L<00P32]/h20<FdbP<0`KO@0P2j^MP20;fhe@<0]k[L0`2d^ml40;:lh@80[kcT102]_ND30:bm
iP<0ZkgV0`2[_NL90:Zmi`H0Z[gX1P2Y_NP3000001<0ZKgX00<000000:Vmj02Y_NP0<P2Y_NP00`00
0000oooo0?ooo`0:0?ooo`060;md001d_ol0oooo0?oOW018B9`0gooo;P3oool001L0oooo00H0oooO
09a80018W=l0oooo0=nLB000M;l80?ooo`80000000@0oooo0:Vmj02Y_NP0ZKgX0`2X_NT30:Nmj@<0
YKg[0`3GN5T0103HQW80f7eQ0=QmH@3CIcd20=R1J080eW5=0`34A@X40?ooo`<0_hFE00D0_HRL0;n5
UP2oQIH0_hFF0<:5TP040;j6V0<0_XNJ00D0_hFE0;f8W02mR9`0_HRL0;n5UP020;f:W`<0_XJH00D0
_8bR0;f7VP2mQiX0_HNJ0;b>Y@020;f8W0@0_HZO00D0_XJH0;b<XP2lS:80_8bR0;f7VP020;b>YP03
0;f8W@3GL4T0bEL_0080bEL_103Q/jP20>6k/0030=j/XP3P/:D0h;2U0080hKJZ0P3MZZ030=n]XP03
0>2aYP3MZ9l0gJRO0080gZ^Q103LYil20=fYX0<0fjJO0P3LZ9l0103IYJ40fZJP0=ZVX03JYZ020=^W
W`060=RUXP3IYZ00fJJP0=VVX03KYYl0ejFS0`3IYJ400`3JYZ00ejJT0=RUXP020=RUXP030=VUX@3F
YZH0eZJV00<0ejJT0`3EYjP20=JVY@040=>Y[@3DYjX0e:NZ0=FVY`80dZV`0`3CZ:`30=6[/P030=:Y
[`3>[KT0cZfi0080cjbe00@0b[300<b__03<[k`0c:nl1039/L<30<FdbP040<NbaP31]m00`KO@0<6g
d0<0_KSE102i^]X30;Jkg@<0/[cQ0`2`_><40:jli0H0[;gV1P2[_NL90:Zmi`<0Z[gX0P2Y_NP30000
01L0ZKgX00<000000:Vmj02Y_NP0<@2Y_NP00`000000oooo0?ooo`090?ooo`070?oo_`1dB9`0gooo
0?ooo`3ookl0M01809cOo`0^0?ooo`005`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
1P3oool2000000<0oooo0`2Y_NP40:Rmj0@0YkgY0P3GN5T20=R6LP80f7eQ0`3HPFP30=IaC@<0egQH
0P3>FBL0103oool0_hFE0;n5U@2oQID40;n5UP050<:5TP2nQYP0_XJH0;j6V031QI<00`2nQiX00`2o
QID0_HRL0;f8W0020;n5UP030;f:W`2nQYP0_XJH0080_XJH00@0_8bR0;f7VP2mQiX0_HNJ0`2mR9`0
1@2oQIL0_HZO0;f:W`2mRYl0_XJH0080_8bR0P2mQiX20;b>YP80_HRM00@0[2L00<UG;`3Kem@0fmOD
0P3Q/jP30>6k/0<0h;2U0`3Q]ZX01P3MZZ00gjfR0=n]XP3O[J80h;6V0=fXW`<0gZ^Q00@0gjjS0=bW
W`3LYil0g:NO0P3MZJ000`3N[:40fjJO0=^VW`020=bXW`<0fZJP0`3KYil30=VVX080fjJO00<0ejFS
0=VUX@3IYJ400P3JYZ001@3GYZ@0f:FR0=RUXP3HYJ80fJFQ0080eZJV0`3GYZ@00`3HYJ80eJNX0=JV
Y@020=JVY@<0e:NZ0P3EYZL01P3BZK00djR/0=>X[03CZ:`0e:NY0=6[/P<0dZV_00<0cZfi0<n/]@3?
[;D0103<[k`00`3>[KP0bK730<Va``020<^`_`030<FdbP37//H0ak;600@0`kG<0`2o]m820;VjfP80
^kWG0`2f^md30;>kh0<0/KcR0`2^_>@40:fmi@80[;gV1`2[_NL80:Zmi`80Z[gX0`00000K0:Vmj003
0000002Y_NP0ZKgX0340ZKgX00<000000?ooo`3oool0203oool01`3ogi`0B4RL0=ooo`3oool0oono
07@0B02Lgol0;P3oool001L0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00<0
00000?ooo`3oool00`3oool70:Vmj080Z;gX00<0Z;gY0=MhF@3HQW800P3HQW820=QmH@040=R7M@3H
PFP0f85X0=R1J080eW5=00@0f8A]0=MhF03GN5P0egQH0P3>FBL30;n5U@050<>6TP2oQIH0_hFF0;n5
UP32QI800`2nQYP00`31QI<0_XNJ0;j7VP020;n5U@80_HRL0P2oQIH00`2mRYl0_XJH0;j6V0020;j6
V0@0_HNJ0`2mR9`00`2oQIL0_HZO0;f:W`020;j6V080_8bR0P2mQiX01@2lSZH0_HRM0;f8W@2mR9d0
^i2Y00@0fmOD00H0hK>X0>6k/03Q^k00hK^`0>39`@3P/:D40>6fZP<0gjfR0P3P/JH01@3MZ9l0gZ^Q
0=j[X@3NZj40gjjS0080g:NO0`3MZJ000`3N[:40fjJO0=bXW`020=bXW`030=fZX03JYZ00fZJP00<0
fjNO00<0gJRO0=VVX03IYZ000P3KYYl30=VUX@80fZJP103HYJ820=VUX@060=JVYP3GYZ@0ejJT0=NV
Y03HYJ80eJNX0`3FYZD00`3GYJ<0e:NZ0=FVY`020=FVY`<0djR/0P3DYjT0103AZk80dZV_0=:Y[`3B
ZJl30<n/]@030=6Z/@3<[k`0c:nl0080cZfh103;/;l30<NbaP050<Va`P33]L`0`kG<0<>ec036/lP0
0`2o]m830;^ie`@0^;[K0`2e^mh30;6lhP<0[kcS102^_>D50:bmiP<0ZkgW1`2Z_NL3000000D0Z[gX
6P2Y_NP00`000000ZKgX0:Vmj00a0:Vmj0030000003oool0oooo00L0oooo00L0omnL04P0001d_ol0
oooo0?oOW018B9`0gooo02h0oooo000G0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`06
0?ooo`030000003oool0oooo00@0oooo2@2Y_NP40=R6LP80f7eQ00D0f8Me0=R1J03HPFP0f85X0=Ia
C@020=R4K@<0egQH00<0f7eQ0;n5U@2oQID00P2oQID01@33QY80_hFF0;n5UP2oQIH0`XFB00<0_XJH
00<0`HFC0;j7VP2nQiX00P2oQID0102mR9`0_hFF0;n5UP2oQIH50;j6V0@0_HNJ0P2mR9`20;n5U`80
_HZO0P2nQYP01@2lS:80_HNJ0;f7VP2mQiX0_8jV00<0_HRM0P2mRYl30=_Ge0<0hK^`0P3PbL400`3P
/:D0hKJZ0>6fZP020>6fZP030>:o]@3O[J80gjfR0080h;6V103NZj420=n^X`030=bWW`3MZJ00gJVP
0080gZbQ00D0fjJO0=bXW`3LZ9l0g:RO0=fZX0020=ZVX0<0fjNO00<0gJRO0=VVX03KYYl00P3KYYl0
0`3LYil0fJFQ0=VUX@020=ZVX0030=^VW`3HYJ80f:FR00<0fJFQ0`3GYZ@20=RUXP060=FWZ03FYZD0
eZJU0=JVY@3GYJ<0e:NZ0`3EYZL00`3GYZD0djR/0=>X[0020=BWZ@@0dZV_00<0djR[0<n/]@3AZ[40
0P3AZ[430<j]^0030=2[]03;/;l0bk2o0080cJjj00D0ak;60<Va`P39/L80bK720<>ec0020<Jcb0@0
`[K?0`2m^=@20;Rjf`80^[WI0P2e^mh40;:lh@<0/;cS0`2^_>D30:fmi@<0[;gV0`2[_NL40:Zmi`80
00001P2Z_NL30:Zmj1T0ZKgX00<000000:Vmj02Y_NP0<@2Y_NP00`000000oooo0?ooo`070?ooo`06
0?oOW018B9`0W7@00000000004P0W=oo;`3oool001L0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo00H0oooo0P0000060?ooo`T0ZKgX0`3HQW800`3HOF40f8Me0=R7M@030=R1J0<0f8A]0P3G
N5P20=R6L@@0_hFE00<0`hJB0;n5UP2oQIH00P32QI820;j6V080`HFC0P2nQiX20;n5U@050;f8W02o
QIH0_hFF0;n5UP32QI<0102nQYP30;f7VP030;n5U@2mR9`0_HRL0080_hFG0P2mRYl20;j6V0040;b<
XP2mQiX0_HNJ0;f7VP@0_HRM00@0_hFG0;f:W`2mRYl0_HZO0P2Gio/0103Q^k00h<W10>39`@3PbL44
0>6fZP80h[ne00D0gjfR0>2aYP3P/JH0h;6V0>6h[@020=j[X@<0gjjS0`3MZJ020=j/X@@0g:RO0P3M
ZZ000`3JYZ00fjNO0=^WW`020=fXW`060=VVX03KYYl0fjJO0=^VW`3LYil0fJFQ0`3JYZ000`3KYYl0
f:FR0=RUXP030=VUX@030=ZVX03GYZ@0ejJT0080f:FR0`3FYZD20=NUX`030=BWZP3EYZL0eJJW0080
ejJU00D0djR/0=BWZ@3DYjT0e:NY0=JVYP020=:Y[`80djR[00H0cjbe0=6Z/@3AZ[40dJZa0=>X[@3>
[KP20=2[]0040<^`_`3=[[X0cJjj0<f^^P@0bK720`36/lP00`38//@0`[K?0<:fc`020<Bdb`80_KSD
102j^MT40;Njg0<0];_O0P2`_><40:jli080[KgU102/_NH30:^miP<000002@2Z_NL60:Zmj1H0ZKgX
00<000000:Vmj02Y_NP0<@2Y_NP00`000000oooo0?ooo`060?ooo`030?oo_`1d07@0_ooo0380oooo
000G0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`030000003oool0oooo00H0
oooo202Y_NP30=R6LP030=QmH@3HQgD0f8Me00<0f85X00@0ehQh0=R4K@3HQ6d0egQH0`3HQW430;n5
U@80`hJB0P2oQIH20<:5TP80_XJH0P31QI<0102nQiX0_hFE0;n5U@2oQID40;n5UP050<:5T`2nQYP0
_XJH0;j6V031QI@00`2mQiX00`2oQID0_HRL0;f8W0020;n5U`040;f:W`2nQYP0_XJH0;j6V0@0_HNJ
00D0_hFE0;f8W@2mR9d0_HRM0;n5U`030;f:W`030;j6V02lS:<0h<W10080h<W10P3BhN830>6fZP80
h[ne00D0gjfR0>2aYP3P/JH0h;6V0>6h[@020=j[X@<0gjjS00<0hK>X0=fYX03MZJ000P3N[:400`3P
/:D0g:RO0=bXW`030=fZX0<0fjNO0P3MZ9l30=^VW`80g:NO00@0fJFQ0=ZVX03JYZ00fZJP0P3KYYl0
1P3HYJ80fJFQ0=VUX@3IYJ40fZJP0=NVY0<0f:FR00<0fJFP0=JVY@3FYZD00P3GYJ<30=FVY`80ejJU
00<0djR/0=BWZ@3DYjT00P3FYZH20=:Y[`80djR[0`3AZ[420=>X[@030<j]^03@Zk@0d:^d00@0cJjj
00<0cjbf0<Va`P39/L800P3<[kd01036/lP0b;;40<Rba038//@30<Bdb`@0`;OA0`2l^MH20;Njg080
^;[J0P2d^ml40;6lhP<0[kcS0P2]_ND30:bmiP<00000102[_NL80:Zmi`L0Z[gX5P2Y_NP00`000000
ZKgX0:Vmj00a0:Vmj0030000003oool0oooo00H0oooo00H0_g@007Boo`3oool0okmd0018W03Oool^
0?ooo`005`3oool01P3ooml0W4P007Boo`3oool0gia8001d_`L0oooo00<000000?ooo`3oool0203o
ool60:Vmj0<0f8Ib0`3HQgD20=R1J080ehQh0P3HQ6d40=R6L@<0_hFE0P33QY820;n5UP80`XFB0P2n
QYP20<65T`050;j7VP2oQID0_hFE0;n5U@33QY800`2oQIH01@32QI<0_XJH0;j6V02nQYP0`HFD0080
_HNJ0P2oQID01@2mR9`0_hFG0;n5U`2oQIL0_HZO00<0_XJH00D0`8FD0;f7VP2mQiX0_HNJ0;n5U@02
0;f8W@80_hFG0P2mRYl20;j6V080_8bS00<0_HNJ0=;QhP3BhN800P3BhN80103Q]ZX0h[ne0>:o]@3R
_kD30>2aYP<0hKR]00<0gZ^Q0=n^X`3O[Z<00P3Q/jP01@3MZJ00gZbQ0=j/X@3N[:40h;2U0080g:RO
0`3MZZ000`3O[J80fjNO0=^WW`020=fXW`030=j[X@3KYYl0fjJO0080g:NO0`3JYZ030=^VW`030=RU
XP3IYJ40fJFQ0080fZJP00H0ejJT0=RUXP3HYJ80f:FR0=VUX03FYZD30=NUX`030=VUX@3EYZL0ejJU
0080ejJU0`3DYjT20=JVYP050=:Y[`3CZ:/0djR[0=>XZ`3EYjP00P3AZ[420=>X[@<0d:^d00<0dZV`
0<f^^P3=[[X00P3?[;H40<b__@<0b;;40P3:/<000`34]</0a[?70<Jca`020<2gd@80`[G=0P2l^MH4
0;RjfP<0]K_N0P2a_>820;>kh080[kcS0P2^_>@3000000D0[;gV1@2[_NL:0:Zmi`80Z[gX5`2Y_NP0
0`000000ZKgX0:Vmj00`0:Vmj08000001`3oool01@3ooml0W4P00000000004P0W=oo02l0oooo000H
0?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`0:0?ooo`D0ZKgX0`3H
QW830=R7M@80f85X0P3GR7P20=R4K@040=J9NP3HQW40f8Ia0<F7T@<0_hFE0P33QY820;n5UP80`XFB
00@0_XJH0<65T`31QI<0`HFC102oQID01@33QY80_hFF0;n5UP2oQIH0`XFC00<0_XJH00<0`HFD0;f7
VP2mQiX00P2oQID0102mR9`0_hFG0;n5U`2oQIL40;j6V0050<25U02mQiX0_HNJ0;f7VP2oQID00P2m
R9d20;n5U`80_HZO0P2nQYP01@2lS:<0_HNJ0;f7VP2mQiX0_8jV0080d^7R103R_kD00`3OclT0h;6V
0>2aYP030>6h[@<0gjjS0P3Q/jP0103MZJ00gZbQ0=j/X@3N[:420>2`Y@060=bXW`3MZZ00gJZP0=fZ
X03O[J80fjNO0`3MZ9l00`3NZj40fjJO0=^VW`020=bWW`030=fYX03JYZ00fZJP00<0fjJO0`3IYJ42
0=ZVX0<0f:FR0P3IYJ001P3FYZD0ejFS0=NUX`3GYJ<0fJFQ0=FVY`<0ejJU00<0f:FR0=BWZ@3FYZH0
0P3FYZH30=>XZ`80eJNX00H0dJZa0=>X[@3CZ:d0djR]0=BWZP3@Zk@30=:Y/0<0cjbf00H0d:Zb0<b_
_@3<[kd0c:nm0<j]^@38//@30<Z``0<0a[?71032]Ld30;jgd`@0^kWH0P2e^mh40;>kh0040;2lhP00
0000000000000080[[cT0`2]_ND40:bmiPD0ZkgW2@2Z_NL30:Zmj1H0ZKgX00<000000:Vmj02Y_NP0
<@2Y_NP00`000000oooo0?ooo`0i0?ooo`008`3oool00`000000oooo0?ooo`0:0?ooo`D0ZKgX0P3H
QW801@3ERG/0f8Me0=R7M@3HQgD0f85X00<0ehQh0P3HQ6d0103FRGX0f8Ia0=R6L@35Qi430;n5U@80
`hJB00D0_hFF0<:5TP32QI80`XFB0;j6V0030<65T`050<F7T@2oQID0_hFE0;n5U@33QY800P2oQIH2
0<:5T`80_XJH0P31QI@20;f7VP80_hFE00D0_HRL0;n5U`2oQIL0_hFG0<:5T`030;j6V0030<25U02m
QiX0_HNJ0080_hFE0P2mR9d20;n5U`80_HZO0P2nQYP0102lS:<0_HNJ0;f7VP2mQiX40;f8W@80h[ne
0`3OclT01P3P/JH0hKR]0>6h[@3Q^:d0hL>j0=n^X`<0hK>X0`3N[:430>2`Y@030=bXW`3MZZ00gJZP
0080gjfR00<0fjNO0=fXW`3MZ9l00P3NZj401@3KYYl0g:NO0=bWW`3LYil0gJVP0080fZJP0`3KYYl0
0`3LZ9l0fJFQ0=VUX@020=ZVX0030=^WW`3HYJ80f:FR0080fJFP0`3GYJ<20=VUX@@0ejJU00<0f:FR
0=BWZ@3FYZH00P3FYZH00`3GYJ@0djR[0=>XZ`020=FWZ0<0djR]0P3DYjX01P3@Zk@0dZV`0=:Y/03B
ZK00djR/0<n/]P<0d:Zb00<0c:nm0<j]^@3>[KT00`3:/<020<b^_080a[?700<0bK730<:ec@32]Ld0
0P35]<T00`2n]m<0`KK@0<6fd0030;^if0@0]k[L0`0000020;2lhP@0[kcT0`2^_>D30:bmiP<0ZkgV
0`2[_NL90:Zmi`H0Z[gX4`2Y_NP00`000000ZKgX0:Vmj00a0:Vmj0030000003oool0oooo03P0oooo
000S0?ooo`8000003@3oool30:Vmj080f8Ib00@0eHUk0=R7M@3HQgD0f8Me103GR7P00`3HQ6d0eXUj
0=J9NP020=R6L@030<F7T@2oQID0_hFE00<0`hJB00D0_hFF0<:5TP32QI80`XFB0;j6V0030<65T`05
0<F7T@2oQID0_hFE0;n5U@33QY800P2oQIH20<:5T`80_XJH0P31QI@0102mQiX0_hFE0;n5U@2oQID4
0;n5U`030<:5T`2nQYP0_XJH0080`8FD0P2mQiX20;n5U@050;f8W@2oQIL0_hFG0;n5U`2mRYl00`2n
QYP40;f7VP050;n5U@2mR9d0_HRM0;f8W@2nQIL0103OclT30>6h[@80hL>j00D0gjjS0>6cZ03Q/jP0
hK>X0>:k/0020=j/X@<0h;2U0`3MZZ020=n]XP<0gJRO0P3NZj40103KYYl0g:NO0=bWW`3LYil20=fY
X0060=ZVX03KYYl0fjJO0=^VW`3LZ9l0fJFQ0`3JYZ000`3KYil0f:FR0=VUX0020=VUX0030=^VW`3G
YJ<0ejFS0080fJFQ00<0fZJP0=NVY@3GYZD00P3HYJ840=JVYP030=NUY03CZ:/0eJNX0080eJNX00<0
eZJU0=>X[@3CZ:d00P3DYjX30=:Y/080djR/00@0cjbf0=2Z/P3@Z[80d:Zb0`3>[KT00`3?ZkD0b[30
0<b^_0020<b^_0040<Jca`39/L<0bK730<Va``<0aKC91031]]030;fhe@<0000000<0^KWI0;Bkg`2d
^ml0102b_>430;2lh`80[[cU102]_ND20:^miPL0ZkgW1P2Z_NL60:Zmj1<0ZKgX00<000000:Vmj02Y
_NP0<02Y_NP00`000000oooo0?ooo`0h0?ooo`008`3oool00`000000oooo0?ooo`0=0?ooo`80ZKgX
00<0f8Ib0=F9N`3ERG/00`3HQgD01@3DR7d0ehQh0=N8N03GR7P0f8A]0080eXUj0P3HQW400`35Qi40
_hFE0;n5U@030<>6TP040;n5UP32QI80`XFB0<:5TP@0`HFC00<0aHNA0;n5U@2oQID00P33QY820;n5
UP80`XFC0P2nQYP20<65U0050;f7VP2oQID0_hFE0;n5U@33QY800`2oQIL00`32QI<0_XJH0;j6V002
0<25U080_HNJ0P2oQID01@2mR9d0_hFG0;n5U`2oQIL0_HZO00<0_XJH00D0`8FD0;f7VP2mQiX0_HNJ
0;n5U@020;f8W@80_XFG00<0_8ZO0;oYlP2ojO800P2ojO80103Q^:d0hL>j0>73^P3Q`kX30>6cZ0<0
h[^`00H0gZbQ0>2`Y@3P/:D0h;2U0>6fZP3MZZ030=n]XP030>2aYP3MZ9l0gJRO0080gZ^Q0`3LYil3
0=fYX0<0fjJO0P3LZ9l00`3IYJ40fZJP0=ZVX0020=^WW`060=RUXP3IYJ00fJFP0=VUX03KYYl0ejFS
0`3IYJ400`3JYZ00ejJU0=NVY@020=RUXP030=VUX@3FYZH0eZJV0080ejFT103EYjP00`3FYZD0djR]
0=BWZP020=BWZP030=FVY`3BZK00dZV`0080djR/103@Z[80103BZJh0cZfi0<n[]@3?ZkD40<b^_0<0
bK730P3;[kh00`35]<T0ak;50<Nba@020<6fd080`kC<0P000000102o]m80^KWI0;Vif@2i^MT30;Jj
g@@0/k_O0P2`_><40:jli0<0[KgU0P2/_NH40:^miP80ZkgW2P2Z_NL20:Zmj1<0ZKgX00<000000:Vm
j02Y_NP0<@2Y_NP00`000000oooo0?ooo`0g0?ooo`008`3oool00`000000oooo0?ooo`0=0?ooo`80
ZKgX00<0f8Ib0=F9N`3ERG/00`3HQgD01@3DR7d0ehQh0=N8N03GR7P0f8A]0080eXUj00<0f8Ia0<F7
T@35Qi400P2oQID30<>6TP040;n5UP32QI80`XFB0<:5TP<0`HFC0P35Qi420;n5U@80`hJB0P2oQIH2
0<:5T`040;j6V031QI@0`HFD0<65U0@0_hFE00D0`hJB0;n5U`2oQIL0_hFG0<:5T`020;j6V080`8FD
00D0_HNJ0;n5U@2oQID0_hFE0;f8W@030;n5U`@0_XJH00D0`8FD0;f7VP2mQiX0_HNJ0;n5U@020;f8
W@80_XFG0P2lRYl00`2nQYT0_nWb0;oYlP040>73^P030=_He03Q/jP0hK>X00<0h[^`0`3P/:D20>6f
ZP060=fZX03O[J80gjfR0=n]XP3P/JH0gJRO0`3NZj400`3O[Z<0g:NO0=bWW`030=fYX0030=j/X@3K
YYl0fjJO0080g:RO0`3JYZ020=^WW`@0fJFP00<0fjJO0=NUX`3IYJ400P3IYJ420=ZVX0040=NVY@3H
YJ80f:FR0=VUX@80eZJV0P3GYJ@00`3HYJ80eJNX0=FWZ0020=JVY@@0e:NZ00<0eJJW0=:Y/03CZ:`0
0P3CZ:`00`3DYjT0d:Zb0=2Z/P020=:Y[P040<j]^@3?ZkD0cj^e0=6Y/@<0c:jl00<0cZbg0<Va``3;
[kh00P3;[kh30<Nba@040<>dc00000000000000000<0_kOB102k^=L30;Rjf`<0/k_O0`2a_>840:nl
h`80[KgU0`2/_NH30:^miP<0ZkgW2P2Z_NL50:Zmj100ZKgX00<000000:Vmj02Y_NP0<@2Y_NP00`00
0000oooo0?ooo`0f0?ooo`008`3oool3000000l0oooo0`3ERG/20=R7M@80e8Qm0`3GR7P30=J9NP03
0=R6L@35Qi40aHNA0080_hFE0`33QY840<:5TP<0`HFC0P35Qi420;n5U@80`hJB00D0_hFF0<:5T`32
QI<0`XFC0;j6V0030<65U0050<B7T@2oQID0_hFE0;n5U@33QY800P2oQIL20<:5T`80_XJH0P30QI@0
102mQiX0_hFE0;n5U@2oQID40;n5U`050<:5T`2nQYP0_XJH0;j6V030QI@00P2mQiX20;n5U@80_HRM
0P2nQIL01P2lRYl0_XJI0;j6V@2nQYT0_8^S0;f7V`80hL>j0P3Kf=@00`3Q/jP0h[^`0>:k/0020>:k
/0030>79`@3P/:D0h;2U0080hKJZ0`3O[J820>2aYP050=fXW`3NZj40gZ^Q0=j[X@3O[Z<00P3LYil3
0=fYX0030=j/X@3KYYl0g:RO0080g:RO00<0gJZP0=ZVX03JYZ000P3KYil00`3MZ9l0fJFP0=VUX002
0=^VW`<0fJFQ0`3JYZ030=RUXP80fJFQ00@0eZJV0=NUY03GYJ@0f:FR0P3EYjP20=JVY@030=NUX`3D
YjX0e:NZ0080eJJW103CZ:`00`3DYjT0d:Zb0=:Y[P020=:Y[P80cj^e0`3AZK400`3<[[`0cZbg0<j/
]`040<^__P040<f]^P000000000000000080`kC<0P36/lP00`2o]m80`[G>0<:ecP020;^he`80_[OC
0P2h^]/40;FkgP<0/[_P0`2__><30:jli0H0[;gV0`2[_NL<0:Zmi`80Z[gX4@2Y_NP00`000000ZKgX
0:Vmj00`0:Vmj0030000003oool0oooo03H0oooo000R0?ooo`8000004@3oool30=F9N`80f8Me0P3D
R7d30=N8N0<0eXUj00@0f8Ia0<F7T@35Qi40_hFE1033QY840<:5TP<0`HFC0P35Qi420;n5U@80`hJB
00@0_hFF0<:5T`32QI<0`XFC1031QI@01@34Qi40_hFE0;n5U@2oQID0`hJB0080_hFG0P32QI<01@2n
QYP0`8FD0<25U030QI@0_HNJ00<0_hFE00D0`hJB0;n5U`2oQIL0_hFG0<:5T`020;j6V080`8FD0P2m
QiX20;n5U@050;f8W@2nQIL0_XFG0;j5U`2lRYl00`2nQYT30;f7V`<0fmSD103R^k020>79`@050>2`
Y@3Q]ZX0hKJZ0>6fZP3R_k@00P3O[J820>2aYP@0gZ^Q0P3O[Z<00`3LYil0gJVP0=fYX0020=j/X@06
0=^VW`3LZ9l0g:RO0=bXW`3MZZ00fZJP0`3KYil00`3MZ9l0fJFP0=VUX0020=^VW`030=bWW`3IYJ40
fJFQ00<0fZJP00<0fjJO0=RUXP3IYJ400P3IYJ430=NUY080f:FR00@0eJNX0=JVY@3FYZD0ejFS0P3D
YjX20=FVY`030=JUY03CZ:`0djR/0080e:NY103BZJh00`3CYj/0cj^e0=6Y/@020=6Y/@<0cZbg00<0
d:Zc0<^__P0000000P0000001037//D0bK310<V``@39/<430<Jcb0@0`[G>0`2n]m<30;Zif080]K_N
0P2g^]`20;:kh0@0/;cR0`2__>@30:fmi@<0[;gV1P2[_NL80:Zmi`L0Z[gX3@2Y_NP00`000000ZKgX
0:Vmj00`0:Vmj0030000003oool0oooo03D0oooo000R0?ooo`030000003oool0oooo0100oooo0`3E
RG/20=R7M@80e8Qm0`3GR7P30=J9NP040=R6L@35Qi40aHNA0;n5U@@0`hJB1032QI830<65T`80aHNA
0P2oQID20<>6TP040;n5UP32QI<0`XFC0<:5T`@0`HFD00<0a8NA0;n5U@2oQID00P33QY820;n5U`80
`XFC00@0_XJH0<25U030QI@0`8FD102oQID01@33QY80_hFG0;n5U`2oQIL0`XFC0080_XJH0P30QI@2
0;f7VP80_hFE00@0_HRM0;j5U`2nQIL0_XFG102nQYT01030QI@0_HNK0;f7V`2mQi/309CWn`80h[^`
0`3QbL430>6fZP80h[nd00D0gjfR0>2aYP3P/JH0h;6V0>:h[@020=j[X@<0gjjS0`3MZJ020=j/X@<0
g:RO0P3MZZ00103JYZ00fjNO0=^WW`3KYil20=fXW`040=VUX03KYYl0fjJO0=bWW`80fJFQ0`3JYZ00
0`3KYYl0f:FR0=VUX@020=VUX@030=ZVX03GYJ@0f:FR0080f:FR0`3FYZD20=NUX`030=BWZP3EYZL0
eJJW0080eZFT00@0djR/0=BWZ@3DYjT0eZJV0P3BZJh20=>WZ`@0dJVa00<0dZR]0<j/]`0000000P00
00030<f]^P<0bK310P3;[[`00`36/lP0b;330<R```020<:ecP80a;?:00<0_[OC0<2fd030]]000`2j
^MP30;Njg0@0];_N0`2b^n420:nli0@0[KcU0P2/_NH40:^miP80ZkgW2@2Z_NL60:Zmj0d0ZKgX00<0
00000:Vmj02Y_NP0<02Y_NP00`000000oooo0?ooo`0e0?ooo`00503oool00`3OW4P0000000000003
0000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0403oool30=F9N`040=R7M@3DR7d0
e8Qm0=B8O@<0ehQh0`3FRGX30<F7T@030;n5U@33QY80`hJB0080`hJB0`32QI800`36R940`HFC0<65
T`030<F7T@050;n5U@33QY80`hJB0<>6TP2oQIH00`32QI<30<65U080a8NA0P2oQID20<>6TP80_hFG
0P32QI<01@2nQYP0`8FD0<25U030QI@0a8NA00<0_hFE00<0`hJB0;n5U`2oQIL00P32QI<20;j6V080
`8FD00D0_HNJ0;n5U@2oQID0_hFE0;f8W@030;j5U`050<65T`2nQYT0_XJI0;j6V@30QI@00`2mQi/0
102oQID0_8RM0;b8W@2nQIL30>79`@80d^;S0P3Q]ZX20>:o]0050=n]XP3P/JH0h;6V0>2aYP3R^:d0
0P3NZj430=n^X`030>6cZ03MZJ00gJVP0080gZbQ00<0h;2T0=bXW`3LZ9l00P3MZZ030=^WW`<0gJRO
0`3KYYl20=bWW`030=VUX@3JYZ00fZJP0080fjJO00H0f:FR0=VUX@3IYJ40fJFQ0=ZVX03GYJ@30=RU
XP030=VUX03FYZD0ejFS0080ejFS0P3EYZL30=JUY0<0e:NY0P3FYZH0103BZJh0djN[0=>WZ`3DYZP2
0=6Y/@<000000`3@Z[<01@3AZ:l0cJfj0<f]^P3>ZkD0bK3100<0bjjl0`38/<<40<BcbP<0`;K@102l
]mD30;Vif@80];_N0P2f^]`20;:kh@@0/;cS0P2]_>D30:bmi@@0[;gV1@2[_NL60:Zmi`H0Z[gX3@2Y
_NP00`000000ZKgX0:Vmj00`0:Vmj0030000003oool0oooo03@0oooo000D0?ooo`030?oOW0180000
M;oo00/0oooo00<000000?ooo`3oool0403oool30=F9N`040=R7M@3DR7d0e8Qm0=B8O@80ehQh00@0
dhMn0=J9NP3FRGX0eXUj0`35Qi440<>6TP050<V:T@32QI80`XFB0<:5TP36R9400P31QI<30<F7T@04
0;n5U@33QY80`hJB0<>6TP@0`XFC0`31QI@20<B7T@80_hFE0P33QY801@2oQIL0`XFC0<:5T`32QI<0
_XJH00<0`8FD00D0a8NA0;n5U@2oQID0_hFE0<>6TP020;n5U`80`XFC0P2nQYP20<25U0040;f7VP2o
QID0_hFE0;n5U@@0_XFG00D0`HFC0;j6V@2nQYT0_XJI0<25U0020;f7V`80_hFE00@0_8RM0;j5U`2n
QIL0_8VP103Bh^<0103Q]ZX0h[nd0>:o]03R_k@30>2aYP<0h[R]00<0gZ^Q0=n^X`3O[Z<00P3Q/jP0
1@3MZJ00gZbQ0=j/X@3N[:40h;2T0080g:RO0P3MZZ000`3O[J80fjNO0=^WW`030=fXW`030=j[X@3K
YYl0g:NO0080g:NO0`3JYZ020=^VW`<0fJFQ0P3JYZ001P3GYJ@0f:FR0=RUXP3HYJ80fJFP0=JVY@<0
ejFS00<0f:FQ0=FVY`3FYJ@00P3FYJ@00`3HYJ80e:NY0=JVYP020=JVYP<0djN[0`0000020=:X[@<0
d:Zc0P3AZ:l00`3=[KX0cZ^e0<j[]@040<^^_0040<f[]`38/<<0b;330<Z^_P80a;?:0P36/LD00`30
]]00`k?;0<>cb`020;bge@80_kKA0P2i^MT40;Jjg0<0/k_O102a^n420:jli0<0[KcU0`2/_NH30:^m
iP<0ZkgW2@2Z_NL30:Zmj0d0ZKgX00<000000:Vmj02Y_NP0<02Y_NP00`000000oooo0?ooo`0c0?oo
o`005@3oool00`3ogi`0B00007Boo`0:0?ooo`8000004@3oool30=F9N`@0e8Qm0P3GR7P0103CQgh0
eXUj0=J9NP3FRGX30<F7T@@0`hJB00D0bHZA0<:5TP32QI80`XFB0<J8T@020<65T`<0aHNA00@0_hFE
0<>6TP33QY80`hJB1032QI<30<65U080a8NA0P2oQID20<>6TP040;n5U`32QI<0`XFC0<:5T`@0`8FD
00<0a8NA0;n5U@2oQID00P33QY820;n5U`80`XFC00D0_XJH0<25U030QI@0`8FD0;f7VP030;n5U@05
0<>6TP2nQIL0_XFG0;j5U`31QI<00P2nQYT20<25U080_HNK0P2oQID0102lR9d0_XFG0;j5U`2lRJ02
0;f6V@80d^;S103R_k@00`3Od<T0h;6V0>2aYP030>:h[@<0gjjS0P3Q/jP00`3MZJ00gZbQ0=j/X@02
0>2`Y0050=bXW`3MZZ00gJZP0=fZX03O[J800P3KYil30=fXW`030=j[X@3KYYl0g:NO0080g:NO00<0
gJVP0=ZVX03JYZ000P3KYYl00`3LZ9l0fJFQ0=VUX@020=ZVX0<0f:FR0P3IYJ001P3FYZD0ejFS0=NU
X`3GYJ<0f:FQ0=FVY`<0eZFT00<0f:FR0=BWZ@3FYZH00P3FYZH0103GYJ<000000000003DYZP40=:X
[@030=>VZ@3@Z[<0d:Zc0080dJR_0`3>ZkD00`3@Z;40bjjl0<^^_0020<f[]`040<R```3:[[h0bZjn
0<Z^_P<0a[750`33/l/40;nfd@<0^kOF102h^MX00`2c^ml0]K[M0;Fjg@030;6kh@<0[kcS0P2]_>D7
0:bmiPH0ZkgW1P2Z_NL60:Zmj0X0ZKgX00<000000:Vmj02Y_NP0;`2Y_NP00`000000oooo0?ooo`0c
0?ooo`005P3oool00`3ookl0M00004RLg`090?ooo`030000003oool0oooo0100oooo0`3ERG/40=B8
O@80ehQh00@0dhMn0=J9NP3FRGX0eXUj0`35Qi440<>6TP050<V:T@32QI80`XFB0<:5TP36R9400P31
QI<30<F7T@040;n5U@33QY80`hJB0<>6TP<0`XFC00@0aXRA0<65U031QI@0`HFD0P34Qi420;n5U@80
`hJB00D0_hFG0<:5T`32QI<0`XFC0<J8T@030<25U0030<B7T@2oQID0_hFE0080`hJB0P2oQIL20<:5
T`040;j6V030QI@0`8FD0<25U0@0_hFE00D0`hJB0;j5U`2nQIL0_XFG0<65T`020;j6V@80`8FD0P2m
Qi/20;n5U@030;b8W@2nQIL0_XFG00@0_HJI00@0`8FD03o1h`3R_k@0h[nd0`3Od<T01P3P/JH0h[R]
0>:h[@3R^:d0h/Bj0=n^X`<0hK>X0`3N[:420>2`Y0040=bXW`3MZZ00gJZP0=fZX080gjfR00<0fjNO
0=fXW`3MZ9l00P3NZj401P3KYYl0g:NO0=bWW`3LYil0gJVP0=ZVX0<0fjJO00<0g:RO0=VUX@3IYJ40
0P3JYZ000`3KYil0f:FR0=RUXP020=VUX0<0ejFS0P3HYJ430=JUY080f:FR00<0e:NY0=JVYP000000
0P000000103CYj/0e:JX0=BVZ03FYJD30=:X[@030=>VZ@3@Z[<0dJR_0080dJR_00<0dZJ[0<j[]@3@
Z;400P3@Z;400`3;[[`0cJ^g0<f[]`030<Z^_P80c:^i00@0a[750<R^`038[/00`k?;0P35/LH20;nf
d@80`K?=00<0^kOF0;fedP2m]M800`2h^MX30;Fjg@@0/[_O0P2__><40:jli0<0[KcU0P2/_NH40:^m
iP80ZkgW2@2Z_NL40:Zmj0T0ZKgX00<000000:Vmj02Y_NP0<02Y_NP00`000000oooo0?ooo`0b0?oo
o`005`3oool00`3ooml0W4P004RLg`070?ooo`030000003oool0oooo0140oooo0`3ERG/40=B8O@03
0=N8N03CQgh0dhMn0080eXUj1035Qi440<>6TP030<V:T@32QI80`XFB0080aXRA00<0`HFC0<F7T@35
Qi400P35Qi440<>6TP<0`XFC00<0aXRA0<65U031QI@00`34Qi401@2oQID0`hJB0<>6TP33QY80_hFG
00<0`XFC00D0aXRA0<25U030QI@0`8FD0<B7T@020;n5U@80`hJB00D0_hFG0<:5T`32QI<0`XFC0;j6
V0030<25U0050<B7T@2oQID0_hFE0;n5U@33QY800P2nQIL20<65T`80_XJI0P30QI@01@2mQi/0_hFE
0;n5U@2oQID0_8RM0080_XFG00D0`HFC0;f6V@2mQYT0_HJI0<25U0020;f7V`@0gm390`3R^:d20>;4
^P060=n^X`3Q/jP0hK>X0>6cZ03R_;00gZbQ0`3P/:@30=fZX0<0gjfR0`3MZ9l20=j[X@030=^VW`3L
Yil0g:NO0080gJVP00<0fZJP0=^VW`3KYYl00P3LZ9l01P3IYJ40fZJP0=ZVX03JYZ00fjNO0=RUXP<0
fJFP00<0fZJO0=NUX`3GYJ<00P3HYJ40103IYJ00eZFT0=JUY03HYJ83000000040=JVYP3GYJ<0ejFS
0=>WZ`80e:JX00<0eZFU0=:X[@3BZ:d00P3CYZT30=6X[`80dZJ[00@0cZ^e0=2X/@3@Z;40d:Ra0`3=
ZkL00`3>Z;80bZjn0<b[^@020<b[^@<0b:k01035/LH30<6cc@@0_KGB0`2j]mL30;NhfP<0/[_O0`2`
^n840:nlh`80[KcU0`2/_>H30:^miP<0ZkgW2@2Z_NL60:Zmj0L0ZKgX00<000000:Vmj02Y_NP0<02Y
_NP00`000000oooo0?ooo`0a0?ooo`00603oool00`3ookl0M01809cOo`060?ooo`030000003oool0
oooo0140oooo0`3ERG/40=B8O@030=N8N03CQgh0dhMn0080eXUj0`35Qi40103;SI40`hJB0<>6TP33
QY820<V:T@80`XFB0P36R9400`31QI<0aHNA0<F7T@020<F7T@@0`hJB0`32QI<00`36R940`HFD0<65
U0030<B7T@040;n5U@33QY80`hJB0<>6TP@0`XFC00<0aXRA0<25U030QI@00P34Qi420;n5U@80`hJB
00D0_hFG0<:5T`32QI<0`XFC0;j6V0030<25U0050<B7T@2oQID0_hFE0;n5U@33QY800P2nQIL20<65
T`80_XJI0P30QI@0102mQi/0_hFE0;n5U@2oQID30;j5U`050<65T`2mQYT0_HJI0;f6V@30QI@00P2m
Qi/00`2oQIH0_n[b0;oZlP020;oZlP040>:h[@3Ra;X0h/Bj0>;4^P@0hK>X00<0h[b`0=j/X@3P/:@0
0P3P/:@00`3Q]ZX0gJZP0=fZX0030=n]XP030>6aYP3MZ9l0gJRO0080gZ^Q0`3LYil20=fYX0<0fjJO
0P3LZ9l00`3IYJ40fZJP0=ZVX0020=^WW`060=RUXP3IYJ00fJFP0=VUX03JYYl0ejFS0`3HYJ401P3I
YJ000000000000000000f:FR0=VUX@80eZJV0P3GYJ<20=BVZ0<0eZFU00@0dZR]0=>VZ@3CYZT0e:FV
0P3AZ:l20=:VZ`@0d:Ra00@0dJJ]0<f[]`3>Z;80cZRb103<ZkT0103=Z;@0b:k00<R^`03:ZkX20<Fa
aP80ajk100<0`K?=0<>`a`33/<L00P2m]M820<2cc@030;Zge`2l]M80_;GB0080]kSJ102d^]d30;:j
h0<0[kcS0`2^_>@30:fli@H0ZkgV302Z_NL20:Zmj0P0ZKgX00<000000:Vmj02Y_NP0;`2Y_NP20000
0380oooo000D0?ooo`030?noM000M;l0oooo0080oooo00<0_g@007Boo`3oool01@3oool200000180
oooo0P3ERG/00`3?QGl0e8Qm0=B8O@020=B8O@030=N8N03CQgh0dhMn0080eXUj0`35Qi40103;SI40
`hJB0<>6TP33QY820<V:T@80`XFB0P36R9400`31QI<0aHNA0<F7T@020<F7T@<0`hJB00D0bHZA0<:5
T`32QI<0`XFC0<J8T@020<65U0<0a8NA00@0_hFE0<>6TP33QY80`hJB1032QI<00`36R940`8FD0<25
U0020<B7T@80_hFE0P33QY80102oQIL0`XFC0<:5T`32QI<40<25U0030<B7T@2oQID0_hFE0080`hJB
0P2nQIL20<65T`050;j6V@30QI@0`8FD0<25U02mQi/00`2oQID30;j5U`030<65T`2mQYT0_HJI0080
`8FD0P2mQi/20;n5UP030;b8WP2oj_80_n[b00@0h/Bj00<0fmWD0>6cZ03Q/jP00P3R_;040>2`Y080
hKJZ00H0gJZP0=n]XP3O[J80gjfR0>6aYP3MZ9l30=j[X@030=n^X`3LYil0g:NO0080gJVP00<0gZbQ
0=^VW`3KYYl00P3LZ9l30=ZVX080fjNO103IYJ000`3JYYl0ejFS0=RUX@03000000060=JUY03HYJ80
f:FR0=RUXP3IYJ40eZJV0`3GYJ<00`3HY:40e:JX0=JUY@020=JUY@<0djJY00<0e:FV0=6X[`3BYZ/0
0P3BYZ/00`3CY:L0d:Ra0=2X/@020=6V[@<0cZRb00<0cjJ^0<b[^@3<ZkT00P3=Z;@00`38[/00bZ^j
0<Z[^P040<N^`@<0`k371030/ld30;bedP@0^KOG0`2f^=X20;:jh0@0/;_R0`2_^n<30:fli@<0[;cV
0P2[_NH40:^mi`T0Z[gW1P2Z_NP30:Vmj0030000002Y_NP0ZKgX0300ZKgX00<000000?ooo`3oool0
<03oool001@0oooo00L0oono07@0B02Lgol0oooo0?oOW01804P0W=oo00H0oooo00<000000?ooo`3o
ool04@3oool20=F9N`030<n5O`3DR7d0e8Qm0080e8Qm0`3CQgh20=J9NP<0aHNA00@0bhfA0<>6TP33
QY80`hJB0P39RY420<:5TP80aXRA00<0`HFC0<F7T@35Qi400P35Qi430<>6TP030<V:T@32QI<0`XFC
0080aXRA0P31QI@30<B7T@040;n5U@33QY80`hJB0<>6TP<0`XFC0P36R9420<25U080a8NA00D0_hFE
0<>6TP33QY80`hJB0;n5U`030<:5T`050<J8T@30QI@0`8FD0<25U034Qi400P2oQID20<>6TP80_XFG
0P31QI<0102nQYT0`8FD0<25U030QI@40;n5U@<0_XFG00<0`HFC0;f6V@2mQYT00P30QI@01@2mQi/0
_hFF0;n5UP2oQIH0_8RN00<0_XFG0P3Ra;X30=_Ie0040>6cZ03R_;00h[b`0>79`@80h;2T0`3Q]ZX3
0=n]XP80hK6V00H0gJRO0=j[X@3NZj40gZ^Q0=n^X`3LYil30=fYX0030=j/X@3KYYl0g:RO0080g:RO
00<0gJZP0=ZVX03JYZ000P3KYil0103LZ9l0fJFP0=VUX03JYYl3000000030=RUX@3IYJ00fJFP00@0
f:FR00<0fJFQ0=JVYP3GYJ<00P3GYJ<00`3HY:40e:JX0=JUY@020=JUY@040=NTXP3CYZT0e:FV0=BU
YP@0dZJ[00<0djBW0=2X/@3AYZd00P3AYZd01@3BY:P0cZRb0<nV[P3?YZh0c:^i00<0cJRd0`3:ZkX0
1P3;Yk@0ajk10<N^`@37[/40b:Zk0<>`a`80aJc10P30/ld20<:_a`030;bedP2o/Ld0_k7=0080^KOG
0P2l/m820;JhfP<0];WM102b^]l20:nkh`@0[[cT0P2/_>H30:^liP@0ZkgV2`2Z_NL30:Zmj0@0ZKgX
00<000000:Vmj02Y_NP0<02Y_NP00`000000oooo0?ooo`0_0?ooo`005@3oool01@3ogi`0B0000000
00000000M;oo00L0oooo00<000000?ooo`3oool04@3oool20=F9N`030<n5O`3DR7d0e8Qm0080e8Qm
0`3CQgh20=J9NP<0aHNA00@0bhfA0<>6TP33QY80`hJB0P39RY401032QI80aXRA0<J8T@36R9450<F7
T@<0`hJB00<0bHZA0<:5T`32QI<00P36R9400`31QI@0a8NA0<B7T@020<B7T@@0`hJB0`32QI<20<J8
T@80`8FD0P34Qi40102oQID0`hJB0<>6TP33QY840<:5T`050<J8T@30QI@0`8FD0<25U034Qi400P2o
QID20<>6TP050;j5U`31QI<0`HFC0<65T`2nQYT00`30QI@40;n5U@80_XFG0P31QI<20;f6V@80`8FD
00D0_HNK0;n5UP2oQIH0_hFF0;b8WP030;j5U`030<65T`3KfM@0fmWD0080fmWD0P3R_;030>79`@05
0>2`Y03Q]ZX0hKJZ0>6fZP3R_k@00P3O[J820>6aYP<0gZ^Q0P3O[Z<00`3LYil0gJVP0=fYX0020=j/
X@060=^VW`3LZ9l0g:RO0=bXW`3MZZ00fZJP0`3KYil01P3LZ9l00000000000000000fZJO0=bWW`80
f:FQ0P3IYJ000`3KYYl0f:FR0=RUXP020=VUX@<0ejFS0P3HY:430=JUY@80ejBR00@0djJY0=BUYP3D
YJH0eJ>S0P3BYZ/20=>TY`<0dJJ]0P3BY:P00`3>Z;80cjJ^0<nV[P040<fX]0030<jU[P3:ZkX0bjNd
0080bjNd00<0ajk10<RZ^`38Z[/00`35[<440<:_a`<0_k7=102l/m830;VeeP<0][OI0`2b^]l30;2j
h@@0[k_S0P2]_>D30:bli@<0ZkgV0`2[_NL90:Zmi`<0Z[gX102Y_NP00`000000ZKgX0:Vmj00_0:Vm
j0030000003oool0oooo02l0oooo000Q0?ooo`030000003oool0oooo0140oooo0P3ERG/00`3?QGl0
e8Qm0=B8O@020=B8O@<0dhMn00@0eXUj0<j@T@35Qi40aHNA0P3;SI420<>6TP<0bHZA00@0`XFB0<J8
T@36R940aXRA1035Qi401@3;SI40`hJB0<>6TP33QY80bHZA0080`XFC0P36R9400`31QI@0a8NA0<B7
T@020<B7T@@0`hJB0`32QI<20<J8T@80`8FD0P34Qi40102oQID0`hJB0<>6TP33QY840<:5T`030<J8
T@30QI@0`8FD0080a8NA0P2oQID20<>6TP040;j5U`31QI<0`HFC0<65T`@0`8FD0`2oQID00`33QY80
_XFG0;j5U`020<65T`80_HJI0P30QI@0102mQi/0_hFF0;n5UP2oQIH40;j5U`030<65T`2mQIT0T^Oj
00<0T^Oj00@0h[b`0>79`@3QbL40hLW10`3Q]ZX20>:o]0050=n]XP3Q/JH0hK6V0>6aYP3R^:d00P3N
Zj420=n^X`<0gJVP0P3N[:440=bXW`040=fZX03JYZ00fjNO0=^WW`80000000D0g:RO0=VUX03JYYl0
fZJO0=bWW`020=RUX@80fJFP00<0fjJO0=RUXP3HYJ800P3IYJ400`3JYIl0ejFS0=NUX`020=RTX@03
0=VTX03FYJD0eZFU0080ejBR0`3DYJH20=FSX`040=:VZ`3CY:L0djBW0=BSY080dJJ]0P3BY:P30<nV
[P030=2SZ@3=Z;@0cJRd0080cZF^103;Yk@30<RZ^`040<VU]035[<40ajRj0<NX^P80`Zo70P34Z/00
0`2o/Ld0`Jg60<6]aP020;bcdP80_Zo;00<0^KGF0;^bd02k/]000`2f]mT30;Bhg0<0/[WN0`2_^n<3
0:jki080[;cU1`2[_>H<0:Zmi`@0ZKgX00<000000:Vmj02Y_NP0;`2Y_NP00`000000oooo0?ooo`0^
0?ooo`00803oool00`000000oooo0000000B0?ooo`030=F9N`3?QGl0chEo00<0e8Qm00H0c89o0=>7
OP3CQgh0dhMn0=J9NP3>T9420<F7T@80bhfA0P33QY830<V:T@040<:5TP36R940aXRA0<J8T@@0aHNA
00D0bhfA0<>6TP33QY80`hJB0<V:T@020<:5T`80aXRA00<0`HFD0<B7T@34Qi400P34Qi430<>6TP04
0<V:T@32QI<0`XFC0<:5T`80aXRA00D0`8FD0<B7T@34Qi40a8NA0;n5U@030<>6TP@0`XFC00<0aXRA
0<25U030QI@00P34Qi420;n5U@80`hJB00@0_XFG0<65T`31QI<0`HFC1030QI@30;n5U@030<>6TP2n
QIL0_XFG0080`HFC00@0_HJI0<25U030QI@0`8FD102oQIH01@33QY80_XFG0;j5U`2nQIL0`HFC0080
_HFI0P30QID0102lQY`0hLW10>79`@3QbL420=;Sh`80hKJZ0P3R_k@00`3O[J80hK6V0>6aYP020>:h
[@050=j[X@3O[Z<0gjjS0=n^X`3Q/jP00P3MZJ020=j/X@030>2`Y03LZ9l0g:RO0080gJZP0`000003
0=bXW`<0fZJO0P3LYil00`3HYJ40fJFP0=VUX0020=^VW`050=RUXP3IYJ40fJFQ0=ZUW`3GYJ<00`3H
Y:400`3IY:00eZFU0=NTXP020=NTXP030=NSX03DYJH0eJ>S0080eJ>S0`3CY:L00`3DXj@0dJJ]0=:T
Z0020=:TZ0030=:QY@3?YZh0cjJ^0080d:>Y00@0cJRd0<jU[P3>YJh0cZ6Y0P3;Yk@20<bS[P030<RZ
^`39YK@0bJFd00@0ajRj0`34Z/040<6]aP<0_Zo;0`2k/]040;Vde0<0][GH0P2b^Mh40;2jh@<0[k[R
0`2]_>D30:bli@80ZkcV102[_NL80:Zmi`<0Z[gX00<0ZKgX0000002Y_NP0<@2Y_NP00`000000oooo
0?ooo`0]0?ooo`00803oool2000001<0oooo00<0eHUk0<n5O`3?QGl00`3DR7d01P3<PWl0dhMn0=>7
OP3CQgh0eXUj0<j@T@80aHNA0P3;SI420<>6TP<0bHZA00@0`XFB0<J8T@36R940aXRA1035Qi400`3;
SI40`hJB0<>6TP020<V:T@80`XFC0P36R9400`31QI@0a8NA0<B7T@020<B7T@<0`hJB00<0bHZA0<:5
T`32QI<00`36R9401@30QI@0a8NA0<B7T@34Qi40_hFE00<0`hJB0`32QI<20<J8T@80`8FD0P34Qi40
1@2oQID0`hJB0<>6TP33QY80_XFG00<0`HFC0`30QI@01@34Qi80_hFE0;n5U@2oQID0`hJB0080_XFG
0P31QI<01@2mQYT0`8FD0<25U030QI@0a8NB00<0_hFF00<0`hJB0;j5U`2nQIL00P31QI<20;f5V@80
`8FE00<0_8JL0;j5UP3Bhn<00`3Bhn<0103Q]ZX0h[nd0>:o]03R_k@30>6aYP80h[R]00H0gZ^Q0=n^
X`3O[Z<0gjjS0>6cZ03MZJ030=j/X@030>2`Y03LZ9l000000080000000<0gjfR0=^WW`3KYil00`3L
Z9l00`3NZj40fZJO0=bWW`020=bWW`80fJFP0`3KYYl30=VUX@030=ZUW`3GYJ<0f:BQ0080f:BQ00<0
fJBP0=JUY@3GY:800P3GY:800`3GXj00e:FV0=FSX`020=FSX`040=JRX@3CY:L0e:>T0=BSY0@0dZBX
00<0dZ6U0<nV[P3@XjT00P3@XjT30<jU[P030<jQZ@3;Yk@0c:>^0080c:>^0`39YK@00`3:X:d0ajRj
0<NX^P020<NR/`030<BZ`035YKP0aJFh0080`Jg60P33Ykh0102n[l/0`:[40<2Za02k/]020;f]b@80
^KCD0P2k[lh20;Jef0@0];OK0`2b^=d20:njhP@0[[_S0P2/_>D30:bliP@0ZkcV2`2Z_NL00`2Y_NP0
00000:Vmj0050:Vmj0<0Z[gX:02Y_NP00`000000oooo0?ooo`0]0?ooo`00803oool00`000000oooo
0?ooo`0B0?ooo`030=F9N`3?QGl0chEo00<0e8Qm00H0c89o0=>7OP3CQgh0dhMn0=66OP3>T9420<F7
T@80bhfA0P33QY830<V:T@@0aXRA1035Qi400`3;SI40`hJB0<>6TP020<V:T@040<:5T`36R940aXRA
0<J8T@@0a8NA00D0bhfA0<>6TP33QY80`hJB0<V:T@020<:5T`<0aXRA00@0`8FD0<B7T@34Qi40a8NA
1033QY830<:5T`80aXRA0P30QI@20<B7T@040;n5U@33QY80`hJB0<>6TP@0`HFC0`30QI@00`34Qi80
_hFE0;n5U@020<>6TP050;j5U`31QI<0`HFC0<65T`2mQYT00`30QI@01@34Qi80_hFF0;n5UP2oQIH0
`hJB0080_XFG0P31QI<20;f5V@80`8FE00@0_8JL0;j5UP2nQIH0^XNN0P3Bhn<40>:o]0030=o@b@3Q
/JH0h[R]0080h[R]0`3O[Z<20>6cZ0030=fYX03N[:40gZbQ00<0000000@0g:RO0=fZX03MZZ00gjfR
0P3KYil30=bXW`030=j[X@3JYYl0g:NO0080g:NO00<0gJVO0=VUX03KYYl00P3KYYl0103LYil0fJFQ
0=ZUW`3JYIl30=RTX@80fJBP103GY:800`3GXj00e:FV0=FSX`020=FSX`050=JRX@3CY:L0e:>T0=BS
Y03DXJ400P3BY:P20=:QY@060<nV[P3@XjT0d:>Y0=2SZ@3@WjD0cZF^0P3>XJT40<bS[P050<bNZ039
YK@0bZ2]0<ZP[@37Z;X00`37X[<30<FU^0@0`jNn0`30Z/@30;f]b@@0^jo>0`2i/M820;Bgf`80]k?F
0P2b^=d30;2ig`<0[[_S0`2]^n@30:bli@H0ZkcV202Z_NL20:Zmj0030000002Y_NP0ZKgX02l0ZKgX
0P00000<0?ooo`050?noM000000000000000B02Lgol0703oool00200oooo00<000000?ooo`3oool0
4P3oool30<n5O`80e8Qm0P3<PWl30=>7OP80cY2A00D0aHNA0<^=T@3;SI40bhfA0<>6TP040<V:T@<0
aXRA00@0cY2A0<F7T@35Qi40aHNA0P3;SI420<>6TP80bHZA00@0`XFC0<J8T@36R940aXRA1034Qi40
1@3;SI40`hJB0<>6TP33QY80bHZA0080`XFC0`36R9401030QI@0a8NA0<B7T@34Qi430<>6TP040<R:
T@32QI<0`XFC0<:5T`80aXRA0P30QI@20<B7T@040;n5U@33QY80`hJB0<>6TP@0`HFC0`30QI@00`34
Qi80_hFE0;n5U@020<>6TP040;j5U`31QI<0`HFC0<65T`@0`8FD00D0a8NB0;n5UP2oQIH0_hFF0<>6
TP020;j5U`80`HFC0P2mQIT20<25U@030;b6W02nQIH0_XFF00@0_HFH0P3R_k@20=o@b@050>6aYP3R
^:d0h[R]0>:h[@3Ra;X00P3O[Z<20>6cZ0<000000`3P/:@30=fZX080gjfR00<0fjNO0=bXW`3LZ9l0
0P3NZj401P3JYYl0g:NO0=bWW`3LYil0gJVO0=VUX0<0fjJO00D0g:NO0=VUX@3JYIl0fZFO0=^VW`02
0=RTX@80fJBP00<0fJBO0=NTXP3GY:800P3GXj030=FSX`80eZ:Q00@0djBW0=BSY03DXj@0e:6Q0P3B
Y:P20=:QY@<0d:>Y0P3@WjD0103>YJh0cZ6Y0<jQZ@3>WJ@30<bS[P040<bNZ039YK@0bZ2]0<ZP[@@0
aj:c00@0aib[0<FU^035YKP0aYj`0P33Ykh20<BQ]@040<2Za032Xk/0`Z>k0;f]b@80_jK00P2k[lh2
0;fYa@80^K7B102g/mH30;Bdf@030;2ig`2c]]/0/kKK00<0[kWQ0`2^^^860:bli@80ZkcV0`2[_NL8
0:Zmi`040000002Y_NP0ZKgX0:Vmj0<0Z[gX:`2Y_NP00`000000oooo0?ooo`090?ooo`070?oOW018
04P0W=oo0?ooo`3o_g@0001d0;ooo`0K0?ooo`00803oool00`000000oooo0000000B0?ooo`<0chEo
0P3DR7d20<b2O`<0dhMn0P3>T9401@35Qi40bhfA0<^=T@3;SI40`hJB00@0bHZA0`36R940103>T940
aHNA0<F7T@35Qi420<^=T@80`hJB0P39RY401032QI<0aXRA0<J8T@36R9440<B7T@050<^=T@33QY80
`hJB0<>6TP39RY400P32QI<30<J8T@040<25U034Qi40a8NA0<B7T@<0`hJB00@0b8ZA0<:5T`32QI<0
`XFC0P36R9401@30QI@0a8NA0<B7T@34Qi40_hFE00<0`hJB0`31QI<01@36R940`8FD0<25U030QI@0
a8NB0080_hFE0P33QY801@2nQIL0`HFC0<65T`31QI<0aXRA00<0`8FD00<0a8NB0;n5UP2oQIH00P33
QY820;j5U`80`HFC00@0_HFI0<25U@30QID0`8FE0`2nQIH01@33QY<0_HFH0;f5V02mQIP0`HFD00<0
gm390`3R^:d30>;4^P<0000000<0h[b`0=j/X@3N[:400`3P/:@00`3Q]ZX0gJZP0=n]XP020=n]XP<0
g:RO0P3NZj430=bWW`80gJVO00<0fJFP0=^VW`3KYYl00P3LYil0103IYJ40fZFO0=ZUW`3KYYl20=RT
X@80fJBP00<0fJBO0=NTXP3GY:800P3GXj000`3HXil0eJ>S0=FSX`020=JRX@<0e:>T0P3DXJ40103B
Y:P0dZ6U0=:QY@3BWj420=2SZ@80d9nU0`3>XJT00`3>WJ@0c:>^0<bS[P020<bNZ0<0bZ2]00<0bI^W
0<NR/`37X[<00P37W:/01035YKP0aYj`0<JN/033Ykh30<BQ]@<0`Z>k102oY/030;fYa@<0^j_9102i
[/h20;Bdf@<0/kKK102a]md20:jjhP<0[K_S102]^n@50:^liPL0Z[gW00<000000:Zmj02Z_NP0102Z
_NP90:Vmj0@0Z[gX7P2Y_NP00`000000oooo0?ooo`090?ooo`070?noM000B9`0gooo0?ooo`3ookl0
M01809cOo`0K0?ooo`00803oool2000001<0oooo0`3?QGl20=B8O@80c89o0`3CQgh20<j@T@050<F7
T@3;SI40bhfA0<^=T@33QY801039RY430<J8T@040<j@T@35Qi40aHNA0<F7T@80bhfA0P33QY820<V:
T@040<:5T`36R940aXRA0<J8T@@0a8NA00<0bhfA0<>6TP33QY800P39RY420<:5T`<0aXRA1034Qi43
0<>6TP030<R:T@32QI<0`XFC00<0aXRA00@0`8FD0<B7T@34Qi40a8NA1033QY830<65T`030<J8T@30
QI@0`8FD0080a8NB0P2oQID20<>6TP050;j5U`31QI<0`HFC0<65T`36R9400`30QI@00`34Qi80_hFF
0;n5UP020<>6TP050;j5U`31QI<0`HFC0<65T`2mQIT00`30QID01034Qi80_XFF0;j5UP33QY<20;f5
V080`HFD00@0^hFJ0;k[l`2njo<0_^_c0P3R^:d3000000<0hK>X0P3R_;000`3N[:40h;2T0>2`Y002
0>6fZP050=fZX03O[J80gjfR0=n]XP3P/JH00P3LZ9l20=j[X@030=n^X`3LYil0g:NO0080gJVO0`3K
YYl20=bWW`<0fZFO0P3KYYl00`3HY:40fJBP0=VTX0020=VTW`050=NTXP3GXj00ej>P0=RSW`3EXj<0
0`3FXZ400`3FXIl0e:>T0=BQX@020=BQX@<0dZ6U00<0dYnQ0=2SZ@3@WjD00P3@WjD00`3@W:40cZ6Y
0<jMY0020<jMY0040<bS[P3<WZP0c9jX0<^IX`80bZ2]0P39VjL00`37X[<0aib[0<NLZ`030<JN/0@0
a:6e00@0a9Z/0<:S^`32Xk/0`Yba0P2oY/020<6N]P040;fYa@2oXK/0_j6k0;^[b@80_JBo0`2i[/h3
0;N`dP<0][;E0`2a]md30;2hg`<0[kWQ0`2]^n@30:bki@H0ZkcV0`2Z_>L00`2Z_NL000000:Zmi`03
0:Zmi`80ZKgW0`2Z_NP60:Vmj0<0Z[gX7`2Y_NP00`000000oooo0?ooo`080?ooo`070?oOW01804P0
W=oo0?ooo`3o_g@0001d0;ooo`0K0?ooo`005@3oool00`3ooml0W4P007Boo`070?ooo`030000003o
ool0oooo01<0oooo0`3?QGl0103DR7d0c89o0<b2O`3<PWl20=>7OP040<UoOP3>T940cY2A0<F7T@<0
bhfA00<0`hJB0<V:T@39RY400P39RY430<J8T@040<j@T@35Qi40aHNA0<F7T@80bhfA00@0`hJB0<V:
T@39RY40bHZA1036R9430<B7T@80bhfA0P33QY820<V:T@030<:5T`36R940aXRA0080aXRA1034Qi43
0<>6TP030<R:T@32QI<0`XFC00<0aXRA00@0`8FD0<B7T@34Qi40a8NA1033QY830<65T`030<J8T@30
QI@0`8FD0080a8NB00@0_hFE0<>6TP33QY80`hJB1031QI<00`36R940`8FD0<25U0020<B7TP80_hFF
0P33QY801@2nQIL0`HFC0<65T`31QI<0_HFI00<0`8FE00@0a8NB0;j5UP2nQIH0`hJC0P2mQIP20<65
U080^hFJ0P2njo<200000080h/Bj0P3KfM@0103Q/jP0h[b`0>:l/03R_;030>2`Y080hKJZ00<0gJZP
0=n]XP3O[J800P3P/JH01@3LZ9l0gZ^Q0=j[X@3NZj40gjjS0080g:NO0P3MZIl00`3NZj40fjJO0=^V
W`020=bWW`030=fYW`3JYIl0fjJO0080fjJO0P3IY:030=VTW`<0ej>P00<0f:>O0=FSX`3FXZ400P3F
XZ400`3FXIl0e:>T0=BQX@020=BQX@040=BOWP3BXJD0dYnQ0=:OX@@0d9nU00<0d9bQ0<jQZ@3>WJ@0
0P3>WJ@30<bNZ0030<^IX`3:X:d0bI^W0080bI^W0`37W:/01037UZ@0aYj`0<JN/035V:P20<BQ]@80
a9Z/00@0`Z>k0<:L/@32W;40_jK00`31W[H30;nQ^`@0_JBo00@0^Jk>0;bWa02lYl@0]k3B0P2jZLT2
0;Jbe@@0];?H0`2b]M/20:nih@@0[[[R0`2]^^<20:bli@@0ZkcV0P2Z_>L20:Zmi`030000002Z_NL0
Z[gW00@0Z[gW0P2Z_NP40:Vmj0<0ZKgW8P2Y_NP00`000000oooo0?ooo`080?ooo`050?oo_`1d0000
00000018W03Oool0703oool001D0oooo00<0oooO09a8001d_ol01`3oool00`000000oooo0?ooo`0C
0?ooo`<0chEo00@0e8Qm0<b2O`3<PWl0c89o0P3CQgh00`39Ogh0cY2A0<j@T@040<^=T@@0bHZA00<0
dY>A0<J8T@36R9400P3>T9420<F7T@<0bhfA00@0`hJB0<V:T@39RY40bHZA1036R9430<B7T@80bhfA
0P33QY820<V:T@030<:5T`36R940aXRA0080aXRA0`34Qi401@3;SI40`hJB0<>6TP33QY80b8ZA0080
`XFC0`36R9401030QI@0a8NA0<B7T@34Qi430<>6TP050<R:T@31QI<0`HFC0<65T`36R9400P30QI@2
0<B7TP050;n5U@33QY80`hJB0<>6TP38RY400`31QI<00`36R940`8FD0<25U0020<B7TP80_hFF0P33
QY80102nQIL0`HFC0<65T`31QI<40<25U@040<B7TP2nQIH0_XFF0<>6T`80_HFH0P31QI@01`2kQIX0
0000000000000000^HFM02/0003Ra;X00`3KfM@01P3Q/jP0h[b`0>:l/03R_;00hLW10>2`Y0<0hKJZ
0`3O[J820>2aYP030=bXW`3NZj40gZ^Q0080gjjS00H0g:NO0=fYW`3MZIl0gJVO0=j[X@3KYYl30=bW
W`030=fYW`3JYIl0fjJO0080fjJO00<0g:NO0=VTX03IY9l00P3IY9l0103JYIh0ej>P0=RSW`3HXil4
0=JRX@030=JQW`3DXj@0e:6Q0080e:6Q00D0e9nN0=:QY@3BWj40dYnQ0=:LWP030=2OY@030=2LX@3>
XJT0cYfT0080cYfT00D0cIVO0<bNZ03;VJ<0biVS0<ZP[@030<VKY`050<VEX@37W:/0aib[0<NFY036
W[000`35V:P00`34XKD0a9Z/0<BJ[0030<:L/@@0`Ijf00@0`IN/0;nQ^`2oXK/0`9V`0`2mY;l30;bW
a0<0^ZW9102h[<d30;N^d@80/[GK102a]]d30;2ggP80[K[S102]^n@50:^liP80Z[gW00<000000:Zm
i`2Z_NL0102Z_NL20:Vmi`@0Z[gW0P2Y_NLR0:Vmj0030000003oool0oooo00L0oooo00L0oono07@0
B02Lgol0oooo0=nLB000B9`0gooo01/0oooo000B0?ooo`030=nLB0000000000000<0000000<0B9cO
0?ooo`3oool0103oool2000001@0oooo0`3?QGl0103DR7d0c89o0<b2O`3<PWl20=>7OP<0cY2A103;
SI440<V:T@030=:CT@36R940aXRA0080cY2A0P35Qi430<^=T@040<>6TP39RY40bHZA0<V:T@<0aXRA
00@0cY2A0<B7T@34Qi40a8NA0P3;SI420<>6TP80bHZA00<0`XFC0<J8T@36R9400P36R9430<B7T@03
0<^=T@33QY80`hJB0080b8ZA0P32QI<30<J8T@040<25U034Qi40a8NA0<B7T@<0`hJB00<0b8ZA0<65
T`31QI<00P36R9420<25U080a8NB00D0_hFE0<>6TP33QY80`hJB0<R:T@030<65T`030<J8T@30QI@0
`8FD0080a8NB0P2oQIH20<>6TP050;j5U`31QI<0`HFC0<65T`36R9400`30QID01034Qi80_XFF0;j5
UP33QY<20;f5V0<000000`2oQID00`2iQId0_HBG0=_Ie0030=_Ie0<0h[b`0P3QbL401P3P/:@0hKJZ
0>6fZP3Q]ZX0h[nd0=n]XP<0h;6V0`3NZj420=n^X`030=bWW`3MZIl0gJVO0080gZ^Q00<0fjJO0=bW
W`3LYil00P3MZIl01P3JYIl0fjJO0=^VW`3KYYl0g:NO0=VTX0<0fJBO00D0fZFN0=NSX03HXil0f:>O
0=RSWP020=JRX@80eZ6O0`3DXJ420=BOWP040=:QY@3BWj40dYnQ0=:LWP80d9nU0P3@W:440<jMY004
0<fIW`3<WZP0biVS0<^IX`<0bI^W0P39UJ401037W:/0aiJT0<NFY036W[030<FHZ0<0a9Z/00@0`i>T
0<:L/@32W;40`YFX0P31W[H20<6G[0030;nQ^`30VK00`9V`0080_JBo0P2nW;@0102lYl@0_Iji0;fN
^@2jZLT20;bQ_P80^:c=0P2kY<820;N^d@<0]K3D102c/]L20;2ggP<0[kSP102^^N450:bki@030:^l
iP000000ZkcV00<0ZkgW202Z_NLU0:Vmj0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d07@0_ooo01/0oooo000B0?ooo`060?oOW018B9`0gooo0?oog`2LB000M;oo1`3oool0
0`000000oooo0?ooo`0C0?ooo`<0chEo103<PWl00`3CQgh0bGmn0<j@T@020<j@T@@0bhfA1039RY40
0`3BTi40aXRA0<J8T@020<j@T@80aHNA0`3;SI401033QY80bHZA0<V:T@39RY430<J8T@040<j@T@34
Qi40a8NA0<B7T@80bhfA0P33QY820<V:T@030<:5T`36R940aXRA0080aXRA0`34Qi400`3;SI40`hJB
0<>6TP020<R:T@030<:5T`36R940aXRA0080aXRA1034Qi430<>6TP030<R:T@31QI<0`HFC0080aXRA
00@0`8FD0<B7TP34Qi80a8NB1033QY800`38RY40`HFC0<65T`020<J8T@80`8FD0P34Qi80102oQIH0
`hJB0<>6TP33QY840<65T`050<J8T@30QID0`8FE0<25U@34Qi800P2nQIH300000080`HFD00@0^hFJ
0;n5U@2oQID0_hFE102mQ9L3097WnP040>:l/03QbL40hLW10>79`@<0hKJZ0P3R_k@01@3O[J80h;6V
0>2aYP3P/JH0h[R]0080gZ^Q0P3O[Z<30=fYW`80gZ^Q0`3LYil20=fYW`030=ZUW`3KYYl0fjJO0080
g:NO00<0fJBP0=VTW`3IY9l00P3JYIh0103GXj00f:>O0=RSW`3HXih20=JRX@80eZ6O00<0eZ2M0=BQ
X@3DXJ400P3DWih30=:OX@80dYbN00@0d9nU0=2LX@3@W:40ciVM0P3>WJ@20<fIW`040<bNZ03;VJ<0
biVS0<^EWP80bI^W0P39UJ400`37W:/0aiJT0<NFY0040<FHZ0050<FBX@34VZ`0a9Z/0<>CY032W;40
0`32UJP00`31W[H0`IN/0<6G[0030<2I/0@0_Ybd0`2mW[T30;bQ_P@0^jC20`2iYlL00`2e/=@0^:[;
0;RZb`030;>be`<0/[CJ0`2a]M`30:jih@<0[K[S0P2/^nD20:^liP040000002[_>H0ZkgW0:^mi`H0
Z[cW1P2Z_NL20:Vmial0ZKgX0P0000070?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P004RL0=ooo`0K
0?ooo`004`3oool01@3OW4P0B9cO0?oog`2LB000M;oo00L0oooo00<000000?ooo`3oool04`3oool3
0<n5O`@0c89o00<0dhMn0<UoOP3>T9400P3>T9440<^=T@@0bHZA00<0dY>A0<J8T@36R9400P3>T942
0<F7T@<0bhfA1039RY430<J8T@030<j@T@34Qi40a8NA00<0bhfA00@0`hJB0<V:T@39RY40bHZA1036
R9401@3>T940a8NA0<B7T@34Qi40bhfA0080`hJB0P38RY400`32QI<0aXRA0<J8T@020<J8T@<0a8NA
00D0bhfA0<>6TP33QY80`hJB0<R:T@020<65T`80aXRA00D0`8FD0<B7TP34Qi80a8NB0<^=T@030<>6
TP030<R:T@31QI<0`HFC0080aXRA0P30QI@20<B7TP050;n5UP33QY80`hJB0<>6TP38RY400`31QI<0
1036R940`8FE0<25U@34Qi83000000030<>6T`2mQIP0`HFD0080`HFD00D0^hFJ0;n5U@2oQID0_hFE
0<B7TP030;f4U`030<:6T`2kQ9T0^hBI00<0hLW10P3Chn<20>6fZP80h[nd103P/JH00`3R^:d0gZ^Q
0=n^X`020=n^X`030>6cY`3MZIl0gZ^Q0080gZ^Q00<0gjnT0=bWW`3LYil00P3MZIl30=^VW`80g:NO
0`3IY9l20=ZUWP030=NSX03HXil0f:>O0080f:>N00@0eZ:Q0=JQW`3FXIl0eZ2M0P3DXJ420=BOWP03
0=BMW03BWj40dYbN0080dYbN00@0d9nU0=2LX@3@W:40ciVM0P3>WJ@20<fIW`<0biVS00<0biFN0<VK
Y`39UJ400P39UJ430<NFY0060<JAWP35V:P0aIRX0<FHZ035TZ40a9Z/0P33Tj@01032W;40`YFX0<:E
Z032UJP30<6G[0040<6@X`30VK00`9V`0<2BYP<0_Ybd00@0_iBZ0;fN^@2mW[T0_YJ^0P2lXKh00`2m
VK80^jC20;^T`P020;bK]`80^JO70`2hZ//40;N/c`030;:dfP2e[]80]JkB0080/KGL102`]mh50:fj
h`80[;_T00<000000:bki02[_>H0102[_>H20:Zli`T0Z[gW7`2Y_NP00`000000oooo0?ooo`060?oo
o`050?oOW018000000000000M02oool0703oool001<0oooo00D0oooO09a8B02Lgml0W4P007Boo`07
0?ooo`030000003oool0oooo01<0oooo0`3?QGl40<b2O`040=>7OP39Ogh0cY2A0<j@T@D0bhfA0`39
RY420=:CT@050<J8T@3>T940cY2A0<j@T@35Qi40103;SI430<V:T@050=:CT@36R940aXRA0<J8T@3>
T9400P34Qi430<^=T@040<>6TP39RY40bHZA0<V:T@@0aXRA00D0cY2A0<B7T@34Qi40a8NA0<^=T@02
0<>6TP80b8ZA00<0`XFC0<J8T@36R9400P36R9430<B7T@050<^=T@33QY80`hJB0<>6TP38RY400P31
QI<20<J8T@050<25U034Qi80a8NB0<B7TP3;SI400`33QY800`38RY40`HFC0<65T`020<J8T@050<25
U034Qi80a8NB0<B7TP2oQIH00`33QY801@38RY40`HFC0<65T`31QI<0aXRA00<0000000D0a8NB0;j5
UP33QY<0`hJC0;f5V0030<65U0@0_hFE00D0a8NB0;f4U`2mQ9L0_HBG0<:6T`020;^4V@030<25U@2i
Q9`0dn?S0080dn?S00D0hKJZ0>:o]03R_k@0h[nd0=o@b@020>2aYP80h[R]00H0gZ^Q0=n^X`3O[Z<0
gjjS0>6cY`3MZIl30=j[X@030=n_Y03LYil0gJVO0080gJVO00<0gZ^Q0=^VW`3KYYl00P3LYil00`3L
Z9l0fJBO0=VTW`020=ZUWP80f:>O0`3HXih01@3FXZ40eZ6O0=JQW`3FX9d0e:6Q00<0e9nN00<0e9fL
0=:OX@3BW9h00P3BW9h30=2LX@030<nIW@3>WJ@0cIVO0080cIVO00D0cIFK0<^IX`3;VJ<0biFN0<VK
Y`030<VEX@040<RAV`37UZ@0aiJT0<JAWP80aIRX0P35TZ400`34VZ`0`i>T0<>CY0040<:EZ0050<:?
X031Uj`0`IN/0<6@X`30VK000P30TZH20;jL]080_iBZ00@0_Iji0;jF[P2nUZh0_:6n0P2mVK801@2k
Y<80_9^g0;bK]`2lVkL0^JO70080^ijk00<0^:[;0;ZQ_`2jXKl00`2g[<l30;F^dP<0];3E0P2`]mh2
0;>bf080[kOO0`2^^N400`2/^n@000000:bki0030:bki@D0ZkcV102Z_>L80:Zmi`<0Z[gX6@2Y_NP0
0`000000oooo0?ooo`0V0?ooo`00503oool0103ogi`0B4Qd07A8001d_ol60?ooo`030000003oool0
oooo01@0oooo0`3?QGl40<b2O`040<UoOP3>T940cY2A0<j@T@@0bhfA00@0eiRB0<V:T@39RY40bHZA
0P3BTi401@36R940cY2A0<j@T@3>T940aHNA00@0bhfA0`39RY401@3BTi40aXRA0<J8T@36R940cY2A
0080a8NA0`3;SI401033QY80bHZA0<V:T@39RY440<J8T@030<j@T@34Qi40a8NA0080bhfA0P33QY82
0<R:T@030<:5T`36R940aXRA0080aXRA0`34Qi400`3;SI40`hJB0<>6TP020<R:T@80`HFC0P36R940
1@30QI@0a8NB0<B7TP34Qi80bhfA0080`hJB0P38RY420<65T`80aXRA00D0`8FD0<B7TP34Qi80a8NB
0;n5UP030<>6TP030<R:T@31QI<00000008000000P30QID20<B7TP040;j5UP33QY<0`hJC0;f5V0<0
`HFD00D0aXVB0;n5U@2oQID0_hFE0<B7TP020;f4U`80`XJC00D0^hBI0<25U@30QID0^HBL0;j5U`02
0=?Sh`<0h[nd0`3Od<T00`3P/JH0h[R]0>:h[@030=n^X`80hK>W103NZj400`3O[j@0g:NO0=fYW`02
0=fYW`030=j[X@3KYYl0g:NO0080g:NO00<0g:RO0=VTW`3JYIh00P3JYIh00`3KYIh0f:>O0=RSWP02
0=RSWP80eZ6O0P3FX9d01P3DXJ40e9nN0=BOWP3DWih0e9fL0=:OX@<0dYbN00D0dIZK0=2LX@3?VId0
ciVM0<jMY0030<fIW`040<fEV`3;VJ<0biFN0<^EWP@0bIFQ00<0b96K0<NFY037UZ@00P36TIh00`35
V:P0aI:Q0<FBX@030<>CY0030<>>W@32UJP0`YFX0080`XnP00@0`IN/0<6@X`31T:<0`9V`0P30TZH0
102nW;@0_iBZ0;nDZP2oU:X30;jF[P<0_IVb102lVkL30;^N^`<0^Z6o102iY<@00`2e[]80^:O80;RW
b0020;B`e@@0/k;H0`2b]=X20:jih@80[[WR00<000000:jihP2]^^<00P2]^^<20:^ki@<0ZkcV1P2Z
_>L60:Zmi`80Z[gX0`2Y_NL40:Zmj180ZKgX00<000000?ooo`3oool09P3oool001D0oooo00<0gia8
0000001d_ol01P3oool3000001@0oooo0P3?QGl00`2oM7`0c89o0<b2O`020<b2O`040<UoOP3>T940
cY2A0<j@T@@0bhfA00@0eiRB0<V:T@39RY40bHZA0P3BTi401@36R940cY2A0<j@T@3>T940aHNA00@0
bhfA0`39RY400`3BTi40aXRA0<J8T@020<j@T@80a8NA0`3;SI401033QY80bHZA0<V:T@39RY440<J8
T@030<j@T@34Qi40a8NA0080bhfA00@0`hJB0<R:T@38RY40b8ZA1@36R9430<B7T@030<^=T@33QY80
`hJB0080b8ZA00@0`HFC0<J8T@36R940aXRA1034Qi800`3;SI40`hJB0<>6TP020<R:T@80`HFC0P36
R9401030QI@0a8NB0<B7TP34Qi840<>6TP80000000<0`HFC0<J8T@36R9400P30QID20<B7TP030;j5
UP33QY<0`hJC00@0`HFD00D0aXVB0;n5U@2oQID0_hFE0<B7TP020;f4U`80`XJC00@0^hBI0<25U@30
QID0^HBL0`2nQIL00`2kQ9T0h[nd0>:o]0030=o@b@<0h[R]00<0h/>i0=n^X`3O[Z<00P3Q/jL00`3R
^Zl0gZ^Q0=j[X@020=n_Y0@0gJVO00<0gZ^Q0=^VW`3LYil00P3LYil00`3LZ9l0fJBO0=ZUWP020=ZU
WP030=^UWP3HXil0f:>N0080f:>N00@0fJ:M0=JQW`3FX9d0eZ2M103DWih00`3DWI`0dYnQ0=:LWP02
0=:LWP040=6JV`3@W:40ciVM0<nIW@@0cIVO00D0cIFK0<^IX`3;UIh0biFN0<ZAVP030<VEX@030<RA
V`37UZ@0aY6N0080aY6N00@0aIRX0<FBX@35TZ40aHfK0P33Tj@00`33SYd0`YFX0<:EZ0020<:?X003
0<6G[031T:<0`I2S00<0`9:V102oU:X0102oSJ40_YJ^0;jF[P2nSj@20;fI/P050;jAZ02lVkL0_9^g
0;bK]`2mTj/00P2kW[/0102lUZl0^Z6o0;ZQ_`2lVK<30;VTa0<0^:O80`2gZ/`40;J/c`80/[CJ0`2`
]M`20;2ggP030000002`]mh0[K[S00@0[K[S2@2[_>H20:Zli`H0Z[gW1P2Z_NPC0:Vmj0030000003o
ool0oooo02D0oooo000E0?ooo`030?oog`2LB000M;oo00H0oooo00<000000?ooo`3oool0503oool2
0<n5O`030;mdO03<PWl0c89o0080c89o00@0bGmn0<j@T@3>T940cY2A103;SI40103GV980bHZA0<V:
T@39RY420=:CT@050<J8T@3>T940cY2A0<j@T@35Qi40103;SI430<V:T@030=:CT@36R940aXRA0080
cY2A00<0a8NA0<^=T@3;SI400P3;SI440<V:T@<0aXRA0P3>T9420<B7T@80bhfA00@0`hJB0<R:T@38
RY40b8ZA1036R9401@3>T940a8NA0<B7T@34Qi40bhfA0080`hJB0P38RY401@31QI<0aXRA0<J8T@36
R940cY2A00<0a8NB00<0bhfA0<>6TP33QY800P38RY420<65T`80aXRA00D0`8FD0<B7TP34Qi80a8NB
0<^=T@03000000030<R:T@31QI<0`HFC0080aXRA0P30QID20<B7TP040;j5UP33QY<0`hJC0<R;T@<0
`HFD00<0aXVB0;n5U@2oQID00P34Qi820;f4U`80`XJC00@0^hBI0<25U@30QID0^HBL0`2nQIL00`34
R9<0^hBI0=o@b@020=o@b@80_n[b00D0h[R]0>;3^@3R`kT0h/>i0=n^X`020>6cY`030>:j[`3NZj40
gZ^Q0080gjnT00<0h;BY0=fYW`3MZIl00P3NZj430=bWW`80g:RO00H0fJBO0=ZUWP3JYIh0fZFN0=^U
WP3HXil30=RSWP050=VRW@3FXIl0eZ2M0=JPW@3FWi`00P3DWih20=BMW0@0dYbN00D0dIZK0=2LX@3?
VId0ciVM0<nFVP020<fIW`80cIFK00@0biVS0<^EWP3;UIh0bY6J0P39UJ420<RAV`040<NFY036TIh0
aY6N0<JAWP<0aI:Q00D0aHfK0<>CY033SYd0`hjM0<:EZ0030<:?X0<0`I2S00@0`H^L0<2BYP30TZH0
`8bN0`2oU:X01@2oSJ40_YJ^0;j?Y02nSj@0_IVb00<0_Y6X00@0_9^g0;fCZ`2mTj/0^ijk0P2lUZl0
1@2jXKl0_9Vc0;bI/`2lVK<0^JC40080^i^h00@0^:O80;ZN_02jW[`0]j[<0P2iXL030;J/c`<0]:kB
0`2c/MH20;2ggP040000002_^=l0[kSO0:nhg`<0[[SQ0P2/^n@40:bki@80ZkcV0`2[_>L60:Zmi`80
Z[gX0`2Y_NL60:Zmj0h0ZKgX00<000000?ooo`3oool0903oool001h0oooo00<000000?ooo`3oool0
503oool20<n5O`040;mdO03<PWl0c89o0<b2O`80bGmn0`3>T9440<^=T@040=NHTP39RY40bHZA0<V:
T@80dY>A103>T9440<^=T@030=NHTP39RY40bHZA0080dY>A0P36R9420<j@T@030<B7T@3;SI40bhfA
0080bhfA1039RY430<J8T@80cY2A0P34Qi420<^=T@040<>6TP38RY40b8ZA0<R:T@@0aXRA00<0cY2A
0<B7T@34Qi400P3;SI420<>6TP80b8ZA00D0`HFC0<J8T@36R940aXRA0<j@T@030<B7TP030<^=T@33
QY80`hJB0080b8ZA00H0`HFC0<J8T@36R940aXRA0<25U034Qi83000000<0`hJB00<0b8ZA0<65T`31
QI<00P36R9401@30QID0a8NB0<B7TP34Qi80_XFF0080`hJC00D0b8^A0<65U031QI@0`HFD0<J9TP02
0;n5U@80a8NB0P2mQ9L20<:6T`030;^4V@30QID0`8FE00@0_XFG00<0a8RC0;^4V@2kQ9T0102oj_80
103R^:d0h/>i0>;3^@3R`kT20>6cY`<0h[Z_00@0gZ^Q0=n_Y03O[j@0h;BY0P3MZIl20=j[X@030=n_
Y@3LYil0g:NO0080g:RO0`3JYIh20=^UWP<0f:>N0P3IXYd0103FXIl0eZ2M0=JPW@3FWi`20=BOWP80
e9fL00<0di^J0=:LWP3BW9h00P3AVY/0103@W:40ciVM0<nIW@3?UYX20<fIW`80cIFK0`3;UIh00`3:
TIX0bIFQ0<VEX@020<RAV`050<NFY036TIh0aY6N0<JAWP36SIT00P35TZ401@35SI/0`i>T0<>>W@33
SYd0`YFX00<0`XnP00@0`X^J0<6@X`31T:<0`H^L0P30TZH00`30S9h0_iBZ0;nDZP020;n=X@040;jF
[P2nSj@0_XnT0;fI/P<0_Y6X0`2mTj/30;bF[`@0_9Vc0`2kVkP30;ZN_0<0^J70102iY<@00`2d[]80
^:O80;RWb0020;>aeP80/[;H00<000000;:bf02a]=X00P2a]=X20:jhh@<0[KWR0`2/^nD60:^ki@H0
Z[cW1@2Z_NL30:Zmj0<0ZKgW3@2Y_NP00`000000oooo0?ooo`0T0?ooo`007P3oool00`000000oooo
0?ooo`0D0?ooo`030<n5O`2oM7`0_gAl00<0c89o00D0bGmn0<j@T@3>T940cY2A0=bOT`030<^=T@80
eiRB0P39RY430=:CT@@0cY2A103;SI400`3GV980bHZA0<V:T@020=:CT@80aXRA0P3>T9400`34Qi40
bhfA0<^=T@020<^=T@<0bHZA00@0dY>A0<J8T@36R940aXRA0P3>T9420<B7T@80bhfA00@0`hJB0<R:
T@38RY40b8ZA1036R9400`3>T940a8NA0<B7T@020<^=T@80`hJB0P38RY401@31QI<0aXRA0<J8T@36
R940cY2A0080a8NB0P3;SI420<>6TP80b8ZA00<0`HFC0<J8T@36R9400`0000020<B7TP030<^=T@33
QY80`hJB0080b8ZA0P31QI<20<J8T@040<25U@34Qi80a8NB0<B7TP<0`hJC00D0b8^A0<65U031QI@0
`HFD0<J9TP020;n5U@80a8NB00D0_HBG0<:6T`32QY<0`XJC0;^4V@020<25U@050<J9TP2nQIL0_XFG
0;j5U`34R9<00`2kQ9T00`31QYD0^8>L0;R3W0030>;3^@80fmOC00@0hK>W0>:j[`3R^Zl0h[Z_0P3O
[j@30>2dZ@040=fYW`3NZj40gZ^Q0=n_Y@80g:NO0P3LZ9l00`3MZZ40fZFN0=ZUWP020=^UWP030=^V
W`3HXih0f:>N0080fJ:M0`3FX9d20=JOW0040=BOWP3DWI`0e9fL0=>KVP80dYbN0P3AVY/30<nIW@80
ciJJ00@0cIVO0<fEV`3=UI/0c9:H0P3;UIh20<ZAVP030<VEX@38TI/0b96K00@0aY6N00D0aXfI0<FB
X@35SI/0aHfK0<>CY0020<>>W@@0`XnP00D0`X^J0<6@X`31T:<0`H^L0<2BYP030<2<WP030;nDZP2o
SJ40_hfQ00<0_XnT102nTJP0102nRil0_I>[0;fCZ`2nSJ820;bF[`030;f>Y@2lVK<0_9Vc0080_I6X
0P2kVkP0102lTj`0^Yjl0;ZN_02lU[020;VQ`0040;^I]02iY<@0^JC40;VTa0<0^:O80`2gZ/`20;J/
d0040000002f[=00/KCJ0;6dfP<0/;GL0`2_]]h30:fjh`<0[K[T0P2[^nD40:^liPD0Z[cW1P2Z_NL5
0:Zmj0/0ZKgX0P00000T0?ooo`007P3oool2000001D0oooo00<0chEo0;mdO02oM7`00`3<PWl01@39
Ogh0cY2A0<j@T@3>T940g9nC00<0bhfA0P3GV9820<V:T@<0dY>A103>T9440<^=T@030=NHTP39RY40
bHZA0080dY>A0P36R9420<j@T@030<B7T@3;SI40bhfA0080bhfA0`39RY40103BTi40aXRA0<J8T@36
R9420<j@T@040<B7T@3;SI40bhfA0<^=T@@0b8ZA1036R9400`3>T940a8NA0<B7T@020<^=T@040<>6
TP38RY40b8ZA0<R:T@@0aXRA00<0cY2A0<B7TP34Qi800P3;SI420<>6TP80b8ZA0`0000000`36R940
ci2A0<B7TP020<B7TP030<^=T@33QY80`hJB0080b8ZA0P31QI<20<J8T@040<25U@34Qi80a8NB0<B7
TP<0`hJC00<0b8^A0<65U031QI@00P36RI820;n5U@80a8NB00@0_HBG0<:6T`32QY<0`XJC0`30QID0
1@36RI80_XFG0;j5U`2nQIL0a8RC0080^hBI0P31QYD00`2hPi`0_hFG0;n5U`040=_Gd`@0h[Z_00<0
h<No0=n_Y03P]:T00P3P]:T20=j[X@<0gjnU00@0g:NO0=bXW`3LZ9l0gJZQ0P3JYIh20=^UWP030=^V
W`3HXih0f:>N00<0fJ:M00D0eZ2M0=JOW03FWi`0eYnL0=BOWP020=BMW080di^J00@0dYbN0=6JV`3A
VY/0dIRI0P3?VId20<nFVP050<fIW`3=UI/0cIFK0<bBV03;UIh00`3:TIX01039UJ40b96K0<RAV`38
SYL20<JAWP80aXfI00<0aI:Q0<F=V`35SI/00`33SYd01P33RiP0`XnP0<:?X032Sj00`X^J0<6@X`80
`H^L00@0`9:V0<2<WP30S9h0`8bN0`2oSJ401030RIX0_XnT0;j?Y02oRYd30;jAZ0050;j;W`2mTj/0
_I>[0;j=XP2lUZl00P2mSZD01@2lVK<0_I6X0;fAZ02mTJP0^i^h0080_9>/00@0^Yjl0;bF/02lU[00
^J700`2kVK@0102iY<@0^i^h0;^K^02hYlP20;ZN_0030;NZc02iXL40^J710080]Zc@00@000000;B^
d`2d[]<0]:kC0`2c/MH20:nfgP@0[kSP0P2]^^@30:bki0<0[;_U0`2[_>H30:^mi`H0Z[gW0P2Z_NP3
0:Vmi`/0ZKgX00<000000?ooo`3oool08P3oool001h0oooo00<000000?ooo`3oool0503oool00`3?
QGl0_gAl0;mdO0030<b2O`050<UoOP3>T940cY2A0<j@T@3LWi<00`3;SI420=NHTP80bHZA0`3BTi44
0<j@T@@0bhfA00<0eiRB0<V:T@39RY400P3BTi401036R940cY2A0<j@T@3>T9450<^=T@<0bHZA00@0
dY>A0<J8T@36R940aXRA0P3>T9401034Qi40bhfA0<^=T@3;SI440<R:T@<0aXRA0P3>T9420<B7T@80
bhfA00D0`hJB0<R:T@38RY40b8ZA0=:CT@030<J8T@030<j@T@34Qi80a8NB0080bhfA00D0`hJB0000
0000000000000<65T`030<J8T@050<n@T@34Qi80a8NB0<B7TP3;SI400P33QY820<R:T@80`HFC0P36
R9401030QID0a8NB0<B7TP34Qi830<>6T`030<R;T@31QI@0`HFD0080aXVB0P2oQID20<B7TP050;f4
U`32QY<0`XJC0<:6T`39Ri800P30QID00`36RI80_XFG0;j5U`020<B8T`80^hBI0P31QYD01@2hPi`0
_hFG0;n5U`2bPJ00^hBI00<0VNOl0P3R^Zl20>37_`060=n_Y03P]:T0h;BY0>2dZ@3Q_;80gZ^Q0`3O
[jD30=bXW`80gJZQ00D0fZFN0=^UWP3KYIh0fjJO0=RSWP040=VRW@040=JPW@3FWi`0eYnL0=JOW0<0
e9fL0P3CViX01@3BW9h0dIZK0=6JV`3AV9T0ciVM00<0ciJJ0`3=UI/00`3<TYP0biFN0<ZAVP020<ZA
VP<0b96K00<0b8jG0<JAWP36TIh00P36SIT01035TZ40aHfK0<F=V`35RiL20<>>W@030<>;V032Sj00
`XnP0080`X^J00<0`I2S0<6;W031Ri`01030S9h01031R9T0_hfQ0;n=X@30RIX20;j?Y0030;n:W@2n
TJP0_Y6X0080_X^O00@0_I>[0;j=XP2nSJ80_9J_0P2mSZD40;fAZ0<0_9>/0`2lU[040;^I]0<0^i^h
0`2jW[`30;VQ`@80]Zc@00<0^:C50000002d[]<00P2gYlT20;>aeP<0/[;H102a]=X20:jhh@<0[KWR
0P2/^nD40:^ki@80ZkgW0`2Z_>L90:Zmi`80Z[gX102Y_NL40:Vmj0030000003oool0oooo0280oooo
000M0?ooo`030000003oool0oooo01D0oooo00<0chEo0;mdO02oM7`00`3<PWl01@39Ogh0cY2A0<j@
T@3>T940g9nC00<0bhfA0P3GV9820<V:T@80dY>A103>T940103LWi<0bhfA0<^=T@3;SI420=NHTP05
0<V:T@3BTi40dY>A0=:CT@36R9400`3>T9440<^=T@050=NIT@39RY40bHZA0<V:T@3BTi400P36R943
0<j@T@040<B7T@3;SI40bhfA0<^=T@<0b8ZA00@0dY>A0<J8T@36R940aXRA0P3>T9420<B7T@80bhfA
00D0`hJB0<R:T@38RY40b8ZA0=:CT@030<J8T@030<j@T@34Qi80a8NB00<000000`38RY401@31QI<0
aXRA0<J8T@36R940ci2A00<0a8NB00<0bhfA0<>6TP33QY800P38RY401@31QI<0aXRA0<J8T@36R940
`8FE00<0a8NB0P33QY<20<R;T@80`HFD0P36RI801@2oQID0a8NB0<B7TP34Qi80_HBG00<0`XJC00@0
bH^B0<25U@30QID0aXVB0P2nQIL20<B8T`80^hBI0P31QYD0102hPi`0_hFG0;n5U`2bPJ020;^4V@80
VNOl00@0h[Z_0>37_`3Pakl0h<No0`3P]:T20>6l/P060=j[X@3O[jD0gjnU0=n_Y@3O/j/0g:RO0`3M
ZZ420=^UWP80fjJO00<0f:>N0=VRW@3IXYd00P3IXYd01P3FX9d0eYnL0=JOW03FWi`0eYjK0=BMW0<0
di^J0`3AVY/00`3AV9T0ciVM0<nFVP020<nFVP050<jDU`3=UI/0cIFK0<bBV03;UIh00`3:TIX0103:
SiH0b96K0<RAV`38SYL20<JAWP80aXfI00@0aI:Q0<F=V`35SI/0aH^G0P33SYd00`33RiP0`XnP0<:?
X0020<:;VP040<6@X`31Ri`0`H^L0<:8U`<0`8bN00D0`HRI0;n=X@2oSJ40`8VJ0;j?Y0030;n:W@04
0;jAZ02nRil0_X^O0;fCZ`80_XfR0`2mSZD01@2nRId0_I6X0;fAZ02mTJP0_H^O0080_9>/00@0_HbR
0;bF/02lU[00_8jU0P2kVK@20;b@Z@80^i^h00@0_9>/0;ZN_02jW[`0^iJ`0P2iXL430;RTa@040000
002gYlT0]jO90;NWb@<0]Z[<00<0/[;H0;F/d02e[=000`2a]=X30;2eg080[KWR0`2]^^<40:bji080
Zk_U0`2[_>H30:Zmi`<0Z[cW1@2Z_NL30:Vmi`<0Z[gX0P2Y_NP00`000000oooo0?ooo`0Q0?ooo`00
7@3oool00`000000oooo0?ooo`0E0?ooo`<0_gAl0P3<PWl00`2gJgX0i:VE0<j@T@020<j@T@030=bO
T`3;SI40bhfA00<0eiRB00@0bHZA0=:CT@3BTi40dY>A103>T940103LWi<0bhfA0<^=T@3;SI420=NH
TP050<V:T@3BTi40dY>A0=:CT@36R9400`3>T9440<^=T@050=NIT@39RY40bHZA0<V:T@3BTi400P36
R9430<j@T@040<B7T@3;SI40bhfA0<^=T@<0b8ZA00@0dY>A0<J8T@36R940aXRA0P3>T9401@34Qi40
bhfA0<^=T@3;SI40`hJB00<0b8ZA00<0dY>A0<J8T@36R9400P3>T94200000080bhfA00@0`hJB0<R:
T@38RY40b8ZA1036R9400`3?T940a8NB0<B7TP020<^=T@80`hJB0P38RY401031QI<0aXRA0<J8T@36
R9440<B7TP80`hJC0P38Ri420<65U080aXVB00@0_hFE0<B7TP34Qi80a8NB1032QY<01039Ri80`8FE
0<25U@36RI820;j5U`80a8RC0P2kQ9T20<66U@030;R3W02oQIL0_hFG00@0^hBI00@0`hRF0>37_`3P
akl0h<No0P3Cg=l20>2dZ@80hKbb0`3O[jD20=ncZ`060=bXW`3MZZ40gJZQ0=fZX@3M[JD0fjFN0P3K
YYl50=VRW@060=JPW@3FWi`0eYnL0=JOW03FWY/0e9fL0`3CViX01@3CVYT0dIZK0=6JV`3AV9T0ciVM
00<0ciJJ00D0cYBG0<fEV`3<TYP0c9:H0<^EWP030<ZAVP050<Z?UP38TI/0b96K0<R>U`36TIh00`36
SIT30<F=V`030<F;U`33SYd0`hjM0080`h^H00<0`XnP0<:;VP32RiX00`31Ri`01P32R9L0`8bN0<2<
WP30S9h0`HRI0;n=X@80`8VJ00D0_XnT0;n:W@2oRYd0_hZM0;jAZ0020;j;W`<0_XfR00@0_XRK0;f>
Y@2mSZD0_XVM0`2mTJP01@2mRil0_9>/0;f<XP2mS:80_9J`0080_8jU00D0^iVd0;b@Z@2lT:T0_92Y
0;^K^0020;bC[0040;ZN_02kU[00^iJ`0;VQ`@80^iRd0P2hY<D00`2jVkT000000;NWb@020;ZN_@80
]Z[<0`2e[=040;B^d`80/;GL0`2_]]h30:nhh0<0[;[T0`2/^n@50:^liP@0ZkgW2`2Z_NL20:Vmj003
0000003oool0oooo0200oooo000M0?ooo`030000003oool0000001D0oooo0`2oM7`20<b2O`040;M[
NP3TZID0cY2A0<j@T@80g9nC0P3;SI430=NHTP040<V:T@3BTi40dY>A0=:CT@@0cY2A00@0g9nC0<^=
T@3;SI40bhfA0P3GV9801@39RY40dY>A0=:CT@3BTi40aXRA00<0cY2A103;SI400`3GVI40bHZA0<V:
T@020=:CT@80aXRA0`3>T9401034Qi40bhfA0<^=T@3;SI430<R:T@040=:CT@36R940aXRA0<J8T@80
cY2A00@0a8NA0<^=T@3;SI40bhfA1038RY400`3BTi40aXRA0000000200000080a8NB0P3;SI401@33
QY80b8ZA0<R:T@38RY40dY>A00<0aXRA00<0ci2A0<B7TP34Qi800P3;SI420<>6TP80b8ZA00@0`HFC
0<J8T@36R940aXRA0`34Qi800`3;SI40`hJC0<>6T`020<R;T@80`HFD0P36RI801@2oQID0a8NB0<B7
TP34Qi80bhfA00<0`XJC00@0bH^B0<25U@30QID0aXVB0P2nQIL20<B8T`050;^4V@31QYD0`HJE0<66
U@2hPi`00P2oQIL01@36RY@0^hBI0;^4V@2kQ9T0`hRF0080]X:M0`3Cg=l01@3P]:T0hKbb0>6l/P3Q
_;80gLW50080gjnU0P3O/j/00`3LZ9l0gJZQ0=fZX@020=f]Y@040=^UWP3KYYl0fjJO0=^WX@@0fJ:M
0`3FWi`20=JNV`060=BMW03CViX0di^J0=>KVP3CVYT0dIZK0P3AV9T01P3?VId0ciJJ0<nFVP3?UYX0
cYBG0<fEV`80c9:H103:TIX01@3:SiH0b96K0<R>U`38SYL0aY6N00<0aXfI00@0ahbE0<F=V`35SI/0
aH^G0P33SYd20<>;V0040<:?X032RiX0`X^J0<>8UP80`H^L00H0`XRG0<2<WP30S9h0`8bN0<68V@2o
SJ420<29VP040;j?Y02oRYd0_hZM0;n:W@<0_X^O00D0_hNI0;j=XP2nSJ80_XRK0;f>Y@030;j9W@04
0;fAZ02mRil0_H^O0;bC[080_HbR00<0_9J`0;b>Y@2lSZD0102lT:T30;bC[0<0^iJ`0`2kV;@40;ZK
^@030000002jW[d0^Yjm00<0^J;100<0]Jc@0;RTa@2hY<D00`2d[]<30;>aeP<0/[;H0P2_^>040:jh
h@<0[KWR0P2/^nD30:^ki@<0ZkgW0`2Z_>L80:Zmi`80Z[gX00<000000?ooo`3oool0803oool001d0
oooo0P00000F0?ooo`<0_gAl0P3<PWl0102gJgX0i:VE0<j@T@3>T9420=bOT`80bhfA0`3GV9801039
RY40dY>A0=:CT@3BTi440<j@T@040=bOT`3;SI40bhfA0<^=T@80eiRB00D0bHZA0=:CT@3BTi40dY>A
0<J8T@030<j@T@@0bhfA00<0eiVA0<V:T@39RY400P3BTi420<J8T@<0cY2A103;SI430<R:T@030=:C
T@36R940aXRA00<0cY2A00@0a8NA0<^=T@3;SI40bhfA0`38RY43000000030<J8T@3>T940cY2A0080
a8NB0P3;SI401@33QY80b8ZA0<R:T@38RY40dY>A00<0aXRA00<0ci2A0<B7TP34Qi800P3;SI401@33
QY80b8ZA0<R:T@38RY40`HFC00<0aXRA0`34Qi800`3;SI40`hJC0<>6T`020<R;T@050<65U036RI80
aXVB0<J9TP2oQID00`34Qi801@3;SI40`XJC0<:6T`32QY<0bH^B0080`8FE00<0aXVB0;j5U`2nQIL0
0P34R9<0102kQ9T0`HJE0<66U@31QYD30;n5U`050<J:U02kQ9T0^hBI0;^4V@33R9H00`2fPYd20=?L
g`<0hKbb0P3MbLD0103O[jD0gk>[0=ncZ`3O/j/30=fZX@80gJfU00@0fjFN0=^VW`3KYYl0fjNQ103I
XYd00`3HXYd0eYnL0=JOW0020=JNV`060=BMW03CViX0di^J0=>KVP3CVYT0dIZK0P3AV9T40<nFVP05
0<jDU`3=UI/0c9:H0<bBV03<TIH00`3:TIX0103:SiH0b96K0<R>U`38SYL40<J=V@030<N<U@35SI/0
aH^G0080aH^G00<0`hjM0<>;V033RiP00`32RiX01033R9H0`H^L0<6;W032R9L20<2<WP80`HRI00<0
_hfQ0<29VP30RIX0102oRYd01030QiL0_X^O0;j;W`2oQiT20;j=XP030;j8V`2mSZD0_XVM0080_XVM
00<0_I6X0;f;W`2mRil00`2mS:830;b>Y@050;f9W@2lT:T0_92Y0;b@Z@2mRZ000P2lTj`0102lS:<0
^iJ`0;^F/02lSZH20;^H]0080;b@Z@2jVkT0^Y^i0;ZK^@2lTjd000000;ZN_@2kU[020;VR`@<0^:C5
102gYlT30;JYc@80/[;H0`2a/mX40;2fg@80[KWR0`2]^^<20:^ki@@0Zk_V0`2[_>H80:Zmi`80ZKgW
00<000000?ooo`3oool07`3oool00100oooo00D0oono07@000000000001d0;ooo`080?ooo`030000
003oool0oooo01@0oooo102oM7`20<b2O`040;M[NP3TZID0cY2A0<j@T@80g9nC0P3;SI430=NHTP04
0<V:T@3BTi40dY>A0=:CT@<0cY2A0P3LWi<20<^=T@<0eiRB103BTi440<j@T@<0bhfA0P3GVI420<V:
T@80dY>A00<0aXRA0<j@T@3>T9400P3>T9430<^=T@050=NIT@38RY40b8ZA0<R:T@3BTi400P36R943
0<j@T@040<B7T@3;SI40bhfA0<^=T@<000000P3BTi420<J8T@80cY2A00D0a8NB0<^=T@3;SI40bhfA
0<>6TP030<R:T@030=:CT@36R940aXRA0080ci2A0P34Qi820<^=T@050<>6TP38RY40b8ZA0<R:T@31
QI<00`36R9430<B7TP030<^=T@33QY<0`hJC0080b8^A00@0`HFD0<J9TP36RI80aXVB1034Qi800`3;
SI40`XJC0<:6T`020<V;TP040<25U@36RI80aXVB0;j5U`<0a8RC00D0^hBI0<66U@31QYD0`HJE0<V<
T`020;n5U`050<J:U02kQ9T0^hBI0;^4V@33R9H00P2fPYd20;n7V080[GnR0P3Q_;820=g9a@060=n_
Y@3O/j/0gk>[0=ncZ`3N^kD0gJZQ0`3M[JD30=^VW`80fjNQ0`3IXYd00`3HXYd0eYnL0=JOW0020=JN
V`<0di^J0P3CVYT0103AVY/0dIRI0=6HV@3@UYL20<nFVP80cYBG00@0cIFK0<bBV03<TYP0c96F0`3:
TIX01@3:SiH0b96K0<R>U`38SYL0b8fD00<0aXfI00<0ahbE0<F=V`35RiL00P35RiL01033SYd0`h^H
0<>;V035RI@20<:;VP030<>8UP31Ri`0`H^L0080`XRG00@0`8bN0<68V@31R9T0_hfQ0P30RIX01@31
QiH0_hZM0;n:W@2oRYd0`8NG0080_X^O00D0_hNI0;j=XP2nR9/0_XRK0;f>Y@030;j9W@<0_H^O00@0
_XNI0;f<XP2mS:80_XRK0P2lSZD01P2mRId0_92Y0;b@Z@2lT:T0_HZP0;bC[080_8bS00@0^iJ`0;b>
YP2lSZH0^iRd0`2lT:T0102jVkT0_9>]0;bC[@0000020;^F/0040;VR`@2kV;@0^iRd0;RTa@80^Y^i
0P2gYlT20;VN_@80]ZW=0`2e[=030;B^d`<0/;KM0`2_]]h30:nhh080[;[T0`2/^n@60:^liP80Z[gW
102Z_>L20:Vmi`030000003oool0oooo01h0oooo000@0?ooo`060;md001d_ol0oooo0?oOW018B9`0
gooo1`3oool00`000000oooo0?ooo`0D0?ooo`@0_gAl0P3<PWl20>BYU@80cY2A0P3LWi<00`3;SI40
eiRB0=NHTP020=NHTP<0dY>A00@0i:VD0<j@T@3>T940cY2A0P3LWi<20<^=T@<0eiRB103BTi430<j@
T@040=fOTP3;SI40bhfA0<^=T@80eiVA0P39RY420=:CT@030<J8T@3>T940cY2A0080cY2A0`3;SI40
0`3GVI40b8ZA0<R:T@020=:CT@80aXRA0`3>T9401034Qi4000000000000000030<R:T@80dY>A0P36
R9420<j@T@040<B7TP3;SI40bhfA0<^=T@@0b8ZA00<0dY>A0<J8T@36R9400P3?T9420<B7TP80bhfA
00@0`hJB0<R:T@38RY40b8ZA1036R9430<B7TP030<^=T@33QY<0`hJC0080b8^A00D0`HFD0<J9TP36
RI80aXVB0<n@T@030<B7TP030<^=T@32QY<0`XJC0080bH^B00@0`8FE0<J9TP36RI80_XFG0`34R9<4
0<66U@040<V<T`2oQIL0_hFG0<J:U0<0^hBI00<0`hRF0;J2W@2fPYd00P2oQiP00`2]Oj80^hFL0;^5
W0030=g9a@<0gk>[0P3N^kD01P3MZZ40gJfU0=f]Y@3M[JD0g;6[0=^VW`<0fjNQ0`3IXYd00`3HXYd0
eYnL0=JNV`020=JNV`030=FMV`3CViX0di^J0080diZI00@0dIZK0=6HV@3AV9T0d9JG0P3?UYX20<jD
U`040<fEV`3<TYP0c9:H0<bAUP80bY6J0P3:SiH01038TI/0b8jG0<R>U`38SI@30<J=V@030<N<U@35
SI/0aH^G0080aH^G00@0`hjM0<>;V033RiP0aHVD0P32RiX00`33R9H0`H^L0<6;W0020<:8U`030<2<
WP31R9T0`HRI00<0`8VJ00H0`HNF0;n:W@2oRYd0_hZM0<27U`2nRil20;n7V@030;j=XP2nR9/0_XRK
00@0_XVM00@0_hJG0;f;W`2mRil0_XNI0P2mS:800`2nR9/0_8jU0;b>Y@020;f9W@040;b@Z@2mRZ00
_HZP0;bC[080_8bS00<0^iJ`0;b>YP2lSZH0102lT:T30;bC[@030;^F/0000000^iJ`00<0^iRd0`2j
VkT40;VN_@040;JYc@2iX/40^J;10;F/d080^:C50P2d[]<30;>`eP@0/[;H0P2_^>030:jhh@80[;_T
102/^nD30:^li@80ZkcV1@2Z_NL00`000000oooo0?ooo`0N0?ooo`003`3oool01`3ookl0M4RL0=oo
o`3oool0oono07@0B02Lgol01P3oool00`000000oooo0?ooo`0E0?ooo`@0_gAl00@0c89o0;M[NP3T
ZID0i:VE0P3>T9420=bOT`030<^=T@3GV980eiRB0080eiRB0`3BTi40103TZI@0cY2A0<j@T@3>T942
0=bOT`80bhfA0`3GV9840=:CT@<0cY2A00@0gInB0<^=T@3;SI40bhfA0P3GVI420<V:T@80dY>A00<0
aXRA0<j@T@3>T9400P3>T9430<^=T@030=NIT@38RY40b8ZA0080dY>A0P36R940103>T94000000000
000000030<^=T@<0b8ZA0P3BTi420<J8T@80cY2A00@0a8NB0<^=T@3;SI40bhfA1038RY400`3BTi40
aXRA0<J8T@020<n@T@80a8NB0P3;SI401033QY80b8ZA0<R:T@38RY430<J8T@060<n@T@34Qi80a8NB
0<B7TP3;SI40`hJC0`38Ri401@31QI@0aXVB0<J9TP36RI80ci2A00<0a8NB00<0bhfA0<:6T`32QY<0
0P39Ri801030QID0aXVB0<J9TP2nQIL30<B8T`050<b>TP31QYD0`HJE0<66U@39S9<00P2oQIL00`36
RY@0^hBI0;^4V@020<>8UP80]X:M0P2oQiP0102]Oj80^hFL0;^5W02MNJX30<KLj@80gk>[0P3N^kD3
0=f]Y@80g;6[00@0fjJO0=^WX@3KYj40fjNQ0P3IXYd20=RRW@050=JOW03FWY/0eYjK0=JNV`3EWI/0
0P3CViX20=>JV@<0dIRI00<0d9JG0<nFVP3?UYX00P3>U9L30<bBV0030<bAUP3:TIX0bY6J0080bXnF
0`38SYL01P38SI@0aXfI0<J=V@36SIT0ahbE0<F=V`<0aH^G0`33RiP00`35RI@0`X^J0<:;VP020<>8
UP040<6;W032R9L0`XRG0<2<WP80`HRI00@0`hND0<29VP30RIX0`HNF0`2oRYd01@30QiL0_X^O0;n7
V@2oQiT0_XfR0080_XRK00D0`8JF0;j9W@2nRId0_XVM0;n6U`020;f;W`030;j7V@2mS:80_HbR0080
_XRK00@0_8jU0;f9W@2mRId0_92Y0P2mRZ030;b<X`<0_8jV00D0_HVM0;b@Z@2lT:T0_92Y0;f:X002
0;bC[@040;b<X`2kU[0000000;b>YP80^iRd00@0_92Y0;ZK^@2jVkT0^i>]0`2iW[d30;VR`@<0^:C5
0`2gYlT00`2c/=H0]Z[=0;JZc@030;:bf0<0/KCK0`2`]M`20:fihP@0[K[S0P2[_>D30:^liPD0Z[gW
00<000000?ooo`3oool07@3oool000l0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0
oooo0`00000E0?ooo`@0_gAl00D0c89o0;M[NP3TZID0i:VE0<j@T@030=bOT`030<^=T@3GV980eiRB
0080eiRB0`3BTi40103TZI@0cY2A0<j@T@3>T9420=bOT`80bhfA0`3GV9840=:CT@<0cY2A00@0gInB
0<^=T@3;SI40bhfA0P3GVI401@39RY40dY>A0=:CT@3BTi40aXRA00@0cY2A0`3;SI400`3GVI40b8ZA
0<R:T@020=:CT@<000000P3>T9440<^=T@<0b8ZA0P3BTi420<J8T@80cY2A00@0a8NB0<^=T@3;SI40
bhfA0`38RY420=:CT@80aXRA0P3?T9401@34Qi80bhfA0<^=T@3;SI40`hJB00<0b8ZA0`36R9400`3?
T940a8NB0<B7TP020<^=T@050<>6T`38Ri40b8^A0<R;T@31QI@00`36RI800`3?T940a8NB0<B7TP02
0<^=T@80`XJC0P39Ri801030QID0aXVB0<J9TP2nQIL30<B8T`050<b>TP31QYD0`HJE0<66U@39S9<0
0P2oQIL20<J:U0040;^4V@33R9H0`hRF0;J2W@<0_hNH00D0[GnR0;^5W02kQI`0WGVZ0;>3X@030<KL
j@<0g[^e00<0elG80=f]Y@3M[JD00P3L/J/01P3KYYl0fjNQ0=^WX@3KYj40fZVT0=VRW@80f::M00H0
eYnL0=JNV`3FWY/0eYjK0=FMV`3CViX30=>JV@030=>IV03AV9T0dIRI0080d9JG00@0ciJJ0<jDU`3>
U9L0cY>F0P3<TYP20<bAUP040<ZAVP3:SiH0bXnF0<^?U080b8jG00<0b8fD0<J=V@36SIT00P37S9D0
1@35SI/0aH^G0<F;U`35RiL0ahZC0080`h^H00<0aHVD0<:;VP33R9H00P33R9H00`31Ri`0`XRG0<:8
U`030<68V@040<>7U030RIX0`8VJ0<67UP80_hZM0P30QiL00`2nRil0_hNI0;n7V@030;j8V`060<26
UP2nRId0_XVM0;j9W@2oQYL0_H^O0P2nQiT01@2mS:80_XRK0;j8V`2nR9/0_8jU0080_HVM0`2mRZ00
102nQiT0_8bS0;b<X`2mR9/20;b>YP060;f9W@2lT:T0_92Y0;b@Z@2mRZ00_9>]0P2lS:<0102kU[00
00000;b>YP2kV;@20;b@Z@030;ZK^@2kTjd0^i>]0080^Ijm0P2kU[40102iX/40^iRd0;^H]02hY<D2
0;ZK^@80]jO90`2fZ/d40;F/d0<0]:kC0P2`]M`30:nfgP<0[K[S0`2/^^@30:bki0D0ZkcV00<00000
0?ooo`3oool0703oool000l0oooo00L0omnL04P0001d_ol0oooo0?oOW018B9`0gooo00H0oooo00<0
00000?ooo`3oool05@3oool40;mdO0050<b2O`3TZID0i:VE0>BYU@3>T9400`3LWi<00`3;SI40eiRB
0=NHTP020=NHTP<0dY>A00<0i:VD0<j@T@3>T9400`3LWi<0103;SI40eiRB0=NHTP3GV9850=:CT@<0
cY2A00<0gInB0<^=T@3;SI400`3GVI401039RY40dY>A0=:CT@3BTi440<j@T@050=fOTP3;SI40bhfA
0<^=T@3GVI400P38RY42000000030<J8T@3>T940cY2A0080cY2A0`3;SI40103GVI40b8ZA0<R:T@38
RY420=:CT@050<J8T@3>T940cY2A0<j@T@34Qi800`3;SI430<R:T@80dY>A0P36R9420<n@T@050<B7
TP3;SI40bhfA0<^=T@33QY800`38RY430<J8T@030<n@T@34Qi80a8NB0080bhfA00@0`hJC0<R;T@38
Ri40b8^A1036RI800`3?T940a8NB0<B7TP020<^=T@80`XJC0P39Ri800`30QID0aXVB0<J9TP040<B8
T`030<b>TP31QYD0`HJE0080bHbC00D0_hFG0<J:U036RY@0aXZD0;^4V@020<>8UP040;J2W@2oQiP0
_hNH0;n7V0<0^hFL102cPj400`2TOJX0;:cZ0=jk]@020=O5b0040=f]Y@3L/J/0g;6[0=baZ`<0fjNQ
0P3JZJ@00`3IXYd0f::M0=RRW@040=JNV`030=FMV`3CViX0diZI0080diZI00<0diVH0=6HV@3@UYL0
0P3@UYL01@3?UYX0cYBG0<jDU`3>TiH0c9:H00<0c96F00@0bY6J0<Z?UP3:SiH0bhnD0P38SYL20<R=
U0030<J=V@37S9D0ahbE00@0aH^G00D0ahZC0<>;V033RiP0aHVD0<:;VP030<>8UP040<6;W032R9L0
`XRG0<B8T`80`HRI00<0`hND0<29VP30RIX00P31QiH0102oRYd0`8NG0<27U`2nRil20;n7V@040<66
U@2nR9/0_XRK0<26UP<0_XVM00D0_hJG0;f;W`2nQiT0_XNI0;f<XP030;j8V`<0_HVM00@0_hJH0;f:
X02mRZ00_XNI0P2lS:<00`2mR9/0_8jV0;f9W@020;f9W@040;b@Z@2mRZ00_HZP0;bC[@80_8bS00@0
^iJ`0;b>YP000000^iRd0P2lT:T30;^C[@@0^iJa0`2kV;@30;ZK^@<0^Ijm00<0]Z[=0;VQ`@2iXL40
0P2e[=020;RTa@80]:kC0`2c/=H30;:bf080[kOO102^^>420:bki0<0[;_U0P2[_>H00`000000oooo
0?ooo`0L0?ooo`003`3oool01P3ogi`0B4RL09ad00000000001809cOo`L0oooo00<000000?ooo`3o
ool05@3oool40;mdO0050<b2O`3TZID0i:VE0>BYU@3>T9400`3LWi<40=NHTP050>nhUP3BTi40dY>A
0=:CT@3TZI@00P3>T9430=bOT`050<^=T@3GV980eiRB0=NHTP3_^9H00`3BTi401@3TZI@0cY2A0<j@
T@3>T940gInB0080bhfA0`3GVI401@39RY40dY>A0=:CT@3BTi40iJVC00<0cY2A00@0gInB0<^=T@3;
SI40eiVA0`0000020=:CT@030<J8T@3>T940cY2A0080cY2A0`3;SI400`3GVI40b8ZA0<R:T@030=:C
T@050<J8T@3>T940cY2A0<j@T@34Qi800`3;SI430<R:T@80dY>A0P36R9420<n@T@040<B7TP3;SI40
bhfA0<^=T@@0b8ZA0`36R9400`3?T940a8NB0<B7TP020<^=T@050<>6T`38Ri40b8^A0<R;T@3BU940
0`36RI800`3?T940a8NB0<B7TP020<^=T@80`XJC0P39Ri801030QID0aXVB0<J9TP3?TI830<B8T`03
0<b>TP31QYD0`HJE0080bHbC00D0_hFG0<J:U036RY@0aXZD0;^4V@020<>8UP@0_hNH00@0b8fF0;^5
W02kQI`0aHbH0`2cPj400`30RY`0Y7fZ0=O5b0020=O5b0050=f]Y@3L/J/0g;6[0=baZ`3I][H00P3K
Yj420=ZYY0040=VRW@3HXYd0f::M0=NRW`80eYjK0P3EWI/01P3CViX0diZI0=>JV@3CVYT0diVH0=6H
V@<0d9JG0`3>U9L00`3>TiH0c9:H0<bAUP020<bAUP040<ZAVP3:SiH0bXnF0<^?U080b8jG0P38SI@0
1036SIT0ahbE0<N<U@39S9<30<F;U`050<N:T`33RiP0aHVD0<F9U032RiX00`33R9H30<:8U`040<B8
T`31R9T0`HRI0<>7U080`8VJ0P31QiH00`2oRYd0`8NG0<27U`030;n7V@040<66U@2nR9/0_XRK0<26
UP80_XVM0P2oQYL0102mRil0_XNI0;j7V@2mS:830;j8V`040<26UP2mRId0_HVM0;n6V080_HZP00D0
_XNI0;b<X`2lS:<0_HRK0;b>YP030;f9W@030;b@Z@2mRZ00_HZP00<0_8bS0`2lSZH010000000_92Y
0;b@Z@2mRZ020;^C[@050;b<X`2kU[40^iJa0;^F/@2lSZH00P2kV;@0102lT:T0^Y^i0;ZK^@2kTjd2
0;VN_@<0^J71102hY<D30;NWb@030;>`eP2fZ/d0]Z[=0080/[;H0`2a]=/40;2eg080[KWR0`2]^^<2
0:^li@030000003oool0oooo01/0oooo000?0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?oo
o`3oool05@3oool40;mdO0050;M[NP3TZID0i:VE0>BYU@3>T9400`3LWi<01@3ldYL0eiRB0=NHTP3G
V980kkRF0080dY>A0P3TZI@20<j@T@<0g9nC00D0bhfA0=NHTP3GV980eiRB0>nhUP030=:CT@030>BY
U03>T940cY2A0080gInB0P3;SI430=NIT@050<V:T@3BTi40dY>A0=:CT@3UZI<00`3>T9401P3MWi80
0000000000000000eiVA0<R:T@<0dY>A00<0aXRA0<j@T@3>T9400P3>T9430<^=T@030=NIT@38RY40
b8ZA00<0dY>A00@0aXRA0<j@T@3>T940cY2A103;SI430<R:T@80dY>A0P36R9420<n@T@040<B7TP3;
SI40bhfA0<^=T@<0b8ZA00D0dY>A0<J8T@36R940aXRA0<n@T@020<B7TP80bhfA00D0`hJC0<R;T@38
Ri40b8^A0=:DT@030<J9TP030<n@T@34Qi80a8NB0080bhfA00D0`XJC0<V;TP39Ri80bH^B0<25U@02
0<J9TP050<nATP34R9<0a8RC0<B8T`3<SY800P31QYD20<V<T`050;n5U`36RY@0aXZD0<J:U02kQ9T0
0P33R9H01@3<Si@0_hNH0;n7V02oQiP0b8fF0080^hFL00D0aHbH0;>3X@2cPj40/h>Q0<2:W0020:Am
ZP80elG80`3L/J/20=Vf]P040=^WX@3JZJ@0fZVT0=ZYY0<0f::M00<0ej:O0=JNV`3FWY/00P3EWI/4
0=>JV@030=>IV03AV9T0d9JG0080d9JG00D0dIJF0<jDU`3>U9L0cY>F0<bBV0030<bAUP<0bXnF00<0
bhnD0<R>U`38SYL00P38SI@01036SIT0ahbE0<N<U@39S9<30<F;U`050<N:T`33RiP0aHVD0<F9U032
RiX00`33R9H01036RI<0`XRG0<:8U`34R9<20<68V@80`hND00@0`8VJ0<67UP31QiH0_hZM0P30QiL0
1033Qi<0_hNI0;n7V@31QYD20;j8V`80`8JF00@0_XVM0;n6U`2oQYL0_H^O0P2nQiT40;j8V`050<26
UP2mRId0_HVM0;n6V02mRZ000P2nQiT0102lS:<0_HRK0;f8V`2lSZH30;f9W@<0_HZP00@0_XNI0;b<
X`2lS:<0_HNK0P2lSZH0102mRIh000000;b@Z@2mRZ020;^C[@030;b<X`2kU[40^iJa0080_8jV00@0
^iRd0;b@Z@2lT:T0^Y^i0P2kTjd0102iW[d0^iJa0;^F/@2iXL420;^H]080^:C50P2jVkT20;NWb@<0
]Z[=0`2e[=000`2a]=/0]:kC0;B^d`030;2eg0<0[kKN0P2]^^<20:bjh`8000003P3oool00`3ogi`0
B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool00100oooo00H0_g@007Boo`3o
ool0okmd0018W03Oool60?ooo`8000005P3oool40;mdO0050;M[NP3TZID0i:VE0>BYU@3>T9400`3L
Wi<01@3ldYL0eiRB0=NHTP3GV980kkRF0080dY>A0P3TZI@20<j@T@<0g9nC00D0bhfA0=NHTP3GV980
eiRB0>nhUP030=:CT@030>BYU03>T940cY2A0080gInB0P3;SI430=NIT@060<V:T@3BTi40dY>A0=:C
T@3UZI<0cY2A0`0000020<^=T@80eiVA00@0b8ZA0=:CT@3BTi40dY>A103>T9401@3MWi80bhfA0<^=
T@3;SI40eiVA0080b8ZA0`3BTi401036R940cY2A0<j@T@3>T9430<^=T@040=NIT@38RY40b8ZA0<R:
T@80dY>A00D0aXRA0<n@T@3?T940ci2A0<B7TP030<^=T@<0b8ZA00<0dY>A0<J8T@36R9400P3?T942
0<B7TP80bhfA00D0`hJC0<R;T@38Ri40b8^A0=:DT@020<J9TP80ci2A0P34Qi820<^=T@040<:6T`39
Ri80bH^B0<V;TP<0aXVB00<0ci6B0<B8T`34R9<00P3<SY820<66U@80bHbC00@0_hFG0<J:U036RY@0
aXZD0`33R9H01@3<Si@0_hNH0;n7V02oQiP0b8fF0080^hFL00D0aHbH0;>3X@2cPj40/h>Q0<2:W002
0:AmZP<0]m3]0P3L/J/20=Vf]P050=^WX@3JZJ@0fZVT0=ZYY03HZjX00P3HXYd20=NRW`040=JNV`3E
WI/0eIfK0=FMV`80diZI0P3CVIP01@3AV9T0d9JG0=2FU`3@UYL0dIJF0080cYBG00<0cY>F0<bBV03<
TIH00P3<TIH0103=TI@0bXnF0<Z?UP3;Si@20<R>U`80b8fD00@0aXfI0<N<U@37S9D0bHbC0`35RiL0
1@37RY<0`h^H0<F9U035RI@0`X^J00<0`hRF00D0aXVC0<:8U`32R9L0a8RC0<68V@030<>7U0030<29
VP31QiH0`HNF00<0`8NG00@0`hNC0;n7V@2oQiT0`HJE0P2nR9/20<26UP030;j9W@2oQYL0_hJG00<0
_XNI00D0`HJE0;j8V`2nR9/0_XRK0<26UP020;f9W@050;n6V02mRZ00_XNI0;j7V@2lS:<00P2mR9/4
0;f9W@040;n6V02mRZ00_HZP0;j7V@80_8bS00D0_HNK0;b>YP2lSZH0_HVN000000030;f:X0040;^C
[@2lS:<0_8bS0;^F/@80_8jV00<0^iRd0;b@Z@2lT:T00`2kTjd30;^F/@<0^iRd102jVkT0102gYlT0
^Ijm0;VN_@2fZ/d20;VQ`@80]Jc@0`2d[]<30;>`eP@0/[;H0P2_]ml20:jih@030000003oool0oooo
00`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00100oooo
00D0oooO09a800000000001809cOo`060?ooo`8000005`3oool30;mdO0030340>03TZID0i:VE0080
i:VE0`3LWi<20?cBU`<0eiRB00<0kkRF0=:CT@3BTi400P3TZI@00`3>T940g9nC0=bOT`020=bOT`<0
eiRB0P3_^9H30=:CT@030>BYU03>T940cY2A0080gInB00<0bhfA0=NIT@3GVI400P3GVI430=:CT@<0
00000P3>T9400`3MWi80bhfA0<^=T@020=NIT@050<R:T@3BTi40dY>A0=:CT@3UZI<00`3>T9401@3M
Wi80bhfA0<^=T@3;SI40eiVA0080b8ZA0`3BTi401036R940cY2A0<j@T@3>T9430<^=T@030=NIT@38
RY40b8ZA00<0dY>A00D0aXRA0<n@T@3?T940ci2A0<B7TP030<^=T@<0b8ZA00<0dY>A0<J8T@36R940
0P3?T9401034Qi80bhfA0<^=T@3;SI440<R;T@030=:DT@36RI80aXVB0080ci2A0P34Qi820<^=T@05
0<:6T`39Ri80bH^B0<V;TP3CU9400P36RI800`3?TI80a8RC0<B8T`020<b>TP80`HJE0P39S9<01@2o
QIL0aXZD0<J:U036RY@0ci:C0080`hRF00<0c8nD0;n7V02oQiP00P38SIH20;^5W080aHbH00<0/h>Q
0<2:W030RY`00P2TOJX0102hR:<0]m3]0;O@k@2gd>d30=Vf]P@0fZVT00<0f:^Z0=RRW@3GXYl00P3G
XYl0103FWY/0eIfK0=FMV`3EWI/20=>JV@80diVH00H0dIRI0=2FU`3@UYL0d9JG0=6FUP3>U9L20<jC
UP050<bBV03<TIH0c96F0<bAUP3=TI@00P3:SiH20<^?U0030<R>U`38SI@0b8fD00<0ahbE00H0bHbC
0<F;U`35RiL0aH^G0<N:T`33RiP20<F9U0@0`hRF00D0aXVC0<:8U`32R9L0a8RC0<68V@030<>7U004
0<29VP31QiH0`HNF0<B7T`80`8NG00<0`hNC0;n7V@2oQiT00P31QYD0102nR9/0`8JF0<26UP2nRId2
0;n6U`040<:6U02nQiT0_XNI0<66U@<0_XRK00D0`8JF0;f9W@2oQYP0_hJH0;f:X0020;j7V@040;b<
X`2mR9/0_HRK0;n6UP<0_HVM00@0_hJH0;f:X02mRZ00_XNI0P2lS:<01P2mQi/0_8jV0;f9WP2mRIh0
_92Y00000080_HZP00<0^i>]0;b<X`2lS:<00`2lSZH30;b@Z@040;b:X02kTjd0^i>]0;b<X`80^iJa
00@0_8jV0;^H]02kV;@0_92Y0`2jVkT30;VN_@<0^J710`2hY<D30;NWb@030;>`eP2fZ/d0]Z[=00<0
/[;H0`2a]=/20:jih@030000003oool0oooo00/0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0
_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`006`3oool00`000000oooo0?ooo`0F0?ooo`<0_gAl00<0
<@0h0>BYU@3TZID00P3TZID30=bOT`80o=:G0P3GV9820>nhUP80dY>A0P3TZI@00`3>T940g9nC0=bO
T`020=bOT`<0eiRB0P3_^9H20=:CT@80i:VD0P3>T9420=fOTP030<^=T@3GVI40eiVA0080eiVA0`00
00020>FYT`80cY2A0P3MWi820<^=T@80eiVA00D0b8ZA0=:CT@3BTi40dY>A0>FYT`030<j@T@030=fO
TP3;SI40bhfA0080eiVA0P38RY430=:CT@040<J8T@3>T940cY2A0<j@T@<0bhfA00<0eiVA0<R:T@38
RY400`3BTi401036R940ci2A0<n@T@3?T9440<^=T@<0b8ZA00<0dY>A0<J8T@36R9400P3?T9401@34
Qi80bhfA0<^=T@3;SI40eiVA00<0b8^A00<0dYBA0<J9TP36RI800P3?T9401@34Qi80bhfA0<^=T@3;
SI40`XJC00<0bH^B00@0diBA0<J9TP36RI80ci6B0P34R9<20<b>TP050<66U@39S9<0bHbC0<V<T`2o
QIL00`36RY@0103?TY<0`hRF0<>8UP3<Si@20;n7V080b8fF00D0^hFL0<F<V035S9P0aHbH0;>3X@02
0<2:W0050:AmZP2hR:<0^8RS0;R8X`1oL;P00P0PUN`20=Vf]P030<jkb03JZJ@0fZVT0080f:^Z00@0
f::M0=NRW`3GXYl0ej:O103EWI/20=>JV@80diVH0`3@UYL20=6FUP040<jDU`3>TiH0cY>F0<bBV0<0
c96F00<0cI6D0<Z?UP3;Si@00P3;Si@01038SYL0b8fD0<R=U03<SY820<N<U@030<V<T`35RiL0aH^G
0080ahZC00@0`h^H0<F9U035RI@0b8^B0`33R9H01@36RI<0`XRG0<:8U`34R9<0`HRI00<0`hND0`31
QiH01034Qi<0`8NG0<27U`33Qi<20;n7V@80`HJE00<0_XRK0<26UP30QYH00`2oQYL01032QY@0_XNI
0;j7V@31QYD20;j8V`80`8JF00@0_HVM0;n6V02oQYP0_HZP0P2nQiT30;f8V`060;n6UP2mRId0_HVM
0;f9W@2oQYP0_HZP0P2nQiT0102lS:<0_HNK0;f7V`2lSZH20;f9WP80_HZP00<000000;f:X02lS:<0
0P2lS:<0102mR9/0_8jV0;b>YP2mRIh20;b@Z@050;b:X02kTjd0^i>]0;b<X`2kU[400P2lSZH01@2k
V;@0_92Y0;b@Z@2lT:T0^Y^i0080^i>]00@0^Ijm0;^F/@2kU[40^J710P2jV;@00`2hY<D0^Y^i0;ZK
^@020;NWb@<0]Z[=0`2e[=020;6df`80]:kC00<0/;GL0000003oool0303oool02`3ogi`0B01d0;oo
o`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000K0?ooo`030000003oool0oooo
01H0oooo0P2oM7`20340>0<0i:VE00@0d=]X0=bOT`3LWi<0g9nC0P3ldYL20=NHTP80kkRF0P3BTi42
0>BYU0030<j@T@3LWi<0g9nC0080g9nC0`3GV9820>nhUP80dY>A0P3TZI@20<j@T@80gInB00<0bhfA
0=NIT@0000000P0000030=:CT@80iJVC0P3>T9420=fOTP80bhfA0P3GVI401@38RY40dY>A0=:CT@3B
Ti40iJVC00<0cY2A00<0gInB0<^=T@3;SI400P3GVI400`38RY40dY>A0=:CT@020=:CT@@0cY2A0`3;
SI400`3GVI40b8ZA0<R:T@030=:CT@040<J8T@3?T940ci2A0<n@T@<0bhfA00D0eiVA0<R:T@38RY40
b8ZA0=:CT@020<J8T@80ci2A00D0a8NB0<^=T@3;SI40bhfA0=NIT@030<R;T@030=:DT@36RI80aXVB
0080ci2A00D0a8NB0<^=T@3;SI40bhfA0<:6T`030<V;TP040=>DT@36RI80aXVB0<nATP80a8RC0P3<
SY801031QYD0bHbC0<V<T`39S9<40<J:U0040<nBT`33R9H0`hRF0<b?U080_hNH0P38SIH01@2kQI`0
aHbH0<F<V035S9P0/h>Q0080`8ZL102hR:<20:N4[P04022Ek03I][H0c[_80<jkb080fZVT0P3HZjX0
1@3HXYd0ej:O0=NRW`3GXYl0eZ>S00@0eIfK00@0diZI0=>IV03CVIP0diVI0P3@UYL20=6FUP030<jD
U`3>TiH0cY>F00@0c96F00<0cI6D0<Z?UP3;Si@00P3;Si@01038SYL0b8fD0<R=U03<SY820<N<U@80
bHbC00@0aH^G0<N:T`37RY<0`h^H0P35RI@01P38Ri80`hRF0<>8UP33R9H0aXVC0<:8U`80a8RC00D0
`HRI0<>7U033Qi@0`hND0<J9TP020<67UP030<B7T`30QiL0`8NG0080`hNC00@0_hNI0<66U@31QYD0
_XRK0P30QYH01034Qi<0_hJG0;n6U`32QY@20;j7V@030<66U@2nR9/0_XRK0080`8JF00<0_HVM0;n6
V02oQYP00`2nQiT01031QYD0_HRK0;f8V`2oQYH30;f9W@050;n6V02mRZ00_XNI0;j7V@2lS:<00P2m
Qi/30;f9WP050;j6V02mRZ00_HZP0000002nQiX00P2lS:<01@2mR9/0_8jV0;b>YP2mRIh0_92Y0080
_8ZP00@0^i>]0;b<X`2lS:<0^iJa0P2lSZH0102kV;@0_92Y0;b@Z@2lT:T30;^C[@<0^iJa0`2jV;@3
0;ZK^@040;NWb@2iW[d0^Ijm0;JZc@80^J710P2e[=040;B^d`80/k3F00<000000?ooo`3oool02P3o
ool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000K0?oo
o`8000005`3oool20;mdO0030340>03TZID0i:VE0080i:VE00<0d=]X0=bOT`3LWi<00`3ldYL20=NH
TP80kkRF00D0dY>A0>BYU03TZI@0i:VD0<j@T@040=bOT`<0eiRB0P3_^9H20=:CT@80i:VD00@0cY2A
0=fOTP3MWi80gInB0P0000030=NIT@<0dY>A0P3UZI<20<j@T@80gInB00@0bhfA0=NIT@3GVI40eiVA
103BTi401@3UZI<0cY2A0<j@T@3>T940gInB0080bhfA0P3GVI400`38RY40dY>A0=:CT@020=:CT@<0
cY2A00D0gInB0<^=T@3;SI40bhfA0=NIT@020<R:T@<0dY>A00@0aXRA0<n@T@3?T940ci2A0`3;SI40
0`3GVI40b8ZA0<R:T@020=:CT@80aXRA0P3?T9401@34Qi80bhfA0<^=T@3;SI40eiVA0080b8^A0P3B
U9420<J9TP80ci2A00@0a8NB0<^=T@3;SI40bhfA1039Ri80103CU940aXVB0<J9TP3?TI820<B8T`80
c8jB00D0`HJE0<V<T`39S9<0bHbC0=>ETP030<J:U0040<nBT`33R9H0`hRF0<b?U080_hNH0P38SIH0
102kQI`0aHbH0<F<V035S9P30<2:W0050<^CVP2hR:<0^8RS0;R8X`36TYl00P2WQ:h40<jkb0030=ZY
Y03HZjX0f:^Z00@0ej:O00<0eZ>S0=FMV`3EWI/00P3EWI/0103CVYT0diVH0=>IV03CVIT20=2FU`80
dIJF00@0cYBG0<jCUP3>TiH0d9BE0`3<TIH00`3=TI@0bXnF0<^?U0020<^?U0040<R>U`38SI@0b8fD
0<b>TP80ahbE0P39S9<00`35RiL0ahZC0<N:T`030<F9U0060<R;TP33R9H0`hRF0<>8UP36RI<0`XRG
0P34R9<01@31R9T0`hND0<>7U033Qi@0aXVB0080`HNF00<0a8NC0<27U`30QiL00P33Qi<0102oQiT0
`HJE0<66U@2nR9/20<26UP040<B7T`2oQYL0_hJG0<:6U080_XNI0P31QYD0102nR9/0`8JF0<26UP2m
RId20;n6V0040<:6U02nQiT0_XNI0<66U@80_HRK00<0_hJF0;f9W@2mRId00P2oQYP0102mRZ00_XNI
0;j7V@2lS:<20;f7V`040;n6UP2mRIh0_HVN0;j6V080_HZP00H000000;j7VP2lS:<0_8bS0;f8V`2l
SZH20;f9WP040;b@Z@2lRZ00_8ZP0;^C[@80_8bS0`2lSZH40;b@Z@040;b:X02kTjd0^i>]0;b<X`80
^iJa00@0_8jV0;ZH]02jV;@0_92Y0P2jVkT30;VN_@<0^J710`2hY<D40;NWb@80/k3F00<000000?oo
o`3oool02@3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0
oooo000K0?ooo`030000003oool0oooo01H0oooo00@0_gAl0340>03oool0oooo0P3TZID0103@ffP0
oooo0=bOT`3LWi<30?cBU`80eiRB0P3_^9H0103BTi40i:VD0>BYU03TZI@40=bOT`030?gCU@3GV980
eiRB00<0kkRF0P3BTi420>BYU0040<j@T@0000000000000000@0eiVA00@0l;RE0=:CT@3BTi40dY>A
0P3UZI<20<j@T@80gInB00D0bhfA0=NIT@3GVI40eiVA0?2iU0030=:CT@030>FYT`3>T940cY2A0080
gInB0P3;SI420=NIT@030<R:T@3BTi40dY>A0080dY>A0`3>T9400`3MWi80bhfA0<^=T@020=NIT@80
b8ZA0`3BTi401036R940ci2A0<n@T@3?T9430<^=T@030=NIT@38RY40b8ZA0080dY>A00@0aXRA0<n@
T@3?T940ci2A103;SI400`3GVI40b8^A0<R;T@020=:DT@80aXVB0P3?T9401@34Qi80bhfA0<^=T@3;
SI40eiVA00<0bH^B00@0diBA0<J9TP36RI80ci6B0P34R9<20<b>TP050<66U@39S9<0bHbC0<V<T`3C
UI800`36RY@01@3?TY<0`hRF0<b?U03<Si@0_hNH00<0b8fF00D0^hFL0<F<V035S9P0aHbH0<nEU`02
0<2:W0050<^CVP2hR:<0^8RS0;R8X`36TYl00P2WQ:h01008>;T0c[_80<jkb03>^lP30=R[ZP030=:^
]03GXYl0ej:O0080eZ>S103EWI/30=>IV0030=>IV@3@UYL0d9JG0080dIJF00@0cYBG0<jCUP3>TiH0
d9BE0`3<TIH00`3=TI@0bXnF0<^?U0020<^?U0<0b8fD00<0c8jB0<N<U@39S9<00P39S9<01035RiL0
ahZC0<N:T`3;SI820<F9U0030<R;TP33R9H0`hRF0080aXVC00<0`XRG0<B8T`34R9<01033Qi@01@36
RI80`HNF0<67UP34Qi<0`8NG00<0`hNC00<0_hNI0<66U@31QYD00`30QYH01034Qi<0_hJG0;n6U`32
QY@20;j7V@80`HJE00<0_XRK0<26UP30QYH00`2oQYP01032QY@0_XNI0;j7V@31QYD20;f8V`80_hJF
00@0_HVM0;n6V02oQYP0_HZP0P2nQiT30;f7V`040;n6UP2mRIh0_HVN0;j6V0<0_HZP00D000000;b<
X`2mR9/0_HRK0;b>YP020;f9WP<0_8ZP0`2lS:<0102mR9`0_8jV0;b>YP2mRIh30;b@Z@050;b:X02k
Tjd0^i>]0;b<X`2kU[400P2lSZH00`2jV;@0_92Y0;b@Z@020;ZK^@050;^C[@2iW[d0^iJa0;^F/@2i
XL400P2jV;@00`2hY<D0^Y^i0;ZK^@030;NWb@80]Z[=00<000000?ooo`3oool01`3oool03@2oM000
001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool001/0oooo
00<000000?ooo`3oool05P3oool0102oM7`0oooo0?ooo`3oool20>BYU@80oooo0P3LWi<30?cBU`05
0=NHTP3_^9H0kkRF0>nhUP3BTi400`3TZI@01@39ef00g9nC0=bOT`3LWi<0oM>E0080eiRB0`3_^9H2
0=:CT@<000000`3MWi801@3mdi@0eiVA0=NIT@3GVI40l;RE0080dY>A0`3UZI<20<j@T@80gInB00D0
bhfA0=NIT@3GVI40eiVA0?2iU0020=:CT@80iJVC0P3>T9420=fOTP80bhfA0P3GVI400`38RY40dY>A
0=:CT@020=:CT@<0cY2A00<0gInB0<^=T@3;SI400P3GVI400`38RY40dY>A0=:CT@020=:CT@040<J8
T@3?T940ci2A0<n@T@<0bhfA00<0eiVA0<R:T@38RY400P3BTi401@36R940ci2A0<n@T@3?T940gInA
00<0bhfA00<0eiVA0<R;T@38Ri400P3BU9420<J9TP80ci2A00D0a8NB0<^=T@3;SI40bhfA0=NIT@03
0<V;TP050=>DT@36RI80ci6B0<nATP34R9<00`3<SY801@31QYD0bHbC0<V<T`39S9<0diFB0080aXZD
0P3?TY<01033R9H0c8nD0<b?U02oQiP30<R=UP@0aHbH00@0ciFG0<2:W030RY`0bi>J0P2hR:<20<JB
W`80YhB^00<0_I6Y0:Nkj02W^nP00P2W^nP00`3HZjX0dZjd0=:^]0020=NRW`80eZ>S103EWI/01@3D
WYh0diVH0=>IV03CVIT0d9JG00<0dIJF00@0cYBG0<jCUP3>TiH0d9BE0P3<TIH20<fAU0050<Z?UP3;
Si@0bhnD0<^?U03>T9<00P38SI@00`3<SY80ahbE0<V<T`020<V<T`040<F;U`37RY<0ahZC0<^=TP80
aHVD00<0b8^B0<>8UP33R9H00P36RI<01032R9L0a8RC0<B8T`39Ri430<>7U0050<J9TP31QiH0`HNF
0<B7T`30QiL00`33Qi<0102oQiT0`HJE0<66U@35R9820<26UP030<B7T`2oQYL0_hJG0080`XJD00@0
_XNI0<66U@31QYD0_XRK0P30QYH01033Qi<0_hJH0;n6V032QY@20;j7V@030<66U@2mR9/0_HRK0080
_hJF00<0_HVM0;n6V02oQYP00`2nQiT01030QYD0_HNK0;f7V`2oQYH20;f9WP80_XJH00@0_HZP0;j7
VP2nQiX000000P2mR9/30;f9WP040;j6V02lRZ00_8ZP0;j7VP80_8bS00@0_HRL0;b>YP2lSZH0_HVN
0P2lT:T20;b:X0040;^C[@2lS:<0_8bS0;^F/@80_8jV00@0^YRd0;b@Z@2lT:T0^Y^i0P2kTjd30;^F
/@<0^YRd0`2jVkT20;NWb@050;ZN_@2fZ/d0]Z[=0;VQ`@0000002@3oool02`3o_g@000000000M02o
ool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo000J0?ooo`030000003oool0oooo01/0
oooo00D0i:VE0=3KJ03oool0oooo0=bOT`040?cBU`050=NHTP3_^9H0kkRF0>nhUP3BTi400`3TZI@0
1@39ef00g9nC0=bOT`3LWi<0oM>E0080eiRB0P3_^9H300000080i:VD00D0cY2A0=fOTP3MWi80gInB
0?gCU0030=NIT@030?2hU@3BTi40dY>A00<0iJVC00D0cY2A0=fOTP3MWi80gInB0<^=T@030=NIT@03
0?2iU03BTi40dY>A0080iJVC0P3>T9420=fOTP050<^=T@3GVI40eiVA0=NIT@38RY40103BTi430<j@
T@030=fOTP3;SI40bhfA0080eiVA00<0b8ZA0=:CT@3BTi400P3BTi430<n@T@050=fOTP3;SI40bhfA
0<^=T@3GVI400P38RY420=:CT@050<J8T@3?T940ci2A0<n@T@3MWi400`3;SI400`3GVI40b8^A0<R;
T@020=:DT@050<J9TP3?T940ci2A0<n@T@34Qi800`3;SI400`3GVI40bH^B0<V;TP020=>DT@040<J9
TP3?TI80ci6B0<B8T`<0c8jB1039S9<00`3CUI80aXZD0<J:U0020<nBT`040<>8UP3<Si@0c8nD0;n7
V0<0b8fF00D0diNE0<F<V035S9P0aHbH0<nEU`020<2:W0030<^CVP2hR:<0^8RS0080aY:O00D0YhB^
0;fAZ@2mTJT0_I6Y075ba@020:Nkj0040=R[ZP3B[[@0dZjd0=NRW`<0eZ>S103EWI/01@3DWYh0diVH
0=>IV@3CVIT0d9JG00<0dIJF0`3>TiH00`3@U9D0c96F0<bAUP020<fAU0050<Z?UP3;Si@0bhnD0<^?
U03>T9<00P38SI@00`3<SY80ahbE0<V<T`020<V<T`040<F;U`37RY<0ahZC0<^=TP80aHVD0P38Ri80
1033R9H0aXVC0<J9T`32R9L20<B8T`060<V;T@33Qi@0`hND0<>7U036RI80`HNF0P34Qi<01030QiL0
`hNC0<>7T`33Qi<30<66U@040<F8TP30QYH0`8JF0<B7T`80_hJG0P32QY@00`2nQiT0`HJE0<66U@03
0<26UP040<>7T`2oQYP0_hJH0<:6U080_XNI0P31QYD0102mR9/0_hJF0;n6UP2mRId20;n6V0040<:6
U02nQiT0_XNI0<26U@80_HNK00<0_hJF0;f9WP2mRIh00P2nQYP0102mRZ00_XNJ0;j7VP0000020;f8
V`040;n6U`2mRIh0_HVN0;j6V080_8ZP00<0_XNJ0;b<X`2lS:<00P2mR9`0102lSZH0_HVN0;f9WP2l
T:T20;b:X0030;^C[@2lS:<0_8bS00<0_8jV0`2lT:T30;^C[@040;b<X`2kU[40^iJa0;b>YP80^YRd
00<0_92Y0;ZK^@2jVkT00`2jW[d30;VQ`@030000003oool0oooo00P0oooo00<0omnL04P0M02oool0
0P3oool01@3ookl0M00000000000B9`0gooo00@0oooo000J0?ooo`030000003oool0oooo01/0oooo
00D0i:VE0?ooo`3oool0oooo0=bOT`040?cBU`040=NHTP3_^9H0kkRF0>nhUP<0i:VD00@0bMMP0?oo
o`3LWi<0g9nC0P3mdiD01P3GV9800000000000000000kkRF0=:CT@<0i:VD00D0cY2A0=fOTP3MWi80
gInB0?gCU0030=NIT@030?2hU@3BTi40dY>A00<0iJVC00D0cY2A0=fOTP3MWi80gInB0<^=T@030=NI
T@030?2iU03BTi40dY>A0080iJVC0P3>T9420=fOTP040<^=T@3GVI40eiVA0=NIT@@0dY>A00D0iJVC
0<j@T@3>T940cY2A0=fOTP020<^=T@80eiVA00<0b8ZA0=:CT@3BTi400P3BTi430<n@T@030=fOTP3;
SI40bhfA0080eiVA0P38RY420=:CT@050<J8T@3?T940ci2A0<n@T@3MWi400P3;SI420=NIT@80b8^A
0P3BU9401036RI80ci2A0<n@T@3?T9440<^=T@030=NIT@39Ri80bH^B0080diBA00@0aXVB0<nATP3?
TI80a8RC0`3<SY801@3HVY80bHbC0<V<T`39S9<0diFB0080aXZD0P3?TY<01033R9H0c8nD0<b?U02o
QiP30<R=UP030=>GU@35S9P0aHbH0080ciFG00@0`8ZL0<^CVP3;TiX0^8RS0`36TYl40;fAZ@80YHnn
00D057[T0=:^]03B[[@0dZjd0=NRW`030=JSX`<0eIfK0P3DWYh0103CVIP0diVI0=>IV@3@UYL30=6F
UP030=:GU`3>TiH0cY>F0080d9BE00<0c96F0<fAU03=TI@0103;Si@01@3>T9<0b8fD0<R=U03<SY80
ahbE00<0bHbC0`37RY<00`3;SI80aHVD0<F9U0020<R;TP040<>8UP36RI<0aXVC0<:8U`80a8RC00H0
bH^A0<>7U033Qi@0`hND0<J9TP31QiH20<B7T`050<27U`33Qi<0`hNC0<>7T`38RI400P31QYD00`35
R980`8JF0<26UP020<B7T`040;n6U`32QY@0`XJD0;j7V@80`HJE00@0aHRB0<26UP30QYH0`hNC0P2o
QYP00`32QY@0_XNI0;j7V@020<66U@030;f8V`2oQYH0_hJF00<0_hJH00@0`XJD0;j7V@2nQiT0`8JE
0P2mQi/20;n6UP040;f9WP2nQYP0_XJH0;f:X080_XNJ00@0_HRK0000002mR9/0_hJG0P2mRIh0102n
QYP0_8ZP0;b:X02nQiX20;b<X`80_HRL00<0_8jV0;f9WP2mRIh00`2lRZ030;b<X`040;f8W02lSZH0
_8jV0;f9WP80_92Y00D0_8ZP0;^C[@2kTjd0_8bS0;^F/@020;b>YP030;ZH]02lT:T0_92Y0080^Y^i
00@0^i>]0;ZN_@2kU[40^iJa0P2iXL400`000000oooo0?ooo`0F0?ooo`006P3oool3000001l0oooo
00<0g9nC0?cBU`3oool00P3oool30>nhUP80oooo0P3TZI@20?ooo`80g9nC0`0000040>nhUP040=:C
T@3TZI@0i:VD0>BYU0<0gInB0P3mdi@20=NIT@80l;RE0P3BTi430>FYT`040<j@T@3MWi80gInB0=fO
TP@0eiVA00<0l;VD0=:CT@3BTi400P3UZI<20<j@T@80gInB00D0bhfA0=NIT@3GVI40eiVA0?6iU003
0=:CT@030>FYT`3>T940cY2A0080gInB0P3;SI420=NIT@030<R:T@3BTi40dY>A0080dY>A0`3?T940
0`3MWi80bhfA0<^=T@020=NIT@050<R:T@3BTi40dY>A0=:CT@36R9400`3?T9400`3MWi40bhfA0<^=
T@020=NIT@80b8^A0P3BU9401@36RI80ci2A0<n@T@3?T940gInB00<0bhfA00<0eiVA0<V;TP39Ri80
0P3CU9401036RI80ci6B0<nATP34R9<30<b>TP030=RJTP39S9<0bHbC0080diFB0P36RY@20<nBT`03
0<>8UP3<Si@0c8nD00@0b8fF00<0diNE0<F<V035S9P00P3?UIL01030RY`0bi>J0<^CVP2hR:<30<JB
W`050=>MWP2mTJT0_I6Y0;fAZ@3=WJH00P2USkh00`0DN^@0dZjd0=:^]0040=JSX`030=>VZP3EWI/0
eIfK0080e9jN00@0diVH0=>IV@3CVIT0d9JG0`3AUYH00`3BUiL0cY>F0<jCUP020=2DU@040<bAUP3=
TI@0cI6D0=6DT`<0bhnD00D0cY2C0<R=U03<SY80c8jB0<N<U@030<V<T`040<j?T@37RY<0ahZC0<^=
TP80aHVD0P38Ri800`33R9H0aXVC0<J9T`030<B8T`060<V;T@33Qi@0`hND0<>7U036RI80`HNF0P34
Qi<01@30QiL0`hNC0<>7T`33Qi<0b8VA0080`HJE00<0aHRB0<26UP30QYH00P34Qi<0102oQYL0`XJD
0<:6U02nQiT20<66U@040<F8TP30QYH0`8JF0<>7T`80_hJH0P32QY@0102nQiT0`HJE0<66U@2mR9/2
0;n6UP040<>6T`2oQYP0_hJH0<:6U080_XNI00<0`8JE0;f7V`2mQi/00P2oQYH00`2mRIh0_XJH0;j6
V0030;j7VP040<26U@2mR9/000000;n6U`80_HVN0P2nQYP0102lRZ00_XNJ0;j7VP2lS:<20;f8W0<0
_HVN00@0_XJH0;b:X02lRZ00_XNJ0P2lS:<0102mR9`0_8jV0;b>YP2mRIh20;b@Z@050;b:X02kTjd0
_8bS0;b<X`2kU[400P2lSZH0102jV;@0_92Y0;b@Z@2jVkT20;^C[@<0^iJa0P3oool00`000000oooo
0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`0U0?ooo`040>nhUP3oool0oooo0?ooo`80i:VD
00@0oooo00000000000000000P3mdiD00`3GV980kkRF0>nhUP020>nhUP050=:CT@3TZI@0i:VD0>BY
U032dEP00P3MWi820?gCU080eiVA0P3`^9D20=:CT@<0iJVC00D0cY2A0=fOTP3MWi80gInB0?kCTP02
0=NIT@80l;VD0P3BTi420>FYT`050<j@T@3MWi80gInB0=fOTP3;SI400`3GVI401@3a^I@0dY>A0=:C
T@3BTi40iJVC0080cY2A0P3MWi801@3;SI40eiVA0=NIT@3GVI40b8ZA00@0dY>A0`3?T9400`3MWi80
bhfA0<^=T@020=NIT@040<R:T@3BTi40dY>A0=:CT@@0ci2A00<0gInA0<^=T@3;SI400P3GVI420<R;
T@80dYBA00D0aXVB0<n@T@3?T940ci2A0=fOTP030<^=T@030=NIT@39Ri80bH^B0080diBA00@0aXVB
0<nATP3?TI80a8RC0`3<SY800`3HVY80bHbC0<V<T`020=>ETP80aXZD0P3?TY<01033R9H0c8nD0<b?
U03HVi@30<R=UP030=>GU@35S9P0aHbH0080ciFG00<0`8ZL0<^CVP3;TiX01036TYl00`3CWIh0_I6Y
0;fAZ@020<fMYP040:F?_P32XKL0`Z6g0=:^]080`k790`3FXj<00`3CYZX0eIfK0=FMV`020=BNWP03
0=>IV03CVIT0diVI00@0dIJF00<0dYNG0<jCUP3@U9D00P3@U9D0103<TIH0cI6D0<fAU03AU9<30<^?
U0050<j@T`38SI@0c8jB0<b>TP37S9D00`39S9<0103>Si40ahZC0<N:T`3;SI820<F9U080b8^B00@0
`hRF0<J9T`36RI<0bhfA0P34R9<00`39Ri40`hND0<>7U0020<J9TP040<67UP34Qi<0a8NC0<27U`<0
`hNC00D0b8VA0<66U@31QYD0aHRB0<26UP030<B7T`030;n6U`32QY@0`XJD00<0`HJE00@0aHRB0<26
UP30QYH0`hNC0P2oQYP20<:6U0030;j7V@31QYD0`HJE00<0_hJF00@0`hJC0;n6V02oQYP0`XJD0P2n
QiT20<26U@040;f7V`2oQYH0_hJF0;f9WP80_XJH00@0`XJD0;j7VP2nQiX0`8JE0P2mR9/00`000000
_HVN0;f9WP020;j6V0040;b:X02nQiX0_XNJ0;b<X`80_HRL00@0_hJG0;f9WP2mRIh0_XJH0P2lRZ00
1@2nQiX0_8bS0;b<X`2mR9`0_8jV0080_HVN00@0_92Y0;b:X02lRZ00^i>]0P2lS:<30;b>YP<0_92Y
0`2kTjd00`2lS:<0^iJa0;^F/@030?ooo`030000003oool0oooo01D0oooo000=0?ooo`050?noM000
000000000000B02Lgol0203oool00`000000oooo0?ooo`0Y0?ooo`050>BYU000000000000?ooo`3L
Wi<00`3mdiD00`3GV980kkRF0>nhUP020>nhUP@0i:VD00<0`]5H0=fOTP3MWi800P3mdi@20=NIT@80
l;RE00<0dY>A0>FYT`3UZI<00P3UZI<01@3>T940gInB0=fOTP3MWi80o]>B0080eiVA0P3`^I@20=:C
T@80iJVC00D0cY2A0=fOTP3MWi80gInB0<^=T@030=NIT@050?6iU03BTi40dY>A0=:CT@3UZI<00P3>
T9420=fOTP040<^=T@3GVI40eiVA0=NIT@D0dY>A0`3?T9400`3MWi80bhfA0<^=T@020=NIT@050<R:
T@3BTi40dY>A0=:CT@3VZI800`3?T9400`3MWi40bhfA0<^=T@020=NIT@050<R;T@3BU940dYBA0=:D
T@36RI800`3?T9400`3MWi80bhfA0<^=T@020=NIT@80bH^B0P3CU9400`36RI80ci6B0<nATP040<b>
TP030=RJTP39S9<0bHbC0080diFB00D0aXZD0<nBT`3?TY<0ci:C0<>8UP020<b?U0050=RKU038SIH0
b8fF0<R=UP3CUiD00P35S9P20<nEU`040<2:W03;TiX0bi>J0=NOVP<0aY:O00<0difN0;fAZ@2mTJT0
0P3=WJH30<:Q]`<0`k790P3FXj<20=>VZP050=FMV`3DWYh0e9jN0=BNWP3CVIP00P3CVIT01P3DW9/0
dIJF0=6FUP3AUYH0dYNG0<jCUP<0d9BE00@0c96F0<fAU03=TI@0dIBC0`3;Si@01@3>T9<0b8fD0<b>
TP3<SY80ahbE00<0bHbC00<0cXnA0<N:T`37RY<00P3;SI801035RI@0b8^B0<R;TP33R9H20<J9T`04
0<^=T@34R9<0a8RC0<V;T@80`hND0P36RI800`31QiH0a8NC0<B7T`040<>7T`050<R9T@31QYD0`HJE
0<F8TP30QYH00`34Qi<0102oQYL0`XJD0<:6U037RI420<66U@030<F8TP30QYH0`8JF0080`hNC00@0
_hJH0<:6U032QY@0_XNI0P31QYD01035Qi80_hJF0;n6UP33QY<20;n6V0030<:6U02nQiT0_XNI0080
`8JE00<0_HNK0;n6UP2oQYH00`2nQYP01032QY@0_XNJ0;j7VP30QYD20;f8V`030000002oQYL0_HVN
0080_XJH00<0_8ZP0;j7VP2nQiX00`2mR9`0102oQYL0_HVN0;f9WP2nQYP20;b:X0050;j7VP2lS:<0
_HRL0;f8W02lSZH00P2mRIh00`2lT:T0_8ZP0;b:X0030;b<X`040;f8W02lSZH0_8jV0;f9WP80_92Y
00@0_8ZQ0;^C[@2kTjd0_8bS0P2kU[430?ooo`030000003oool0oooo01D0oooo000<0?ooo`070?oO
W01804P0W=oo0?ooo`3o_g@0001d0;ooo`070?ooo`030000003oool0oooo02L0oooo0`0000030?oo
o`050=bOT`3mdiD0oooo0?gCU@3GV9800`3_^9H20?ooo`80i:VD00@0oooo0<;AF03MWi80gInB0P3m
di@20=NIT@80l;RE00<0dY>A0>FYT`3UZI<00P3UZI<30=fOTP80o]>B0P3GVI420?2iU0050=:CT@3U
ZI<0iJVC0>FYT`3>T9400`3MWi840=NIT@050?6iU03BTi40dY>A0=:CT@3UZI<00P3>T9420=fOTP05
0<^=T@3GVI40eiVA0=NIT@3a^I<00`3BTi400`3UZI80ci2A0<n@T@020=fOTP80bhfA0P3GVI401@38
RY40dY>A0=:CT@3BTi40iZVB0080ci2A0P3MWi420<^=T@80eiVA00D0b8^A0=:DT@3BU940dYBA0<J9
TP030<n@T@030=fOTP3;SI40bhfA0080eiVA0P39Ri820=>DT@040<J9TP3?TI80ci6B0=fPTP<0c8jB
00<0f9ZB0<V<T`39S9<00P3CUI801036RY@0ci:C0<nBT`3?TY<30<b?U0060=RKU038SIH0b8fF0<R=
UP3CUiD0aHbH0`3?UIL30<^CVP030=NOVP36TYl0aY:O0080difN00D0_I6Y0<fMYP3=WJH0cIfV0=^[
Y@020<:Q]`050=B^/@33/LT0`k790<>ab@3FXj<00P3CYZX0103EWI/0e9jN0=BNWP3DWYh30=>IV@06
0=BLV`3AUYH0dIJF0=6FUP3BUiL0cY>F0`3@U9D30<fAU0060=6DT`3;Si@0bhnD0<^?U03>T9<0b8fD
0P3<SY840<V<T`030<j?T@37RY<0ahZC0080bhfB00<0aHVD0<R;TP38Ri800`36RI<00`3;SI40a8RC
0<B8T`020<V;T@040<>7U036RI80aXVB0<67UP80a8NC00D0bXbA0<>7T`33Qi<0`hNC0<R9T@020<66
U@030<F8TP30QYH0a8NC0080a8NC00@0_hJG0<:6U032QY@0ahVA0P31QYD00`35R980`8JF0<26UP02
0<>7T`040;n6V032QY@0`XJD0;j7V@80`HJE00@0aHNB0;n6UP2oQYH0`hJC0P2oQYP20<:6U0040;j7
V@30QYD0`8JE0;f7V`80_hJF00@0`hJC0;j6V02nQYP0`XJD0P2nQiX01P30QYD0_HRK0;f8V`2oQYL0
00000;f9WP80_XJH0`2nQiX01030QYD0_HRL0;f8W02oQYL20;f9WP050;j6V02lRZ00_XNJ0;j7VP2l
S:<00P2mR9`00`2lSZH0_HVN0;f9WP030;b:X0040;j7VP2lS:<0_8bS0;f8W080_8jV00@0_HVN0;b@
Z@2lT:T0_8ZQ0P2kTjd20;b<X`050;^F/@3oool0oooo0?ooo`0000005`3oool000`0oooo00L0okmd
0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00<000000?ooo`0000009@3oool3000000H0oooo
00@0g9nC0?ooo`3oool0oooo0`3_^9H30?ooo`80i:VD00<0oooo0<;AF03MWi800`3mdi@01@3GVI40
l;RE0?2hU@3`^9D0dY>A00@0iJVC0`3MWi820?kCTP80eiVA0P3`^I@01@3BTi40iJVC0>FYT`3UZI<0
cY2A00<0gInB00<0o]B@0=NIT@3GVI400P3a^I@20=:CT@80iJVC0P3>T9420=fOTP050<^=T@3GVI40
eiVA0=NIT@3a^I<00`3BTi400`3UZI80ci2A0<n@T@020=fOTP050<^=T@3GVI40eiVA0=NIT@38RY40
0`3BTi400`3VZI80ci2A0<n@T@020=fOT@80bhfA0P3GVI401038Ri40dYBA0=:DT@3BU9440<n@T@03
0=fOTP3;SI40bhfA0080eiVA00D0bH^B0=>DT@3CU940diBA0<J9TP020<nATP030=fPTP3<SY80c8jB
0080f9ZB0P39S9<20=>ETP050<J:U03?TY<0ci:C0<nBT`3MXI@00P3<Si@00`3HVi@0b8fF0<R=UP02
0=>GU@050<F<V03?UIL0ciFG0<nEU`3LXiP00P3;TiX00`3GWiX0aY:O0<JBW`020=>MWP@0cIfV00@0
fj^U0<:Q]`3D[[40e:ja0`33/LT30=>VZP@0e9jN00@0eJ>T0=>IV@3CVIT0e9bK0P3AUYH20=:GU`05
0<jCUP3@U9D0d9BE0=2DU@3DV9D00P3=TI@00`3AU9<0bhnD0<^?U0020<j@T`040<R=U03<SY80c8jB
0=6CTP<0bHbC00<0cXnA0<N:T`3;SI800P3;SI801035RI@0b8^B0<R;TP3?T9420<J9T`030<^=T@34
R9<0a8RC0080bH^A00@0`hND0<J9TP36RI80`HNF0P34Qi<01P3:S940`hNC0<>7T`33Qi<0b8VA0<66
U@80aHRB00@0`8JF0<B7T`34Qi<0a8NC0`32QY@01037RI40`HJE0<66U@35R9820<26UP80`hNC00<0
_hJH0<:6U032QY@00`31QYD01035Qi80_hJF0;n6UP33QY<20;n6V080`XJD00<0_XNI0<26U@30QYD0
0`2oQYH01033QY<0_XJH0;j6V032QY@20;j7VP80`8JE00@0_HRK0;n6U`2oQYL000000P2nQYP01031
QY@0_XNJ0;j7VP30QYD20;f8W0050;n6U`2mRIh0_XJH0;j6V02lRZ000P2nQiX00`2lS:<0_HRL0;f8
W0030;f9WP040;j6V02lRZ00_8ZP0;j7VP80_8bS00<0_HRL0;b>YP2lSZH00P2mRIh0102lT:T0_8ZQ
0;b:X@2kTjd20;b<X`@0oooo00<000000?ooo`3oool05@3oool000`0oooo00L0omnL04P0B02Lgol0
oooo0?noM00007@0_ooo00H0oooo0P00000S0?ooo`<000004`3oool01@3TZI@0oooo0?ooo`32dEP0
gInB00<0oM>D00D0eiVA0?2hU@3`^9D0l;RE0=:CT@040>FYT`<0gInB0P3ndi820=NIT@80l;VD00D0
dY>A0>FYT`3UZI<0iJVC0<j@T@030=fOTP030?kDT03GVI40eiVA0080lKVD0P3BTi420>FYT`050<j@
T@3MWi80gInB0=fOTP3;SI400`3GVI401@3a^I<0dY>A0=:CT@3BTi40iJVB0080ci2A0P3MWi80103;
SI40eiVA0=NIT@3GVI440=:CT@030>JYTP3?T940ci2A0080gInA0P3;SI420=NIT@050<R;T@3BU940
dYBA0=:DT@3VZI800`3?T9400`3MWi80bhfA0<^=T@020=NIT@050<V;TP3CU940diBA0=>DT@36RI80
0P3?TI800`3MX980c8jB0<b>TP020=RJTP80bHbC0P3CUI801@36RY@0ci:C0<nBT`3?TY<0gJ6D0080
c8nD00<0f9^D0<R=UP38SIH00P3CUiD01@35S9P0ciFG0<nEU`3?UIL0g:>H0080bi>J0P3GWiX01036
TYl0difN0=>MWP3P[9l30<fMYP040=^[Y@32XKL0e:ja0=B^/@80h;R^0P1jZO420=>VZP050<f^^`3D
WYh0e9jN0=BNWP3EXj@00P3CVIT00`3DW9/0dIJF0=6FUP020=:GU`050<jCUP3@U9D0d9BE0=2DU@3D
V9D00P3=TI@00`3AU9<0bhnD0<^?U0020<j@T`040<R=U03<SY80c8jB0=6CTP<0bHbC00<0cXnA0<N:
T`3;SI800P3;SI801035RI@0b8^B0<R;TP3?T9420<J9T`030<^=T@34R9<0a8RC0080bH^A00<0`hND
0<J9TP36RI800`34Qi<01P3:S940`hNC0<>7T`33Qi<0b8VA0<66U@80aHRB00D0`8JF0<B7T`34Qi<0
a8NC0<V;T@020<:6U0030<N9T@31QYD0`HJE0080aHRB00@0`8JF0<>7T`33Qi<0_hJH0P32QY@01037
RI40`HJE0<66U@35Qi820;n6UP80`hJC00@0_hJH0<:6U032QY@0_XNI0P30QYD01035Qi80_hJF0;n6
UP33QY<20;j6V0030<:6U02nQiX0_XNJ0080`8JE00L0_HRK0;n6U`2oQYL0_XJH0000002nQYP0`HJD
0080_XNJ00D0`8JE0;f8W02oQYL0_hJG0;f9WP020;j6V0030;b:X02nQiX0_XNJ00<0_HRL00@0_hJG
0;f9WP2mRIh0_XJH0P2lRZ000`2nQiX0_8bS0;b<X`020;f8W0040;b>YP2mRIh0_HVN0;b@Z@80_8ZQ
0`2lS:<40?ooo`030000003oool0oooo01D0oooo000=0?ooo`050?oo_`1d000000000018W03Oool0
1`3oool00`000000oooo0?ooo`0O0?ooo`<000005P3oool01@3TZI@0oooo0?ooo`3oool0gInB00<0
oM>D00@0eiVA0?2hU@3`^9D0l;RE103UZI<00`3oool0gInB0=fOTP030?kCTP050=NIT@3`^I@0l;VD
0?2iU03BTi400`3UZI<40=fOTP030?kDT03GVI40eiVA0080lKVD0P3BTi420>FYT`040<j@T@3MWi80
gInB0=fOTP@0eiVA00D0lKVC0=:CT@3BTi40dY>A0>FYTP020<n@T@80gInB00D0bhfA0=NIT@3GVI40
eiVA0?6iT`030=:CT@030>JYTP3?T940ci2A0080gInA00D0bhfA0=NIT@3GVI40eiVA0<R;T@030=:D
T@030>JYTP3?T940ci2A0080gInB0P3;SI420=NIT@040<V;TP3CU940diBA0=>DT@<0ci6B00<0gJ2B
0<b>TP3<SY800P3HVY801@39S9<0diFB0=>ETP3CUI80aXZD00<0ci:C00<0gJ6D0<b?U03<Si@00P3H
Vi@00`38SIH0diNE0=>GU@040<nEU`030=bSV03;TiX0einJ0080einJ00@0aY:O0=>MWP3CWIh0h:bO
0P3=WJH20=^[Y@<0e:ja0P3P^:h00`3X_j`0NZWa0=>VZP020<f^^`<0e9jN00<0eJ>T0=>IV@3DW9/0
0P3DW9/0103AUYH0dYNG0=:GU`3>TiH30=2DU@030=BHU@3=TI@0cI6D0080dIBC00@0bhnD0<j@T`3>
T9<0b8fD0P3<SY801P3ATi80bHbC0<V<T`39S9<0cXnA0<N:T`<0bhfB00@0aHVD0<R;TP38Ri80ci2A
0P36RI<00`3;SI40a8RC0<B8T`020<V;T@040<>7U036RI80aXVB0<f>T080a8NC00H0bXbA0<>7T`33
Qi<0`hNC0<R9T@31QYD20<F8TP050<26UP34Qi<0a8NC0<B7T`39Ri400P32QY@00`37RI40`HJE0<66
U@020<F8TP040<26UP33Qi<0`hNC0;n6V080`XJD00@0ahVA0<66U@31QYD0aHNB0P2oQYH20<>6T`04
0;n6V032QY@0`XJD0;j7V@80`8JE00@0aHNB0;n6UP2oQYH0`hJC0P2nQYP20<:6U0040;j7VP30QYD0
`8JE0;f8V`80_hJG00@0`hJC0000002nQYP0`HJD0P2nQiX01@30QYD0_HRL0;n6U`2oQYL0_HVN0080
_XJH0`2nQiX01030QYH0_HRL0;f8W02oQYL20;f9WP030;j6V02lRZ00_8ZP0080_XNJ00@0_8bS0;f8
W02mR9`0_8jV0P2mRIh30;b:X@030;j7VP2lS:<0_8bS00@0oooo00<000000?ooo`3oool05@3oool0
00`0oooo00L0oono07@0B02Lgol0oooo0=nLB000B9`0gooo00H0oooo00<000000?ooo`3oool0703o
ool3000001d0oooo00@0gInB0?ooo`3oool0oooo103`^9D01@3oool0iJVC0>FYT`3UZI<0oooo0080
gInB0`3ndi801@3GVI40l;VD0?2iU03`^I@0dY>A00<0iJVC00<0]<I90=fOTP3MWi800P3ne9020=NI
T@80lKVD0P3BTi420>FYT`050<j@T@3MWi80gInB0=fOTP3ne8l00P3GVI420?6iT`80dY>A0P3UZI82
0<n@T@80gInB00D0bhfA0=NIT@3GVI40eiVA0?6iT`020=:CT@80iZVB0P3?T9420=fOT@050<^=T@3G
VI40eiVA0=NIT@38Ri400`3BU9400`3VZI80ci2A0<n@T@020=fOTP80bhfA0P3GVI401@39Ri80diBA
0=>DT@3CU940iJVB0080ci6B00<0gJ2B0<b>TP3<SY800P3HVY801039S9<0diFB0=>ETP3CUI840<nB
T`030=fQU03<Si@0f9^D0080f9^D00@0b8fF0=>GU@3CUiD0hjVG0P3?UIL20=bSV0040<^CVP3GWiX0
einJ0=NOVP<0difN0P3P[9l01@3=WJH0fj^U0=^[Y@3W^JH0e:ja00<0h;R^00<0j;n/0>6m/`3=[[/0
0P3=[[/20=BNWP80eJ>T00D0diVI0=BLV`3DW9/0e9bK0=6FUP020=:GU`@0d9BE00<0e9RE0<fAU03A
U9<00P3AU9<00`3;Si@0cY2C0<j@T`030<b>TP060=6CTP39S9<0bHbC0<V<T`3>Si40ahZC0`3;SI83
0<R;TP030<n@T@36RI<0aXVC0080bhfA00@0a8RC0<V;T@39Ri40`hND0P36RI80103=SY00a8NC0<B7
T`3:S9420<>7T`80b8VA00@0`HJE0<F8TP35R980`8JF0`34Qi<01039Ri40`XJD0<:6U037RI420<66
U@80aHRB00<0`8JF0<>7T`33Qi<00`32QY@01037RI40`HJE0<66U@35Qi820;n6UP80`hJC00<0_hJH
0<:6U032QY@00`30QYD01035Qi80_hJF0;n6UP33QY<20;j6V080`XJD00<0_XNJ0<26U@30QYD00`2o
QYL01033QY<0_XJH00000031QY@20;j7VP050<26U@2mR9`0_hJG0;n6U`2mRIh00P2nQYP01031QY@0
_XNJ0;j7VP30QYH20;f8W0030;n6U`2mRIh0_HVN0080_XJH00@0_8ZP0;j7VP2nQiX0_8bS0P2mR9`3
0;f9WP040;j6V02lRZ40_8ZQ0;j7VP80_8bS103oool00`000000oooo0?ooo`0E0?ooo`00303oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0M02oool01P3oool00`000000oooo0?ooo`0I0?ooo`<00000
9@3oool20?2hU@80oooo0`3UZI<00`3oool0gInB0=fOTP030?kCTP050=NIT@3`^I@0l;VD0?2iU03B
Ti400`3UZI<00`2daTT0gInB0=fOTP020?kDT080eiVA0P3a^I@20=:CT@80iJVC00D0cY2A0=fOTP3M
Wi80gInB0?kDS`020=NIT@80lKVC0P3BTi420>FYTP050<n@T@3MWi80gInB0=fOTP3;SI400`3GVI40
0`3a^I<0dY>A0=:CT@020>JYTP80ci2A0P3MWi40103;SI40eiVA0=NIT@3GVI440=:DT@030>JYTP3?
T940ci2A0080gInB00D0bhfA0=NIT@3GVI40eiVA0<V;TP030=>DT@040>FYTP3?TI80ci6B0=fPTP80
c8jB0P3HVY801@39S9<0diFB0=>ETP3CUI80i:RD0080ci:C0P3MXI@01@3<Si@0f9^D0=RKU03HVi@0
b8fF0080diNE00<0hjVG0<nEU`3?UIL00P3LXiP01@3;TiX0einJ0=NOVP3GWiX0ik:M0080difN0P3P
[9l0103=WJH0fj^U0=^[Y@3W^JH30>2h[P80j;n/00<0kLR]09`>003=[[/00P3=[[/0103DWYh0eJ>T
0=FSY03CVIT30=BLV`040=6FUP3BUiL0dYNG0=NNV@<0d9BE00<0e9RE0<fAU03AU9<00P3AU9<0103;
Si@0cY2C0<j@T`3EUi<20<b>TP030=6CTP39S9<0bHbC0080cXnA00D0ahZC0<^=TP3;SI80bhfB0=>C
T@020<R;TP030<n@T@36RI<0aXVC0080bhfA00@0a8RC0<V;T@39Ri40`hND0P36RI80103=SY00a8NC
0<B7T`3:S9420<>7T`80b8VA00<0`HJE0<F8TP35R9801034Qi<00`39Ri40`XJD0<:6U0020<N9T@04
0<66U@35R980aHRB0<26UP80`hNC00@0bH^A0<:6U032QY@0ahVA0P31QYD20<F7TP040;n6UP33QY<0
`hJC0;n6V080`XJD00@0ahVA0<26U@30QYD0aHNB0P2oQYH20<>6T`040;j6V032QY@0`XJD0;j7VP80
`8JE00@0aHNB0;n6U`2oQYL0`hJC0P2nQYP01@000000_XNJ0<26U@30QYD0_HRL0080_hJG0`2nQYP0
1031QY@0_XNJ0;j7VP30QYH20;f8W080_hJG00@0_HVN0;j6V02nQYP0_8ZP0P2nQiX30;f8W0040;n6
U`2mRIh0_HVN0;j6V080_8ZQ00<0_XNJ0;b<X`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`00
303oool01`3ookl0M01809cOo`3oool0gia80018W03Oool01P3oool2000001P0oooo0P00000]0?oo
o`040>FYT`3oool0oooo0=fOTP@0o]>B00@0eiVA0?2iU03`^I@0l;VD0`3UZI<20;C6B@80gInB0P3n
e9001@3GVI40lKVD0?6iU03a^I@0dY>A00<0iJVC00D0cY2A0=fOTP3MWi80gInB0?kDS`020=NIT@80
lKVC0P3BTi420>FYTP040<n@T@3MWi80gInB0=fOTP@0eiVA00<0lKVC0=:CT@3BTi400P3VZI820<n@
T@80gInA00D0bhfA0=NIT@3GVI40eiVA0?6iTP030=:DT@030>JYTP3?T940ci2A0080gInB00D0bhfA
0=NIT@3GVI40eiVA0<V;TP030=>DT@040>FYTP3?TI80ci6B0=fPTP80c8jB0P3HVY801@39S9<0diFB
0=>ETP3CUI80i:RD0080ci:C0P3MXI@01@3<Si@0f9^D0=RKU03HVi@0b8fF0080diNE00<0hjVG0<nE
U`3?UIL00P3LXiP01P3;TiX0einJ0=NOVP3GWiX0ik:M0=>MWP<0h:bO0P3KZjD20>NiYP030?7;Z`3P
^:h0h;R^0080j;n/00<0kLR]0>Fm[@3=[[/00P3=[[/0103DWYh0eJ>T0=FSY03CVIT30=BLV`<0dYNG
00H0eijI0=2DU@3@U9D0d9BE0=BHU@3=TI@30=6DT`040<^?U03>T9<0cY2C0=FGT`80c8jB00<0dI>B
0<V<T`39S9<00P3>Si401@37RY<0bhfB0<^=TP3;SI80di>A0080b8^B00<0ci2A0<J9T`3;SI400P3;
SI400`34R9<0bH^A0<V;T@030<J9TP030<f>T034Qi<0a8NC0080bXbA00@0`hNC0<R9T@38RI40`HJE
0P35R9801@3=SI00a8NC0<B7T`34Qi<0bH^A0080`XJD0P37RI401031QYD0aHRB0<F8TP30QYH20<>7
T`040<V;T@32QY@0`XJD0<N9T@80`HJE0P35Qi80102oQYH0`hJC0<>6T`2oQYP20<:6U0040<N9T@30
QYD0`8JE0<F7TP80_hJF0P33QY<0102nQYP0`XJD0<:6U02nQiX20<26U@040<F7TP2oQYL0_hJG0<>6
T`80_XJH00D0`HJD00000030QYD0`8JE0;f8W0020;n6U`040<>6T`2nQYP0_XJH0<66U080_XNJ00<0
`8JF0;f8W02mR9`00P2oQYL00`2mRIh0_XJH0;j6V0030;j7VP040<26UP2mR9`0_HRL0;n6U`80_HVN
00D0_XJH0;b:X@2nQiX0_XNJ0;b<X`060?ooo`030000003oool0oooo01@0oooo000=0?ooo`050?oO
W018000000000000M02oool01P3oool00`000000oooo0?ooo`0E0?ooo`<00000;`3oool0103UZI<0
oooo0?ooo`3MWi830?ooo`040?kCTP3GVI40l;VD0?2iU080oooo0P3UZI<0103oool0]<I90=fOTP3M
Wi820?kDT0050=NIT@3a^I@0lKVD0?6iU03BTi400`3UZI<30=fOTP80o]B?0P3GVI420?6iT`80dY>A
0P3UZI801@3?T940gInB0=fOTP3MWi80omB=0080eiVA0P3a^I<20=:CT@80iZVB00D0ci2A0=fOT@3M
Wi40gInA0<^=T@030=NIT@030?6iTP3BU940dYBA0080iZVB0P3?T9420=fOTP040<^=T@3GVI40eiVA
0=NIT@@0diBA00D0iJVB0<nATP3?TI80gJ2B0<b>TP030=RJTP050<V<T`3CUI80diFB0=>ETP3TZ9@0
0P3?TY<20=fQU0040<b?U03HVi@0f9^D0=RKU0<0diNE00<0hjVG0<nEU`3?UIL00P3LXiP01P3;TiX0
einJ0=NOVP3GWiX0ik:M0=>MWP<0h:bO00@0kl:T0=^[Y@3W^JH0ikVV0P3abj/01@3P^:h0j;n/0>g8
[@3]b:d0l=:c00<0cJjk0`3EXj@40=BLV`040=VWXP3BUiL0dYNG0=NNV@80d9BE0P3DV9D01@3=TI@0
dIBC0=6DT`3AU9<0bhnD0080cY2C00<0eINC0<b>TP3<SY800P3ATi801039S9<0cXnA0<j?T@37RY<3
0<^=TP050=>CT@38Ri80b8^B0<n@T@36RI<00`3;SI401034R9<0bH^A0<V;T@3ATY020<J9TP030<f>
T034Qi<0a8NC0080bXbA00@0`hNC0<R9T@38RI40`HJE0P35R9801@3=SI00a8NC0<B7T`34Qi<0bH^A
0080`XJD0P37RI400`31QYD0aHRB0<F8TP030<>7T`040<V;T@32QY@0`XJD0<N9T@80`HJE0P35Qi80
0`2oQYH0`hJC0<>6T`030<:6U0040<N9T@30QYD0`8JE0<F7TP80_hJF0P33QY<00`2nQYP0`XJD0<:6
U0030<26U@040<F7TP2oQYL0_hJG0<>6T`80_XJH00@0`HJD00000030QYD0`8JE0`2oQYL01033QY<0
_XJH0;j6V031QY@20;j7VP80`8JF00@0_HRL0;n6U`2oQYL0_HVN0P2nQYP01031QY@0_XNJ0;j7VP30
QYH20;f8W0050;n6U`2mRIh0_XJH0;j6V02lRZ400P2nQiX00`2lS:<0oooo0?ooo`040?ooo`030000
003oool0oooo01@0oooo000H0?ooo`030000003oool0oooo0180oooo0`00000j0?ooo`80l;VD0`3o
ool20>FYT`030?ooo`2daTT0gInB00<0o]B@00D0eiVA0?6iU03a^I@0lKVD0=:CT@030>FYT`030:k1
@P3MWi80gInB0080o]B?0P3GVI420?6iT`80dY>A0P3UZI801@3?T940gInB0=fOTP3MWi80omB=0080
eiVA0P3a^I<20=:CT@80iZVB00D0ci2A0=fOT@3MWi40gInA0<^=T@030=NIT@030?6iTP3BU940dYBA
0080iZVB0P3?T9420=fOTP050<^=T@3GVI40eiVA0=NIT@3`^9800`3CU9401@3UZI80ci6B0=fPTP3M
X980c8jB00<0f9ZB103CUI800`3TZ9@0ci:C0<nBT`020=fQU0050<b?U03HVi@0f9^D0=RKU03[/iH0
0P3CUiD00`3SZIL0ciFG0=bSV0020=bSV0<0einJ0P3W/Yd01`3CWIh0h:bO0>2/W`3P[9l0kl:T0=^[
Y@3W^JH00`3abj/20>Ro[0040>g8[@3`d[<0l=:c0?3B/`<0Sl?i0P3EXj@01@3F][T0e9bK0=BLV`3D
W9/0fJNR0080dYNG00<0eijI0=2DU@3@U9D00P3DV9D0103=TI@0dIBC0=6DT`3AU9<30<j@T`030=FG
T`3<SY80dI>B0080dI>B00@0bHbC0<j?T@3>Si40ahZC0`3;SI801@3CTi40b8^B0<R;TP3?T940aXVC
00<0bhfA00@0a8RC0<V;T@39Ri40dI:@0P36RI800`3=SY00a8NC0<B7T`020<Z<T@030<>7T`38RI40
b8VA00<0aHRB00D0cHf@0<B7T`34Qi<0a8NC0<V;T@020<:6U080ahVA00@0`HJE0<F8TP35R980c8f@
0P33Qi<00`39Ri40`XJD0<:6U0020<N9T@040<66U@35Qi80aHNB0;n6UP80`hJC00@0bH^A0<:6U032
QY@0ahVA0P30QYD20<F7TP040;n6UP33QY<0`hJC0;j6V080`XJD00@0ahVA0<26U@30QYD0aHNB0P2o
QYL20<>6T`060;j6V031QY@0_XNJ00000030QYD0a8NB0P2oQYL01033QY<0_XJH0;j6V031QY@20;j7
VP80`8JF00<0_HRL0;n6U`2oQYL00`2nQYP01031QY@0_XNJ0;j7VP30QYH20;f8W0050;n6U`2mRIh0
_XJH0;j6V02lRZ400P2nQiX70?ooo`030000003oool0oooo01@0oooo000H0?ooo`030000003oool0
oooo00l0oooo0`0000120?ooo`050>FYT`3oool0oooo0;C6B@3MWi800`3ne9001@3GVI40lKVD0?6i
U03a^I@0dY>A00<0iJVC00<0[/520=fOTP3MWi800P3ne8l01@3GVI40lKVC0?6iT`3a^I<0dY>A00<0
iJVB00D0ci2A0=fOTP3MWi80gInB0?oDS@020=NIT@80lKVC0P3BTi420>JYTP040<n@T@3MWi40gInA
0=fOT@@0eiVA00<0lKVB0=:DT@3BU9400P3VZI801@3?T940gInB0=fOTP3MWi80bhfA00<0eiVA00<0
l;RB0=>DT@3CU9400P3UZI80103?TI80gJ2B0=fPTP3<SY830=RJTP030>jfU03CUI80diFB0080i:RD
0P3?TY<20=fQU0050<b?U03HVi@0f9^D0=RKU03[/iH00P3CUiD00`3SZIL0ciFG0=bSV0020=bSV003
0?2mW03GWiX0einJ0080ik:M00<0difN0>2/W`3P[9l00P3_`Z@20>NiYP<0lL^[00<0mn>c0>g8[@3]
b:d00P3`d[<20?7S_`80Sl?i00<0eJ>T0=Jf^@3F][T00P3DW9/20=VWXP050=:GU`3GWYT0eijI0=NN
V@3@U9D00P3DV9D01@3=TI@0dIBC0=6DT`3AU9<0fIfD0080cY2C00<0eINC0<b>TP3ATi800P3ATi80
0`39S9<0cXnA0<j?T@040<^=TP050=>CT@38Ri80b8^B0<n@T@36RI<00`3;SI401034R9<0bH^A0<V;
T@3ATY020<J9TP030<f>T034Qi<0a8NC0080bXbA00@0`hNC0<R9T@38RI40d96@0P35R980103=SI00
a8NC0<B7T`34Qi<20<V;T@040<:6U037RI40ahVA0<66U@80aHRB00@0c8f@0<>7T`33Qi<0bH^A0P32
QY@20<N9T@040<66U@35Qi80aHNB0;n6UP80`hJC00@0bH^A0<:6U032QY@0ahVA0P30QYD20<F7TP04
0;n6UP33QY<0`hJC0;j6V080`XJD00@0ahVA0<26U@30QYD0aHNB0P2oQYL20<>6T`060;j6V031QY@0
_XNJ0<26U@000000a8NB0P2oQYL00`33QY<0_XJH0;j6V0020<66U0040;j7VP30QYH0`8JF0;f8W080
_hJG00@0`hJC0;j6V02nQYP0`HJD0P2nQiX01@30QYH0_HRL0;n6U`2oQYL0_HVN0080_XJH0`2nQiX7
0?ooo`030000003oool0oooo01@0oooo000H0?ooo`030000003oool0oooo00`0oooo0`0000150?oo
o`050>FYT`3oool0oooo0?ooo`3MWi800`3ne900103GVI40lKVD0?6iU03a^I@30>FYT`040:Vmj02^
`D80gInB0=fOTP80o]B?00D0eiVA0?6iT`3a^I<0lKVC0=:CT@030>FYTP<0gInB0P3oe8d20=NIT@80
lKVC00D0dY>A0>JYTP3VZI80iZVB0<n@T@030=fOT@030?oCS@3GVI40eiVA0080lKVB0P3BU9420>JY
TP050<n@T@3MWi80gInB0=fOTP3;SI400`3GVI400`3`^980diBA0=>DT@020>FYTP040<nATP3MX980
gJ2B0<b>TP<0f9ZB00<0k[JD0=>ETP3CUI800P3TZ9@01@3?TY<0gJ6D0=fQU03MXI@0c8nD00<0f9^D
00D0jk>F0=>GU@3SZIL0hjVG0<nEU`030=bSV0030?2mW03GWiX0einJ0080ik:M0`3P[9l20>o2Y004
0?[VZ`3W^JH0lL^[0?7;Z`80mn>c00<0h_fl0?3B/`3`d[<00P3ahkl20=kleP0408o3n@3EXj@0e[Ji
0=Jf^@80e9bK0P3IYj801@3BUiL0eijI0=NNV@3GWYT0d9BE0080e9RE00D0cI6D0=6DT`3AU9<0dIBC
0=VMU0020<j@T`030=FGT`3<SY80dI>B0080dI>B00@0bHbC0<j?T@3>Si40eiVA0`3;SI801@3CTi40
b8^B0<n@T@3?T940aXVC00<0bhfA0`39Ri400`3ATY00aXVB0<J9TP020<f>T0040<B7T`3:S940bXbA
0<>7T`80b8VA00@0d96@0<F8TP35R980cHf@0P34Qi<30<V;T@040<:6U037RI40ahVA0<66U@80aHRB
00@0c8f@0<>7T`33Qi<0bH^A0P32QY@20<N9T@030<66U@35Qi80aHNB00<0`hJC00@0bH^A0<:6U032
QY@0ahVA0P30QYD20<F7TP030;n6UP33QY<0`hJC00<0`XJD00@0ahVA0<26U@30QYD0aHNB0P2oQYL2
0<>6T`060;j6V031QY@0`8JE0<26U@000000a8NB0P2oQYL00`33QY<0_XJH0;j6V0020<66U0030;j7
VP30QYH0`8JF00<0_hJG00@0`hJC0;j6V02nQYP0`HJD0P2nQiX01@30QYH0_HRL0;n6U`2oQYL0_HVN
0080_XJH00<0`HJD0;j7VP2nQiX01`3oool00`000000oooo0?ooo`0D0?ooo`00603oool2000000X0
oooo0`00001<0?ooo`040=fOTP3oool0oooo0?ooo`<0lKVD00L0oooo0000003UZI<0iJVC0:Vmj02^
`D80gInB00<0o]B?00D0eiVA0?6iT`3a^I<0lKVC0=:CT@030>FYTP030:bn?P3MWi80gInB0080omB=
0P3GVI420?6iT`050=:CT@3VZI80iZVB0>JYTP3?T9400`3MWi400`3odhd0eiVA0=NIT@020?6iTP80
dYBA0P3VZI80103?T940gInB0=fOTP3MWi840=NIT@030?2hTP3CU940diBA0080iJVB00@0ci6B0=fP
TP3MX980c8jB0`3HVY800`3^]Y@0diFB0=>ETP020>BXU0040<nBT`3MXI@0gJ6D0=fQU0<0f9^D0P3[
/iH0103CUiD0hjVG0>>YU`3?UIL30=bSV0030?2mW03GWiX0ik:M0080ik:M00<0n]JR0>2/W`3_`Z@0
0P3_`Z@00`3jiZ/0lL^[0?7;Z`020?OS/`040>;m_000000000000?7S_`@0g_cF00D0jlZd0=Jf^@3F
][T0e[Ji0=BLV`030=VWXP050=:GU`3GWYT0eijI0=NNV@3@U9D00P3DV9D40=6DT`050=VMU03>T9<0
cY2C0=FGT`3<SY800`3ATi801039S9<0cXnA0<j?T@3GVI430<^=TP050=>CT@38Ri80ci2A0<n@T@36
RI<00`3;SI40103FUY00bH^A0<V;T@3ATY020<J9TP80cHj@00@0a8NC0<Z<T@3:S940`hNC0P38RI40
103@TI00aHRB0<F8TP3=SI020<B7T`<0bH^A00<0`XJD0<N9T@37RI400`35R980103<SI00`hNC0<>7
T`39Ri420<:6U080ahVA00@0`HJE0<F7TP35Qi80c8f@0P33QY<00`39Ri40`XJD0<:6U0020<N9T@04
0<26U@35Qi80aHNB0;n6UP80`hJC00@0bH^A0<:6U032QY@0ahVA0P30QYD20<F7TP060;n6U`33QY<0
`hJC0;j6V031QY@0aXVA0P30QYD00`000000_hJG0;n6U`020<>6T`040;j6V031QY@0`HJD0;j7VP80
`8JF00@0a8NB0;n6U`2oQYL0`hJC0P2nQYP01@31QY@0_XNJ0;j7VP30QYH0_HRL0080_hJG0`2nQYP0
0`31QY@0_XNJ0;j7VP080?ooo`030000003oool0oooo01<0oooo000H0?ooo`030000003oool0oooo
00H0oooo0`00001D0?ooo`040?6iU03oool0oooo0?ooo`80iJVC00<0ZKgX0:k1@P3MWi800`3ne8l0
1@3GVI40lKVC0?6iT`3a^I<0dY>A00<0iJVB00<0[;hn0=fOTP3MWi800P3oe8d01@3GVI40lKVC0?6i
T`3a^I<0dY>A00<0iZVB00D0ci2A0=fOT@3MWi40gInA0?oCS@020=NIT@80lKVB0P3BU9420>JYTP05
0<n@T@3MWi80gInB0=fOTP3ndHh00P3GVI420?2hTP80diBA0P3UZI800`3?TI80gJ2B0=fPTP040=RJ
TP030>jfU03CUI80diFB0080i:RD00D0ci:C0=fQU03MXI@0gJ6D0?S5U@020=RKU080jk>F00<0diNE
0>>YU`3SZIL0103LXiP00`3`_I`0einJ0>NbW@020>NbW@040?[FXP3P[9l0kl:T0>o2Y080n^J[00@0
Sm=h0?OS/`3ghk<0h_fl2@2Y_NP0103ZfL<0e[Ji0=Jf^@3DW9/30=VWXP050=:GU`3GWYT0eijI0=NN
V@3@U9D00P3DV9D01P3NYYT0dIBC0=6DT`3AU9<0fIfD0<j@T`80eINC00D0c8jB0=6CTP3ATi80dI>B
0<V<T`020<j?T@060=NIT@3;SI80bhfB0<^=TP3CTi40b8^B0P3?T9401@36RI<0bhfA0<^=T@3;SI40
eYJ@0080bH^A00<0dI:@0<J9TP36RI800P3=SY000`34Qi<0bXbA0<Z<T@030<R9T@040=2AT035R980
aHRB0<f=T080a8NC0`39Ri401032QY@0ahVA0<N9T@3@T8l20<F8TP030<b=T033Qi<0`hNC0080bH^A
00@0`XJD0<N9T@37RI40`HJE0P35Qi80103<SI00`hJC0<>6T`39Ri420<:6U080ahVA00@0`8JE0<F7
TP35Qi80_hJF0P33QY<01039Ri40`XJD0<:6U037RI420<26U@80aHNB00H0_hJG0<>6T`33QY<0_XJH
0<66U036RI420<26U@030<B7TP000000_hJG0080`hJC00@0_XJH0<66U031QY@0_XNJ0P30QYH01034
Qi80_hJG0;n6U`33QY<20;j6V080`HJD00<0_XNJ0<26UP2mR9`00P2oQYL01033QY<0_XJH0;j6V031
QY@20;j7VPP0oooo00<000000?ooo`3oool04`3oool001L0oooo00<000000?ooo`3oool01@3oool2
000005/0oooo00D0iJVC0000002Y_NP0ZKgX0=fOTP030?kDS`040=NIT@3a^I<0lKVC0?6iT`<0iJVB
00@0ZKgX0:bn?P3MWi80gInB0P3oe8d01@3GVI40lKVC0?6iT`3a^I<0dY>A00<0iZVB0`3MWi420?oC
S@80eiVA0P3a^I801@3BU940iZVB0>JYTP3VZI80ci2A00<0gInB00<0o]6>0=NIT@3GVI400P3`^982
0=>DT@80iJVB00@0ci6B0=fPTP3MX980o<fA0`3HVY800`3^]Y@0diFB0=>ETP020>BXU0050<nBT`3M
XI@0gJ6D0=fQU03haID00P3HVi@20>^cUP040=>GU@3SZIL0hjVG0?cCV@80g:>H0P3`_I`00`3GWiX0
ik:M0>NbW@020?[FXP<0kl:T00<0n^J[0:Vmj02Y_NP03@2Y_NP20=Jf^@@0fJNR00@0dYNG0=NNV@3G
WYT0eijI0`3DV9D01P3NYYT0dIBC0=6DT`3AU9<0fIfD0<j@T`80eINC00@0c8jB0=6CTP3ATi80dI>B
0`3>Si400`3GVI40bhfB0<^=TP020=>CT@040<R;TP3?T940ci2A0<J9T`<0bhfA00@0eYJ@0<V;T@39
Ri40dI:@0P36RI820<f>T0040<B7T`3:S940bXbA0=FES`80b8VA00<0d96@0<F8TP35R9800P3=SI00
1@34Qi<0bH^A0<V;T@39Ri40`XJD0080ahVA00@0d92?0<F8TP35R980c8f@0P33Qi<20<V;T@040<:6
U037RI40ahVA0<66U@80aHNB00@0c8f@0<>6T`33QY<0bH^A0P32QY@20<N9T@030<26U@35Qi80aHNB
00<0`hJC00@0bH^A0<:6U032QY@0ahVA0P30QYD20<F7TP030;n6U`33QY<0`hJC0080`HJD00H0aXVA
0<26U@30QYD0a8NB0;n6U`0000020<>6T`030;j6V031QY@0`HJD00<0`8JF00@0a8NB0;n6U`2oQYL0
`hJC0P2nQYP20<66U0030;j7VP30QYH0_hJG0080_hJG00@0`hJC0;j6V02nQYP0`HJD0P2nQiX80?oo
o`030000003oool0oooo01<0oooo000G0?ooo`030000003oool0oooo0080oooo0`00001M0?ooo`05
0>FYT`3oool000000:Vmj03MWi800`2Y_NP40?6iT`060:Vmj03UZI80iJVB0:Vmj02/_Sh0gInB0`3o
e8d01@3GVI40lKVC0?6iT`3a^I<0dY>A00<0iZVB00<0[klo0=fOT@3MWi400P3odhd20=NIT@80lKVB
00D0dYBA0>JYTP3VZI80iZVB0<n@T@030=fOTP030?kASP3GVI40eiVA0080l;RB00D0diBA0>FYTP3U
ZI80iJVB0<nATP020=fPTP060?c=T@3HVY80f9ZB0=RJTP3^]Y@0diFB0`3TZ9@01@3?TY<0gJ6D0=fQ
U03MXI@0n<FE0080f9^D0P3[/iH0103CUiD0hjVG0>>YU`3ldiT20=bSV080l;fL0`3W/Yd20?[FXP80
000000<0n^J[0:Vmj02Y_NP0402Y_NP0100Y0000fJNR0=VWXP3IYj840=NNV@040>FfY@3DV9D0e9RE
0=jVV@<0dIBC00D0fIfD0<j@T`3EUi<0eINC0<b>TP030=6CTP040=fOTP3>Si40cXnA0=NIT@80bhfB
0P3CTi400`38Ri80ci2A0<n@T@040<^=T@030=JFT039Ri40bH^A0080dI:@00@0aXVB0<f>T03=SY00
a8NC0P3:S940103EUHl0b8VA0<R9T@3@TI020<F8TP80cHf@00D0a8NC0<V;T@39Ri40bH^A0<:6U002
0<N9T@040=2@S`35R980aHRB0<b=T080`hNC0P39Ri400`32QY@0ahVA0<N9T@030<F7TP040<b=T033
QY<0`hJC0<V;T@80`XJD0P37RI401030QYD0aHNB0<F7TP3<SI020<>6T`030<V;T@32QY@0`XJD0080
ahVA00@0`8JE0<F7TP35Qi80_hJG0P33QY<00`39Ri40`HJD0<J9T@020<26U@80a8NB00@000000<>6
T`33QY<0_XJH0P31QY@01036RI40`8JF0<26UP34Qi820;n6U`80`hJC00H0_XJH0<66U031QY@0_XNJ
0<26UP34Qi820;n6U`040<>6T`2nQYP0_XJH0<66U080_XNJ203oool00`000000oooo0?ooo`0C0?oo
o`005`3oool00`000000oooo00000002000006<0oooo00<000000:Vmj02Y_NP00`2Y_NP20?6iT`80
ZKgX0P3UZI800`2Y_NP0[;hn0=fOTP030?oDS@050=NIT@3a^I<0lKVC0?6iT`3BTi400`3VZI800`2_
_cl0gInA0=fOT@020?oCS@050=NIT@3a^I80lKVB0?6iTP3BU9400`3VZI830=fOTP80o]6>0P3GVI42
0?2hTP050=>DT@3UZI80iJVB0>FYTP3?TI800P3MX9800`3lcI40f9ZB0=RJTP020>jfU0040=>ETP3T
Z9@0i:RD0>BXU0<0gJ6D0P3haID01@3HVi@0jk>F0>^cUP3[/iH0diNE0080hjVG0P3ldiT0103LXiP0
l;fL0?2mW03SjhH20>NbW@030?[FXP2Y_NP0ZKgX01D0ZKgX0`3IYj801@3Vf/X0eijI0=NNV@3GWYT0
iKJU0080e9RE00<0gZJI0=6DT`3AU9<00P3IWI@0103>T9<0eINC0=FGT`3<SY830=6CTP040=fOTP3>
Si40cXnA0=NIT@80bhfB0P3CTi401038Ri80ci2A0<n@T@3LW9030<^=T@030=JFT039Ri40bH^A0080
dI:@00@0aXVB0<f>T03=SY00a8NC0P3:S940103EUHl0b8VA0<R9T@3@TI020<F8TP80cHf@00@0a8NC
0<V;T@39Ri40bH^A0`37RI400`3@T8l0aHRB0<F8TP020<b=T0040<>7T`39Ri40bH^A0<:6U080ahVA
00@0d92?0<F7TP35Qi80c8f@0P33QY<20<V;T@040<:6U037RI40ahVA0<26U@80aHNB00@0c8f@0<>6
T`33QY<0bH^A0P32QY@20<N9T@040<26U@35Qi80aHNB0;n6U`80`hJC00D0bH^A0<66U036RI40aXVA
0<26U@020<B7TP040;n6U`000000`hJC0;j6V080`HJD00@0aXVA0<26UP30QYH0a8NB0P2oQYL20<>6
T`060;j6V031QY@0`HJD0;j7VP30QYH0a8NB0P2oQYL00`33QY<0_XJH0;j6V0020<66U0030;j7VP3o
ool0oooo00H0oooo00<000000?ooo`3oool04`3oool001L0oooo0P00001W0?ooo`030000003oool0
ZKgX00H0ZKgX00D0iJVB0:Vmj02Y_NP0ZKgX0=fOTP030?oDS@040=NIT@3a^I<0lKVC0?6iT`<0iZVB
00@0ZKgX0:no?`3MWi40gInA0P3odhd01@3GVI40lKVB0?6iTP3a^I80dYBA00<0iZVB00<0_/Q90=fO
TP3MWi800P3ndHh20=NIT@80l;RB00@0diBA0>FYTP3UZI80iJVB0`3MX9800`3lcI40f9ZB0=RJTP02
0>jfU0050=>ETP3TZ9@0i:RD0>BXU03jhH@00P3MXI@20?S5U@040=RKU03[/iH0jk>F0>^cUP80hjVG
0`3ldiT00`3LXiP0l;fL0?2mW0020>?[QP030?[FXP2Y_NP0ZKgX01L0ZKgX00<0fJNR0>KJbP3Vf/X0
0P3GWYT20>FfY@030=BHU@3NYYT0gZJI0080dIBC0P3IWI@00`3>T9<0eINC0=FGT`040=6CTP030=fO
TP3>Si40cXnA0080eiVA00@0bhfB0=>CT@3CTi40b8^B0P3?T9401@3LW900bhfA0<^=T@3;SI40eYJ@
0080bH^A0P3ATY001036RI80cHj@0<f>T034Qi<20<Z<T@040=FES`38RI40b8VA0=2AT080aHRB0P3=
SI001@34Qi<0bH^A0<V;T@39Ri40eIB?0080ahVA00<0d92?0<F8TP35R9800P3<SI001033Qi<0bH^A
0<V;T@32QY@20<N9T@040=2@S`35Qi80aHNB0<b=T080`hJC0P39Ri401032QY@0ahVA0<N9T@30QYD2
0<F7TP040<b=T033QY<0`hJC0<V;T@80`XJD0P37RI400`30QYD0aHNB0<F7TP030<>6T`050<V;T@31
QY@0aXVA0<J9T@30QYD00P34Qi800`2oQYL0`hJC000000030<66U0040<J9T@30QYH0`8JF0<B7TP80
_hJG0P33QY<00`2nQYP0`HJD0<66U0020<26UP040<B7TP2oQYL0_hJG0<>6T`80_XJH0P31QY@00`2n
QiX0oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00060?ooo`030?oOW01807@0_ooo0080
oooo00D0oono07@00000000004RL0=ooo`080?ooo`030000003oool0oooo06H0oooo0P0000060:Vm
j0050>FYTP2Y_NP0ZKgX0:Vmj03MWi800`2Y_NP40?6iT`060:Vmj03VZI80iZVB0:Vmj02__cl0gInA
0`3odhd01@3GVI40lKVB0?6iTP3a^I80dYBA00<0iZVB00<0_/Q90=fOTP3MWi800P3ndHh01@3GVI40
l;RB0?2hTP3`^980diBA00<0iJVB00@0gMQR0=fPTP3MX980o<fA0P3HVY820>jfU0050=>ETP3TZ9@0
i:RD0>BXU03jhH@00P3MXI@20?S5U@060=RKU03[/iH0jk>F0>^cUP3Jgfh0hjVG0`3ldiT20?2mW1d0
ZKgX0`3Vf/X20=NNV@80iKJU00D0e9RE0=jVV@3NYYT0gZJI0=6DT`020=VMU0040<j@T`3EUi<0eINC
0>F[U@<0dI>B00<0gInB0<j?T@3GVI400P3GVI40103;SI80di>A0=>CT@38Ri820<n@T@050=bLT03;
SI40bhfA0<^=T@3FUY000P39Ri420=6BT0030<J9TP3=SY00cHj@00<0bXbA00<0eIF?0<R9T@38RI40
0P3@TI001035R980cHf@0<f=T034Qi<30<V;T@040=FDS`37RI40ahVA0=2@S`80aHRB0P3<SI001033
Qi<0bH^A0<V;T@32QY@20<N9T@040=2@S`35Qi80aHNB0<b=T080`hJC0P39Ri400`32QY@0ahVA0<N9
T@030<F7TP040<b=T033QY<0`hJC0<V;T@80`XJD0P37RI401030QYD0aHNB0<F7TP3<SI020<>6T`05
0<V;T@31QY@0aXVA0<J9T@30QYD00P34Qi80102oQYL0`hJC0<>6T`0000020<66U0030<J9T@30QYH0
`8JF0080a8NB00@0_hJG0<>6T`33QY<0_XJH0P31QY@00`36RI40`8JF0<B7TP020;n6U`80`hJC00@0
_XJH0<66U031QY@0_XNJ203oool00`000000oooo0?ooo`0C0?ooo`001P3oool02P3ogi`0B01d0;oo
o`3oool0oooO09a80018W=l0oooo0=nLB000M;l90?ooo`800000J03oool?0:Vmj080lKVC0P2Y_NP2
0>JYTP030:Vmj02__cl0gInA00<0om>=00@0eiVA0?6iTP3a^I80lKVB0`3VZI820;k8B@80gInB0P3n
dHh01@3GVI40l;RB0?2hTP3`^980diBA00<0iJVB00<0gMQR0=fPTP3lcI400P3lcI40103HVY80k[JD
0>jfU03CUI830>BXU0030?[QQ03MXI@0gJ6D0080n<FE00<0f9^D0>^cUP3[/iH00P3Jgfh00`3SZIL0
o=>I0?cCV@020:Vmj0030?2mW02Y_NP0ZKgX01`0ZKgX0P3Vf/X01@3GWYT0iKJU0>FfY@3U]ZD0e9RE
00<0gZJI00@0dIBC0=VMU03IWI@0cY2C0P3EUi<01P3UZiD0dI>B0=6CTP3ATi80gInB0<j?T@<0eiVA
00@0bhfB0=>CT@3CTi40b8^B0P3?T940103LW900bhfA0<^=T@3;SI420=JFT0040<V;T@3ATY00dI:@
0<J9TP80cHj@00@0fi^?0<Z<T@3:S940eIF?0P38RI420=2AT0040<F8TP3=SI00cHf@0<B7T`<0bH^A
00@0eIB?0<N9T@37RI40d92?0P35R9820<b=T0030<>7T`39Ri40bH^A00<0ahVA00<0d92?0<F7TP35
Qi800P3<SI001033QY<0bH^A0<V;T@32QY@20<N9T@040=2@S`35Qi80aHNB0<b=T080`hJC0P39Ri40
1032QY@0ahVA0<N9T@30QYD20<F7TP050<b=T033QY<0`hJC0<V;T@31QY@00P36RI401030QYD0a8NB
0<B7TP2oQYL20<>6T`0400000031QY@0`HJD0<J9T@80`8JF0P34Qi80102oQYL0`hJC0<>6T`2nQYP2
0<66U0050<J9T@30QYH0a8NB0<B7TP2oQYL00P33QY<0102nQYP0`HJD0<66U02nQiX90?ooo`030000
003oool0oooo0180oooo00060?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool02P3oool00`000000oooo0?ooo`1V0?oooa80ZKgX00D0iZVB0:Vmj02Y_NP0ZKgX0=fO
T@030?oCS@050=NIT@3a^I80lKVB0?6iTP2Y_NP00P3VZI800`2Y_NP0_/Q90=fOTP030?kASP040=NI
T@3`^980l;RB0?2hTP<0iJVB0P3Mf6801@3MX980o<fA0?c=T@3lcI40f9ZB0080k[JD103TZ9@00`3j
hH@0gJ6D0?S5U@020?S5U@<0jk>F0P3Jgfh00`3SZIL0o=>I0:Vmj00R0:Vmj0030>KJbP3GWYT0iKJU
0080iKJU00D0e9RE0=jVV@3NYYT0gZJI0=6DT`020=VMU0<0eINC00H0iJ^E0=6CTP3ATi80dI>B0=fO
TP3>Si430=NIT@030<^=TP3CTi40di>A00<0ci2A00@0g9b@0<^=T@3;SI40bhfA0P3FUY001039Ri40
dI:@0=6BT036RI820<f>T0040=^KS`3:S940bXbA0=FES`80b8VA0P3@TI000`35R980cHf@0<f=T004
0<V;T@040=FDS`37RI40ahVA0=2@S`80aHRB0P3<SI001033Qi<0bH^A0<V;T@3DU8l20<N9T@030=2@
S`35Qi80aHNB0080c8f@00@0`hJC0<V;T@39Ri40`XJD0P37RI40103@T8l0aHNB0<F7TP3<SI020<>6
T`80bH^A00@0`XJD0<N9T@37RI40`8JE0P35Qi801@3<SI00`hJC0<>6T`39Ri40`HJD00<0aXVA0P34
Qi830<>6T`040<V;T@000000`HJD0<J9T@80`8JF0P34Qi800`2oQYL0`hJC0<>6T`030<66U0050<J9
T@30QYH0a8NB0<B7TP2oQYL00P33QY<00`2nQYP0`HJD0<66U00:0?ooo`030000003oool0oooo0180
oooo00060?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol02`3o
ool00`000000oooo0?ooo`1V0?oooa40ZKgX00D0iZVB0:Vmj02Y_NP0ZKgX0=fOT@030:Vmj0<0lKVB
0P2Y_NP20>JYTP030:Vmj02nb4T0gInB00<0o]6>00D0eiVA0?2hTP3`^980l;RB0200>`020>FYTP80
gMQR00D0gJ2B0?c=T@3lcI40o<fA0=RJTP020>jfU0030000303TZ9@0i:RD0080n^6400L0gJ6D0?S5
U@3haID0n<FE0:Vmj03[/iH0f]m^0080ZKgX00<0o=>I0:Vmj02Y_NP08`2Y_NP40>FfY@050=BHU@3N
YYT0gZJI0=jVV@3AU9<00P3IWI@0103__9`0eINC0=FGT`3UZiD20=6CTP80gInB00D0cXnA0=NIT@3G
VI40eiVA0<^=TP020=>CT@040>>UT03?T940ci2A0=bLT080bhfA0`3FUY001039Ri40dI:@0=6BT036
RI820<f>T0040=^KS`3:S940bXbA0=FES`80b8VA0P3@TI001035R980cHf@0<f=T03JVXh30<V;T@03
0=FDS`37RI40ahVA0080d92?00@0aHRB0<b=T03<SI00`hNC0P39Ri40103DU8l0ahVA0<N9T@3@T8l2
0<F7TP80c8f@00@0`hJC0<V;T@39Ri40`XJD0P37RI40103@T8l0aHNB0<F7TP3<SI020<>6T`80bH^A
00<0`XJD0<N9T@37RI400`35Qi801@3<SI00`hJC0<>6T`39Ri40`HJD00<0aXVA0P34Qi801P3<SI00
`hJC0<>6T`39Ri40`HJD00000080aXVA00@0`8JF0<B7TP34Qi80_hJG0P33QY<01@39Ri40`HJD0<66
U036RI40`8JF0080a8NB00@0_hJG0<>6T`33QY<0_XJH0P31QY@:0?ooo`030000003oool0oooo0180
oooo00060?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0303o
ool00`000000oooo0?ooo`1V0?ooo`030000002Y_NP0ZKgX01H0ZKgX00D0lKVB0:Vmj02Y_NP0ZKgX
0>JYTP030:Vmj0050=fOTP3ndHh0o]6>0?kASP3GVI400P3`^9820:Vmj080iJVB00<0ZKgX0=gHHP3M
X9800`3lcI40103HVY80k[JD0>jfU02Y_NP20>BXU080n^6400<0gJ6D0?S5U@3haID00P2Y_NP00`3[
/iH0ZKgX0:Vmj00X0:Vmj0<0iKJU103NYYT30=VMU0040>nlW03EUi<0eINC0>F[U@80dI>B0P3MWi80
1@3>Si40eiVA0=NIT@3GVI40bhfB0080di>A00@0hjF@0<n@T@3?T940g9b@0P3;SI430=JFT0030<V;
T@3ATY00dI:@00<0cHj@00<0fi^?0<Z<T@3:S9400P3EUHl01038RI40d96@0=2AT035R9820<f=T005
0=ZJSP39Ri40bH^A0<V;T@3EU8l00P37RI420=2@S`040<F8TP3<SI00c8f@0<>7T`80bH^A00@0e9B?
0<N9T@37RI40d92?0P35Qi820<b=T0030<>6T`39Ri40bH^A00<0ahVA00<0d92?0<F7TP35Qi800P3<
SI001033QY<0bH^A0<V;T@32QY@20<N9T@040=2@S`35Qi80aHNB0<b=T080`hJC0P39Ri430<J9T@80
a8NB00<0c8f@0<>6T`33QY<00P39Ri4010000000aXVA0<J9T@30QYH20<B7TP040;n6U`33QY<0`hJC
0<V;T@80`HJD00D0aXVA0<26UP34Qi80a8NB0;n6U`020<>6T`030;j6V031QY@0`HJD00X0oooo00<0
00000?ooo`3oool04P3oool000H0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`0=0?ooo`800000I`3oool00`000000ZKgX0:Vmj00I0:Vmj0050>JYTP2Y_NP0ZKgX
0:Vmj03MWi800`2Y_NP20?2hTP<0ZKgX00D0iJVB0:Vmj02Y_NP0gMQR0=fPTP030?c=T@80k[JD0P2Y
_NP0100000`0i:RD0:Vmj02Y_NP20?S5UC40ZKgX00D09`000=jVV@3NYYT0gZJI0?W/Z@020=VMU003
0>nlW03EUi<0iJ^E0080iJ^E00@0dI>B0=fOTP3MWi80cXnA0`3GVI430=>CT@030>>UT03?T940ci2A
0080g9b@00D0bhfA0=JFT03FUY00eYJ@0<V;T@020=6BT0040>:SS`3=SY00cHj@0=^KS`80bXbA0P3E
UHl01038RI40d96@0=2AT035R9820<f=T0050=ZJSP39Ri40bH^A0<V;T@3EU8l00P37RI420=2@S`03
0<F8TP3<SI00c8f@00<0bH^A00@0e9B?0<N9T@37RI40d92?0P35Qi820<b=T0040<>6T`39Ri40bH^A
0=BDS`80ahVA00<0d92?0<F7TP35Qi800P3<SI001033QY<0bH^A0<V;T@32QY@20<N9T@040=2@S`35
Qi80aHNB0<b=T080`hJC0P39Ri430<J9T@80a8NB00<0c8f@0<>6T`33QY<00P39Ri401031QY@00000
0<J9T@30QYH20<B7TP<0`hJC00D0bH^A0<66U031QY@0aXVA0<26UP030<B7TP80`hJC0`31QY@:0?oo
o`030000003oool0oooo0180oooo00040?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d
07@0_ooo0?ooo`3ogi`0B01d0;ooo`0?0?ooo`030000003oool0oooo06D0oooo00<000000:Vmj02Y
_NP09@2Y_NP01@3UZI80ZKgX0:Vmj02Y_NP0gJ2B0080Z[gX0P2Y_NP01@3^]Y@0ZKgX0:Vmj02Y_NP0
i:RD03D0ZKgX00<09`000=jVV@3NYYT00P3ik:T20=VMU0030>nlW03EUi<0iJ^E0080iJ^E00@0dI>B
0=fOTP3MWi80cXnA0`3GVI40103^]980di>A0=>CT@3SYI020<n@T@80g9b@00D0bhfA0=JFT03FUY00
eYJ@0<V;T@020=6BT0040>:SS`3=SY00cHj@0=^KS`80bXbA0P3EUHl01038RI40d96@0=2AT035R982
0<f=T0050=ZJSP39Ri40bH^A0<V;T@3EU8l00P37RI420=2@S`040<F8TP3<SI00c8f@0=ZJSP80bH^A
00<0e9B?0<N9T@37RI400P3@T8l01035Qi80c8f@0<b=T033QY<20<V;T@040=BDS`37RI40ahVA0=2@
S`80aHNB0P3<SI001033QY<0bH^A0<V;T@32QY@20<N9T@040=2@S`35Qi80aHNB0<b=T080`hJC0P39
Ri430<J9T@80a8NB00<0c8f@0<>6T`33QY<00P39Ri401031QY@0aXVA00000030QYH20<B7TP040<b=
T033QY<0`hJC0<V;T@80`HJD0P36RI430<B7TP80`hJC00<0bH^A0<66U031QY@02P3oool00`000000
oooo0?ooo`0B0?ooo`001@3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3O
W4P007Bo0140oooo00<000000?ooo`3oool0I@3ooom[0:Vmj080gZJI0P3ik:T0103IWI@0kkbL0>nl
W03EUi<30>F[U@040=6CTP3MWi80gInB0<j?T@<0eiVA00@0k[BB0=>CT@3CTi40hjF@0P3?T9420=bL
T0050<^=T@3FUY00eYJ@0=JFT039Ri400P3ATY00103RXhl0cHj@0<f>T03KVhl20<Z<T@80eIF?00<0
b8VA0=2AT03@TI000`3=SI00103JVXh0bH^A0<V;T@39Ri420=FDS`040<N9T@3@T8l0d92?0<F8TP80
c8f@00@0fYZ>0<V;T@39Ri40e9B?0P37RI420=2@S`040<F7TP3<SI00c8f@0<>6T`80bH^A00@0e9B?
0<N9T@37RI40d92?0P35Qi820<b=T0030<>6T`39Ri40bH^A00<0ahVA00<0d92?0<F7TP35Qi800P3<
SI000`33QY<0bH^A0<V;T@030<J9T@030=2@S`34Qi80c8f@0080`hJC0P39Ri401031QY@0aXVA0<J9
T@0000020<B7TP040<b=T033QY<0`hJC0<V;T@80`HJD0P36RI430<B7TP80`hJC00<0bH^A0<66U031
QY@02P3oool00`000000oooo0?ooo`0B0?ooo`001P3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool04P3oool00`000000oooo0?ooo`1U0?ooofX0ZKgX00D0gZJI0?W/Z@3i
k:T0nNbY0=VMU0020>nlW0050=FGT`3UZiD0iJ^E0>F[U@3ATi800P3MWi840=NIT@040>jdTP3CTi40
di>A0>>UT080ci2A0P3LW900103;SI40eYJ@0=JFT03FUY030=6BT0030>:SS`3=SY00cHj@0080fi^?
00@0bXbA0=FES`3EUHl0b8VA0P3@TI00103RXXh0cHf@0<f=T03JVXh20<V;T@<0eIB?00@0ahVA0=2@
S`3@T8l0aHRB0P3<SI00103JVXh0bH^A0<V;T@3DU8l20<N9T@80d92?00<0aHNB0<b=T03<SI000`39
Ri40103DU8l0ahVA0<N9T@3@T8l20<F7TP80c8f@00@0`hJC0<V;T@39Ri40e9B>0P37RI400`3@T8l0
aHNB0<F7TP020<b=T0030<>6T`39Ri40bH^A00<0aXVA00D0d92?0<B7TP3<SI00c8f@0<>6T`020<V;
T@040<66U036RI40aXVA00000080a8NB00@0c8f@0<>6T`33QY<0bH^A0P31QY@20<J9T@<0a8NB0P33
QY<00`39Ri40`HJD0<66U00;0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000IP3oool0
0`000000ZKgX0:Vmj01X0:Vmj080nNbY00@0fIfD0>nlW03__9`0eINC0`3UZiD0103ATi80gInB0=fO
TP3mdI430=NIT@030>jdTP3CTi40di>A0080hjF@00@0ci2A0=bLT03LW900bhfA0`3FUY00103]/8h0
dI:@0=6BT03RXhl20<f>T080fi^?00@0bXbA0=FES`3EUHl0b8VA0P3@TI00103RXXh0cHf@0<f=T03J
VXh20<V;T@<0eIB?00@0ahVA0=2@S`3@T8l0aHRB0P3<SI00103JVXh0bH^A0<V;T@3DU8l20<N9T@80
d92?00@0aHNB0<b=T03<SI00fYZ>0P39Ri400`3DU8l0ahVA0<N9T@020=2@S`040<F7TP3<SI00c8f@
0<>6T`80bH^A00@0e9B>0<N9T@37RI40d92?0P35Qi820<b=T0030<>6T`39Ri40bH^A00<0aXVA00D0
d92?0<B7TP3<SI00c8f@0<>6T`030<V;T@80aXVA00@0a8NB00000034Qi80c8f@0P33QY<00`39Ri40
`HJD0<66U0020<J9T@<0a8NB00<0c8f@0<>6T`39Ri400P31QY@;0?ooo`030000003oool0oooo0140
oooo000U0?ooo`030000003oool0oooo06@0oooo00<000000:Vmj02Y_NP0G02Y_NP20:Zmj0X0ZKgX
00D0nNbY0=VMU03__9`0kkbL0=FGT`030>F[U@<0gInB00H0oM6A0=NIT@3GVI40eiVA0>jdTP3CTi43
0>>UT0040<n@T@3LW900g9b@0<^=T@<0eYJ@00@0kK2>0=6BT03ATY00hZ>?0P3=SY020=^KS`040<Z<
T@3EUHl0eIF?0<R9T@80d96@00@0hZ:>0<f=T03=SI00fYZ>0P39Ri430=FDS`030<N9T@3@T8l0d92?
00<0c8f@00<0fYZ>0<V;T@39Ri400P3DU8l01037RI40d92?0=2@S`35Qi820<b=T0040=ZJSP39Ri40
bH^A0=BDS`80ahVA0P3@T8l01035Qi80c8f@0<b=T033QY<20<V;T@040=BDSP37RI40ahVA0=2@S`80
aHNB0P3<SI000`33QY<0bH^A0<V;T@030<J9T@050=2@S`34Qi80c8f@0<b=T033QY<00`39Ri420<J9
T@040=2@S`34Qi8000000<b=T080`hJC0P39Ri400`31QY@0aXVA0<J9T@030<B7TP050<b=T033QY<0
bH^A0<V;T@31QY@02`3oool00`000000oooo0?ooo`0A0?ooo`009P3oool00`000000oooo0?ooo`1T
0?ooo`030000002Y_NP0ZKgX06P0ZKgX0`3__9`40>F[U@040:[7CP3MWi80gInB0?gAT@<0eiVA00<0
k[BB0=>CT@3SYI000P3SYI00103?T940g9b@0=bLT03;SI430=JFT0040>f`SP3ATY00dI:@0>:SS`80
cHj@0P3KVhl00`3:S940eIF?0=FES`030=2AT0030>:RSP3=SI00cHf@0080fYZ>00D0bH^A0=FDS`3E
U8l0eIB?0<N9T@020=2@S`040>:RS@3<SI00c8f@0=ZJSP80bH^A0P3DU8l01037RI40d92?0=2@S`35
Qi820<b=T0040=ZJSP39Ri40bH^A0=BDS`80ahVA0P3@T8l00`35Qi80c8f@0<b=T0030<V;T@040=BD
SP37RI40ahVA0=2@S`80aHNB0P3<SI001033QY<0bH^A0<V;T@3DU8h20<J9T@050=2@S`34Qi80c8f@
0<b=T033QY<00`39Ri420<J9T@060=2@S`34Qi80a8NB0000003<SI00`hJC0P39Ri400`31QY@0aXVA
0<J9T@030<B7TP050<b=T033QY<0bH^A0<V;T@31QY@02`3oool00`000000oooo0?ooo`0A0?ooo`00
9`3oool00`000000oooo0?ooo`1T0?ooo`030000002Y_NP0ZKgX01H0ZKgX0P2Z_NPb0:Vmj080Z[gX
7`2Y_NP30>F[U@040:[7CP3MWi80gInB0?gAT@80eiVA0P3^]9801@3CTi40hjF@0>>UT03SYI00ci2A
0080g9b@103FUY000`3]/8h0dI:@0=6BT0020>:SS`040<f>T03KVhl0fi^?0<Z<T@80eIF?00@0kJj<
0=2AT03@TI00hZ:>0P3=SI020=ZJSP050<V;T@3EU8l0eIB?0=FDS`37RI400P3@T8l0103RXXd0c8f@
0<b=T03JVXh20<V;T@80e9B?00@0ahVA0=2@S`3@T8l0aHNB0P3<SI00103JVXh0bH^A0<V;T@3DU8l2
0<N9T@80d92?00@0aHNB0<b=T03<SI00fYV>0P39Ri400`3DU8h0ahVA0<N9T@020=2@S`040<F7TP3<
SI00c8f@0<>6T`80bH^A00D0e9B>0<J9T@36RI40d92?0<B7TP020<b=T0040<>6T`39Ri40bH^A0<V;
T@80aXVA00H0d92?0<B7TP34Qi8000000<b=T033QY<20<V;T@030<66U036RI40aXVA00<0a8NB00D0
c8f@0<>6T`39Ri40bH^A0<66U00;0?ooo`030000003oool0oooo0140oooo000X0?ooo`800000I@3o
ool00`000000ZKgX0:Vmj01>0:Vmj0<0Z[gX6@2Y_NP20>F[U@80Z/M>00<0gInB0?gAT@3mdI400P3G
VI420>jdTP050=>CT@3SYI00hjF@0>>UT03?T9400P3LW9001P3lahX0eYJ@0=JFT03FUY00kK2>0=6B
T0<0hZ>?00@0cHj@0=^KS`3KVhl0bXbA0P3EUHl0103][X`0d96@0=2AT03RXXh20<f=T080fYZ>00D0
bH^A0=FDS`3EU8l0eIB?0<N9T@020=2@S`040>:RS@3<SI00c8f@0=ZJSP80bH^A0P3DU8l00`37RI40
d92?0=2@S`030<b=T0030=ZJSP39Ri40bH^A0080e9B?00@0ahVA0=2@S`3@T8l0aHNB0P3<SI00103J
VHh0bH^A0<V;T@3DU8h20<N9T@80d92?00@0aHNB0<b=T03<SI00`hJC0P39Ri401@3DU8h0aXVA0<J9
T@3@T8l0a8NB00<0c8f@0`39Ri420<J9T@060=2@S`34Qi80a8NB0<b=T0000000`hJC0P39Ri401031
QY@0aXVA0<J9T@3@T8l20<B7TP050<b=T033QY<0bH^A0<V;T@31QY@02`3oool00`000000oooo0?oo
o`0A0?ooo`00:P3oool00`000000oooo0?ooo`1S0?ooo`030000002Y_NP0ZKgX06X0ZKgX00@0iJ^E
0000002Zadh0gInB0`3mdI40103GVI40k[BB0>jdTP3CTi430>>UT0040<n@T@3LW900g9b@0?c7RP<0
eYJ@00<0kK2>0=6BT03RXhl00P3RXhl0103=SY00fi^?0=^KS`3:S9420=FES`040>f^S03@TI00d96@
0>:RSP80cHf@0P3JVXh01039Ri40eIB?0=FDS`3EU8l30=2@S`030>:RS@3<SI00c8f@0080fYZ>00@0
bH^A0=BDS`3DU8l0ahVA0P3@T8l0103RXHd0c8f@0<b=T03JVXh20<V;T@80e9B?00@0ahVA0=2@S`3@
T8l0aHNB0P3<SI00103JVHh0bH^A0<V;T@3DU8h20<N9T@80d92?00<0aHNB0<b=T03<SI000`39Ri40
1@3DU8h0aXVA0<J9T@3@T8l0a8NB00<0c8f@0`39Ri400`3DU8h0aXVA0=2@S`020<B7TP80c8f@00@0
00000<V;T@39Ri40`HJD0P36RI401@3@T8l0a8NB0<B7TP3<SI00`hJC0080bH^A00<0`HJD0?ooo`3o
ool02@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000
002Y_NP0ZKgX00T0ZKgX0P2Z_NQK0:Vmj0<000000P3oool00`2Zadh0gInB0?gAT@020?gAT@040=NI
T@3^]980k[BB0=>CT@<0hjF@0`3LW9001P3lahX0eYJ@0=JFT03FUY00kK2>0=6BT0<0hZ>?00<0cHj@
0=^KS`3KVhl00`3EUHl00`3][X`0d96@0=2AT0020>:RSP040<f=T03JVXh0fYZ>0<V;T@<0eIB?00@0
kJj;0=2@S`3@T8l0hZ:=0P3<SI020=ZJSP040<V;T@3DU8l0e9B?0<N9T@80d92?00@0hZ6=0<b=T03<
SI00fYZ>0P39Ri420=BDS`040<N9T@3@T8l0d92?0<F7TP80c8f@00@0fYV>0<V;T@39Ri40e9B>0P37
RI420=2@S`040<F7TP3<SI00c8f@0=ZIS@80bH^A00<0e9B>0<J9T@36RI400P3@T8l30<b=T0<0bH^A
00D0e9B>0<J9T@3@T8l0d92?0<B7TP020<b=T0040<>6T`000000bH^A0<66U080aXVA00D0d92?0<B7
TP34Qi80c8f@0<>6T`030<V;T@`0oooo00<000000?ooo`3oool0403oool002`0oooo00<000000?oo
o`3oool0I03ooomU0:Vmj08000001P3oool01@3MWi80oM6A0?gAT@3mdI40eiVA0080k[BB00D0di>A
0>>UT03SYI00hjF@0=WAE@020=bLT0030?c7RP3FUY00eYJ@0080kK2>00D0dI:@0>:SS`3RXhl0hZ>?
0<f>T0020=^KS`040?_3QP3EUHl0eIF?0>f^S080d96@0P3RXXh0103=SI00fYZ>0=ZJSP39Ri430=FD
S`040>f^R`3@T8l0d92?0>:RS@80c8f@0P3JVXh01039Ri40e9B?0=BDS`37RI420=2@S`040>:QS@3<
SI00c8f@0=ZJSP80bH^A0P3DU8l00`37RI40d92?0=2@S`030<b=T0030=ZISP39Ri40bH^A0080e9B>
00@0ahVA0=2@S`3@T8l0aHNB0P3<SI00103JVHd0bH^A0<V;T@3DU8h20<J9T@80d92?0`3<SI030<V;
T@050=BDSP36RI40d92?0=2@S`34Qi800`3<SI000`000000bH^A0<J9T@020<J9T@030=2@S`34Qi80
a8NB0080c8f@0`39Ri4<0?ooo`030000003oool0oooo0100oooo000]0?ooo`800000I@3ooomP0:Vm
j08000002P3oool40?gAT@030=NIT@3^]980k[BB00@0hjF@00@0fM5E0=bLT03LW900o<N:0P3FUY02
0>f`SP050=6BT03RXhl0hZ>?0>:SS`3=SY000P3KVhl0103k`hH0eIF?0=FES`3][X`20=2AT080hZ:>
00@0cHf@0=ZJSP3JVXh0bH^A0`3EU8l0103][X/0d92?0=2@S`3RXXd20<b=T080fYZ>00<0bH^A0=BD
S`3DU8l00`3@T8l00`3RXHd0c8f@0<b=T0020=ZJSP040<V;T@3DU8l0e9B?0<N9T@80d92?00@0hZ6<
0<b=T03<SI00fYV>0P39Ri420=BDSP040<N9T@3@T8l0d92?0<F7TP80c8f@00@0fYV=0<V;T@39Ri40
e9B>0P36RI420=2@S`<0c8f@0`39Ri401@3DU8h0aXVA0=2@S`3@T8l0a8NB00<0c8f@00<0bH^A0000
003DU8h00P36RI400`3@T8l0a8NB0<B7TP020<b=T0<0bH^A303oool00`000000oooo0?ooo`0@0?oo
o`00;`3oool00`000000oooo0?ooo`1S0?oooe/0ZKgX0`00000A0?ooo`<0k[BB00H0<@160>>UT03S
YI00hjF@0=WAE@3LW9030?c7RP040=JFT03]/8h0kK2>0=6BT0<0hZ>?00@0cHj@0=^KS`3KVhl0nl>6
0P3EUHl00`3][X`0d96@0=2AT0020>:RSP030<f=T03JVXh0fYZ>00@0eIB?00<0kJj;0=2@S`3@T8l0
0P3RXXd0103<SI00fYZ>0=ZJSP39Ri420=BDS`040>f]RP3@T8l0d92?0>:QS@80c8f@0P3JVXh01039
Ri40e9B?0=BDS`37RI420=2@S`040>:QS03<SI00c8f@0=ZISP80bH^A0P3DU8h01037RI40d92?0=2@
S`35Qi820<b=T0040=ZIS@39Ri40bH^A0=BDSP80aXVA0P3@T8l30<b=T0050=^IS@39Ri40bH^A0=BD
SP36RI400P3@T8l01034Qi80c8f@0<b=T03<SI020<V;T@0300000036RI40aXVA0080d92?00<0a8NB
0<b=T03<SI000`39Ri4<0?ooo`030000003oool0oooo0100oooo000`0?ooo`030000003oool0oooo
06<0oooo00<000000:Vmj02Y_NP0E@2Y_NP2000001D0oooo00<0k[BB0?ooo`3oool00P3SYI020=WA
E@050=bLT03lahX0o<N:0?c7RP3FUY000P3]/8h0103ATY00hZ>?0>:SS`3RXhl30=^KS`030?_3QP3E
UHl0eIF?0080kJj<00@0d96@0>:RSP3RXXh0cHf@0P3JVXh01P3k`X@0eIB?0=FDS`3EU8l0kJj;0=2@
S`<0hZ:=00@0c8f@0=ZJSP3JVXh0bH^A0P3DU8l0103][HX0d92?0=2@S`3RXHd20<b=T080fYZ>00@0
bH^A0=BDS`3DU8l0ahVA0P3@T8l0103RXH`0c8f@0<b=T03JVHh20<V;T@80e9B>00<0ahVA0=2@S`3@
T8l00`3<SI000`3JVHd0bH^A0<V;T@020=BDSP030<J9T@3@T8l0d92?00<0c8f@00D0fiV=0<V;T@39
Ri40e9B>0<J9T@020=2@S`040<B7TP3<SI00c8f@0<b=T080bH^A00<000000<J9T@36RI400P3@T8l0
0`34Qi80c8f@0<b=T0030<V;T@`0oooo00<000000?ooo`3oool0403oool00340oooo00<000000?oo
o`3oool0H`3oool00`000000ZKgX0:Vmj01@0:Vmj08000006@3oool00`3^]980oooo0?ooo`020>>U
T080fM5E00D0g9b@0?c7RP3lahX0o<N:0=JFT0020>f`SP050=6BT03RXhl0hZ>?0>:SS`3Ud5H00P3K
Vhl00`3k`hH0eIF?0=FES`020>f^S0040=2AT03RXXh0hZ:>0<f=T080fYZ>00H0nl:40=FDS`3EU8l0
eIB?0>f^R`3@T8l30>:RS@040<b=T03JVXh0fYZ>0<V;T@80e9B?00@0kJf:0=2@S`3@T8l0hZ6=0P3<
SI020=ZJSP030<V;T@3DU8l0e9B?00<0d92?00<0hZ6<0<b=T03<SI000P3JVHh01039Ri40e9B>0=BD
SP37RI420=2@S`040>>QS03<SI00c8f@0=ZIS@80bH^A0P3DU8h00`36RI40d92?0=2@S`030<b=T005
0=^IS@39Ri40bH^A0=BDSP36RI400`3@T8l30<b=T080bH^A00<0e9B>00000036RI400P3@T8l00`34
Qi80c8f@0<b=T0030<V;T@`0oooo00<000000?ooo`3oool0403oool00380oooo0P00001T0?ooo`03
0000002Y_NP0ZKgX03<0ZKgX0`2Z_NPE0:Vmj0<00000803oool0103SYI00oooo0=WAE@3LW9030?c7
RP030=JFT03]/8h0kK2>00@0hZ>?00@0iM1F0=^KS`3KVhl0nl>60P3EUHl20>f^S0040=2AT03RXXh0
hZ:>0<f=T080fYZ>00H0nl:40=FDS`3EU8l0eIB?0>f^R`3@T8l30>:RS@030<b=T03JVXh0fYZ>00<0
e9B?00<0kJf:0=2@S`3@T8l00P3RXHd0103<SI00fYZ>0=ZJSP39Ri420=BDS`040>f]R@3@T8l0d92?
0>:QS080c8f@0P3JVHh01039Ri40e9B>0=BDSP37RI420=2@S`040>>QS03<SI00c8f@0=ZIS@80bH^A
0P3DU8h00`36RI40d92?0=2@S`030<b=T0050=^IS@39Ri40bH^A0=BDSP36RI400`3@T8l30<b=T005
0=^IS@39Ri40e9B>0<J9T@0000000P3@T8l00`34Qi80c8f@0<b=T0030<V;T@d0oooo00<000000?oo
o`3oool03`3oool003@0oooo00<000000?ooo`3oool0HP3oool00`000000ZKgX0:Vmj0180:Vmj080
00008`3oool0103SYI00oooo0=WAE@3LW9030?c7RP040=JFT03]/8h0kK2>01<0@P<0hZ>?00<0iM1F
0=^KS`3k`hH00P3k`hH0103EUHl0kJj<0>f^S03@TI020>:RSP<0fYZ>00H0nl:40=FDS`3EU8l0eIB?
0>f^R`3@T8l30>:RS@040<b=T03JVXh0fYZ>0?c1PP80e9B?00<0kJf:0=2@S`3@T8l00P3RXHd0103<
SI00fYZ>0=ZJSP39Ri420=BDS`040>f]R@3@T8l0d92?0>:QS080c8f@0P3JVHh01039Ri40e9B>0=BD
SP37RI420=2@S`040>>QS03<SI00c8f@0=ZIS@80bH^A0P3DU8h00`36RI40d92?0=2@S`030<b=T003
0=^IS@39Ri40bH^A0080e9B>0`3@T8l30<b=T0080=^IS@39Ri40e9B>0=BDSP36RI4000000=2@S`34
Qi820<b=T0<0bH^A3@3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool00`000000oooo0?ooo`1R
0?ooo`030000002Y_NP0ZKgX0240ZKgX0`2Z_NPO0:Vmj0800000:P3oool0103LW900o<N:0?c7RP3l
ahX30>f`SP0601<0@P3RXhl0hZ>?0>:SS`3Ud5H0fi^?0`3k`hH0103EUHl0kJj<0>f^S03@TI020>:R
SP040>O=D`3JVXh0fYZ>0?_2Q080eIB?0P3][X/01@3@T8l0hZ:=0>:RS@3RXXd0c8f@0080fYZ>00@0
o<620=BDS`3DU8l0kJf:0P3@T8l20>:QS@040<b=T03JVXh0fYZ>0<V;T@80e9B?00@0kJf90=2@S`3@
T8l0hZ6<0P3<SI020=ZISP030<V;T@3DU8h0e9B>00<0d92?00<0hj6<0<b=T03<SI000P3JVHd01039
Ri40e9B>0=BDSP36RI420=2@S`040>>QR`3<SI00c8f@0=^IS@80bH^A0P3DU8h30=2@S`<0c8f@00H0
fiV=0<V;T@3DU8h0e9B>0<J9T@0000020=2@S`80c8f@0`39Ri4=0?ooo`030000003oool0oooo00l0
oooo000f0?ooo`030000003oool0oooo0680oooo00<000000:Vmj02Y_NP0?P2Y_NP3000002d0oooo
00<0o<N:0?ooo`3oool00P3oool00`3]/8h0oooo0?ooo`020>:SS`80iM1F00D0fi^?0?_3QP3k`hH0
nl>60=FES`020>f^S0040=2AT03RXXh0hZ:>0>O=D`80fYZ>00<0nl:40=FDS`3EU8l00P3][X/01@3@
T8l0hZ:=0>:RS@3RXXd0c8f@0080fYZ>00@0o<620=BDS`3DU8l0kJf:0P3@T8l20>:QS@030<b=T03J
VXh0fYZ>00<0e9B?00<0kJf90=2@S`3@T8l00P3RXH`0103<SI00fYV>0=ZISP39Ri420=BDSP040>j]
R@3@T8l0d92?0>>QS080c8f@0P3JVHd01039Ri40e9B>0=BDSP36RI420=2@S`040>>QR`3<SI00c8f@
0=^IS@80bH^A0P3DU8h30=2@S`<0c8f@00P0fiV=0<V;T@3DU8h0e9B>0<J9T@3@T8l000000=2@S`80
c8f@00<0fiV=0<V;T@39Ri403@3oool00`000000oooo0?ooo`0?0?ooo`00=`3oool2000006<0oooo
?P2Y_NP2000003D0oooo00D0kK2>0?ooo`3oool04`120>:SS`020>G@EP050=^KS`3k`hH0nl>60?_3
QP3EUHl00P3][X`30>:RSP030>O=D`3JVXh0fYZ>0080nl:400@0eIB?0>f^R`3][X/0d92?0`3RXXd3
0=ZJSP030?c1PP3DU8l0e9B?0080kJf:00@0d92?0>:QS@3RXHd0c8f@0P3JVXh0103l`H00e9B?0=BD
S`3][HT20=2@S`80hZ6<00@0c8f@0=ZISP3JVHh0bH^A0P3DU8h0103^[HT0d92?0=2@S`3SXH`20<b=
T080fYV=00@0bH^A0=BDSP3DU8h0aXVA0P3@T8l0103SXH/0c8f@0<b=T03KVHd20<V;T@80e9B>0`3@
T8l30<b=T0050=^IS@39Ri40e9B>0=BDSP36RI400P3@T8l010000000c8f@0<b=T03KVHd20<V;T@d0
oooo00<000000?ooo`3oool03`3oool003T0oooo00<000000?ooo`3oool0H@3oool010000000ZKgW
0:Vmi`2Y_NLe0:Vmj0800000>@3oool0203]/8h0oooo0?ooo`3oool0hZ>?0?ooo`3Ud5H0fi^?0`3k
`hH0103EUHl0kJj<0>f^S00704820>:RSP030>O=D`3JVXh0fYZ>0080nl:400@0eIB?0>f^R`3][X/0
d92?0`3RXXd0103VbTh0fYZ>0=ZJSP3l`H820=BDS`80kJf:00@0d92?0>:QS@3RXHd0c8f@0P3JVXh0
103l`H00e9B?0=BDS`3][HT20=2@S`80hZ6<00@0c8f@0=ZISP3JVHh0bH^A0P3DU8h0103^[HT0d92?
0=2@S`3SXH`20<b=T080fYV=00<0bH^A0=BDSP3DU8h00`3@T8l00`3SXH/0c8f@0<b=T0020=^IS@03
0<V;T@3DU8h0e9B>00<0d92?00D0hj6;0<b=T03<SI00fiV=0<V;T@020=BDSP070<J9T@3@T8l0d92?
0=2@S`000000c8f@0=^IS@020<V;T@d0oooo00<000000?ooo`3oool03`3oool003X0oooo00<00000
0?ooo`3oool0H@3oool010000000ZKgX0:Vmj02Y_NP20:Zmj2h0ZKgX0`0000100?ooo`040>:SS`3o
ool0oooo0=^KS`<0nl>60`3][X`010070480hZ:>0>O=D`3WcE<20=ZJSP80nl:400@0eIB?0>f^R`3]
[X/0d92?0`3RXXd0103VbTh0fYZ>0=ZJSP3l`H820=BDS`80kJf:00@0d92?0>:QS@3RXHd0c8f@0P3J
VXh0103l`H00e9B?0=BDS`3][HT20=2@S`80hZ6<00<0c8f@0=ZISP3JVHh00`3DU8h00`3^[HT0d92?
0=2@S`020>>QS0040<b=T03JVHd0fYV=0<V;T@80e9B>00@0kZf80=2@S`3@T8l0hj6;0P3<SI020=^I
S@030<V;T@3DU8h0e9B>00<0d92?00D0hj6;0<b=T03<SI00fiV=0<V;T@030=BDSP<0d92?00<00000
0<b=T03KVHd00P39Ri4=0?ooo`030000003oool0oooo00l0oooo000k0?ooo`030000003oool0oooo
0640oooo00@000000:Vmi`2Y_NL0ZKgW;@2Y_NP2000004H0oooo0`3k`hH20?ooo`040>f^S03oool0
1`120>:RSP<0ileC00@0fYZ>0?_2Q03k`X@0eIB?0P3][X/40>:RS@030>K:CP3JVXh0o<620080o<62
00@0e9B?0>f]RP3][HX0d92?0P3RXHd30=ZJSP030?c1P03DU8l0e9B?0080kJf900@0d92?0>:QS03R
XH`0c8f@0P3JVHh0103l`Gl0e9B>0=BDSP3^[HT20=2@S`80hj6<00@0c8f@0=ZIS@3JVHd0bH^A0P3D
U8h0103^[HP0d92?0=2@S`3SXH/20<b=T080fiV=00<0bH^A0=BDSP3DU8h00`3@T8l01@3SXH/0c8f@
0<b=T03KVHd0bH^A00<0e9B>0`3@T8l00`3<SI0000000=^IS@020<V;T@h0oooo00<000000?ooo`3o
ool03P3oool003`0oooo0P00001R0?ooo`030000002Z_NL0Z[gW00H0Z[gW0P2Y_NL30:Zmj1h0ZKgX
0P00001?0?ooo`040>f^S03oool0oooo0>:RSP<0ileC00@0fYZ>0?_2Q03k`X@0eIB?0P3][X/01P05
04D0hZ:=0>:RS@3RXXd0i/Y>0=ZJSP<0o<6200@0e9B?0>f]RP3][HX0d92?0P3RXHd0103SadT0fYZ>
0=ZJSP3l`H020=BDS`80kJf900@0d92?0>:QS03RXH`0c8f@0P3JVHh0103l`Gl0e9B>0=BDSP3^[HT2
0=2@S`80hj6<00@0c8f@0=ZIS@3JVHd0bH^A0P3DU8h0103^[HP0d92?0=2@S`3SXH/20<b=T080fiV=
00<0bH^A0=BDSP3DU8h00`3@T8l00`3SXH/0c8f@0<b=T0020=^IS@<0e9B>0`3@T8l01@3SXH/0c8f@
0000003KVHd0bH^A00h0oooo00<000000?ooo`3oool03P3oool003h0oooo00<000000?ooo`3oool0
H03oool00`000000Z[gW0:Zmi`030:Zmi`<0ZKgW0P2Z_NP30:Vmi`L0ZKgX0`2Z_NP?0:Vmj0<00000
DP3oool01@3][X`0oooo0?ooo`3RXXh0oooo0080ileC00@0fYZ>0?_2Q03k`X@0eIB?0P3][X/01P05
04D0hZ:=0>:RS@3RXXd0i/Y>0=ZJSP<0o<6200@0e9B?0>f]RP3][HX0d92?0P3RXHd0103SadT0fYZ>
0=ZJSP3l`H020=BDS`80kJf900@0d92?0>:QS03RXH`0c8f@0P3JVHh0103l`Gl0e9B>0=BDSP3^[HT2
0=2@S`80hj6<00<0c8f@0=ZIS@3JVHd00`3DU8h00`3^[HP0d92?0=2@S`020>>QR`040<b=T03KVHd0
fiV=0<V;T@80e9B>00@0kjj70=2@S`3@T8l0hj6;0P3<SI020=^IS@<0e9B>0`3@T8l01@3SXH/0c8f@
0=^IS@000000bH^A00h0oooo00<000000?ooo`3oool03P3oool003l0oooo00<000000?ooo`3oool0
H03oool00`000000Z[gW0:Zmi`030:Zli`D0Z[gW1@2Z_NP30:Vmi`l0ZKgX1000001H0?ooo`050>:R
SP3oool0oooo0>O=D`3JVXh00P3k`X@30>f^R`0300D0A@3RXXd0hZ:=0080i/Y>00D0fYZ>0?c1PP3l
`H80o<620=BDS`020>f]RP040=2@S`3RXHd0hZ6=0>?7B@80fYZ>0P3l`H00103DU8l0kJf90>f]R@3@
T8l20>:QS0<0fYV>00<0o<5o0=BDSP3DU8h00P3^[HT0103@T8l0hj6<0>>QS03<SI020=ZIS@040?g1
O@3DU8h0e9B>0>j]R080d92?0P3SXH/0103<SI00fiV=0=^IS@39Ri420=BDSP040>n^Q`3@T8l0d92?
0>>QR`80c8f@0P3KVHd30=BDSP<0d92?00D0hj6;0<b=T03KVHd000000<V;T@0>0?ooo`030000003o
ool0oooo00h0oooo00100?ooo`030000003oool0oooo0640oooo00<000000:^liP2Z_NL02P2Z_NL2
0:Vmi`<0Z[gX302Y_NP200000600oooo0P3k`X@20?ooo`030>f^R`3oool0oooo0080hZ:=0P3VbTh0
1@3JVXh0o<620?c1PP3l`H80e9B?0080kJf:0`3RXHd00`3SadT0fYZ>0=ZJSP020?c1P0040=BDS`3]
[HT0kJf90=2@S`80hZ6<00@0h<A40=ZISP3JVHh0o<5o0P3DU8h20>j]R@040=2@S`3SXH`0hj6<0<b=
T080fYV=00<0oL5m0=BDSP3DU8h00P3^[HP0103@T8l0hj6;0>>QR`3<SI020=^IS@040<V;T@3DU8h0
e9B>0>n^Q`80d92?00<0hj6;0<b=T03<SI000P3KVHd30=BDSP<0d92?00D0hj6;0<b=T03KVHd0fiV=
0000000>0?ooo`030000003oool0oooo00h0oooo00110?ooo`800000HP3oool00`000000Zk_U0:^k
i@030:^liP80Z[cW0`2Z_NL20:Zli`<0Z[gX0`2Z_NL0102Y_NL0Z[gX0:Zmj02Z_NP20:Vmj0<00000
I`3oool01@3][X/0oooo0?ooo`0504D0hZ:=0080i/Y>00D0fYZ>0?c1PP3l`H80o<620=BDS`020>f]
RP0400L0B03RXHd0hZ6=0>?7B@80fYZ>0P3l`H00103DU8l0kJf90>f]R@3@T8l20>:QS0040>34A03J
VHh0fYV>0?c1O`80e9B>0P3^[HT0103@T8l0hj6<0>>QS03<SI020=ZIS@030?g1O@3DU8h0e9B>0080
kZf800@0d92?0>>QR`3SXH/0c8f@0P3KVHd30=BDSP030>n^Q`3@T8l0d92?0080hj6;00<0c8f@0=^I
S@3KVHd00`3DU8h01@3_[XH0d92?0=2@S`3SXH/0c8f@0080fiV=00<0bH^A0000003oool0303oool0
0`000000oooo0?ooo`0>0?ooo`00@`3oool00`000000oooo0?ooo`1P0?ooo`030000002/^^@0[;[T
00<0[;_T0P2[_>H30:ZliP80Z[cW1P2Z_NL20:Vmj0<00000JP3oool0203][X/0oooo0?ooo`3oool0
hZ:=0?ooo`3VbTh0fYZ>0`3l`H830>f]RP0300L0B03RXHd0hlM90080hlM900@0fYZ>0?c1P03l`H00
e9B?0P3][HT0103@T8l0hZ6<0>:QS03Pa4@20=ZISP80o<5o00@0e9B>0>j]R@3^[HT0d92?0P3SXH`3
0=ZIS@030?g1O@3DU8h0e9B>0080kZf800@0d92?0>>QR`3SXH/0c8f@0P3KVHd0103m`G/0e9B>0=BD
SP3_[XL20=2@S`80hj6;00<0c8f@0=^IS@3KVHd00`3DU8h01@3_[XH0d92?0=2@S`3SXH/0c8f@00<0
fiV=00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`00A03oool00`000000oooo
0?ooo`1P0?ooo`030000002^^>40[[SQ00<0[K[R0P2/^nD30:^li@80ZkcW0`2Z_>L20:Zmi`030000
003oool0oooo0700oooo00<0hZ:=0?ooo`3oool00`3l`H820?ooo`040>f]RP3oool01`180>:QS@<0
hlM900@0fYZ>0?c1P03l`H00e9B?0P3][HT30>:QS0030>34A03JVHh0fYV>0080o<5o00@0e9B>0>j]
R@3^[HT0d92?0P3SXH`0103K`3`0fYV=0=ZIS@3m`Gd20=BDSP80kZf800@0d92?0>>QR`3SXH/0c8f@
0P3KVHd0103m`G/0e9B>0=BDSP3_[XL20=2@S`80hj6;00<0c8f@0=^IS@3KVHd00`3DU8h01@3_[XH0
d92?0=2@S`3SXH/0c8f@00<0fiV=00<0oooo0000003oool0303oool00`000000oooo0?ooo`0=0?oo
o`00A@3oool00`000000oooo0?ooo`1P0?ooo`<0/;KM0`2_]]h20:bjh`<0[;_T0P2[_>H2000007d0
oooo00@0kJf:0?ooo`0704P0hZ6=0`3SadT0103JVXh0o<600?c1P03DU8l20>f]R@0400/0C03RXH`0
hZ6<0>34A080fYV>0P3l`Gl0103DU8h0kZf90>j]R@3@T8l20>>QS0040=_0?03JVHd0fYV=0?g1O@80
e9B>0P3^[HP0103@T8l0hj6;0>>QR`3<SI020=^IS@040?g1N`3DU8h0e9B>0>n^Q`80d92?0P3SXH/0
0`3<SI00fiV=0=^IS@030=BDSP030>n^QP3@T8l0d92?0080hj6;0`3KVHd20?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03@3oool004H0oooo0P00001Q0?ooo`<0/[7G0P2_]]h30:jh
h0<00000P03oool01@3][HX0oooo0?ooo`3RXHd0oooo0080hlM900<0fYZ>0?c1P03l`H000`3][HT0
0`0;04`0hZ6<0>:QS0020>34A0040=ZISP3l`Gl0o<5o0=BDSP80kZf900@0d92?0>>QS03SXH`0fl0l
0P3JVHd20?g1O@040=BDSP3^[HP0kZf80>j]R080hj6;0`3KVHd00`3m`G/0e9B>0=BDSP020>n^Q`04
0=2@S`3SXH/0hj6;0<b=T080fiV=00@0oL5i0=BDSP3DU8h0kjj60P3@T8l20>>QR`<0fiV=0`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00180?ooo`030000003oool0oooo
05l0oooo0`2eZlh20;6cf@030000003oool0oooo08D0oooo00H0hZ6=0?ooo`3oool0hlM90=ZJSP3l
`H020?ooo`030>f]R@3oool0oooo0080hZ6<0P3Pa4@0103JVHh0o<5o0?c1O`3DU8h20>j]R@<0hj6<
00<0fl0l0=ZIS@3JVHd00P3m`Gd0103DU8h0kZf80>j]R03^[HP20>>QR`040=Fk=@3KVHd0fiV=0?g1
N`80e9B>0P3_[XL0103@T8l0hj6;0>>QR`3<SI020=^IS@040?g1N@3DU8h0e9B>0>n^QP80d92?0P3S
XH/30=^IS@<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`00B@3oool0
0`000000oooo0?ooo`1O0?ooo`80]J_>SP3oool01@3l`H00oooo0?ooo`3oool0kJf90080oooo00D0
2`1<0>:QS03Pa4@0h<A40=ZISP020?c1O`040=BDSP3^[HT0kZf90140D080hj6<00<0fl0l0=ZIS@3J
VHd00P3m`Gd0103DU8h0kZf80>j]R03^[HP20>>QR`040=Fk=@3KVHd0fiV=0?g1N`80e9B>0P3_[XL0
103@T8l0hj6;0>>QR`3<SI020=^IS@040?g1N@3DU8h0e9B>0>n^QP80d92?0P3SXH/30=^IS@@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`00BP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0940oooo00D0kJf90?ooo`3oool0oooo0>:QS0020>34A0030=ZI
SP3l`Gl0o<5o00<0kZf900<04@1@0>>QS03SXH`00P3K`3`0103JVHd0oL5m0?g1O@3DU8h30>j]R080
hj6;00<0eK/e0=^IS@3KVHd00P3m`G/0103DU8h0kjj70>n^Q`3@T8l20>>QR`<0fiV=00<0oL5i0=BD
SP3DU8h00P3_[XH00`3@T8l0hj6;0>>QR`030=^IS@D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00B`3oool2000005h0oooo00<000000?ooo`3oool0U@3oool01@3RXH`0
oooo0>34A03JVHh0o<5o0080oooo0P3^[HT00`3oool0hj6<0>>QS0020=_0?0040=ZIS@3m`Gd0oL5m
0=BDSP<0kZf80P3SXH/00`3E^cD0fiV=0=^IS@020?g1N`040=BDSP3_[XL0kjj70=2@S`80hj6;00@0
ckH^0=^IS@3KVHd0oL5i0P3DU8h20>n^QP030=2@S`3SXH/0hj6;00<0fiV=1P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00d0oooo001=0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0V03oool0103l`Gl0oooo0?ooo`3oool20>j]R@030?ooo`0A0500hj6<0080fl0l
00@0fYV=0?g1O@3m`Gd0e9B>0`3^[HP00`0F05@0hj6;0=Fk=@020=^IS@80oL5k00@0e9B>0>n^Q`3_
[XL0d92?0P3SXH/0103?]Rh0fiV=0=^IS@3m`GT20=BDSP80kjj600<0d92?0>>QR`3SXH/00`3KVHd6
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool004h0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`2M0?ooo`070>j]R@3oool0oooo0>>QS03oool0fl0l0=ZI
S@020?g1O@@0kZf800D05P1D0>>QR`3E^cD0eK/e0=^IS@020?g1N`030=BDSP3_[XL0kjj700<0hj6;
00<0ckH^0=^IS@3KVHd00P3m`GT0103DU8h0kjj60>n^QP3@T8l20>>QR`<0fiV=1`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo001?0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0X03oool01@3SXH`0oooo0?ooo`3JVHd0oL5m0080oooo0P3^[HP00`3oool0
5P1D0>>QR`020=Fk=@040=^IS@3m`G/0oL5k0=BDSP80kjj700@06`1H0>>QR`3SXH/0ckH^0P3KVHd2
0?g1N@040=BDSP3_[XH0kjj60=2@S`80hj6;00<0bK4V0=^IS@3KVHd0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo001@0?ooo`800000F@3oool00`000000oooo0?ooo`2S
0?ooo`040?g1O@3oool0oooo0?ooo`80kZf800<0oooo01H0E03SXH/00P3E^cD0103KVHd0oL5k0?g1
N`3DU8h20>n^Q`0401/0F03SXH/0hj6;0<nf;P80fiV=0P3m`GT0103DU8h0kjj60>n^QP3@T8l20>>Q
R`030<Va9P3KVHd0fiV=00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`00DP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0:P0oooo00L0kZf80?ooo`3o
ool0hj6;0?ooo`3E^cD0fiV=0080oL5k0`3_[XL00`0K05P0hj6;0>>QR`020<nf;P040=^IS@3m`GT0
oL5i0=BDSP80kjj60`3SXH/00`39/BH0fiV=0=^IS@090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool005<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2[
0?ooo`050>>QR`3oool0oooo0=^IS@3m`G/00P3oool20>n^Q`030?ooo`3SXH/0hj6;0080ckH^00@0
fiV=0?g1N@3m`GT0e9B>0P3_[XH0100P05`0hj6;0>>QR`39/BH20=^IS@X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`00E03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0:h0oooo00@0oL5k0?ooo`3oool0oooo0P3_[XL00`3oool06`1H0>>QR`020<nf;P04
0=^IS@3m`GT0oL5i0=BDSP80kjj600@0801L0>>QR`3SXH/0bK4V0P3KVHd;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool005D0oooo0P00001D0?ooo`030000003oool0oooo
0;<0oooo00L0kjj70?ooo`3oool0hj6;0?ooo`3?]Rh0fiV=0080oL5i0`3_[XH00`0P05`0hj6;0>>Q
R`020<Va9P030=^IS@3oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`00E`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0;H0oooo00<0hj6;
0?ooo`3oool00P3m`GT20?ooo`80kjj600<0oooo0>>QR`3SXH/00P39/BH00`3KVHd0oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool005P0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`2m0?ooo`80kjj600<0oooo0200G03SXH/00P39/BH00`3K
VHd0oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000003@3oool005T0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`2n0?ooo`070>n^QP3oool0oooo0>>QR`3oool0bK4V0=^I
S@0>0?ooo`040000003oool0oooo000000d0oooo001J0?ooo`800000C`3oool00`000000oooo0?oo
o`310?ooo`030>>QR`3oool0oooo00l0oooo00@000000?ooo`3oool000003@3oool005`0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0000000d0oooo001M
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0000000<
0?ooo`00GP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0=H0oooo0P00000<0?oo
o`00G`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=H0oooo0P00000<0?ooo`00
H03oool2000004T0oooo00<000000?ooo`3oool0eP3oool2000000`0oooo001R0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0d`3oool4000000h0oooo001S0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0c`3oool400000180oooo001T0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0b`3oool4000001H0oooo001U0?ooo`800000@`3oool00`000000
oooo0?ooo`370?ooo`@000006P3oool006L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`340?ooo`<000007P3oool006P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`300?ooo`@000008@3oool006T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2l
0?ooo`@000009@3oool006X0oooo0P00000n0?ooo`030000003oool0oooo0;P0oooo1000000Y0?oo
o`00K03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;@0oooo1000000]0?ooo`00
K@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0`00000a0?ooo`00KP3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1000000d0?ooo`00K`3oool2
000003T0oooo00<000000?ooo`3oool0Z@3oool4000003P0oooo001a0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0Y@3oool4000003`0oooo001b0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0XP3oool300000400oooo001c0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0WP3oool4000004<0oooo001d0?ooo`800000=03oool00`000000oooo0?oo
o`2J0?ooo`@00000A`3oool007H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F
0?ooo`@00000B`3oool007L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?oo
o`@00000C`3oool007P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2?0?ooo`<0
0000D`3oool007T0oooo0P00000_0?ooo`030000003oool0oooo08/0oooo1000001F0?ooo`00N`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo1000001J0?ooo`00O03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000001N0?ooo`00O@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo1000001R0?ooo`00OP3oool2000002X0
oooo00<000000?ooo`3oool0O03oool3000006H0oooo00200?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0N03oool4000006T0oooo00210?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0M03oool4000006d0oooo00220?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0L03oool400000740oooo00230?ooo`8000009@3oool00`000000oooo0?ooo`1/0?oo
o`@00000M@3oool008D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1Y0?ooo`<0
0000N@3oool008H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1U0?ooo`@00000
O03oool008L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Q0?ooo`@00000P03o
ool008P0oooo0P00000P0?ooo`030000003oool0oooo05d0oooo100000240?ooo`00RP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05T0oooo100000280?ooo`00R`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05H0oooo0`00002<0?ooo`00S03oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0580oooo1000002?0?ooo`00S@3oool2000001/0oooo00<0
00000?ooo`3oool0CP3oool4000009<0oooo002?0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0BP3oool4000009L0oooo002@0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0AP3oool4000009/0oooo002A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0A03oool3000009l0oooo002B0?ooo`8000005@3oool00`000000oooo0?ooo`100?ooo`@00000
XP3oool009@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`@00000YP3o
ool009D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`@00000ZP3oool0
09H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0e0?ooo`<00000[P3oool009L0
oooo0P00000@0?ooo`030000003oool0oooo0340oooo1000002a0?ooo`00V@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02d0oooo1000002e0?ooo`00VP3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02T0oooo1000002i0?ooo`00V`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02D0oooo1000002m0?ooo`00W03oool2000000/0oooo00<000000?oo
o`3oool08P3oool300000<40oooo002N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool07P3oool400000<@0oooo002O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<P0oooo002P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3o
ool400000<`0oooo002Q0?ooo`8000001P3oool00`000000oooo0?ooo`0B0?ooo`@00000d03oool0
0:<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000e03oool00:@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000e`3oool00:D0oooo
00D000000?ooo`3oool0oooo000000090?ooo`@00000f`3oool00:H0oooo0P0000000`3oool00000
0?ooo`040?ooo`@00000g`3oool00:P0oooo0P0000000`3oool000000000000200000><0oooo002Y
0?ooo`800000i`3oool00?l0ooooT`3oool00?l0ooooT`3oool00?l0ooooT`3oool00?l0ooooT`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 401.75}, {325.625, 0}} -> {-0.0621918, -0.000230048, \
0.00391261, 0.00391261}}]
}, Open  ]],

Cell["Notice the nonlinear interaction when they pass each other.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {\(-1.855\), \(-1.725\), 4.000}]; \)], "Input",\

  CellLabel->"In[94]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .96258 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-0.00104224 1.00509 5.63243e-017 1.00509 [
[.52934 -0.0082 0 -10.1752 ]
[.52934 -0.0082 8.4375 .76234 ]
[.64807 .11071 0 -9.99308 ]
[.64807 .11071 12.875 .94442 ]
[.76186 .22468 0 -9.82455 ]
[.76186 .22468 12.875 1.11295 ]
[.87102 .33402 0 -9.66813 ]
[.87102 .33402 12.875 1.26937 ]
[.97583 .43901 0 -9.52256 ]
[.97583 .43901 12.875 1.41494 ]
[.51094 -0.00889 -8.43212 -10.9375 ]
[.51094 -0.00889 .00538 0 ]
[.40761 .08006 -8.4375 -10.7602 ]
[.40761 .08006 0 .17734 ]
[.3075 .16624 -8.4375 -10.5878 ]
[.3075 .16624 0 .34966 ]
[.21047 .24978 -8.4375 -10.4264 ]
[.21047 .24978 0 .51111 ]
[.11638 .33078 -8.4375 -10.2748 ]
[.11638 .33078 0 .66269 ]
[.0251 .40938 -12.875 -10.1322 ]
[.0251 .40938 0 .80527 ]
[.97583 .43901 0 -9.52256 ]
[.97583 .43901 8.4375 1.41494 ]
[.98233 .46677 0 -9.49702 ]
[.98233 .46677 8.4375 1.44048 ]
[.989 .49531 0 -9.4708 ]
[.989 .49531 8.4375 1.4667 ]
[.99587 .52468 0 -9.44389 ]
[.99587 .52468 8.4375 1.49361 ]
[1.00294 .5549 0 -9.41625 ]
[1.00294 .5549 8.4375 1.52125 ]
[1.01021 .58601 0 -9.38785 ]
[1.01021 .58601 12.875 1.54965 ]
[ 0 0 0 0 ]
[ 1 .96258 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.51982 0 m
.96574 .44649 L
s
.51982 0 m
.51506 .0041 L
s
gsave
.52934 -0.0082 -61 -14.1752 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.63839 .11872 m
.63355 .12272 L
s
gsave
.64807 .11071 -61 -13.9931 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.75203 .23251 m
.74712 .23642 L
s
gsave
.76186 .22468 -61 -13.8246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.86106 .34167 m
.85608 .3455 L
s
gsave
.87102 .33402 -61 -13.6681 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.96574 .44649 m
.96069 .45023 L
s
gsave
.97583 .43901 -61 -13.5226 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
.54394 .02415 m
.54108 .0266 L
s
.56786 .0481 m
.56498 .05053 L
s
.59157 .07184 m
.58868 .07426 L
s
.61508 .09538 m
.61218 .09779 L
s
.6615 .14186 m
.65859 .14425 L
s
.68442 .16481 m
.6815 .16719 L
s
.70714 .18756 m
.70421 .18993 L
s
.72968 .21013 m
.72674 .21249 L
s
.7742 .2547 m
.77124 .25704 L
s
.79618 .27671 m
.79322 .27904 L
s
.81798 .29854 m
.81501 .30086 L
s
.83961 .3202 m
.83663 .3225 L
s
.88233 .36298 m
.87934 .36526 L
s
.90344 .38411 m
.90043 .38638 L
s
.92437 .40507 m
.92136 .40733 L
s
.94514 .42586 m
.94212 .42812 L
s
.25 Mabswid
.51982 0 m
.03466 .41753 L
s
.51982 0 m
.52426 .00444 L
s
gsave
.51094 -0.00889 -69.4321 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.41664 .0888 m
.42115 .09317 L
s
gsave
.40761 .08006 -69.4375 -14.7602 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.31667 .17483 m
.32126 .17912 L
s
gsave
.3075 .16624 -69.4375 -14.5878 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.21978 .25821 m
.22444 .26243 L
s
gsave
.21047 .24978 -69.4375 -14.4264 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.12582 .33908 m
.13054 .34322 L
s
gsave
.11638 .33078 -69.4375 -14.2748 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.03466 .41753 m
.03944 .42161 L
s
gsave
.0251 .40938 -73.875 -14.1322 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.49371 .02247 m
.49639 .02512 L
s
.46782 .04475 m
.4705 .0474 L
s
.44213 .06686 m
.44482 .0695 L
s
.39135 .11056 m
.39407 .11317 L
s
.36626 .13215 m
.36899 .13475 L
s
.34137 .15357 m
.34411 .15616 L
s
.29217 .19592 m
.29493 .19848 L
s
.26785 .21684 m
.27063 .2194 L
s
.24372 .23761 m
.24651 .24015 L
s
.19602 .27866 m
.19882 .28118 L
s
.17244 .29895 m
.17525 .30146 L
s
.14904 .31909 m
.15186 .32159 L
s
.10277 .35891 m
.10561 .36139 L
s
.0799 .3786 m
.08275 .38107 L
s
.05719 .39814 m
.06005 .40059 L
s
.25 Mabswid
.96574 .44649 m
1 .59332 L
s
.96574 .44649 m
.96069 .45023 L
s
gsave
.97583 .43901 -61 -13.5226 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.97221 .47422 m
.96715 .47795 L
s
gsave
.98233 .46677 -61 -13.497 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97886 .50273 m
.97379 .50644 L
s
gsave
.989 .49531 -61 -13.4708 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.98571 .53206 m
.98063 .53576 L
s
gsave
.99587 .52468 -61 -13.4439 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.99275 .56225 m
.98766 .56593 L
s
gsave
1.00294 .5549 -61 -13.4163 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
1 .59332 m
.99489 .59698 L
s
gsave
1.01021 .58601 -61 -13.3879 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.96734 .45335 m
.96431 .45559 L
s
.96895 .46026 m
.96592 .4625 L
s
.97058 .46722 m
.96754 .46945 L
s
.97386 .48127 m
.97082 .48351 L
s
.97551 .48838 m
.97248 .49061 L
s
.97718 .49553 m
.97414 .49776 L
s
.98056 .50999 m
.97751 .51221 L
s
.98226 .51729 m
.97922 .51952 L
s
.98398 .52465 m
.98093 .52687 L
s
.98745 .53953 m
.9844 .54174 L
s
.9892 .54705 m
.98615 .54926 L
s
.99097 .55462 m
.98792 .55683 L
s
.99454 .56993 m
.99148 .57214 L
s
.99635 .57767 m
.99329 .57987 L
s
.99817 .58547 m
.99511 .58767 L
s
.25 Mabswid
.51982 0 m
.5213 .12454 L
s
.5213 .12454 m
0 .5631 L
s
0 .5631 m
.03466 .41753 L
s
.03466 .41753 m
.51982 0 L
s
.96574 .44649 m
.48581 .80225 L
s
.48581 .80225 m
.48474 .96258 L
s
.48474 .96258 m
1 .59332 L
s
1 .59332 m
.96574 .44649 L
s
.51982 0 m
.5213 .12454 L
s
.5213 .12454 m
1 .59332 L
s
1 .59332 m
.96574 .44649 L
s
.96574 .44649 m
.51982 0 L
s
.03466 .41753 m
.48581 .80225 L
s
.48581 .80225 m
.48474 .96258 L
s
.48474 .96258 m
0 .5631 L
s
0 .5631 m
.03466 .41753 L
s
0 0 m
1 0 L
1 .96258 L
0 .96258 L
closepath
clip
newpath
.819 .726 .762 r
.48608 .79904 .48153 .80493 .48579 .80541 .49032 .80077 Mtetra
.893 .775 .723 r
.48181 .79912 .47723 .80741 .48153 .80493 .48608 .79904 Mtetra
.968 .82 .644 r
.47749 .80267 .47283 .8153 .47723 .80741 .48181 .79912 Mtetra
.999 .838 .521 r
.47306 .81241 .46826 .83205 .47283 .8153 .47749 .80267 Mtetra
.946 .808 .358 r
.46844 .83185 .46343 .86016 .46826 .83205 .47306 .81241 Mtetra
0 0 0 r
.46355 .86247 .45836 .89485 .46343 .86016 .46844 .83185 Mtetra
0 0 .22 r
.45847 .89634 .45337 .91745 .45836 .89485 .46355 .86247 Mtetra
.537 .22 .378 r
.4536 .91212 .44897 .90784 .45337 .91745 .45847 .89634 Mtetra
.875 .557 .044 r
.44937 .89407 .44522 .87107 .44897 .90784 .4536 .91212 Mtetra
0 0 .384 r
.44569 .85411 .44169 .82993 .44522 .87107 .44937 .89407 Mtetra
.134 .036 .469 r
.44213 .81471 .43804 .79841 .44169 .82993 .44569 .85411 Mtetra
.263 .143 .523 r
.43841 .78614 .43417 .77781 .43804 .79841 .44213 .81471 Mtetra
.368 .25 .585 r
.43447 .76782 .43012 .76484 .43417 .77781 .43841 .78614 Mtetra
.472 .365 .652 r
.43038 .75623 .42595 .75633 .43012 .76484 .43447 .76782 Mtetra
.563 .471 .709 r
.42619 .74845 .42172 .75022 .42595 .75633 .43038 .75623 Mtetra
.626 .548 .748 r
.42193 .74271 .41744 .74533 .42172 .75022 .42619 .74845 Mtetra
.663 .596 .77 r
.41764 .73804 .41313 .74108 .41744 .74533 .42193 .74271 Mtetra
.684 .624 .782 r
.41332 .73392 .4088 .73718 .41313 .74108 .41764 .73804 Mtetra
.697 .64 .788 r
.40899 .7301 .40446 .73351 .4088 .73718 .41332 .73392 Mtetra
.707 .651 .791 r
.40464 .72649 .40011 .73002 .40446 .73351 .40899 .7301 Mtetra
.717 .663 .796 r
.40027 .7231 .39573 .72675 .40011 .73002 .40464 .72649 Mtetra
.729 .679 .801 r
.39588 .71999 .39134 .72376 .39573 .72675 .40027 .7231 Mtetra
.747 .701 .808 r
.39146 .71728 .38691 .72126 .39134 .72376 .39588 .71999 Mtetra
.776 .736 .816 r
.387 .71519 .38243 .7195 .38691 .72126 .39146 .71728 Mtetra
.82 .79 .824 r
.38248 .71406 .37787 .71888 .38243 .7195 .387 .71519 Mtetra
.876 .867 .826 r
.37786 .71439 .37319 .71992 .37787 .71888 .38248 .71406 Mtetra
.923 .951 .792 r
.3731 .71676 .36836 .72321 .37319 .71992 .37786 .71439 Mtetra
.89 .974 .672 r
.36815 .72172 .36333 .72922 .36836 .72321 .3731 .71676 Mtetra
.742 .885 .48 r
.363 .72933 .3581 .73763 .36333 .72922 .36815 .72172 Mtetra
0 0 0 r
.3577 .73841 .35277 .74664 .3581 .73763 .363 .72933 Mtetra
.35243 .74602 .34758 .75268 .35277 .74664 .3577 .73841 Mtetra
.715 .987 .842 r
.34748 .74816 .34281 .75193 .34758 .75268 .35243 .74602 Mtetra
.506 .51 .795 r
.34306 .74224 .3386 .74303 .34281 .75193 .34748 .74816 Mtetra
.394 .3 .63 r
.33914 .72921 .33483 .72823 .3386 .74303 .34306 .74224 Mtetra
.391 .267 .589 r
.3355 .71277 .33125 .71153 .33483 .72823 .33914 .72921 Mtetra
.418 .286 .592 r
.3319 .69661 .32762 .6961 .33125 .71153 .3355 .71277 Mtetra
.459 .328 .615 r
.32815 .68275 .32382 .68326 .32762 .6961 .3319 .69661 Mtetra
.506 .385 .648 r
.32423 .67162 .31984 .67306 .32382 .68326 .32815 .68275 Mtetra
.555 .446 .684 r
.32013 .66282 .3157 .66498 .31984 .67306 .32423 .67162 Mtetra
.598 .502 .716 r
.31591 .65574 .31144 .65842 .3157 .66498 .32013 .66282 Mtetra
.633 .548 .741 r
.31159 .64984 .3071 .65286 .31144 .65842 .31591 .65574 Mtetra
.657 .582 .759 r
.3072 .64472 .3027 .64795 .3071 .65286 .31159 .64984 Mtetra
.673 .606 .772 r
.30277 .64008 .29825 .64344 .3027 .64795 .3072 .64472 Mtetra
.683 .62 .779 r
.2983 .63574 .29378 .63918 .29825 .64344 .30277 .64008 Mtetra
.691 .63 .783 r
.29382 .63158 .28929 .63509 .29378 .63918 .2983 .63574 Mtetra
.695 .636 .786 r
.28931 .62754 .28478 .63109 .28929 .63509 .29382 .63158 Mtetra
.698 .64 .788 r
.28479 .62356 .28026 .62713 .28478 .63109 .28931 .62754 Mtetra
.699 .642 .789 r
.28026 .61962 .27573 .6232 .28026 .62713 .28479 .62356 Mtetra
.7 .643 .79 r
.27572 .6157 .27119 .61929 .27573 .6232 .28026 .61962 Mtetra
.701 .644 .79 r
.27118 .61179 .26664 .6154 .27119 .61929 .27572 .6157 Mtetra
.701 .645 .79 r
.26662 .60788 .26209 .6115 .26664 .6154 .27118 .61179 Mtetra
.701 .645 .791 r
.26206 .60397 .25752 .60759 .26209 .6115 .26662 .60788 Mtetra
.25749 .60006 .25295 .60368 .25752 .60759 .26206 .60397 Mtetra
.701 .646 .791 r
.25291 .59615 .24837 .59978 .25295 .60368 .25749 .60006 Mtetra
.24832 .59223 .24379 .59587 .24837 .59978 .25291 .59615 Mtetra
.701 .645 .791 r
.24373 .5883 .23919 .59195 .24379 .59587 .24832 .59223 Mtetra
.701 .646 .791 r
.23913 .58437 .23459 .58803 .23919 .59195 .24373 .5883 Mtetra
.23452 .58044 .22999 .5841 .23459 .58803 .23913 .58437 Mtetra
.22991 .5765 .22537 .58016 .22999 .5841 .23452 .58044 Mtetra
.22529 .57255 .22075 .57622 .22537 .58016 .22991 .5765 Mtetra
.22066 .5686 .21612 .57227 .22075 .57622 .22529 .57255 Mtetra
.21602 .56464 .21148 .56832 .21612 .57227 .22066 .5686 Mtetra
.21138 .56067 .20684 .56436 .21148 .56832 .21602 .56464 Mtetra
.20673 .5567 .20219 .56039 .20684 .56436 .21138 .56067 Mtetra
.20207 .55272 .19753 .55642 .20219 .56039 .20673 .5567 Mtetra
.1974 .54874 .19287 .55244 .19753 .55642 .20207 .55272 Mtetra
.19273 .54475 .18819 .54846 .19287 .55244 .1974 .54874 Mtetra
.18805 .54075 .18351 .54447 .18819 .54846 .19273 .54475 Mtetra
.18336 .53675 .17882 .54047 .18351 .54447 .18805 .54075 Mtetra
.17867 .53274 .17413 .53647 .17882 .54047 .18336 .53675 Mtetra
.17396 .52872 .16943 .53246 .17413 .53647 .17867 .53274 Mtetra
.16925 .5247 .16472 .52844 .16943 .53246 .17396 .52872 Mtetra
.701 .645 .791 r
.16454 .52067 .16 .52441 .16472 .52844 .16925 .5247 Mtetra
.701 .646 .791 r
.15981 .51663 .15527 .52039 .16 .52441 .16454 .52067 Mtetra
.702 .646 .791 r
.15508 .51259 .15054 .51635 .15527 .52039 .15981 .51663 Mtetra
.701 .646 .791 r
.15034 .50855 .1458 .51231 .15054 .51635 .15508 .51259 Mtetra
.14559 .50449 .14105 .50826 .1458 .51231 .15034 .50855 Mtetra
.14084 .50043 .1363 .5042 .14105 .50826 .14559 .50449 Mtetra
.702 .646 .791 r
.13607 .49636 .13153 .50015 .1363 .5042 .14084 .50043 Mtetra
.1313 .49229 .12676 .49608 .13153 .50015 .13607 .49636 Mtetra
.701 .646 .791 r
.12652 .48821 .12199 .492 .12676 .49608 .1313 .49229 Mtetra
.701 .645 .791 r
.12174 .48412 .1172 .48792 .12199 .492 .12652 .48821 Mtetra
.701 .646 .791 r
.11695 .48002 .11241 .48383 .1172 .48792 .12174 .48412 Mtetra
.702 .646 .791 r
.11214 .47592 .10761 .47974 .11241 .48383 .11695 .48002 Mtetra
.701 .646 .791 r
.10734 .47182 .1028 .47564 .10761 .47974 .11214 .47592 Mtetra
.10252 .46771 .09798 .47153 .1028 .47564 .10734 .47182 Mtetra
.701 .645 .791 r
.0977 .46359 .09316 .46742 .09798 .47153 .10252 .46771 Mtetra
.702 .646 .79 r
.09286 .45946 .08832 .4633 .09316 .46742 .0977 .46359 Mtetra
.702 .646 .791 r
.08802 .45532 .08348 .45918 .08832 .4633 .09286 .45946 Mtetra
.701 .646 .791 r
.08318 .45119 .07864 .45504 .08348 .45918 .08802 .45532 Mtetra
.07832 .44705 .07378 .4509 .07864 .45504 .08318 .45119 Mtetra
.702 .646 .791 r
.07346 .4429 .06892 .44677 .07378 .4509 .07832 .44705 Mtetra
.703 .646 .79 r
.06858 .43875 .06404 .44264 .06892 .44677 .07346 .4429 Mtetra
.704 .647 .79 r
.0637 .4346 .05915 .43853 .06404 .44264 .06858 .43875 Mtetra
.706 .649 .79 r
.0588 .43049 .05424 .43444 .05915 .43853 .0637 .4346 Mtetra
.71 .652 .79 r
.05388 .42642 .04931 .43044 .05424 .43444 .0588 .43049 Mtetra
.718 .657 .788 r
.04893 .42244 .04432 .42662 .04931 .43044 .05388 .42642 Mtetra
.735 .667 .783 r
.04392 .41867 .03924 .42315 .04432 .42662 .04893 .42244 Mtetra
.764 .684 .775 r
.0388 .41531 .03398 .42039 .03924 .42315 .04392 .41867 Mtetra
.777 .698 .777 r
.49062 .79417 .48608 .79904 .49032 .80077 .49484 .79665 Mtetra
.836 .738 .756 r
.48637 .79278 .48181 .79912 .48608 .79904 .49062 .79417 Mtetra
.913 .787 .708 r
.48209 .79351 .47749 .80267 .48181 .79912 .48637 .79278 Mtetra
.981 .828 .617 r
.47775 .79827 .47306 .81241 .47749 .80267 .48209 .79351 Mtetra
.996 .835 .484 r
.47329 .81007 .46844 .83185 .47306 .81241 .47775 .79827 Mtetra
.908 .787 .305 r
.46861 .83235 .46355 .86247 .46844 .83185 .47329 .81007 Mtetra
0 0 0 r
.46367 .86505 .45847 .89634 .46355 .86247 .46861 .83235 Mtetra
.076 0 .28 r
.45861 .89665 .4536 .91212 .45847 .89634 .46367 .86505 Mtetra
.686 .333 .371 r
.45387 .90446 .44937 .89407 .4536 .91212 .45861 .89665 Mtetra
0 0 .141 r
.44979 .87887 .44569 .85411 .44937 .89407 .45387 .90446 Mtetra
0 0 .413 r
.44616 .83729 .44213 .81471 .44569 .85411 .44979 .87887 Mtetra
.171 .065 .482 r
.44255 .80025 .43841 .78614 .44213 .81471 .44616 .83729 Mtetra
.29 .169 .537 r
.43876 .77452 .43447 .76782 .43841 .78614 .44255 .80025 Mtetra
.395 .278 .601 r
.43477 .75822 .43038 .75623 .43447 .76782 .43876 .77452 Mtetra
.497 .394 .668 r
.43064 .74782 .42619 .74845 .43038 .75623 .43477 .75822 Mtetra
.58 .494 .721 r
.42642 .74069 .42193 .74271 .42619 .74845 .43064 .74782 Mtetra
.637 .563 .755 r
.42215 .73529 .41764 .73804 .42193 .74271 .42642 .74069 Mtetra
.67 .605 .773 r
.41784 .73078 .41332 .73392 .41764 .73804 .42215 .73529 Mtetra
.69 .629 .783 r
.41352 .72675 .40899 .7301 .41332 .73392 .41784 .73078 Mtetra
.702 .645 .79 r
.40917 .72302 .40464 .72649 .40899 .7301 .41352 .72675 Mtetra
.712 .658 .795 r
.40481 .71952 .40027 .7231 .40464 .72649 .40917 .72302 Mtetra
.723 .672 .799 r
.40043 .71627 .39588 .71999 .40027 .7231 .40481 .71952 Mtetra
.739 .691 .804 r
.39602 .71337 .39146 .71728 .39588 .71999 .40043 .71627 Mtetra
.764 .72 .811 r
.39158 .71099 .387 .71519 .39146 .71728 .39602 .71337 Mtetra
.802 .767 .821 r
.38708 .70944 .38248 .71406 .387 .71519 .39158 .71099 Mtetra
.854 .837 .828 r
.3825 .70916 .37786 .71439 .38248 .71406 .38708 .70944 Mtetra
.91 .923 .812 r
.3778 .71069 .3731 .71676 .37786 .71439 .3825 .70916 Mtetra
.917 .979 .729 r
.37294 .7146 .36815 .72172 .3731 .71676 .3778 .71069 Mtetra
.81 .93 .555 r
.36787 .72124 .363 .72933 .36815 .72172 .37294 .7146 Mtetra
.634 .808 .378 r
.36263 .72999 .3577 .73841 .363 .72933 .36787 .72124 Mtetra
0 0 0 r
.35734 .7386 .35243 .74602 .3577 .73841 .36263 .72999 Mtetra
.609 .894 .593 r
.35224 .74322 .34748 .74816 .35243 .74602 .35734 .7386 Mtetra
.621 .712 .911 r
.3476 .7404 .34306 .74224 .34748 .74816 .35224 .74322 Mtetra
.415 .344 .668 r
.3435 .72969 .33914 .72921 .34306 .74224 .3476 .7404 Mtetra
.387 .271 .597 r
.33978 .71405 .3355 .71277 .33914 .72921 .3435 .72969 Mtetra
.405 .275 .588 r
.33617 .69746 .3319 .69661 .3355 .71277 .33978 .71405 Mtetra
.442 .31 .605 r
.33247 .68262 .32815 .68275 .3319 .69661 .33617 .69746 Mtetra
.489 .362 .635 r
.3286 .67048 .32423 .67162 .32815 .68275 .33247 .68262 Mtetra
.538 .423 .671 r
.32456 .66087 .32013 .66282 .32423 .67162 .3286 .67048 Mtetra
.583 .482 .705 r
.32037 .65322 .31591 .65574 .32013 .66282 .32456 .66087 Mtetra
.621 .533 .733 r
.31608 .64694 .31159 .64984 .31591 .65574 .32037 .65322 Mtetra
.649 .571 .754 r
.31171 .64156 .3072 .64472 .31159 .64984 .31608 .64694 Mtetra
.668 .598 .767 r
.30729 .63675 .30277 .64008 .3072 .64472 .31171 .64156 Mtetra
.681 .615 .776 r
.30283 .63231 .2983 .63574 .30277 .64008 .30729 .63675 Mtetra
.688 .627 .782 r
.29835 .62809 .29382 .63158 .2983 .63574 .30283 .63231 Mtetra
.693 .634 .786 r
.29384 .624 .28931 .62754 .29382 .63158 .29835 .62809 Mtetra
.696 .639 .788 r
.28933 .62 .28479 .62356 .28931 .62754 .29384 .624 Mtetra
.698 .641 .789 r
.2848 .61603 .28026 .61962 .28479 .62356 .28933 .62 Mtetra
.7 .643 .789 r
.28026 .61209 .27572 .6157 .28026 .61962 .2848 .61603 Mtetra
.7 .644 .79 r
.27572 .60817 .27118 .61179 .27572 .6157 .28026 .61209 Mtetra
.701 .645 .79 r
.27116 .60426 .26662 .60788 .27118 .61179 .27572 .60817 Mtetra
.2666 .60034 .26206 .60397 .26662 .60788 .27116 .60426 Mtetra
.701 .645 .791 r
.26203 .59642 .25749 .60006 .26206 .60397 .2666 .60034 Mtetra
.701 .646 .791 r
.25745 .59251 .25291 .59615 .25749 .60006 .26203 .59642 Mtetra
.25286 .58858 .24832 .59223 .25291 .59615 .25745 .59251 Mtetra
.701 .645 .791 r
.24827 .58465 .24373 .5883 .24832 .59223 .25286 .58858 Mtetra
.701 .646 .791 r
.24367 .58071 .23913 .58437 .24373 .5883 .24827 .58465 Mtetra
.23906 .57677 .23452 .58044 .23913 .58437 .24367 .58071 Mtetra
.23445 .57283 .22991 .5765 .23452 .58044 .23906 .57677 Mtetra
.22983 .56888 .22529 .57255 .22991 .5765 .23445 .57283 Mtetra
.701 .645 .791 r
.2252 .56492 .22066 .5686 .22529 .57255 .22983 .56888 Mtetra
.701 .646 .791 r
.22056 .56095 .21602 .56464 .22066 .5686 .2252 .56492 Mtetra
.21592 .55698 .21138 .56067 .21602 .56464 .22056 .56095 Mtetra
.21127 .553 .20673 .5567 .21138 .56067 .21592 .55698 Mtetra
.20661 .54902 .20207 .55272 .20673 .5567 .21127 .553 Mtetra
.20195 .54503 .1974 .54874 .20207 .55272 .20661 .54902 Mtetra
.702 .646 .791 r
.19727 .54103 .19273 .54475 .1974 .54874 .20195 .54503 Mtetra
.701 .646 .791 r
.19259 .53703 .18805 .54075 .19273 .54475 .19727 .54103 Mtetra
.18791 .53302 .18336 .53675 .18805 .54075 .19259 .53703 Mtetra
.18321 .529 .17867 .53274 .18336 .53675 .18791 .53302 Mtetra
.17851 .52498 .17396 .52872 .17867 .53274 .18321 .529 Mtetra
.702 .646 .791 r
.1738 .52095 .16925 .5247 .17396 .52872 .17851 .52498 Mtetra
.701 .646 .791 r
.16908 .51692 .16454 .52067 .16925 .5247 .1738 .52095 Mtetra
.16436 .51288 .15981 .51663 .16454 .52067 .16908 .51692 Mtetra
.701 .645 .791 r
.15962 .50883 .15508 .51259 .15981 .51663 .16436 .51288 Mtetra
.702 .646 .791 r
.15488 .50477 .15034 .50855 .15508 .51259 .15962 .50883 Mtetra
.15014 .50071 .14559 .50449 .15034 .50855 .15488 .50477 Mtetra
.701 .646 .791 r
.14538 .49665 .14084 .50043 .14559 .50449 .15014 .50071 Mtetra
.14062 .49258 .13607 .49636 .14084 .50043 .14538 .49665 Mtetra
.701 .645 .791 r
.13585 .48849 .1313 .49229 .13607 .49636 .14062 .49258 Mtetra
.702 .646 .791 r
.13107 .4844 .12652 .48821 .1313 .49229 .13585 .48849 Mtetra
.12628 .48031 .12174 .48412 .12652 .48821 .13107 .4844 Mtetra
.701 .646 .791 r
.12149 .47621 .11695 .48002 .12174 .48412 .12628 .48031 Mtetra
.11669 .47211 .11214 .47592 .11695 .48002 .12149 .47621 Mtetra
.701 .645 .791 r
.11188 .46799 .10734 .47182 .11214 .47592 .11669 .47211 Mtetra
.702 .646 .791 r
.10707 .46387 .10252 .46771 .10734 .47182 .11188 .46799 Mtetra
.10224 .45975 .0977 .46359 .10252 .46771 .10707 .46387 Mtetra
.701 .646 .791 r
.09741 .45561 .09286 .45946 .0977 .46359 .10224 .45975 Mtetra
.09257 .45148 .08802 .45532 .09286 .45946 .09741 .45561 Mtetra
.08772 .44733 .08318 .45119 .08802 .45532 .09257 .45148 Mtetra
.702 .646 .79 r
.08287 .44318 .07832 .44705 .08318 .45119 .08772 .44733 Mtetra
.078 .43902 .07346 .4429 .07832 .44705 .08287 .44318 Mtetra
.702 .646 .791 r
.07313 .43486 .06858 .43875 .07346 .4429 .078 .43902 Mtetra
.703 .647 .791 r
.06825 .43071 .0637 .4346 .06858 .43875 .07313 .43486 Mtetra
.704 .648 .791 r
.06335 .42656 .0588 .43049 .0637 .4346 .06825 .43071 Mtetra
.707 .649 .79 r
.05845 .42244 .05388 .42642 .0588 .43049 .06335 .42656 Mtetra
.712 .652 .788 r
.05352 .41837 .04893 .42244 .05388 .42642 .05845 .42244 Mtetra
.722 .658 .786 r
.04855 .41441 .04392 .41867 .04893 .42244 .05352 .41837 Mtetra
.741 .671 .782 r
.04351 .41071 .0388 .41531 .04392 .41867 .04855 .41441 Mtetra
.748 .678 .783 r
.49515 .78989 .49062 .79417 .49484 .79665 .49938 .79286 Mtetra
.79 .706 .772 r
.49092 .78759 .48637 .79278 .49062 .79417 .49515 .78989 Mtetra
.854 .749 .747 r
.48666 .7866 .48209 .79351 .48637 .79278 .49092 .78759 Mtetra
.934 .8 .689 r
.48237 .78812 .47775 .79827 .48209 .79351 .48666 .7866 Mtetra
.992 .834 .587 r
.47801 .7943 .47329 .81007 .47775 .79827 .48237 .78812 Mtetra
.986 .83 .444 r
.4735 .80839 .46861 .83235 .47329 .81007 .47801 .7943 Mtetra
.856 .757 .246 r
.46878 .83351 .46367 .86505 .46861 .83235 .4735 .80839 Mtetra
0 0 .061 r
.4638 .86757 .45861 .89665 .46367 .86505 .46878 .83351 Mtetra
.235 0 .327 r
.45878 .89536 .45387 .90446 .45861 .89665 .4638 .86757 Mtetra
.833 .45 .327 r
.45419 .89455 .44979 .87887 .45387 .90446 .45878 .89536 Mtetra
0 0 .267 r
.45024 .86267 .44616 .83729 .44979 .87887 .45419 .89455 Mtetra
.035 0 .435 r
.44662 .82082 .44255 .80025 .44616 .83729 .45024 .86267 Mtetra
.203 .091 .495 r
.44296 .78651 .43876 .77452 .44255 .80025 .44662 .82082 Mtetra
.315 .194 .552 r
.4391 .7635 .43477 .75822 .43876 .77452 .44296 .78651 Mtetra
.421 .307 .618 r
.43505 .74899 .43064 .74782 .43477 .75822 .4391 .7635 Mtetra
.52 .421 .683 r
.43089 .73959 .42642 .74069 .43064 .74782 .43505 .74899 Mtetra
.598 .514 .731 r
.42665 .733 .42215 .73529 .42642 .74069 .43089 .73959 Mtetra
.648 .576 .761 r
.42236 .72789 .41784 .73078 .42215 .73529 .42665 .733 Mtetra
.676 .614 .778 r
.41804 .72355 .41352 .72675 .41784 .73078 .42236 .72789 Mtetra
.694 .635 .786 r
.41371 .71963 .40917 .72302 .41352 .72675 .41804 .72355 Mtetra
.706 .65 .791 r
.40935 .71598 .40481 .71952 .40917 .72302 .41371 .71963 Mtetra
.718 .664 .796 r
.40498 .71259 .40043 .71627 .40481 .71952 .40935 .71598 Mtetra
.733 .682 .802 r
.40058 .70953 .39602 .71337 .40043 .71627 .40498 .71259 Mtetra
.753 .708 .809 r
.39615 .70693 .39158 .71099 .39602 .71337 .40058 .70953 Mtetra
.785 .747 .818 r
.39168 .70502 .38708 .70944 .39158 .71099 .39615 .70693 Mtetra
.833 .807 .826 r
.38714 .70418 .3825 .70916 .38708 .70944 .39168 .70502 Mtetra
.891 .889 .822 r
.38249 .70493 .3778 .71069 .3825 .70916 .38714 .70418 Mtetra
.926 .966 .771 r
.3777 .70788 .37294 .7146 .3778 .71069 .38249 .70493 Mtetra
.862 .961 .626 r
.37272 .71349 .36787 .72124 .37294 .7146 .3777 .70788 Mtetra
.697 .853 .435 r
.36755 .7216 .36263 .72999 .36787 .72124 .37272 .71349 Mtetra
0 0 0 r
.36226 .73061 .35734 .7386 .36263 .72999 .36755 .7216 Mtetra
.35707 .73719 .35224 .74322 .35734 .7386 .36226 .73061 Mtetra
.728 .943 .953 r
.35224 .73741 .3476 .7404 .35224 .74322 .35707 .73719 Mtetra
.458 .423 .732 r
.34794 .72947 .3435 .72969 .3476 .7404 .35224 .73741 Mtetra
.388 .284 .613 r
.34409 .7152 .33978 .71405 .3435 .72969 .34794 .72947 Mtetra
.396 .268 .587 r
.34045 .69855 .33617 .69746 .33978 .71405 .34409 .7152 Mtetra
.427 .294 .596 r
.33678 .68287 .33247 .68262 .33617 .69746 .34045 .69855 Mtetra
.47 .341 .622 r
.33296 .6697 .3286 .67048 .33247 .68262 .33678 .68287 Mtetra
.519 .4 .657 r
.32897 .6592 .32456 .66087 .3286 .67048 .33296 .6697 Mtetra
.567 .461 .693 r
.32483 .65088 .32037 .65322 .32456 .66087 .32897 .6592 Mtetra
.608 .515 .723 r
.32056 .64414 .31608 .64694 .32037 .65322 .32483 .65088 Mtetra
.64 .558 .747 r
.31622 .63846 .31171 .64156 .31608 .64694 .32056 .64414 Mtetra
.662 .589 .763 r
.31181 .63347 .30729 .63675 .31171 .64156 .31622 .63846 Mtetra
.676 .61 .774 r
.30736 .62891 .30283 .63231 .30729 .63675 .31181 .63347 Mtetra
.686 .623 .78 r
.30288 .6246 .29835 .62809 .30283 .63231 .30736 .62891 Mtetra
.692 .632 .784 r
.29838 .62047 .29384 .624 .29835 .62809 .30288 .6246 Mtetra
.696 .637 .787 r
.29387 .61643 .28933 .62 .29384 .624 .29838 .62047 Mtetra
.698 .64 .788 r
.28934 .61245 .2848 .61603 .28933 .62 .29387 .61643 Mtetra
.699 .642 .789 r
.28481 .60849 .28026 .61209 .2848 .61603 .28934 .61245 Mtetra
.7 .644 .79 r
.28026 .60456 .27572 .60817 .28026 .61209 .28481 .60849 Mtetra
.701 .645 .79 r
.27571 .60064 .27116 .60426 .27572 .60817 .28026 .60456 Mtetra
.701 .645 .791 r
.27114 .59672 .2666 .60034 .27116 .60426 .27571 .60064 Mtetra
.701 .645 .79 r
.26657 .59279 .26203 .59642 .2666 .60034 .27114 .59672 Mtetra
.262 .58886 .25745 .59251 .26203 .59642 .26657 .59279 Mtetra
.702 .646 .791 r
.25741 .58493 .25286 .58858 .25745 .59251 .262 .58886 Mtetra
.701 .646 .791 r
.25282 .581 .24827 .58465 .25286 .58858 .25741 .58493 Mtetra
.24822 .57706 .24367 .58071 .24827 .58465 .25282 .581 Mtetra
.701 .645 .791 r
.24361 .5731 .23906 .57677 .24367 .58071 .24822 .57706 Mtetra
.702 .646 .791 r
.239 .56915 .23445 .57283 .23906 .57677 .24361 .5731 Mtetra
.23438 .56519 .22983 .56888 .23445 .57283 .239 .56915 Mtetra
.701 .646 .791 r
.22975 .56123 .2252 .56492 .22983 .56888 .23438 .56519 Mtetra
.22511 .55726 .22056 .56095 .2252 .56492 .22975 .56123 Mtetra
.22047 .55328 .21592 .55698 .22056 .56095 .22511 .55726 Mtetra
.702 .646 .791 r
.21582 .5493 .21127 .553 .21592 .55698 .22047 .55328 Mtetra
.701 .646 .791 r
.21116 .54531 .20661 .54902 .21127 .553 .21582 .5493 Mtetra
.2065 .54131 .20195 .54503 .20661 .54902 .21116 .54531 Mtetra
.20182 .53731 .19727 .54103 .20195 .54503 .2065 .54131 Mtetra
.19714 .5333 .19259 .53703 .19727 .54103 .20182 .53731 Mtetra
.702 .646 .791 r
.19246 .52928 .18791 .53302 .19259 .53703 .19714 .5333 Mtetra
.701 .646 .791 r
.18776 .52526 .18321 .529 .18791 .53302 .19246 .52928 Mtetra
.18306 .52124 .17851 .52498 .18321 .529 .18776 .52526 Mtetra
.17835 .5172 .1738 .52095 .17851 .52498 .18306 .52124 Mtetra
.702 .646 .791 r
.17363 .51316 .16908 .51692 .1738 .52095 .17835 .5172 Mtetra
.16891 .50911 .16436 .51288 .16908 .51692 .17363 .51316 Mtetra
.701 .646 .791 r
.16417 .50506 .15962 .50883 .16436 .51288 .16891 .50911 Mtetra
.15943 .501 .15488 .50477 .15962 .50883 .16417 .50506 Mtetra
.15469 .49693 .15014 .50071 .15488 .50477 .15943 .501 Mtetra
.702 .645 .79 r
.14993 .49286 .14538 .49665 .15014 .50071 .15469 .49693 Mtetra
.702 .646 .791 r
.14517 .48878 .14062 .49258 .14538 .49665 .14993 .49286 Mtetra
.701 .646 .791 r
.1404 .48469 .13585 .48849 .14062 .49258 .14517 .48878 Mtetra
.13562 .4806 .13107 .4844 .13585 .48849 .1404 .48469 Mtetra
.13084 .4765 .12628 .48031 .13107 .4844 .13562 .4806 Mtetra
.12604 .47239 .12149 .47621 .12628 .48031 .13084 .4765 Mtetra
.702 .646 .791 r
.12124 .46828 .11669 .47211 .12149 .47621 .12604 .47239 Mtetra
.701 .646 .791 r
.11643 .46416 .11188 .46799 .11669 .47211 .12124 .46828 Mtetra
.11162 .46004 .10707 .46387 .11188 .46799 .11643 .46416 Mtetra
.10679 .4559 .10224 .45975 .10707 .46387 .11162 .46004 Mtetra
.10196 .45177 .09741 .45561 .10224 .45975 .10679 .4559 Mtetra
.09712 .44762 .09257 .45148 .09741 .45561 .10196 .45177 Mtetra
.702 .645 .791 r
.09228 .44347 .08772 .44733 .09257 .45148 .09712 .44762 Mtetra
.702 .646 .791 r
.08742 .43931 .08287 .44318 .08772 .44733 .09228 .44347 Mtetra
.08256 .43515 .078 .43902 .08287 .44318 .08742 .43931 Mtetra
.07768 .43099 .07313 .43486 .078 .43902 .08256 .43515 Mtetra
.0728 .42682 .06825 .43071 .07313 .43486 .07768 .43099 Mtetra
.703 .646 .79 r
.06791 .42264 .06335 .42656 .06825 .43071 .0728 .42682 Mtetra
.705 .647 .789 r
.06301 .41848 .05845 .42244 .06335 .42656 .06791 .42264 Mtetra
.708 .65 .79 r
.05809 .41436 .05352 .41837 .05845 .42244 .06301 .41848 Mtetra
.713 .654 .789 r
.05315 .41031 .04855 .41441 .05352 .41837 .05809 .41436 Mtetra
.725 .661 .786 r
.04816 .40639 .04351 .41071 .04855 .41441 .05315 .41031 Mtetra
.73 .666 .786 r
.49969 .78599 .49515 .78989 .49938 .79286 .50391 .78922 Mtetra
.757 .684 .781 r
.49546 .78315 .49092 .78759 .49515 .78989 .49969 .78599 Mtetra
.803 .716 .768 r
.49122 .7811 .48666 .7866 .49092 .78759 .49546 .78315 Mtetra
.874 .762 .736 r
.48695 .78057 .48237 .78812 .48666 .7866 .49122 .7811 Mtetra
.952 .811 .668 r
.48265 .78298 .47801 .7943 .48237 .78812 .48695 .78057 Mtetra
.998 .837 .554 r
.47826 .79077 .4735 .80839 .47801 .7943 .48265 .78298 Mtetra
.969 .821 .401 r
.47372 .80737 .46878 .83351 .4735 .80839 .47826 .79077 Mtetra
.783 .714 .179 r
.46894 .83528 .4638 .86757 .46878 .83351 .47372 .80737 Mtetra
0 0 .142 r
.46393 .86972 .45878 .89536 .4638 .86757 .46894 .83528 Mtetra
.384 .103 .357 r
.45898 .89213 .45419 .89455 .45878 .89536 .46393 .86972 Mtetra
.929 .546 .215 r
.45455 .88252 .45024 .86267 .45419 .89455 .45898 .89213 Mtetra
0 0 .34 r
.4507 .8459 .44662 .82082 .45024 .86267 .45455 .88252 Mtetra
.088 .002 .452 r
.44707 .80492 .44296 .78651 .44662 .82082 .4507 .8459 Mtetra
.233 .117 .508 r
.44334 .77351 .4391 .7635 .44296 .78651 .44707 .80492 Mtetra
.342 .221 .568 r
.43942 .75297 .43505 .74899 .4391 .7635 .44334 .77351 Mtetra
.446 .336 .635 r
.43533 .74004 .43089 .73959 .43505 .74899 .43942 .75297 Mtetra
.541 .447 .697 r
.43114 .73154 .42665 .733 .43089 .73959 .43533 .74004 Mtetra
.612 .533 .741 r
.42688 .72542 .42236 .72789 .42665 .733 .43114 .73154 Mtetra
.657 .588 .766 r
.42257 .72054 .41804 .72355 .42236 .72789 .42688 .72542 Mtetra
.683 .621 .78 r
.41825 .71633 .41371 .71963 .41804 .72355 .42257 .72054 Mtetra
.699 .641 .788 r
.4139 .71252 .40935 .71598 .41371 .71963 .41825 .71633 Mtetra
.712 .657 .794 r
.40953 .70899 .40498 .71259 .40935 .71598 .4139 .71252 Mtetra
.725 .674 .799 r
.40514 .70577 .40058 .70953 .40498 .71259 .40953 .70899 Mtetra
.744 .696 .806 r
.40073 .70295 .39615 .70693 .40058 .70953 .40514 .70577 Mtetra
.772 .73 .814 r
.39627 .70072 .39168 .70502 .39615 .70693 .40073 .70295 Mtetra
.813 .782 .823 r
.39176 .69942 .38714 .70418 .39168 .70502 .39627 .70072 Mtetra
.869 .858 .828 r
.38716 .69951 .38249 .70493 .38714 .70418 .39176 .69942 Mtetra
.919 .943 .8 r
.38243 .70155 .3777 .70788 .38249 .70493 .38716 .69951 Mtetra
.902 .978 .692 r
.37754 .7061 .37272 .71349 .3777 .70788 .38243 .70155 Mtetra
.766 .901 .505 r
.37245 .71334 .36755 .7216 .37272 .71349 .37754 .7061 Mtetra
0 0 0 r
.3672 .7223 .36226 .73061 .36755 .7216 .37245 .71334 Mtetra
.36195 .73025 .35707 .73719 .36226 .73061 .3672 .7223 Mtetra
.686 .969 .761 r
.35696 .73323 .35224 .73741 .35707 .73719 .36195 .73025 Mtetra
.54 .567 .831 r
.35246 .72831 .34794 .72947 .35224 .73741 .35696 .73323 Mtetra
.4 .312 .641 r
.34845 .71601 .34409 .7152 .34794 .72947 .35246 .72831 Mtetra
.389 .267 .592 r
.34474 .69979 .34045 .69855 .34409 .7152 .34845 .71601 Mtetra
.414 .281 .59 r
.34108 .68347 .33678 .68287 .34045 .69855 .34474 .69979 Mtetra
.453 .322 .611 r
.33732 .66929 .33296 .6697 .33678 .68287 .34108 .68347 Mtetra
.501 .377 .644 r
.33338 .65783 .32897 .6592 .33296 .6697 .33732 .66929 Mtetra
.549 .438 .68 r
.32928 .64876 .32483 .65088 .32897 .6592 .33338 .65783 Mtetra
.593 .496 .713 r
.32505 .64149 .32056 .64414 .32483 .65088 .32928 .64876 Mtetra
.629 .543 .739 r
.32072 .63546 .31622 .63846 .32056 .64414 .32505 .64149 Mtetra
.655 .579 .758 r
.31633 .63024 .31181 .63347 .31622 .63846 .32072 .63546 Mtetra
.672 .603 .77 r
.31189 .62554 .30736 .62891 .31181 .63347 .31633 .63024 Mtetra
.683 .619 .778 r
.30742 .62115 .30288 .6246 .30736 .62891 .31189 .62554 Mtetra
.69 .629 .783 r
.30293 .61694 .29838 .62047 .30288 .6246 .30742 .62115 Mtetra
.695 .635 .786 r
.29842 .61286 .29387 .61643 .29838 .62047 .30293 .61694 Mtetra
.697 .64 .788 r
.29389 .60886 .28934 .61245 .29387 .61643 .29842 .61286 Mtetra
.699 .642 .789 r
.28936 .60489 .28481 .60849 .28934 .61245 .29389 .60886 Mtetra
.7 .643 .79 r
.28481 .60094 .28026 .60456 .28481 .60849 .28936 .60489 Mtetra
.701 .644 .79 r
.28026 .597 .27571 .60064 .28026 .60456 .28481 .60094 Mtetra
.701 .645 .79 r
.2757 .59307 .27114 .59672 .27571 .60064 .28026 .597 Mtetra
.701 .645 .791 r
.27113 .58914 .26657 .59279 .27114 .59672 .2757 .59307 Mtetra
.26655 .58521 .262 .58886 .26657 .59279 .27113 .58914 Mtetra
.26197 .58127 .25741 .58493 .262 .58886 .26655 .58521 Mtetra
.702 .645 .79 r
.25737 .57733 .25282 .581 .25741 .58493 .26197 .58127 Mtetra
.702 .646 .791 r
.25278 .57338 .24822 .57706 .25282 .581 .25737 .57733 Mtetra
.701 .646 .791 r
.24817 .56943 .24361 .5731 .24822 .57706 .25278 .57338 Mtetra
.24355 .56548 .239 .56915 .24361 .5731 .24817 .56943 Mtetra
.701 .645 .791 r
.23893 .56151 .23438 .56519 .239 .56915 .24355 .56548 Mtetra
.702 .646 .791 r
.23431 .55754 .22975 .56123 .23438 .56519 .23893 .56151 Mtetra
.22967 .55356 .22511 .55726 .22975 .56123 .23431 .55754 Mtetra
.701 .646 .791 r
.22503 .54958 .22047 .55328 .22511 .55726 .22967 .55356 Mtetra
.22038 .54559 .21582 .5493 .22047 .55328 .22503 .54958 Mtetra
.701 .645 .791 r
.21572 .54159 .21116 .54531 .21582 .5493 .22038 .54559 Mtetra
.702 .646 .791 r
.21105 .53759 .2065 .54131 .21116 .54531 .21572 .54159 Mtetra
.701 .646 .791 r
.20638 .53358 .20182 .53731 .2065 .54131 .21105 .53759 Mtetra
.2017 .52957 .19714 .5333 .20182 .53731 .20638 .53358 Mtetra
.19701 .52555 .19246 .52928 .19714 .5333 .2017 .52957 Mtetra
.701 .645 .791 r
.19232 .52152 .18776 .52526 .19246 .52928 .19701 .52555 Mtetra
.702 .646 .791 r
.18762 .51748 .18306 .52124 .18776 .52526 .19232 .52152 Mtetra
.18291 .51344 .17835 .5172 .18306 .52124 .18762 .51748 Mtetra
.701 .646 .791 r
.17819 .5094 .17363 .51316 .17835 .5172 .18291 .51344 Mtetra
.17346 .50534 .16891 .50911 .17363 .51316 .17819 .5094 Mtetra
.16873 .50128 .16417 .50506 .16891 .50911 .17346 .50534 Mtetra
.702 .646 .791 r
.16399 .49722 .15943 .501 .16417 .50506 .16873 .50128 Mtetra
.15925 .49314 .15469 .49693 .15943 .501 .16399 .49722 Mtetra
.701 .646 .791 r
.15449 .48906 .14993 .49286 .15469 .49693 .15925 .49314 Mtetra
.14973 .48498 .14517 .48878 .14993 .49286 .15449 .48906 Mtetra
.14496 .48089 .1404 .48469 .14517 .48878 .14973 .48498 Mtetra
.14018 .47679 .13562 .4806 .1404 .48469 .14496 .48089 Mtetra
.701 .645 .79 r
.1354 .47268 .13084 .4765 .13562 .4806 .14018 .47679 Mtetra
.701 .646 .791 r
.1306 .46857 .12604 .47239 .13084 .4765 .1354 .47268 Mtetra
.1258 .46445 .12124 .46828 .12604 .47239 .1306 .46857 Mtetra
.12099 .46033 .11643 .46416 .12124 .46828 .1258 .46445 Mtetra
.11618 .4562 .11162 .46004 .11643 .46416 .12099 .46033 Mtetra
.701 .645 .791 r
.11135 .45206 .10679 .4559 .11162 .46004 .11618 .4562 Mtetra
.702 .646 .791 r
.10652 .44791 .10196 .45177 .10679 .4559 .11135 .45206 Mtetra
.10168 .44376 .09712 .44762 .10196 .45177 .10652 .44791 Mtetra
.701 .646 .791 r
.09683 .4396 .09228 .44347 .09712 .44762 .10168 .44376 Mtetra
.09198 .43544 .08742 .43931 .09228 .44347 .09683 .4396 Mtetra
.08712 .43127 .08256 .43515 .08742 .43931 .09198 .43544 Mtetra
.702 .645 .79 r
.08225 .42709 .07768 .43099 .08256 .43515 .08712 .43127 Mtetra
.702 .646 .79 r
.07737 .4229 .0728 .42682 .07768 .43099 .08225 .42709 Mtetra
.702 .646 .791 r
.07248 .41873 .06791 .42264 .0728 .42682 .07737 .4229 Mtetra
.703 .647 .791 r
.06758 .41455 .06301 .41848 .06791 .42264 .07248 .41873 Mtetra
.705 .648 .79 r
.06266 .41039 .05809 .41436 .06301 .41848 .06758 .41455 Mtetra
.709 .65 .789 r
.05773 .40627 .05315 .41031 .05809 .41436 .06266 .41039 Mtetra
.716 .655 .787 r
.05278 .40222 .04816 .40639 .05315 .41031 .05773 .40627 Mtetra
.719 .658 .789 r
.50424 .78231 .49969 .78599 .50391 .78922 .50846 .78569 Mtetra
.735 .669 .786 r
.50001 .77914 .49546 .78315 .49969 .78599 .50424 .78231 Mtetra
.766 .69 .778 r
.49577 .77643 .49122 .7811 .49546 .78315 .50001 .77914 Mtetra
.819 .726 .762 r
.49152 .77465 .48695 .78057 .49122 .7811 .49577 .77643 Mtetra
.894 .776 .723 r
.48725 .77468 .48265 .78298 .48695 .78057 .49152 .77465 Mtetra
.969 .822 .643 r
.48292 .77816 .47826 .79077 .48265 .78298 .48725 .77468 Mtetra
.999 .838 .519 r
.47851 .78778 .47372 .80737 .47826 .79077 .48292 .77816 Mtetra
.944 .807 .354 r
.47392 .80705 .46894 .83528 .47372 .80737 .47851 .78778 Mtetra
0 0 0 r
.46909 .83746 .46393 .86972 .46894 .83528 .47392 .80705 Mtetra
0 0 .215 r
.46407 .8711 .45898 .89213 .46393 .86972 .46909 .83746 Mtetra
.533 .213 .372 r
.45922 .88673 .45455 .88252 .45898 .89213 .46407 .8711 Mtetra
.866 .549 .03 r
.45494 .86871 .4507 .8459 .45455 .88252 .45922 .88673 Mtetra
0 0 .384 r
.45116 .82891 .44707 .80492 .4507 .8459 .45494 .86871 Mtetra
.132 .034 .467 r
.44751 .78968 .44334 .77351 .44707 .80492 .45116 .82891 Mtetra
.26 .141 .522 r
.44371 .76121 .43942 .75297 .44334 .77351 .44751 .78968 Mtetra
.367 .248 .584 r
.43973 .74293 .43533 .74004 .43942 .75297 .44371 .76121 Mtetra
.472 .365 .652 r
.4356 .73136 .43114 .73154 .43533 .74004 .43973 .74293 Mtetra
.563 .472 .71 r
.43138 .7236 .42688 .72542 .43114 .73154 .4356 .73136 Mtetra
.626 .55 .749 r
.4271 .71788 .42257 .72054 .42688 .72542 .43138 .7236 Mtetra
.665 .599 .771 r
.42279 .71323 .41825 .71633 .42257 .72054 .4271 .71788 Mtetra
.689 .628 .783 r
.41845 .70916 .4139 .71252 .41825 .71633 .42279 .71323 Mtetra
.705 .648 .79 r
.41409 .70545 .40953 .70899 .4139 .71252 .41845 .70916 Mtetra
.719 .665 .796 r
.40971 .70207 .40514 .70577 .40953 .70899 .41409 .70545 Mtetra
.736 .686 .803 r
.4053 .69907 .40073 .70295 .40514 .70577 .40971 .70207 Mtetra
.76 .716 .811 r
.40086 .69658 .39627 .70072 .40073 .70295 .4053 .69907 Mtetra
.796 .76 .82 r
.39638 .69486 .39176 .69942 .39627 .70072 .40086 .69658 Mtetra
.847 .826 .827 r
.39181 .69435 .38716 .69951 .39176 .69942 .39638 .69486 Mtetra
.904 .912 .816 r
.38715 .69557 .38243 .70155 .38716 .69951 .39181 .69435 Mtetra
.921 .977 .744 r
.38232 .69912 .37754 .7061 .38243 .70155 .38715 .69557 Mtetra
.827 .941 .578 r
.37732 .70536 .37245 .71334 .37754 .7061 .38232 .69912 Mtetra
.654 .822 .396 r
.37213 .71386 .3672 .7223 .37245 .71334 .37732 .70536 Mtetra
0 0 0 r
.36687 .7226 .36195 .73025 .3672 .7223 .37213 .71386 Mtetra
.583 .86 .53 r
.36176 .7279 .35696 .73323 .36195 .73025 .36687 .7226 Mtetra
.665 .795 .944 r
.35706 .72608 .35246 .72831 .35696 .73323 .36176 .7279 Mtetra
.427 .366 .686 r
.35287 .71624 .34845 .71601 .35246 .72831 .35706 .72608 Mtetra
.387 .274 .602 r
.34906 .70101 .34474 .69979 .34845 .71601 .35287 .71624 Mtetra
.402 .272 .587 r
.34539 .68438 .34108 .68347 .34474 .69979 .34906 .70101 Mtetra
.437 .304 .601 r
.34166 .66925 .33732 .66929 .34108 .68347 .34539 .68438 Mtetra
.482 .355 .63 r
.33778 .65678 .33338 .65783 .33732 .66929 .34166 .66925 Mtetra
.531 .415 .666 r
.33372 .64688 .32928 .64876 .33338 .65783 .33778 .65678 Mtetra
.578 .475 .701 r
.32953 .63901 .32505 .64149 .32928 .64876 .33372 .64688 Mtetra
.616 .527 .73 r
.32523 .63257 .32072 .63546 .32505 .64149 .32953 .63901 Mtetra
.646 .567 .751 r
.32086 .62708 .31633 .63024 .32072 .63546 .32523 .63257 Mtetra
.666 .595 .766 r
.31643 .6222 .31189 .62554 .31633 .63024 .32086 .62708 Mtetra
.679 .614 .775 r
.31197 .6177 .30742 .62115 .31189 .62554 .31643 .6222 Mtetra
.688 .626 .782 r
.30748 .61344 .30293 .61694 .30742 .62115 .31197 .6177 Mtetra
.693 .633 .785 r
.30297 .60931 .29842 .61286 .30293 .61694 .30748 .61344 Mtetra
.696 .638 .787 r
.29845 .60527 .29389 .60886 .29842 .61286 .30297 .60931 Mtetra
.699 .641 .788 r
.29392 .60128 .28936 .60489 .29389 .60886 .29845 .60527 Mtetra
.7 .643 .789 r
.28937 .59732 .28481 .60094 .28936 .60489 .29392 .60128 Mtetra
.7 .644 .79 r
.28482 .59338 .28026 .597 .28481 .60094 .28937 .59732 Mtetra
.7 .645 .79 r
.28026 .58944 .2757 .59307 .28026 .597 .28482 .59338 Mtetra
.701 .645 .79 r
.27569 .58549 .27113 .58914 .2757 .59307 .28026 .58944 Mtetra
.27111 .58155 .26655 .58521 .27113 .58914 .27569 .58549 Mtetra
.701 .646 .791 r
.26653 .57761 .26197 .58127 .26655 .58521 .27111 .58155 Mtetra
.26194 .57367 .25737 .57733 .26197 .58127 .26653 .57761 Mtetra
.701 .645 .791 r
.25734 .56971 .25278 .57338 .25737 .57733 .26194 .57367 Mtetra
.701 .645 .79 r
.25273 .56575 .24817 .56943 .25278 .57338 .25734 .56971 Mtetra
.702 .646 .791 r
.24812 .56178 .24355 .56548 .24817 .56943 .25273 .56575 Mtetra
.701 .646 .791 r
.2435 .55782 .23893 .56151 .24355 .56548 .24812 .56178 Mtetra
.23887 .55384 .23431 .55754 .23893 .56151 .2435 .55782 Mtetra
.23423 .54986 .22967 .55356 .23431 .55754 .23887 .55384 Mtetra
.701 .645 .791 r
.22959 .54587 .22503 .54958 .22967 .55356 .23423 .54986 Mtetra
.702 .646 .791 r
.22494 .54187 .22038 .54559 .22503 .54958 .22959 .54587 Mtetra
.701 .646 .791 r
.22028 .53787 .21572 .54159 .22038 .54559 .22494 .54187 Mtetra
.21562 .53386 .21105 .53759 .21572 .54159 .22028 .53787 Mtetra
.21094 .52985 .20638 .53358 .21105 .53759 .21562 .53386 Mtetra
.702 .646 .791 r
.20626 .52583 .2017 .52957 .20638 .53358 .21094 .52985 Mtetra
.20158 .5218 .19701 .52555 .2017 .52957 .20626 .52583 Mtetra
.701 .646 .791 r
.19688 .51776 .19232 .52152 .19701 .52555 .20158 .5218 Mtetra
.19218 .51372 .18762 .51748 .19232 .52152 .19688 .51776 Mtetra
.18747 .50968 .18291 .51344 .18762 .51748 .19218 .51372 Mtetra
.18275 .50563 .17819 .5094 .18291 .51344 .18747 .50968 Mtetra
.17803 .50157 .17346 .50534 .17819 .5094 .18275 .50563 Mtetra
.701 .645 .791 r
.1733 .4975 .16873 .50128 .17346 .50534 .17803 .50157 Mtetra
.701 .646 .791 r
.16856 .49343 .16399 .49722 .16873 .50128 .1733 .4975 Mtetra
.16381 .48935 .15925 .49314 .16399 .49722 .16856 .49343 Mtetra
.15905 .48527 .15449 .48906 .15925 .49314 .16381 .48935 Mtetra
.15429 .48118 .14973 .48498 .15449 .48906 .15905 .48527 Mtetra
.701 .645 .79 r
.14952 .47707 .14496 .48089 .14973 .48498 .15429 .48118 Mtetra
.702 .646 .791 r
.14475 .47297 .14018 .47679 .14496 .48089 .14952 .47707 Mtetra
.701 .646 .791 r
.13996 .46886 .1354 .47268 .14018 .47679 .14475 .47297 Mtetra
.13517 .46475 .1306 .46857 .1354 .47268 .13996 .46886 Mtetra
.13037 .46062 .1258 .46445 .1306 .46857 .13517 .46475 Mtetra
.701 .645 .79 r
.12556 .45648 .12099 .46033 .1258 .46445 .13037 .46062 Mtetra
.702 .646 .79 r
.12074 .45235 .11618 .4562 .12099 .46033 .12556 .45648 Mtetra
.701 .646 .791 r
.11592 .4482 .11135 .45206 .11618 .4562 .12074 .45235 Mtetra
.11109 .44405 .10652 .44791 .11135 .45206 .11592 .4482 Mtetra
.10625 .4399 .10168 .44376 .10652 .44791 .11109 .44405 Mtetra
.1014 .43573 .09683 .4396 .10168 .44376 .10625 .4399 Mtetra
.702 .646 .79 r
.09655 .43156 .09198 .43544 .09683 .4396 .1014 .43573 Mtetra
.702 .646 .791 r
.09168 .42738 .08712 .43127 .09198 .43544 .09655 .43156 Mtetra
.701 .646 .791 r
.08681 .42319 .08225 .42709 .08712 .43127 .09168 .42738 Mtetra
.702 .646 .791 r
.08193 .41901 .07737 .4229 .08225 .42709 .08681 .42319 Mtetra
.07704 .41482 .07248 .41873 .07737 .4229 .08193 .41901 Mtetra
.702 .646 .79 r
.07215 .41063 .06758 .41455 .07248 .41873 .07704 .41482 Mtetra
.704 .647 .79 r
.06724 .40643 .06266 .41039 .06758 .41455 .07215 .41063 Mtetra
.706 .648 .79 r
.06232 .40226 .05773 .40627 .06266 .41039 .06724 .40643 Mtetra
.71 .652 .789 r
.05737 .39815 .05278 .40222 .05773 .40627 .06232 .40226 Mtetra
.712 .653 .789 r
.50878 .77873 .50424 .78231 .50846 .78569 .513 .78223 Mtetra
.722 .66 .788 r
.50456 .77537 .50001 .77914 .50424 .78231 .50878 .77873 Mtetra
.741 .674 .785 r
.50032 .77229 .49577 .77643 .50001 .77914 .50456 .77537 Mtetra
.777 .698 .777 r
.49608 .76976 .49152 .77465 .49577 .77643 .50032 .77229 Mtetra
.836 .738 .756 r
.49182 .76831 .48725 .77468 .49152 .77465 .49608 .76976 Mtetra
.914 .788 .707 r
.48754 .76899 .48292 .77816 .48725 .77468 .49182 .76831 Mtetra
.982 .829 .615 r
.4832 .77367 .47851 .78778 .48292 .77816 .48754 .76899 Mtetra
.995 .835 .481 r
.47875 .78535 .47392 .80705 .47851 .78778 .4832 .77367 Mtetra
.906 .785 .301 r
.47412 .80745 .46909 .83746 .47392 .80705 .47875 .78535 Mtetra
0 0 0 r
.46924 .8399 .46407 .8711 .46909 .83746 .47412 .80745 Mtetra
.07 0 .275 r
.46424 .87128 .45922 .88673 .46407 .8711 .46924 .8399 Mtetra
.684 .327 .364 r
.4595 .879 .45494 .86871 .45922 .88673 .46424 .87128 Mtetra
0 0 .152 r
.45536 .85347 .45116 .82891 .45494 .86871 .4595 .879 Mtetra
0 0 .413 r
.45162 .81206 .44751 .78968 .45116 .82891 .45536 .85347 Mtetra
.169 .062 .481 r
.44792 .77517 .44371 .76121 .44751 .78968 .45162 .81206 Mtetra
.287 .167 .536 r
.44406 .74954 .43973 .74293 .44371 .76121 .44792 .77517 Mtetra
.393 .277 .601 r
.44003 .73329 .4356 .73136 .43973 .74293 .44406 .74954 Mtetra
.496 .394 .668 r
.43586 .7229 .43138 .7236 .4356 .73136 .44003 .73329 Mtetra
.581 .495 .722 r
.43162 .71578 .4271 .71788 .43138 .7236 .43586 .7229 Mtetra
.639 .565 .756 r
.42732 .7104 .42279 .71323 .4271 .71788 .43162 .71578 Mtetra
.674 .609 .775 r
.423 .70595 .41845 .70916 .42279 .71323 .42732 .7104 Mtetra
.695 .636 .786 r
.41864 .70202 .41409 .70545 .41845 .70916 .423 .70595 Mtetra
.711 .656 .793 r
.41427 .69845 .40971 .70207 .41409 .70545 .41864 .70202 Mtetra
.728 .676 .8 r
.40988 .69526 .4053 .69907 .40971 .70207 .41427 .69845 Mtetra
.749 .703 .807 r
.40545 .69253 .40086 .69658 .4053 .69907 .40988 .69526 Mtetra
.78 .741 .817 r
.40099 .69047 .39638 .69486 .40086 .69658 .40545 .69253 Mtetra
.826 .798 .826 r
.39646 .68944 .39181 .69435 .39638 .69486 .40099 .69047 Mtetra
.884 .879 .825 r
.39184 .68992 .38715 .69557 .39181 .69435 .39646 .68944 Mtetra
.925 .96 .782 r
.38708 .69251 .38232 .69912 .38715 .69557 .39184 .68992 Mtetra
.876 .969 .648 r
.38216 .69773 .37732 .70536 .38232 .69912 .38708 .69251 Mtetra
.719 .869 .457 r
.37704 .7055 .37213 .71386 .37732 .70536 .38216 .69773 Mtetra
0 0 0 r
.3718 .71447 .36687 .7226 .37213 .71386 .37704 .7055 Mtetra
.36662 .72152 .36176 .7279 .36687 .7226 .3718 .71447 Mtetra
.734 .981 .913 r
.36174 .72267 .35706 .72608 .36176 .7279 .36662 .72152 Mtetra
.48 .463 .761 r
.35736 .71571 .35287 .71624 .35706 .72608 .36174 .72267 Mtetra
.392 .292 .621 r
.35342 .70203 .34906 .70101 .35287 .71624 .35736 .71571 Mtetra
.394 .268 .588 r
.34971 .68549 .34539 .68438 .34906 .70101 .35342 .70203 Mtetra
.422 .289 .594 r
.346 .66959 .34166 .66925 .34539 .68438 .34971 .68549 Mtetra
.464 .334 .618 r
.34216 .65609 .33778 .65678 .34166 .66925 .346 .66959 Mtetra
.512 .392 .653 r
.33816 .64528 .33372 .64688 .33778 .65678 .34216 .65609 Mtetra
.561 .453 .688 r
.33401 .63672 .32953 .63901 .33372 .64688 .33816 .64528 Mtetra
.604 .509 .72 r
.32974 .6298 .32523 .63257 .32953 .63901 .33401 .63672 Mtetra
.636 .553 .744 r
.32539 .624 .32086 .62708 .32523 .63257 .32974 .6298 Mtetra
.659 .586 .762 r
.32097 .61892 .31643 .6222 .32086 .62708 .32539 .624 Mtetra
.675 .607 .772 r
.31652 .61429 .31197 .6177 .31643 .6222 .32097 .61892 Mtetra
.685 .622 .779 r
.31204 .60993 .30748 .61344 .31197 .6177 .31652 .61429 Mtetra
.692 .631 .784 r
.30753 .60576 .30297 .60931 .30748 .61344 .31204 .60993 Mtetra
.695 .637 .787 r
.30301 .60169 .29845 .60527 .30297 .60931 .30753 .60576 Mtetra
.697 .64 .789 r
.29848 .59768 .29392 .60128 .29845 .60527 .30301 .60169 Mtetra
.699 .642 .789 r
.29394 .5937 .28937 .59732 .29392 .60128 .29848 .59768 Mtetra
.7 .643 .789 r
.28939 .58973 .28482 .59338 .28937 .59732 .29394 .5937 Mtetra
.701 .645 .79 r
.28483 .58578 .28026 .58944 .28482 .59338 .28939 .58973 Mtetra
.701 .645 .791 r
.28026 .58185 .27569 .58549 .28026 .58944 .28483 .58578 Mtetra
.27568 .5779 .27111 .58155 .27569 .58549 .28026 .58185 Mtetra
.701 .645 .79 r
.2711 .57394 .26653 .57761 .27111 .58155 .27568 .5779 Mtetra
.702 .645 .79 r
.2665 .56998 .26194 .57367 .26653 .57761 .2711 .57394 Mtetra
.702 .646 .791 r
.26191 .56603 .25734 .56971 .26194 .57367 .2665 .56998 Mtetra
.701 .646 .791 r
.2573 .56207 .25273 .56575 .25734 .56971 .26191 .56603 Mtetra
.25269 .5581 .24812 .56178 .25273 .56575 .2573 .56207 Mtetra
.24806 .55412 .2435 .55782 .24812 .56178 .25269 .5581 Mtetra
.702 .646 .791 r
.24344 .55013 .23887 .55384 .2435 .55782 .24806 .55412 Mtetra
.2388 .54615 .23423 .54986 .23887 .55384 .24344 .55013 Mtetra
.701 .646 .791 r
.23416 .54215 .22959 .54587 .23423 .54986 .2388 .54615 Mtetra
.22951 .53815 .22494 .54187 .22959 .54587 .23416 .54215 Mtetra
.22485 .53414 .22028 .53787 .22494 .54187 .22951 .53815 Mtetra
.22019 .53013 .21562 .53386 .22028 .53787 .22485 .53414 Mtetra
.701 .645 .791 r
.21551 .52611 .21094 .52985 .21562 .53386 .22019 .53013 Mtetra
.701 .646 .791 r
.21084 .52208 .20626 .52583 .21094 .52985 .21551 .52611 Mtetra
.20615 .51805 .20158 .5218 .20626 .52583 .21084 .52208 Mtetra
.20145 .51401 .19688 .51776 .20158 .5218 .20615 .51805 Mtetra
.19675 .50997 .19218 .51372 .19688 .51776 .20145 .51401 Mtetra
.701 .645 .791 r
.19204 .50591 .18747 .50968 .19218 .51372 .19675 .50997 Mtetra
.702 .646 .791 r
.18733 .50185 .18275 .50563 .18747 .50968 .19204 .50591 Mtetra
.1826 .49779 .17803 .50157 .18275 .50563 .18733 .50185 Mtetra
.701 .646 .791 r
.17787 .49372 .1733 .4975 .17803 .50157 .1826 .49779 Mtetra
.17313 .48964 .16856 .49343 .1733 .4975 .17787 .49372 Mtetra
.701 .645 .791 r
.16838 .48555 .16381 .48935 .16856 .49343 .17313 .48964 Mtetra
.702 .646 .79 r
.16363 .48146 .15905 .48527 .16381 .48935 .16838 .48555 Mtetra
.702 .646 .791 r
.15887 .47736 .15429 .48118 .15905 .48527 .16363 .48146 Mtetra
.701 .646 .791 r
.1541 .47326 .14952 .47707 .15429 .48118 .15887 .47736 Mtetra
.14932 .46915 .14475 .47297 .14952 .47707 .1541 .47326 Mtetra
.14453 .46503 .13996 .46886 .14475 .47297 .14932 .46915 Mtetra
.702 .646 .791 r
.13974 .46091 .13517 .46475 .13996 .46886 .14453 .46503 Mtetra
.13494 .45677 .13037 .46062 .13517 .46475 .13974 .46091 Mtetra
.701 .646 .791 r
.13013 .45264 .12556 .45648 .13037 .46062 .13494 .45677 Mtetra
.12532 .44849 .12074 .45235 .12556 .45648 .13013 .45264 Mtetra
.12049 .44434 .11592 .4482 .12074 .45235 .12532 .44849 Mtetra
.11566 .44019 .11109 .44405 .11592 .4482 .12049 .44434 Mtetra
.701 .645 .791 r
.11082 .43602 .10625 .4399 .11109 .44405 .11566 .44019 Mtetra
.702 .646 .791 r
.10597 .43185 .1014 .43573 .10625 .4399 .11082 .43602 Mtetra
.701 .646 .791 r
.10112 .42767 .09655 .43156 .1014 .43573 .10597 .43185 Mtetra
.09626 .42349 .09168 .42738 .09655 .43156 .10112 .42767 Mtetra
.09138 .4193 .08681 .42319 .09168 .42738 .09626 .42349 Mtetra
.701 .645 .79 r
.08651 .4151 .08193 .41901 .08681 .42319 .09138 .4193 Mtetra
.702 .646 .79 r
.08162 .41089 .07704 .41482 .08193 .41901 .08651 .4151 Mtetra
.07672 .40669 .07215 .41063 .07704 .41482 .08162 .41089 Mtetra
.703 .647 .791 r
.07182 .4025 .06724 .40643 .07215 .41063 .07672 .40669 Mtetra
.704 .648 .791 r
.0669 .3983 .06232 .40226 .06724 .40643 .07182 .4025 Mtetra
.706 .649 .79 r
.06197 .39413 .05737 .39815 .06232 .40226 .0669 .3983 Mtetra
.708 .65 .79 r
.51334 .77524 .50878 .77873 .513 .78223 .51756 .77879 Mtetra
.713 .655 .79 r
.50911 .77177 .50456 .77537 .50878 .77873 .51334 .77524 Mtetra
.726 .663 .787 r
.50488 .76845 .50032 .77229 .50456 .77537 .50911 .77177 Mtetra
.749 .678 .783 r
.50064 .76545 .49608 .76976 .50032 .77229 .50488 .76845 Mtetra
.79 .706 .772 r
.49639 .76311 .49182 .76831 .49608 .76976 .50064 .76545 Mtetra
.855 .75 .747 r
.49213 .76207 .48754 .76899 .49182 .76831 .49639 .76311 Mtetra
.934 .801 .689 r
.48783 .76352 .4832 .77367 .48754 .76899 .49213 .76207 Mtetra
.992 .834 .585 r
.48347 .76961 .47875 .78535 .4832 .77367 .48783 .76352 Mtetra
.985 .829 .44 r
.47899 .78356 .47412 .80745 .47875 .78535 .48347 .76961 Mtetra
.853 .755 .242 r
.47431 .80849 .46924 .8399 .47412 .80745 .47899 .78356 Mtetra
0 0 .059 r
.4694 .8423 .46424 .87128 .46924 .8399 .47431 .80849 Mtetra
.228 0 .32 r
.46443 .86989 .4595 .879 .46424 .87128 .4694 .8423 Mtetra
.833 .446 .317 r
.45983 .86901 .45536 .85347 .4595 .879 .46443 .86989 Mtetra
0 0 .272 r
.4558 .83724 .45162 .81206 .45536 .85347 .45983 .86901 Mtetra
.033 0 .434 r
.45208 .79557 .44792 .77517 .45162 .81206 .4558 .83724 Mtetra
.201 .089 .494 r
.44832 .7614 .44406 .74954 .44792 .77517 .45208 .79557 Mtetra
.313 .193 .551 r
.4444 .73846 .44003 .73329 .44406 .74954 .44832 .7614 Mtetra
.42 .306 .618 r
.44032 .724 .43586 .7229 .44003 .73329 .4444 .73846 Mtetra
.52 .421 .683 r
.43612 .71464 .43162 .71578 .43586 .7229 .44032 .724 Mtetra
.599 .516 .732 r
.43186 .70806 .42732 .7104 .43162 .71578 .43612 .71464 Mtetra
.65 .579 .762 r
.42754 .70298 .423 .70595 .42732 .7104 .43186 .70806 Mtetra
.682 .619 .779 r
.4232 .69871 .41864 .70202 .423 .70595 .42754 .70298 Mtetra
.702 .645 .79 r
.41884 .69493 .41427 .69845 .41864 .70202 .4232 .69871 Mtetra
.719 .666 .797 r
.41445 .69154 .40988 .69526 .41427 .69845 .41884 .69493 Mtetra
.739 .69 .803 r
.41004 .68858 .40545 .69253 .40988 .69526 .41445 .69154 Mtetra
.767 .724 .812 r
.40559 .68622 .40099 .69047 .40545 .69253 .41004 .68858 Mtetra
.807 .774 .823 r
.40109 .68474 .39646 .68944 .40099 .69047 .40559 .68622 Mtetra
.861 .847 .828 r
.39651 .68458 .39184 .68992 .39646 .68944 .40109 .68474 Mtetra
.915 .933 .807 r
.39182 .68629 .38708 .69251 .39184 .68992 .39651 .68458 Mtetra
.91 .979 .711 r
.38697 .69046 .38216 .69773 .38708 .69251 .39182 .68629 Mtetra
.786 .915 .528 r
.38193 .69732 .37704 .7055 .38216 .69773 .38697 .69046 Mtetra
.611 .792 .361 r
.37674 .7061 .3718 .71447 .37704 .7055 .38193 .69732 Mtetra
0 0 0 r
.37152 .71432 .36662 .72152 .3718 .71447 .37674 .7061 Mtetra
.655 .939 .679 r
.36651 .71808 .36174 .72267 .36662 .72152 .37152 .71432 Mtetra
.58 .635 .87 r
.36193 .71417 .35736 .71571 .36174 .72267 .36651 .71808 Mtetra
.407 .327 .654 r
.35783 .70265 .35342 .70203 .35736 .71571 .36193 .71417 Mtetra
.387 .269 .594 r
.35404 .68672 .34971 .68549 .35342 .70203 .35783 .70265 Mtetra
.409 .278 .589 r
.35034 .67027 .346 .66959 .34971 .68549 .35404 .68672 Mtetra
.448 .316 .608 r
.34654 .65577 .34216 .65609 .346 .66959 .35034 .67027 Mtetra
.494 .37 .639 r
.34259 .64398 .33816 .64528 .34216 .65609 .34654 .65577 Mtetra
.543 .43 .675 r
.33848 .63465 .33401 .63672 .33816 .64528 .34259 .64398 Mtetra
.588 .489 .709 r
.33425 .62718 .32974 .6298 .33401 .63672 .33848 .63465 Mtetra
.625 .538 .736 r
.32992 .621 .32539 .624 .32974 .6298 .33425 .62718 Mtetra
.652 .575 .755 r
.32552 .61568 .32097 .61892 .32539 .624 .32992 .621 Mtetra
.67 .601 .769 r
.32107 .6109 .31652 .61429 .32097 .61892 .32552 .61568 Mtetra
.681 .617 .778 r
.3166 .60647 .31204 .60993 .31652 .61429 .32107 .6109 Mtetra
.689 .628 .782 r
.3121 .60222 .30753 .60576 .31204 .60993 .3166 .60647 Mtetra
.694 .634 .785 r
.30758 .5981 .30301 .60169 .30753 .60576 .3121 .60222 Mtetra
.697 .639 .787 r
.30305 .59406 .29848 .59768 .30301 .60169 .30758 .5981 Mtetra
.699 .642 .789 r
.29851 .59007 .29394 .5937 .29848 .59768 .30305 .59406 Mtetra
.699 .643 .79 r
.29396 .5861 .28939 .58973 .29394 .5937 .29851 .59007 Mtetra
.7 .644 .79 r
.2894 .58214 .28483 .58578 .28939 .58973 .29396 .5861 Mtetra
.701 .645 .79 r
.28483 .57818 .28026 .58185 .28483 .58578 .2894 .58214 Mtetra
.28025 .57423 .27568 .5779 .28026 .58185 .28483 .57818 Mtetra
.701 .645 .791 r
.27567 .57027 .2711 .57394 .27568 .5779 .28025 .57423 Mtetra
.27108 .56631 .2665 .56998 .2711 .57394 .27567 .57027 Mtetra
.701 .646 .791 r
.26648 .56234 .26191 .56603 .2665 .56998 .27108 .56631 Mtetra
.26187 .55838 .2573 .56207 .26191 .56603 .26648 .56234 Mtetra
.25726 .5544 .25269 .5581 .2573 .56207 .26187 .55838 Mtetra
.701 .645 .791 r
.25264 .55041 .24806 .55412 .25269 .5581 .25726 .5544 Mtetra
.701 .646 .791 r
.24801 .54642 .24344 .55013 .24806 .55412 .25264 .55041 Mtetra
.24338 .54243 .2388 .54615 .24344 .55013 .24801 .54642 Mtetra
.23873 .53844 .23416 .54215 .2388 .54615 .24338 .54243 Mtetra
.23408 .53443 .22951 .53815 .23416 .54215 .23873 .53844 Mtetra
.701 .645 .79 r
.22943 .53041 .22485 .53414 .22951 .53815 .23408 .53443 Mtetra
.702 .646 .791 r
.22476 .52639 .22019 .53013 .22485 .53414 .22943 .53041 Mtetra
.701 .646 .791 r
.22009 .52236 .21551 .52611 .22019 .53013 .22476 .52639 Mtetra
.21541 .51834 .21084 .52208 .21551 .52611 .22009 .52236 Mtetra
.21072 .5143 .20615 .51805 .21084 .52208 .21541 .51834 Mtetra
.701 .645 .79 r
.20603 .51025 .20145 .51401 .20615 .51805 .21072 .5143 Mtetra
.702 .646 .79 r
.20133 .50619 .19675 .50997 .20145 .51401 .20603 .51025 Mtetra
.701 .646 .791 r
.19662 .50214 .19204 .50591 .19675 .50997 .20133 .50619 Mtetra
.1919 .49807 .18733 .50185 .19204 .50591 .19662 .50214 Mtetra
.18718 .494 .1826 .49779 .18733 .50185 .1919 .49807 Mtetra
.18245 .48993 .17787 .49372 .1826 .49779 .18718 .494 Mtetra
.702 .645 .79 r
.17771 .48584 .17313 .48964 .17787 .49372 .18245 .48993 Mtetra
.702 .646 .791 r
.17296 .48175 .16838 .48555 .17313 .48964 .17771 .48584 Mtetra
.701 .646 .791 r
.16821 .47765 .16363 .48146 .16838 .48555 .17296 .48175 Mtetra
.16344 .47355 .15887 .47736 .16363 .48146 .16821 .47765 Mtetra
.15867 .46944 .1541 .47326 .15887 .47736 .16344 .47355 Mtetra
.701 .645 .791 r
.1539 .46532 .14932 .46915 .1541 .47326 .15867 .46944 Mtetra
.14911 .46119 .14453 .46503 .14932 .46915 .1539 .46532 Mtetra
.701 .646 .791 r
.14432 .45706 .13974 .46091 .14453 .46503 .14911 .46119 Mtetra
.13952 .45293 .13494 .45677 .13974 .46091 .14432 .45706 Mtetra
.13471 .44879 .13013 .45264 .13494 .45677 .13952 .45293 Mtetra
.12989 .44464 .12532 .44849 .13013 .45264 .13471 .44879 Mtetra
.701 .645 .791 r
.12507 .44048 .12049 .44434 .12532 .44849 .12989 .44464 Mtetra
.702 .646 .791 r
.12024 .43631 .11566 .44019 .12049 .44434 .12507 .44048 Mtetra
.701 .646 .791 r
.1154 .43214 .11082 .43602 .11566 .44019 .12024 .43631 Mtetra
.11055 .42797 .10597 .43185 .11082 .43602 .1154 .43214 Mtetra
.1057 .42378 .10112 .42767 .10597 .43185 .11055 .42797 Mtetra
.702 .645 .79 r
.10084 .41959 .09626 .42349 .10112 .42767 .1057 .42378 Mtetra
.702 .646 .791 r
.09597 .41539 .09138 .4193 .09626 .42349 .10084 .41959 Mtetra
.09109 .41119 .08651 .4151 .09138 .4193 .09597 .41539 Mtetra
.701 .646 .791 r
.0862 .40698 .08162 .41089 .08651 .4151 .09109 .41119 Mtetra
.0813 .40277 .07672 .40669 .08162 .41089 .0862 .40698 Mtetra
.702 .646 .79 r
.0764 .39855 .07182 .4025 .07672 .40669 .0813 .40277 Mtetra
.703 .646 .79 r
.07149 .39433 .0669 .3983 .07182 .4025 .0764 .39855 Mtetra
.705 .648 .79 r
.06656 .39013 .06197 .39413 .0669 .3983 .07149 .39433 Mtetra
.5179 .77179 .51334 .77524 .51756 .77879 .52212 .77538 Mtetra
.709 .651 .79 r
.51368 .76824 .50911 .77177 .51334 .77524 .5179 .77179 Mtetra
.716 .656 .789 r
.50944 .76478 .50488 .76845 .50911 .77177 .51368 .76824 Mtetra
.73 .666 .787 r
.50521 .76152 .50064 .76545 .50488 .76845 .50944 .76478 Mtetra
.757 .684 .781 r
.50096 .75864 .49639 .76311 .50064 .76545 .50521 .76152 Mtetra
.804 .716 .768 r
.4967 .75653 .49213 .76207 .49639 .76311 .50096 .75864 Mtetra
.874 .763 .736 r
.49243 .75595 .48783 .76352 .49213 .76207 .4967 .75653 Mtetra
.953 .812 .667 r
.48812 .75831 .48347 .76961 .48783 .76352 .49243 .75595 Mtetra
.998 .837 .551 r
.48374 .76599 .47899 .78356 .48347 .76961 .48812 .75831 Mtetra
.968 .82 .397 r
.47923 .78244 .47431 .80849 .47899 .78356 .48374 .76599 Mtetra
.782 .712 .176 r
.4745 .81012 .4694 .8423 .47431 .80849 .47923 .78244 Mtetra
0 0 .139 r
.46956 .84433 .46443 .86989 .4694 .8423 .4745 .81012 Mtetra
.379 .095 .351 r
.46465 .86656 .45983 .86901 .46443 .86989 .46956 .84433 Mtetra
.927 .541 .201 r
.46018 .85693 .4558 .83724 .45983 .86901 .46465 .86656 Mtetra
0 0 .342 r
.45625 .82043 .45208 .79557 .4558 .83724 .46018 .85693 Mtetra
.086 0 .451 r
.45252 .77965 .44832 .7614 .45208 .79557 .45625 .82043 Mtetra
.23 .114 .507 r
.44871 .74837 .4444 .73846 .44832 .7614 .45252 .77965 Mtetra
.34 .22 .567 r
.44473 .7279 .44032 .724 .4444 .73846 .44871 .74837 Mtetra
.446 .336 .635 r
.4406 .71501 .43612 .71464 .44032 .724 .44473 .7279 Mtetra
.542 .448 .698 r
.43638 .70653 .43186 .70806 .43612 .71464 .4406 .71501 Mtetra
.614 .535 .742 r
.43209 .70044 .42754 .70298 .43186 .70806 .43638 .70653 Mtetra
.661 .592 .768 r
.42776 .69562 .4232 .69871 .42754 .70298 .43209 .70044 Mtetra
.69 .628 .782 r
.42341 .69152 .41884 .69493 .4232 .69871 .42776 .69562 Mtetra
.71 .654 .792 r
.41903 .68791 .41445 .69154 .41884 .69493 .42341 .69152 Mtetra
.73 .679 .801 r
.41463 .68474 .41004 .68858 .41445 .69154 .41903 .68791 Mtetra
.754 .709 .809 r
.4102 .68211 .40559 .68622 .41004 .68858 .41463 .68474 Mtetra
.79 .752 .818 r
.40572 .68023 .40109 .68474 .40559 .68622 .4102 .68211 Mtetra
.839 .816 .827 r
.40117 .67949 .39651 .68458 .40109 .68474 .40572 .68023 Mtetra
.898 .901 .82 r
.39653 .68041 .39182 .68629 .39651 .68458 .40117 .67949 Mtetra
.924 .973 .758 r
.39175 .6836 .38697 .69046 .39182 .68629 .39653 .68041 Mtetra
.845 .952 .602 r
.3868 .68944 .38193 .69732 .38697 .69046 .39175 .6836 Mtetra
.677 .838 .415 r
.38167 .69766 .37674 .7061 .38193 .69732 .3868 .68944 Mtetra
0 0 0 r
.37645 .70648 .37152 .71432 .37674 .7061 .38167 .69766 Mtetra
.559 .829 .476 r
.37134 .71237 .36651 .71808 .37152 .71432 .37645 .70648 Mtetra
.704 .875 .962 r
.36658 .71154 .36193 .71417 .36651 .71808 .37134 .71237 Mtetra
.442 .392 .707 r
.3623 .70261 .35783 .70265 .36193 .71417 .36658 .71154 Mtetra
.388 .279 .607 r
.35841 .68785 .35404 .68672 .35783 .70265 .3623 .70261 Mtetra
.399 .27 .587 r
.35468 .67122 .35034 .67027 .35404 .68672 .35841 .68785 Mtetra
.431 .299 .599 r
.35092 .65584 .34654 .65577 .35034 .67027 .35468 .67122 Mtetra
.476 .348 .626 r
.34701 .64302 .34259 .64398 .34654 .65577 .35092 .65584 Mtetra
.525 .407 .661 r
.34295 .63283 .33848 .63465 .34259 .64398 .34701 .64302 Mtetra
.573 .468 .697 r
.33875 .62473 .33425 .62718 .33848 .63465 .34295 .63283 Mtetra
.612 .521 .727 r
.33444 .61813 .32992 .621 .33425 .62718 .33875 .62473 Mtetra
.642 .562 .749 r
.33006 .61253 .32552 .61568 .32992 .621 .33444 .61813 Mtetra
.664 .592 .764 r
.32563 .60756 .32107 .6109 .32552 .61568 .33006 .61253 Mtetra
.678 .612 .774 r
.32116 .60301 .3166 .60647 .32107 .6109 .32563 .60756 Mtetra
.687 .625 .781 r
.31667 .59869 .3121 .60222 .3166 .60647 .32116 .60301 Mtetra
.692 .632 .785 r
.31216 .59453 .30758 .5981 .3121 .60222 .31667 .59869 Mtetra
.696 .638 .787 r
.30763 .59046 .30305 .59406 .30758 .5981 .31216 .59453 Mtetra
.698 .641 .789 r
.30309 .58645 .29851 .59007 .30305 .59406 .30763 .59046 Mtetra
.699 .643 .79 r
.29854 .58246 .29396 .5861 .29851 .59007 .30309 .58645 Mtetra
.7 .643 .79 r
.29398 .57849 .2894 .58214 .29396 .5861 .29854 .58246 Mtetra
.701 .644 .79 r
.28941 .57451 .28483 .57818 .2894 .58214 .29398 .57849 Mtetra
.701 .645 .79 r
.28483 .57055 .28025 .57423 .28483 .57818 .28941 .57451 Mtetra
.701 .646 .791 r
.28025 .5666 .27567 .57027 .28025 .57423 .28483 .57055 Mtetra
.27566 .56264 .27108 .56631 .27567 .57027 .28025 .5666 Mtetra
.701 .645 .79 r
.27106 .55865 .26648 .56234 .27108 .56631 .27566 .56264 Mtetra
.702 .645 .79 r
.26646 .55467 .26187 .55838 .26648 .56234 .27106 .55865 Mtetra
.702 .646 .791 r
.26184 .55069 .25726 .5544 .26187 .55838 .26646 .55467 Mtetra
.701 .646 .791 r
.25722 .54671 .25264 .55041 .25726 .5544 .26184 .55069 Mtetra
.25259 .54272 .24801 .54642 .25264 .55041 .25722 .54671 Mtetra
.701 .645 .791 r
.24796 .53871 .24338 .54243 .24801 .54642 .25259 .54272 Mtetra
.702 .646 .79 r
.24332 .5347 .23873 .53844 .24338 .54243 .24796 .53871 Mtetra
.702 .646 .791 r
.23867 .53069 .23408 .53443 .23873 .53844 .24332 .5347 Mtetra
.701 .646 .791 r
.23401 .52667 .22943 .53041 .23408 .53443 .23867 .53069 Mtetra
.22935 .52265 .22476 .52639 .22943 .53041 .23401 .52667 Mtetra
.22468 .51862 .22009 .52236 .22476 .52639 .22935 .52265 Mtetra
.702 .646 .791 r
.22 .51458 .21541 .51834 .22009 .52236 .22468 .51862 Mtetra
.21531 .51053 .21072 .5143 .21541 .51834 .22 .51458 Mtetra
.701 .646 .791 r
.21062 .50648 .20603 .51025 .21072 .5143 .21531 .51053 Mtetra
.20591 .50242 .20133 .50619 .20603 .51025 .21062 .50648 Mtetra
.2012 .49836 .19662 .50214 .20133 .50619 .20591 .50242 Mtetra
.19649 .49429 .1919 .49807 .19662 .50214 .2012 .49836 Mtetra
.701 .645 .79 r
.19176 .49021 .18718 .494 .1919 .49807 .19649 .49429 Mtetra
.702 .646 .791 r
.18703 .48612 .18245 .48993 .18718 .494 .19176 .49021 Mtetra
.701 .646 .791 r
.18229 .48203 .17771 .48584 .18245 .48993 .18703 .48612 Mtetra
.17755 .47794 .17296 .48175 .17771 .48584 .18229 .48203 Mtetra
.17279 .47384 .16821 .47765 .17296 .48175 .17755 .47794 Mtetra
.701 .645 .791 r
.16803 .46972 .16344 .47355 .16821 .47765 .17279 .47384 Mtetra
.702 .646 .791 r
.16326 .46561 .15867 .46944 .16344 .47355 .16803 .46972 Mtetra
.15848 .46148 .1539 .46532 .15867 .46944 .16326 .46561 Mtetra
.701 .646 .791 r
.1537 .45736 .14911 .46119 .1539 .46532 .15848 .46148 Mtetra
.14891 .45322 .14432 .45706 .14911 .46119 .1537 .45736 Mtetra
.701 .645 .791 r
.14411 .44907 .13952 .45293 .14432 .45706 .14891 .45322 Mtetra
.702 .646 .791 r
.1393 .44492 .13471 .44879 .13952 .45293 .14411 .44907 Mtetra
.13448 .44077 .12989 .44464 .13471 .44879 .1393 .44492 Mtetra
.701 .646 .791 r
.12966 .4366 .12507 .44048 .12989 .44464 .13448 .44077 Mtetra
.12483 .43244 .12024 .43631 .12507 .44048 .12966 .4366 Mtetra
.11999 .42826 .1154 .43214 .12024 .43631 .12483 .43244 Mtetra
.702 .645 .79 r
.11514 .42407 .11055 .42797 .1154 .43214 .11999 .42826 Mtetra
.702 .646 .791 r
.11029 .41988 .1057 .42378 .11055 .42797 .11514 .42407 Mtetra
.701 .646 .791 r
.10542 .41569 .10084 .41959 .1057 .42378 .11029 .41988 Mtetra
.10055 .41149 .09597 .41539 .10084 .41959 .10542 .41569 Mtetra
.09567 .40728 .09109 .41119 .09597 .41539 .10055 .41149 Mtetra
.702 .645 .79 r
.09079 .40306 .0862 .40698 .09109 .41119 .09567 .40728 Mtetra
.702 .646 .79 r
.08589 .39883 .0813 .40277 .0862 .40698 .09079 .40306 Mtetra
.702 .646 .791 r
.08099 .39461 .0764 .39855 .0813 .40277 .08589 .39883 Mtetra
.702 .647 .791 r
.07608 .39038 .07149 .39433 .0764 .39855 .08099 .39461 Mtetra
.703 .647 .791 r
.07115 .38616 .06656 .39013 .07149 .39433 .07608 .39038 Mtetra
.52247 .76836 .5179 .77179 .52212 .77538 .52669 .77198 Mtetra
.706 .648 .79 r
.51824 .76476 .51368 .76824 .5179 .77179 .52247 .76836 Mtetra
.71 .652 .789 r
.51401 .76122 .50944 .76478 .51368 .76824 .51824 .76476 Mtetra
.719 .658 .789 r
.50978 .75779 .50521 .76152 .50944 .76478 .51401 .76122 Mtetra
.735 .67 .786 r
.50553 .75459 .50096 .75864 .50521 .76152 .50978 .75779 Mtetra
.766 .691 .779 r
.50128 .75185 .4967 .75653 .50096 .75864 .50553 .75459 Mtetra
.819 .726 .762 r
.49702 .75002 .49243 .75595 .4967 .75653 .50128 .75185 Mtetra
.895 .776 .723 r
.49273 .74999 .48812 .75831 .49243 .75595 .49702 .75002 Mtetra
.97 .822 .642 r
.48841 .75339 .48374 .76599 .48812 .75831 .49273 .74999 Mtetra
.999 .838 .516 r
.48401 .76291 .47923 .78244 .48374 .76599 .48841 .75339 Mtetra
.941 .805 .349 r
.47946 .78201 .4745 .81012 .47923 .78244 .48401 .76291 Mtetra
0 0 0 r
.47469 .81219 .46956 .84433 .4745 .81012 .47946 .78201 Mtetra
0 0 .21 r
.46974 .84557 .46465 .86656 .46956 .84433 .47469 .81219 Mtetra
.529 .206 .365 r
.46491 .86106 .46018 .85693 .46465 .86656 .46974 .84557 Mtetra
.856 .54 .015 r
.46057 .84306 .45625 .82043 .46018 .85693 .46491 .86106 Mtetra
0 0 .385 r
.4567 .80342 .45252 .77965 .45625 .82043 .46057 .84306 Mtetra
.129 .032 .466 r
.45294 .76438 .44871 .74837 .45252 .77965 .4567 .80342 Mtetra
.257 .139 .52 r
.44907 .73603 .44473 .7279 .44871 .74837 .45294 .76438 Mtetra
.366 .247 .583 r
.44504 .71782 .4406 .71501 .44473 .7279 .44907 .73603 Mtetra
.472 .365 .652 r
.44087 .70628 .43638 .70653 .4406 .71501 .44504 .71782 Mtetra
.564 .473 .711 r
.43662 .69855 .43209 .70044 .43638 .70653 .44087 .70628 Mtetra
.629 .553 .75 r
.43232 .69288 .42776 .69562 .43209 .70044 .43662 .69855 Mtetra
.67 .605 .773 r
.42798 .68832 .42341 .69152 .42776 .69562 .43232 .69288 Mtetra
.698 .639 .787 r
.42361 .68441 .41903 .68791 .42341 .69152 .42798 .68832 Mtetra
.72 .666 .796 r
.41922 .68099 .41463 .68474 .41903 .68791 .42361 .68441 Mtetra
.743 .695 .805 r
.4148 .6781 .4102 .68211 .41463 .68474 .41922 .68099 Mtetra
.774 .734 .815 r
.41034 .67589 .40572 .68023 .4102 .68211 .4148 .6781 Mtetra
.818 .789 .825 r
.40583 .67465 .40117 .67949 .40572 .68023 .41034 .67589 Mtetra
.876 .867 .826 r
.40123 .67486 .39653 .68041 .40117 .67949 .40583 .67465 Mtetra
.923 .951 .791 r
.39651 .6771 .39175 .6836 .39653 .68041 .40123 .67486 Mtetra
.889 .974 .67 r
.39163 .68192 .3868 .68944 .39175 .6836 .39651 .6771 Mtetra
.74 .884 .478 r
.38658 .68935 .38167 .69766 .3868 .68944 .39163 .68192 Mtetra
0 0 0 r
.38139 .69824 .37645 .70648 .38167 .69766 .38658 .68935 Mtetra
.37622 .70569 .37134 .71237 .37645 .70648 .38139 .69824 Mtetra
.722 .989 .847 r
.37131 .70771 .36658 .71154 .37134 .71237 .37622 .70569 Mtetra
.508 .511 .794 r
.36684 .70174 .3623 .70261 .36658 .71154 .37131 .70771 Mtetra
.395 .301 .63 r
.36282 .68873 .35841 .68785 .3623 .70261 .36684 .70174 Mtetra
.391 .267 .59 r
.35904 .67235 .35468 .67122 .35841 .68785 .36282 .68873 Mtetra
.418 .285 .592 r
.35529 .65626 .35092 .65584 .35468 .67122 .35904 .67235 Mtetra
.458 .328 .615 r
.35142 .64243 .34701 .64302 .35092 .65584 .35529 .65626 Mtetra
.506 .384 .648 r
.34741 .6313 .34295 .63283 .34701 .64302 .35142 .64243 Mtetra
.555 .446 .684 r
.34325 .62249 .33875 .62473 .34295 .63283 .34741 .6313 Mtetra
.598 .503 .717 r
.33897 .61539 .33444 .61813 .33875 .62473 .34325 .62249 Mtetra
.632 .548 .742 r
.33461 .60946 .33006 .61253 .33444 .61813 .33897 .61539 Mtetra
.657 .582 .759 r
.33019 .60427 .32563 .60756 .33006 .61253 .33461 .60946 Mtetra
.674 .605 .771 r
.32574 .59957 .32116 .60301 .32563 .60756 .33019 .60427 Mtetra
.684 .621 .779 r
.32125 .59518 .31667 .59869 .32116 .60301 .32574 .59957 Mtetra
.69 .631 .784 r
.31674 .59098 .31216 .59453 .31667 .59869 .32125 .59518 Mtetra
.694 .636 .786 r
.31221 .58687 .30763 .59046 .31216 .59453 .31674 .59098 Mtetra
.697 .639 .787 r
.30767 .58281 .30309 .58645 .30763 .59046 .31221 .58687 Mtetra
.7 .642 .788 r
.30312 .5788 .29854 .58246 .30309 .58645 .30767 .58281 Mtetra
.7 .644 .79 r
.29856 .57483 .29398 .57849 .29854 .58246 .30312 .5788 Mtetra
.7 .645 .791 r
.294 .57086 .28941 .57451 .29398 .57849 .29856 .57483 Mtetra
.28942 .56689 .28483 .57055 .28941 .57451 .294 .57086 Mtetra
.701 .645 .79 r
.28484 .56291 .28025 .5666 .28483 .57055 .28942 .56689 Mtetra
.702 .645 .79 r
.28025 .55893 .27566 .56264 .28025 .5666 .28484 .56291 Mtetra
.702 .646 .791 r
.27565 .55496 .27106 .55865 .27566 .56264 .28025 .55893 Mtetra
.701 .646 .791 r
.27105 .55098 .26646 .55467 .27106 .55865 .27565 .55496 Mtetra
.26643 .54699 .26184 .55069 .26646 .55467 .27105 .55098 Mtetra
.26181 .543 .25722 .54671 .26184 .55069 .26643 .54699 Mtetra
.702 .645 .79 r
.25719 .53899 .25259 .54272 .25722 .54671 .26181 .543 Mtetra
.702 .646 .791 r
.25255 .53498 .24796 .53871 .25259 .54272 .25719 .53899 Mtetra
.701 .646 .791 r
.24791 .53097 .24332 .5347 .24796 .53871 .25255 .53498 Mtetra
.24326 .52696 .23867 .53069 .24332 .5347 .24791 .53097 Mtetra
.2386 .52294 .23401 .52667 .23867 .53069 .24326 .52696 Mtetra
.701 .645 .791 r
.23394 .5189 .22935 .52265 .23401 .52667 .2386 .52294 Mtetra
.702 .645 .791 r
.22927 .51486 .22468 .51862 .22935 .52265 .23394 .5189 Mtetra
.702 .646 .791 r
.22459 .51081 .22 .51458 .22468 .51862 .22927 .51486 Mtetra
.701 .646 .791 r
.2199 .50676 .21531 .51053 .22 .51458 .22459 .51081 Mtetra
.21521 .50271 .21062 .50648 .21531 .51053 .2199 .50676 Mtetra
.21051 .49865 .20591 .50242 .21062 .50648 .21521 .50271 Mtetra
.702 .645 .79 r
.2058 .49457 .2012 .49836 .20591 .50242 .21051 .49865 Mtetra
.702 .646 .791 r
.20108 .49049 .19649 .49429 .2012 .49836 .2058 .49457 Mtetra
.701 .646 .791 r
.19636 .48641 .19176 .49021 .19649 .49429 .20108 .49049 Mtetra
.19162 .48232 .18703 .48612 .19176 .49021 .19636 .48641 Mtetra
.18689 .47823 .18229 .48203 .18703 .48612 .19162 .48232 Mtetra
.701 .645 .79 r
.18214 .47412 .17755 .47794 .18229 .48203 .18689 .47823 Mtetra
.702 .646 .791 r
.17739 .47001 .17279 .47384 .17755 .47794 .18214 .47412 Mtetra
.701 .646 .791 r
.17262 .46589 .16803 .46972 .17279 .47384 .17739 .47001 Mtetra
.16785 .46177 .16326 .46561 .16803 .46972 .17262 .46589 Mtetra
.16308 .45765 .15848 .46148 .16326 .46561 .16785 .46177 Mtetra
.701 .645 .791 r
.15829 .45351 .1537 .45736 .15848 .46148 .16308 .45765 Mtetra
.702 .646 .791 r
.1535 .44936 .14891 .45322 .1537 .45736 .15829 .45351 Mtetra
.701 .646 .791 r
.1487 .44521 .14411 .44907 .14891 .45322 .1535 .44936 Mtetra
.14389 .44106 .1393 .44492 .14411 .44907 .1487 .44521 Mtetra
.13907 .4369 .13448 .44077 .1393 .44492 .14389 .44106 Mtetra
.13425 .43273 .12966 .4366 .13448 .44077 .13907 .4369 Mtetra
.702 .646 .791 r
.12942 .42855 .12483 .43244 .12966 .4366 .13425 .43273 Mtetra
.12458 .42437 .11999 .42826 .12483 .43244 .12942 .42855 Mtetra
.701 .646 .791 r
.11973 .42018 .11514 .42407 .11999 .42826 .12458 .42437 Mtetra
.11488 .41598 .11029 .41988 .11514 .42407 .11973 .42018 Mtetra
.11002 .41178 .10542 .41569 .11029 .41988 .11488 .41598 Mtetra
.702 .646 .791 r
.10515 .40757 .10055 .41149 .10542 .41569 .11002 .41178 Mtetra
.10027 .40335 .09567 .40728 .10055 .41149 .10515 .40757 Mtetra
.701 .646 .791 r
.09538 .39913 .09079 .40306 .09567 .40728 .10027 .40335 Mtetra
.09049 .3949 .08589 .39883 .09079 .40306 .09538 .39913 Mtetra
.702 .646 .791 r
.08558 .39066 .08099 .39461 .08589 .39883 .09049 .3949 Mtetra
.08067 .38642 .07608 .39038 .08099 .39461 .08558 .39066 Mtetra
.703 .647 .791 r
.07575 .38219 .07115 .38616 .07608 .39038 .08067 .38642 Mtetra
.52704 .76494 .52247 .76836 .52669 .77198 .53126 .76857 Mtetra
.704 .648 .791 r
.52282 .76132 .51824 .76476 .52247 .76836 .52704 .76494 Mtetra
.706 .649 .79 r
.51859 .75773 .51401 .76122 .51824 .76476 .52282 .76132 Mtetra
.712 .652 .789 r
.51435 .75419 .50978 .75779 .51401 .76122 .51859 .75773 Mtetra
.722 .66 .788 r
.51011 .75079 .50553 .75459 .50978 .75779 .51435 .75419 Mtetra
.742 .674 .785 r
.50586 .74767 .50128 .75185 .50553 .75459 .51011 .75079 Mtetra
.777 .699 .777 r
.5016 .7451 .49702 .75002 .50128 .75185 .50586 .74767 Mtetra
.836 .738 .756 r
.49733 .7436 .49273 .74999 .49702 .75002 .5016 .7451 Mtetra
.915 .789 .707 r
.49304 .74422 .48841 .75339 .49273 .74999 .49733 .7436 Mtetra
.983 .83 .614 r
.4887 .74882 .48401 .76291 .48841 .75339 .49304 .74422 Mtetra
.995 .835 .477 r
.48427 .76039 .47946 .78201 .48401 .76291 .4887 .74882 Mtetra
.903 .783 .297 r
.47968 .78229 .47469 .81219 .47946 .78201 .48427 .76039 Mtetra
0 0 0 r
.47487 .8145 .46974 .84557 .47469 .81219 .47968 .78229 Mtetra
.062 0 .269 r
.46993 .84564 .46491 .86106 .46974 .84557 .47487 .8145 Mtetra
.683 .322 .356 r
.4652 .85324 .46057 .84306 .46491 .86106 .46993 .84564 Mtetra
0 0 .162 r
.46098 .82779 .4567 .80342 .46057 .84306 .4652 .85324 Mtetra
0 0 .413 r
.45715 .78655 .45294 .76438 .4567 .80342 .46098 .82779 Mtetra
.166 .06 .479 r
.45335 .74984 .44907 .73603 .45294 .76438 .45715 .78655 Mtetra
.285 .164 .535 r
.44942 .72433 .44504 .71782 .44907 .73603 .45335 .74984 Mtetra
.392 .276 .6 r
.44534 .70813 .44087 .70628 .44504 .71782 .44942 .72433 Mtetra
.497 .394 .668 r
.44114 .69778 .43662 .69855 .44087 .70628 .44534 .70813 Mtetra
.583 .497 .723 r
.43687 .69071 .43232 .69288 .43662 .69855 .44114 .69778 Mtetra
.643 .57 .758 r
.43255 .6854 .42798 .68832 .43232 .69288 .43687 .69071 Mtetra
.681 .618 .778 r
.42819 .68108 .42361 .68441 .42798 .68832 .43255 .6854 Mtetra
.707 .651 .791 r
.42381 .67738 .41922 .68099 .42361 .68441 .42819 .68108 Mtetra
.731 .68 .8 r
.4194 .67422 .4148 .6781 .41922 .68099 .42381 .67738 Mtetra
.76 .715 .81 r
.41496 .67168 .41034 .67589 .4148 .6781 .4194 .67422 Mtetra
.8 .765 .821 r
.41047 .67001 .40583 .67465 .41034 .67589 .41496 .67168 Mtetra
.853 .836 .828 r
.40591 .6696 .40123 .67486 .40583 .67465 .41047 .67001 Mtetra
.91 .923 .812 r
.40125 .67099 .39651 .6771 .40123 .67486 .40591 .6696 Mtetra
.916 .979 .728 r
.39644 .67478 .39163 .68192 .39651 .6771 .40125 .67099 Mtetra
.806 .928 .552 r
.39146 .68126 .38658 .68935 .39163 .68192 .39644 .67478 Mtetra
.633 .807 .378 r
.38633 .68982 .38139 .69824 .38658 .68935 .39146 .68126 Mtetra
0 0 0 r
.38114 .69823 .37622 .70569 .38139 .69824 .38633 .68982 Mtetra
.62 .902 .603 r
.37611 .70272 .37131 .70771 .37622 .70569 .38114 .69823 Mtetra
.622 .712 .91 r
.37146 .69983 .36684 .70174 .37131 .70771 .37611 .70272 Mtetra
.416 .345 .669 r
.36728 .68912 .36282 .68873 .36684 .70174 .37146 .69983 Mtetra
.388 .271 .598 r
.36342 .67352 .35904 .67235 .36282 .68873 .36728 .68912 Mtetra
.406 .275 .588 r
.35966 .65699 .35529 .65626 .35904 .67235 .36342 .67352 Mtetra
.442 .309 .604 r
.35583 .64221 .35142 .64243 .35529 .65626 .35966 .65699 Mtetra
.487 .362 .635 r
.35186 .6301 .34741 .6313 .35142 .64243 .35583 .64221 Mtetra
.537 .422 .67 r
.34774 .62047 .34325 .62249 .34741 .6313 .35186 .6301 Mtetra
.584 .482 .705 r
.3435 .61279 .33897 .61539 .34325 .62249 .34774 .62047 Mtetra
.621 .533 .733 r
.33916 .60647 .33461 .60946 .33897 .61539 .3435 .61279 Mtetra
.649 .571 .754 r
.33476 .60105 .33019 .60427 .33461 .60946 .33916 .60647 Mtetra
.667 .598 .768 r
.33031 .5962 .32574 .59957 .33019 .60427 .33476 .60105 Mtetra
.68 .615 .776 r
.32583 .59169 .32125 .59518 .32574 .59957 .33031 .5962 Mtetra
.689 .627 .781 r
.32132 .58741 .31674 .59098 .32125 .59518 .32583 .59169 Mtetra
.694 .634 .785 r
.3168 .58326 .31221 .58687 .31674 .59098 .32132 .58741 Mtetra
.696 .639 .788 r
.31226 .57919 .30767 .58281 .31221 .58687 .3168 .58326 Mtetra
.698 .642 .789 r
.30771 .57517 .30312 .5788 .30767 .58281 .31226 .57919 Mtetra
.699 .643 .79 r
.30316 .57117 .29856 .57483 .30312 .5788 .30771 .57517 Mtetra
.7 .644 .79 r
.29859 .56719 .294 .57086 .29856 .57483 .30316 .57117 Mtetra
.701 .644 .79 r
.29402 .5632 .28942 .56689 .294 .57086 .29859 .56719 Mtetra
.701 .645 .79 r
.28943 .55922 .28484 .56291 .28942 .56689 .29402 .5632 Mtetra
.701 .646 .791 r
.28484 .55524 .28025 .55893 .28484 .56291 .28943 .55922 Mtetra
.28024 .55126 .27565 .55496 .28025 .55893 .28484 .55524 Mtetra
.27564 .54728 .27105 .55098 .27565 .55496 .28024 .55126 Mtetra
.701 .645 .79 r
.27103 .54327 .26643 .54699 .27105 .55098 .27564 .54728 Mtetra
.702 .646 .791 r
.26641 .53927 .26181 .543 .26643 .54699 .27103 .54327 Mtetra
.701 .646 .791 r
.26178 .53527 .25719 .53899 .26181 .543 .26641 .53927 Mtetra
.25715 .53126 .25255 .53498 .25719 .53899 .26178 .53527 Mtetra
.2525 .52724 .24791 .53097 .25255 .53498 .25715 .53126 Mtetra
.701 .645 .79 r
.24786 .52321 .24326 .52696 .24791 .53097 .2525 .52724 Mtetra
.702 .646 .79 r
.2432 .51918 .2386 .52294 .24326 .52696 .24786 .52321 Mtetra
.702 .646 .791 r
.23854 .51514 .23394 .5189 .2386 .52294 .2432 .51918 Mtetra
.701 .646 .791 r
.23386 .5111 .22927 .51486 .23394 .5189 .23854 .51514 Mtetra
.22918 .50705 .22459 .51081 .22927 .51486 .23386 .5111 Mtetra
.2245 .50299 .2199 .50676 .22459 .51081 .22918 .50705 Mtetra
.702 .646 .79 r
.21981 .49893 .21521 .50271 .2199 .50676 .2245 .50299 Mtetra
.702 .646 .791 r
.2151 .49486 .21051 .49865 .21521 .50271 .21981 .49893 Mtetra
.701 .646 .791 r
.2104 .49078 .2058 .49457 .21051 .49865 .2151 .49486 Mtetra
.20568 .4867 .20108 .49049 .2058 .49457 .2104 .49078 Mtetra
.20095 .48261 .19636 .48641 .20108 .49049 .20568 .4867 Mtetra
.701 .645 .79 r
.19622 .47851 .19162 .48232 .19636 .48641 .20095 .48261 Mtetra
.702 .646 .791 r
.19149 .47441 .18689 .47823 .19162 .48232 .19622 .47851 Mtetra
.701 .646 .791 r
.18674 .4703 .18214 .47412 .18689 .47823 .19149 .47441 Mtetra
.18198 .46619 .17739 .47001 .18214 .47412 .18674 .4703 Mtetra
.17722 .46207 .17262 .46589 .17739 .47001 .18198 .46619 Mtetra
.701 .645 .791 r
.17245 .45793 .16785 .46177 .17262 .46589 .17722 .46207 Mtetra
.702 .646 .791 r
.16768 .4538 .16308 .45765 .16785 .46177 .17245 .45793 Mtetra
.701 .646 .791 r
.16289 .44965 .15829 .45351 .16308 .45765 .16768 .4538 Mtetra
.1581 .44551 .1535 .44936 .15829 .45351 .16289 .44965 Mtetra
.1533 .44135 .1487 .44521 .1535 .44936 .1581 .44551 Mtetra
.14849 .43719 .14389 .44106 .1487 .44521 .1533 .44135 Mtetra
.702 .646 .791 r
.14368 .43302 .13907 .4369 .14389 .44106 .14849 .43719 Mtetra
.13885 .42884 .13425 .43273 .13907 .4369 .14368 .43302 Mtetra
.701 .646 .791 r
.13402 .42466 .12942 .42855 .13425 .43273 .13885 .42884 Mtetra
.12918 .42047 .12458 .42437 .12942 .42855 .13402 .42466 Mtetra
.12434 .41628 .11973 .42018 .12458 .42437 .12918 .42047 Mtetra
.702 .646 .791 r
.11948 .41207 .11488 .41598 .11973 .42018 .12434 .41628 Mtetra
.701 .646 .791 r
.11462 .40787 .11002 .41178 .11488 .41598 .11948 .41207 Mtetra
.10975 .40365 .10515 .40757 .11002 .41178 .11462 .40787 Mtetra
.10487 .39942 .10027 .40335 .10515 .40757 .10975 .40365 Mtetra
.702 .646 .791 r
.09998 .39519 .09538 .39913 .10027 .40335 .10487 .39942 Mtetra
.09509 .39096 .09049 .3949 .09538 .39913 .09998 .39519 Mtetra
.701 .646 .791 r
.09018 .38672 .08558 .39066 .09049 .3949 .09509 .39096 Mtetra
.702 .646 .79 r
.08527 .38246 .08067 .38642 .08558 .39066 .09018 .38672 Mtetra
.08036 .37821 .07575 .38219 .08067 .38642 .08527 .38246 Mtetra
.53162 .76152 .52704 .76494 .53126 .76857 .53584 .76518 Mtetra
.703 .647 .79 r
.5274 .75788 .52282 .76132 .52704 .76494 .53162 .76152 Mtetra
.705 .648 .791 r
.52317 .75426 .51859 .75773 .52282 .76132 .5274 .75788 Mtetra
.707 .65 .791 r
.51893 .75067 .51435 .75419 .51859 .75773 .52317 .75426 Mtetra
.713 .654 .789 r
.51469 .74715 .51011 .75079 .51435 .75419 .51893 .75067 Mtetra
.726 .662 .787 r
.51044 .74379 .50586 .74767 .51011 .75079 .51469 .74715 Mtetra
.749 .679 .783 r
.50619 .74076 .5016 .7451 .50586 .74767 .51044 .74379 Mtetra
.79 .707 .773 r
.50192 .73838 .49733 .7436 .5016 .7451 .50619 .74076 Mtetra
.855 .751 .747 r
.49765 .73728 .49304 .74422 .49733 .7436 .50192 .73838 Mtetra
.935 .802 .688 r
.49334 .73867 .4887 .74882 .49304 .74422 .49765 .73728 Mtetra
.993 .835 .583 r
.48899 .74467 .48427 .76039 .4887 .74882 .49334 .73867 Mtetra
.984 .829 .436 r
.48453 .75849 .47968 .78229 .48427 .76039 .48899 .74467 Mtetra
.85 .753 .238 r
.4799 .78322 .47487 .8145 .47968 .78229 .48453 .75849 Mtetra
0 0 .057 r
.47506 .81677 .46993 .84564 .47487 .8145 .4799 .78322 Mtetra
.22 0 .314 r
.47014 .84412 .4652 .85324 .46993 .84564 .47506 .81677 Mtetra
.834 .441 .306 r
.46553 .84317 .46098 .82779 .4652 .85324 .47014 .84412 Mtetra
0 0 .277 r
.46141 .81152 .45715 .78655 .46098 .82779 .46553 .84317 Mtetra
.031 0 .434 r
.45759 .77005 .45335 .74984 .45715 .78655 .46141 .81152 Mtetra
.198 .086 .492 r
.45375 .73605 .44942 .72433 .45335 .74984 .45759 .77005 Mtetra
.311 .191 .55 r
.44976 .71321 .44534 .70813 .44942 .72433 .45375 .73605 Mtetra
.419 .305 .618 r
.44563 .6988 .44114 .69778 .44534 .70813 .44976 .71321 Mtetra
.521 .422 .684 r
.44141 .68948 .43687 .69071 .44114 .69778 .44563 .6988 Mtetra
.601 .519 .734 r
.43711 .68298 .43255 .6854 .43687 .69071 .44141 .68948 Mtetra
.656 .586 .765 r
.43277 .67801 .42819 .68108 .43255 .6854 .43711 .68298 Mtetra
.691 .631 .783 r
.42841 .67392 .42381 .67738 .42819 .68108 .43277 .67801 Mtetra
.719 .664 .795 r
.42401 .67046 .4194 .67422 .42381 .67738 .42841 .67392 Mtetra
.747 .698 .806 r
.41958 .66762 .41496 .67168 .4194 .67422 .42401 .67046 Mtetra
.783 .743 .817 r
.41511 .66556 .41047 .67001 .41496 .67168 .41958 .66762 Mtetra
.832 .807 .827 r
.41058 .66461 .40591 .6696 .41047 .67001 .41511 .66556 Mtetra
.89 .89 .823 r
.40597 .66523 .40125 .67099 .40591 .6696 .41058 .66461 Mtetra
.926 .966 .771 r
.40123 .66803 .39644 .67478 .40125 .67099 .40597 .66523 Mtetra
.862 .961 .626 r
.39632 .67348 .39146 .68126 .39644 .67478 .40123 .66803 Mtetra
.695 .851 .433 r
.39125 .68141 .38633 .68982 .39146 .68126 .39632 .67348 Mtetra
0 0 0 r
.38608 .69025 .38114 .69823 .38633 .68982 .39125 .68141 Mtetra
.38097 .69665 .37611 .70272 .38114 .69823 .38608 .69025 Mtetra
.734 .94 .953 r
.37616 .69676 .37146 .69983 .37611 .70272 .38097 .69665 Mtetra
.461 .425 .732 r
.3718 .68879 .36728 .68912 .37146 .69983 .37616 .69676 Mtetra
.389 .284 .614 r
.36783 .67457 .36342 .67352 .36728 .68912 .3718 .68879 Mtetra
.395 .268 .587 r
.36404 .65799 .35966 .65699 .36342 .67352 .36783 .67457 Mtetra
.427 .294 .596 r
.36023 .64236 .35583 .64221 .35966 .65699 .36404 .65799 Mtetra
.47 .341 .622 r
.35631 .62921 .35186 .6301 .35583 .64221 .36023 .64236 Mtetra
.519 .4 .657 r
.35223 .61872 .34774 .62047 .35186 .6301 .35631 .62921 Mtetra
.566 .46 .693 r
.34802 .61039 .3435 .61279 .34774 .62047 .35223 .61872 Mtetra
.608 .515 .724 r
.34371 .60362 .33916 .60647 .3435 .61279 .34802 .61039 Mtetra
.639 .558 .747 r
.33933 .5979 .33476 .60105 .33916 .60647 .34371 .60362 Mtetra
.662 .589 .763 r
.33489 .59285 .33031 .5962 .33476 .60105 .33933 .5979 Mtetra
.677 .609 .773 r
.33041 .58822 .32583 .59169 .33031 .5962 .33489 .59285 Mtetra
.686 .623 .78 r
.32591 .58386 .32132 .58741 .32583 .59169 .33041 .58822 Mtetra
.692 .632 .785 r
.32139 .57967 .3168 .58326 .32132 .58741 .32591 .58386 Mtetra
.695 .637 .787 r
.31686 .57558 .31226 .57919 .3168 .58326 .32139 .57967 Mtetra
.698 .64 .788 r
.31231 .57152 .30771 .57517 .31226 .57919 .31686 .57558 Mtetra
.699 .642 .789 r
.30776 .5675 .30316 .57117 .30771 .57517 .31231 .57152 Mtetra
.701 .644 .79 r
.30319 .5635 .29859 .56719 .30316 .57117 .30776 .5675 Mtetra
.701 .645 .791 r
.29862 .55952 .29402 .5632 .29859 .56719 .30319 .5635 Mtetra
.29403 .55554 .28943 .55922 .29402 .5632 .29862 .55952 Mtetra
.28944 .55155 .28484 .55524 .28943 .55922 .29403 .55554 Mtetra
.701 .645 .79 r
.28485 .54755 .28024 .55126 .28484 .55524 .28944 .55155 Mtetra
.702 .645 .79 r
.28024 .54355 .27564 .54728 .28024 .55126 .28485 .54755 Mtetra
.701 .646 .791 r
.27563 .53955 .27103 .54327 .27564 .54728 .28024 .54355 Mtetra
.27101 .53555 .26641 .53927 .27103 .54327 .27563 .53955 Mtetra
.26638 .53154 .26178 .53527 .26641 .53927 .27101 .53555 Mtetra
.701 .645 .79 r
.26175 .52752 .25715 .53126 .26178 .53527 .26638 .53154 Mtetra
.702 .646 .79 r
.25711 .52349 .2525 .52724 .25715 .53126 .26175 .52752 Mtetra
.701 .646 .791 r
.25246 .51946 .24786 .52321 .2525 .52724 .25711 .52349 Mtetra
.2478 .51542 .2432 .51918 .24786 .52321 .25246 .51946 Mtetra
.24314 .51139 .23854 .51514 .2432 .51918 .2478 .51542 Mtetra
.701 .645 .791 r
.23847 .50733 .23386 .5111 .23854 .51514 .24314 .51139 Mtetra
.702 .646 .791 r
.23379 .50327 .22918 .50705 .23386 .5111 .23847 .50733 Mtetra
.2291 .49921 .2245 .50299 .22918 .50705 .23379 .50327 Mtetra
.701 .646 .791 r
.22441 .49514 .21981 .49893 .2245 .50299 .2291 .49921 Mtetra
.21971 .49107 .2151 .49486 .21981 .49893 .22441 .49514 Mtetra
.701 .645 .791 r
.215 .48699 .2104 .49078 .2151 .49486 .21971 .49107 Mtetra
.702 .646 .791 r
.21028 .48289 .20568 .4867 .2104 .49078 .215 .48699 Mtetra
.20556 .4788 .20095 .48261 .20568 .4867 .21028 .48289 Mtetra
.701 .646 .791 r
.20083 .4747 .19622 .47851 .20095 .48261 .20556 .4788 Mtetra
.19609 .47059 .19149 .47441 .19622 .47851 .20083 .4747 Mtetra
.701 .645 .791 r
.19134 .46647 .18674 .4703 .19149 .47441 .19609 .47059 Mtetra
.702 .646 .791 r
.18659 .46235 .18198 .46619 .18674 .4703 .19134 .46647 Mtetra
.18183 .45822 .17722 .46207 .18198 .46619 .18659 .46235 Mtetra
.701 .646 .791 r
.17706 .45409 .17245 .45793 .17722 .46207 .18183 .45822 Mtetra
.17228 .44994 .16768 .4538 .17245 .45793 .17706 .45409 Mtetra
.1675 .4458 .16289 .44965 .16768 .4538 .17228 .44994 Mtetra
.702 .646 .791 r
.16271 .44164 .1581 .44551 .16289 .44965 .1675 .4458 Mtetra
.701 .646 .791 r
.15791 .43748 .1533 .44135 .1581 .44551 .16271 .44164 Mtetra
.1531 .43331 .14849 .43719 .1533 .44135 .15791 .43748 Mtetra
.14828 .42914 .14368 .43302 .14849 .43719 .1531 .43331 Mtetra
.14346 .42495 .13885 .42884 .14368 .43302 .14828 .42914 Mtetra
.13863 .42077 .13402 .42466 .13885 .42884 .14346 .42495 Mtetra
.13379 .41657 .12918 .42047 .13402 .42466 .13863 .42077 Mtetra
.701 .645 .791 r
.12894 .41237 .12434 .41628 .12918 .42047 .13379 .41657 Mtetra
.701 .646 .791 r
.12409 .40816 .11948 .41207 .12434 .41628 .12894 .41237 Mtetra
.702 .646 .791 r
.11923 .40394 .11462 .40787 .11948 .41207 .12409 .40816 Mtetra
.701 .646 .791 r
.11435 .39972 .10975 .40365 .11462 .40787 .11923 .40394 Mtetra
.10948 .39549 .10487 .39942 .10975 .40365 .11435 .39972 Mtetra
.701 .645 .791 r
.10459 .39125 .09998 .39519 .10487 .39942 .10948 .39549 Mtetra
.702 .646 .791 r
.0997 .38701 .09509 .39096 .09998 .39519 .10459 .39125 Mtetra
.09479 .38276 .09018 .38672 .09509 .39096 .0997 .38701 Mtetra
.701 .646 .791 r
.08988 .37851 .08527 .38246 .09018 .38672 .09479 .38276 Mtetra
.08496 .37425 .08036 .37821 .08527 .38246 .08988 .37851 Mtetra
.702 .646 .791 r
.53621 .75812 .53162 .76152 .53584 .76518 .54043 .76177 Mtetra
.53199 .75446 .5274 .75788 .53162 .76152 .53621 .75812 Mtetra
.703 .647 .79 r
.52776 .75081 .52317 .75426 .5274 .75788 .53199 .75446 Mtetra
.705 .648 .79 r
.52352 .74718 .51893 .75067 .52317 .75426 .52776 .75081 Mtetra
.709 .651 .79 r
.51928 .74359 .51469 .74715 .51893 .75067 .52352 .74718 Mtetra
.716 .656 .789 r
.51503 .7401 .51044 .74379 .51469 .74715 .51928 .74359 Mtetra
.73 .666 .787 r
.51078 .73679 .50619 .74076 .51044 .74379 .51503 .7401 Mtetra
.757 .684 .781 r
.50652 .73387 .50192 .73838 .50619 .74076 .51078 .73679 Mtetra
.804 .716 .768 r
.50225 .73172 .49765 .73728 .50192 .73838 .50652 .73387 Mtetra
.875 .764 .736 r
.49796 .73109 .49334 .73867 .49765 .73728 .50225 .73172 Mtetra
.954 .813 .666 r
.49365 .73337 .48899 .74467 .49334 .73867 .49796 .73109 Mtetra
.998 .838 .549 r
.48928 .74097 .48453 .75849 .48899 .74467 .49365 .73337 Mtetra
.966 .818 .392 r
.48479 .75727 .4799 .78322 .48453 .75849 .48928 .74097 Mtetra
.779 .71 .173 r
.48012 .78473 .47506 .81677 .4799 .78322 .48479 .75727 Mtetra
0 0 .135 r
.47525 .81865 .47014 .84412 .47506 .81677 .48012 .78473 Mtetra
.372 .086 .344 r
.47038 .84067 .46553 .84317 .47014 .84412 .47525 .81865 Mtetra
.925 .535 .187 r
.46588 .83103 .46141 .81152 .46553 .84317 .47038 .84067 Mtetra
0 0 .344 r
.46185 .79469 .45759 .77005 .46141 .81152 .46588 .83103 Mtetra
.084 0 .45 r
.45802 .7541 .45375 .73605 .45759 .77005 .46185 .79469 Mtetra
.228 .112 .505 r
.45412 .72298 .44976 .71321 .45375 .73605 .45802 .7541 Mtetra
.337 .218 .566 r
.45009 .70262 .44563 .6988 .44976 .71321 .45412 .72298 Mtetra
.445 .335 .635 r
.44592 .68978 .44141 .68948 .44563 .6988 .45009 .70262 Mtetra
.544 .45 .698 r
.44166 .68135 .43711 .68298 .44141 .68948 .44592 .68978 Mtetra
.619 .54 .743 r
.43735 .67534 .43277 .67801 .43711 .68298 .44166 .68135 Mtetra
.669 .602 .771 r
.433 .67069 .42841 .67392 .43277 .67801 .43735 .67534 Mtetra
.703 .645 .789 r
.42861 .66687 .42401 .67046 .42841 .67392 .433 .67069 Mtetra
.732 .682 .801 r
.4242 .66372 .41958 .66762 .42401 .67046 .42861 .66687 Mtetra
.766 .722 .812 r
.41975 .66128 .41511 .66556 .41958 .66762 .4242 .66372 Mtetra
.811 .778 .822 r
.41525 .65982 .41058 .66461 .41511 .66556 .41975 .66128 Mtetra
.868 .856 .827 r
.41067 .65977 .40597 .66523 .41058 .66461 .41525 .65982 Mtetra
.919 .943 .8 r
.40598 .66168 .40123 .66803 .40597 .66523 .41067 .65977 Mtetra
.9 .978 .691 r
.40115 .66609 .39632 .67348 .40123 .66803 .40598 .66168 Mtetra
.763 .899 .503 r
.39616 .67315 .39125 .68141 .39632 .67348 .40115 .66609 Mtetra
0 0 0 r
.39102 .68191 .38608 .69025 .39125 .68141 .39616 .67315 Mtetra
.38588 .68968 .38097 .69665 .38608 .69025 .39102 .68191 Mtetra
.694 .973 .768 r
.38094 .69253 .37616 .69676 .38097 .69665 .38588 .68968 Mtetra
.542 .568 .831 r
.3764 .68757 .3718 .68879 .37616 .69676 .38094 .69253 Mtetra
.401 .313 .641 r
.37229 .67528 .36783 .67457 .3718 .68879 .3764 .68757 Mtetra
.39 .268 .592 r
.36844 .65911 .36404 .65799 .36783 .67457 .37229 .67528 Mtetra
.414 .281 .59 r
.36464 .64285 .36023 .64236 .36404 .65799 .36844 .65911 Mtetra
.453 .321 .611 r
.36075 .62871 .35631 .62921 .36023 .64236 .36464 .64285 Mtetra
.5 .376 .644 r
.35671 .61727 .35223 .61872 .35631 .62921 .36075 .62871 Mtetra
.549 .438 .68 r
.35254 .6082 .34802 .61039 .35223 .61872 .35671 .61727 Mtetra
.594 .496 .712 r
.34826 .6009 .34371 .60362 .34802 .61039 .35254 .6082 Mtetra
.629 .543 .739 r
.34389 .59482 .33933 .5979 .34371 .60362 .34826 .6009 Mtetra
.655 .579 .758 r
.33947 .58955 .33489 .59285 .33933 .5979 .34389 .59482 Mtetra
.671 .603 .771 r
.335 .5848 .33041 .58822 .33489 .59285 .33947 .58955 Mtetra
.682 .619 .778 r
.33051 .58035 .32591 .58386 .33041 .58822 .335 .5848 Mtetra
.69 .629 .783 r
.32599 .57609 .32139 .57967 .32591 .58386 .33051 .58035 Mtetra
.695 .635 .785 r
.32146 .57194 .31686 .57558 .32139 .57967 .32599 .57609 Mtetra
.697 .639 .788 r
.31692 .56787 .31231 .57152 .31686 .57558 .32146 .57194 Mtetra
.699 .642 .789 r
.31236 .56384 .30776 .5675 .31231 .57152 .31692 .56787 Mtetra
.699 .644 .79 r
.3078 .55984 .30319 .5635 .30776 .5675 .31236 .56384 Mtetra
.7 .644 .79 r
.30322 .55584 .29862 .55952 .30319 .5635 .3078 .55984 Mtetra
.701 .644 .79 r
.29864 .55183 .29403 .55554 .29862 .55952 .30322 .55584 Mtetra
.701 .645 .79 r
.29405 .54783 .28944 .55155 .29403 .55554 .29864 .55183 Mtetra
.701 .646 .791 r
.28946 .54384 .28485 .54755 .28944 .55155 .29405 .54783 Mtetra
.28485 .53984 .28024 .54355 .28485 .54755 .28946 .54384 Mtetra
.28024 .53584 .27563 .53955 .28024 .54355 .28485 .53984 Mtetra
.701 .645 .79 r
.27562 .53182 .27101 .53555 .27563 .53955 .28024 .53584 Mtetra
.702 .646 .791 r
.27099 .5278 .26638 .53154 .27101 .53555 .27562 .53182 Mtetra
.26636 .52377 .26175 .52752 .26638 .53154 .27099 .5278 Mtetra
.701 .646 .791 r
.26172 .51975 .25711 .52349 .26175 .52752 .26636 .52377 Mtetra
.25707 .51571 .25246 .51946 .25711 .52349 .26172 .51975 Mtetra
.701 .645 .791 r
.25241 .51166 .2478 .51542 .25246 .51946 .25707 .51571 Mtetra
.702 .646 .791 r
.24775 .50761 .24314 .51139 .2478 .51542 .25241 .51166 Mtetra
.24308 .50356 .23847 .50733 .24314 .51139 .24775 .50761 Mtetra
.701 .646 .791 r
.2384 .4995 .23379 .50327 .23847 .50733 .24308 .50356 Mtetra
.23371 .49543 .2291 .49921 .23379 .50327 .2384 .4995 Mtetra
.22902 .49135 .22441 .49514 .2291 .49921 .23371 .49543 Mtetra
.702 .646 .791 r
.22432 .48727 .21971 .49107 .22441 .49514 .22902 .49135 Mtetra
.21961 .48318 .215 .48699 .21971 .49107 .22432 .48727 Mtetra
.701 .646 .791 r
.2149 .47909 .21028 .48289 .215 .48699 .21961 .48318 Mtetra
.21017 .47498 .20556 .4788 .21028 .48289 .2149 .47909 Mtetra
.702 .646 .791 r
.20544 .47088 .20083 .4747 .20556 .4788 .21017 .47498 Mtetra
.2007 .46676 .19609 .47059 .20083 .4747 .20544 .47088 Mtetra
.701 .646 .791 r
.19596 .46264 .19134 .46647 .19609 .47059 .2007 .46676 Mtetra
.701 .645 .791 r
.1912 .45851 .18659 .46235 .19134 .46647 .19596 .46264 Mtetra
.701 .646 .791 r
.18644 .45438 .18183 .45822 .18659 .46235 .1912 .45851 Mtetra
.702 .646 .791 r
.18167 .45024 .17706 .45409 .18183 .45822 .18644 .45438 Mtetra
.701 .646 .791 r
.1769 .44609 .17228 .44994 .17706 .45409 .18167 .45024 Mtetra
.17211 .44194 .1675 .4458 .17228 .44994 .1769 .44609 Mtetra
.701 .645 .791 r
.16732 .43777 .16271 .44164 .1675 .4458 .17211 .44194 Mtetra
.702 .646 .791 r
.16252 .4336 .15791 .43748 .16271 .44164 .16732 .43777 Mtetra
.15771 .42943 .1531 .43331 .15791 .43748 .16252 .4336 Mtetra
.701 .646 .791 r
.1529 .42525 .14828 .42914 .1531 .43331 .15771 .42943 Mtetra
.701 .645 .791 r
.14807 .42106 .14346 .42495 .14828 .42914 .1529 .42525 Mtetra
.701 .646 .791 r
.14324 .41686 .13863 .42077 .14346 .42495 .14807 .42106 Mtetra
.702 .646 .791 r
.1384 .41266 .13379 .41657 .13863 .42077 .14324 .41686 Mtetra
.701 .646 .791 r
.13356 .40846 .12894 .41237 .13379 .41657 .1384 .41266 Mtetra
.1287 .40424 .12409 .40816 .12894 .41237 .13356 .40846 Mtetra
.701 .645 .791 r
.12384 .40002 .11923 .40394 .12409 .40816 .1287 .40424 Mtetra
.702 .646 .791 r
.11897 .39579 .11435 .39972 .11923 .40394 .12384 .40002 Mtetra
.11409 .39155 .10948 .39549 .11435 .39972 .11897 .39579 Mtetra
.701 .646 .791 r
.1092 .38731 .10459 .39125 .10948 .39549 .11409 .39155 Mtetra
.10431 .38306 .0997 .38701 .10459 .39125 .1092 .38731 Mtetra
.701 .645 .791 r
.09941 .3788 .09479 .38276 .0997 .38701 .10431 .38306 Mtetra
.702 .646 .79 r
.0945 .37454 .08988 .37851 .09479 .38276 .09941 .3788 Mtetra
.702 .646 .791 r
.08958 .37027 .08496 .37425 .08988 .37851 .0945 .37454 Mtetra
.5408 .7547 .53621 .75812 .54043 .76177 .54502 .75836 Mtetra
.53658 .75103 .53199 .75446 .53621 .75812 .5408 .7547 Mtetra
.53235 .74737 .52776 .75081 .53199 .75446 .53658 .75103 Mtetra
.704 .647 .791 r
.52812 .74371 .52352 .74718 .52776 .75081 .53235 .74737 Mtetra
.706 .649 .79 r
.52388 .74008 .51928 .74359 .52352 .74718 .52812 .74371 Mtetra
.71 .652 .79 r
.51963 .73651 .51503 .7401 .51928 .74359 .52388 .74008 Mtetra
.719 .658 .788 r
.51538 .73304 .51078 .73679 .51503 .7401 .51963 .73651 Mtetra
.735 .669 .786 r
.51112 .72979 .50652 .73387 .51078 .73679 .51538 .73304 Mtetra
.767 .691 .779 r
.50685 .72701 .50225 .73172 .50652 .73387 .51112 .72979 Mtetra
.82 .727 .763 r
.50257 .72514 .49796 .73109 .50225 .73172 .50685 .72701 Mtetra
.895 .777 .723 r
.49828 .72506 .49365 .73337 .49796 .73109 .50257 .72514 Mtetra
.97 .823 .641 r
.49395 .72838 .48928 .74097 .49365 .73337 .49828 .72506 Mtetra
.999 .838 .513 r
.48956 .73778 .48479 .75727 .48928 .74097 .49395 .72838 Mtetra
.939 .803 .345 r
.48505 .75673 .48012 .78473 .48479 .75727 .48956 .73778 Mtetra
0 0 0 r
.48034 .78667 .47525 .81865 .48012 .78473 .48505 .75673 Mtetra
0 0 .205 r
.47546 .81977 .47038 .84067 .47525 .81865 .48034 .78667 Mtetra
.524 .198 .357 r
.47066 .83505 .46588 .83103 .47038 .84067 .47546 .81977 Mtetra
.846 .531 0 r
.46627 .8171 .46185 .79469 .46588 .83103 .47066 .83505 Mtetra
0 0 .385 r
.46229 .77767 .45802 .7541 .46185 .79469 .46627 .8171 Mtetra
.127 .029 .464 r
.45843 .73882 .45412 .72298 .45802 .7541 .46229 .77767 Mtetra
.256 .137 .519 r
.45449 .71061 .45009 .70262 .45412 .72298 .45843 .73882 Mtetra
.365 .246 .583 r
.4504 .69248 .44592 .68978 .45009 .70262 .45449 .71061 Mtetra
.472 .366 .652 r
.4462 .68102 .44166 .68135 .44592 .68978 .4504 .69248 Mtetra
.566 .476 .713 r
.44192 .67338 .43735 .67534 .44166 .68135 .4462 .68102 Mtetra
.635 .56 .753 r
.43759 .66784 .433 .67069 .43735 .67534 .44192 .67338 Mtetra
.682 .618 .778 r
.43322 .66349 .42861 .66687 .433 .67069 .43759 .66784 Mtetra
.717 .661 .793 r
.42882 .65995 .4242 .66372 .42861 .66687 .43322 .66349 Mtetra
.75 .702 .806 r
.42438 .65716 .41975 .66128 .4242 .66372 .42882 .65995 Mtetra
.791 .754 .819 r
.4199 .65526 .41525 .65982 .41975 .66128 .42438 .65716 Mtetra
.845 .825 .828 r
.41536 .6546 .41067 .65977 .41525 .65982 .4199 .65526 Mtetra
.904 .912 .817 r
.41072 .65569 .40598 .66168 .41067 .65977 .41536 .6546 Mtetra
.922 .976 .744 r
.40596 .65908 .40115 .66609 .40598 .66168 .41072 .65569 Mtetra
.828 .941 .578 r
.40104 .66515 .39616 .67315 .40115 .66609 .40596 .65908 Mtetra
.653 .821 .395 r
.39596 .67347 .39102 .68191 .39616 .67315 .40104 .66515 Mtetra
0 0 0 r
.39081 .68203 .38588 .68968 .39102 .68191 .39596 .67347 Mtetra
.59 .867 .539 r
.38577 .68716 .38094 .69253 .38588 .68968 .39081 .68203 Mtetra
.668 .792 .941 r
.38107 .68525 .3764 .68757 .38094 .69253 .38577 .68716 Mtetra
.429 .367 .687 r
.3768 .67541 .37229 .67528 .3764 .68757 .38107 .68525 Mtetra
.387 .274 .602 r
.37286 .66023 .36844 .65911 .37229 .67528 .3768 .67541 Mtetra
.401 .272 .587 r
.36904 .64366 .36464 .64285 .36844 .65911 .37286 .66023 Mtetra
.436 .304 .601 r
.36518 .62859 .36075 .62871 .36464 .64285 .36904 .64366 Mtetra
.482 .355 .63 r
.36119 .61613 .35671 .61727 .36075 .62871 .36518 .62859 Mtetra
.531 .415 .666 r
.35706 .60623 .35254 .6082 .35671 .61727 .36119 .61613 Mtetra
.578 .475 .701 r
.35281 .59834 .34826 .6009 .35254 .6082 .35706 .60623 Mtetra
.616 .527 .73 r
.34846 .59187 .34389 .59482 .34826 .6009 .35281 .59834 Mtetra
.645 .567 .752 r
.34405 .58634 .33947 .58955 .34389 .59482 .34846 .59187 Mtetra
.666 .595 .766 r
.3396 .5814 .335 .5848 .33947 .58955 .34405 .58634 Mtetra
.679 .613 .775 r
.33511 .57683 .33051 .58035 .335 .5848 .3396 .5814 Mtetra
.688 .626 .781 r
.3306 .57251 .32599 .57609 .33051 .58035 .33511 .57683 Mtetra
.693 .634 .785 r
.32607 .56833 .32146 .57194 .32599 .57609 .3306 .57251 Mtetra
.696 .639 .788 r
.32153 .56424 .31692 .56787 .32146 .57194 .32607 .56833 Mtetra
.698 .641 .789 r
.31697 .56018 .31236 .56384 .31692 .56787 .32153 .56424 Mtetra
.7 .642 .789 r
.31241 .55614 .3078 .55984 .31236 .56384 .31697 .56018 Mtetra
.701 .644 .79 r
.30784 .55213 .30322 .55584 .3078 .55984 .31241 .55614 Mtetra
.701 .645 .791 r
.30326 .54813 .29864 .55183 .30322 .55584 .30784 .55213 Mtetra
.29867 .54414 .29405 .54783 .29864 .55183 .30326 .54813 Mtetra
.29407 .54013 .28946 .54384 .29405 .54783 .29867 .54414 Mtetra
.701 .645 .79 r
.28947 .53611 .28485 .53984 .28946 .54384 .29407 .54013 Mtetra
.702 .646 .79 r
.28486 .5321 .28024 .53584 .28485 .53984 .28947 .53611 Mtetra
.701 .646 .791 r
.28024 .52809 .27562 .53182 .28024 .53584 .28486 .5321 Mtetra
.27561 .52406 .27099 .5278 .27562 .53182 .28024 .52809 Mtetra
.701 .645 .791 r
.27098 .52003 .26636 .52377 .27099 .5278 .27561 .52406 Mtetra
.702 .646 .791 r
.26634 .51599 .26172 .51975 .26636 .52377 .27098 .52003 Mtetra
.26169 .51195 .25707 .51571 .26172 .51975 .26634 .51599 Mtetra
.701 .646 .791 r
.25703 .5079 .25241 .51166 .25707 .51571 .26169 .51195 Mtetra
.25237 .50384 .24775 .50761 .25241 .51166 .25703 .5079 Mtetra
.2477 .49978 .24308 .50356 .24775 .50761 .25237 .50384 Mtetra
.702 .646 .791 r
.24302 .49571 .2384 .4995 .24308 .50356 .2477 .49978 Mtetra
.23833 .49164 .23371 .49543 .2384 .4995 .24302 .49571 Mtetra
.701 .646 .791 r
.23364 .48756 .22902 .49135 .23371 .49543 .23833 .49164 Mtetra
.22894 .48347 .22432 .48727 .22902 .49135 .23364 .48756 Mtetra
.22423 .47937 .21961 .48318 .22432 .48727 .22894 .48347 Mtetra
.21952 .47527 .2149 .47909 .21961 .48318 .22423 .47937 Mtetra
.21479 .47117 .21017 .47498 .2149 .47909 .21952 .47527 Mtetra
.701 .645 .791 r
.21006 .46705 .20544 .47088 .21017 .47498 .21479 .47117 Mtetra
.702 .646 .791 r
.20532 .46293 .2007 .46676 .20544 .47088 .21006 .46705 Mtetra
.20058 .4588 .19596 .46264 .2007 .46676 .20532 .46293 Mtetra
.701 .646 .791 r
.19582 .45467 .1912 .45851 .19596 .46264 .20058 .4588 Mtetra
.19106 .45053 .18644 .45438 .1912 .45851 .19582 .45467 Mtetra
.701 .645 .791 r
.18629 .44638 .18167 .45024 .18644 .45438 .19106 .45053 Mtetra
.702 .646 .791 r
.18152 .44222 .1769 .44609 .18167 .45024 .18629 .44638 Mtetra
.17673 .43806 .17211 .44194 .1769 .44609 .18152 .44222 Mtetra
.701 .646 .791 r
.17194 .4339 .16732 .43777 .17211 .44194 .17673 .43806 Mtetra
.16714 .42972 .16252 .4336 .16732 .43777 .17194 .4339 Mtetra
.16233 .42554 .15771 .42943 .16252 .4336 .16714 .42972 Mtetra
.702 .646 .791 r
.15752 .42135 .1529 .42525 .15771 .42943 .16233 .42554 Mtetra
.15269 .41716 .14807 .42106 .1529 .42525 .15752 .42135 Mtetra
.701 .646 .791 r
.14786 .41296 .14324 .41686 .14807 .42106 .15269 .41716 Mtetra
.14302 .40875 .1384 .41266 .14324 .41686 .14786 .41296 Mtetra
.13818 .40453 .13356 .40846 .1384 .41266 .14302 .40875 Mtetra
.702 .646 .791 r
.13332 .40031 .1287 .40424 .13356 .40846 .13818 .40453 Mtetra
.701 .646 .791 r
.12846 .39608 .12384 .40002 .1287 .40424 .13332 .40031 Mtetra
.12359 .39185 .11897 .39579 .12384 .40002 .12846 .39608 Mtetra
.11871 .3876 .11409 .39155 .11897 .39579 .12359 .39185 Mtetra
.702 .646 .791 r
.11383 .38335 .1092 .38731 .11409 .39155 .11871 .3876 Mtetra
.10893 .3791 .10431 .38306 .1092 .38731 .11383 .38335 Mtetra
.701 .646 .791 r
.10403 .37484 .09941 .3788 .10431 .38306 .10893 .3791 Mtetra
.09912 .37057 .0945 .37454 .09941 .3788 .10403 .37484 Mtetra
.702 .646 .791 r
.0942 .36629 .08958 .37027 .0945 .37454 .09912 .37057 Mtetra
.5454 .75128 .5408 .7547 .54502 .75836 .54962 .75495 Mtetra
.54118 .74761 .53658 .75103 .5408 .7547 .5454 .75128 Mtetra
.53695 .74394 .53235 .74737 .53658 .75103 .54118 .74761 Mtetra
.703 .647 .791 r
.53272 .74026 .52812 .74371 .53235 .74737 .53695 .74394 Mtetra
.704 .647 .79 r
.52848 .7366 .52388 .74008 .52812 .74371 .53272 .74026 Mtetra
.707 .649 .79 r
.52423 .73297 .51963 .73651 .52388 .74008 .52848 .7366 Mtetra
.712 .653 .79 r
.51998 .7294 .51538 .73304 .51963 .73651 .52423 .73297 Mtetra
.722 .661 .788 r
.51572 .72597 .51112 .72979 .51538 .73304 .51998 .7294 Mtetra
.741 .674 .785 r
.51145 .72281 .50685 .72701 .51112 .72979 .51572 .72597 Mtetra
.777 .698 .776 r
.50718 .72018 .50257 .72514 .50685 .72701 .51145 .72281 Mtetra
.837 .738 .755 r
.5029 .71863 .49828 .72506 .50257 .72514 .50718 .72018 Mtetra
.916 .79 .707 r
.4986 .7192 .49395 .72838 .49828 .72506 .5029 .71863 Mtetra
.984 .831 .612 r
.49426 .72374 .48956 .73778 .49395 .72838 .4986 .7192 Mtetra
.994 .835 .473 r
.48985 .73517 .48505 .75673 .48956 .73778 .49426 .72374 Mtetra
.9 .781 .293 r
.4853 .75689 .48034 .78667 .48505 .75673 .48985 .73517 Mtetra
0 0 0 r
.48056 .78883 .47546 .81977 .48034 .78667 .4853 .75689 Mtetra
.055 0 .263 r
.47568 .81969 .47066 .83505 .47546 .81977 .48056 .78883 Mtetra
.681 .315 .347 r
.47096 .82715 .46627 .8171 .47066 .83505 .47568 .81969 Mtetra
0 0 .173 r
.46667 .80179 .46229 .77767 .46627 .8171 .47096 .82715 Mtetra
0 0 .413 r
.46273 .76077 .45843 .73882 .46229 .77767 .46667 .80179 Mtetra
.164 .058 .478 r
.45884 .72426 .45449 .71061 .45843 .73882 .46273 .76077 Mtetra
.282 .162 .534 r
.45484 .69888 .4504 .69248 .45449 .71061 .45884 .72426 Mtetra
.391 .275 .6 r
.45071 .68278 .4462 .68102 .4504 .69248 .45484 .69888 Mtetra
.498 .396 .669 r
.44647 .67252 .44192 .67338 .4462 .68102 .45071 .68278 Mtetra
.588 .502 .725 r
.44217 .66555 .43759 .66784 .44192 .67338 .44647 .67252 Mtetra
.652 .58 .761 r
.43782 .66042 .43322 .66349 .43759 .66784 .44217 .66555 Mtetra
.696 .636 .784 r
.43343 .6564 .42882 .65995 .43322 .66349 .43782 .66042 Mtetra
.733 .682 .801 r
.42901 .65323 .42438 .65716 .42882 .65995 .43343 .6564 Mtetra
.772 .73 .814 r
.42455 .65091 .4199 .65526 .42438 .65716 .42901 .65323 Mtetra
.822 .793 .825 r
.42004 .64968 .41536 .6546 .4199 .65526 .42455 .65091 Mtetra
.882 .876 .825 r
.41545 .65001 .41072 .65569 .41536 .6546 .42004 .64968 Mtetra
.925 .96 .782 r
.41074 .65245 .40596 .65908 .41072 .65569 .41545 .65001 Mtetra
.875 .968 .647 r
.40589 .6575 .40104 .66515 .40596 .65908 .41074 .65245 Mtetra
.717 .867 .455 r
.40088 .6651 .39596 .67347 .40104 .66515 .40589 .6575 Mtetra
0 0 0 r
.39575 .67389 .39081 .68203 .39596 .67347 .40088 .6651 Mtetra
.39066 .68075 .38577 .68716 .39081 .68203 .39575 .67389 Mtetra
.74 .98 .916 r
.38582 .68178 .38107 .68525 .38577 .68716 .39066 .68075 Mtetra
.482 .464 .761 r
.38138 .67478 .3768 .67541 .38107 .68525 .38582 .68178 Mtetra
.392 .292 .621 r
.37732 .66115 .37286 .66023 .3768 .67541 .38138 .67478 Mtetra
.393 .267 .588 r
.37346 .64467 .36904 .64366 .37286 .66023 .37732 .66115 Mtetra
.422 .289 .594 r
.36962 .62881 .36518 .62859 .36904 .64366 .37346 .64467 Mtetra
.464 .334 .618 r
.36566 .61535 .36119 .61613 .36518 .62859 .36962 .62881 Mtetra
.512 .392 .653 r
.36157 .60456 .35706 .60623 .36119 .61613 .36566 .61535 Mtetra
.56 .453 .689 r
.35735 .59599 .35281 .59834 .35706 .60623 .36157 .60456 Mtetra
.603 .508 .72 r
.35303 .58903 .34846 .59187 .35281 .59834 .35735 .59599 Mtetra
.636 .553 .744 r
.34864 .58317 .34405 .58634 .34846 .59187 .35303 .58903 Mtetra
.66 .586 .761 r
.3442 .57804 .3396 .5814 .34405 .58634 .34864 .58317 Mtetra
.675 .608 .773 r
.33972 .57337 .33511 .57683 .3396 .5814 .3442 .57804 Mtetra
.684 .622 .78 r
.33521 .56896 .3306 .57251 .33511 .57683 .33972 .57337 Mtetra
.691 .631 .783 r
.33069 .56472 .32607 .56833 .3306 .57251 .33521 .56896 Mtetra
.696 .636 .786 r
.32615 .56058 .32153 .56424 .32607 .56833 .33069 .56472 Mtetra
.698 .64 .788 r
.32159 .55651 .31697 .56018 .32153 .56424 .32615 .56058 Mtetra
.699 .643 .79 r
.31703 .55247 .31241 .55614 .31697 .56018 .32159 .55651 Mtetra
.7 .643 .79 r
.31246 .54844 .30784 .55213 .31241 .55614 .31703 .55247 Mtetra
.701 .644 .79 r
.30788 .54442 .30326 .54813 .30784 .55213 .31246 .54844 Mtetra
.701 .645 .79 r
.30329 .54041 .29867 .54414 .30326 .54813 .30788 .54442 Mtetra
.701 .645 .791 r
.29869 .5364 .29407 .54013 .29867 .54414 .30329 .54041 Mtetra
.29409 .53239 .28947 .53611 .29407 .54013 .29869 .5364 Mtetra
.28948 .52836 .28486 .5321 .28947 .53611 .29409 .53239 Mtetra
.702 .646 .791 r
.28486 .52434 .28024 .52809 .28486 .5321 .28948 .52836 Mtetra
.28023 .52031 .27561 .52406 .28024 .52809 .28486 .52434 Mtetra
.701 .646 .791 r
.2756 .51628 .27098 .52003 .27561 .52406 .28023 .52031 Mtetra
.701 .645 .791 r
.27096 .51223 .26634 .51599 .27098 .52003 .2756 .51628 Mtetra
.701 .646 .791 r
.26631 .50818 .26169 .51195 .26634 .51599 .27096 .51223 Mtetra
.702 .646 .791 r
.26166 .50413 .25703 .5079 .26169 .51195 .26631 .50818 Mtetra
.701 .646 .791 r
.25699 .50007 .25237 .50384 .25703 .5079 .26166 .50413 Mtetra
.25232 .496 .2477 .49978 .25237 .50384 .25699 .50007 Mtetra
.701 .645 .791 r
.24764 .49192 .24302 .49571 .2477 .49978 .25232 .496 Mtetra
.702 .646 .791 r
.24296 .48784 .23833 .49164 .24302 .49571 .24764 .49192 Mtetra
.701 .646 .791 r
.23827 .48375 .23364 .48756 .23833 .49164 .24296 .48784 Mtetra
.23356 .47967 .22894 .48347 .23364 .48756 .23827 .48375 Mtetra
.701 .645 .791 r
.22886 .47556 .22423 .47937 .22894 .48347 .23356 .47967 Mtetra
.701 .646 .791 r
.22414 .47145 .21952 .47527 .22423 .47937 .22886 .47556 Mtetra
.702 .646 .791 r
.21942 .46734 .21479 .47117 .21952 .47527 .22414 .47145 Mtetra
.701 .646 .791 r
.21469 .46322 .21006 .46705 .21479 .47117 .21942 .46734 Mtetra
.20995 .4591 .20532 .46293 .21006 .46705 .21469 .46322 Mtetra
.701 .645 .791 r
.2052 .45496 .20058 .4588 .20532 .46293 .20995 .4591 Mtetra
.702 .646 .791 r
.20045 .45082 .19582 .45467 .20058 .4588 .2052 .45496 Mtetra
.19569 .44667 .19106 .45053 .19582 .45467 .20045 .45082 Mtetra
.701 .646 .791 r
.19092 .44252 .18629 .44638 .19106 .45053 .19569 .44667 Mtetra
.18614 .43836 .18152 .44222 .18629 .44638 .19092 .44252 Mtetra
.18136 .43419 .17673 .43806 .18152 .44222 .18614 .43836 Mtetra
.702 .646 .791 r
.17657 .43001 .17194 .4339 .17673 .43806 .18136 .43419 Mtetra
.17177 .42583 .16714 .42972 .17194 .4339 .17657 .43001 Mtetra
.701 .646 .791 r
.16696 .42165 .16233 .42554 .16714 .42972 .17177 .42583 Mtetra
.16215 .41745 .15752 .42135 .16233 .42554 .16696 .42165 Mtetra
.15732 .41325 .15269 .41716 .15752 .42135 .16215 .41745 Mtetra
.702 .646 .791 r
.15249 .40904 .14786 .41296 .15269 .41716 .15732 .41325 Mtetra
.701 .646 .791 r
.14765 .40483 .14302 .40875 .14786 .41296 .15249 .40904 Mtetra
.14281 .40061 .13818 .40453 .14302 .40875 .14765 .40483 Mtetra
.13795 .39638 .13332 .40031 .13818 .40453 .14281 .40061 Mtetra
.13309 .39214 .12846 .39608 .13332 .40031 .13795 .39638 Mtetra
.12822 .3879 .12359 .39185 .12846 .39608 .13309 .39214 Mtetra
.12334 .38365 .11871 .3876 .12359 .39185 .12822 .3879 Mtetra
.11846 .3794 .11383 .38335 .11871 .3876 .12334 .38365 Mtetra
.11356 .37513 .10893 .3791 .11383 .38335 .11846 .3794 Mtetra
.10866 .37087 .10403 .37484 .10893 .3791 .11356 .37513 Mtetra
.10375 .36659 .09912 .37057 .10403 .37484 .10866 .37087 Mtetra
.09883 .3623 .0942 .36629 .09912 .37057 .10375 .36659 Mtetra
.55001 .74787 .5454 .75128 .54962 .75495 .55422 .75154 Mtetra
.54579 .74418 .54118 .74761 .5454 .75128 .55001 .74787 Mtetra
.702 .646 .79 r
.54156 .74049 .53695 .74394 .54118 .74761 .54579 .74418 Mtetra
.703 .646 .79 r
.53733 .73681 .53272 .74026 .53695 .74394 .54156 .74049 Mtetra
.703 .647 .791 r
.53309 .73314 .52848 .7366 .53272 .74026 .53733 .73681 Mtetra
.704 .648 .791 r
.52884 .72948 .52423 .73297 .52848 .7366 .53309 .73314 Mtetra
.707 .65 .79 r
.52459 .72584 .51998 .7294 .52423 .73297 .52884 .72948 Mtetra
.714 .654 .789 r
.52033 .72229 .51572 .72597 .51998 .7294 .52459 .72584 Mtetra
.726 .663 .787 r
.51606 .71889 .51145 .72281 .51572 .72597 .52033 .72229 Mtetra
.749 .679 .783 r
.51179 .71582 .50718 .72018 .51145 .72281 .51606 .71889 Mtetra
.79 .708 .773 r
.50751 .7134 .5029 .71863 .50718 .72018 .51179 .71582 Mtetra
.856 .752 .747 r
.50322 .71225 .4986 .7192 .5029 .71863 .50751 .7134 Mtetra
.936 .803 .688 r
.49892 .71358 .49426 .72374 .4986 .7192 .50322 .71225 Mtetra
.993 .836 .581 r
.49457 .71949 .48985 .73517 .49426 .72374 .49892 .71358 Mtetra
.983 .828 .432 r
.49014 .73317 .4853 .75689 .48985 .73517 .49457 .71949 Mtetra
.846 .75 .234 r
.48555 .7577 .48056 .78883 .4853 .75689 .49014 .73317 Mtetra
0 0 .055 r
.48078 .79097 .47568 .81969 .48056 .78883 .48555 .7577 Mtetra
.212 0 .307 r
.47592 .81804 .47096 .82715 .47568 .81969 .48078 .79097 Mtetra
.834 .436 .294 r
.47129 .81698 .46667 .80179 .47096 .82715 .47592 .81804 Mtetra
0 0 .282 r
.46709 .78549 .46273 .76077 .46667 .80179 .47129 .81698 Mtetra
.029 0 .433 r
.46316 .74427 .45884 .72426 .46273 .76077 .46709 .78549 Mtetra
.196 .084 .491 r
.45922 .71046 .45484 .69888 .45884 .72426 .46316 .74427 Mtetra
.31 .189 .549 r
.45518 .68774 .45071 .68278 .45484 .69888 .45922 .71046 Mtetra
.419 .306 .618 r
.451 .67342 .44647 .67252 .45071 .68278 .45518 .68774 Mtetra
.524 .426 .685 r
.44674 .66421 .44217 .66555 .44647 .67252 .451 .67342 Mtetra
.607 .527 .738 r
.44242 .65788 .43782 .66042 .44217 .66555 .44674 .66421 Mtetra
.667 .6 .771 r
.43805 .65316 .43343 .6564 .43782 .66042 .44242 .65788 Mtetra
.712 .655 .791 r
.43365 .64949 .42901 .65323 .43343 .6564 .43805 .65316 Mtetra
.753 .705 .806 r
.4292 .64673 .42455 .65091 .42901 .65323 .43365 .64949 Mtetra
.8 .765 .82 r
.42471 .645 .42004 .64968 .42455 .65091 .4292 .64673 Mtetra
.859 .843 .828 r
.42016 .64466 .41545 .65001 .42004 .64968 .42471 .645 Mtetra
.914 .933 .808 r
.4155 .64623 .41074 .65245 .41545 .65001 .42016 .64466 Mtetra
.909 .979 .711 r
.41072 .65023 .40589 .6575 .41074 .65245 .4155 .64623 Mtetra
.787 .915 .529 r
.40578 .6569 .40088 .6651 .40589 .6575 .41072 .65023 Mtetra
.615 .794 .363 r
.4007 .66549 .39575 .67389 .40088 .6651 .40578 .6569 Mtetra
0 0 0 r
.39558 .67353 .39066 .68075 .39575 .67389 .4007 .66549 Mtetra
.659 .942 .686 r
.39063 .67715 .38582 .68178 .39066 .68075 .39558 .67353 Mtetra
.581 .634 .868 r
.38603 .67317 .38138 .67478 .38582 .68178 .39063 .67715 Mtetra
.409 .329 .654 r
.38183 .66164 .37732 .66115 .38138 .67478 .38603 .67317 Mtetra
.388 .269 .594 r
.37791 .64577 .37346 .64467 .37732 .66115 .38183 .66164 Mtetra
.408 .277 .589 r
.37405 .6294 .36962 .62881 .37346 .64467 .37791 .64577 Mtetra
.447 .315 .607 r
.37013 .61495 .36566 .61535 .36962 .62881 .37405 .6294 Mtetra
.494 .369 .639 r
.36608 .60317 .36157 .60456 .36566 .61535 .37013 .61495 Mtetra
.543 .43 .675 r
.3619 .59383 .35735 .59599 .36157 .60456 .36608 .60317 Mtetra
.588 .489 .709 r
.3576 .58634 .35303 .58903 .35735 .59599 .3619 .59383 Mtetra
.624 .538 .736 r
.35323 .58013 .34864 .58317 .35303 .58903 .3576 .58634 Mtetra
.651 .575 .756 r
.3488 .57475 .3442 .57804 .34864 .58317 .35323 .58013 Mtetra
.67 .6 .768 r
.34433 .56992 .33972 .57337 .3442 .57804 .3488 .57475 Mtetra
.682 .617 .777 r
.33983 .56542 .33521 .56896 .33972 .57337 .34433 .56992 Mtetra
.689 .628 .783 r
.33531 .56112 .33069 .56472 .33521 .56896 .33983 .56542 Mtetra
.694 .635 .786 r
.33077 .55694 .32615 .56058 .33069 .56472 .33531 .56112 Mtetra
.697 .639 .788 r
.32622 .55284 .32159 .55651 .32615 .56058 .33077 .55694 Mtetra
.699 .642 .789 r
.32166 .54878 .31703 .55247 .32159 .55651 .32622 .55284 Mtetra
.7 .643 .79 r
.31709 .54475 .31246 .54844 .31703 .55247 .32166 .54878 Mtetra
.7 .644 .79 r
.31251 .54072 .30788 .54442 .31246 .54844 .31709 .54475 Mtetra
.701 .644 .79 r
.30792 .53669 .30329 .54041 .30788 .54442 .31251 .54072 Mtetra
.701 .645 .79 r
.30332 .53267 .29869 .5364 .30329 .54041 .30792 .53669 Mtetra
.701 .646 .791 r
.29872 .52866 .29409 .53239 .29869 .5364 .30332 .53267 Mtetra
.29411 .52463 .28948 .52836 .29409 .53239 .29872 .52866 Mtetra
.701 .645 .79 r
.28949 .52059 .28486 .52434 .28948 .52836 .29411 .52463 Mtetra
.702 .646 .791 r
.28486 .51656 .28023 .52031 .28486 .52434 .28949 .52059 Mtetra
.28023 .51251 .2756 .51628 .28023 .52031 .28486 .51656 Mtetra
.701 .646 .791 r
.27559 .50847 .27096 .51223 .2756 .51628 .28023 .51251 Mtetra
.27094 .50442 .26631 .50818 .27096 .51223 .27559 .50847 Mtetra
.701 .645 .791 r
.26629 .50035 .26166 .50413 .26631 .50818 .27094 .50442 Mtetra
.702 .646 .791 r
.26162 .49628 .25699 .50007 .26166 .50413 .26629 .50035 Mtetra
.25695 .49221 .25232 .496 .25699 .50007 .26162 .49628 Mtetra
.701 .646 .791 r
.25228 .48813 .24764 .49192 .25232 .496 .25695 .49221 Mtetra
.24759 .48404 .24296 .48784 .24764 .49192 .25228 .48813 Mtetra
.2429 .47995 .23827 .48375 .24296 .48784 .24759 .48404 Mtetra
.702 .646 .791 r
.2382 .47585 .23356 .47967 .23827 .48375 .2429 .47995 Mtetra
.23349 .47174 .22886 .47556 .23356 .47967 .2382 .47585 Mtetra
.701 .646 .791 r
.22877 .46763 .22414 .47145 .22886 .47556 .23349 .47174 Mtetra
.22405 .46351 .21942 .46734 .22414 .47145 .22877 .46763 Mtetra
.702 .646 .791 r
.21932 .45938 .21469 .46322 .21942 .46734 .22405 .46351 Mtetra
.21458 .45525 .20995 .4591 .21469 .46322 .21932 .45938 Mtetra
.701 .646 .791 r
.20984 .45111 .2052 .45496 .20995 .4591 .21458 .45525 Mtetra
.20508 .44696 .20045 .45082 .2052 .45496 .20984 .45111 Mtetra
.20032 .44281 .19569 .44667 .20045 .45082 .20508 .44696 Mtetra
.702 .646 .791 r
.19556 .43865 .19092 .44252 .19569 .44667 .20032 .44281 Mtetra
.19078 .43448 .18614 .43836 .19092 .44252 .19556 .43865 Mtetra
.701 .646 .791 r
.18599 .43031 .18136 .43419 .18614 .43836 .19078 .43448 Mtetra
.1812 .42613 .17657 .43001 .18136 .43419 .18599 .43031 Mtetra
.1764 .42194 .17177 .42583 .17657 .43001 .1812 .42613 Mtetra
.1716 .41775 .16696 .42165 .17177 .42583 .1764 .42194 Mtetra
.16678 .41355 .16215 .41745 .16696 .42165 .1716 .41775 Mtetra
.16196 .40934 .15732 .41325 .16215 .41745 .16678 .41355 Mtetra
.15713 .40512 .15249 .40904 .15732 .41325 .16196 .40934 Mtetra
.15229 .4009 .14765 .40483 .15249 .40904 .15713 .40512 Mtetra
.14744 .39668 .14281 .40061 .14765 .40483 .15229 .4009 Mtetra
.14259 .39244 .13795 .39638 .14281 .40061 .14744 .39668 Mtetra
.13773 .3882 .13309 .39214 .13795 .39638 .14259 .39244 Mtetra
.13286 .38395 .12822 .3879 .13309 .39214 .13773 .3882 Mtetra
.12798 .3797 .12334 .38365 .12822 .3879 .13286 .38395 Mtetra
.12309 .37544 .11846 .3794 .12334 .38365 .12798 .3797 Mtetra
.1182 .37116 .11356 .37513 .11846 .3794 .12309 .37544 Mtetra
.1133 .36689 .10866 .37087 .11356 .37513 .1182 .37116 Mtetra
.702 .646 .791 r
.10839 .3626 .10375 .36659 .10866 .37087 .1133 .36689 Mtetra
.701 .646 .791 r
.10347 .35832 .09883 .3623 .10375 .36659 .10839 .3626 Mtetra
.702 .646 .791 r
.55462 .74443 .55001 .74787 .55422 .75154 .55884 .74812 Mtetra
.5504 .74075 .54579 .74418 .55001 .74787 .55462 .74443 Mtetra
.54617 .73706 .54156 .74049 .54579 .74418 .5504 .74075 Mtetra
.54194 .73337 .53733 .73681 .54156 .74049 .54617 .73706 Mtetra
.5377 .72968 .53309 .73314 .53733 .73681 .54194 .73337 Mtetra
.703 .647 .79 r
.53345 .72599 .52884 .72948 .53309 .73314 .5377 .72968 Mtetra
.705 .648 .79 r
.5292 .72231 .52459 .72584 .52884 .72948 .53345 .72599 Mtetra
.709 .651 .79 r
.52494 .71869 .52033 .72229 .52459 .72584 .5292 .72231 Mtetra
.716 .656 .789 r
.52068 .71516 .51606 .71889 .52033 .72229 .52494 .71869 Mtetra
.73 .666 .787 r
.51641 .71182 .51179 .71582 .51606 .71889 .52068 .71516 Mtetra
.757 .685 .781 r
.51213 .70886 .50751 .7134 .51179 .71582 .51641 .71182 Mtetra
.804 .716 .768 r
.50785 .70666 .50322 .71225 .50751 .7134 .51213 .70886 Mtetra
.876 .764 .736 r
.50355 .70598 .49892 .71358 .50322 .71225 .50785 .70666 Mtetra
.955 .815 .665 r
.49924 .7082 .49457 .71949 .49892 .71358 .50355 .70598 Mtetra
.999 .839 .546 r
.49487 .71571 .49014 .73317 .49457 .71949 .49924 .7082 Mtetra
.963 .817 .387 r
.49042 .73186 .48555 .7577 .49014 .73317 .49487 .71571 Mtetra
.776 .708 .17 r
.4858 .75909 .48078 .79097 .48555 .7577 .49042 .73186 Mtetra
0 0 .131 r
.48101 .79269 .47592 .81804 .48078 .79097 .4858 .75909 Mtetra
.366 .077 .336 r
.47618 .81444 .47129 .81698 .47592 .81804 .48101 .79269 Mtetra
.922 .529 .171 r
.47165 .80478 .46709 .78549 .47129 .81698 .47618 .81444 Mtetra
0 0 .347 r
.46751 .76865 .46316 .74427 .46709 .78549 .47165 .80478 Mtetra
.082 0 .449 r
.46358 .72829 .45922 .71046 .46316 .74427 .46751 .76865 Mtetra
.225 .11 .504 r
.4596 .69737 .45518 .68774 .45922 .71046 .46358 .72829 Mtetra
.335 .216 .565 r
.4555 .67714 .451 .67342 .45518 .68774 .4596 .69737 Mtetra
.446 .336 .636 r
.45129 .66442 .44674 .66421 .451 .67342 .4555 .67714 Mtetra
.549 .455 .701 r
.44701 .65612 .44242 .65788 .44674 .66421 .45129 .66442 Mtetra
.629 .551 .748 r
.44266 .65033 .43805 .65316 .44242 .65788 .44701 .65612 Mtetra
.686 .622 .779 r
.43827 .64602 .43365 .64949 .43805 .65316 .44266 .65033 Mtetra
.731 .679 .799 r
.43385 .64278 .4292 .64673 .43365 .64949 .43827 .64602 Mtetra
.778 .737 .815 r
.42938 .64057 .42471 .645 .4292 .64673 .43385 .64278 Mtetra
.834 .809 .826 r
.42486 .6396 .42016 .64466 .42471 .645 .42938 .64057 Mtetra
.896 .898 .82 r
.42025 .64033 .4155 .64623 .42016 .64466 .42486 .6396 Mtetra
.924 .972 .759 r
.41552 .64335 .41072 .65023 .4155 .64623 .42025 .64033 Mtetra
.842 .951 .6 r
.41065 .64903 .40578 .6569 .41072 .65023 .41552 .64335 Mtetra
.673 .836 .413 r
.40563 .65706 .4007 .66549 .40578 .6569 .41065 .64903 Mtetra
0 0 0 r
.40052 .66567 .39558 .67353 .4007 .66549 .40563 .65706 Mtetra
.572 .839 .487 r
.39549 .67139 .39063 .67715 .39558 .67353 .40052 .66567 Mtetra
.706 .872 .96 r
.39075 .67047 .38603 .67317 .39063 .67715 .39549 .67139 Mtetra
.443 .393 .708 r
.3864 .66153 .38183 .66164 .38603 .67317 .39075 .67047 Mtetra
.388 .279 .607 r
.38238 .64681 .37791 .64577 .38183 .66164 .3864 .66153 Mtetra
.399 .27 .587 r
.3785 .63024 .37405 .6294 .37791 .64577 .38238 .64681 Mtetra
.431 .298 .598 r
.3746 .61491 .37013 .61495 .37405 .6294 .3785 .63024 Mtetra
.475 .347 .626 r
.37058 .60213 .36608 .60317 .37013 .61495 .3746 .61491 Mtetra
.524 .407 .661 r
.36644 .59193 .3619 .59383 .36608 .60317 .37058 .60213 Mtetra
.572 .468 .697 r
.36217 .58382 .3576 .58634 .3619 .59383 .36644 .59193 Mtetra
.612 .521 .727 r
.35782 .57719 .35323 .58013 .3576 .58634 .36217 .58382 Mtetra
.642 .562 .749 r
.35341 .57153 .3488 .57475 .35323 .58013 .35782 .57719 Mtetra
.664 .592 .764 r
.34895 .56651 .34433 .56992 .3488 .57475 .35341 .57153 Mtetra
.678 .612 .774 r
.34445 .5619 .33983 .56542 .34433 .56992 .34895 .56651 Mtetra
.687 .625 .781 r
.33993 .55753 .33531 .56112 .33983 .56542 .34445 .5619 Mtetra
.692 .633 .785 r
.3354 .55331 .33077 .55694 .33531 .56112 .33993 .55753 Mtetra
.696 .637 .787 r
.33085 .54918 .32622 .55284 .33077 .55694 .3354 .55331 Mtetra
.698 .64 .788 r
.32629 .54509 .32166 .54878 .32622 .55284 .33085 .54918 Mtetra
.7 .643 .789 r
.32172 .54104 .31709 .54475 .32166 .54878 .32629 .54509 Mtetra
.7 .644 .79 r
.31714 .53701 .31251 .54072 .31709 .54475 .32172 .54104 Mtetra
.7 .645 .791 r
.31255 .53298 .30792 .53669 .31251 .54072 .31714 .53701 Mtetra
.701 .645 .79 r
.30796 .52895 .30332 .53267 .30792 .53669 .31255 .53298 Mtetra
.30336 .52491 .29872 .52866 .30332 .53267 .30796 .52895 Mtetra
.702 .646 .79 r
.29874 .52088 .29411 .52463 .29872 .52866 .30336 .52491 Mtetra
.701 .646 .791 r
.29413 .51685 .28949 .52059 .29411 .52463 .29874 .52088 Mtetra
.2895 .5128 .28486 .51656 .28949 .52059 .29413 .51685 Mtetra
.701 .645 .791 r
.28487 .50875 .28023 .51251 .28486 .51656 .2895 .5128 Mtetra
.702 .646 .791 r
.28023 .5047 .27559 .50847 .28023 .51251 .28487 .50875 Mtetra
.27558 .50064 .27094 .50442 .27559 .50847 .28023 .5047 Mtetra
.701 .646 .791 r
.27092 .49657 .26629 .50035 .27094 .50442 .27558 .50064 Mtetra
.26626 .4925 .26162 .49628 .26629 .50035 .27092 .49657 Mtetra
.26159 .48841 .25695 .49221 .26162 .49628 .26626 .4925 Mtetra
.702 .646 .791 r
.25691 .48433 .25228 .48813 .25695 .49221 .26159 .48841 Mtetra
.25223 .48023 .24759 .48404 .25228 .48813 .25691 .48433 Mtetra
.701 .646 .791 r
.24754 .47613 .2429 .47995 .24759 .48404 .25223 .48023 Mtetra
.24284 .47203 .2382 .47585 .2429 .47995 .24754 .47613 Mtetra
.23813 .46792 .23349 .47174 .2382 .47585 .24284 .47203 Mtetra
.702 .646 .791 r
.23341 .4638 .22877 .46763 .23349 .47174 .23813 .46792 Mtetra
.701 .646 .791 r
.22869 .45967 .22405 .46351 .22877 .46763 .23341 .4638 Mtetra
.22396 .45554 .21932 .45938 .22405 .46351 .22869 .45967 Mtetra
.21922 .4514 .21458 .45525 .21932 .45938 .22396 .45554 Mtetra
.21448 .44725 .20984 .45111 .21458 .45525 .21922 .4514 Mtetra
.20973 .4431 .20508 .44696 .20984 .45111 .21448 .44725 Mtetra
.20496 .43894 .20032 .44281 .20508 .44696 .20973 .4431 Mtetra
.2002 .43477 .19556 .43865 .20032 .44281 .20496 .43894 Mtetra
.19542 .4306 .19078 .43448 .19556 .43865 .2002 .43477 Mtetra
.19064 .42642 .18599 .43031 .19078 .43448 .19542 .4306 Mtetra
.18584 .42223 .1812 .42613 .18599 .43031 .19064 .42642 Mtetra
.18105 .41804 .1764 .42194 .1812 .42613 .18584 .42223 Mtetra
.17624 .41384 .1716 .41775 .1764 .42194 .18105 .41804 Mtetra
.17142 .40963 .16678 .41355 .1716 .41775 .17624 .41384 Mtetra
.1666 .40542 .16196 .40934 .16678 .41355 .17142 .40963 Mtetra
.16177 .4012 .15713 .40512 .16196 .40934 .1666 .40542 Mtetra
.15693 .39697 .15229 .4009 .15713 .40512 .16177 .4012 Mtetra
.15208 .39274 .14744 .39668 .15229 .4009 .15693 .39697 Mtetra
.14723 .3885 .14259 .39244 .14744 .39668 .15208 .39274 Mtetra
.14237 .38425 .13773 .3882 .14259 .39244 .14723 .3885 Mtetra
.1375 .38 .13286 .38395 .13773 .3882 .14237 .38425 Mtetra
.13262 .37573 .12798 .3797 .13286 .38395 .1375 .38 Mtetra
.702 .646 .791 r
.12773 .37146 .12309 .37544 .12798 .3797 .13262 .37573 Mtetra
.701 .646 .791 r
.12284 .36719 .1182 .37116 .12309 .37544 .12773 .37146 Mtetra
.11794 .36291 .1133 .36689 .1182 .37116 .12284 .36719 Mtetra
.11303 .35862 .10839 .3626 .1133 .36689 .11794 .36291 Mtetra
.10811 .35432 .10347 .35832 .10839 .3626 .11303 .35862 Mtetra
.55924 .741 .55462 .74443 .55884 .74812 .56346 .74469 Mtetra
.55502 .73732 .5504 .74075 .55462 .74443 .55924 .741 Mtetra
.5508 .73362 .54617 .73706 .5504 .74075 .55502 .73732 Mtetra
.702 .646 .79 r
.54656 .72992 .54194 .73337 .54617 .73706 .5508 .73362 Mtetra
.54232 .72621 .5377 .72968 .54194 .73337 .54656 .72992 Mtetra
.703 .646 .79 r
.53808 .72251 .53345 .72599 .5377 .72968 .54232 .72621 Mtetra
.704 .648 .791 r
.53382 .71882 .5292 .72231 .53345 .72599 .53808 .72251 Mtetra
.706 .649 .791 r
.52957 .71516 .52494 .71869 .5292 .72231 .53382 .71882 Mtetra
.71 .652 .79 r
.5253 .71154 .52068 .71516 .52494 .71869 .52957 .71516 Mtetra
.719 .657 .788 r
.52103 .70802 .51641 .71182 .52068 .71516 .5253 .71154 Mtetra
.736 .669 .785 r
.51675 .70474 .51213 .70886 .51641 .71182 .52103 .70802 Mtetra
.767 .692 .779 r
.51247 .70192 .50785 .70666 .51213 .70886 .51675 .70474 Mtetra
.82 .728 .764 r
.50818 .70001 .50355 .70598 .50785 .70666 .51247 .70192 Mtetra
.896 .778 .723 r
.50388 .69988 .49924 .7082 .50355 .70598 .50818 .70001 Mtetra
.971 .824 .639 r
.49956 .70313 .49487 .71571 .49924 .7082 .50388 .69988 Mtetra
.999 .838 .509 r
.49518 .71242 .49042 .73186 .49487 .71571 .49956 .70313 Mtetra
.935 .801 .339 r
.4907 .73122 .4858 .75909 .49042 .73186 .49518 .71242 Mtetra
0 0 0 r
.48605 .76091 .48101 .79269 .4858 .75909 .4907 .73122 Mtetra
0 0 .199 r
.48124 .79366 .47618 .81444 .48101 .79269 .48605 .76091 Mtetra
.519 .189 .348 r
.47647 .80868 .47165 .80478 .47618 .81444 .48124 .79366 Mtetra
.835 .521 0 r
.47202 .79078 .46751 .76865 .47165 .80478 .47647 .80868 Mtetra
0 0 .386 r
.46794 .75162 .46358 .72829 .46751 .76865 .47202 .79078 Mtetra
.124 .027 .463 r
.46398 .71302 .4596 .69737 .46358 .72829 .46794 .75162 Mtetra
.254 .135 .518 r
.45996 .68499 .4555 .67714 .4596 .69737 .46398 .71302 Mtetra
.364 .246 .582 r
.45582 .667 .45129 .66442 .4555 .67714 .45996 .68499 Mtetra
.474 .368 .654 r
.45158 .65568 .44701 .65612 .45129 .66442 .45582 .667 Mtetra
.572 .484 .716 r
.44726 .64822 .44266 .65033 .44701 .65612 .45158 .65568 Mtetra
.648 .576 .759 r
.4429 .64296 .43827 .64602 .44266 .65033 .44726 .64822 Mtetra
.705 .645 .787 r
.43849 .6391 .43385 .64278 .43827 .64602 .4429 .64296 Mtetra
.755 .707 .807 r
.43405 .63635 .42938 .64057 .43385 .64278 .43849 .6391 Mtetra
.809 .776 .822 r
.42955 .6348 .42486 .6396 .42938 .64057 .43405 .63635 Mtetra
.872 .863 .827 r
.42498 .6348 .42025 .64033 .42486 .6396 .42955 .6348 Mtetra
.922 .951 .793 r
.42031 .63686 .41552 .64335 .42025 .64033 .42498 .6348 Mtetra
.89 .974 .671 r
.4155 .64149 .41065 .64903 .41552 .64335 .42031 .63686 Mtetra
.741 .884 .479 r
.41055 .64873 .40563 .65706 .41065 .64903 .4155 .64149 Mtetra
0 0 0 r
.40547 .65742 .40052 .66567 .40563 .65706 .41055 .64873 Mtetra
.4004 .66469 .39549 .67139 .40052 .66567 .40547 .65742 Mtetra
.728 .99 .853 r
.39553 .66658 .39075 .67047 .39549 .67139 .4004 .66469 Mtetra
.511 .512 .793 r
.39103 .66056 .3864 .66153 .39075 .67047 .39553 .66658 Mtetra
.397 .302 .631 r
.38689 .64758 .38238 .64681 .3864 .66153 .39103 .66056 Mtetra
.391 .267 .59 r
.38296 .63126 .3785 .63024 .38238 .64681 .38689 .64758 Mtetra
.417 .285 .592 r
.37907 .61523 .3746 .61491 .3785 .63024 .38296 .63126 Mtetra
.458 .327 .614 r
.37508 .60144 .37058 .60213 .3746 .61491 .37907 .61523 Mtetra
.506 .384 .648 r
.37097 .59033 .36644 .59193 .37058 .60213 .37508 .60144 Mtetra
.555 .445 .684 r
.36674 .5815 .36217 .58382 .36644 .59193 .37097 .59033 Mtetra
.599 .502 .716 r
.36242 .57436 .35782 .57719 .36217 .58382 .36674 .5815 Mtetra
.633 .549 .742 r
.35802 .56839 .35341 .57153 .35782 .57719 .36242 .57436 Mtetra
.657 .582 .76 r
.35357 .56317 .34895 .56651 .35341 .57153 .35802 .56839 Mtetra
.673 .605 .771 r
.34908 .55842 .34445 .5619 .34895 .56651 .35357 .56317 Mtetra
.684 .62 .778 r
.34457 .55396 .33993 .55753 .34445 .5619 .34908 .55842 Mtetra
.691 .63 .783 r
.34004 .54968 .3354 .55331 .33993 .55753 .34457 .55396 Mtetra
.695 .636 .786 r
.33549 .54551 .33085 .54918 .3354 .55331 .34004 .54968 Mtetra
.697 .64 .788 r
.33093 .54141 .32629 .54509 .33085 .54918 .33549 .54551 Mtetra
.699 .642 .789 r
.32636 .53734 .32172 .54104 .32629 .54509 .33093 .54141 Mtetra
.7 .643 .79 r
.32178 .53329 .31714 .53701 .32172 .54104 .32636 .53734 Mtetra
.701 .644 .79 r
.3172 .52924 .31255 .53298 .31714 .53701 .32178 .53329 Mtetra
.701 .645 .79 r
.3126 .52521 .30796 .52895 .31255 .53298 .3172 .52924 Mtetra
.701 .645 .791 r
.308 .52117 .30336 .52491 .30796 .52895 .3126 .52521 Mtetra
.30339 .51713 .29874 .52088 .30336 .52491 .308 .52117 Mtetra
.29877 .51309 .29413 .51685 .29874 .52088 .30339 .51713 Mtetra
.701 .646 .791 r
.29414 .50904 .2895 .5128 .29413 .51685 .29877 .51309 Mtetra
.28951 .50498 .28487 .50875 .2895 .5128 .29414 .50904 Mtetra
.28487 .50092 .28023 .5047 .28487 .50875 .28951 .50498 Mtetra
.28022 .49685 .27558 .50064 .28023 .5047 .28487 .50092 Mtetra
.27557 .49278 .27092 .49657 .27558 .50064 .28022 .49685 Mtetra
.27091 .4887 .26626 .4925 .27092 .49657 .27557 .49278 Mtetra
.26624 .48461 .26159 .48841 .26626 .4925 .27091 .4887 Mtetra
.26156 .48052 .25691 .48433 .26159 .48841 .26624 .48461 Mtetra
.25688 .47642 .25223 .48023 .25691 .48433 .26156 .48052 Mtetra
.25218 .47232 .24754 .47613 .25223 .48023 .25688 .47642 Mtetra
.24748 .4682 .24284 .47203 .24754 .47613 .25218 .47232 Mtetra
.24278 .46408 .23813 .46792 .24284 .47203 .24748 .4682 Mtetra
.23806 .45996 .23341 .4638 .23813 .46792 .24278 .46408 Mtetra
.23334 .45583 .22869 .45967 .23341 .4638 .23806 .45996 Mtetra
.22861 .45169 .22396 .45554 .22869 .45967 .23334 .45583 Mtetra
.22387 .44754 .21922 .4514 .22396 .45554 .22861 .45169 Mtetra
.21913 .44339 .21448 .44725 .21922 .4514 .22387 .44754 Mtetra
.21437 .43923 .20973 .4431 .21448 .44725 .21913 .44339 Mtetra
.20961 .43507 .20496 .43894 .20973 .4431 .21437 .43923 Mtetra
.20484 .43089 .2002 .43477 .20496 .43894 .20961 .43507 Mtetra
.20007 .42671 .19542 .4306 .2002 .43477 .20484 .43089 Mtetra
.19528 .42253 .19064 .42642 .19542 .4306 .20007 .42671 Mtetra
.19049 .41833 .18584 .42223 .19064 .42642 .19528 .42253 Mtetra
.18569 .41414 .18105 .41804 .18584 .42223 .19049 .41833 Mtetra
.18089 .40993 .17624 .41384 .18105 .41804 .18569 .41414 Mtetra
.17607 .40572 .17142 .40963 .17624 .41384 .18089 .40993 Mtetra
.702 .646 .791 r
.17125 .4015 .1666 .40542 .17142 .40963 .17607 .40572 Mtetra
.701 .646 .791 r
.16642 .39727 .16177 .4012 .1666 .40542 .17125 .4015 Mtetra
.16158 .39303 .15693 .39697 .16177 .4012 .16642 .39727 Mtetra
.15673 .3888 .15208 .39274 .15693 .39697 .16158 .39303 Mtetra
.15188 .38455 .14723 .3885 .15208 .39274 .15673 .3888 Mtetra
.702 .646 .791 r
.14702 .38029 .14237 .38425 .14723 .3885 .15188 .38455 Mtetra
.14215 .37603 .1375 .38 .14237 .38425 .14702 .38029 Mtetra
.701 .646 .791 r
.13727 .37176 .13262 .37573 .1375 .38 .14215 .37603 Mtetra
.13238 .36749 .12773 .37146 .13262 .37573 .13727 .37176 Mtetra
.12749 .36321 .12284 .36719 .12773 .37146 .13238 .36749 Mtetra
.12259 .35892 .11794 .36291 .12284 .36719 .12749 .36321 Mtetra
.702 .646 .791 r
.11768 .35462 .11303 .35862 .11794 .36291 .12259 .35892 Mtetra
.701 .646 .791 r
.11276 .35032 .10811 .35432 .11303 .35862 .11768 .35462 Mtetra
.56387 .73758 .55924 .741 .56346 .74469 .56808 .74127 Mtetra
.701 .645 .79 r
.55965 .73387 .55502 .73732 .55924 .741 .56387 .73758 Mtetra
.702 .646 .79 r
.55542 .73017 .5508 .73362 .55502 .73732 .55965 .73387 Mtetra
.702 .646 .791 r
.55119 .72646 .54656 .72992 .5508 .73362 .55542 .73017 Mtetra
.54695 .72275 .54232 .72621 .54656 .72992 .55119 .72646 Mtetra
.54271 .71905 .53808 .72251 .54232 .72621 .54695 .72275 Mtetra
.703 .646 .791 r
.53845 .71534 .53382 .71882 .53808 .72251 .54271 .71905 Mtetra
.704 .647 .79 r
.5342 .71163 .52957 .71516 .53382 .71882 .53845 .71534 Mtetra
.707 .649 .79 r
.52993 .70796 .5253 .71154 .52957 .71516 .5342 .71163 Mtetra
.712 .653 .79 r
.52566 .70436 .52103 .70802 .5253 .71154 .52993 .70796 Mtetra
.722 .661 .789 r
.52138 .70089 .51675 .70474 .52103 .70802 .52566 .70436 Mtetra
.742 .674 .785 r
.5171 .69769 .51247 .70192 .51675 .70474 .52138 .70089 Mtetra
.778 .699 .776 r
.51282 .69502 .50818 .70001 .51247 .70192 .5171 .69769 Mtetra
.838 .739 .755 r
.50852 .69343 .50388 .69988 .50818 .70001 .51282 .69502 Mtetra
.917 .792 .707 r
.50421 .69395 .49956 .70313 .50388 .69988 .50852 .69343 Mtetra
.985 .832 .61 r
.49988 .69841 .49518 .71242 .49956 .70313 .50421 .69395 Mtetra
.993 .834 .469 r
.49549 .70973 .4907 .73122 .49518 .71242 .49988 .69841 Mtetra
.896 .779 .287 r
.49098 .73127 .48605 .76091 .4907 .73122 .49549 .70973 Mtetra
0 0 0 r
.48631 .76293 .48124 .79366 .48605 .76091 .49098 .73127 Mtetra
.048 0 .257 r
.48149 .79343 .47647 .80868 .48124 .79366 .48631 .76293 Mtetra
.68 .309 .337 r
.47678 .80067 .47202 .79078 .47647 .80868 .48149 .79343 Mtetra
0 0 .184 r
.47242 .77543 .46794 .75162 .47202 .79078 .47678 .80067 Mtetra
0 0 .413 r
.46837 .73471 .46398 .71302 .46794 .75162 .47242 .77543 Mtetra
.161 .056 .477 r
.46438 .69845 .45996 .68499 .46398 .71302 .46837 .73471 Mtetra
.281 .161 .533 r
.46031 .67326 .45582 .667 .45996 .68499 .46438 .69845 Mtetra
.391 .275 .6 r
.45613 .65731 .45158 .65568 .45582 .667 .46031 .67326 Mtetra
.501 .4 .671 r
.45186 .64722 .44726 .64822 .45158 .65568 .45613 .65731 Mtetra
.597 .513 .73 r
.44752 .6405 .4429 .64296 .44726 .64822 .45186 .64722 Mtetra
.67 .602 .77 r
.44313 .63578 .43849 .6391 .4429 .64296 .44752 .6405 Mtetra
.728 .673 .797 r
.43871 .63241 .43405 .63635 .43849 .6391 .44313 .63578 Mtetra
.783 .743 .816 r
.43423 .63027 .42955 .6348 .43405 .63635 .43871 .63241 Mtetra
.846 .826 .827 r
.42969 .62958 .42498 .6348 .42955 .6348 .43423 .63027 Mtetra
.908 .92 .814 r
.42507 .63076 .42031 .63686 .42498 .6348 .42969 .62958 Mtetra
.917 .979 .729 r
.42033 .63435 .4155 .64149 .42031 .63686 .42507 .63076 Mtetra
.806 .928 .552 r
.41544 .64064 .41055 .64873 .4155 .64149 .42033 .63435 Mtetra
.632 .807 .377 r
.41042 .649 .40547 .65742 .41055 .64873 .41544 .64064 Mtetra
0 0 0 r
.40534 .65722 .4004 .66469 .40547 .65742 .41042 .649 Mtetra
.63 .909 .614 r
.40038 .66155 .39553 .66658 .4004 .66469 .40534 .65722 Mtetra
.625 .709 .907 r
.39573 .65857 .39103 .66056 .39553 .66658 .40038 .66155 Mtetra
.418 .346 .669 r
.39145 .64787 .38689 .64758 .39103 .66056 .39573 .65857 Mtetra
.387 .271 .598 r
.38745 .63233 .38296 .63126 .38689 .64758 .39145 .64787 Mtetra
.405 .274 .588 r
.38354 .61587 .37907 .61523 .38296 .63126 .38745 .63233 Mtetra
.442 .309 .604 r
.37958 .60112 .37508 .60144 .37907 .61523 .38354 .61587 Mtetra
.488 .362 .634 r
.37551 .58902 .37097 .59033 .37508 .60144 .37958 .60112 Mtetra
.537 .422 .671 r
.37131 .57941 .36674 .5815 .37097 .59033 .37551 .58902 Mtetra
.583 .482 .705 r
.36701 .57171 .36242 .57436 .36674 .5815 .37131 .57941 Mtetra
.621 .532 .733 r
.36263 .56535 .35802 .56839 .36242 .57436 .36701 .57171 Mtetra
.649 .571 .753 r
.35819 .55987 .35357 .56317 .35802 .56839 .36263 .56535 Mtetra
.668 .598 .767 r
.35371 .55496 .34908 .55842 .35357 .56317 .35819 .55987 Mtetra
.681 .616 .776 r
.3492 .5504 .34457 .55396 .34908 .55842 .35371 .55496 Mtetra
.688 .627 .782 r
.34468 .54607 .34004 .54968 .34457 .55396 .3492 .5504 Mtetra
.693 .634 .785 r
.34013 .54185 .33549 .54551 .34004 .54968 .34468 .54607 Mtetra
.697 .638 .787 r
.33558 .53772 .33093 .54141 .33549 .54551 .34013 .54185 Mtetra
.699 .641 .789 r
.33101 .53363 .32636 .53734 .33093 .54141 .33558 .53772 Mtetra
.7 .643 .79 r
.32643 .52957 .32178 .53329 .32636 .53734 .33101 .53363 Mtetra
.7 .644 .79 r
.32184 .52552 .3172 .52924 .32178 .53329 .32643 .52957 Mtetra
.701 .645 .79 r
.31725 .52147 .3126 .52521 .3172 .52924 .32184 .52552 Mtetra
.31265 .51742 .308 .52117 .3126 .52521 .31725 .52147 Mtetra
.701 .645 .791 r
.30804 .51337 .30339 .51713 .308 .52117 .31265 .51742 Mtetra
.701 .646 .791 r
.30342 .50932 .29877 .51309 .30339 .51713 .30804 .51337 Mtetra
.2988 .50527 .29414 .50904 .29877 .51309 .30342 .50932 Mtetra
.29416 .50121 .28951 .50498 .29414 .50904 .2988 .50527 Mtetra
.28952 .49714 .28487 .50092 .28951 .50498 .29416 .50121 Mtetra
.28488 .49307 .28022 .49685 .28487 .50092 .28952 .49714 Mtetra
.28022 .48899 .27557 .49278 .28022 .49685 .28488 .49307 Mtetra
.27556 .4849 .27091 .4887 .27557 .49278 .28022 .48899 Mtetra
.27089 .48081 .26624 .48461 .27091 .4887 .27556 .4849 Mtetra
.26621 .47671 .26156 .48052 .26624 .48461 .27089 .48081 Mtetra
.26153 .4726 .25688 .47642 .26156 .48052 .26621 .47671 Mtetra
.702 .646 .791 r
.25684 .46849 .25218 .47232 .25688 .47642 .26153 .4726 Mtetra
.701 .646 .791 r
.25214 .46437 .24748 .4682 .25218 .47232 .25684 .46849 Mtetra
.24743 .46025 .24278 .46408 .24748 .4682 .25214 .46437 Mtetra
.24271 .45612 .23806 .45996 .24278 .46408 .24743 .46025 Mtetra
.23799 .45198 .23334 .45583 .23806 .45996 .24271 .45612 Mtetra
.702 .646 .791 r
.23326 .44783 .22861 .45169 .23334 .45583 .23799 .45198 Mtetra
.701 .646 .791 r
.22853 .44368 .22387 .44754 .22861 .45169 .23326 .44783 Mtetra
.22378 .43952 .21913 .44339 .22387 .44754 .22853 .44368 Mtetra
.21903 .43536 .21437 .43923 .21913 .44339 .22378 .43952 Mtetra
.21427 .43118 .20961 .43507 .21437 .43923 .21903 .43536 Mtetra
.2095 .42701 .20484 .43089 .20961 .43507 .21427 .43118 Mtetra
.20472 .42282 .20007 .42671 .20484 .43089 .2095 .42701 Mtetra
.19994 .41863 .19528 .42253 .20007 .42671 .20472 .42282 Mtetra
.19515 .41443 .19049 .41833 .19528 .42253 .19994 .41863 Mtetra
.19035 .41022 .18569 .41414 .19049 .41833 .19515 .41443 Mtetra
.702 .646 .791 r
.18554 .40601 .18089 .40993 .18569 .41414 .19035 .41022 Mtetra
.701 .646 .791 r
.18073 .40179 .17607 .40572 .18089 .40993 .18554 .40601 Mtetra
.17591 .39757 .17125 .4015 .17607 .40572 .18073 .40179 Mtetra
.17107 .39334 .16642 .39727 .17125 .4015 .17591 .39757 Mtetra
.16624 .38909 .16158 .39303 .16642 .39727 .17107 .39334 Mtetra
.16139 .38484 .15673 .3888 .16158 .39303 .16624 .38909 Mtetra
.15654 .38059 .15188 .38455 .15673 .3888 .16139 .38484 Mtetra
.15168 .37633 .14702 .38029 .15188 .38455 .15654 .38059 Mtetra
.14681 .37206 .14215 .37603 .14702 .38029 .15168 .37633 Mtetra
.14193 .36779 .13727 .37176 .14215 .37603 .14681 .37206 Mtetra
.13704 .36351 .13238 .36749 .13727 .37176 .14193 .36779 Mtetra
.702 .646 .791 r
.13215 .35922 .12749 .36321 .13238 .36749 .13704 .36351 Mtetra
.701 .646 .791 r
.12725 .35492 .12259 .35892 .12749 .36321 .13215 .35922 Mtetra
.12234 .35062 .11768 .35462 .12259 .35892 .12725 .35492 Mtetra
.11742 .34631 .11276 .35032 .11768 .35462 .12234 .35062 Mtetra
.702 .646 .791 r
.5685 .73413 .56387 .73758 .56808 .74127 .57271 .73783 Mtetra
.701 .646 .791 r
.56428 .73043 .55965 .73387 .56387 .73758 .5685 .73413 Mtetra
.56006 .72672 .55542 .73017 .55965 .73387 .56428 .73043 Mtetra
.55582 .72302 .55119 .72646 .55542 .73017 .56006 .72672 Mtetra
.55159 .71929 .54695 .72275 .55119 .72646 .55582 .72302 Mtetra
.702 .646 .79 r
.54734 .71556 .54271 .71905 .54695 .72275 .55159 .71929 Mtetra
.703 .646 .79 r
.54309 .71184 .53845 .71534 .54271 .71905 .54734 .71556 Mtetra
.703 .647 .791 r
.53883 .70813 .5342 .71163 .53845 .71534 .54309 .71184 Mtetra
.704 .648 .791 r
.53457 .70443 .52993 .70796 .5342 .71163 .53883 .70813 Mtetra
.707 .65 .79 r
.5303 .70077 .52566 .70436 .52993 .70796 .53457 .70443 Mtetra
.714 .654 .789 r
.52602 .69717 .52138 .70089 .52566 .70436 .5303 .70077 Mtetra
.726 .663 .787 r
.52174 .69373 .5171 .69769 .52138 .70089 .52602 .69717 Mtetra
.749 .679 .783 r
.51745 .69063 .51282 .69502 .5171 .69769 .52174 .69373 Mtetra
.79 .708 .773 r
.51316 .68817 .50852 .69343 .51282 .69502 .51745 .69063 Mtetra
.856 .752 .747 r
.50886 .68697 .50421 .69395 .50852 .69343 .51316 .68817 Mtetra
.937 .804 .687 r
.50455 .68825 .49988 .69841 .50421 .69395 .50886 .68697 Mtetra
.994 .837 .578 r
.5002 .69408 .49549 .70973 .49988 .69841 .50455 .68825 Mtetra
.981 .827 .427 r
.4958 .70765 .49098 .73127 .49549 .70973 .5002 .69408 Mtetra
.842 .747 .23 r
.49127 .73197 .48631 .76293 .49098 .73127 .4958 .70765 Mtetra
0 0 .054 r
.48656 .76491 .48149 .79343 .48631 .76293 .49127 .73197 Mtetra
.205 0 .3 r
.48176 .79161 .47678 .80067 .48149 .79343 .48656 .76491 Mtetra
.835 .431 .28 r
.47711 .79042 .47242 .77543 .47678 .80067 .48176 .79161 Mtetra
0 0 .289 r
.47283 .7591 .46837 .73471 .47242 .77543 .47711 .79042 Mtetra
.028 0 .432 r
.46878 .71819 .46438 .69845 .46837 .73471 .47283 .7591 Mtetra
.193 .082 .49 r
.46476 .68465 .46031 .67326 .46438 .69845 .46878 .71819 Mtetra
.308 .188 .549 r
.46065 .66213 .45613 .65731 .46031 .67326 .46476 .68465 Mtetra
.42 .307 .619 r
.45643 .648 .45186 .64722 .45613 .65731 .46065 .66213 Mtetra
.529 .432 .689 r
.45213 .639 .44752 .6405 .45186 .64722 .45643 .648 Mtetra
.622 .542 .744 r
.44777 .63299 .44313 .63578 .44752 .6405 .45213 .639 Mtetra
.693 .63 .781 r
.44336 .62882 .43871 .63241 .44313 .63578 .44777 .63299 Mtetra
.755 .706 .806 r
.43891 .62604 .43423 .63027 .43871 .63241 .44336 .62882 Mtetra
.818 .787 .823 r
.4344 .62466 .42969 .62958 .43423 .63027 .43891 .62604 Mtetra
.886 .882 .824 r
.42982 .62502 .42507 .63076 .42969 .62958 .4344 .62466 Mtetra
.925 .966 .773 r
.42513 .62762 .42033 .63435 .42507 .63076 .42982 .62502 Mtetra
.86 .961 .626 r
.42031 .63288 .41544 .64064 .42033 .63435 .42513 .62762 Mtetra
.697 .853 .435 r
.41535 .64059 .41042 .649 .41544 .64064 .42031 .63288 Mtetra
0 0 0 r
.41029 .6492 .40534 .65722 .41042 .649 .41535 .64059 Mtetra
.552 .812 .444 r
.40527 .65545 .40038 .66155 .40534 .65722 .41029 .6492 Mtetra
.733 .938 .953 r
.40049 .65546 .39573 .65857 .40038 .66155 .40527 .65545 Mtetra
.462 .426 .732 r
.39607 .64746 .39145 .64787 .39573 .65857 .40049 .65546 Mtetra
.39 .285 .614 r
.39197 .63326 .38745 .63233 .39145 .64787 .39607 .64746 Mtetra
.396 .268 .587 r
.38802 .61674 .38354 .61587 .38745 .63233 .39197 .63326 Mtetra
.426 .293 .596 r
.38408 .60117 .37958 .60112 .38354 .61587 .38802 .61674 Mtetra
.469 .34 .622 r
.38004 .58807 .37551 .58902 .37958 .60112 .38408 .60117 Mtetra
.518 .399 .657 r
.37587 .57758 .37131 .57941 .37551 .58902 .38004 .58807 Mtetra
.567 .46 .693 r
.3716 .56923 .36701 .57171 .37131 .57941 .37587 .57758 Mtetra
.608 .515 .724 r
.36724 .56242 .36263 .56535 .36701 .57171 .3716 .56923 Mtetra
.639 .558 .747 r
.36282 .55666 .35819 .55987 .36263 .56535 .36724 .56242 Mtetra
.661 .589 .763 r
.35835 .55156 .35371 .55496 .35819 .55987 .36282 .55666 Mtetra
.676 .61 .773 r
.35385 .54688 .3492 .5504 .35371 .55496 .35835 .55156 Mtetra
.686 .623 .78 r
.34932 .54246 .34468 .54607 .3492 .5504 .35385 .54688 Mtetra
.692 .632 .784 r
.34478 .5382 .34013 .54185 .34468 .54607 .34932 .54246 Mtetra
.695 .637 .787 r
.34023 .53403 .33558 .53772 .34013 .54185 .34478 .5382 Mtetra
.698 .64 .788 r
.33566 .52992 .33101 .53363 .33558 .53772 .34023 .53403 Mtetra
.699 .642 .789 r
.33108 .52584 .32643 .52957 .33101 .53363 .33566 .52992 Mtetra
.7 .644 .79 r
.3265 .52178 .32184 .52552 .32643 .52957 .33108 .52584 Mtetra
.701 .644 .79 r
.32191 .51772 .31725 .52147 .32184 .52552 .3265 .52178 Mtetra
.701 .645 .79 r
.3173 .51367 .31265 .51742 .31725 .52147 .32191 .51772 Mtetra
.701 .645 .791 r
.31269 .50961 .30804 .51337 .31265 .51742 .3173 .51367 Mtetra
.701 .646 .791 r
.30808 .50556 .30342 .50932 .30804 .51337 .31269 .50961 Mtetra
.30345 .5015 .2988 .50527 .30342 .50932 .30808 .50556 Mtetra
.701 .645 .791 r
.29882 .49743 .29416 .50121 .2988 .50527 .30345 .5015 Mtetra
.701 .646 .791 r
.29418 .49335 .28952 .49714 .29416 .50121 .29882 .49743 Mtetra
.28953 .48927 .28488 .49307 .28952 .49714 .29418 .49335 Mtetra
.28488 .48519 .28022 .48899 .28488 .49307 .28953 .48927 Mtetra
.28022 .4811 .27556 .4849 .28022 .48899 .28488 .48519 Mtetra
.27555 .477 .27089 .48081 .27556 .4849 .28022 .4811 Mtetra
.27087 .47289 .26621 .47671 .27089 .48081 .27555 .477 Mtetra
.26619 .46878 .26153 .4726 .26621 .47671 .27087 .47289 Mtetra
.2615 .46467 .25684 .46849 .26153 .4726 .26619 .46878 Mtetra
.2568 .46054 .25214 .46437 .25684 .46849 .2615 .46467 Mtetra
.25209 .45641 .24743 .46025 .25214 .46437 .2568 .46054 Mtetra
.702 .646 .791 r
.24738 .45227 .24271 .45612 .24743 .46025 .25209 .45641 Mtetra
.701 .646 .791 r
.24265 .44812 .23799 .45198 .24271 .45612 .24738 .45227 Mtetra
.23792 .44398 .23326 .44783 .23799 .45198 .24265 .44812 Mtetra
.23319 .43982 .22853 .44368 .23326 .44783 .23792 .44398 Mtetra
.22844 .43565 .22378 .43952 .22853 .44368 .23319 .43982 Mtetra
.702 .646 .791 r
.22369 .43148 .21903 .43536 .22378 .43952 .22844 .43565 Mtetra
.701 .646 .791 r
.21893 .4273 .21427 .43118 .21903 .43536 .22369 .43148 Mtetra
.21416 .42312 .2095 .42701 .21427 .43118 .21893 .4273 Mtetra
.20939 .41893 .20472 .42282 .2095 .42701 .21416 .42312 Mtetra
.2046 .41472 .19994 .41863 .20472 .42282 .20939 .41893 Mtetra
.702 .646 .791 r
.19981 .41052 .19515 .41443 .19994 .41863 .2046 .41472 Mtetra
.701 .646 .791 r
.19501 .40631 .19035 .41022 .19515 .41443 .19981 .41052 Mtetra
.19021 .40209 .18554 .40601 .19035 .41022 .19501 .40631 Mtetra
.18539 .39786 .18073 .40179 .18554 .40601 .19021 .40209 Mtetra
.18057 .39363 .17591 .39757 .18073 .40179 .18539 .39786 Mtetra
.701 .645 .791 r
.17574 .38939 .17107 .39334 .17591 .39757 .18057 .39363 Mtetra
.702 .646 .791 r
.1709 .38514 .16624 .38909 .17107 .39334 .17574 .38939 Mtetra
.701 .646 .791 r
.16605 .38089 .16139 .38484 .16624 .38909 .1709 .38514 Mtetra
.1612 .37663 .15654 .38059 .16139 .38484 .16605 .38089 Mtetra
.15634 .37237 .15168 .37633 .15654 .38059 .1612 .37663 Mtetra
.15147 .36809 .14681 .37206 .15168 .37633 .15634 .37237 Mtetra
.702 .645 .791 r
.14659 .36381 .14193 .36779 .14681 .37206 .15147 .36809 Mtetra
.702 .646 .791 r
.14171 .35952 .13704 .36351 .14193 .36779 .14659 .36381 Mtetra
.701 .646 .791 r
.13681 .35522 .13215 .35922 .13704 .36351 .14171 .35952 Mtetra
.13191 .35092 .12725 .35492 .13215 .35922 .13681 .35522 Mtetra
.127 .34662 .12234 .35062 .12725 .35492 .13191 .35092 Mtetra
.701 .645 .79 r
.12208 .34229 .11742 .34631 .12234 .35062 .127 .34662 Mtetra
.701 .646 .791 r
.57314 .73069 .5685 .73413 .57271 .73783 .57735 .73439 Mtetra
.56892 .72699 .56428 .73043 .5685 .73413 .57314 .73069 Mtetra
.701 .645 .79 r
.5647 .72326 .56006 .72672 .56428 .73043 .56892 .72699 Mtetra
.702 .646 .79 r
.56046 .71954 .55582 .72302 .56006 .72672 .5647 .72326 Mtetra
.702 .646 .791 r
.55623 .71582 .55159 .71929 .55582 .72302 .56046 .71954 Mtetra
.55198 .7121 .54734 .71556 .55159 .71929 .55623 .71582 Mtetra
.54773 .70837 .54309 .71184 .54734 .71556 .55198 .7121 Mtetra
.54347 .70463 .53883 .70813 .54309 .71184 .54773 .70837 Mtetra
.704 .647 .79 r
.53921 .70091 .53457 .70443 .53883 .70813 .54347 .70463 Mtetra
.705 .648 .79 r
.53494 .6972 .5303 .70077 .53457 .70443 .53921 .70091 Mtetra
.709 .651 .79 r
.53066 .69354 .52602 .69717 .5303 .70077 .53494 .6972 Mtetra
.716 .656 .789 r
.52638 .68997 .52174 .69373 .52602 .69717 .53066 .69354 Mtetra
.73 .666 .787 r
.5221 .68659 .51745 .69063 .52174 .69373 .52638 .68997 Mtetra
.758 .685 .782 r
.5178 .6836 .51316 .68817 .51745 .69063 .5221 .68659 Mtetra
.805 .718 .769 r
.5135 .68136 .50886 .68697 .51316 .68817 .5178 .6836 Mtetra
.877 .766 .736 r
.5092 .68064 .50455 .68825 .50886 .68697 .5135 .68136 Mtetra
.956 .816 .664 r
.50488 .6828 .5002 .69408 .50455 .68825 .5092 .68064 Mtetra
.999 .839 .543 r
.50053 .69022 .4958 .70765 .5002 .69408 .50488 .6828 Mtetra
.961 .815 .383 r
.4961 .70623 .49127 .73197 .4958 .70765 .50053 .69022 Mtetra
.771 .705 .166 r
.49155 .73322 .48656 .76491 .49127 .73197 .4961 .70623 Mtetra
0 0 .128 r
.48682 .76647 .48176 .79161 .48656 .76491 .49155 .73322 Mtetra
.36 .069 .329 r
.48204 .78788 .47711 .79042 .48176 .79161 .48682 .76647 Mtetra
.918 .522 .152 r
.47747 .77813 .47283 .7591 .47711 .79042 .48204 .78788 Mtetra
0 0 .35 r
.47324 .74223 .46878 .71819 .47283 .7591 .47747 .77813 Mtetra
.081 0 .448 r
.46919 .70222 .46476 .68465 .46878 .71819 .47324 .74223 Mtetra
.223 .108 .503 r
.46513 .67157 .46065 .66213 .46476 .68465 .46919 .70222 Mtetra
.335 .216 .565 r
.46097 .65156 .45643 .648 .46065 .66213 .46513 .67157 Mtetra
.448 .34 .638 r
.45672 .63905 .45213 .639 .45643 .648 .46097 .65156 Mtetra
.557 .465 .706 r
.45239 .63105 .44777 .63299 .45213 .639 .45672 .63905 Mtetra
.648 .573 .757 r
.44801 .62571 .44336 .62882 .44777 .63299 .45239 .63105 Mtetra
.721 .663 .792 r
.44358 .62215 .43891 .62604 .44336 .62882 .44801 .62571 Mtetra
.787 .748 .817 r
.4391 .62008 .4344 .62466 .43891 .62604 .44358 .62215 Mtetra
.858 .842 .828 r
.43455 .61965 .42982 .62502 .4344 .62466 .4391 .62008 Mtetra
.918 .938 .803 r
.42992 .62128 .42513 .62762 .42982 .62502 .43455 .61965 Mtetra
.902 .978 .693 r
.42516 .62548 .42031 .63288 .42513 .62762 .42992 .62128 Mtetra
.763 .899 .503 r
.42026 .63233 .41535 .64059 .42031 .63288 .42516 .62548 Mtetra
0 0 0 r
.41524 .64088 .41029 .6492 .41535 .64059 .42026 .63233 Mtetra
.4102 .64846 .40527 .65545 .41029 .6492 .41524 .64088 Mtetra
.703 .977 .776 r
.40531 .65117 .40049 .65546 .40527 .65545 .4102 .64846 Mtetra
.544 .568 .829 r
.40075 .64614 .39607 .64746 .40049 .65546 .40531 .65117 Mtetra
.402 .314 .642 r
.39653 .63386 .39197 .63326 .39607 .64746 .40075 .64614 Mtetra
.389 .268 .592 r
.39253 .61776 .38802 .61674 .39197 .63326 .39653 .63386 Mtetra
.413 .281 .59 r
.38858 .60157 .38408 .60117 .38802 .61674 .39253 .61776 Mtetra
.452 .321 .611 r
.38456 .58747 .38004 .58807 .38408 .60117 .38858 .60157 Mtetra
.499 .376 .643 r
.38043 .57604 .37587 .57758 .38004 .58807 .38456 .58747 Mtetra
.549 .438 .68 r
.37619 .56695 .3716 .56923 .37587 .57758 .38043 .57604 Mtetra
.593 .496 .713 r
.37185 .55963 .36724 .56242 .3716 .56923 .37619 .56695 Mtetra
.629 .543 .739 r
.36745 .55352 .36282 .55666 .36724 .56242 .37185 .55963 Mtetra
.654 .579 .758 r
.36299 .5482 .35835 .55156 .36282 .55666 .36745 .55352 Mtetra
.672 .603 .77 r
.3585 .54338 .35385 .54688 .35835 .55156 .36299 .5482 Mtetra
.683 .619 .778 r
.35398 .53887 .34932 .54246 .35385 .54688 .3585 .54338 Mtetra
.69 .629 .783 r
.34944 .53455 .34478 .5382 .34932 .54246 .35398 .53887 Mtetra
.694 .636 .786 r
.34489 .53035 .34023 .53403 .34478 .5382 .34944 .53455 Mtetra
.697 .639 .788 r
.34032 .52621 .33566 .52992 .34023 .53403 .34489 .53035 Mtetra
.699 .642 .789 r
.33575 .52211 .33108 .52584 .33566 .52992 .34032 .52621 Mtetra
.7 .643 .79 r
.33116 .51804 .3265 .52178 .33108 .52584 .33575 .52211 Mtetra
.701 .644 .79 r
.32657 .51397 .32191 .51772 .3265 .52178 .33116 .51804 Mtetra
.701 .645 .791 r
.32197 .50991 .3173 .51367 .32191 .51772 .32657 .51397 Mtetra
.701 .645 .79 r
.31736 .50585 .31269 .50961 .3173 .51367 .32197 .50991 Mtetra
.31274 .50178 .30808 .50556 .31269 .50961 .31736 .50585 Mtetra
.702 .646 .791 r
.30812 .49771 .30345 .5015 .30808 .50556 .31274 .50178 Mtetra
.701 .646 .791 r
.30349 .49364 .29882 .49743 .30345 .5015 .30812 .49771 Mtetra
.29885 .48956 .29418 .49335 .29882 .49743 .30349 .49364 Mtetra
.701 .645 .791 r
.2942 .48547 .28953 .48927 .29418 .49335 .29885 .48956 Mtetra
.702 .646 .791 r
.28955 .48138 .28488 .48519 .28953 .48927 .2942 .48547 Mtetra
.28488 .47728 .28022 .4811 .28488 .48519 .28955 .48138 Mtetra
.701 .646 .791 r
.28022 .47318 .27555 .477 .28022 .4811 .28488 .47728 Mtetra
.27554 .46907 .27087 .47289 .27555 .477 .28022 .47318 Mtetra
.701 .645 .791 r
.27085 .46495 .26619 .46878 .27087 .47289 .27554 .46907 Mtetra
.702 .646 .791 r
.26616 .46083 .2615 .46467 .26619 .46878 .27085 .46495 Mtetra
.26146 .4567 .2568 .46054 .2615 .46467 .26616 .46083 Mtetra
.701 .646 .791 r
.25676 .45256 .25209 .45641 .2568 .46054 .26146 .4567 Mtetra
.25204 .44842 .24738 .45227 .25209 .45641 .25676 .45256 Mtetra
.24732 .44426 .24265 .44812 .24738 .45227 .25204 .44842 Mtetra
.702 .646 .791 r
.24259 .44011 .23792 .44398 .24265 .44812 .24732 .44426 Mtetra
.23786 .43594 .23319 .43982 .23792 .44398 .24259 .44011 Mtetra
.701 .646 .791 r
.23311 .43177 .22844 .43565 .23319 .43982 .23786 .43594 Mtetra
.22836 .42759 .22369 .43148 .22844 .43565 .23311 .43177 Mtetra
.2236 .42341 .21893 .4273 .22369 .43148 .22836 .42759 Mtetra
.21883 .41922 .21416 .42312 .21893 .4273 .2236 .42341 Mtetra
.702 .646 .791 r
.21405 .41502 .20939 .41893 .21416 .42312 .21883 .41922 Mtetra
.701 .646 .791 r
.20927 .41081 .2046 .41472 .20939 .41893 .21405 .41502 Mtetra
.20448 .4066 .19981 .41052 .2046 .41472 .20927 .41081 Mtetra
.19968 .40239 .19501 .40631 .19981 .41052 .20448 .4066 Mtetra
.19487 .39816 .19021 .40209 .19501 .40631 .19968 .40239 Mtetra
.701 .645 .791 r
.19006 .39393 .18539 .39786 .19021 .40209 .19487 .39816 Mtetra
.702 .646 .791 r
.18524 .38969 .18057 .39363 .18539 .39786 .19006 .39393 Mtetra
.701 .646 .791 r
.18041 .38544 .17574 .38939 .18057 .39363 .18524 .38969 Mtetra
.17557 .38119 .1709 .38514 .17574 .38939 .18041 .38544 Mtetra
.17072 .37694 .16605 .38089 .1709 .38514 .17557 .38119 Mtetra
.701 .645 .791 r
.16587 .37266 .1612 .37663 .16605 .38089 .17072 .37694 Mtetra
.702 .645 .79 r
.16101 .36839 .15634 .37237 .1612 .37663 .16587 .37266 Mtetra
.702 .646 .791 r
.15614 .36411 .15147 .36809 .15634 .37237 .16101 .36839 Mtetra
.701 .646 .791 r
.15126 .35982 .14659 .36381 .15147 .36809 .15614 .36411 Mtetra
.14638 .35553 .14171 .35952 .14659 .36381 .15126 .35982 Mtetra
.14148 .35123 .13681 .35522 .14171 .35952 .14638 .35553 Mtetra
.701 .645 .79 r
.13658 .34691 .13191 .35092 .13681 .35522 .14148 .35123 Mtetra
.702 .646 .791 r
.13167 .3426 .127 .34662 .13191 .35092 .13658 .34691 Mtetra
.701 .646 .791 r
.12675 .33827 .12208 .34229 .127 .34662 .13167 .3426 Mtetra
.702 .646 .791 r
.57779 .72724 .57314 .73069 .57735 .73439 .582 .73095 Mtetra
.57357 .72353 .56892 .72699 .57314 .73069 .57779 .72724 Mtetra
.701 .646 .791 r
.56934 .71981 .5647 .72326 .56892 .72699 .57357 .72353 Mtetra
.56511 .71608 .56046 .71954 .5647 .72326 .56934 .71981 Mtetra
.56087 .71235 .55623 .71582 .56046 .71954 .56511 .71608 Mtetra
.702 .646 .791 r
.55663 .70862 .55198 .7121 .55623 .71582 .56087 .71235 Mtetra
.55238 .70488 .54773 .70837 .55198 .7121 .55663 .70862 Mtetra
.54812 .70114 .54347 .70463 .54773 .70837 .55238 .70488 Mtetra
.703 .646 .791 r
.54386 .6974 .53921 .70091 .54347 .70463 .54812 .70114 Mtetra
.704 .647 .791 r
.53959 .69367 .53494 .6972 .53921 .70091 .54386 .6974 Mtetra
.706 .649 .791 r
.53531 .68996 .53066 .69354 .53494 .6972 .53959 .69367 Mtetra
.71 .652 .79 r
.53103 .68631 .52638 .68997 .53066 .69354 .53531 .68996 Mtetra
.719 .658 .788 r
.52675 .68276 .5221 .68659 .52638 .68997 .53103 .68631 Mtetra
.736 .67 .786 r
.52245 .67944 .5178 .6836 .5221 .68659 .52675 .68276 Mtetra
.767 .692 .779 r
.51815 .67658 .5135 .68136 .5178 .6836 .52245 .67944 Mtetra
.821 .729 .763 r
.51385 .67464 .5092 .68064 .5135 .68136 .51815 .67658 Mtetra
.898 .78 .723 r
.50954 .67447 .50488 .6828 .5092 .68064 .51385 .67464 Mtetra
.973 .826 .638 r
.50522 .67766 .50053 .69022 .50488 .6828 .50954 .67447 Mtetra
.998 .838 .505 r
.50086 .68687 .4961 .70623 .50053 .69022 .50522 .67766 Mtetra
.932 .799 .334 r
.49641 .70549 .49155 .73322 .4961 .70623 .50086 .68687 Mtetra
0 0 0 r
.49183 .73489 .48682 .76647 .49155 .73322 .49641 .70549 Mtetra
0 0 .194 r
.48709 .76726 .48204 .78788 .48682 .76647 .49183 .73489 Mtetra
.516 .182 .34 r
.48234 .78199 .47747 .77813 .48204 .78788 .48709 .76726 Mtetra
.82 .509 0 r
.47785 .76407 .47324 .74223 .47747 .77813 .48234 .78199 Mtetra
0 0 .388 r
.47366 .72519 .46919 .70222 .47324 .74223 .47785 .76407 Mtetra
.123 .026 .462 r
.46959 .68695 .46513 .67157 .46919 .70222 .47366 .72519 Mtetra
.252 .134 .518 r
.46549 .65922 .46097 .65156 .46513 .67157 .46959 .68695 Mtetra
.364 .246 .583 r
.46129 .64148 .45672 .63905 .46097 .65156 .46549 .65922 Mtetra
.479 .374 .657 r
.45701 .63043 .45239 .63105 .45672 .63905 .46129 .64148 Mtetra
.586 .499 .723 r
.45265 .62336 .44801 .62571 .45239 .63105 .45701 .63043 Mtetra
.676 .607 .771 r
.44825 .61871 .44358 .62215 .44801 .62571 .45265 .62336 Mtetra
.752 .702 .804 r
.44379 .61583 .4391 .62008 .44358 .62215 .44825 .61871 Mtetra
.827 .798 .825 r
.43928 .61462 .43455 .61965 .4391 .62008 .44379 .61583 Mtetra
.898 .902 .82 r
.43468 .61536 .42992 .62128 .43455 .61965 .43928 .61462 Mtetra
.922 .976 .749 r
.42998 .6185 .42516 .62548 .42992 .62128 .43468 .61536 Mtetra
.827 .941 .578 r
.42515 .62435 .42026 .63233 .42516 .62548 .42998 .6185 Mtetra
.653 .822 .395 r
.42018 .63245 .41524 .64088 .42026 .63233 .42515 .62435 Mtetra
0 0 0 r
.41515 .64079 .4102 .64846 .41524 .64088 .42018 .63245 Mtetra
.602 .875 .549 r
.41019 .64575 .40531 .65117 .4102 .64846 .41515 .64079 Mtetra
.668 .79 .94 r
.40549 .64376 .40075 .64614 .40531 .65117 .41019 .64575 Mtetra
.43 .368 .687 r
.40114 .63391 .39653 .63386 .40075 .64614 .40549 .64376 Mtetra
.388 .275 .602 r
.39706 .61877 .39253 .61776 .39653 .63386 .40114 .63391 Mtetra
.402 .272 .587 r
.39309 .60226 .38858 .60157 .39253 .61776 .39706 .61877 Mtetra
.436 .303 .601 r
.38909 .58724 .38456 .58747 .38858 .60157 .39309 .60226 Mtetra
.481 .354 .63 r
.38499 .57482 .38043 .57604 .38456 .58747 .38909 .58724 Mtetra
.53 .414 .666 r
.38078 .56492 .37619 .56695 .38043 .57604 .38499 .57482 Mtetra
.577 .475 .701 r
.37647 .557 .37185 .55963 .37619 .56695 .38078 .56492 Mtetra
.617 .527 .73 r
.37208 .55049 .36745 .55352 .37185 .55963 .37647 .557 Mtetra
.646 .567 .752 r
.36763 .54491 .36299 .5482 .36745 .55352 .37208 .55049 Mtetra
.666 .595 .766 r
.36315 .53993 .3585 .54338 .36299 .5482 .36763 .54491 Mtetra
.679 .614 .776 r
.35864 .53531 .35398 .53887 .3585 .54338 .36315 .53993 Mtetra
.688 .626 .781 r
.3541 .53092 .34944 .53455 .35398 .53887 .35864 .53531 Mtetra
.693 .633 .785 r
.34955 .52667 .34489 .53035 .34944 .53455 .3541 .53092 Mtetra
.696 .638 .787 r
.34499 .52251 .34032 .52621 .34489 .53035 .34955 .52667 Mtetra
.698 .641 .789 r
.34041 .51839 .33575 .52211 .34032 .52621 .34499 .52251 Mtetra
.699 .643 .79 r
.33583 .5143 .33116 .51804 .33575 .52211 .34041 .51839 Mtetra
.7 .644 .79 r
.33124 .51022 .32657 .51397 .33116 .51804 .33583 .5143 Mtetra
.701 .645 .79 r
.32664 .50614 .32197 .50991 .32657 .51397 .33124 .51022 Mtetra
.701 .645 .791 r
.32203 .50208 .31736 .50585 .32197 .50991 .32664 .50614 Mtetra
.31741 .49801 .31274 .50178 .31736 .50585 .32203 .50208 Mtetra
.31279 .49393 .30812 .49771 .31274 .50178 .31741 .49801 Mtetra
.701 .645 .79 r
.30816 .48985 .30349 .49364 .30812 .49771 .31279 .49393 Mtetra
.702 .646 .791 r
.30352 .48576 .29885 .48956 .30349 .49364 .30816 .48985 Mtetra
.701 .646 .791 r
.29887 .48167 .2942 .48547 .29885 .48956 .30352 .48576 Mtetra
.29422 .47757 .28955 .48138 .2942 .48547 .29887 .48167 Mtetra
.28956 .47347 .28488 .47728 .28955 .48138 .29422 .47757 Mtetra
.702 .646 .791 r
.28489 .46936 .28022 .47318 .28488 .47728 .28956 .47347 Mtetra
.28021 .46524 .27554 .46907 .28022 .47318 .28489 .46936 Mtetra
.701 .646 .791 r
.27553 .46112 .27085 .46495 .27554 .46907 .28021 .46524 Mtetra
.27084 .45699 .26616 .46083 .27085 .46495 .27553 .46112 Mtetra
.26614 .45285 .26146 .4567 .26616 .46083 .27084 .45699 Mtetra
.26143 .44871 .25676 .45256 .26146 .4567 .26614 .45285 Mtetra
.25672 .44456 .25204 .44842 .25676 .45256 .26143 .44871 Mtetra
.252 .4404 .24732 .44426 .25204 .44842 .25672 .44456 Mtetra
.24727 .43623 .24259 .44011 .24732 .44426 .252 .4404 Mtetra
.24253 .43206 .23786 .43594 .24259 .44011 .24727 .43623 Mtetra
.23779 .42789 .23311 .43177 .23786 .43594 .24253 .43206 Mtetra
.23303 .42371 .22836 .42759 .23311 .43177 .23779 .42789 Mtetra
.701 .645 .791 r
.22827 .41951 .2236 .42341 .22836 .42759 .23303 .42371 Mtetra
.702 .646 .791 r
.22351 .41531 .21883 .41922 .2236 .42341 .22827 .41951 Mtetra
.701 .646 .791 r
.21873 .41111 .21405 .41502 .21883 .41922 .22351 .41531 Mtetra
.21395 .4069 .20927 .41081 .21405 .41502 .21873 .41111 Mtetra
.20916 .40269 .20448 .4066 .20927 .41081 .21395 .4069 Mtetra
.701 .645 .79 r
.20436 .39845 .19968 .40239 .20448 .4066 .20916 .40269 Mtetra
.702 .646 .791 r
.19955 .39422 .19487 .39816 .19968 .40239 .20436 .39845 Mtetra
.701 .646 .791 r
.19474 .38998 .19006 .39393 .19487 .39816 .19955 .39422 Mtetra
.18992 .38574 .18524 .38969 .19006 .39393 .19474 .38998 Mtetra
.18508 .38149 .18041 .38544 .18524 .38969 .18992 .38574 Mtetra
.701 .645 .791 r
.18025 .37723 .17557 .38119 .18041 .38544 .18508 .38149 Mtetra
.702 .646 .79 r
.1754 .37296 .17072 .37694 .17557 .38119 .18025 .37723 Mtetra
.702 .646 .791 r
.17055 .36869 .16587 .37266 .17072 .37694 .1754 .37296 Mtetra
.701 .646 .791 r
.16569 .36441 .16101 .36839 .16587 .37266 .17055 .36869 Mtetra
.16082 .36012 .15614 .36411 .16101 .36839 .16569 .36441 Mtetra
.701 .645 .791 r
.15594 .35583 .15126 .35982 .15614 .36411 .16082 .36012 Mtetra
.702 .646 .79 r
.15106 .35152 .14638 .35553 .15126 .35982 .15594 .35583 Mtetra
.702 .646 .791 r
.14616 .34721 .14148 .35123 .14638 .35553 .15106 .35152 Mtetra
.701 .646 .791 r
.14126 .3429 .13658 .34691 .14148 .35123 .14616 .34721 Mtetra
.13635 .33858 .13167 .3426 .13658 .34691 .14126 .3429 Mtetra
.13143 .33425 .12675 .33827 .13167 .3426 .13635 .33858 Mtetra
.58244 .72379 .57779 .72724 .582 .73095 .58665 .7275 Mtetra
.57822 .72007 .57357 .72353 .57779 .72724 .58244 .72379 Mtetra
.574 .71634 .56934 .71981 .57357 .72353 .57822 .72007 Mtetra
.56977 .71262 .56511 .71608 .56934 .71981 .574 .71634 Mtetra
.56553 .70888 .56087 .71235 .56511 .71608 .56977 .71262 Mtetra
.702 .645 .79 r
.56129 .70513 .55663 .70862 .56087 .71235 .56553 .70888 Mtetra
.702 .646 .79 r
.55704 .70139 .55238 .70488 .55663 .70862 .56129 .70513 Mtetra
.702 .646 .791 r
.55278 .69764 .54812 .70114 .55238 .70488 .55704 .70139 Mtetra
.54852 .6939 .54386 .6974 .54812 .70114 .55278 .69764 Mtetra
.703 .647 .791 r
.54425 .69015 .53959 .69367 .54386 .6974 .54852 .6939 Mtetra
.704 .647 .79 r
.53997 .68641 .53531 .68996 .53959 .69367 .54425 .69015 Mtetra
.707 .649 .79 r
.53569 .6827 .53103 .68631 .53531 .68996 .53997 .68641 Mtetra
.712 .654 .79 r
.5314 .67906 .52675 .68276 .53103 .68631 .53569 .6827 Mtetra
.722 .661 .789 r
.52711 .67555 .52245 .67944 .52675 .68276 .5314 .67906 Mtetra
.742 .674 .785 r
.52281 .67231 .51815 .67658 .52245 .67944 .52711 .67555 Mtetra
.778 .699 .776 r
.51851 .66961 .51385 .67464 .51815 .67658 .52281 .67231 Mtetra
.839 .741 .756 r
.5142 .66799 .50954 .67447 .51385 .67464 .51851 .66961 Mtetra
.919 .794 .706 r
.50989 .66847 .50522 .67766 .50954 .67447 .5142 .66799 Mtetra
.986 .834 .608 r
.50556 .67287 .50086 .68687 .50522 .67766 .50989 .66847 Mtetra
.992 .834 .465 r
.50118 .6841 .49641 .70549 .50086 .68687 .50556 .67287 Mtetra
.892 .776 .282 r
.49673 .70544 .49183 .73489 .49641 .70549 .50118 .6841 Mtetra
0 0 0 r
.49212 .73677 .48709 .76726 .49183 .73489 .49673 .70544 Mtetra
.039 0 .249 r
.48737 .76684 .48234 .78199 .48709 .76726 .49212 .73677 Mtetra
.679 .302 .325 r
.48267 .7738 .47785 .76407 .48234 .78199 .48737 .76684 Mtetra
0 0 .198 r
.47823 .74865 .47366 .72519 .47785 .76407 .48267 .7738 Mtetra
0 0 .413 r
.47407 .70829 .46959 .68695 .47366 .72519 .47823 .74865 Mtetra
.159 .054 .476 r
.46998 .67243 .46549 .65922 .46959 .68695 .47407 .70829 Mtetra
.279 .16 .533 r
.46583 .64755 .46129 .64148 .46549 .65922 .46998 .67243 Mtetra
.393 .278 .602 r
.4616 .63187 .45701 .63043 .46129 .64148 .46583 .64755 Mtetra
.51 .41 .677 r
.45729 .62213 .45265 .62336 .45701 .63043 .4616 .63187 Mtetra
.617 .536 .74 r
.45291 .61594 .44825 .61871 .45265 .62336 .45729 .62213 Mtetra
.708 .646 .786 r
.44848 .61204 .44379 .61583 .44825 .61871 .45291 .61594 Mtetra
.79 .749 .816 r
.44399 .60998 .43928 .61462 .44379 .61583 .44848 .61204 Mtetra
.87 .858 .827 r
.43944 .60982 .43468 .61536 .43928 .61462 .44399 .60998 Mtetra
.923 .956 .789 r
.43479 .61194 .42998 .6185 .43468 .61536 .43944 .60982 Mtetra
.878 .97 .653 r
.43002 .61672 .42515 .62435 .42998 .6185 .43479 .61194 Mtetra
.72 .869 .458 r
.42511 .62408 .42018 .63245 .42515 .62435 .43002 .61672 Mtetra
0 0 0 r
.4201 .63265 .41515 .64079 .42018 .63245 .42511 .62408 Mtetra
.41511 .63934 .41019 .64575 .41515 .64079 .4201 .63265 Mtetra
.744 .978 .919 r
.4103 .64023 .40549 .64376 .41019 .64575 .41511 .63934 Mtetra
.485 .465 .76 r
.40581 .63319 .40114 .63391 .40549 .64376 .4103 .64023 Mtetra
.393 .293 .622 r
.40163 .61959 .39706 .61877 .40114 .63391 .40581 .63319 Mtetra
.393 .267 .588 r
.39762 .60317 .39309 .60226 .39706 .61877 .40163 .61959 Mtetra
.421 .288 .593 r
.39363 .58738 .38909 .58724 .39309 .60226 .39762 .60317 Mtetra
.463 .333 .618 r
.38955 .57394 .38499 .57482 .38909 .58724 .39363 .58738 Mtetra
.512 .391 .652 r
.38537 .56315 .38078 .56492 .38499 .57482 .38955 .57394 Mtetra
.56 .453 .689 r
.38108 .55457 .37647 .557 .38078 .56492 .38537 .56315 Mtetra
.603 .508 .72 r
.37671 .54759 .37208 .55049 .37647 .557 .38108 .55457 Mtetra
.636 .553 .744 r
.37228 .54169 .36763 .54491 .37208 .55049 .37671 .54759 Mtetra
.66 .586 .761 r
.36781 .5365 .36315 .53993 .36763 .54491 .37228 .54169 Mtetra
.675 .608 .772 r
.3633 .53177 .35864 .53531 .36315 .53993 .36781 .5365 Mtetra
.685 .622 .78 r
.35877 .5273 .3541 .53092 .35864 .53531 .3633 .53177 Mtetra
.691 .631 .784 r
.35422 .523 .34955 .52667 .3541 .53092 .35877 .5273 Mtetra
.695 .636 .786 r
.34966 .5188 .34499 .52251 .34955 .52667 .35422 .523 Mtetra
.698 .64 .788 r
.34509 .51466 .34041 .51839 .34499 .52251 .34966 .5188 Mtetra
.699 .642 .789 r
.34051 .51055 .33583 .5143 .34041 .51839 .34509 .51466 Mtetra
.7 .644 .79 r
.33591 .50646 .33124 .51022 .33583 .5143 .34051 .51055 Mtetra
.33131 .50238 .32664 .50614 .33124 .51022 .33591 .50646 Mtetra
.701 .645 .79 r
.32671 .4983 .32203 .50208 .32664 .50614 .33131 .50238 Mtetra
.32209 .49422 .31741 .49801 .32203 .50208 .32671 .4983 Mtetra
.701 .645 .791 r
.31747 .49014 .31279 .49393 .31741 .49801 .32209 .49422 Mtetra
.31284 .48605 .30816 .48985 .31279 .49393 .31747 .49014 Mtetra
.701 .646 .791 r
.3082 .48196 .30352 .48576 .30816 .48985 .31284 .48605 Mtetra
.30355 .47786 .29887 .48167 .30352 .48576 .3082 .48196 Mtetra
.2989 .47376 .29422 .47757 .29887 .48167 .30355 .47786 Mtetra
.701 .645 .791 r
.29424 .46965 .28956 .47347 .29422 .47757 .2989 .47376 Mtetra
.701 .646 .791 r
.28957 .46553 .28489 .46936 .28956 .47347 .29424 .46965 Mtetra
.28489 .46141 .28021 .46524 .28489 .46936 .28957 .46553 Mtetra
.28021 .45728 .27553 .46112 .28021 .46524 .28489 .46141 Mtetra
.27552 .45315 .27084 .45699 .27553 .46112 .28021 .45728 Mtetra
.701 .645 .791 r
.27082 .449 .26614 .45285 .27084 .45699 .27552 .45315 Mtetra
.702 .646 .791 r
.26611 .44485 .26143 .44871 .26614 .45285 .27082 .449 Mtetra
.2614 .44069 .25672 .44456 .26143 .44871 .26611 .44485 Mtetra
.701 .646 .791 r
.25668 .43653 .252 .4404 .25672 .44456 .2614 .44069 Mtetra
.25195 .43237 .24727 .43623 .252 .4404 .25668 .43653 Mtetra
.701 .645 .791 r
.24721 .42818 .24253 .43206 .24727 .43623 .25195 .43237 Mtetra
.702 .645 .79 r
.24247 .42399 .23779 .42789 .24253 .43206 .24721 .42818 Mtetra
.702 .646 .791 r
.23772 .4198 .23303 .42371 .23779 .42789 .24247 .42399 Mtetra
.701 .646 .791 r
.23296 .41561 .22827 .41951 .23303 .42371 .23772 .4198 Mtetra
.22819 .41141 .22351 .41531 .22827 .41951 .23296 .41561 Mtetra
.701 .645 .791 r
.22341 .4072 .21873 .41111 .22351 .41531 .22819 .41141 Mtetra
.702 .645 .79 r
.21863 .40297 .21395 .4069 .21873 .41111 .22341 .4072 Mtetra
.702 .646 .79 r
.21384 .39875 .20916 .40269 .21395 .4069 .21863 .40297 Mtetra
.701 .646 .791 r
.20904 .39452 .20436 .39845 .20916 .40269 .21384 .39875 Mtetra
.20424 .39029 .19955 .39422 .20436 .39845 .20904 .39452 Mtetra
.19942 .38604 .19474 .38998 .19955 .39422 .20424 .39029 Mtetra
.702 .645 .79 r
.1946 .38178 .18992 .38574 .19474 .38998 .19942 .38604 Mtetra
.702 .646 .79 r
.18977 .37752 .18508 .38149 .18992 .38574 .1946 .38178 Mtetra
.701 .646 .791 r
.18493 .37326 .18025 .37723 .18508 .38149 .18977 .37752 Mtetra
.18009 .36899 .1754 .37296 .18025 .37723 .18493 .37326 Mtetra
.17523 .36471 .17055 .36869 .1754 .37296 .18009 .36899 Mtetra
.17037 .36042 .16569 .36441 .17055 .36869 .17523 .36471 Mtetra
.702 .646 .791 r
.1655 .35613 .16082 .36012 .16569 .36441 .17037 .36042 Mtetra
.701 .646 .791 r
.16063 .35182 .15594 .35583 .16082 .36012 .1655 .35613 Mtetra
.15574 .34752 .15106 .35152 .15594 .35583 .16063 .35182 Mtetra
.15085 .3432 .14616 .34721 .15106 .35152 .15574 .34752 Mtetra
.14595 .33888 .14126 .3429 .14616 .34721 .15085 .3432 Mtetra
.702 .646 .791 r
.14104 .33455 .13635 .33858 .14126 .3429 .14595 .33888 Mtetra
.701 .646 .791 r
.13612 .33021 .13143 .33425 .13635 .33858 .14104 .33455 Mtetra
.5871 .72033 .58244 .72379 .58665 .7275 .59131 .72405 Mtetra
.58288 .71661 .57822 .72007 .58244 .72379 .5871 .72033 Mtetra
.57866 .71287 .574 .71634 .57822 .72007 .58288 .71661 Mtetra
.702 .646 .791 r
.57443 .70914 .56977 .71262 .574 .71634 .57866 .71287 Mtetra
.57019 .7054 .56553 .70888 .56977 .71262 .57443 .70914 Mtetra
.701 .646 .791 r
.56595 .70165 .56129 .70513 .56553 .70888 .57019 .7054 Mtetra
.5617 .6979 .55704 .70139 .56129 .70513 .56595 .70165 Mtetra
.702 .646 .791 r
.55744 .69414 .55278 .69764 .55704 .70139 .5617 .6979 Mtetra
.702 .646 .79 r
.55318 .69038 .54852 .6939 .55278 .69764 .55744 .69414 Mtetra
.702 .646 .791 r
.54891 .68662 .54425 .69015 .54852 .6939 .55318 .69038 Mtetra
.703 .647 .791 r
.54464 .68287 .53997 .68641 .54425 .69015 .54891 .68662 Mtetra
.704 .648 .791 r
.54035 .67913 .53569 .6827 .53997 .68641 .54464 .68287 Mtetra
.708 .65 .79 r
.53607 .67542 .5314 .67906 .53569 .6827 .54035 .67913 Mtetra
.714 .655 .789 r
.53177 .6718 .52711 .67555 .5314 .67906 .53607 .67542 Mtetra
.726 .663 .788 r
.52747 .66833 .52281 .67231 .52711 .67555 .53177 .6718 Mtetra
.749 .68 .784 r
.52317 .66519 .51851 .66961 .52281 .67231 .52747 .66833 Mtetra
.791 .709 .773 r
.51886 .66269 .5142 .66799 .51851 .66961 .52317 .66519 Mtetra
.858 .754 .747 r
.51455 .66147 .50989 .66847 .5142 .66799 .51886 .66269 Mtetra
.939 .806 .686 r
.51023 .6627 .50556 .67287 .50989 .66847 .51455 .66147 Mtetra
.995 .838 .575 r
.5059 .66849 .50118 .6841 .50556 .67287 .51023 .6627 Mtetra
.978 .826 .422 r
.50152 .68195 .49673 .70544 .50118 .6841 .5059 .66849 Mtetra
.836 .744 .224 r
.49704 .70605 .49212 .73677 .49673 .70544 .50152 .68195 Mtetra
0 0 .052 r
.49241 .73858 .48737 .76684 .49212 .73677 .49704 .70605 Mtetra
.195 0 .291 r
.48766 .76478 .48267 .7738 .48737 .76684 .49241 .73858 Mtetra
.836 .426 .264 r
.48301 .76336 .47823 .74865 .48267 .7738 .48766 .76478 Mtetra
0 0 .296 r
.47863 .7323 .47407 .70829 .47823 .74865 .48301 .76336 Mtetra
.028 0 .432 r
.47447 .69182 .46998 .67243 .47407 .70829 .47863 .7323 Mtetra
.192 .081 .489 r
.47035 .65868 .46583 .64755 .46998 .67243 .47447 .69182 Mtetra
.308 .188 .549 r
.46617 .6365 .4616 .63187 .46583 .64755 .47035 .65868 Mtetra
.424 .312 .622 r
.4619 .6227 .45729 .62213 .4616 .63187 .46617 .6365 Mtetra
.543 .447 .696 r
.45756 .61417 .45291 .61594 .45729 .62213 .4619 .6227 Mtetra
.651 .576 .758 r
.45316 .60885 .44848 .61204 .45291 .61594 .45756 .61417 Mtetra
.745 .692 .801 r
.4487 .60578 .44399 .60998 .44848 .61204 .45316 .60885 Mtetra
.833 .806 .825 r
.44418 .6047 .43944 .60982 .44399 .60998 .4487 .60578 Mtetra
.908 .92 .814 r
.43957 .60581 .43479 .61194 .43944 .60982 .44418 .6047 Mtetra
.911 .98 .718 r
.43486 .60951 .43002 .61672 .43479 .61194 .43957 .60581 Mtetra
.786 .916 .53 r
.43002 .61593 .42511 .62408 .43002 .61672 .43486 .60951 Mtetra
.616 .796 .366 r
.42505 .62427 .4201 .63265 .42511 .62408 .43002 .61593 Mtetra
0 0 0 r
.42005 .63209 .41511 .63934 .4201 .63265 .42505 .62427 Mtetra
.669 .948 .696 r
.41516 .63555 .4103 .64023 .41511 .63934 .42005 .63209 Mtetra
.582 .633 .867 r
.41054 .63151 .40581 .63319 .4103 .64023 .41516 .63555 Mtetra
.41 .329 .654 r
.40624 .61999 .40163 .61959 .40581 .63319 .41054 .63151 Mtetra
.388 .269 .594 r
.40217 .60417 .39762 .60317 .40163 .61959 .40624 .61999 Mtetra
.409 .277 .589 r
.39817 .58785 .39363 .58738 .39762 .60317 .40217 .60417 Mtetra
.446 .314 .607 r
.39411 .57344 .38955 .57394 .39363 .58738 .39817 .58785 Mtetra
.493 .368 .639 r
.38996 .56169 .38537 .56315 .38955 .57394 .39411 .57344 Mtetra
.543 .43 .675 r
.3857 .55234 .38108 .55457 .38537 .56315 .38996 .56169 Mtetra
.588 .489 .709 r
.38135 .54482 .37671 .54759 .38108 .55457 .3857 .55234 Mtetra
.625 .538 .736 r
.37693 .53857 .37228 .54169 .37671 .54759 .38135 .54482 Mtetra
.651 .575 .756 r
.37247 .53315 .36781 .5365 .37228 .54169 .37693 .53857 Mtetra
.67 .6 .769 r
.36797 .52826 .3633 .53177 .36781 .5365 .37247 .53315 Mtetra
.682 .617 .777 r
.36345 .5237 .35877 .5273 .3633 .53177 .36797 .52826 Mtetra
.689 .628 .782 r
.3589 .51934 .35422 .523 .35877 .5273 .36345 .5237 Mtetra
.694 .635 .786 r
.35434 .51509 .34966 .5188 .35422 .523 .3589 .51934 Mtetra
.697 .639 .788 r
.34977 .51093 .34509 .51466 .34966 .5188 .35434 .51509 Mtetra
.699 .642 .789 r
.34519 .50681 .34051 .51055 .34509 .51466 .34977 .51093 Mtetra
.7 .643 .79 r
.3406 .5027 .33591 .50646 .34051 .51055 .34519 .50681 Mtetra
.7 .644 .79 r
.336 .49861 .33131 .50238 .33591 .50646 .3406 .5027 Mtetra
.701 .644 .79 r
.33139 .49451 .32671 .4983 .33131 .50238 .336 .49861 Mtetra
.701 .645 .79 r
.32678 .49043 .32209 .49422 .32671 .4983 .33139 .49451 Mtetra
.701 .646 .791 r
.32215 .48635 .31747 .49014 .32209 .49422 .32678 .49043 Mtetra
.31752 .48226 .31284 .48605 .31747 .49014 .32215 .48635 Mtetra
.701 .645 .791 r
.31288 .47815 .3082 .48196 .31284 .48605 .31752 .48226 Mtetra
.701 .645 .79 r
.30824 .47404 .30355 .47786 .3082 .48196 .31288 .47815 Mtetra
.702 .646 .791 r
.30358 .46993 .2989 .47376 .30355 .47786 .30824 .47404 Mtetra
.701 .646 .791 r
.29892 .46582 .29424 .46965 .2989 .47376 .30358 .46993 Mtetra
.29425 .4617 .28957 .46553 .29424 .46965 .29892 .46582 Mtetra
.28958 .45757 .28489 .46141 .28957 .46553 .29425 .4617 Mtetra
.701 .645 .79 r
.2849 .45343 .28021 .45728 .28489 .46141 .28958 .45757 Mtetra
.702 .646 .791 r
.28021 .44929 .27552 .45315 .28021 .45728 .2849 .45343 Mtetra
.701 .646 .791 r
.27551 .44514 .27082 .449 .27552 .45315 .28021 .44929 Mtetra
.2708 .44099 .26611 .44485 .27082 .449 .27551 .44514 Mtetra
.26609 .43682 .2614 .44069 .26611 .44485 .2708 .44099 Mtetra
.701 .645 .79 r
.26137 .43265 .25668 .43653 .2614 .44069 .26609 .43682 Mtetra
.702 .646 .79 r
.25664 .42847 .25195 .43237 .25668 .43653 .26137 .43265 Mtetra
.702 .646 .791 r
.2519 .42429 .24721 .42818 .25195 .43237 .25664 .42847 Mtetra
.701 .646 .791 r
.24716 .4201 .24247 .42399 .24721 .42818 .2519 .42429 Mtetra
.24241 .41591 .23772 .4198 .24247 .42399 .24716 .4201 Mtetra
.23765 .4117 .23296 .41561 .23772 .4198 .24241 .41591 Mtetra
.702 .646 .79 r
.23288 .40749 .22819 .41141 .23296 .41561 .23765 .4117 Mtetra
.702 .646 .791 r
.2281 .40327 .22341 .4072 .22819 .41141 .23288 .40749 Mtetra
.701 .646 .791 r
.22332 .39905 .21863 .40297 .22341 .4072 .2281 .40327 Mtetra
.21853 .39482 .21384 .39875 .21863 .40297 .22332 .39905 Mtetra
.21373 .39058 .20904 .39452 .21384 .39875 .21853 .39482 Mtetra
.702 .646 .791 r
.20893 .38633 .20424 .39029 .20904 .39452 .21373 .39058 Mtetra
.20411 .38208 .19942 .38604 .20424 .39029 .20893 .38633 Mtetra
.701 .646 .791 r
.19929 .37782 .1946 .38178 .19942 .38604 .20411 .38208 Mtetra
.19446 .37356 .18977 .37752 .1946 .38178 .19929 .37782 Mtetra
.18963 .36929 .18493 .37326 .18977 .37752 .19446 .37356 Mtetra
.18478 .36501 .18009 .36899 .18493 .37326 .18963 .36929 Mtetra
.17993 .36072 .17523 .36471 .18009 .36899 .18478 .36501 Mtetra
.17507 .35643 .17037 .36042 .17523 .36471 .17993 .36072 Mtetra
.1702 .35213 .1655 .35613 .17037 .36042 .17507 .35643 Mtetra
.16532 .34782 .16063 .35182 .1655 .35613 .1702 .35213 Mtetra
.16043 .34351 .15574 .34752 .16063 .35182 .16532 .34782 Mtetra
.15554 .33918 .15085 .3432 .15574 .34752 .16043 .34351 Mtetra
.15064 .33485 .14595 .33888 .15085 .3432 .15554 .33918 Mtetra
.702 .646 .791 r
.14573 .33052 .14104 .33455 .14595 .33888 .15064 .33485 Mtetra
.701 .646 .791 r
.14081 .32618 .13612 .33021 .14104 .33455 .14573 .33052 Mtetra
.702 .646 .791 r
.59176 .71686 .5871 .72033 .59131 .72405 .59597 .72059 Mtetra
.58755 .71313 .58288 .71661 .5871 .72033 .59176 .71686 Mtetra
.701 .646 .791 r
.58332 .7094 .57866 .71287 .58288 .71661 .58755 .71313 Mtetra
.57909 .70566 .57443 .70914 .57866 .71287 .58332 .7094 Mtetra
.57486 .70191 .57019 .7054 .57443 .70914 .57909 .70566 Mtetra
.702 .646 .791 r
.57062 .69816 .56595 .70165 .57019 .7054 .57486 .70191 Mtetra
.56637 .6944 .5617 .6979 .56595 .70165 .57062 .69816 Mtetra
.56211 .69064 .55744 .69414 .5617 .6979 .56637 .6944 Mtetra
.55785 .68688 .55318 .69038 .55744 .69414 .56211 .69064 Mtetra
.55358 .68311 .54891 .68662 .55318 .69038 .55785 .68688 Mtetra
.54931 .67934 .54464 .68287 .54891 .68662 .55358 .68311 Mtetra
.703 .647 .79 r
.54503 .67557 .54035 .67913 .54464 .68287 .54931 .67934 Mtetra
.705 .648 .79 r
.54074 .67183 .53607 .67542 .54035 .67913 .54503 .67557 Mtetra
.709 .651 .79 r
.53644 .66813 .53177 .6718 .53607 .67542 .54074 .67183 Mtetra
.716 .657 .789 r
.53215 .66453 .52747 .66833 .53177 .6718 .53644 .66813 Mtetra
.731 .667 .787 r
.52784 .66111 .52317 .66519 .52747 .66833 .53215 .66453 Mtetra
.758 .686 .782 r
.52353 .65808 .51886 .66269 .52317 .66519 .52784 .66111 Mtetra
.806 .719 .769 r
.51922 .65582 .51455 .66147 .51886 .66269 .52353 .65808 Mtetra
.878 .768 .736 r
.51491 .65507 .51023 .6627 .51455 .66147 .51922 .65582 Mtetra
.958 .818 .663 r
.51058 .6572 .5059 .66849 .51023 .6627 .51491 .65507 Mtetra
.999 .84 .539 r
.50624 .66457 .50152 .68195 .5059 .66849 .51058 .6572 Mtetra
.958 .814 .376 r
.50185 .68046 .49704 .70605 .50152 .68195 .50624 .66457 Mtetra
.764 .701 .161 r
.49735 .7072 .49241 .73858 .49704 .70605 .50185 .68046 Mtetra
0 0 .124 r
.4927 .73996 .48766 .76478 .49241 .73858 .49735 .7072 Mtetra
.352 .058 .319 r
.48797 .7608 .48301 .76336 .48766 .76478 .4927 .73996 Mtetra
.912 .514 .126 r
.48336 .75091 .47863 .7323 .48301 .76336 .48797 .7608 Mtetra
0 0 .354 r
.47903 .71541 .47447 .69182 .47863 .7323 .48336 .75091 Mtetra
.079 0 .448 r
.47487 .67592 .47035 .65868 .47447 .69182 .47903 .71541 Mtetra
.222 .107 .503 r
.47072 .64569 .46617 .6365 .47035 .65868 .47487 .67592 Mtetra
.337 .218 .567 r
.4665 .62604 .4619 .6227 .46617 .6365 .47072 .64569 Mtetra
.456 .348 .643 r
.4622 .61396 .45756 .61417 .4619 .6227 .4665 .62604 Mtetra
.578 .488 .717 r
.45783 .60656 .45316 .60885 .45756 .61417 .4622 .61396 Mtetra
.688 .621 .776 r
.4534 .60216 .4487 .60578 .45316 .60885 .45783 .60656 Mtetra
.789 .748 .815 r
.44891 .60004 .44418 .6047 .4487 .60578 .4534 .60216 Mtetra
.879 .872 .826 r
.44434 .60013 .43957 .60581 .44418 .6047 .44891 .60004 Mtetra
.925 .968 .77 r
.43968 .60272 .43486 .60951 .43957 .60581 .44434 .60013 Mtetra
.849 .955 .609 r
.4349 .60809 .43002 .61593 .43486 .60951 .43968 .60272 Mtetra
.675 .838 .416 r
.42999 .61586 .42505 .62427 .43002 .61593 .4349 .60809 Mtetra
0 0 0 r
.425 .62425 .42005 .63209 .42505 .62427 .42999 .61586 Mtetra
.578 .845 .496 r
.42006 .62978 .41516 .63555 .42005 .63209 .425 .62425 Mtetra
.708 .868 .958 r
.41533 .62874 .41054 .63151 .41516 .63555 .42006 .62978 Mtetra
.445 .395 .708 r
.4109 .61978 .40624 .61999 .41054 .63151 .41533 .62874 Mtetra
.389 .279 .608 r
.40675 .6051 .40217 .60417 .40624 .61999 .4109 .61978 Mtetra
.398 .269 .587 r
.40272 .58859 .39817 .58785 .40217 .60417 .40675 .6051 Mtetra
.431 .298 .598 r
.39867 .57331 .39411 .57344 .39817 .58785 .40272 .58859 Mtetra
.475 .347 .626 r
.39455 .56055 .38996 .56169 .39411 .57344 .39867 .57331 Mtetra
.524 .407 .661 r
.39031 .55037 .3857 .55234 .38996 .56169 .39455 .56055 Mtetra
.572 .468 .697 r
.38599 .54223 .38135 .54482 .3857 .55234 .39031 .55037 Mtetra
.612 .521 .727 r
.38159 .53556 .37693 .53857 .38135 .54482 .38599 .54223 Mtetra
.643 .562 .749 r
.37714 .52986 .37247 .53315 .37693 .53857 .38159 .53556 Mtetra
.664 .592 .764 r
.37265 .52479 .36797 .52826 .37247 .53315 .37714 .52986 Mtetra
.678 .612 .774 r
.36813 .52011 .36345 .5237 .36797 .52826 .37265 .52479 Mtetra
.687 .625 .781 r
.36358 .51568 .3589 .51934 .36345 .5237 .36813 .52011 Mtetra
.692 .633 .785 r
.35903 .5114 .35434 .51509 .3589 .51934 .36358 .51568 Mtetra
.696 .638 .787 r
.35446 .5072 .34977 .51093 .35434 .51509 .35903 .5114 Mtetra
.698 .641 .788 r
.34988 .50305 .34519 .50681 .34977 .51093 .35446 .5072 Mtetra
.7 .642 .789 r
.34529 .49893 .3406 .5027 .34519 .50681 .34988 .50305 Mtetra
.7 .644 .79 r
.34069 .49483 .336 .49861 .3406 .5027 .34529 .49893 Mtetra
.701 .645 .791 r
.33608 .49074 .33139 .49451 .336 .49861 .34069 .49483 Mtetra
.33147 .48664 .32678 .49043 .33139 .49451 .33608 .49074 Mtetra
.32684 .48254 .32215 .48635 .32678 .49043 .33147 .48664 Mtetra
.702 .645 .79 r
.32221 .47844 .31752 .48226 .32215 .48635 .32684 .48254 Mtetra
.702 .646 .79 r
.31758 .47433 .31288 .47815 .31752 .48226 .32221 .47844 Mtetra
.701 .646 .791 r
.31293 .47022 .30824 .47404 .31288 .47815 .31758 .47433 Mtetra
.30828 .46611 .30358 .46993 .30824 .47404 .31293 .47022 Mtetra
.30362 .46199 .29892 .46582 .30358 .46993 .30828 .46611 Mtetra
.702 .645 .79 r
.29895 .45785 .29425 .4617 .29892 .46582 .30362 .46199 Mtetra
.702 .646 .791 r
.29427 .45372 .28958 .45757 .29425 .4617 .29895 .45785 Mtetra
.701 .646 .791 r
.28959 .44958 .2849 .45343 .28958 .45757 .29427 .45372 Mtetra
.2849 .44543 .28021 .44929 .2849 .45343 .28959 .44958 Mtetra
.2802 .44128 .27551 .44514 .28021 .44929 .2849 .44543 Mtetra
.701 .645 .791 r
.2755 .43711 .2708 .44099 .27551 .44514 .2802 .44128 Mtetra
.702 .646 .79 r
.27078 .43294 .26609 .43682 .2708 .44099 .2755 .43711 Mtetra
.701 .646 .791 r
.26606 .42876 .26137 .43265 .26609 .43682 .27078 .43294 Mtetra
.26133 .42458 .25664 .42847 .26137 .43265 .26606 .42876 Mtetra
.2566 .4204 .2519 .42429 .25664 .42847 .26133 .42458 Mtetra
.25185 .4162 .24716 .4201 .2519 .42429 .2566 .4204 Mtetra
.702 .646 .791 r
.2471 .41199 .24241 .41591 .24716 .4201 .25185 .4162 Mtetra
.701 .646 .791 r
.24234 .40778 .23765 .4117 .24241 .41591 .2471 .41199 Mtetra
.23758 .40357 .23288 .40749 .23765 .4117 .24234 .40778 Mtetra
.2328 .39934 .2281 .40327 .23288 .40749 .23758 .40357 Mtetra
.22802 .39511 .22332 .39905 .2281 .40327 .2328 .39934 Mtetra
.22323 .39088 .21853 .39482 .22332 .39905 .22802 .39511 Mtetra
.21843 .38663 .21373 .39058 .21853 .39482 .22323 .39088 Mtetra
.21363 .38238 .20893 .38633 .21373 .39058 .21843 .38663 Mtetra
.20881 .37812 .20411 .38208 .20893 .38633 .21363 .38238 Mtetra
.20399 .37386 .19929 .37782 .20411 .38208 .20881 .37812 Mtetra
.19916 .36959 .19446 .37356 .19929 .37782 .20399 .37386 Mtetra
.19432 .36531 .18963 .36929 .19446 .37356 .19916 .36959 Mtetra
.702 .646 .791 r
.18948 .36102 .18478 .36501 .18963 .36929 .19432 .36531 Mtetra
.701 .646 .791 r
.18463 .35673 .17993 .36072 .18478 .36501 .18948 .36102 Mtetra
.17976 .35243 .17507 .35643 .17993 .36072 .18463 .35673 Mtetra
.1749 .34812 .1702 .35213 .17507 .35643 .17976 .35243 Mtetra
.17002 .34381 .16532 .34782 .1702 .35213 .1749 .34812 Mtetra
.702 .646 .791 r
.16513 .33949 .16043 .34351 .16532 .34782 .17002 .34381 Mtetra
.16024 .33516 .15554 .33918 .16043 .34351 .16513 .33949 Mtetra
.701 .646 .791 r
.15534 .33082 .15064 .33485 .15554 .33918 .16024 .33516 Mtetra
.15043 .32648 .14573 .33052 .15064 .33485 .15534 .33082 Mtetra
.14551 .32213 .14081 .32618 .14573 .33052 .15043 .32648 Mtetra
.59643 .7134 .59176 .71686 .59597 .72059 .60064 .71713 Mtetra
.59222 .70967 .58755 .71313 .59176 .71686 .59643 .7134 Mtetra
.701 .645 .791 r
.588 .70592 .58332 .7094 .58755 .71313 .59222 .70967 Mtetra
.702 .646 .791 r
.58377 .70217 .57909 .70566 .58332 .7094 .588 .70592 Mtetra
.57953 .69842 .57486 .70191 .57909 .70566 .58377 .70217 Mtetra
.701 .646 .791 r
.57529 .69467 .57062 .69816 .57486 .70191 .57953 .69842 Mtetra
.57104 .6909 .56637 .6944 .57062 .69816 .57529 .69467 Mtetra
.56679 .68713 .56211 .69064 .56637 .6944 .57104 .6909 Mtetra
.702 .646 .791 r
.56253 .68336 .55785 .68688 .56211 .69064 .56679 .68713 Mtetra
.55826 .67958 .55358 .68311 .55785 .68688 .56253 .68336 Mtetra
.55398 .67581 .54931 .67934 .55358 .68311 .55826 .67958 Mtetra
.5497 .67203 .54503 .67557 .54931 .67934 .55398 .67581 Mtetra
.704 .647 .791 r
.54542 .66826 .54074 .67183 .54503 .67557 .5497 .67203 Mtetra
.706 .649 .79 r
.54112 .66451 .53644 .66813 .54074 .67183 .54542 .66826 Mtetra
.711 .652 .79 r
.53682 .66083 .53215 .66453 .53644 .66813 .54112 .66451 Mtetra
.719 .659 .789 r
.53252 .65725 .52784 .66111 .53215 .66453 .53682 .66083 Mtetra
.736 .671 .786 r
.52821 .6539 .52353 .65808 .52784 .66111 .53252 .65725 Mtetra
.768 .693 .78 r
.5239 .65101 .51922 .65582 .52353 .65808 .52821 .6539 Mtetra
.822 .731 .763 r
.51958 .64903 .51491 .65507 .51922 .65582 .5239 .65101 Mtetra
.9 .782 .723 r
.51526 .64884 .51058 .6572 .51491 .65507 .51958 .64903 Mtetra
.974 .828 .636 r
.51094 .65201 .50624 .66457 .51058 .6572 .51526 .64884 Mtetra
.998 .839 .501 r
.50659 .66117 .50185 .68046 .50624 .66457 .51094 .65201 Mtetra
.928 .796 .328 r
.50219 .67965 .49735 .7072 .50185 .68046 .50659 .66117 Mtetra
0 0 0 r
.49767 .70871 .4927 .73996 .49735 .7072 .50219 .67965 Mtetra
0 0 .189 r
.493 .74051 .48797 .7608 .4927 .73996 .49767 .70871 Mtetra
.512 .173 .329 r
.48828 .7547 .48336 .75091 .48797 .7608 .493 .74051 Mtetra
.798 .492 0 r
.48373 .73677 .47903 .71541 .48336 .75091 .48828 .7547 Mtetra
0 0 .39 r
.47943 .69837 .47487 .67592 .47903 .71541 .48373 .73677 Mtetra
.122 .026 .462 r
.47526 .6607 .47072 .64569 .47487 .67592 .47943 .69837 Mtetra
.251 .133 .518 r
.47107 .63344 .4665 .62604 .47072 .64569 .47526 .6607 Mtetra
.367 .25 .586 r
.46681 .61614 .4622 .61396 .4665 .62604 .47107 .63344 Mtetra
.491 .388 .665 r
.46248 .60563 .45783 .60656 .4622 .61396 .46681 .61614 Mtetra
.616 .533 .739 r
.45808 .59936 .4534 .60216 .45783 .60656 .46248 .60563 Mtetra
.732 .674 .794 r
.45363 .59594 .44891 .60004 .4534 .60216 .45808 .59936 Mtetra
.838 .812 .825 r
.4491 .59493 .44434 .60013 .44891 .60004 .45363 .59594 Mtetra
.916 .937 .806 r
.44449 .59641 .43968 .60272 .44434 .60013 .4491 .59493 Mtetra
.895 .977 .684 r
.43976 .60065 .4349 .60809 .43968 .60272 .44449 .59641 Mtetra
.745 .888 .486 r
.43491 .60758 .42999 .61586 .4349 .60809 .43976 .60065 Mtetra
0 0 0 r
.42996 .61602 .425 .62425 .42999 .61586 .43491 .60758 Mtetra
.42499 .62307 .42006 .62978 .425 .62425 .42996 .61602 Mtetra
.733 .991 .859 r
.42017 .62482 .41533 .62874 .42006 .62978 .42499 .62307 Mtetra
.512 .512 .792 r
.41562 .61874 .4109 .61978 .41533 .62874 .42017 .62482 Mtetra
.397 .303 .631 r
.41136 .60578 .40675 .6051 .4109 .61978 .41562 .61874 Mtetra
.391 .267 .59 r
.40729 .58951 .40272 .58859 .40675 .6051 .41136 .60578 Mtetra
.417 .284 .591 r
.40324 .57352 .39867 .57331 .40272 .58859 .40729 .58951 Mtetra
.457 .326 .614 r
.39913 .55978 .39455 .56055 .39867 .57331 .40324 .57352 Mtetra
.505 .383 .648 r
.39493 .54868 .39031 .55037 .39455 .56055 .39913 .55978 Mtetra
.554 .445 .684 r
.39063 .53984 .38599 .54223 .39031 .55037 .39493 .54868 Mtetra
.598 .502 .716 r
.38625 .53267 .38159 .53556 .38599 .54223 .39063 .53984 Mtetra
.632 .548 .741 r
.38181 .52664 .37714 .52986 .38159 .53556 .38625 .53267 Mtetra
.657 .582 .76 r
.37733 .52137 .37265 .52479 .37714 .52986 .38181 .52664 Mtetra
.673 .606 .772 r
.37281 .51657 .36813 .52011 .37265 .52479 .37733 .52137 Mtetra
.684 .621 .779 r
.36827 .51206 .36358 .51568 .36813 .52011 .37281 .51657 Mtetra
.69 .63 .783 r
.36372 .50771 .35903 .5114 .36358 .51568 .36827 .51206 Mtetra
.695 .636 .785 r
.35915 .50346 .35446 .5072 .35903 .5114 .36372 .50771 Mtetra
.698 .64 .788 r
.35457 .4993 .34988 .50305 .35446 .5072 .35915 .50346 Mtetra
.699 .643 .79 r
.34998 .49517 .34529 .49893 .34988 .50305 .35457 .4993 Mtetra
.699 .644 .79 r
.34539 .49106 .34069 .49483 .34529 .49893 .34998 .49517 Mtetra
.7 .644 .79 r
.34078 .48695 .33608 .49074 .34069 .49483 .34539 .49106 Mtetra
.701 .644 .79 r
.33617 .48283 .33147 .48664 .33608 .49074 .34078 .48695 Mtetra
.702 .645 .79 r
.33154 .47873 .32684 .48254 .33147 .48664 .33617 .48283 Mtetra
.701 .646 .791 r
.32691 .47463 .32221 .47844 .32684 .48254 .33154 .47873 Mtetra
.32228 .47052 .31758 .47433 .32221 .47844 .32691 .47463 Mtetra
.701 .645 .791 r
.31763 .4664 .31293 .47022 .31758 .47433 .32228 .47052 Mtetra
.702 .645 .79 r
.31298 .46227 .30828 .46611 .31293 .47022 .31763 .4664 Mtetra
.702 .646 .791 r
.30832 .45814 .30362 .46199 .30828 .46611 .31298 .46227 Mtetra
.701 .646 .791 r
.30365 .45401 .29895 .45785 .30362 .46199 .30832 .45814 Mtetra
.29898 .44987 .29427 .45372 .29895 .45785 .30365 .45401 Mtetra
.29429 .44572 .28959 .44958 .29427 .45372 .29898 .44987 Mtetra
.2896 .44156 .2849 .44543 .28959 .44958 .29429 .44572 Mtetra
.702 .646 .791 r
.28491 .4374 .2802 .44128 .2849 .44543 .2896 .44156 Mtetra
.2802 .43323 .2755 .43711 .2802 .44128 .28491 .4374 Mtetra
.701 .646 .791 r
.27549 .42906 .27078 .43294 .2755 .43711 .2802 .43323 Mtetra
.27077 .42487 .26606 .42876 .27078 .43294 .27549 .42906 Mtetra
.26604 .42069 .26133 .42458 .26606 .42876 .27077 .42487 Mtetra
.702 .646 .791 r
.2613 .41649 .2566 .4204 .26133 .42458 .26604 .42069 Mtetra
.25656 .41229 .25185 .4162 .2566 .4204 .2613 .41649 Mtetra
.701 .646 .791 r
.25181 .40808 .2471 .41199 .25185 .4162 .25656 .41229 Mtetra
.24705 .40386 .24234 .40778 .2471 .41199 .25181 .40808 Mtetra
.24228 .39964 .23758 .40357 .24234 .40778 .24705 .40386 Mtetra
.23751 .39541 .2328 .39934 .23758 .40357 .24228 .39964 Mtetra
.23272 .39117 .22802 .39511 .2328 .39934 .23751 .39541 Mtetra
.22793 .38693 .22323 .39088 .22802 .39511 .23272 .39117 Mtetra
.22314 .38268 .21843 .38663 .22323 .39088 .22793 .38693 Mtetra
.21833 .37842 .21363 .38238 .21843 .38663 .22314 .38268 Mtetra
.21352 .37416 .20881 .37812 .21363 .38238 .21833 .37842 Mtetra
.701 .645 .791 r
.2087 .36989 .20399 .37386 .20881 .37812 .21352 .37416 Mtetra
.701 .646 .791 r
.20387 .36561 .19916 .36959 .20399 .37386 .2087 .36989 Mtetra
.19903 .36132 .19432 .36531 .19916 .36959 .20387 .36561 Mtetra
.19419 .35703 .18948 .36102 .19432 .36531 .19903 .36132 Mtetra
.18933 .35273 .18463 .35673 .18948 .36102 .19419 .35703 Mtetra
.701 .645 .791 r
.18447 .34842 .17976 .35243 .18463 .35673 .18933 .35273 Mtetra
.701 .646 .791 r
.1796 .34411 .1749 .34812 .17976 .35243 .18447 .34842 Mtetra
.17473 .33979 .17002 .34381 .1749 .34812 .1796 .34411 Mtetra
.16984 .33546 .16513 .33949 .17002 .34381 .17473 .33979 Mtetra
.16495 .33113 .16024 .33516 .16513 .33949 .16984 .33546 Mtetra
.701 .645 .791 r
.16005 .32678 .15534 .33082 .16024 .33516 .16495 .33113 Mtetra
.701 .646 .791 r
.15514 .32244 .15043 .32648 .15534 .33082 .16005 .32678 Mtetra
.702 .646 .791 r
.15022 .31808 .14551 .32213 .15043 .32648 .15514 .32244 Mtetra
.60111 .70992 .59643 .7134 .60064 .71713 .60532 .71366 Mtetra
.5969 .70618 .59222 .70967 .59643 .7134 .60111 .70992 Mtetra
.701 .646 .791 r
.59268 .70244 .588 .70592 .59222 .70967 .5969 .70618 Mtetra
.58845 .69869 .58377 .70217 .588 .70592 .59268 .70244 Mtetra
.58421 .69493 .57953 .69842 .58377 .70217 .58845 .69869 Mtetra
.702 .646 .791 r
.57997 .69116 .57529 .69467 .57953 .69842 .58421 .69493 Mtetra
.57572 .6874 .57104 .6909 .57529 .69467 .57997 .69116 Mtetra
.701 .646 .791 r
.57147 .68362 .56679 .68713 .57104 .6909 .57572 .6874 Mtetra
.56721 .67984 .56253 .68336 .56679 .68713 .57147 .68362 Mtetra
.702 .646 .791 r
.56294 .67606 .55826 .67958 .56253 .68336 .56721 .67984 Mtetra
.55867 .67227 .55398 .67581 .55826 .67958 .56294 .67606 Mtetra
.55439 .66848 .5497 .67203 .55398 .67581 .55867 .67227 Mtetra
.703 .647 .791 r
.5501 .6647 .54542 .66826 .5497 .67203 .55439 .66848 Mtetra
.704 .648 .79 r
.54581 .66092 .54112 .66451 .54542 .66826 .5501 .6647 Mtetra
.707 .65 .79 r
.54151 .65718 .53682 .66083 .54112 .66451 .54581 .66092 Mtetra
.712 .654 .79 r
.5372 .65351 .53252 .65725 .53682 .66083 .54151 .65718 Mtetra
.723 .661 .789 r
.53289 .64996 .52821 .6539 .53252 .65725 .5372 .65351 Mtetra
.743 .675 .785 r
.52858 .64669 .5239 .65101 .52821 .6539 .53289 .64996 Mtetra
.78 .701 .777 r
.52426 .64397 .51958 .64903 .5239 .65101 .52858 .64669 Mtetra
.84 .743 .756 r
.51994 .64234 .51526 .64884 .51958 .64903 .52426 .64397 Mtetra
.921 .797 .706 r
.51562 .64281 .51094 .65201 .51526 .64884 .51994 .64234 Mtetra
.987 .836 .606 r
.51129 .64719 .50659 .66117 .51094 .65201 .51562 .64281 Mtetra
.99 .834 .459 r
.50694 .65835 .50219 .67965 .50659 .66117 .51129 .64719 Mtetra
.886 .772 .275 r
.50253 .67951 .49767 .70871 .50219 .67965 .50694 .65835 Mtetra
0 0 0 r
.49799 .71041 .493 .74051 .49767 .70871 .50253 .67951 Mtetra
.033 0 .242 r
.49331 .73982 .48828 .7547 .493 .74051 .49799 .71041 Mtetra
.68 .295 .311 r
.48862 .7463 .48373 .73677 .48828 .7547 .49331 .73982 Mtetra
0 0 .217 r
.48411 .72128 .47943 .69837 .48373 .73677 .48862 .7463 Mtetra
0 0 .415 r
.47983 .68152 .47526 .6607 .47943 .69837 .48411 .72128 Mtetra
.158 .054 .476 r
.47564 .64628 .47107 .63344 .47526 .6607 .47983 .68152 Mtetra
.28 .161 .534 r
.47142 .62193 .46681 .61614 .47107 .63344 .47564 .64628 Mtetra
.399 .285 .607 r
.46712 .60679 .46248 .60563 .46681 .61614 .47142 .62193 Mtetra
.529 .431 .688 r
.46276 .59774 .45808 .59936 .46248 .60563 .46712 .60679 Mtetra
.66 .586 .761 r
.45833 .5926 .45363 .59594 .45808 .59936 .46276 .59774 Mtetra
.782 .739 .813 r
.45384 .59031 .4491 .59493 .45363 .59594 .45833 .5926 Mtetra
.887 .884 .824 r
.44927 .59061 .44449 .59641 .4491 .59493 .45384 .59031 Mtetra
.921 .976 .748 r
.4446 .59366 .43976 .60065 .44449 .59641 .44927 .59061 Mtetra
.813 .934 .564 r
.43981 .59957 .43491 .60758 .43976 .60065 .4446 .59366 Mtetra
.636 .811 .384 r
.43491 .60764 .42996 .61602 .43491 .60758 .43981 .59957 Mtetra
0 0 0 r
.42994 .61562 .42499 .62307 .42996 .61602 .43491 .60764 Mtetra
.635 .913 .622 r
.42506 .61977 .42017 .62482 .42499 .62307 .42994 .61562 Mtetra
.624 .706 .905 r
.4204 .61669 .41562 .61874 .42017 .62482 .42506 .61977 Mtetra
.419 .347 .669 r
.41603 .60596 .41136 .60578 .41562 .61874 .4204 .61669 Mtetra
.387 .271 .598 r
.41188 .59048 .40729 .58951 .41136 .60578 .41603 .60596 Mtetra
.404 .273 .588 r
.40782 .57408 .40324 .57352 .40729 .58951 .41188 .59048 Mtetra
.44 .308 .604 r
.40372 .55937 .39913 .55978 .40324 .57352 .40782 .57408 Mtetra
.487 .361 .634 r
.39954 .54728 .39493 .54868 .39913 .55978 .40372 .55937 Mtetra
.537 .422 .67 r
.39527 .53765 .39063 .53984 .39493 .54868 .39954 .54728 Mtetra
.583 .482 .705 r
.39091 .52994 .38625 .53267 .39063 .53984 .39527 .53765 Mtetra
.62 .533 .734 r
.38648 .52355 .38181 .52664 .38625 .53267 .39091 .52994 Mtetra
.648 .57 .754 r
.38201 .51802 .37733 .52137 .38181 .52664 .38648 .52355 Mtetra
.668 .597 .767 r
.3775 .51304 .37281 .51657 .37733 .52137 .38201 .51802 Mtetra
.681 .615 .776 r
.37297 .50842 .36827 .51206 .37281 .51657 .3775 .51304 Mtetra
.689 .628 .782 r
.36842 .50403 .36372 .50771 .36827 .51206 .37297 .50842 Mtetra
.693 .635 .786 r
.36385 .49976 .35915 .50346 .36372 .50771 .36842 .50403 Mtetra
.696 .638 .788 r
.35928 .49556 .35457 .4993 .35915 .50346 .36385 .49976 Mtetra
.699 .641 .788 r
.35469 .49139 .34998 .49517 .35457 .4993 .35928 .49556 Mtetra
.7 .643 .789 r
.35009 .48726 .34539 .49106 .34998 .49517 .35469 .49139 Mtetra
.701 .644 .79 r
.34549 .48315 .34078 .48695 .34539 .49106 .35009 .48726 Mtetra
.7 .645 .791 r
.34087 .47904 .33617 .48283 .34078 .48695 .34549 .48315 Mtetra
.701 .645 .791 r
.33625 .47493 .33154 .47873 .33617 .48283 .34087 .47904 Mtetra
.701 .645 .79 r
.33162 .47081 .32691 .47463 .33154 .47873 .33625 .47493 Mtetra
.702 .645 .79 r
.32698 .46669 .32228 .47052 .32691 .47463 .33162 .47081 Mtetra
.702 .646 .791 r
.32234 .46256 .31763 .4664 .32228 .47052 .32698 .46669 Mtetra
.701 .646 .791 r
.31769 .45844 .31298 .46227 .31763 .4664 .32234 .46256 Mtetra
.31303 .4543 .30832 .45814 .31298 .46227 .31769 .45844 Mtetra
.30836 .45016 .30365 .45401 .30832 .45814 .31303 .4543 Mtetra
.702 .646 .791 r
.30368 .44601 .29898 .44987 .30365 .45401 .30836 .45016 Mtetra
.701 .646 .791 r
.299 .44186 .29429 .44572 .29898 .44987 .30368 .44601 Mtetra
.29431 .43769 .2896 .44156 .29429 .44572 .299 .44186 Mtetra
.28961 .43352 .28491 .4374 .2896 .44156 .29431 .43769 Mtetra
.28491 .42935 .2802 .43323 .28491 .4374 .28961 .43352 Mtetra
.2802 .42517 .27549 .42906 .2802 .43323 .28491 .42935 Mtetra
.27548 .42098 .27077 .42487 .27549 .42906 .2802 .42517 Mtetra
.701 .645 .791 r
.27075 .41678 .26604 .42069 .27077 .42487 .27548 .42098 Mtetra
.701 .646 .791 r
.26601 .41258 .2613 .41649 .26604 .42069 .27075 .41678 Mtetra
.26127 .40837 .25656 .41229 .2613 .41649 .26601 .41258 Mtetra
.25652 .40416 .25181 .40808 .25656 .41229 .26127 .40837 Mtetra
.25176 .39994 .24705 .40386 .25181 .40808 .25652 .40416 Mtetra
.701 .645 .791 r
.24699 .39571 .24228 .39964 .24705 .40386 .25176 .39994 Mtetra
.702 .646 .791 r
.24222 .39147 .23751 .39541 .24228 .39964 .24699 .39571 Mtetra
.701 .646 .791 r
.23744 .38723 .23272 .39117 .23751 .39541 .24222 .39147 Mtetra
.23265 .38298 .22793 .38693 .23272 .39117 .23744 .38723 Mtetra
.22785 .37872 .22314 .38268 .22793 .38693 .23265 .38298 Mtetra
.701 .645 .791 r
.22304 .37446 .21833 .37842 .22314 .38268 .22785 .37872 Mtetra
.702 .646 .791 r
.21823 .37018 .21352 .37416 .21833 .37842 .22304 .37446 Mtetra
.701 .646 .791 r
.21341 .36591 .2087 .36989 .21352 .37416 .21823 .37018 Mtetra
.20858 .36163 .20387 .36561 .2087 .36989 .21341 .36591 Mtetra
.20374 .35733 .19903 .36132 .20387 .36561 .20858 .36163 Mtetra
.1989 .35303 .19419 .35703 .19903 .36132 .20374 .35733 Mtetra
.702 .646 .791 r
.19405 .34873 .18933 .35273 .19419 .35703 .1989 .35303 Mtetra
.701 .646 .791 r
.18919 .34441 .18447 .34842 .18933 .35273 .19405 .34873 Mtetra
.18432 .3401 .1796 .34411 .18447 .34842 .18919 .34441 Mtetra
.17944 .33577 .17473 .33979 .1796 .34411 .18432 .3401 Mtetra
.17455 .33143 .16984 .33546 .17473 .33979 .17944 .33577 Mtetra
.702 .646 .791 r
.16966 .32709 .16495 .33113 .16984 .33546 .17455 .33143 Mtetra
.701 .646 .791 r
.16476 .32274 .16005 .32678 .16495 .33113 .16966 .32709 Mtetra
.15985 .31839 .15514 .32244 .16005 .32678 .16476 .32274 Mtetra
.15493 .31402 .15022 .31808 .15514 .32244 .15985 .31839 Mtetra
.6058 .70645 .60111 .70992 .60532 .71366 .61001 .71019 Mtetra
.60158 .7027 .5969 .70618 .60111 .70992 .6058 .70645 Mtetra
.59736 .69895 .59268 .70244 .5969 .70618 .60158 .7027 Mtetra
.59314 .69519 .58845 .69869 .59268 .70244 .59736 .69895 Mtetra
.5889 .69143 .58421 .69493 .58845 .69869 .59314 .69519 Mtetra
.58466 .68766 .57997 .69116 .58421 .69493 .5889 .69143 Mtetra
.702 .646 .791 r
.58041 .68388 .57572 .6874 .57997 .69116 .58466 .68766 Mtetra
.57616 .68011 .57147 .68362 .57572 .6874 .58041 .68388 Mtetra
.701 .646 .791 r
.5719 .67632 .56721 .67984 .57147 .68362 .57616 .68011 Mtetra
.56763 .67253 .56294 .67606 .56721 .67984 .5719 .67632 Mtetra
.702 .646 .791 r
.56336 .66873 .55867 .67227 .56294 .67606 .56763 .67253 Mtetra
.55908 .66494 .55439 .66848 .55867 .67227 .56336 .66873 Mtetra
.702 .647 .791 r
.55479 .66114 .5501 .6647 .55439 .66848 .55908 .66494 Mtetra
.703 .647 .791 r
.5505 .65735 .54581 .66092 .5501 .6647 .55479 .66114 Mtetra
.705 .648 .791 r
.5462 .65357 .54151 .65718 .54581 .66092 .5505 .65735 Mtetra
.708 .65 .79 r
.5419 .64983 .5372 .65351 .54151 .65718 .5462 .65357 Mtetra
.715 .655 .789 r
.53759 .64617 .53289 .64996 .5372 .65351 .5419 .64983 Mtetra
.727 .664 .788 r
.53327 .64268 .52858 .64669 .53289 .64996 .53759 .64617 Mtetra
.75 .681 .784 r
.52895 .63951 .52426 .64397 .52858 .64669 .53327 .64268 Mtetra
.793 .711 .774 r
.52463 .63699 .51994 .64234 .52426 .64397 .52895 .63951 Mtetra
.86 .756 .747 r
.52031 .63576 .51562 .64281 .51994 .64234 .52463 .63699 Mtetra
.942 .81 .685 r
.51598 .637 .51129 .64719 .51562 .64281 .52031 .63576 Mtetra
.996 .841 .571 r
.51165 .64278 .50694 .65835 .51129 .64719 .51598 .637 Mtetra
.975 .825 .415 r
.5073 .65618 .50253 .67951 .50694 .65835 .51165 .64278 Mtetra
.828 .739 .216 r
.50287 .68004 .49799 .71041 .50253 .67951 .5073 .65618 Mtetra
0 0 .05 r
.49832 .71202 .49331 .73982 .49799 .71041 .50287 .68004 Mtetra
.186 0 .281 r
.49363 .73744 .48862 .7463 .49331 .73982 .49832 .71202 Mtetra
.839 .421 .241 r
.48896 .73562 .48411 .72128 .48862 .7463 .49363 .73744 Mtetra
0 0 .307 r
.4845 .70489 .47983 .68152 .48411 .72128 .48896 .73562 Mtetra
.03 0 .433 r
.48023 .66513 .47564 .64628 .47983 .68152 .4845 .70489 Mtetra
.191 .081 .49 r
.47601 .63267 .47142 .62193 .47564 .64628 .48023 .66513 Mtetra
.309 .191 .551 r
.47175 .6111 .46712 .60679 .47142 .62193 .47601 .63267 Mtetra
.434 .324 .629 r
.46742 .59797 .46276 .59774 .46712 .60679 .47175 .6111 Mtetra
.571 .48 .713 r
.46303 .59034 .45833 .5926 .46276 .59774 .46742 .59797 Mtetra
.711 .647 .784 r
.45857 .5864 .45384 .59031 .45833 .5926 .46303 .59034 Mtetra
.839 .813 .825 r
.45404 .58538 .44927 .59061 .45384 .59031 .45857 .5864 Mtetra
.921 .949 .796 r
.44942 .58719 .4446 .59366 .44927 .59061 .45404 .58538 Mtetra
.871 .968 .647 r
.44469 .59195 .43981 .59957 .4446 .59366 .44942 .58719 Mtetra
.701 .858 .443 r
.43984 .59931 .43491 .60764 .43981 .59957 .44469 .59195 Mtetra
0 0 0 r
.4349 .60764 .42994 .61562 .43491 .60764 .43984 .59931 Mtetra
.562 .821 .455 r
.42998 .61366 .42506 .61977 .42994 .61562 .4349 .60764 Mtetra
.734 .934 .954 r
.42522 .61354 .4204 .61669 .42506 .61977 .42998 .61366 Mtetra
.461 .426 .732 r
.42074 .6055 .41603 .60596 .4204 .61669 .42522 .61354 Mtetra
.39 .285 .614 r
.41651 .59132 .41188 .59048 .41603 .60596 .42074 .6055 Mtetra
.396 .268 .587 r
.41241 .57484 .40782 .57408 .41188 .59048 .41651 .59132 Mtetra
.426 .293 .595 r
.40832 .55932 .40372 .55937 .40782 .57408 .41241 .57484 Mtetra
.468 .339 .622 r
.40416 .54625 .39954 .54728 .40372 .55937 .40832 .55932 Mtetra
.517 .398 .657 r
.39991 .53576 .39527 .53765 .39954 .54728 .40416 .54625 Mtetra
.566 .46 .692 r
.39557 .52739 .39091 .52994 .39527 .53765 .39991 .53576 Mtetra
.608 .515 .723 r
.39116 .52054 .38648 .52355 .39091 .52994 .39557 .52739 Mtetra
.64 .558 .747 r
.3867 .51473 .38201 .51802 .38648 .52355 .39116 .52054 Mtetra
.661 .589 .763 r
.3822 .50958 .3775 .51304 .38201 .51802 .3867 .51473 Mtetra
.676 .61 .774 r
.37767 .50484 .37297 .50842 .3775 .51304 .3822 .50958 Mtetra
.686 .623 .78 r
.37312 .50036 .36842 .50403 .37297 .50842 .37767 .50484 Mtetra
.692 .632 .784 r
.36856 .49604 .36385 .49976 .36842 .50403 .37312 .50036 Mtetra
.696 .637 .787 r
.36399 .4918 .35928 .49556 .36385 .49976 .36856 .49604 Mtetra
.698 .64 .788 r
.3594 .48762 .35469 .49139 .35928 .49556 .36399 .4918 Mtetra
.699 .642 .789 r
.3548 .48348 .35009 .48726 .35469 .49139 .3594 .48762 Mtetra
.7 .644 .79 r
.3502 .47935 .34549 .48315 .35009 .48726 .3548 .48348 Mtetra
.701 .645 .79 r
.34558 .47523 .34087 .47904 .34549 .48315 .3502 .47935 Mtetra
.34096 .47111 .33625 .47493 .34087 .47904 .34558 .47523 Mtetra
.33633 .46698 .33162 .47081 .33625 .47493 .34096 .47111 Mtetra
.3317 .46285 .32698 .46669 .33162 .47081 .33633 .46698 Mtetra
.701 .646 .791 r
.32705 .45873 .32234 .46256 .32698 .46669 .3317 .46285 Mtetra
.3224 .4546 .31769 .45844 .32234 .46256 .32705 .45873 Mtetra
.31774 .45045 .31303 .4543 .31769 .45844 .3224 .4546 Mtetra
.701 .645 .791 r
.31307 .4463 .30836 .45016 .31303 .4543 .31774 .45045 Mtetra
.702 .646 .791 r
.3084 .44215 .30368 .44601 .30836 .45016 .31307 .4463 Mtetra
.30372 .43798 .299 .44186 .30368 .44601 .3084 .44215 Mtetra
.701 .646 .791 r
.29903 .43382 .29431 .43769 .299 .44186 .30372 .43798 Mtetra
.29433 .42965 .28961 .43352 .29431 .43769 .29903 .43382 Mtetra
.701 .645 .791 r
.28963 .42546 .28491 .42935 .28961 .43352 .29433 .42965 Mtetra
.702 .646 .791 r
.28491 .42127 .2802 .42517 .28491 .42935 .28963 .42546 Mtetra
.28019 .41708 .27548 .42098 .2802 .42517 .28491 .42127 Mtetra
.701 .646 .791 r
.27547 .41288 .27075 .41678 .27548 .42098 .28019 .41708 Mtetra
.27073 .40867 .26601 .41258 .27075 .41678 .27547 .41288 Mtetra
.26599 .40445 .26127 .40837 .26601 .41258 .27073 .40867 Mtetra
.702 .646 .791 r
.26124 .40023 .25652 .40416 .26127 .40837 .26599 .40445 Mtetra
.25648 .396 .25176 .39994 .25652 .40416 .26124 .40023 Mtetra
.701 .646 .791 r
.25171 .39177 .24699 .39571 .25176 .39994 .25648 .396 Mtetra
.24694 .38753 .24222 .39147 .24699 .39571 .25171 .39177 Mtetra
.24216 .38327 .23744 .38723 .24222 .39147 .24694 .38753 Mtetra
.702 .646 .791 r
.23737 .37902 .23265 .38298 .23744 .38723 .24216 .38327 Mtetra
.23257 .37475 .22785 .37872 .23265 .38298 .23737 .37902 Mtetra
.701 .646 .791 r
.22776 .37049 .22304 .37446 .22785 .37872 .23257 .37475 Mtetra
.22295 .36621 .21823 .37018 .22304 .37446 .22776 .37049 Mtetra
.21813 .36192 .21341 .36591 .21823 .37018 .22295 .36621 Mtetra
.702 .646 .791 r
.2133 .35763 .20858 .36163 .21341 .36591 .21813 .36192 Mtetra
.20846 .35333 .20374 .35733 .20858 .36163 .2133 .35763 Mtetra
.701 .646 .791 r
.20362 .34903 .1989 .35303 .20374 .35733 .20846 .35333 Mtetra
.19877 .34471 .19405 .34873 .1989 .35303 .20362 .34903 Mtetra
.19391 .34039 .18919 .34441 .19405 .34873 .19877 .34471 Mtetra
.702 .646 .791 r
.18904 .33607 .18432 .3401 .18919 .34441 .19391 .34039 Mtetra
.701 .646 .791 r
.18416 .33173 .17944 .33577 .18432 .3401 .18904 .33607 Mtetra
.17928 .32739 .17455 .33143 .17944 .33577 .18416 .33173 Mtetra
.17438 .32305 .16966 .32709 .17455 .33143 .17928 .32739 Mtetra
.16948 .31869 .16476 .32274 .16966 .32709 .17438 .32305 Mtetra
.702 .646 .791 r
.16457 .31433 .15985 .31839 .16476 .32274 .16948 .31869 Mtetra
.701 .646 .791 r
.15966 .30996 .15493 .31402 .15985 .31839 .16457 .31433 Mtetra
.61049 .70296 .6058 .70645 .61001 .71019 .6147 .70671 Mtetra
.60628 .69921 .60158 .7027 .6058 .70645 .61049 .70296 Mtetra
.60206 .69545 .59736 .69895 .60158 .7027 .60628 .69921 Mtetra
.702 .646 .791 r
.59783 .69169 .59314 .69519 .59736 .69895 .60206 .69545 Mtetra
.701 .646 .791 r
.5936 .68792 .5889 .69143 .59314 .69519 .59783 .69169 Mtetra
.58936 .68415 .58466 .68766 .5889 .69143 .5936 .68792 Mtetra
.58511 .68037 .58041 .68388 .58466 .68766 .58936 .68415 Mtetra
.58086 .67659 .57616 .68011 .58041 .68388 .58511 .68037 Mtetra
.702 .646 .791 r
.5766 .67279 .5719 .67632 .57616 .68011 .58086 .67659 Mtetra
.57233 .669 .56763 .67253 .5719 .67632 .5766 .67279 Mtetra
.56806 .6652 .56336 .66873 .56763 .67253 .57233 .669 Mtetra
.56378 .66139 .55908 .66494 .56336 .66873 .56806 .6652 Mtetra
.55949 .65759 .55479 .66114 .55908 .66494 .56378 .66139 Mtetra
.703 .646 .79 r
.5552 .65378 .5505 .65735 .55479 .66114 .55949 .65759 Mtetra
.704 .647 .791 r
.5509 .64998 .5462 .65357 .5505 .65735 .5552 .65378 Mtetra
.705 .649 .791 r
.5466 .6462 .5419 .64983 .5462 .65357 .5509 .64998 Mtetra
.709 .652 .79 r
.54229 .64247 .53759 .64617 .5419 .64983 .5466 .6462 Mtetra
.717 .657 .789 r
.53797 .63883 .53327 .64268 .53759 .64617 .54229 .64247 Mtetra
.732 .667 .787 r
.53365 .63539 .52895 .63951 .53327 .64268 .53797 .63883 Mtetra
.759 .687 .782 r
.52932 .63234 .52463 .63699 .52895 .63951 .53365 .63539 Mtetra
.808 .722 .77 r
.525 .63008 .52031 .63576 .52463 .63699 .52932 .63234 Mtetra
.881 .772 .737 r
.52067 .62933 .51598 .637 .52031 .63576 .525 .63008 Mtetra
.961 .822 .662 r
.51635 .63148 .51165 .64278 .51598 .637 .52067 .62933 Mtetra
.999 .842 .534 r
.51202 .63884 .5073 .65618 .51165 .64278 .51635 .63148 Mtetra
.952 .812 .368 r
.50766 .65466 .50287 .68004 .5073 .65618 .51202 .63884 Mtetra
.755 .696 .154 r
.50322 .68108 .49832 .71202 .50287 .68004 .50766 .65466 Mtetra
0 0 .121 r
.49865 .71314 .49363 .73744 .49832 .71202 .50322 .68108 Mtetra
.344 .046 .307 r
.49396 .73312 .48896 .73562 .49363 .73744 .49865 .71314 Mtetra
.902 .503 .09 r
.48932 .72295 .4845 .70489 .48896 .73562 .49396 .73312 Mtetra
0 0 .361 r
.48489 .688 .48023 .66513 .4845 .70489 .48932 .72295 Mtetra
.08 0 .449 r
.48061 .64936 .47601 .63267 .48023 .66513 .48489 .688 Mtetra
.222 .108 .504 r
.47636 .6199 .47175 .6111 .47601 .63267 .48061 .64936 Mtetra
.341 .224 .571 r
.47207 .60094 .46742 .59797 .47175 .6111 .47636 .6199 Mtetra
.474 .368 .654 r
.46772 .58969 .46303 .59034 .46742 .59797 .47207 .60094 Mtetra
.62 .538 .74 r
.46329 .58348 .45857 .5864 .46303 .59034 .46772 .58969 Mtetra
.769 .721 .808 r
.4588 .58086 .45404 .58538 .45857 .5864 .46329 .58348 Mtetra
.892 .894 .823 r
.45423 .58131 .44942 .58719 .45404 .58538 .4588 .58086 Mtetra
.913 .98 .725 r
.44955 .58479 .44469 .59195 .44942 .58719 .45423 .58131 Mtetra
.778 .911 .523 r
.44476 .59117 .43984 .59931 .44469 .59195 .44955 .58479 Mtetra
0 0 0 r
.43986 .59938 .4349 .60764 .43984 .59931 .44476 .59117 Mtetra
.43493 .60671 .42998 .61366 .4349 .60764 .43986 .59938 Mtetra
.706 .979 .786 r
.4301 .60924 .42522 .61354 .42998 .61366 .43493 .60671 Mtetra
.544 .566 .827 r
.4255 .60412 .42074 .6055 .42522 .61354 .4301 .60924 Mtetra
.402 .314 .642 r
.42118 .59184 .41651 .59132 .42074 .6055 .4255 .60412 Mtetra
.388 .267 .591 r
.41703 .57578 .41241 .57484 .41651 .59132 .42118 .59184 Mtetra
.412 .279 .59 r
.41293 .55963 .40832 .55932 .41241 .57484 .41703 .57578 Mtetra
.451 .32 .61 r
.40878 .54556 .40416 .54625 .40832 .55932 .41293 .55963 Mtetra
.499 .375 .643 r
.40455 .53413 .39991 .53576 .40416 .54625 .40878 .54556 Mtetra
.548 .437 .679 r
.40023 .52503 .39557 .52739 .39991 .53576 .40455 .53413 Mtetra
.593 .495 .713 r
.39584 .51768 .39116 .52054 .39557 .52739 .40023 .52503 Mtetra
.628 .543 .739 r
.39139 .51153 .3867 .51473 .39116 .52054 .39584 .51768 Mtetra
.654 .578 .758 r
.3869 .50616 .3822 .50958 .3867 .51473 .39139 .51153 Mtetra
.671 .603 .77 r
.38238 .50128 .37767 .50484 .3822 .50958 .3869 .50616 Mtetra
.683 .619 .778 r
.37784 .49671 .37312 .50036 .37767 .50484 .38238 .50128 Mtetra
.69 .629 .783 r
.37328 .49233 .36856 .49604 .37312 .50036 .37784 .49671 Mtetra
.694 .636 .786 r
.3687 .48806 .36399 .4918 .36856 .49604 .37328 .49233 Mtetra
.697 .64 .788 r
.36412 .48386 .3594 .48762 .36399 .4918 .3687 .48806 Mtetra
.699 .642 .789 r
.35952 .47969 .3548 .48348 .3594 .48762 .36412 .48386 Mtetra
.7 .643 .79 r
.35492 .47555 .3502 .47935 .3548 .48348 .35952 .47969 Mtetra
.701 .644 .79 r
.3503 .47141 .34558 .47523 .3502 .47935 .35492 .47555 Mtetra
.701 .645 .79 r
.34568 .46728 .34096 .47111 .34558 .47523 .3503 .47141 Mtetra
.701 .645 .791 r
.34105 .46315 .33633 .46698 .34096 .47111 .34568 .46728 Mtetra
.701 .646 .791 r
.33642 .45902 .3317 .46285 .33633 .46698 .34105 .46315 Mtetra
.33177 .45489 .32705 .45873 .3317 .46285 .33642 .45902 Mtetra
.702 .645 .79 r
.32712 .45074 .3224 .4546 .32705 .45873 .33177 .45489 Mtetra
.702 .646 .791 r
.32246 .44659 .31774 .45045 .3224 .4546 .32712 .45074 Mtetra
.701 .646 .791 r
.3178 .44244 .31307 .4463 .31774 .45045 .32246 .44659 Mtetra
.31312 .43828 .3084 .44215 .31307 .4463 .3178 .44244 Mtetra
.30844 .43411 .30372 .43798 .3084 .44215 .31312 .43828 Mtetra
.702 .646 .791 r
.30375 .42994 .29903 .43382 .30372 .43798 .30844 .43411 Mtetra
.29905 .42575 .29433 .42965 .29903 .43382 .30375 .42994 Mtetra
.701 .646 .791 r
.29435 .42157 .28963 .42546 .29433 .42965 .29905 .42575 Mtetra
.28964 .41737 .28491 .42127 .28963 .42546 .29435 .42157 Mtetra
.28492 .41317 .28019 .41708 .28491 .42127 .28964 .41737 Mtetra
.28019 .40896 .27547 .41288 .28019 .41708 .28492 .41317 Mtetra
.702 .646 .791 r
.27545 .40475 .27073 .40867 .27547 .41288 .28019 .40896 Mtetra
.701 .646 .791 r
.27071 .40053 .26599 .40445 .27073 .40867 .27545 .40475 Mtetra
.26596 .3963 .26124 .40023 .26599 .40445 .27071 .40053 Mtetra
.2612 .39207 .25648 .396 .26124 .40023 .26596 .3963 Mtetra
.25644 .38782 .25171 .39177 .25648 .396 .2612 .39207 Mtetra
.25166 .38357 .24694 .38753 .25171 .39177 .25644 .38782 Mtetra
.24688 .37932 .24216 .38327 .24694 .38753 .25166 .38357 Mtetra
.24209 .37505 .23737 .37902 .24216 .38327 .24688 .37932 Mtetra
.2373 .37079 .23257 .37475 .23737 .37902 .24209 .37505 Mtetra
.23249 .36651 .22776 .37049 .23257 .37475 .2373 .37079 Mtetra
.22768 .36222 .22295 .36621 .22776 .37049 .23249 .36651 Mtetra
.22286 .35793 .21813 .36192 .22295 .36621 .22768 .36222 Mtetra
.21803 .35363 .2133 .35763 .21813 .36192 .22286 .35793 Mtetra
.21319 .34933 .20846 .35333 .2133 .35763 .21803 .35363 Mtetra
.20835 .34502 .20362 .34903 .20846 .35333 .21319 .34933 Mtetra
.20349 .3407 .19877 .34471 .20362 .34903 .20835 .34502 Mtetra
.19863 .33637 .19391 .34039 .19877 .34471 .20349 .3407 Mtetra
.19377 .33204 .18904 .33607 .19391 .34039 .19863 .33637 Mtetra
.18889 .3277 .18416 .33173 .18904 .33607 .19377 .33204 Mtetra
.184 .32335 .17928 .32739 .18416 .33173 .18889 .3277 Mtetra
.17911 .319 .17438 .32305 .17928 .32739 .184 .32335 Mtetra
.17421 .31463 .16948 .31869 .17438 .32305 .17911 .319 Mtetra
.1693 .31026 .16457 .31433 .16948 .31869 .17421 .31463 Mtetra
.16439 .30589 .15966 .30996 .16457 .31433 .1693 .31026 Mtetra
.61519 .69947 .61049 .70296 .6147 .70671 .6194 .70323 Mtetra
.61098 .69572 .60628 .69921 .61049 .70296 .61519 .69947 Mtetra
.60676 .69196 .60206 .69545 .60628 .69921 .61098 .69572 Mtetra
.60253 .68819 .59783 .69169 .60206 .69545 .60676 .69196 Mtetra
.5983 .68442 .5936 .68792 .59783 .69169 .60253 .68819 Mtetra
.701 .645 .791 r
.59406 .68063 .58936 .68415 .5936 .68792 .5983 .68442 Mtetra
.702 .646 .791 r
.58981 .67685 .58511 .68037 .58936 .68415 .59406 .68063 Mtetra
.701 .646 .791 r
.58556 .67306 .58086 .67659 .58511 .68037 .58981 .67685 Mtetra
.5813 .66927 .5766 .67279 .58086 .67659 .58556 .67306 Mtetra
.57703 .66547 .57233 .669 .5766 .67279 .5813 .66927 Mtetra
.701 .645 .791 r
.57276 .66165 .56806 .6652 .57233 .669 .57703 .66547 Mtetra
.702 .646 .79 r
.56848 .65784 .56378 .66139 .56806 .6652 .57276 .66165 Mtetra
.702 .646 .791 r
.5642 .65402 .55949 .65759 .56378 .66139 .56848 .65784 Mtetra
.702 .647 .791 r
.55991 .65021 .5552 .65378 .55949 .65759 .5642 .65402 Mtetra
.55561 .6464 .5509 .64998 .5552 .65378 .55991 .65021 Mtetra
.704 .647 .79 r
.5513 .64259 .5466 .6462 .5509 .64998 .55561 .6464 Mtetra
.706 .649 .79 r
.54699 .63881 .54229 .64247 .5466 .6462 .5513 .64259 Mtetra
.711 .653 .79 r
.54268 .63508 .53797 .63883 .54229 .64247 .54699 .63881 Mtetra
.72 .66 .789 r
.53835 .63149 .53365 .63539 .53797 .63883 .54268 .63508 Mtetra
.737 .672 .787 r
.53403 .62812 .52932 .63234 .53365 .63539 .53835 .63149 Mtetra
.769 .695 .78 r
.5297 .62522 .525 .63008 .52932 .63234 .53403 .62812 Mtetra
.825 .733 .764 r
.52537 .62324 .52067 .62933 .525 .63008 .5297 .62522 Mtetra
.903 .786 .722 r
.52104 .62307 .51635 .63148 .52067 .62933 .52537 .62324 Mtetra
.977 .833 .634 r
.51672 .62628 .51202 .63884 .51635 .63148 .52104 .62307 Mtetra
.996 .84 .494 r
.51239 .63546 .50766 .65466 .51202 .63884 .51672 .62628 Mtetra
.92 .793 .319 r
.50803 .65383 .50322 .68108 .50766 .65466 .51239 .63546 Mtetra
0 0 0 r
.50358 .68244 .49865 .71314 .50322 .68108 .50803 .65383 Mtetra
0 0 .182 r
.49898 .71334 .49396 .73312 .49865 .71314 .50358 .68244 Mtetra
.51 .163 .315 r
.49429 .72664 .48932 .72295 .49396 .73312 .49898 .71334 Mtetra
.764 .468 0 r
.48969 .70865 .48489 .688 .48932 .72295 .49429 .72664 Mtetra
0 0 .396 r
.48528 .67101 .48061 .64936 .48489 .688 .48969 .70865 Mtetra
.123 .027 .464 r
.48099 .63431 .47636 .6199 .48061 .64936 .48528 .67101 Mtetra
.252 .136 .52 r
.47671 .60792 .47207 .60094 .47636 .6199 .48099 .63431 Mtetra
.375 .26 .593 r
.47239 .59147 .46772 .58969 .47207 .60094 .47671 .60792 Mtetra
.517 .418 .681 r
.468 .58202 .46329 .58348 .46772 .58969 .47239 .59147 Mtetra
.678 .607 .769 r
.46354 .57727 .4588 .58086 .46329 .58348 .468 .58202 Mtetra
.834 .806 .823 r
.45901 .5761 .45423 .58131 .4588 .58086 .46354 .57727 Mtetra
.923 .959 .787 r
.45439 .57819 .44955 .58479 .45423 .58131 .45901 .5761 Mtetra
.843 .955 .609 r
.44965 .58341 .44476 .59117 .44955 .58479 .45439 .57819 Mtetra
.662 .832 .41 r
.44481 .59107 .43986 .59938 .44476 .59117 .44965 .58341 Mtetra
0 0 0 r
.43989 .59909 .43493 .60671 .43986 .59938 .44481 .59107 Mtetra
.607 .881 .56 r
.43502 .60384 .4301 .60924 .43493 .60671 .43989 .59909 Mtetra
.664 .785 .938 r
.43032 .60172 .4255 .60412 .4301 .60924 .43502 .60384 Mtetra
.429 .367 .687 r
.42589 .59183 .42118 .59184 .4255 .60412 .43032 .60172 Mtetra
.387 .274 .602 r
.42167 .5767 .41703 .57578 .42118 .59184 .42589 .59183 Mtetra
.401 .271 .587 r
.41754 .56023 .41293 .55963 .41703 .57578 .42167 .5767 Mtetra
.435 .302 .6 r
.4134 .54524 .40878 .54556 .41293 .55963 .41754 .56023 Mtetra
.48 .353 .63 r
.40919 .53283 .40455 .53413 .40878 .54556 .4134 .54524 Mtetra
.53 .414 .666 r
.4049 .52292 .40023 .52503 .40455 .53413 .40919 .53283 Mtetra
.577 .475 .701 r
.40052 .51499 .39584 .51768 .40023 .52503 .4049 .52292 Mtetra
.616 .527 .73 r
.39609 .50844 .39139 .51153 .39584 .51768 .40052 .51499 Mtetra
.646 .566 .751 r
.39161 .5028 .3869 .50616 .39139 .51153 .39609 .50844 Mtetra
.666 .595 .766 r
.38709 .49775 .38238 .50128 .3869 .50616 .39161 .5028 Mtetra
.679 .614 .775 r
.38255 .49307 .37784 .49671 .38238 .50128 .38709 .49775 Mtetra
.688 .626 .782 r
.378 .48863 .37328 .49233 .37784 .49671 .38255 .49307 Mtetra
.693 .634 .786 r
.37342 .48432 .3687 .48806 .37328 .49233 .378 .48863 Mtetra
.696 .638 .787 r
.36884 .48009 .36412 .48386 .3687 .48806 .37342 .48432 Mtetra
.698 .641 .788 r
.36425 .47589 .35952 .47969 .36412 .48386 .36884 .48009 Mtetra
.7 .643 .789 r
.35964 .47174 .35492 .47555 .35952 .47969 .36425 .47589 Mtetra
.7 .644 .79 r
.35503 .4676 .3503 .47141 .35492 .47555 .35964 .47174 Mtetra
.7 .645 .791 r
.35041 .46347 .34568 .46728 .3503 .47141 .35503 .4676 Mtetra
.701 .645 .79 r
.34578 .45932 .34105 .46315 .34568 .46728 .35041 .46347 Mtetra
.34115 .45517 .33642 .45902 .34105 .46315 .34578 .45932 Mtetra
.702 .645 .79 r
.3365 .45103 .33177 .45489 .33642 .45902 .34115 .45517 Mtetra
.701 .646 .791 r
.33185 .44689 .32712 .45074 .33177 .45489 .3365 .45103 Mtetra
.32719 .44274 .32246 .44659 .32712 .45074 .33185 .44689 Mtetra
.701 .645 .791 r
.32253 .43857 .3178 .44244 .32246 .44659 .32719 .44274 Mtetra
.701 .646 .791 r
.31785 .4344 .31312 .43828 .3178 .44244 .32253 .43857 Mtetra
.702 .646 .791 r
.31317 .43023 .30844 .43411 .31312 .43828 .31785 .4344 Mtetra
.701 .646 .791 r
.30848 .42605 .30375 .42994 .30844 .43411 .31317 .43023 Mtetra
.30378 .42187 .29905 .42575 .30375 .42994 .30848 .42605 Mtetra
.701 .645 .791 r
.29908 .41767 .29435 .42157 .29905 .42575 .30378 .42187 Mtetra
.701 .646 .791 r
.29437 .41347 .28964 .41737 .29435 .42157 .29908 .41767 Mtetra
.702 .646 .791 r
.28965 .40926 .28492 .41317 .28964 .41737 .29437 .41347 Mtetra
.701 .646 .791 r
.28492 .40505 .28019 .40896 .28492 .41317 .28965 .40926 Mtetra
.28019 .40083 .27545 .40475 .28019 .40896 .28492 .40505 Mtetra
.27544 .3966 .27071 .40053 .27545 .40475 .28019 .40083 Mtetra
.27069 .39236 .26596 .3963 .27071 .40053 .27544 .3966 Mtetra
.702 .646 .791 r
.26594 .38812 .2612 .39207 .26596 .3963 .27069 .39236 Mtetra
.701 .646 .791 r
.26117 .38387 .25644 .38782 .2612 .39207 .26594 .38812 Mtetra
.2564 .37962 .25166 .38357 .25644 .38782 .26117 .38387 Mtetra
.25162 .37535 .24688 .37932 .25166 .38357 .2564 .37962 Mtetra
.24683 .37108 .24209 .37505 .24688 .37932 .25162 .37535 Mtetra
.24203 .36681 .2373 .37079 .24209 .37505 .24683 .37108 Mtetra
.23722 .36252 .23249 .36651 .2373 .37079 .24203 .36681 Mtetra
.23241 .35823 .22768 .36222 .23249 .36651 .23722 .36252 Mtetra
.22759 .35394 .22286 .35793 .22768 .36222 .23241 .35823 Mtetra
.22276 .34963 .21803 .35363 .22286 .35793 .22759 .35394 Mtetra
.21793 .34532 .21319 .34933 .21803 .35363 .22276 .34963 Mtetra
.21308 .341 .20835 .34502 .21319 .34933 .21793 .34532 Mtetra
.20823 .33668 .20349 .3407 .20835 .34502 .21308 .341 Mtetra
.20337 .33234 .19863 .33637 .20349 .3407 .20823 .33668 Mtetra
.1985 .328 .19377 .33204 .19863 .33637 .20337 .33234 Mtetra
.19362 .32366 .18889 .3277 .19377 .33204 .1985 .328 Mtetra
.18874 .3193 .184 .32335 .18889 .3277 .19362 .32366 Mtetra
.18385 .31494 .17911 .319 .184 .32335 .18874 .3193 Mtetra
.17895 .31057 .17421 .31463 .17911 .319 .18385 .31494 Mtetra
.17404 .3062 .1693 .31026 .17421 .31463 .17895 .31057 Mtetra
.16912 .30181 .16439 .30589 .1693 .31026 .17404 .3062 Mtetra
.61989 .69598 .61519 .69947 .6194 .70323 .6241 .69974 Mtetra
.61568 .69223 .61098 .69572 .61519 .69947 .61989 .69598 Mtetra
.701 .645 .791 r
.61146 .68845 .60676 .69196 .61098 .69572 .61568 .69223 Mtetra
.702 .646 .791 r
.60724 .68468 .60253 .68819 .60676 .69196 .61146 .68845 Mtetra
.603 .6809 .5983 .68442 .60253 .68819 .60724 .68468 Mtetra
.701 .646 .791 r
.59877 .67712 .59406 .68063 .5983 .68442 .603 .6809 Mtetra
.59452 .67333 .58981 .67685 .59406 .68063 .59877 .67712 Mtetra
.59027 .66953 .58556 .67306 .58981 .67685 .59452 .67333 Mtetra
.702 .645 .79 r
.58601 .66573 .5813 .66927 .58556 .67306 .59027 .66953 Mtetra
.702 .646 .791 r
.58174 .66192 .57703 .66547 .5813 .66927 .58601 .66573 Mtetra
.57747 .65811 .57276 .66165 .57703 .66547 .58174 .66192 Mtetra
.701 .646 .791 r
.57319 .65429 .56848 .65784 .57276 .66165 .57747 .65811 Mtetra
.56891 .65047 .5642 .65402 .56848 .65784 .57319 .65429 Mtetra
.702 .646 .79 r
.56462 .64664 .55991 .65021 .5642 .65402 .56891 .65047 Mtetra
.703 .646 .79 r
.56032 .64281 .55561 .6464 .55991 .65021 .56462 .64664 Mtetra
.703 .647 .791 r
.55602 .63899 .5513 .64259 .55561 .6464 .56032 .64281 Mtetra
.704 .648 .791 r
.55171 .63519 .54699 .63881 .5513 .64259 .55602 .63899 Mtetra
.707 .65 .791 r
.54739 .63141 .54268 .63508 .54699 .63881 .55171 .63519 Mtetra
.713 .654 .79 r
.54307 .6277 .53835 .63149 .54268 .63508 .54739 .63141 Mtetra
.724 .662 .788 r
.53874 .62413 .53403 .62812 .53835 .63149 .54307 .6277 Mtetra
.744 .677 .785 r
.53441 .62085 .5297 .62522 .53403 .62812 .53874 .62413 Mtetra
.782 .704 .778 r
.53008 .61814 .52537 .62324 .5297 .62522 .53441 .62085 Mtetra
.844 .748 .757 r
.52575 .61653 .52104 .62307 .52537 .62324 .53008 .61814 Mtetra
.925 .802 .705 r
.52142 .61704 .51672 .62628 .52104 .62307 .52575 .61653 Mtetra
.989 .84 .602 r
.5171 .62147 .51239 .63546 .51672 .62628 .52142 .61704 Mtetra
.987 .834 .451 r
.51277 .63266 .50803 .65383 .51239 .63546 .5171 .62147 Mtetra
.875 .767 .265 r
.5084 .65366 .50358 .68244 .50803 .65383 .51277 .63266 Mtetra
0 0 0 r
.50393 .68395 .49898 .71334 .50358 .68244 .5084 .65366 Mtetra
.025 0 .232 r
.49932 .71225 .49429 .72664 .49898 .71334 .50393 .68395 Mtetra
.684 .287 .289 r
.49464 .71783 .48969 .70865 .49429 .72664 .49932 .71225 Mtetra
0 0 .245 r
.49006 .69302 .48528 .67101 .48969 .70865 .49464 .71783 Mtetra
0 0 .419 r
.48566 .65428 .48099 .63431 .48528 .67101 .49006 .69302 Mtetra
.159 .056 .478 r
.48136 .62015 .47671 .60792 .48099 .63431 .48566 .65428 Mtetra
.284 .166 .538 r
.47705 .59677 .47239 .59147 .47671 .60792 .48136 .62015 Mtetra
.414 .302 .617 r
.4727 .58266 .468 .58202 .47239 .59147 .47705 .59677 Mtetra
.57 .479 .712 r
.46827 .57498 .46354 .57727 .468 .58202 .4727 .58266 Mtetra
.746 .691 .799 r
.46378 .5718 .45901 .5761 .46354 .57727 .46827 .57498 Mtetra
.894 .897 .823 r
.4592 .57228 .45439 .57819 .45901 .5761 .46378 .5718 Mtetra
.9 .98 .702 r
.45453 .57613 .44965 .58341 .45439 .57819 .4592 .57228 Mtetra
.737 .885 .484 r
.44974 .58289 .44481 .59107 .44965 .58341 .45453 .57613 Mtetra
0 0 0 r
.44485 .59106 .43989 .59909 .44481 .59107 .44974 .58289 Mtetra
.43996 .59747 .43502 .60384 .43989 .59909 .44485 .59106 Mtetra
.741 .975 .924 r
.43519 .5982 .43032 .60172 .43502 .60384 .43996 .59747 Mtetra
.482 .463 .76 r
.43065 .59108 .42589 .59183 .43032 .60172 .43519 .5982 Mtetra
.392 .292 .621 r
.42634 .57745 .42167 .5767 .42589 .59183 .43065 .59108 Mtetra
.392 .266 .588 r
.42218 .56105 .41754 .56023 .42167 .5767 .42634 .57745 Mtetra
.42 .287 .593 r
.41804 .54529 .4134 .54524 .41754 .56023 .42218 .56105 Mtetra
.462 .332 .618 r
.41384 .53189 .40919 .53283 .4134 .54524 .41804 .54529 Mtetra
.51 .39 .652 r
.40956 .52109 .4049 .52292 .40919 .53283 .41384 .53189 Mtetra
.56 .452 .688 r
.40521 .51247 .40052 .51499 .4049 .52292 .40956 .52109 Mtetra
.603 .508 .72 r
.40079 .50544 .39609 .50844 .40052 .51499 .40521 .51247 Mtetra
.636 .553 .745 r
.39632 .49951 .39161 .5028 .39609 .50844 .40079 .50544 Mtetra
.659 .586 .762 r
.39181 .49428 .38709 .49775 .39161 .5028 .39632 .49951 Mtetra
.674 .607 .773 r
.38728 .48948 .38255 .49307 .38709 .49775 .39181 .49428 Mtetra
.685 .621 .779 r
.38272 .48494 .378 .48863 .38255 .49307 .38728 .48948 Mtetra
.692 .631 .783 r
.37815 .48057 .37342 .48432 .378 .48863 .38272 .48494 Mtetra
.696 .637 .787 r
.37357 .47632 .36884 .48009 .37342 .48432 .37815 .48057 Mtetra
.697 .64 .789 r
.36898 .47212 .36425 .47589 .36884 .48009 .37357 .47632 Mtetra
.699 .642 .789 r
.36437 .46794 .35964 .47174 .36425 .47589 .36898 .47212 Mtetra
.7 .643 .789 r
.35976 .46377 .35503 .4676 .35964 .47174 .36437 .46794 Mtetra
.701 .644 .79 r
.35514 .45962 .35041 .46347 .35503 .4676 .35976 .46377 Mtetra
.701 .645 .791 r
.35052 .45548 .34578 .45932 .35041 .46347 .35514 .45962 Mtetra
.34588 .45134 .34115 .45517 .34578 .45932 .35052 .45548 Mtetra
.34124 .44718 .3365 .45103 .34115 .45517 .34588 .45134 Mtetra
.701 .645 .79 r
.33659 .44302 .33185 .44689 .3365 .45103 .34124 .44718 Mtetra
.702 .646 .79 r
.33193 .43886 .32719 .44274 .33185 .44689 .33659 .44302 Mtetra
.702 .646 .791 r
.32726 .4347 .32253 .43857 .32719 .44274 .33193 .43886 Mtetra
.701 .646 .791 r
.32259 .43053 .31785 .4344 .32253 .43857 .32726 .4347 Mtetra
.701 .645 .791 r
.31791 .42634 .31317 .43023 .31785 .4344 .32259 .43053 Mtetra
.702 .646 .791 r
.31322 .42215 .30848 .42605 .31317 .43023 .31791 .42634 Mtetra
.30852 .41796 .30378 .42187 .30848 .42605 .31322 .42215 Mtetra
.701 .646 .791 r
.30382 .41376 .29908 .41767 .30378 .42187 .30852 .41796 Mtetra
.29911 .40956 .29437 .41347 .29908 .41767 .30382 .41376 Mtetra
.29439 .40534 .28965 .40926 .29437 .41347 .29911 .40956 Mtetra
.702 .646 .791 r
.28966 .40112 .28492 .40505 .28965 .40926 .29439 .40534 Mtetra
.28493 .39689 .28019 .40083 .28492 .40505 .28966 .40112 Mtetra
.701 .646 .791 r
.28018 .39266 .27544 .3966 .28019 .40083 .28493 .39689 Mtetra
.27543 .38842 .27069 .39236 .27544 .3966 .28018 .39266 Mtetra
.27068 .38417 .26594 .38812 .27069 .39236 .27543 .38842 Mtetra
.702 .646 .791 r
.26591 .37991 .26117 .38387 .26594 .38812 .27068 .38417 Mtetra
.701 .646 .791 r
.26114 .37565 .2564 .37962 .26117 .38387 .26591 .37991 Mtetra
.25636 .37138 .25162 .37535 .2564 .37962 .26114 .37565 Mtetra
.25157 .36711 .24683 .37108 .25162 .37535 .25636 .37138 Mtetra
.24677 .36282 .24203 .36681 .24683 .37108 .25157 .36711 Mtetra
.24197 .35853 .23722 .36252 .24203 .36681 .24677 .36282 Mtetra
.23715 .35424 .23241 .35823 .23722 .36252 .24197 .35853 Mtetra
.23233 .34993 .22759 .35394 .23241 .35823 .23715 .35424 Mtetra
.2275 .34562 .22276 .34963 .22759 .35394 .23233 .34993 Mtetra
.702 .646 .791 r
.22267 .3413 .21793 .34532 .22276 .34963 .2275 .34562 Mtetra
.701 .646 .791 r
.21782 .33698 .21308 .341 .21793 .34532 .22267 .3413 Mtetra
.21297 .33265 .20823 .33668 .21308 .341 .21782 .33698 Mtetra
.20811 .32831 .20337 .33234 .20823 .33668 .21297 .33265 Mtetra
.20324 .32396 .1985 .328 .20337 .33234 .20811 .32831 Mtetra
.702 .646 .791 r
.19837 .31961 .19362 .32366 .1985 .328 .20324 .32396 Mtetra
.701 .646 .791 r
.19348 .31525 .18874 .3193 .19362 .32366 .19837 .31961 Mtetra
.18859 .31088 .18385 .31494 .18874 .3193 .19348 .31525 Mtetra
.701 .645 .791 r
.18369 .3065 .17895 .31057 .18385 .31494 .18859 .31088 Mtetra
.701 .646 .791 r
.17878 .30212 .17404 .3062 .17895 .31057 .18369 .3065 Mtetra
.702 .646 .791 r
.17387 .29773 .16912 .30181 .17404 .3062 .17878 .30212 Mtetra
.701 .645 .791 r
.62461 .69248 .61989 .69598 .6241 .69974 .62881 .69625 Mtetra
.702 .646 .791 r
.62039 .68872 .61568 .69223 .61989 .69598 .62461 .69248 Mtetra
.61618 .68494 .61146 .68845 .61568 .69223 .62039 .68872 Mtetra
.701 .646 .791 r
.61195 .68117 .60724 .68468 .61146 .68845 .61618 .68494 Mtetra
.60772 .67738 .603 .6809 .60724 .68468 .61195 .68117 Mtetra
.60348 .67359 .59877 .67712 .603 .6809 .60772 .67738 Mtetra
.702 .646 .791 r
.59924 .66979 .59452 .67333 .59877 .67712 .60348 .67359 Mtetra
.59498 .66599 .59027 .66953 .59452 .67333 .59924 .66979 Mtetra
.701 .646 .791 r
.59073 .66219 .58601 .66573 .59027 .66953 .59498 .66599 Mtetra
.58646 .65838 .58174 .66192 .58601 .66573 .59073 .66219 Mtetra
.58219 .65456 .57747 .65811 .58174 .66192 .58646 .65838 Mtetra
.702 .645 .79 r
.57791 .65073 .57319 .65429 .57747 .65811 .58219 .65456 Mtetra
.702 .646 .79 r
.57363 .64689 .56891 .65047 .57319 .65429 .57791 .65073 Mtetra
.702 .646 .791 r
.56934 .64306 .56462 .64664 .56891 .65047 .57363 .64689 Mtetra
.56504 .63923 .56032 .64281 .56462 .64664 .56934 .64306 Mtetra
.702 .647 .791 r
.56074 .6354 .55602 .63899 .56032 .64281 .56504 .63923 Mtetra
.703 .647 .791 r
.55643 .63157 .55171 .63519 .55602 .63899 .56074 .6354 Mtetra
.705 .648 .79 r
.55211 .62775 .54739 .63141 .55171 .63519 .55643 .63157 Mtetra
.709 .651 .79 r
.54779 .62398 .54307 .6277 .54739 .63141 .55211 .62775 Mtetra
.715 .656 .79 r
.54346 .6203 .53874 .62413 .54307 .6277 .54779 .62398 Mtetra
.728 .666 .789 r
.53913 .61679 .53441 .62085 .53874 .62413 .54346 .6203 Mtetra
.752 .683 .785 r
.53479 .61362 .53008 .61814 .53441 .62085 .53913 .61679 Mtetra
.796 .714 .774 r
.53046 .61112 .52575 .61653 .53008 .61814 .53479 .61362 Mtetra
.864 .762 .748 r
.52612 .60993 .52142 .61704 .52575 .61653 .53046 .61112 Mtetra
.946 .816 .684 r
.5218 .61124 .5171 .62147 .52142 .61704 .52612 .60993 Mtetra
.997 .845 .566 r
.51748 .61711 .51277 .63266 .5171 .62147 .5218 .61124 Mtetra
.969 .824 .404 r
.51315 .63054 .5084 .65366 .51277 .63266 .51748 .61711 Mtetra
.815 .733 .206 r
.50878 .65414 .50393 .68395 .5084 .65366 .51315 .63054 Mtetra
0 0 .05 r
.50429 .68526 .49932 .71225 .50393 .68395 .50878 .65414 Mtetra
.177 0 .268 r
.49966 .70935 .49464 .71783 .49932 .71225 .50429 .68526 Mtetra
.846 .415 .203 r
.49499 .70676 .49006 .69302 .49464 .71783 .49966 .70935 Mtetra
0 0 .326 r
.49043 .67658 .48566 .65428 .49006 .69302 .49499 .70676 Mtetra
.035 0 .437 r
.48604 .63809 .48136 .62015 .48566 .65428 .49043 .67658 Mtetra
.193 .084 .493 r
.48172 .60688 .47705 .59677 .48136 .62015 .48604 .63809 Mtetra
.316 .2 .558 r
.47738 .58644 .4727 .58266 .47705 .59677 .48172 .60688 Mtetra
.458 .351 .646 r
.47299 .57459 .46827 .57498 .4727 .58266 .47738 .58644 Mtetra
.633 .553 .747 r
.46854 .5687 .46378 .5718 .46827 .57498 .47299 .57459 Mtetra
.821 .789 .822 r
.464 .56721 .4592 .57228 .46378 .5718 .46854 .5687 Mtetra
.922 .966 .78 r
.45938 .56947 .45453 .57613 .4592 .57228 .464 .56721 Mtetra
.816 .94 .577 r
.45464 .57505 .44974 .58289 .45453 .57613 .45938 .56947 Mtetra
.626 .808 .384 r
.44981 .58287 .44485 .59106 .44974 .58289 .45464 .57505 Mtetra
0 0 0 r
.44492 .59033 .43996 .59747 .44485 .59106 .44981 .58287 Mtetra
.674 .954 .711 r
.44009 .59356 .43519 .5982 .43996 .59747 .44492 .59033 Mtetra
.578 .628 .865 r
.43546 .58939 .43065 .59108 .43519 .5982 .44009 .59356 Mtetra
.407 .327 .654 r
.43106 .57783 .42634 .57745 .43065 .59108 .43546 .58939 Mtetra
.386 .267 .594 r
.42684 .562 .42218 .56105 .42634 .57745 .43106 .57783 Mtetra
.407 .275 .588 r
.42268 .54569 .41804 .54529 .42218 .56105 .42684 .562 Mtetra
.445 .313 .606 r
.41849 .53129 .41384 .53189 .41804 .54529 .42268 .54569 Mtetra
.492 .368 .638 r
.41423 .51954 .40956 .52109 .41384 .53189 .41849 .53129 Mtetra
.542 .429 .675 r
.4099 .51018 .40521 .51247 .40956 .52109 .41423 .51954 Mtetra
.587 .488 .709 r
.40549 .50262 .40079 .50544 .40521 .51247 .4099 .51018 Mtetra
.624 .538 .736 r
.40103 .49632 .39632 .49951 .40079 .50544 .40549 .50262 Mtetra
.652 .575 .755 r
.39653 .49085 .39181 .49428 .39632 .49951 .40103 .49632 Mtetra
.67 .6 .769 r
.39201 .4859 .38728 .48948 .39181 .49428 .39653 .49085 Mtetra
.681 .617 .777 r
.38746 .48128 .38272 .48494 .38728 .48948 .39201 .4859 Mtetra
.689 .628 .783 r
.38289 .47685 .37815 .48057 .38272 .48494 .38746 .48128 Mtetra
.694 .635 .786 r
.37831 .47255 .37357 .47632 .37815 .48057 .38289 .47685 Mtetra
.697 .639 .787 r
.37372 .46831 .36898 .47212 .37357 .47632 .37831 .47255 Mtetra
.699 .642 .789 r
.36911 .46412 .36437 .46794 .36898 .47212 .37372 .46831 Mtetra
.699 .643 .79 r
.3645 .45995 .35976 .46377 .36437 .46794 .36911 .46412 Mtetra
.7 .644 .79 r
.35989 .45579 .35514 .45962 .35976 .46377 .3645 .45995 Mtetra
.701 .645 .79 r
.35526 .45163 .35052 .45548 .35514 .45962 .35989 .45579 Mtetra
.35062 .44748 .34588 .45134 .35052 .45548 .35526 .45163 Mtetra
.701 .645 .791 r
.34598 .44332 .34124 .44718 .34588 .45134 .35062 .44748 Mtetra
.34133 .43916 .33659 .44302 .34124 .44718 .34598 .44332 Mtetra
.33667 .43499 .33193 .43886 .33659 .44302 .34133 .43916 Mtetra
.702 .646 .791 r
.33201 .43082 .32726 .4347 .33193 .43886 .33667 .43499 Mtetra
.32733 .42664 .32259 .43053 .32726 .4347 .33201 .43082 Mtetra
.701 .646 .791 r
.32265 .42245 .31791 .42634 .32259 .43053 .32733 .42664 Mtetra
.31796 .41826 .31322 .42215 .31791 .42634 .32265 .42245 Mtetra
.31327 .41406 .30852 .41796 .31322 .42215 .31796 .41826 Mtetra
.702 .646 .791 r
.30856 .40985 .30382 .41376 .30852 .41796 .31327 .41406 Mtetra
.701 .646 .791 r
.30385 .40564 .29911 .40956 .30382 .41376 .30856 .40985 Mtetra
.29913 .40142 .29439 .40534 .29911 .40956 .30385 .40564 Mtetra
.29441 .39719 .28966 .40112 .29439 .40534 .29913 .40142 Mtetra
.28967 .39295 .28493 .39689 .28966 .40112 .29441 .39719 Mtetra
.702 .646 .791 r
.28493 .38871 .28018 .39266 .28493 .39689 .28967 .39295 Mtetra
.701 .646 .791 r
.28018 .38447 .27543 .38842 .28018 .39266 .28493 .38871 Mtetra
.27542 .38021 .27068 .38417 .27543 .38842 .28018 .38447 Mtetra
.27066 .37595 .26591 .37991 .27068 .38417 .27542 .38021 Mtetra
.702 .646 .791 r
.26588 .37168 .26114 .37565 .26591 .37991 .27066 .37595 Mtetra
.2611 .36741 .25636 .37138 .26114 .37565 .26588 .37168 Mtetra
.701 .646 .791 r
.25631 .36313 .25157 .36711 .25636 .37138 .2611 .36741 Mtetra
.25152 .35884 .24677 .36282 .25157 .36711 .25631 .36313 Mtetra
.24671 .35454 .24197 .35853 .24677 .36282 .25152 .35884 Mtetra
.702 .646 .791 r
.2419 .35023 .23715 .35424 .24197 .35853 .24671 .35454 Mtetra
.701 .646 .791 r
.23708 .34592 .23233 .34993 .23715 .35424 .2419 .35023 Mtetra
.23225 .34161 .2275 .34562 .23233 .34993 .23708 .34592 Mtetra
.22742 .33728 .22267 .3413 .2275 .34562 .23225 .34161 Mtetra
.22257 .33295 .21782 .33698 .22267 .3413 .22742 .33728 Mtetra
.702 .646 .791 r
.21772 .32861 .21297 .33265 .21782 .33698 .22257 .33295 Mtetra
.701 .646 .791 r
.21286 .32426 .20811 .32831 .21297 .33265 .21772 .32861 Mtetra
.20799 .31991 .20324 .32396 .20811 .32831 .21286 .32426 Mtetra
.20312 .31555 .19837 .31961 .20324 .32396 .20799 .31991 Mtetra
.19823 .31118 .19348 .31525 .19837 .31961 .20312 .31555 Mtetra
.702 .646 .791 r
.19334 .30681 .18859 .31088 .19348 .31525 .19823 .31118 Mtetra
.701 .646 .791 r
.18844 .30243 .18369 .3065 .18859 .31088 .19334 .30681 Mtetra
.18353 .29804 .17878 .30212 .18369 .3065 .18844 .30243 Mtetra
.17862 .29364 .17387 .29773 .17878 .30212 .18353 .29804 Mtetra
.62933 .68898 .62461 .69248 .62881 .69625 .63353 .69275 Mtetra
.62511 .68521 .62039 .68872 .62461 .69248 .62933 .68898 Mtetra
.6209 .68143 .61618 .68494 .62039 .68872 .62511 .68521 Mtetra
.61667 .67765 .61195 .68117 .61618 .68494 .6209 .68143 Mtetra
.702 .646 .791 r
.61244 .67386 .60772 .67738 .61195 .68117 .61667 .67765 Mtetra
.701 .646 .791 r
.6082 .67006 .60348 .67359 .60772 .67738 .61244 .67386 Mtetra
.60396 .66626 .59924 .66979 .60348 .67359 .6082 .67006 Mtetra
.59971 .66246 .59498 .66599 .59924 .66979 .60396 .66626 Mtetra
.59545 .65864 .59073 .66219 .59498 .66599 .59971 .66246 Mtetra
.702 .645 .79 r
.59119 .65482 .58646 .65838 .59073 .66219 .59545 .65864 Mtetra
.702 .646 .791 r
.58692 .65099 .58219 .65456 .58646 .65838 .59119 .65482 Mtetra
.701 .646 .791 r
.58264 .64716 .57791 .65073 .58219 .65456 .58692 .65099 Mtetra
.57836 .64333 .57363 .64689 .57791 .65073 .58264 .64716 Mtetra
.57406 .6395 .56934 .64306 .57363 .64689 .57836 .64333 Mtetra
.702 .646 .791 r
.56977 .63565 .56504 .63923 .56934 .64306 .57406 .6395 Mtetra
.702 .646 .79 r
.56546 .6318 .56074 .6354 .56504 .63923 .56977 .63565 Mtetra
.703 .647 .791 r
.56115 .62795 .55643 .63157 .56074 .6354 .56546 .6318 Mtetra
.704 .648 .791 r
.55684 .62412 .55211 .62775 .55643 .63157 .56115 .62795 Mtetra
.706 .649 .791 r
.55252 .62031 .54779 .62398 .55211 .62775 .55684 .62412 Mtetra
.71 .652 .791 r
.54819 .61655 .54346 .6203 .54779 .62398 .55252 .62031 Mtetra
.718 .658 .789 r
.54385 .61289 .53913 .61679 .54346 .6203 .54819 .61655 Mtetra
.733 .669 .787 r
.53952 .60944 .53479 .61362 .53913 .61679 .54385 .61289 Mtetra
.762 .691 .783 r
.53518 .6064 .53046 .61112 .53479 .61362 .53952 .60944 Mtetra
.812 .727 .771 r
.53084 .60418 .52612 .60993 .53046 .61112 .53518 .6064 Mtetra
.886 .778 .737 r
.52651 .60351 .5218 .61124 .52612 .60993 .53084 .60418 Mtetra
.965 .829 .659 r
.52218 .60577 .51748 .61711 .5218 .61124 .52651 .60351 Mtetra
.998 .846 .526 r
.51786 .61326 .51315 .63054 .51748 .61711 .52218 .60577 Mtetra
.943 .809 .356 r
.51354 .62908 .50878 .65414 .51315 .63054 .51786 .61326 Mtetra
.74 .688 .144 r
.50916 .65508 .50429 .68526 .50878 .65414 .51354 .62908 Mtetra
0 0 .117 r
.50466 .68598 .49966 .70935 .50429 .68526 .50916 .65508 Mtetra
.337 .031 .29 r
.50001 .70443 .49499 .70676 .49966 .70935 .50466 .68598 Mtetra
.879 .483 .029 r
.49534 .69372 .49043 .67658 .49499 .70676 .50001 .70443 Mtetra
0 0 .374 r
.49081 .65972 .48604 .63809 .49043 .67658 .49534 .69372 Mtetra
.085 0 .453 r
.48641 .6226 .48172 .60688 .48604 .63809 .49081 .65972 Mtetra
.226 .113 .509 r
.48207 .59455 .47738 .58644 .48172 .60688 .48641 .6226 Mtetra
.354 .239 .581 r
.4777 .57695 .47299 .57459 .47738 .58644 .48207 .59455 Mtetra
.511 .412 .678 r
.47328 .56728 .46854 .5687 .47299 .57459 .4777 .57695 Mtetra
.709 .646 .784 r
.46879 .56326 .464 .56721 .46854 .5687 .47328 .56728 Mtetra
.891 .894 .825 r
.46421 .56361 .45938 .56947 .464 .56721 .46879 .56326 Mtetra
.885 .978 .682 r
.45953 .56772 .45464 .57505 .45938 .56947 .46421 .56361 Mtetra
.7 .863 .454 r
.45475 .57474 .44981 .58287 .45464 .57505 .45953 .56772 Mtetra
0 0 0 r
.44988 .58264 .44492 .59033 .44981 .58287 .45475 .57474 Mtetra
.579 .851 .509 r
.44503 .58788 .44009 .59356 .44492 .59033 .44988 .58264 Mtetra
.697 .861 .96 r
.44031 .58667 .43546 .58939 .44009 .59356 .44503 .58788 Mtetra
.44 .391 .707 r
.43582 .57761 .43106 .57783 .43546 .58939 .44031 .58667 Mtetra
.386 .277 .607 r
.43153 .56289 .42684 .562 .43106 .57783 .43582 .57761 Mtetra
.396 .267 .586 r
.42734 .54637 .42268 .54569 .42684 .562 .43153 .56289 Mtetra
.429 .296 .597 r
.42315 .53109 .41849 .53129 .42268 .54569 .42734 .54637 Mtetra
.473 .345 .625 r
.41891 .51834 .41423 .51954 .41849 .53129 .42315 .53109 Mtetra
.523 .405 .661 r
.41459 .50813 .4099 .51018 .41423 .51954 .41891 .51834 Mtetra
.571 .467 .696 r
.4102 .49996 .40549 .50262 .4099 .51018 .41459 .50813 Mtetra
.612 .52 .727 r
.40575 .49324 .40103 .49632 .40549 .50262 .4102 .49996 Mtetra
.642 .562 .749 r
.40126 .4875 .39653 .49085 .40103 .49632 .40575 .49324 Mtetra
.664 .592 .765 r
.39674 .48237 .39201 .4859 .39653 .49085 .40126 .4875 Mtetra
.678 .612 .774 r
.39219 .47764 .38746 .48128 .39201 .4859 .39674 .48237 Mtetra
.687 .624 .781 r
.38763 .47314 .38289 .47685 .38746 .48128 .39219 .47764 Mtetra
.692 .633 .785 r
.38305 .46879 .37831 .47255 .38289 .47685 .38763 .47314 Mtetra
.696 .638 .787 r
.37846 .46452 .37372 .46831 .37831 .47255 .38305 .46879 Mtetra
.698 .641 .788 r
.37386 .46031 .36911 .46412 .37372 .46831 .37846 .46452 Mtetra
.699 .643 .789 r
.36925 .45612 .3645 .45995 .36911 .46412 .37386 .46031 Mtetra
.7 .644 .79 r
.36463 .45195 .35989 .45579 .3645 .45995 .36925 .45612 Mtetra
.701 .645 .79 r
.36001 .44778 .35526 .45163 .35989 .45579 .36463 .45195 Mtetra
.35537 .44362 .35062 .44748 .35526 .45163 .36001 .44778 Mtetra
.701 .645 .791 r
.35073 .43946 .34598 .44332 .35062 .44748 .35537 .44362 Mtetra
.34608 .43528 .34133 .43916 .34598 .44332 .35073 .43946 Mtetra
.701 .646 .791 r
.34142 .43111 .33667 .43499 .34133 .43916 .34608 .43528 Mtetra
.33676 .42693 .33201 .43082 .33667 .43499 .34142 .43111 Mtetra
.33208 .42274 .32733 .42664 .33201 .43082 .33676 .42693 Mtetra
.3274 .41855 .32265 .42245 .32733 .42664 .33208 .42274 Mtetra
.32271 .41435 .31796 .41826 .32265 .42245 .3274 .41855 Mtetra
.31802 .41015 .31327 .41406 .31796 .41826 .32271 .41435 Mtetra
.31332 .40593 .30856 .40985 .31327 .41406 .31802 .41015 Mtetra
.3086 .40171 .30385 .40564 .30856 .40985 .31332 .40593 Mtetra
.30389 .39749 .29913 .40142 .30385 .40564 .3086 .40171 Mtetra
.29916 .39325 .29441 .39719 .29913 .40142 .30389 .39749 Mtetra
.29443 .38901 .28967 .39295 .29441 .39719 .29916 .39325 Mtetra
.28968 .38477 .28493 .38871 .28967 .39295 .29443 .38901 Mtetra
.702 .646 .791 r
.28493 .38051 .28018 .38447 .28493 .38871 .28968 .38477 Mtetra
.701 .646 .791 r
.28018 .37625 .27542 .38021 .28018 .38447 .28493 .38051 Mtetra
.27541 .37198 .27066 .37595 .27542 .38021 .28018 .37625 Mtetra
.27064 .36771 .26588 .37168 .27066 .37595 .27541 .37198 Mtetra
.26586 .36343 .2611 .36741 .26588 .37168 .27064 .36771 Mtetra
.702 .646 .791 r
.26107 .35914 .25631 .36313 .2611 .36741 .26586 .36343 Mtetra
.701 .646 .791 r
.25627 .35484 .25152 .35884 .25631 .36313 .26107 .35914 Mtetra
.25147 .35054 .24671 .35454 .25152 .35884 .25627 .35484 Mtetra
.24666 .34623 .2419 .35023 .24671 .35454 .25147 .35054 Mtetra
.24184 .34191 .23708 .34592 .2419 .35023 .24666 .34623 Mtetra
.702 .646 .791 r
.23701 .33759 .23225 .34161 .23708 .34592 .24184 .34191 Mtetra
.701 .646 .791 r
.23217 .33325 .22742 .33728 .23225 .34161 .23701 .33759 Mtetra
.22733 .32892 .22257 .33295 .22742 .33728 .23217 .33325 Mtetra
.22248 .32457 .21772 .32861 .22257 .33295 .22733 .32892 Mtetra
.21762 .32022 .21286 .32426 .21772 .32861 .22248 .32457 Mtetra
.21275 .31586 .20799 .31991 .21286 .32426 .21762 .32022 Mtetra
.702 .646 .791 r
.20788 .31149 .20312 .31555 .20799 .31991 .21275 .31586 Mtetra
.701 .646 .791 r
.20299 .30712 .19823 .31118 .20312 .31555 .20788 .31149 Mtetra
.1981 .30274 .19334 .30681 .19823 .31118 .20299 .30712 Mtetra
.1932 .29835 .18844 .30243 .19334 .30681 .1981 .30274 Mtetra
.18829 .29395 .18353 .29804 .18844 .30243 .1932 .29835 Mtetra
.702 .646 .791 r
.18338 .28954 .17862 .29364 .18353 .29804 .18829 .29395 Mtetra
.701 .646 .791 r
.63405 .68548 .62933 .68898 .63353 .69275 .63826 .68925 Mtetra
.701 .645 .791 r
.62984 .6817 .62511 .68521 .62933 .68898 .63405 .68548 Mtetra
.702 .646 .791 r
.62562 .67791 .6209 .68143 .62511 .68521 .62984 .6817 Mtetra
.701 .646 .791 r
.6214 .67412 .61667 .67765 .6209 .68143 .62562 .67791 Mtetra
.61717 .67033 .61244 .67386 .61667 .67765 .6214 .67412 Mtetra
.61293 .66653 .6082 .67006 .61244 .67386 .61717 .67033 Mtetra
.60869 .66272 .60396 .66626 .6082 .67006 .61293 .66653 Mtetra
.702 .645 .79 r
.60444 .65891 .59971 .66246 .60396 .66626 .60869 .66272 Mtetra
.702 .646 .791 r
.60018 .65509 .59545 .65864 .59971 .66246 .60444 .65891 Mtetra
.701 .646 .791 r
.59592 .65126 .59119 .65482 .59545 .65864 .60018 .65509 Mtetra
.59165 .64743 .58692 .65099 .59119 .65482 .59592 .65126 Mtetra
.58737 .6436 .58264 .64716 .58692 .65099 .59165 .64743 Mtetra
.58309 .63976 .57836 .64333 .58264 .64716 .58737 .6436 Mtetra
.702 .645 .79 r
.5788 .63591 .57406 .6395 .57836 .64333 .58309 .63976 Mtetra
.702 .646 .79 r
.5745 .63205 .56977 .63565 .57406 .6395 .5788 .63591 Mtetra
.702 .646 .791 r
.5702 .6282 .56546 .6318 .56977 .63565 .5745 .63205 Mtetra
.702 .647 .791 r
.56589 .62435 .56115 .62795 .56546 .6318 .5702 .6282 Mtetra
.703 .647 .791 r
.56157 .6205 .55684 .62412 .56115 .62795 .56589 .62435 Mtetra
.704 .648 .791 r
.55725 .61666 .55252 .62031 .55684 .62412 .56157 .6205 Mtetra
.707 .65 .79 r
.55292 .61285 .54819 .61655 .55252 .62031 .55725 .61666 Mtetra
.712 .654 .79 r
.54859 .6091 .54385 .61289 .54819 .61655 .55292 .61285 Mtetra
.721 .661 .79 r
.54425 .60549 .53952 .60944 .54385 .61289 .54859 .6091 Mtetra
.739 .675 .788 r
.53991 .60213 .53518 .6064 .53952 .60944 .54425 .60549 Mtetra
.773 .699 .782 r
.53557 .59926 .53084 .60418 .53518 .6064 .53991 .60213 Mtetra
.83 .74 .765 r
.53123 .59735 .52651 .60351 .53084 .60418 .53557 .59926 Mtetra
.909 .794 .722 r
.52689 .59729 .52218 .60577 .52651 .60351 .53123 .59735 Mtetra
.981 .84 .629 r
.52257 .60066 .51786 .61326 .52218 .60577 .52689 .59729 Mtetra
.993 .843 .483 r
.51826 .61 .51354 .62908 .51786 .61326 .52257 .60066 Mtetra
.906 .788 .304 r
.51394 .62832 .50916 .65508 .51354 .62908 .51826 .61 Mtetra
0 0 0 r
.50955 .65628 .50466 .68598 .50916 .65508 .51394 .62832 Mtetra
0 0 .173 r
.50502 .68563 .50001 .70443 .50466 .68598 .50955 .65628 Mtetra
.509 .149 .291 r
.50036 .69727 .49534 .69372 .50001 .70443 .50502 .68563 Mtetra
.699 .425 0 r
.4957 .67912 .49081 .65972 .49534 .69372 .50036 .69727 Mtetra
0 0 .405 r
.49118 .64288 .48641 .6226 .49081 .65972 .4957 .67912 Mtetra
.128 .033 .468 r
.48678 .60796 .48207 .59455 .48641 .6226 .49118 .64288 Mtetra
.259 .145 .527 r
.48241 .58317 .4777 .57695 .48207 .59455 .48678 .60796 Mtetra
.396 .285 .609 r
.47801 .56832 .47328 .56728 .4777 .57695 .48241 .58317 Mtetra
.576 .488 .717 r
.47356 .56086 .46879 .56326 .47328 .56728 .47801 .56832 Mtetra
.796 .758 .818 r
.46902 .5588 .46421 .56361 .46879 .56326 .47356 .56086 Mtetra
.92 .969 .78 r
.4644 .56109 .45953 .56772 .46421 .56361 .46902 .5588 Mtetra
.786 .924 .55 r
.45967 .56691 .45475 .57474 .45953 .56772 .4644 .56109 Mtetra
0 0 0 r
.45484 .57469 .44988 .58264 .45475 .57474 .45967 .56691 Mtetra
.44999 .58133 .44503 .58788 .44988 .58264 .45484 .57469 Mtetra
.728 .989 .872 r
.44521 .58283 .44031 .58667 .44503 .58788 .44999 .58133 Mtetra
.503 .505 .791 r
.44062 .57662 .43582 .57761 .44031 .58667 .44521 .58283 Mtetra
.392 .299 .63 r
.43625 .56357 .43153 .56289 .43582 .57761 .44062 .57662 Mtetra
.388 .264 .588 r
.43202 .54726 .42734 .54637 .43153 .56289 .43625 .56357 Mtetra
.414 .282 .59 r
.42782 .53125 .42315 .53109 .42734 .54637 .43202 .54726 Mtetra
.455 .325 .613 r
.42359 .51749 .41891 .51834 .42315 .53109 .42782 .53125 Mtetra
.504 .382 .647 r
.41928 .50637 .41459 .50813 .41891 .51834 .42359 .51749 Mtetra
.553 .444 .683 r
.41491 .49749 .4102 .49996 .41459 .50813 .41928 .50637 Mtetra
.597 .501 .716 r
.41048 .49029 .40575 .49324 .4102 .49996 .41491 .49749 Mtetra
.632 .548 .742 r
.406 .48422 .40126 .4875 .40575 .49324 .41048 .49029 Mtetra
.657 .582 .76 r
.40148 .47889 .39674 .48237 .40126 .4875 .406 .48422 Mtetra
.673 .605 .771 r
.39694 .47402 .39219 .47764 .39674 .48237 .40148 .47889 Mtetra
.684 .62 .779 r
.39238 .46944 .38763 .47314 .39219 .47764 .39694 .47402 Mtetra
.691 .63 .783 r
.3878 .46503 .38305 .46879 .38763 .47314 .39238 .46944 Mtetra
.695 .636 .786 r
.38321 .46073 .37846 .46452 .38305 .46879 .3878 .46503 Mtetra
.697 .64 .788 r
.37861 .4565 .37386 .46031 .37846 .46452 .38321 .46073 Mtetra
.699 .642 .789 r
.37401 .45229 .36925 .45612 .37386 .46031 .37861 .4565 Mtetra
.7 .643 .79 r
.36939 .4481 .36463 .45195 .36925 .45612 .37401 .45229 Mtetra
.701 .644 .79 r
.36476 .44393 .36001 .44778 .36463 .45195 .36939 .4481 Mtetra
.701 .645 .791 r
.36013 .43976 .35537 .44362 .36001 .44778 .36476 .44393 Mtetra
.35549 .43559 .35073 .43946 .35537 .44362 .36013 .43976 Mtetra
.35084 .43141 .34608 .43528 .35073 .43946 .35549 .43559 Mtetra
.701 .645 .79 r
.34618 .42722 .34142 .43111 .34608 .43528 .35084 .43141 Mtetra
.702 .646 .791 r
.34151 .42304 .33676 .42693 .34142 .43111 .34618 .42722 Mtetra
.701 .646 .791 r
.33684 .41885 .33208 .42274 .33676 .42693 .34151 .42304 Mtetra
.33216 .41465 .3274 .41855 .33208 .42274 .33684 .41885 Mtetra
.701 .645 .791 r
.32747 .41044 .32271 .41435 .3274 .41855 .33216 .41465 Mtetra
.701 .646 .791 r
.32278 .40623 .31802 .41015 .32271 .41435 .32747 .41044 Mtetra
.31807 .40201 .31332 .40593 .31802 .41015 .32278 .40623 Mtetra
.31336 .39778 .3086 .40171 .31332 .40593 .31807 .40201 Mtetra
.30865 .39355 .30389 .39749 .3086 .40171 .31336 .39778 Mtetra
.701 .645 .791 r
.30392 .38931 .29916 .39325 .30389 .39749 .30865 .39355 Mtetra
.701 .646 .791 r
.29919 .38506 .29443 .38901 .29916 .39325 .30392 .38931 Mtetra
.29444 .38081 .28968 .38477 .29443 .38901 .29919 .38506 Mtetra
.2897 .37655 .28493 .38051 .28968 .38477 .29444 .38081 Mtetra
.28494 .37229 .28018 .37625 .28493 .38051 .2897 .37655 Mtetra
.701 .645 .791 r
.28017 .36801 .27541 .37198 .28018 .37625 .28494 .37229 Mtetra
.701 .646 .791 r
.2754 .36372 .27064 .36771 .27541 .37198 .28017 .36801 Mtetra
.27062 .35944 .26586 .36343 .27064 .36771 .2754 .36372 Mtetra
.26583 .35514 .26107 .35914 .26586 .36343 .27062 .35944 Mtetra
.26104 .35084 .25627 .35484 .26107 .35914 .26583 .35514 Mtetra
.701 .645 .791 r
.25623 .34653 .25147 .35054 .25627 .35484 .26104 .35084 Mtetra
.702 .646 .791 r
.25142 .34221 .24666 .34623 .25147 .35054 .25623 .34653 Mtetra
.701 .646 .791 r
.2466 .33789 .24184 .34191 .24666 .34623 .25142 .34221 Mtetra
.24177 .33356 .23701 .33759 .24184 .34191 .2466 .33789 Mtetra
.23694 .32922 .23217 .33325 .23701 .33759 .24177 .33356 Mtetra
.23209 .32488 .22733 .32892 .23217 .33325 .23694 .32922 Mtetra
.22724 .32052 .22248 .32457 .22733 .32892 .23209 .32488 Mtetra
.702 .646 .791 r
.22238 .31616 .21762 .32022 .22248 .32457 .22724 .32052 Mtetra
.701 .646 .791 r
.21752 .3118 .21275 .31586 .21762 .32022 .22238 .31616 Mtetra
.21264 .30743 .20788 .31149 .21275 .31586 .21752 .3118 Mtetra
.20776 .30304 .20299 .30712 .20788 .31149 .21264 .30743 Mtetra
.20287 .29865 .1981 .30274 .20299 .30712 .20776 .30304 Mtetra
.702 .646 .791 r
.19797 .29426 .1932 .29835 .1981 .30274 .20287 .29865 Mtetra
.701 .646 .791 r
.19306 .28985 .18829 .29395 .1932 .29835 .19797 .29426 Mtetra
.18814 .28545 .18338 .28954 .18829 .29395 .19306 .28985 Mtetra
.702 .646 .791 r
.63878 .68196 .63405 .68548 .63826 .68925 .64299 .68574 Mtetra
.701 .646 .791 r
.63457 .67818 .62984 .6817 .63405 .68548 .63878 .68196 Mtetra
.63036 .67439 .62562 .67791 .62984 .6817 .63457 .67818 Mtetra
.62613 .6706 .6214 .67412 .62562 .67791 .63036 .67439 Mtetra
.6219 .6668 .61717 .67033 .6214 .67412 .62613 .6706 Mtetra
.702 .645 .79 r
.61767 .66299 .61293 .66653 .61717 .67033 .6219 .6668 Mtetra
.702 .646 .791 r
.61342 .65917 .60869 .66272 .61293 .66653 .61767 .66299 Mtetra
.701 .646 .791 r
.60917 .65535 .60444 .65891 .60869 .66272 .61342 .65917 Mtetra
.60492 .65153 .60018 .65509 .60444 .65891 .60917 .65535 Mtetra
.60066 .64771 .59592 .65126 .60018 .65509 .60492 .65153 Mtetra
.59639 .64387 .59165 .64743 .59592 .65126 .60066 .64771 Mtetra
.702 .645 .79 r
.59211 .64002 .58737 .6436 .59165 .64743 .59639 .64387 Mtetra
.702 .646 .791 r
.58783 .63617 .58309 .63976 .58737 .6436 .59211 .64002 Mtetra
.58354 .63232 .5788 .63591 .58309 .63976 .58783 .63617 Mtetra
.701 .646 .791 r
.57924 .62847 .5745 .63205 .5788 .63591 .58354 .63232 Mtetra
.57494 .62461 .5702 .6282 .5745 .63205 .57924 .62847 Mtetra
.702 .646 .791 r
.57063 .62074 .56589 .62435 .5702 .6282 .57494 .62461 Mtetra
.703 .646 .79 r
.56632 .61687 .56157 .6205 .56589 .62435 .57063 .62074 Mtetra
.703 .647 .791 r
.56199 .61302 .55725 .61666 .56157 .6205 .56632 .61687 Mtetra
.705 .649 .791 r
.55767 .60918 .55292 .61285 .55725 .61666 .56199 .61302 Mtetra
.708 .651 .791 r
.55333 .60538 .54859 .6091 .55292 .61285 .55767 .60918 Mtetra
.714 .656 .79 r
.54899 .60166 .54425 .60549 .54859 .6091 .55333 .60538 Mtetra
.725 .664 .789 r
.54465 .59808 .53991 .60213 .54425 .60549 .54899 .60166 Mtetra
.747 .68 .786 r
.5403 .59482 .53557 .59926 .53991 .60213 .54465 .59808 Mtetra
.786 .71 .779 r
.53596 .59216 .53123 .59735 .53557 .59926 .5403 .59482 Mtetra
.85 .756 .758 r
.53162 .59065 .52689 .59729 .53123 .59735 .53596 .59216 Mtetra
.932 .812 .704 r
.52728 .59133 .52257 .60066 .52689 .59729 .53162 .59065 Mtetra
.992 .848 .594 r
.52297 .59599 .51826 .61 .52257 .60066 .52728 .59133 Mtetra
.98 .835 .437 r
.51866 .60736 .51394 .62832 .51826 .61 .52297 .59599 Mtetra
.857 .759 .249 r
.51434 .62821 .50955 .65628 .51394 .62832 .51866 .60736 Mtetra
0 0 0 r
.50994 .65749 .50502 .68563 .50955 .65628 .51434 .62821 Mtetra
.016 0 .218 r
.50539 .6838 .50036 .69727 .50502 .68563 .50994 .65749 Mtetra
.695 .277 .249 r
.50071 .68775 .4957 .67912 .50036 .69727 .50539 .6838 Mtetra
0 0 .289 r
.49607 .6633 .49118 .64288 .4957 .67912 .50071 .68775 Mtetra
0 0 .427 r
.49155 .62641 .48678 .60796 .49118 .64288 .49607 .6633 Mtetra
.166 .063 .484 r
.48714 .59432 .48241 .58317 .48678 .60796 .49155 .62641 Mtetra
.295 .18 .548 r
.48274 .57279 .47801 .56832 .48241 .58317 .48714 .59432 Mtetra
.448 .342 .642 r
.47831 .56062 .47356 .56086 .47801 .56832 .48274 .57279 Mtetra
.658 .585 .762 r
.47382 .55539 .46902 .5588 .47356 .56086 .47831 .56062 Mtetra
.879 .881 .831 r
.46924 .55541 .4644 .56109 .46902 .5588 .47382 .55539 Mtetra
.872 .976 .672 r
.46457 .55963 .45967 .56691 .4644 .56109 .46924 .55541 Mtetra
.669 .845 .434 r
.45979 .56672 .45484 .57469 .45967 .56691 .46457 .55963 Mtetra
0 0 0 r
.45495 .57413 .44999 .58133 .45484 .57469 .45979 .56672 Mtetra
.632 .919 .641 r
.45014 .57794 .44521 .58283 .44999 .58133 .45495 .57413 Mtetra
.608 .694 .904 r
.44548 .57467 .44062 .57662 .44521 .58283 .45014 .57794 Mtetra
.411 .341 .668 r
.44101 .56382 .43625 .56357 .44062 .57662 .44548 .57467 Mtetra
.383 .267 .596 r
.43672 .54824 .43202 .54726 .43625 .56357 .44101 .56382 Mtetra
.401 .27 .586 r
.4325 .53177 .42782 .53125 .43202 .54726 .43672 .54824 Mtetra
.438 .306 .602 r
.42827 .51702 .42359 .51749 .42782 .53125 .4325 .53177 Mtetra
.485 .359 .633 r
.42398 .50491 .41928 .50637 .42359 .51749 .42827 .51702 Mtetra
.535 .421 .67 r
.41963 .49526 .41491 .49749 .41928 .50637 .42398 .50491 Mtetra
.581 .481 .705 r
.4152 .48749 .41048 .49029 .41491 .49749 .41963 .49526 Mtetra
.62 .532 .733 r
.41073 .48104 .406 .48422 .41048 .49029 .4152 .48749 Mtetra
.649 .571 .753 r
.40623 .47546 .40148 .47889 .406 .48422 .41073 .48104 Mtetra
.668 .598 .767 r
.40169 .47044 .39694 .47402 .40148 .47889 .40623 .47546 Mtetra
.68 .616 .777 r
.39713 .46576 .39238 .46944 .39694 .47402 .40169 .47044 Mtetra
.688 .627 .782 r
.39256 .46129 .3878 .46503 .39238 .46944 .39713 .46576 Mtetra
.693 .634 .785 r
.38797 .45694 .38321 .46073 .3878 .46503 .39256 .46129 Mtetra
.697 .638 .787 r
.38338 .45268 .37861 .4565 .38321 .46073 .38797 .45694 Mtetra
.699 .642 .789 r
.37877 .44846 .37401 .45229 .37861 .4565 .38338 .45268 Mtetra
.699 .643 .79 r
.37415 .44426 .36939 .4481 .37401 .45229 .37877 .44846 Mtetra
.7 .644 .79 r
.36952 .44007 .36476 .44393 .36939 .4481 .37415 .44426 Mtetra
.701 .644 .79 r
.36489 .43589 .36013 .43976 .36476 .44393 .36952 .44007 Mtetra
.701 .645 .79 r
.36025 .4317 .35549 .43559 .36013 .43976 .36489 .43589 Mtetra
.701 .646 .791 r
.3556 .42752 .35084 .43141 .35549 .43559 .36025 .4317 Mtetra
.35094 .42334 .34618 .42722 .35084 .43141 .3556 .42752 Mtetra
.701 .645 .791 r
.34628 .41914 .34151 .42304 .34618 .42722 .35094 .42334 Mtetra
.701 .645 .79 r
.34161 .41494 .33684 .41885 .34151 .42304 .34628 .41914 Mtetra
.702 .646 .791 r
.33693 .41073 .33216 .41465 .33684 .41885 .34161 .41494 Mtetra
.701 .646 .791 r
.33224 .40652 .32747 .41044 .33216 .41465 .33693 .41073 Mtetra
.32754 .40231 .32278 .40623 .32747 .41044 .33224 .40652 Mtetra
.32284 .39808 .31807 .40201 .32278 .40623 .32754 .40231 Mtetra
.31813 .39385 .31336 .39778 .31807 .40201 .32284 .39808 Mtetra
.702 .646 .791 r
.31341 .38961 .30865 .39355 .31336 .39778 .31813 .39385 Mtetra
.701 .646 .791 r
.30869 .38536 .30392 .38931 .30865 .39355 .31341 .38961 Mtetra
.30395 .38111 .29919 .38506 .30392 .38931 .30869 .38536 Mtetra
.29921 .37685 .29444 .38081 .29919 .38506 .30395 .38111 Mtetra
.29446 .37258 .2897 .37655 .29444 .38081 .29921 .37685 Mtetra
.702 .646 .791 r
.28971 .36831 .28494 .37229 .2897 .37655 .29446 .37258 Mtetra
.701 .646 .791 r
.28494 .36403 .28017 .36801 .28494 .37229 .28971 .36831 Mtetra
.28017 .35974 .2754 .36372 .28017 .36801 .28494 .36403 Mtetra
.27539 .35545 .27062 .35944 .2754 .36372 .28017 .35974 Mtetra
.701 .645 .791 r
.2706 .35114 .26583 .35514 .27062 .35944 .27539 .35545 Mtetra
.702 .646 .791 r
.26581 .34683 .26104 .35084 .26583 .35514 .2706 .35114 Mtetra
.701 .646 .791 r
.261 .34251 .25623 .34653 .26104 .35084 .26581 .34683 Mtetra
.25619 .33819 .25142 .34221 .25623 .34653 .261 .34251 Mtetra
.25137 .33387 .2466 .33789 .25142 .34221 .25619 .33819 Mtetra
.701 .645 .791 r
.24655 .32952 .24177 .33356 .2466 .33789 .25137 .33387 Mtetra
.702 .646 .791 r
.24171 .32518 .23694 .32922 .24177 .33356 .24655 .32952 Mtetra
.23687 .32083 .23209 .32488 .23694 .32922 .24171 .32518 Mtetra
.701 .646 .791 r
.23202 .31647 .22724 .32052 .23209 .32488 .23687 .32083 Mtetra
.22716 .31211 .22238 .31616 .22724 .32052 .23202 .31647 Mtetra
.22229 .30773 .21752 .3118 .22238 .31616 .22716 .31211 Mtetra
.702 .646 .791 r
.21741 .30335 .21264 .30743 .21752 .3118 .22229 .30773 Mtetra
.21253 .29896 .20776 .30304 .21264 .30743 .21741 .30335 Mtetra
.701 .646 .791 r
.20764 .29457 .20287 .29865 .20776 .30304 .21253 .29896 Mtetra
.20274 .29017 .19797 .29426 .20287 .29865 .20764 .29457 Mtetra
.19783 .28576 .19306 .28985 .19797 .29426 .20274 .29017 Mtetra
.701 .645 .791 r
.19291 .28134 .18814 .28545 .19306 .28985 .19783 .28576 Mtetra
.701 .646 .791 r
.64352 .67844 .63878 .68196 .64299 .68574 .64773 .68222 Mtetra
.63931 .67466 .63457 .67818 .63878 .68196 .64352 .67844 Mtetra
.6351 .67086 .63036 .67439 .63457 .67818 .63931 .67466 Mtetra
.701 .645 .791 r
.63087 .66706 .62613 .6706 .63036 .67439 .6351 .67086 Mtetra
.702 .646 .791 r
.62664 .66325 .6219 .6668 .62613 .6706 .63087 .66706 Mtetra
.701 .646 .791 r
.62241 .65944 .61767 .66299 .6219 .6668 .62664 .66325 Mtetra
.61817 .65562 .61342 .65917 .61767 .66299 .62241 .65944 Mtetra
.61392 .6518 .60917 .65535 .61342 .65917 .61817 .65562 Mtetra
.60966 .64797 .60492 .65153 .60917 .65535 .61392 .6518 Mtetra
.702 .645 .79 r
.6054 .64413 .60066 .64771 .60492 .65153 .60966 .64797 Mtetra
.702 .646 .791 r
.60113 .64029 .59639 .64387 .60066 .64771 .6054 .64413 Mtetra
.701 .646 .791 r
.59686 .63644 .59211 .64002 .59639 .64387 .60113 .64029 Mtetra
.59257 .6326 .58783 .63617 .59211 .64002 .59686 .63644 Mtetra
.58829 .62874 .58354 .63232 .58783 .63617 .59257 .6326 Mtetra
.702 .646 .791 r
.58399 .62487 .57924 .62847 .58354 .63232 .58829 .62874 Mtetra
.702 .646 .79 r
.57969 .621 .57494 .62461 .57924 .62847 .58399 .62487 Mtetra
.702 .646 .791 r
.57538 .61713 .57063 .62074 .57494 .62461 .57969 .621 Mtetra
.57106 .61326 .56632 .61687 .57063 .62074 .57538 .61713 Mtetra
.702 .647 .791 r
.56674 .60939 .56199 .61302 .56632 .61687 .57106 .61326 Mtetra
.704 .647 .791 r
.56242 .60552 .55767 .60918 .56199 .61302 .56674 .60939 Mtetra
.706 .649 .791 r
.55808 .60168 .55333 .60538 .55767 .60918 .56242 .60552 Mtetra
.71 .652 .791 r
.55374 .59789 .54899 .60166 .55333 .60538 .55808 .60168 Mtetra
.717 .658 .79 r
.5494 .5942 .54465 .59808 .54899 .60166 .55374 .59789 Mtetra
.73 .669 .79 r
.54505 .5907 .5403 .59482 .54465 .59808 .5494 .5942 Mtetra
.756 .688 .786 r
.5407 .58756 .53596 .59216 .5403 .59482 .54505 .5907 Mtetra
.802 .722 .776 r
.53635 .58515 .53162 .59065 .53596 .59216 .5407 .58756 Mtetra
.872 .772 .748 r
.53201 .58412 .52728 .59133 .53162 .59065 .53635 .58515 Mtetra
.954 .828 .681 r
.52768 .58567 .52297 .59599 .52728 .59133 .53201 .58412 Mtetra
.998 .853 .555 r
.52337 .59183 .51866 .60736 .52297 .59599 .52768 .58567 Mtetra
.957 .822 .387 r
.51907 .60544 .51434 .62821 .51866 .60736 .52337 .59183 Mtetra
.792 .721 .189 r
.51475 .6287 .50994 .65749 .51434 .62821 .51907 .60544 Mtetra
0 0 .051 r
.51034 .65834 .50539 .6838 .50994 .65749 .51475 .6287 Mtetra
.165 0 .247 r
.50576 .68 .50071 .68775 .50539 .6838 .51034 .65834 Mtetra
.854 .404 .124 r
.50107 .67598 .49607 .6633 .50071 .68775 .50576 .68 Mtetra
0 0 .356 r
.49643 .64679 .49155 .62641 .49607 .6633 .50107 .67598 Mtetra
.049 0 .445 r
.49192 .61064 .48714 .59432 .49155 .62641 .49643 .64679 Mtetra
.202 .094 .501 r
.48749 .58175 .48274 .57279 .48714 .59432 .49192 .61064 Mtetra
.335 .222 .574 r
.48307 .56345 .47831 .56062 .48274 .57279 .48749 .58175 Mtetra
.512 .415 .682 r
.4786 .55395 .47382 .55539 .47831 .56062 .48307 .56345 Mtetra
.756 .709 .808 r
.47407 .55101 .46924 .55541 .47382 .55539 .4786 .55395 Mtetra
.915 .97 .788 r
.46945 .55315 .46457 .55963 .46924 .55541 .47407 .55101 Mtetra
.76 .913 .534 r
.46473 .55904 .45979 .56672 .46457 .55963 .46945 .55315 Mtetra
0 0 0 r
.45992 .56655 .45495 .57413 .45979 .56672 .46473 .55904 Mtetra
.557 .828 .474 r
.4551 .5721 .45014 .57794 .45495 .57413 .45992 .56655 Mtetra
.712 .921 .964 r
.45037 .5717 .44548 .57467 .45014 .57794 .4551 .5721 Mtetra
.449 .416 .729 r
.44582 .56346 .44101 .56382 .44548 .57467 .45037 .5717 Mtetra
.383 .279 .612 r
.44146 .54914 .43672 .54824 .44101 .56382 .44582 .56346 Mtetra
.39 .263 .585 r
.4372 .53256 .4325 .53177 .43672 .54824 .44146 .54914 Mtetra
.421 .289 .594 r
.43297 .51696 .42827 .51702 .4325 .53177 .4372 .53256 Mtetra
.466 .337 .62 r
.42869 .50382 .42398 .50491 .42827 .51702 .43297 .51696 Mtetra
.516 .397 .656 r
.42434 .49328 .41963 .49526 .42398 .50491 .42869 .50382 Mtetra
.565 .459 .692 r
.41994 .48487 .4152 .48749 .41963 .49526 .42434 .49328 Mtetra
.607 .514 .723 r
.41548 .47798 .41073 .48104 .4152 .48749 .41994 .48487 Mtetra
.639 .557 .747 r
.41098 .47211 .40623 .47546 .41073 .48104 .41548 .47798 Mtetra
.661 .588 .763 r
.40645 .4669 .40169 .47044 .40623 .47546 .41098 .47211 Mtetra
.677 .61 .773 r
.4019 .4621 .39713 .46576 .40169 .47044 .40645 .4669 Mtetra
.686 .623 .78 r
.39732 .45756 .39256 .46129 .39713 .46576 .4019 .4621 Mtetra
.692 .632 .784 r
.39274 .45317 .38797 .45694 .39256 .46129 .39732 .45756 Mtetra
.695 .637 .787 r
.38814 .44887 .38338 .45268 .38797 .45694 .39274 .45317 Mtetra
.698 .64 .788 r
.38354 .44462 .37877 .44846 .38338 .45268 .38814 .44887 Mtetra
.699 .642 .789 r
.37892 .4404 .37415 .44426 .37877 .44846 .38354 .44462 Mtetra
.7 .644 .79 r
.37429 .43621 .36952 .44007 .37415 .44426 .37892 .4404 Mtetra
.7 .645 .791 r
.36966 .43202 .36489 .43589 .36952 .44007 .37429 .43621 Mtetra
.701 .645 .791 r
.36502 .42783 .36025 .4317 .36489 .43589 .36966 .43202 Mtetra
.701 .645 .79 r
.36037 .42363 .3556 .42752 .36025 .4317 .36502 .42783 Mtetra
.702 .645 .79 r
.35572 .41944 .35094 .42334 .3556 .42752 .36037 .42363 Mtetra
.702 .646 .791 r
.35105 .41524 .34628 .41914 .35094 .42334 .35572 .41944 Mtetra
.701 .646 .791 r
.34638 .41103 .34161 .41494 .34628 .41914 .35105 .41524 Mtetra
.3417 .40682 .33693 .41073 .34161 .41494 .34638 .41103 Mtetra
.701 .645 .791 r
.33701 .4026 .33224 .40652 .33693 .41073 .3417 .40682 Mtetra
.702 .646 .791 r
.33232 .39837 .32754 .40231 .33224 .40652 .33701 .4026 Mtetra
.32762 .39414 .32284 .39808 .32754 .40231 .33232 .39837 Mtetra
.701 .646 .791 r
.32291 .38991 .31813 .39385 .32284 .39808 .32762 .39414 Mtetra
.31819 .38566 .31341 .38961 .31813 .39385 .32291 .38991 Mtetra
.31346 .38141 .30869 .38536 .31341 .38961 .31819 .38566 Mtetra
.702 .646 .791 r
.30873 .37715 .30395 .38111 .30869 .38536 .31346 .38141 Mtetra
.30399 .37288 .29921 .37685 .30395 .38111 .30873 .37715 Mtetra
.701 .646 .791 r
.29924 .36861 .29446 .37258 .29921 .37685 .30399 .37288 Mtetra
.29448 .36433 .28971 .36831 .29446 .37258 .29924 .36861 Mtetra
.28972 .36004 .28494 .36403 .28971 .36831 .29448 .36433 Mtetra
.702 .646 .791 r
.28495 .35574 .28017 .35974 .28494 .36403 .28972 .36004 Mtetra
.28017 .35144 .27539 .35545 .28017 .35974 .28495 .35574 Mtetra
.701 .646 .791 r
.27538 .34713 .2706 .35114 .27539 .35545 .28017 .35144 Mtetra
.27058 .34282 .26581 .34683 .2706 .35114 .27538 .34713 Mtetra
.26578 .3385 .261 .34251 .26581 .34683 .27058 .34282 Mtetra
.26097 .33416 .25619 .33819 .261 .34251 .26578 .3385 Mtetra
.702 .646 .791 r
.25615 .32983 .25137 .33387 .25619 .33819 .26097 .33416 Mtetra
.701 .646 .791 r
.25132 .32548 .24655 .32952 .25137 .33387 .25615 .32983 Mtetra
.24649 .32113 .24171 .32518 .24655 .32952 .25132 .32548 Mtetra
.24164 .31678 .23687 .32083 .24171 .32518 .24649 .32113 Mtetra
.23679 .31241 .23202 .31647 .23687 .32083 .24164 .31678 Mtetra
.702 .646 .791 r
.23194 .30804 .22716 .31211 .23202 .31647 .23679 .31241 Mtetra
.22707 .30366 .22229 .30773 .22716 .31211 .23194 .30804 Mtetra
.701 .646 .791 r
.22219 .29927 .21741 .30335 .22229 .30773 .22707 .30366 Mtetra
.21731 .29487 .21253 .29896 .21741 .30335 .22219 .29927 Mtetra
.21242 .29048 .20764 .29457 .21253 .29896 .21731 .29487 Mtetra
.20752 .28606 .20274 .29017 .20764 .29457 .21242 .29048 Mtetra
.702 .646 .791 r
.20261 .28165 .19783 .28576 .20274 .29017 .20752 .28606 Mtetra
.701 .646 .791 r
.1977 .27722 .19291 .28134 .19783 .28576 .20261 .28165 Mtetra
.64827 .67492 .64352 .67844 .64773 .68222 .65247 .67871 Mtetra
.64406 .67113 .63931 .67466 .64352 .67844 .64827 .67492 Mtetra
.702 .646 .791 r
.63984 .66733 .6351 .67086 .63931 .67466 .64406 .67113 Mtetra
.701 .646 .791 r
.63562 .66352 .63087 .66706 .6351 .67086 .63984 .66733 Mtetra
.63139 .65971 .62664 .66325 .63087 .66706 .63562 .66352 Mtetra
.62716 .65589 .62241 .65944 .62664 .66325 .63139 .65971 Mtetra
.62292 .65207 .61817 .65562 .62241 .65944 .62716 .65589 Mtetra
.702 .645 .79 r
.61867 .64824 .61392 .6518 .61817 .65562 .62292 .65207 Mtetra
.702 .646 .791 r
.61441 .6444 .60966 .64797 .61392 .6518 .61867 .64824 Mtetra
.701 .646 .791 r
.61015 .64056 .6054 .64413 .60966 .64797 .61441 .6444 Mtetra
.60588 .63672 .60113 .64029 .6054 .64413 .61015 .64056 Mtetra
.60161 .63287 .59686 .63644 .60113 .64029 .60588 .63672 Mtetra
.59733 .629 .59257 .6326 .59686 .63644 .60161 .63287 Mtetra
.702 .646 .79 r
.59304 .62514 .58829 .62874 .59257 .6326 .59733 .629 Mtetra
.702 .646 .791 r
.58874 .62127 .58399 .62487 .58829 .62874 .59304 .62514 Mtetra
.58444 .61739 .57969 .621 .58399 .62487 .58874 .62127 Mtetra
.58014 .61352 .57538 .61713 .57969 .621 .58444 .61739 Mtetra
.57582 .60963 .57106 .61326 .57538 .61713 .58014 .61352 Mtetra
.5715 .60575 .56674 .60939 .57106 .61326 .57582 .60963 Mtetra
.703 .647 .791 r
.56717 .60187 .56242 .60552 .56674 .60939 .5715 .60575 Mtetra
.704 .648 .791 r
.56284 .59801 .55808 .60168 .56242 .60552 .56717 .60187 Mtetra
.706 .65 .791 r
.5585 .59417 .55374 .59789 .55808 .60168 .56284 .59801 Mtetra
.711 .654 .791 r
.55415 .5904 .5494 .5942 .55374 .59789 .5585 .59417 Mtetra
.72 .661 .79 r
.5498 .58674 .54505 .5907 .5494 .5942 .55415 .5904 Mtetra
.737 .674 .789 r
.54545 .58332 .5407 .58756 .54505 .5907 .5498 .58674 Mtetra
.767 .697 .785 r
.5411 .58036 .53635 .58515 .5407 .58756 .54545 .58332 Mtetra
.82 .736 .772 r
.53675 .57826 .53201 .58412 .53635 .58515 .5411 .58036 Mtetra
.896 .791 .737 r
.53241 .57781 .52768 .58567 .53201 .58412 .53675 .57826 Mtetra
.973 .842 .653 r
.52808 .58039 .52337 .59183 .52768 .58567 .53241 .57781 Mtetra
.995 .852 .512 r
.52378 .58824 .51907 .60544 .52337 .59183 .52808 .58039 Mtetra
.924 .803 .336 r
.51949 .60421 .51475 .6287 .51907 .60544 .52378 .58824 Mtetra
.712 .674 .128 r
.51517 .62955 .51034 .65834 .51475 .6287 .51949 .60421 Mtetra
0 0 .109 r
.51073 .65834 .50576 .68 .51034 .65834 .51517 .62955 Mtetra
.327 .006 .259 r
.50612 .67401 .50107 .67598 .50576 .68 .51073 .65834 Mtetra
.81 .434 0 r
.50142 .66232 .49643 .64679 .50107 .67598 .50612 .67401 Mtetra
0 0 .397 r
.49679 .63006 .49192 .61064 .49643 .64679 .50142 .66232 Mtetra
.099 .014 .462 r
.49228 .59574 .48749 .58175 .49192 .61064 .49679 .63006 Mtetra
.238 .128 .52 r
.48783 .57032 .48307 .56345 .48749 .58175 .49228 .59574 Mtetra
.384 .275 .605 r
.48338 .55521 .4786 .55395 .48307 .56345 .48783 .57032 Mtetra
.594 .513 .732 r
.47888 .54838 .47407 .55101 .4786 .55395 .48338 .55521 Mtetra
.856 .852 .837 r
.47431 .5478 .46945 .55315 .47407 .55101 .47888 .54838 Mtetra
.861 .977 .674 r
.46964 .55193 .46473 .55904 .46945 .55315 .47431 .5478 Mtetra
.638 .832 .425 r
.46488 .5589 .45992 .56655 .46473 .55904 .46964 .55193 Mtetra
0 0 0 r
.46006 .56554 .4551 .5721 .45992 .56655 .46488 .5589 Mtetra
.689 .978 .81 r
.45529 .56767 .45037 .5717 .4551 .5721 .46006 .56554 Mtetra
.52 .549 .826 r
.45067 .5623 .44582 .56346 .45037 .5717 .45529 .56767 Mtetra
.39 .305 .639 r
.44623 .54981 .44146 .54914 .44582 .56346 .45067 .5623 Mtetra
.381 .261 .589 r
.44193 .53356 .4372 .53256 .44146 .54914 .44623 .54981 Mtetra
.407 .275 .587 r
.43767 .51727 .43297 .51696 .4372 .53256 .44193 .53356 Mtetra
.447 .316 .608 r
.4334 .50311 .42869 .50382 .43297 .51696 .43767 .51727 Mtetra
.496 .372 .642 r
.42907 .49162 .42434 .49328 .42869 .50382 .4334 .50311 Mtetra
.546 .435 .678 r
.42467 .48247 .41994 .48487 .42434 .49328 .42907 .49162 Mtetra
.592 .494 .712 r
.42023 .47506 .41548 .47798 .41994 .48487 .42467 .48247 Mtetra
.628 .542 .739 r
.41574 .46884 .41098 .47211 .41548 .47798 .42023 .47506 Mtetra
.654 .578 .758 r
.41121 .46341 .40645 .4669 .41098 .47211 .41574 .46884 Mtetra
.671 .603 .77 r
.40666 .45848 .4019 .4621 .40645 .4669 .41121 .46341 Mtetra
.683 .619 .778 r
.40209 .45384 .39732 .45756 .4019 .4621 .40666 .45848 Mtetra
.69 .629 .783 r
.39751 .44939 .39274 .45317 .39732 .45756 .40209 .45384 Mtetra
.694 .635 .786 r
.39292 .44505 .38814 .44887 .39274 .45317 .39751 .44939 Mtetra
.697 .639 .788 r
.38831 .44078 .38354 .44462 .38814 .44887 .39292 .44505 Mtetra
.699 .642 .789 r
.3837 .43656 .37892 .4404 .38354 .44462 .38831 .44078 Mtetra
.7 .643 .79 r
.37907 .43234 .37429 .43621 .37892 .4404 .3837 .43656 Mtetra
.7 .644 .79 r
.37444 .42814 .36966 .43202 .37429 .43621 .37907 .43234 Mtetra
.701 .645 .79 r
.3698 .42394 .36502 .42783 .36966 .43202 .37444 .42814 Mtetra
.701 .645 .791 r
.36515 .41974 .36037 .42363 .36502 .42783 .3698 .42394 Mtetra
.701 .646 .791 r
.36049 .41554 .35572 .41944 .36037 .42363 .36515 .41974 Mtetra
.35583 .41133 .35105 .41524 .35572 .41944 .36049 .41554 Mtetra
.701 .645 .791 r
.35116 .40712 .34638 .41103 .35105 .41524 .35583 .41133 Mtetra
.702 .645 .791 r
.34648 .4029 .3417 .40682 .34638 .41103 .35116 .40712 Mtetra
.701 .646 .791 r
.34179 .39867 .33701 .4026 .3417 .40682 .34648 .4029 Mtetra
.3371 .39444 .33232 .39837 .33701 .4026 .34179 .39867 Mtetra
.3324 .3902 .32762 .39414 .33232 .39837 .3371 .39444 Mtetra
.32769 .38596 .32291 .38991 .32762 .39414 .3324 .3902 Mtetra
.702 .646 .791 r
.32297 .3817 .31819 .38566 .32291 .38991 .32769 .38596 Mtetra
.701 .646 .791 r
.31824 .37744 .31346 .38141 .31819 .38566 .32297 .3817 Mtetra
.31351 .37318 .30873 .37715 .31346 .38141 .31824 .37744 Mtetra
.30877 .36891 .30399 .37288 .30873 .37715 .31351 .37318 Mtetra
.30402 .36463 .29924 .36861 .30399 .37288 .30877 .36891 Mtetra
.29927 .36034 .29448 .36433 .29924 .36861 .30402 .36463 Mtetra
.702 .646 .791 r
.2945 .35604 .28972 .36004 .29448 .36433 .29927 .36034 Mtetra
.701 .646 .791 r
.28973 .35174 .28495 .35574 .28972 .36004 .2945 .35604 Mtetra
.28495 .34744 .28017 .35144 .28495 .35574 .28973 .35174 Mtetra
.28016 .34312 .27538 .34713 .28017 .35144 .28495 .34744 Mtetra
.27537 .3388 .27058 .34282 .27538 .34713 .28016 .34312 Mtetra
.702 .646 .791 r
.27057 .33447 .26578 .3385 .27058 .34282 .27537 .3388 Mtetra
.701 .646 .791 r
.26575 .33013 .26097 .33416 .26578 .3385 .27057 .33447 Mtetra
.26094 .32579 .25615 .32983 .26097 .33416 .26575 .33013 Mtetra
.25611 .32144 .25132 .32548 .25615 .32983 .26094 .32579 Mtetra
.25127 .31708 .24649 .32113 .25132 .32548 .25611 .32144 Mtetra
.24643 .31271 .24164 .31678 .24649 .32113 .25127 .31708 Mtetra
.702 .646 .791 r
.24158 .30834 .23679 .31241 .24164 .31678 .24643 .31271 Mtetra
.701 .646 .791 r
.23672 .30396 .23194 .30804 .23679 .31241 .24158 .30834 Mtetra
.23185 .29958 .22707 .30366 .23194 .30804 .23672 .30396 Mtetra
.22698 .29519 .22219 .29927 .22707 .30366 .23185 .29958 Mtetra
.2221 .29078 .21731 .29487 .22219 .29927 .22698 .29519 Mtetra
.702 .646 .791 r
.21721 .28637 .21242 .29048 .21731 .29487 .2221 .29078 Mtetra
.701 .646 .791 r
.21231 .28196 .20752 .28606 .21242 .29048 .21721 .28637 Mtetra
.2074 .27753 .20261 .28165 .20752 .28606 .21231 .28196 Mtetra
.20248 .2731 .1977 .27722 .20261 .28165 .2074 .27753 Mtetra
.702 .646 .791 r
.65302 .67139 .64827 .67492 .65247 .67871 .65722 .67519 Mtetra
.701 .646 .791 r
.64881 .66759 .64406 .67113 .64827 .67492 .65302 .67139 Mtetra
.6446 .66379 .63984 .66733 .64406 .67113 .64881 .66759 Mtetra
.64038 .65998 .63562 .66352 .63984 .66733 .6446 .66379 Mtetra
.63615 .65616 .63139 .65971 .63562 .66352 .64038 .65998 Mtetra
.63191 .65234 .62716 .65589 .63139 .65971 .63615 .65616 Mtetra
.702 .646 .791 r
.62767 .64851 .62292 .65207 .62716 .65589 .63191 .65234 Mtetra
.701 .646 .791 r
.62342 .64467 .61867 .64824 .62292 .65207 .62767 .64851 Mtetra
.61917 .64083 .61441 .6444 .61867 .64824 .62342 .64467 Mtetra
.61491 .63699 .61015 .64056 .61441 .6444 .61917 .64083 Mtetra
.61064 .63313 .60588 .63672 .61015 .64056 .61491 .63699 Mtetra
.702 .646 .791 r
.60637 .62927 .60161 .63287 .60588 .63672 .61064 .63313 Mtetra
.60209 .62541 .59733 .629 .60161 .63287 .60637 .62927 Mtetra
.701 .646 .791 r
.5978 .62154 .59304 .62514 .59733 .629 .60209 .62541 Mtetra
.59351 .61767 .58874 .62127 .59304 .62514 .5978 .62154 Mtetra
.58921 .61378 .58444 .61739 .58874 .62127 .59351 .61767 Mtetra
.702 .646 .791 r
.5849 .60989 .58014 .61352 .58444 .61739 .58921 .61378 Mtetra
.58058 .60601 .57582 .60963 .58014 .61352 .5849 .60989 Mtetra
.57626 .60212 .5715 .60575 .57582 .60963 .58058 .60601 Mtetra
.702 .647 .791 r
.57194 .59823 .56717 .60187 .5715 .60575 .57626 .60212 Mtetra
.703 .647 .791 r
.5676 .59434 .56284 .59801 .56717 .60187 .57194 .59823 Mtetra
.705 .649 .791 r
.56326 .59048 .5585 .59417 .56284 .59801 .5676 .59434 Mtetra
.708 .651 .791 r
.55892 .58665 .55415 .5904 .5585 .59417 .56326 .59048 Mtetra
.713 .656 .791 r
.55457 .5829 .5498 .58674 .55415 .5904 .55892 .58665 Mtetra
.724 .664 .791 r
.55021 .5793 .54545 .58332 .5498 .58674 .55457 .5829 Mtetra
.744 .68 .789 r
.54585 .57599 .5411 .58036 .54545 .58332 .55021 .5793 Mtetra
.78 .708 .784 r
.5415 .57323 .53675 .57826 .5411 .58036 .54585 .57599 Mtetra
.84 .753 .767 r
.53715 .57151 .53241 .57781 .53675 .57826 .5415 .57323 Mtetra
.921 .811 .721 r
.53281 .57176 .52808 .58039 .53241 .57781 .53715 .57151 Mtetra
.987 .854 .62 r
.5285 .57555 .52378 .58824 .52808 .58039 .53281 .57176 Mtetra
.984 .846 .464 r
.52421 .5853 .51949 .60421 .52378 .58824 .5285 .57555 Mtetra
.88 .778 .281 r
.51992 .60366 .51517 .62955 .51949 .60421 .52421 .5853 Mtetra
0 0 0 r
.5156 .63048 .51073 .65834 .51517 .62955 .51992 .60366 Mtetra
0 0 .157 r
.51113 .657 .50612 .67401 .51073 .65834 .5156 .63048 Mtetra
.513 .123 .24 r
.50648 .66567 .50142 .66232 .50612 .67401 .51113 .657 Mtetra
0 0 .267 r
.50177 .64724 .49679 .63006 .50142 .66232 .50648 .66567 Mtetra
0 0 .425 r
.49715 .61353 .49228 .59574 .49679 .63006 .50177 .64724 Mtetra
.144 .049 .48 r
.49263 .58188 .48783 .57032 .49228 .59574 .49715 .61353 Mtetra
.278 .168 .544 r
.48817 .56008 .48338 .55521 .48783 .57032 .49263 .58188 Mtetra
.445 .344 .646 r
.48369 .54816 .47888 .54838 .48338 .55521 .48817 .56008 Mtetra
.699 .644 .79 r
.47915 .54402 .47431 .5478 .47888 .54838 .48369 .54816 Mtetra
.907 .966 .808 r
.47453 .54576 .46964 .55193 .47431 .5478 .47915 .54402 Mtetra
.739 .908 .533 r
.46982 .55151 .46488 .5589 .46964 .55193 .47453 .54576 Mtetra
0 0 0 r
.46503 .5585 .46006 .56554 .46488 .5589 .46982 .55151 Mtetra
.587 .884 .587 r
.46024 .5627 .45529 .56767 .46006 .56554 .46503 .5585 Mtetra
.626 .76 .943 r
.45556 .56023 .45067 .5623 .45529 .56767 .46024 .5627 Mtetra
.41 .353 .683 r
.45104 .55004 .44623 .54981 .45067 .5623 .45556 .56023 Mtetra
.376 .265 .598 r
.44668 .53465 .44193 .53356 .44623 .54981 .45104 .55004 Mtetra
.393 .263 .584 r
.4424 .51797 .43767 .51727 .44193 .53356 .44668 .53465 Mtetra
.429 .297 .598 r
.43812 .50281 .4334 .50311 .43767 .51727 .4424 .51797 Mtetra
.476 .349 .628 r
.4338 .49029 .42907 .49162 .4334 .50311 .43812 .50281 Mtetra
.527 .411 .664 r
.42942 .4803 .42467 .48247 .42907 .49162 .4338 .49029 Mtetra
.575 .473 .7 r
.42498 .4723 .42023 .47506 .42467 .48247 .42942 .4803 Mtetra
.615 .525 .73 r
.4205 .46569 .41574 .46884 .42023 .47506 .42498 .4723 Mtetra
.645 .566 .751 r
.41598 .45999 .41121 .46341 .41574 .46884 .4205 .46569 Mtetra
.666 .594 .766 r
.41144 .45488 .40666 .45848 .41121 .46341 .41598 .45999 Mtetra
.679 .614 .775 r
.40687 .45014 .40209 .45384 .40666 .45848 .41144 .45488 Mtetra
.688 .626 .782 r
.40229 .44563 .39751 .44939 .40209 .45384 .40687 .45014 Mtetra
.693 .634 .785 r
.3977 .44125 .39292 .44505 .39751 .44939 .40229 .44563 Mtetra
.696 .638 .787 r
.39309 .43695 .38831 .44078 .39292 .44505 .3977 .44125 Mtetra
.698 .641 .788 r
.38848 .43269 .3837 .43656 .38831 .44078 .39309 .43695 Mtetra
.7 .643 .789 r
.38386 .42847 .37907 .43234 .3837 .43656 .38848 .43269 Mtetra
.7 .644 .79 r
.37922 .42426 .37444 .42814 .37907 .43234 .38386 .42847 Mtetra
.701 .645 .791 r
.37458 .42005 .3698 .42394 .37444 .42814 .37922 .42426 Mtetra
.36994 .41584 .36515 .41974 .3698 .42394 .37458 .42005 Mtetra
.701 .645 .79 r
.36528 .41163 .36049 .41554 .36515 .41974 .36994 .41584 Mtetra
.702 .645 .79 r
.36062 .40741 .35583 .41133 .36049 .41554 .36528 .41163 Mtetra
.702 .646 .791 r
.35595 .40319 .35116 .40712 .35583 .41133 .36062 .40741 Mtetra
.701 .646 .791 r
.35127 .39897 .34648 .4029 .35116 .40712 .35595 .40319 Mtetra
.34658 .39474 .34179 .39867 .34648 .4029 .35127 .39897 Mtetra
.701 .645 .791 r
.34189 .3905 .3371 .39444 .34179 .39867 .34658 .39474 Mtetra
.702 .646 .791 r
.33718 .38625 .3324 .3902 .3371 .39444 .34189 .3905 Mtetra
.33248 .382 .32769 .38596 .3324 .3902 .33718 .38625 Mtetra
.701 .646 .791 r
.32776 .37774 .32297 .3817 .32769 .38596 .33248 .382 Mtetra
.32303 .37348 .31824 .37744 .32297 .3817 .32776 .37774 Mtetra
.3183 .36921 .31351 .37318 .31824 .37744 .32303 .37348 Mtetra
.702 .646 .791 r
.31356 .36493 .30877 .36891 .31351 .37318 .3183 .36921 Mtetra
.30881 .36064 .30402 .36463 .30877 .36891 .31356 .36493 Mtetra
.701 .646 .791 r
.30406 .35635 .29927 .36034 .30402 .36463 .30881 .36064 Mtetra
.29929 .35205 .2945 .35604 .29927 .36034 .30406 .35635 Mtetra
.29452 .34774 .28973 .35174 .2945 .35604 .29929 .35205 Mtetra
.701 .645 .791 r
.28974 .34342 .28495 .34744 .28973 .35174 .29452 .34774 Mtetra
.702 .646 .791 r
.28496 .3391 .28016 .34312 .28495 .34744 .28974 .34342 Mtetra
.701 .646 .791 r
.28016 .33477 .27537 .3388 .28016 .34312 .28496 .3391 Mtetra
.27536 .33044 .27057 .33447 .27537 .3388 .28016 .33477 Mtetra
.27055 .3261 .26575 .33013 .27057 .33447 .27536 .33044 Mtetra
.26573 .32175 .26094 .32579 .26575 .33013 .27055 .3261 Mtetra
.701 .645 .791 r
.2609 .31739 .25611 .32144 .26094 .32579 .26573 .32175 Mtetra
.702 .646 .791 r
.25607 .31302 .25127 .31708 .25611 .32144 .2609 .31739 Mtetra
.701 .646 .791 r
.25122 .30865 .24643 .31271 .25127 .31708 .25607 .31302 Mtetra
.24637 .30427 .24158 .30834 .24643 .31271 .25122 .30865 Mtetra
.24151 .29989 .23672 .30396 .24158 .30834 .24637 .30427 Mtetra
.23665 .29549 .23185 .29958 .23672 .30396 .24151 .29989 Mtetra
.702 .646 .791 r
.23177 .29109 .22698 .29519 .23185 .29958 .23665 .29549 Mtetra
.22689 .28668 .2221 .29078 .22698 .29519 .23177 .29109 Mtetra
.701 .646 .791 r
.222 .28226 .21721 .28637 .2221 .29078 .22689 .28668 Mtetra
.2171 .27784 .21231 .28196 .21721 .28637 .222 .28226 Mtetra
.21219 .27342 .2074 .27753 .21231 .28196 .2171 .27784 Mtetra
.701 .645 .791 r
.20728 .26897 .20248 .2731 .2074 .27753 .21219 .27342 Mtetra
.701 .646 .791 r
.65778 .66786 .65302 .67139 .65722 .67519 .66198 .67166 Mtetra
.65357 .66406 .64881 .66759 .65302 .67139 .65778 .66786 Mtetra
.64936 .66024 .6446 .66379 .64881 .66759 .65357 .66406 Mtetra
.702 .646 .791 r
.64514 .65643 .64038 .65998 .6446 .66379 .64936 .66024 Mtetra
.64091 .6526 .63615 .65616 .64038 .65998 .64514 .65643 Mtetra
.701 .646 .791 r
.63668 .64878 .63191 .65234 .63615 .65616 .64091 .6526 Mtetra
.63244 .64494 .62767 .64851 .63191 .65234 .63668 .64878 Mtetra
.62819 .6411 .62342 .64467 .62767 .64851 .63244 .64494 Mtetra
.702 .646 .791 r
.62394 .63725 .61917 .64083 .62342 .64467 .62819 .6411 Mtetra
.61967 .6334 .61491 .63699 .61917 .64083 .62394 .63725 Mtetra
.701 .646 .791 r
.61541 .62954 .61064 .63313 .61491 .63699 .61967 .6334 Mtetra
.61113 .62568 .60637 .62927 .61064 .63313 .61541 .62954 Mtetra
.60685 .62181 .60209 .62541 .60637 .62927 .61113 .62568 Mtetra
.702 .646 .791 r
.60257 .61793 .5978 .62154 .60209 .62541 .60685 .62181 Mtetra
.59827 .61405 .59351 .61767 .5978 .62154 .60257 .61793 Mtetra
.59397 .61017 .58921 .61378 .59351 .61767 .59827 .61405 Mtetra
.701 .646 .791 r
.58967 .60627 .5849 .60989 .58921 .61378 .59397 .61017 Mtetra
.702 .646 .791 r
.58535 .60238 .58058 .60601 .5849 .60989 .58967 .60627 Mtetra
.58103 .59848 .57626 .60212 .58058 .60601 .58535 .60238 Mtetra
.57671 .59458 .57194 .59823 .57626 .60212 .58103 .59848 Mtetra
.703 .647 .791 r
.57237 .59068 .5676 .59434 .57194 .59823 .57671 .59458 Mtetra
.704 .648 .791 r
.56803 .58679 .56326 .59048 .5676 .59434 .57237 .59068 Mtetra
.706 .65 .791 r
.56369 .58293 .55892 .58665 .56326 .59048 .56803 .58679 Mtetra
.709 .653 .791 r
.55934 .57912 .55457 .5829 .55892 .58665 .56369 .58293 Mtetra
.716 .658 .791 r
.55498 .5754 .55021 .5793 .55457 .5829 .55934 .57912 Mtetra
.729 .669 .791 r
.55062 .57187 .54585 .57599 .55021 .5793 .55498 .5754 Mtetra
.753 .688 .789 r
.54626 .5687 .5415 .57323 .54585 .57599 .55062 .57187 Mtetra
.796 .721 .782 r
.54191 .56619 .53715 .57151 .5415 .57323 .54626 .5687 Mtetra
.863 .772 .759 r
.53756 .56495 .53281 .57176 .53715 .57151 .54191 .56619 Mtetra
.945 .83 .7 r
.53323 .56604 .5285 .57555 .53281 .57176 .53756 .56495 Mtetra
.995 .862 .58 r
.52892 .57124 .52421 .5853 .5285 .57555 .53323 .56604 Mtetra
.963 .835 .412 r
.52464 .58309 .51992 .60366 .52421 .5853 .52892 .57124 Mtetra
.82 .744 .222 r
.52036 .60376 .5156 .63048 .51992 .60366 .52464 .58309 Mtetra
0 0 0 r
.51602 .63119 .51113 .657 .5156 .63048 .52036 .60376 Mtetra
0 0 .187 r
.51152 .65381 .50648 .66567 .51113 .657 .51602 .63119 Mtetra
.719 .254 .144 r
.50684 .65486 .50177 .64724 .50648 .66567 .51152 .65381 Mtetra
0 0 .358 r
.50213 .63116 .49715 .61353 .50177 .64724 .50684 .65486 Mtetra
.024 0 .445 r
.49751 .59765 .49263 .58188 .49715 .61353 .50213 .63116 Mtetra
.185 .084 .499 r
.49298 .56928 .48817 .56008 .49263 .58188 .49751 .59765 Mtetra
.325 .217 .574 r
.4885 .55113 .48369 .54816 .48817 .56008 .49298 .56928 Mtetra
.525 .437 .698 r
.48398 .54238 .47915 .54402 .48369 .54816 .4885 .55113 Mtetra
.816 .806 .841 r
.47941 .54092 .47453 .54576 .47915 .54402 .48398 .54238 Mtetra
.852 .982 .692 r
.47474 .54475 .46982 .55151 .47453 .54576 .47941 .54092 Mtetra
.612 .827 .431 r
.47 .55134 .46503 .5585 .46982 .55151 .47474 .54475 Mtetra
0 0 0 r
.46521 .55692 .46024 .5627 .46503 .5585 .47 .55134 Mtetra
.694 .956 .95 r
.46048 .55718 .45556 .56023 .46024 .5627 .46521 .55692 Mtetra
.448 .438 .755 r
.45589 .54968 .45104 .55004 .45556 .56023 .46048 .55718 Mtetra
.374 .278 .616 r
.45146 .5357 .44668 .53465 .45104 .55004 .45589 .54968 Mtetra
.381 .256 .583 r
.44714 .51896 .4424 .51797 .44668 .53465 .45146 .5357 Mtetra
.412 .28 .589 r
.44285 .50294 .43812 .50281 .4424 .51797 .44714 .51896 Mtetra
.456 .326 .615 r
.43853 .48936 .4338 .49029 .43812 .50281 .44285 .50294 Mtetra
.507 .386 .65 r
.43416 .47844 .42942 .4803 .4338 .49029 .43853 .48936 Mtetra
.557 .449 .687 r
.42974 .46974 .42498 .4723 .42942 .4803 .43416 .47844 Mtetra
.601 .507 .719 r
.42526 .46265 .4205 .46569 .42498 .4723 .42974 .46974 Mtetra
.635 .552 .744 r
.42075 .45665 .41598 .45999 .4205 .46569 .42526 .46265 Mtetra
.658 .585 .762 r
.41622 .45135 .41144 .45488 .41598 .45999 .42075 .45665 Mtetra
.674 .607 .772 r
.41166 .44648 .40687 .45014 .41144 .45488 .41622 .45135 Mtetra
.685 .621 .779 r
.40708 .44188 .40229 .44563 .40687 .45014 .41166 .44648 Mtetra
.691 .631 .783 r
.40249 .43745 .3977 .44125 .40229 .44563 .40708 .44188 Mtetra
.695 .637 .787 r
.39788 .43312 .39309 .43695 .3977 .44125 .40249 .43745 Mtetra
.697 .64 .788 r
.39327 .42884 .38848 .43269 .39309 .43695 .39788 .43312 Mtetra
.699 .642 .79 r
.38865 .4246 .38386 .42847 .38848 .43269 .39327 .42884 Mtetra
.7 .644 .79 r
.38402 .42037 .37922 .42426 .38386 .42847 .38865 .4246 Mtetra
.701 .644 .79 r
.37938 .41615 .37458 .42005 .37922 .42426 .38402 .42037 Mtetra
.701 .645 .79 r
.37473 .41193 .36994 .41584 .37458 .42005 .37938 .41615 Mtetra
.701 .645 .791 r
.37007 .40772 .36528 .41163 .36994 .41584 .37473 .41193 Mtetra
.701 .646 .791 r
.36541 .4035 .36062 .40741 .36528 .41163 .37007 .40772 Mtetra
.36074 .39927 .35595 .40319 .36062 .40741 .36541 .4035 Mtetra
.701 .645 .791 r
.35606 .39504 .35127 .39897 .35595 .40319 .36074 .39927 Mtetra
.702 .646 .79 r
.35138 .3908 .34658 .39474 .35127 .39897 .35606 .39504 Mtetra
.701 .646 .791 r
.34668 .38655 .34189 .3905 .34658 .39474 .35138 .3908 Mtetra
.34198 .3823 .33718 .38625 .34189 .3905 .34668 .38655 Mtetra
.33727 .37805 .33248 .382 .33718 .38625 .34198 .3823 Mtetra
.33255 .37378 .32776 .37774 .33248 .382 .33727 .37805 Mtetra
.702 .646 .791 r
.32783 .3695 .32303 .37348 .32776 .37774 .33255 .37378 Mtetra
.3231 .36523 .3183 .36921 .32303 .37348 .32783 .3695 Mtetra
.701 .646 .791 r
.31836 .36094 .31356 .36493 .3183 .36921 .3231 .36523 Mtetra
.31361 .35665 .30881 .36064 .31356 .36493 .31836 .36094 Mtetra
.30885 .35235 .30406 .35635 .30881 .36064 .31361 .35665 Mtetra
.30409 .34804 .29929 .35205 .30406 .35635 .30885 .35235 Mtetra
.702 .646 .791 r
.29932 .34373 .29452 .34774 .29929 .35205 .30409 .34804 Mtetra
.701 .646 .791 r
.29454 .3394 .28974 .34342 .29452 .34774 .29932 .34373 Mtetra
.28975 .33508 .28496 .3391 .28974 .34342 .29454 .3394 Mtetra
.28496 .33074 .28016 .33477 .28496 .3391 .28975 .33508 Mtetra
.28016 .3264 .27536 .33044 .28016 .33477 .28496 .33074 Mtetra
.701 .645 .791 r
.27535 .32205 .27055 .3261 .27536 .33044 .28016 .3264 Mtetra
.702 .646 .791 r
.27053 .31769 .26573 .32175 .27055 .3261 .27535 .32205 Mtetra
.701 .646 .791 r
.2657 .31333 .2609 .31739 .26573 .32175 .27053 .31769 Mtetra
.26087 .30896 .25607 .31302 .2609 .31739 .2657 .31333 Mtetra
.25602 .30458 .25122 .30865 .25607 .31302 .26087 .30896 Mtetra
.25117 .30019 .24637 .30427 .25122 .30865 .25602 .30458 Mtetra
.702 .646 .791 r
.24632 .2958 .24151 .29989 .24637 .30427 .25117 .30019 Mtetra
.24145 .2914 .23665 .29549 .24151 .29989 .24632 .2958 Mtetra
.701 .646 .791 r
.23658 .28699 .23177 .29109 .23665 .29549 .24145 .2914 Mtetra
.23169 .28258 .22689 .28668 .23177 .29109 .23658 .28699 Mtetra
.2268 .27815 .222 .28226 .22689 .28668 .23169 .28258 Mtetra
.2219 .27372 .2171 .27784 .222 .28226 .2268 .27815 Mtetra
.702 .646 .791 r
.217 .26929 .21219 .27342 .2171 .27784 .2219 .27372 Mtetra
.701 .646 .791 r
.21208 .26484 .20728 .26897 .21219 .27342 .217 .26929 Mtetra
.66255 .66432 .65778 .66786 .66198 .67166 .66675 .66813 Mtetra
.65834 .66051 .65357 .66406 .65778 .66786 .66255 .66432 Mtetra
.65413 .65669 .64936 .66024 .65357 .66406 .65834 .66051 Mtetra
.64991 .65287 .64514 .65643 .64936 .66024 .65413 .65669 Mtetra
.64568 .64904 .64091 .6526 .64514 .65643 .64991 .65287 Mtetra
.64145 .64521 .63668 .64878 .64091 .6526 .64568 .64904 Mtetra
.63721 .64137 .63244 .64494 .63668 .64878 .64145 .64521 Mtetra
.63296 .63752 .62819 .6411 .63244 .64494 .63721 .64137 Mtetra
.62871 .63367 .62394 .63725 .62819 .6411 .63296 .63752 Mtetra
.62445 .62981 .61967 .6334 .62394 .63725 .62871 .63367 Mtetra
.62018 .62595 .61541 .62954 .61967 .6334 .62445 .62981 Mtetra
.61591 .62208 .61113 .62568 .61541 .62954 .62018 .62595 Mtetra
.61163 .6182 .60685 .62181 .61113 .62568 .61591 .62208 Mtetra
.60734 .61432 .60257 .61793 .60685 .62181 .61163 .6182 Mtetra
.60305 .61044 .59827 .61405 .60257 .61793 .60734 .61432 Mtetra
.59875 .60654 .59397 .61017 .59827 .61405 .60305 .61044 Mtetra
.702 .646 .791 r
.59444 .60264 .58967 .60627 .59397 .61017 .59875 .60654 Mtetra
.59013 .59874 .58535 .60238 .58967 .60627 .59444 .60264 Mtetra
.58581 .59483 .58103 .59848 .58535 .60238 .59013 .59874 Mtetra
.58149 .59093 .57671 .59458 .58103 .59848 .58581 .59483 Mtetra
.702 .647 .791 r
.57715 .58702 .57237 .59068 .57671 .59458 .58149 .59093 Mtetra
.703 .647 .791 r
.57281 .58311 .56803 .58679 .57237 .59068 .57715 .58702 Mtetra
.704 .648 .791 r
.56847 .57923 .56369 .58293 .56803 .58679 .57281 .58311 Mtetra
.707 .651 .791 r
.56412 .57537 .55934 .57912 .56369 .58293 .56847 .57923 Mtetra
.711 .655 .792 r
.55976 .57158 .55498 .5754 .55934 .57912 .56412 .57537 Mtetra
.72 .662 .792 r
.5554 .56791 .55062 .57187 .55498 .5754 .55976 .57158 Mtetra
.736 .675 .791 r
.55104 .56447 .54626 .5687 .55062 .57187 .5554 .56791 Mtetra
.764 .698 .789 r
.54667 .56147 .54191 .56619 .54626 .5687 .55104 .56447 Mtetra
.814 .737 .779 r
.54232 .55929 .53756 .56495 .54191 .56619 .54667 .56147 Mtetra
.888 .793 .749 r
.53797 .55864 .53323 .56604 .53756 .56495 .54232 .55929 Mtetra
.967 .849 .673 r
.53365 .56073 .52892 .57124 .53323 .56604 .53797 .55864 Mtetra
.995 .864 .534 r
.52935 .56754 .52464 .58309 .52892 .57124 .53365 .56073 Mtetra
.93 .816 .357 r
.52509 .58161 .52036 .60376 .52464 .58309 .52935 .56754 Mtetra
.747 .701 .162 r
.52081 .60429 .51602 .63119 .52036 .60376 .52509 .58161 Mtetra
0 0 .049 r
.51645 .63116 .51152 .65381 .51602 .63119 .52081 .60429 Mtetra
.141 0 .199 r
.5119 .6484 .50684 .65486 .51152 .65381 .51645 .63116 Mtetra
.81 .349 0 r
.50719 .64191 .50213 .63116 .50684 .65486 .5119 .6484 Mtetra
0 0 .408 r
.50248 .61463 .49751 .59765 .50213 .63116 .50719 .64191 Mtetra
.082 .009 .465 r
.49786 .5827 .49298 .56928 .49751 .59765 .50248 .61463 Mtetra
.226 .123 .522 r
.49333 .55803 .4885 .55113 .49298 .56928 .49786 .5827 Mtetra
.382 .28 .613 r
.48882 .54355 .48398 .54238 .4885 .55113 .49333 .55803 Mtetra
.63 .567 .765 r
.48427 .53794 .47941 .54092 .48398 .54238 .48882 .54355 Mtetra
.892 .954 .836 r
.47965 .53905 .47474 .54475 .47941 .54092 .48427 .53794 Mtetra
.719 .909 .547 r
.47495 .54441 .47 .55134 .47474 .54475 .47965 .53905 Mtetra
0 0 0 r
.47018 .55062 .46521 .55692 .47 .55134 .47495 .54441 Mtetra
.619 .944 .745 r
.46543 .5532 .46048 .55718 .46521 .55692 .47018 .55062 Mtetra
.518 .588 .864 r
.46077 .54857 .45589 .54968 .46048 .55718 .46543 .5532 Mtetra
.379 .305 .647 r
.45627 .53651 .45146 .5357 .45589 .54968 .46077 .54857 Mtetra
.369 .253 .588 r
.45191 .52021 .44714 .51896 .45146 .5357 .45627 .53651 Mtetra
.395 .265 .583 r
.44759 .50353 .44285 .50294 .44714 .51896 .45191 .52021 Mtetra
.437 .305 .602 r
.44328 .48885 .43853 .48936 .44285 .50294 .44759 .50353 Mtetra
.487 .361 .635 r
.43891 .4769 .43416 .47844 .43853 .48936 .44328 .48885 Mtetra
.538 .425 .673 r
.4345 .46741 .42974 .46974 .43416 .47844 .43891 .4769 Mtetra
.585 .486 .708 r
.43004 .45978 .42526 .46265 .42974 .46974 .4345 .46741 Mtetra
.623 .536 .736 r
.42553 .45341 .42075 .45665 .42526 .46265 .43004 .45978 Mtetra
.651 .574 .755 r
.421 .44786 .41622 .45135 .42075 .45665 .42553 .45341 Mtetra
.67 .6 .768 r
.41645 .44284 .41166 .44648 .41622 .45135 .421 .44786 Mtetra
.681 .617 .777 r
.41187 .43815 .40708 .44188 .41166 .44648 .41645 .44284 Mtetra
.689 .628 .783 r
.40728 .43366 .40249 .43745 .40708 .44188 .41187 .43815 Mtetra
.694 .635 .786 r
.40268 .42929 .39788 .43312 .40249 .43745 .40728 .43366 Mtetra
.697 .639 .788 r
.39807 .42498 .39327 .42884 .39788 .43312 .40268 .42929 Mtetra
.699 .642 .789 r
.39344 .42072 .38865 .4246 .39327 .42884 .39807 .42498 Mtetra
.7 .643 .789 r
.38881 .41648 .38402 .42037 .38865 .4246 .39344 .42072 Mtetra
.7 .644 .79 r
.38418 .41225 .37938 .41615 .38402 .42037 .38881 .41648 Mtetra
.701 .645 .791 r
.37953 .40803 .37473 .41193 .37938 .41615 .38418 .41225 Mtetra
.37487 .4038 .37007 .40772 .37473 .41193 .37953 .40803 Mtetra
.37021 .39957 .36541 .4035 .37007 .40772 .37487 .4038 Mtetra
.701 .645 .79 r
.36554 .39533 .36074 .39927 .36541 .4035 .37021 .39957 Mtetra
.701 .646 .791 r
.36086 .39109 .35606 .39504 .36074 .39927 .36554 .39533 Mtetra
.35618 .38685 .35138 .3908 .35606 .39504 .36086 .39109 Mtetra
.35148 .3826 .34668 .38655 .35138 .3908 .35618 .38685 Mtetra
.34678 .37834 .34198 .3823 .34668 .38655 .35148 .3826 Mtetra
.702 .646 .791 r
.34207 .37408 .33727 .37805 .34198 .3823 .34678 .37834 Mtetra
.33736 .3698 .33255 .37378 .33727 .37805 .34207 .37408 Mtetra
.701 .646 .791 r
.33263 .36553 .32783 .3695 .33255 .37378 .33736 .3698 Mtetra
.3279 .36124 .3231 .36523 .32783 .3695 .33263 .36553 Mtetra
.32316 .35695 .31836 .36094 .3231 .36523 .3279 .36124 Mtetra
.31841 .35265 .31361 .35665 .31836 .36094 .32316 .35695 Mtetra
.702 .646 .791 r
.31366 .34834 .30885 .35235 .31361 .35665 .31841 .35265 Mtetra
.701 .646 .791 r
.3089 .34403 .30409 .34804 .30885 .35235 .31366 .34834 Mtetra
.30413 .33971 .29932 .34373 .30409 .34804 .3089 .34403 Mtetra
.29935 .33538 .29454 .3394 .29932 .34373 .30413 .33971 Mtetra
.29456 .33105 .28975 .33508 .29454 .3394 .29935 .33538 Mtetra
.28977 .3267 .28496 .33074 .28975 .33508 .29456 .33105 Mtetra
.702 .646 .791 r
.28496 .32235 .28016 .3264 .28496 .33074 .28977 .3267 Mtetra
.701 .646 .791 r
.28015 .318 .27535 .32205 .28016 .3264 .28496 .32235 Mtetra
.27534 .31363 .27053 .31769 .27535 .32205 .28015 .318 Mtetra
.27051 .30926 .2657 .31333 .27053 .31769 .27534 .31363 Mtetra
.26568 .30489 .26087 .30896 .2657 .31333 .27051 .30926 Mtetra
.702 .646 .791 r
.26083 .3005 .25602 .30458 .26087 .30896 .26568 .30489 Mtetra
.701 .646 .791 r
.25598 .29611 .25117 .30019 .25602 .30458 .26083 .3005 Mtetra
.25113 .29171 .24632 .2958 .25117 .30019 .25598 .29611 Mtetra
.24626 .2873 .24145 .2914 .24632 .2958 .25113 .29171 Mtetra
.24138 .28289 .23658 .28699 .24145 .2914 .24626 .2873 Mtetra
.2365 .27846 .23169 .28258 .23658 .28699 .24138 .28289 Mtetra
.702 .646 .791 r
.23161 .27403 .2268 .27815 .23169 .28258 .2365 .27846 Mtetra
.701 .646 .791 r
.22671 .2696 .2219 .27372 .2268 .27815 .23161 .27403 Mtetra
.22181 .26515 .217 .26929 .2219 .27372 .22671 .2696 Mtetra
.21689 .2607 .21208 .26484 .217 .26929 .22181 .26515 Mtetra
.66732 .66078 .66255 .66432 .66675 .66813 .67152 .66459 Mtetra
.66311 .65696 .65834 .66051 .66255 .66432 .66732 .66078 Mtetra
.6589 .65314 .65413 .65669 .65834 .66051 .66311 .65696 Mtetra
.65468 .64931 .64991 .65287 .65413 .65669 .6589 .65314 Mtetra
.65046 .64548 .64568 .64904 .64991 .65287 .65468 .64931 Mtetra
.702 .646 .791 r
.64622 .64164 .64145 .64521 .64568 .64904 .65046 .64548 Mtetra
.701 .646 .791 r
.64198 .63779 .63721 .64137 .64145 .64521 .64622 .64164 Mtetra
.63774 .63394 .63296 .63752 .63721 .64137 .64198 .63779 Mtetra
.63349 .63008 .62871 .63367 .63296 .63752 .63774 .63394 Mtetra
.62923 .62622 .62445 .62981 .62871 .63367 .63349 .63008 Mtetra
.62496 .62235 .62018 .62595 .62445 .62981 .62923 .62622 Mtetra
.62069 .61848 .61591 .62208 .62018 .62595 .62496 .62235 Mtetra
.61641 .6146 .61163 .6182 .61591 .62208 .62069 .61848 Mtetra
.61212 .61071 .60734 .61432 .61163 .6182 .61641 .6146 Mtetra
.60783 .60681 .60305 .61044 .60734 .61432 .61212 .61071 Mtetra
.702 .646 .791 r
.60353 .60292 .59875 .60654 .60305 .61044 .60783 .60681 Mtetra
.59923 .59901 .59444 .60264 .59875 .60654 .60353 .60292 Mtetra
.59491 .5951 .59013 .59874 .59444 .60264 .59923 .59901 Mtetra
.5906 .59119 .58581 .59483 .59013 .59874 .59491 .5951 Mtetra
.58627 .58727 .58149 .59093 .58581 .59483 .5906 .59119 Mtetra
.58194 .58335 .57715 .58702 .58149 .59093 .58627 .58727 Mtetra
.703 .647 .791 r
.5776 .57944 .57281 .58311 .57715 .58702 .58194 .58335 Mtetra
.704 .648 .791 r
.57325 .57553 .56847 .57923 .57281 .58311 .5776 .57944 Mtetra
.705 .649 .791 r
.5689 .57165 .56412 .57537 .56847 .57923 .57325 .57553 Mtetra
.708 .652 .792 r
.56455 .5678 .55976 .57158 .56412 .57537 .5689 .57165 Mtetra
.714 .657 .792 r
.56018 .56404 .5554 .56791 .55976 .57158 .56455 .5678 Mtetra
.724 .666 .792 r
.55582 .56044 .55104 .56447 .5554 .56791 .56018 .56404 Mtetra
.744 .682 .792 r
.55145 .55712 .54667 .56147 .55104 .56447 .55582 .56044 Mtetra
.778 .71 .788 r
.54709 .55435 .54232 .55929 .54667 .56147 .55145 .55712 Mtetra
.835 .756 .775 r
.54273 .55258 .53797 .55864 .54232 .55929 .54709 .55435 Mtetra
.915 .817 .735 r
.53839 .55263 .53365 .56073 .53797 .55864 .54273 .55258 Mtetra
.984 .865 .64 r
.53408 .55591 .52935 .56754 .53365 .56073 .53839 .55263 Mtetra
.983 .859 .483 r
.5298 .56454 .52509 .58161 .52935 .56754 .53408 .55591 Mtetra
.886 .791 .301 r
.52554 .58083 .52081 .60429 .52509 .58161 .5298 .56454 Mtetra
0 0 0 r
.52127 .60488 .51645 .63116 .52081 .60429 .52554 .58083 Mtetra
0 0 .091 r
.51687 .62977 .5119 .6484 .51645 .63116 .52127 .60488 Mtetra
.311 0 .181 r
.51228 .64059 .50719 .64191 .5119 .6484 .51687 .62977 Mtetra
0 0 .312 r
.50754 .62741 .50248 .61463 .50719 .64191 .51228 .64059 Mtetra
0 0 .439 r
.50282 .59824 .49786 .5827 .50248 .61463 .50754 .62741 Mtetra
.137 .051 .486 r
.49821 .56887 .49333 .55803 .49786 .5827 .50282 .59824 Mtetra
.275 .171 .551 r
.49367 .54817 .48882 .54355 .49333 .55803 .49821 .56887 Mtetra
.459 .368 .666 r
.48913 .53741 .48427 .53794 .48882 .54355 .49367 .54817 Mtetra
.76 .743 .837 r
.48455 .53487 .47965 .53905 .48427 .53794 .48913 .53741 Mtetra
.843 .99 .727 r
.47989 .53818 .47495 .54441 .47965 .53905 .48455 .53487 Mtetra
.585 .828 .453 r
.47516 .54415 .47018 .55062 .47495 .54441 .47989 .53818 Mtetra
.533 .851 .555 r
.4704 .54842 .46543 .5532 .47018 .55062 .47516 .54415 Mtetra
.608 .813 .979 r
.46569 .54661 .46077 .54857 .46543 .5532 .4704 .54842 Mtetra
.392 .355 .698 r
.46113 .53698 .45627 .53651 .46077 .54857 .46569 .54661 Mtetra
.359 .255 .599 r
.4567 .52163 .45191 .52021 .45627 .53651 .46113 .53698 Mtetra
.379 .252 .579 r
.45236 .50453 .44759 .50353 .45191 .52021 .4567 .52163 Mtetra
.417 .285 .592 r
.44803 .48881 .44328 .48885 .44759 .50353 .45236 .50453 Mtetra
.465 .336 .621 r
.44367 .47577 .43891 .4769 .44328 .48885 .44803 .48881 Mtetra
.517 .399 .658 r
.43927 .46537 .4345 .46741 .43891 .4769 .44367 .47577 Mtetra
.567 .463 .695 r
.43482 .45708 .43004 .45978 .4345 .46741 .43927 .46537 Mtetra
.61 .518 .725 r
.43032 .45027 .42553 .45341 .43004 .45978 .43482 .45708 Mtetra
.641 .561 .748 r
.42579 .44444 .421 .44786 .42553 .45341 .43032 .45027 Mtetra
.663 .591 .765 r
.42124 .43925 .41645 .44284 .421 .44786 .42579 .44444 Mtetra
.677 .611 .775 r
.41667 .43445 .41187 .43815 .41645 .44284 .42124 .43925 Mtetra
.686 .624 .781 r
.41208 .42988 .40728 .43366 .41187 .43815 .41667 .43445 Mtetra
.692 .632 .784 r
.40748 .42546 .40268 .42929 .40728 .43366 .41208 .42988 Mtetra
.696 .638 .787 r
.40287 .42112 .39807 .42498 .40268 .42929 .40748 .42546 Mtetra
.698 .641 .789 r
.39825 .41684 .39344 .42072 .39807 .42498 .40287 .42112 Mtetra
.699 .643 .79 r
.39362 .41259 .38881 .41648 .39344 .42072 .39825 .41684 Mtetra
.7 .644 .79 r
.38898 .40835 .38418 .41225 .38881 .41648 .39362 .41259 Mtetra
.701 .644 .79 r
.38434 .40411 .37953 .40803 .38418 .41225 .38898 .40835 Mtetra
.701 .645 .79 r
.37968 .39987 .37487 .4038 .37953 .40803 .38434 .40411 Mtetra
.37502 .39563 .37021 .39957 .37487 .4038 .37968 .39987 Mtetra
.701 .646 .791 r
.37035 .3914 .36554 .39533 .37021 .39957 .37502 .39563 Mtetra
.36567 .38715 .36086 .39109 .36554 .39533 .37035 .3914 Mtetra
.36099 .3829 .35618 .38685 .36086 .39109 .36567 .38715 Mtetra
.701 .645 .79 r
.35629 .37864 .35148 .3826 .35618 .38685 .36099 .3829 Mtetra
.702 .646 .791 r
.35159 .37438 .34678 .37834 .35148 .3826 .35629 .37864 Mtetra
.701 .646 .791 r
.34688 .3701 .34207 .37408 .34678 .37834 .35159 .37438 Mtetra
.34217 .36583 .33736 .3698 .34207 .37408 .34688 .3701 Mtetra
.33744 .36155 .33263 .36553 .33736 .3698 .34217 .36583 Mtetra
.33271 .35725 .3279 .36124 .33263 .36553 .33744 .36155 Mtetra
.701 .645 .791 r
.32797 .35295 .32316 .35695 .3279 .36124 .33271 .35725 Mtetra
.701 .646 .791 r
.32323 .34864 .31841 .35265 .32316 .35695 .32797 .35295 Mtetra
.31847 .34433 .31366 .34834 .31841 .35265 .32323 .34864 Mtetra
.31371 .34001 .3089 .34403 .31366 .34834 .31847 .34433 Mtetra
.30894 .33569 .30413 .33971 .3089 .34403 .31371 .34001 Mtetra
.701 .645 .791 r
.30416 .33135 .29935 .33538 .30413 .33971 .30894 .33569 Mtetra
.702 .646 .791 r
.29937 .32701 .29456 .33105 .29935 .33538 .30416 .33135 Mtetra
.29458 .32266 .28977 .3267 .29456 .33105 .29937 .32701 Mtetra
.701 .646 .791 r
.28978 .3183 .28496 .32235 .28977 .3267 .29458 .32266 Mtetra
.28497 .31394 .28015 .318 .28496 .32235 .28978 .3183 Mtetra
.28015 .30957 .27534 .31363 .28015 .318 .28497 .31394 Mtetra
.27532 .30519 .27051 .30926 .27534 .31363 .28015 .30957 Mtetra
.702 .646 .791 r
.27049 .30081 .26568 .30489 .27051 .30926 .27532 .30519 Mtetra
.701 .646 .791 r
.26565 .29641 .26083 .3005 .26568 .30489 .27049 .30081 Mtetra
.2608 .29202 .25598 .29611 .26083 .3005 .26565 .29641 Mtetra
.25594 .28761 .25113 .29171 .25598 .29611 .2608 .29202 Mtetra
.25108 .28319 .24626 .2873 .25113 .29171 .25594 .28761 Mtetra
.702 .646 .791 r
.2462 .27877 .24138 .28289 .24626 .2873 .25108 .28319 Mtetra
.701 .646 .791 r
.24132 .27434 .2365 .27846 .24138 .28289 .2462 .27877 Mtetra
.23643 .26991 .23161 .27403 .2365 .27846 .24132 .27434 Mtetra
.23153 .26546 .22671 .2696 .23161 .27403 .23643 .26991 Mtetra
.22662 .26101 .22181 .26515 .22671 .2696 .23153 .26546 Mtetra
.22171 .25656 .21689 .2607 .22181 .26515 .22662 .26101 Mtetra
.6721 .65723 .66732 .66078 .67152 .66459 .6763 .66104 Mtetra
.66789 .65341 .66311 .65696 .66732 .66078 .6721 .65723 Mtetra
.66368 .64958 .6589 .65314 .66311 .65696 .66789 .65341 Mtetra
.65946 .64575 .65468 .64931 .6589 .65314 .66368 .64958 Mtetra
.65524 .64191 .65046 .64548 .65468 .64931 .65946 .64575 Mtetra
.65101 .63806 .64622 .64164 .65046 .64548 .65524 .64191 Mtetra
.64677 .63421 .64198 .63779 .64622 .64164 .65101 .63806 Mtetra
.64252 .63036 .63774 .63394 .64198 .63779 .64677 .63421 Mtetra
.63827 .62649 .63349 .63008 .63774 .63394 .64252 .63036 Mtetra
.63401 .62262 .62923 .62622 .63349 .63008 .63827 .62649 Mtetra
.62975 .61875 .62496 .62235 .62923 .62622 .63401 .62262 Mtetra
.62548 .61487 .62069 .61848 .62496 .62235 .62975 .61875 Mtetra
.6212 .61098 .61641 .6146 .62069 .61848 .62548 .61487 Mtetra
.61691 .60709 .61212 .61071 .61641 .6146 .6212 .61098 Mtetra
.61262 .60319 .60783 .60681 .61212 .61071 .61691 .60709 Mtetra
.60832 .59928 .60353 .60292 .60783 .60681 .61262 .60319 Mtetra
.60402 .59537 .59923 .59901 .60353 .60292 .60832 .59928 Mtetra
.702 .646 .791 r
.59971 .59146 .59491 .5951 .59923 .59901 .60402 .59537 Mtetra
.59539 .58754 .5906 .59119 .59491 .5951 .59971 .59146 Mtetra
.59106 .58361 .58627 .58727 .5906 .59119 .59539 .58754 Mtetra
.58673 .57969 .58194 .58335 .58627 .58727 .59106 .58361 Mtetra
.702 .647 .791 r
.58239 .57576 .5776 .57944 .58194 .58335 .58673 .57969 Mtetra
.703 .647 .791 r
.57805 .57184 .57325 .57553 .5776 .57944 .58239 .57576 Mtetra
.704 .648 .791 r
.5737 .56793 .5689 .57165 .57325 .57553 .57805 .57184 Mtetra
.706 .65 .792 r
.56934 .56405 .56455 .5678 .5689 .57165 .5737 .56793 Mtetra
.71 .654 .792 r
.56498 .56023 .56018 .56404 .56455 .5678 .56934 .56405 Mtetra
.717 .66 .792 r
.56061 .55652 .55582 .56044 .56018 .56404 .56498 .56023 Mtetra
.73 .671 .793 r
.55624 .553 .55145 .55712 .55582 .56044 .56061 .55652 Mtetra
.754 .691 .792 r
.55187 .54984 .54709 .55435 .55145 .55712 .55624 .553 Mtetra
.795 .726 .787 r
.54751 .54735 .54273 .55258 .54709 .55435 .55187 .54984 Mtetra
.86 .778 .769 r
.54315 .54608 .53839 .55263 .54273 .55258 .54751 .54735 Mtetra
.942 .841 .715 r
.53882 .54699 .53408 .55591 .53839 .55263 .54315 .54608 Mtetra
.993 .876 .598 r
.53452 .55167 .5298 .56454 .53408 .55591 .53882 .54699 Mtetra
.958 .846 .425 r
.53026 .56231 .52554 .58083 .5298 .56454 .53452 .55167 Mtetra
.821 .754 .237 r
.52602 .58076 .52127 .60488 .52554 .58083 .53026 .56231 Mtetra
0 0 0 r
.52173 .60535 .51687 .62977 .52127 .60488 .52602 .58076 Mtetra
0 0 .11 r
.51729 .62654 .51228 .64059 .51687 .62977 .52173 .60535 Mtetra
.503 .022 .048 r
.51264 .63004 .50754 .62741 .51228 .64059 .51729 .62654 Mtetra
0 0 .416 r
.50788 .61155 .50282 .59824 .50754 .62741 .51264 .63004 Mtetra
.027 0 .461 r
.50317 .58246 .49821 .56887 .50282 .59824 .50788 .61155 Mtetra
.184 .091 .509 r
.49856 .55653 .49367 .54817 .49821 .56887 .50317 .58246 Mtetra
.331 .231 .588 r
.494 .53992 .48913 .53741 .49367 .54817 .49856 .55653 Mtetra
.562 .494 .737 r
.48943 .53278 .48455 .53487 .48913 .53741 .494 .53992 Mtetra
.864 .929 .867 r
.48482 .53308 .47989 .53818 .48455 .53487 .48943 .53278 Mtetra
.693 .913 .574 r
.48012 .53789 .47516 .54415 .47989 .53818 .48482 .53308 Mtetra
0 0 0 r
.47538 .54307 .4704 .54842 .47516 .54415 .48012 .53789 Mtetra
.611 .952 .915 r
.47065 .54381 .46569 .54661 .4704 .54842 .47538 .54307 Mtetra
.421 .447 .782 r
.46602 .53692 .46113 .53698 .46569 .54661 .47065 .54381 Mtetra
.351 .266 .618 r
.46152 .52308 .4567 .52163 .46113 .53698 .46602 .53692 Mtetra
.363 .242 .579 r
.45714 .50596 .45236 .50453 .4567 .52163 .46152 .52308 Mtetra
.397 .265 .583 r
.4528 .48931 .44803 .48881 .45236 .50453 .45714 .50596 Mtetra
.443 .312 .607 r
.44844 .47509 .44367 .47577 .44803 .48881 .4528 .48931 Mtetra
.495 .373 .642 r
.44404 .46366 .43927 .46537 .44367 .47577 .44844 .47509 Mtetra
.548 .438 .68 r
.4396 .4546 .43482 .45708 .43927 .46537 .44404 .46366 Mtetra
.594 .498 .715 r
.43511 .44728 .43032 .45027 .43482 .45708 .4396 .4546 Mtetra
.63 .546 .741 r
.43059 .44112 .42579 .44444 .43032 .45027 .43511 .44728 Mtetra
.655 .581 .759 r
.42604 .43571 .42124 .43925 .42579 .44444 .43059 .44112 Mtetra
.673 .604 .771 r
.42148 .43076 .41667 .43445 .42124 .43925 .42604 .43571 Mtetra
.684 .62 .778 r
.41689 .42611 .41208 .42988 .41667 .43445 .42148 .43076 Mtetra
.69 .63 .784 r
.41229 .42164 .40748 .42546 .41208 .42988 .41689 .42611 Mtetra
.694 .636 .787 r
.40768 .41728 .40287 .42112 .40748 .42546 .41229 .42164 Mtetra
.697 .64 .788 r
.40306 .41296 .39825 .41684 .40287 .42112 .40768 .41728 Mtetra
.699 .642 .789 r
.39843 .40869 .39362 .41259 .39825 .41684 .40306 .41296 Mtetra
.7 .643 .79 r
.3938 .40443 .38898 .40835 .39362 .41259 .39843 .40869 Mtetra
.701 .645 .79 r
.38915 .40019 .38434 .40411 .38898 .40835 .3938 .40443 Mtetra
.701 .645 .791 r
.3845 .39595 .37968 .39987 .38434 .40411 .38915 .40019 Mtetra
.37983 .3917 .37502 .39563 .37968 .39987 .3845 .39595 Mtetra
.37517 .38745 .37035 .3914 .37502 .39563 .37983 .3917 Mtetra
.701 .646 .791 r
.37049 .3832 .36567 .38715 .37035 .3914 .37517 .38745 Mtetra
.702 .646 .791 r
.3658 .37894 .36099 .3829 .36567 .38715 .37049 .3832 Mtetra
.701 .646 .791 r
.36111 .37467 .35629 .37864 .36099 .3829 .3658 .37894 Mtetra
.35641 .3704 .35159 .37438 .35629 .37864 .36111 .37467 Mtetra
.3517 .36613 .34688 .3701 .35159 .37438 .35641 .3704 Mtetra
.34699 .36184 .34217 .36583 .34688 .3701 .3517 .36613 Mtetra
.702 .646 .791 r
.34226 .35755 .33744 .36155 .34217 .36583 .34699 .36184 Mtetra
.33753 .35325 .33271 .35725 .33744 .36155 .34226 .35755 Mtetra
.701 .646 .791 r
.33279 .34895 .32797 .35295 .33271 .35725 .33753 .35325 Mtetra
.32805 .34463 .32323 .34864 .32797 .35295 .33279 .34895 Mtetra
.32329 .34031 .31847 .34433 .32323 .34864 .32805 .34463 Mtetra
.702 .646 .791 r
.31853 .33599 .31371 .34001 .31847 .34433 .32329 .34031 Mtetra
.31376 .33165 .30894 .33569 .31371 .34001 .31853 .33599 Mtetra
.701 .646 .791 r
.30898 .32731 .30416 .33135 .30894 .33569 .31376 .33165 Mtetra
.3042 .32296 .29937 .32701 .30416 .33135 .30898 .32731 Mtetra
.2994 .31861 .29458 .32266 .29937 .32701 .3042 .32296 Mtetra
.2946 .31425 .28978 .3183 .29458 .32266 .2994 .31861 Mtetra
.702 .646 .791 r
.28979 .30988 .28497 .31394 .28978 .3183 .2946 .31425 Mtetra
.701 .646 .791 r
.28497 .3055 .28015 .30957 .28497 .31394 .28979 .30988 Mtetra
.28015 .30111 .27532 .30519 .28015 .30957 .28497 .3055 Mtetra
.27531 .29672 .27049 .30081 .27532 .30519 .28015 .30111 Mtetra
.27047 .29232 .26565 .29641 .27049 .30081 .27531 .29672 Mtetra
.26562 .28792 .2608 .29202 .26565 .29641 .27047 .29232 Mtetra
.26077 .2835 .25594 .28761 .2608 .29202 .26562 .28792 Mtetra
.2559 .27908 .25108 .28319 .25594 .28761 .26077 .2835 Mtetra
.25103 .27465 .2462 .27877 .25108 .28319 .2559 .27908 Mtetra
.24614 .27022 .24132 .27434 .2462 .27877 .25103 .27465 Mtetra
.24125 .26578 .23643 .26991 .24132 .27434 .24614 .27022 Mtetra
.23636 .26133 .23153 .26546 .23643 .26991 .24125 .26578 Mtetra
.23145 .25687 .22662 .26101 .23153 .26546 .23636 .26133 Mtetra
.22653 .2524 .22171 .25656 .22662 .26101 .23145 .25687 Mtetra
.67689 .65368 .6721 .65723 .6763 .66104 .68109 .6575 Mtetra
.67268 .64985 .66789 .65341 .6721 .65723 .67689 .65368 Mtetra
.66847 .64602 .66368 .64958 .66789 .65341 .67268 .64985 Mtetra
.66425 .64218 .65946 .64575 .66368 .64958 .66847 .64602 Mtetra
.66003 .63833 .65524 .64191 .65946 .64575 .66425 .64218 Mtetra
.6558 .63448 .65101 .63806 .65524 .64191 .66003 .63833 Mtetra
.65156 .63063 .64677 .63421 .65101 .63806 .6558 .63448 Mtetra
.64731 .62676 .64252 .63036 .64677 .63421 .65156 .63063 Mtetra
.64306 .62289 .63827 .62649 .64252 .63036 .64731 .62676 Mtetra
.6388 .61902 .63401 .62262 .63827 .62649 .64306 .62289 Mtetra
.63454 .61514 .62975 .61875 .63401 .62262 .6388 .61902 Mtetra
.63027 .61125 .62548 .61487 .62975 .61875 .63454 .61514 Mtetra
.62599 .60736 .6212 .61098 .62548 .61487 .63027 .61125 Mtetra
.62171 .60346 .61691 .60709 .6212 .61098 .62599 .60736 Mtetra
.61742 .59956 .61262 .60319 .61691 .60709 .62171 .60346 Mtetra
.61312 .59565 .60832 .59928 .61262 .60319 .61742 .59956 Mtetra
.60881 .59173 .60402 .59537 .60832 .59928 .61312 .59565 Mtetra
.702 .646 .791 r
.6045 .58781 .59971 .59146 .60402 .59537 .60881 .59173 Mtetra
.60019 .58388 .59539 .58754 .59971 .59146 .6045 .58781 Mtetra
.59586 .57995 .59106 .58361 .59539 .58754 .60019 .58388 Mtetra
.59153 .57602 .58673 .57969 .59106 .58361 .59586 .57995 Mtetra
.58719 .57208 .58239 .57576 .58673 .57969 .59153 .57602 Mtetra
.703 .647 .791 r
.58285 .56815 .57805 .57184 .58239 .57576 .58719 .57208 Mtetra
.703 .648 .791 r
.5785 .56422 .5737 .56793 .57805 .57184 .58285 .56815 Mtetra
.705 .649 .792 r
.57414 .56032 .56934 .56405 .5737 .56793 .5785 .56422 Mtetra
.708 .652 .792 r
.56978 .55645 .56498 .56023 .56934 .56405 .57414 .56032 Mtetra
.712 .656 .793 r
.56541 .55266 .56061 .55652 .56498 .56023 .56978 .55645 Mtetra
.721 .664 .793 r
.56104 .54901 .55624 .553 .56061 .55652 .56541 .55266 Mtetra
.737 .679 .794 r
.55667 .5456 .55187 .54984 .55624 .553 .56104 .54901 Mtetra
.766 .703 .793 r
.5523 .54266 .54751 .54735 .55187 .54984 .55667 .5456 Mtetra
.815 .745 .786 r
.54793 .54053 .54315 .54608 .54751 .54735 .5523 .54266 Mtetra
.888 .805 .761 r
.54359 .53989 .53882 .54699 .54315 .54608 .54793 .54053 Mtetra
.965 .865 .689 r
.53926 .54185 .53452 .55167 .53882 .54699 .54359 .53989 Mtetra
.99 .879 .547 r
.53498 .54813 .53026 .56231 .53452 .55167 .53926 .54185 Mtetra
.922 .825 .367 r
.53073 .56083 .52602 .58076 .53026 .56231 .53498 .54813 Mtetra
.76 .718 .185 r
.52649 .58094 .52173 .60535 .52602 .58076 .53073 .56083 Mtetra
0 0 0 r
.52218 .60478 .51729 .62654 .52173 .60535 .52649 .58094 Mtetra
0 0 .113 r
.51768 .62104 .51264 .63004 .51729 .62654 .52218 .60478 Mtetra
.672 .132 0 r
.51299 .61757 .50788 .61155 .51264 .63004 .51768 .62104 Mtetra
0 0 .457 r
.50822 .59534 .50317 .58246 .50788 .61155 .51299 .61757 Mtetra
.105 .035 .486 r
.50352 .56759 .49856 .55653 .50317 .58246 .50822 .59534 Mtetra
.242 .144 .539 r
.4989 .54563 .494 .53992 .49856 .55653 .50352 .56759 Mtetra
.409 .318 .641 r
.49433 .53322 .48943 .53278 .494 .53992 .4989 .54563 Mtetra
.699 .679 .827 r
.48973 .52962 .48482 .53308 .48943 .53278 .49433 .53322 Mtetra
.826 .997 .772 r
.48508 .5323 .48012 .53789 .48482 .53308 .48973 .52962 Mtetra
.541 .826 .484 r
.48036 .53749 .47538 .54307 .48012 .53789 .48508 .5323 Mtetra
.506 .882 .682 r
.47562 .54024 .47065 .54381 .47538 .54307 .48036 .53749 Mtetra
.469 .613 .91 r
.47094 .53622 .46602 .53692 .47065 .54381 .47562 .54024 Mtetra
.343 .29 .652 r
.46638 .52444 .46152 .52308 .46602 .53692 .47094 .53622 Mtetra
.344 .235 .584 r
.46195 .5078 .45714 .50596 .46152 .52308 .46638 .52444 Mtetra
.376 .248 .576 r
.45758 .49037 .4528 .48931 .45714 .50596 .46195 .5078 Mtetra
.42 .288 .594 r
.45322 .47493 .44844 .47509 .4528 .48931 .45758 .49037 Mtetra
.472 .346 .627 r
.44882 .46235 .44404 .46366 .44844 .47509 .45322 .47493 Mtetra
.526 .411 .665 r
.44439 .45242 .4396 .4546 .44404 .46366 .44882 .46235 Mtetra
.576 .475 .702 r
.43991 .44447 .43511 .44728 .4396 .4546 .44439 .45242 Mtetra
.617 .528 .731 r
.4354 .4379 .43059 .44112 .43511 .44728 .43991 .44447 Mtetra
.647 .568 .752 r
.43085 .43222 .42604 .43571 .43059 .44112 .4354 .4379 Mtetra
.667 .596 .767 r
.42629 .42712 .42148 .43076 .42604 .43571 .43085 .43222 Mtetra
.68 .615 .777 r
.42171 .42237 .41689 .42611 .42148 .43076 .42629 .42712 Mtetra
.688 .627 .782 r
.41711 .41784 .41229 .42164 .41689 .42611 .42171 .42237 Mtetra
.693 .634 .785 r
.4125 .41342 .40768 .41728 .41229 .42164 .41711 .41784 Mtetra
.697 .638 .787 r
.40788 .40908 .40306 .41296 .40768 .41728 .4125 .41342 Mtetra
.699 .641 .789 r
.40325 .40478 .39843 .40869 .40306 .41296 .40788 .40908 Mtetra
.7 .643 .79 r
.39862 .40052 .3938 .40443 .39843 .40869 .40325 .40478 Mtetra
.7 .644 .79 r
.39397 .39627 .38915 .40019 .3938 .40443 .39862 .40052 Mtetra
.701 .645 .79 r
.38932 .39202 .3845 .39595 .38915 .40019 .39397 .39627 Mtetra
.38466 .38776 .37983 .3917 .3845 .39595 .38932 .39202 Mtetra
.37999 .3835 .37517 .38745 .37983 .3917 .38466 .38776 Mtetra
.702 .646 .791 r
.37531 .37924 .37049 .3832 .37517 .38745 .37999 .3835 Mtetra
.701 .646 .791 r
.37063 .37498 .3658 .37894 .37049 .3832 .37531 .37924 Mtetra
.36593 .37071 .36111 .37467 .3658 .37894 .37063 .37498 Mtetra
.701 .645 .791 r
.36123 .36643 .35641 .3704 .36111 .37467 .36593 .37071 Mtetra
.701 .646 .791 r
.35653 .36214 .3517 .36613 .35641 .3704 .36123 .36643 Mtetra
.702 .646 .791 r
.35181 .35785 .34699 .36184 .3517 .36613 .35653 .36214 Mtetra
.34709 .35355 .34226 .35755 .34699 .36184 .35181 .35785 Mtetra
.701 .646 .791 r
.34236 .34925 .33753 .35325 .34226 .35755 .34709 .35355 Mtetra
.33762 .34494 .33279 .34895 .33753 .35325 .34236 .34925 Mtetra
.33287 .34062 .32805 .34463 .33279 .34895 .33762 .34494 Mtetra
.702 .646 .791 r
.32812 .33629 .32329 .34031 .32805 .34463 .33287 .34062 Mtetra
.32336 .33196 .31853 .33599 .32329 .34031 .32812 .33629 Mtetra
.701 .646 .791 r
.31859 .32762 .31376 .33165 .31853 .33599 .32336 .33196 Mtetra
.31381 .32327 .30898 .32731 .31376 .33165 .31859 .32762 Mtetra
.30902 .31891 .3042 .32296 .30898 .32731 .31381 .32327 Mtetra
.30423 .31455 .2994 .31861 .3042 .32296 .30902 .31891 Mtetra
.702 .646 .791 r
.29943 .31018 .2946 .31425 .2994 .31861 .30423 .31455 Mtetra
.701 .646 .791 r
.29462 .30581 .28979 .30988 .2946 .31425 .29943 .31018 Mtetra
.2898 .30142 .28497 .3055 .28979 .30988 .29462 .30581 Mtetra
.28498 .29703 .28015 .30111 .28497 .3055 .2898 .30142 Mtetra
.28014 .29263 .27531 .29672 .28015 .30111 .28498 .29703 Mtetra
.2753 .28823 .27047 .29232 .27531 .29672 .28014 .29263 Mtetra
.27045 .28381 .26562 .28792 .27047 .29232 .2753 .28823 Mtetra
.2656 .27939 .26077 .2835 .26562 .28792 .27045 .28381 Mtetra
.26073 .27497 .2559 .27908 .26077 .2835 .2656 .27939 Mtetra
.25586 .27053 .25103 .27465 .2559 .27908 .26073 .27497 Mtetra
.25098 .26609 .24614 .27022 .25103 .27465 .25586 .27053 Mtetra
.24609 .26164 .24125 .26578 .24614 .27022 .25098 .26609 Mtetra
.24119 .25718 .23636 .26133 .24125 .26578 .24609 .26164 Mtetra
.23628 .25272 .23145 .25687 .23636 .26133 .24119 .25718 Mtetra
.23137 .24824 .22653 .2524 .23145 .25687 .23628 .25272 Mtetra
.68168 .65012 .67689 .65368 .68109 .6575 .68588 .65394 Mtetra
.67748 .64628 .67268 .64985 .67689 .65368 .68168 .65012 Mtetra
.67327 .64245 .66847 .64602 .67268 .64985 .67748 .64628 Mtetra
.66905 .6386 .66425 .64218 .66847 .64602 .67327 .64245 Mtetra
.66482 .63475 .66003 .63833 .66425 .64218 .66905 .6386 Mtetra
.66059 .6309 .6558 .63448 .66003 .63833 .66482 .63475 Mtetra
.65636 .62703 .65156 .63063 .6558 .63448 .66059 .6309 Mtetra
.65211 .62317 .64731 .62676 .65156 .63063 .65636 .62703 Mtetra
.64786 .61929 .64306 .62289 .64731 .62676 .65211 .62317 Mtetra
.6436 .61541 .6388 .61902 .64306 .62289 .64786 .61929 Mtetra
.63934 .61153 .63454 .61514 .6388 .61902 .6436 .61541 Mtetra
.63507 .60763 .63027 .61125 .63454 .61514 .63934 .61153 Mtetra
.63079 .60373 .62599 .60736 .63027 .61125 .63507 .60763 Mtetra
.62651 .59983 .62171 .60346 .62599 .60736 .63079 .60373 Mtetra
.62222 .59592 .61742 .59956 .62171 .60346 .62651 .59983 Mtetra
.61792 .592 .61312 .59565 .61742 .59956 .62222 .59592 Mtetra
.61362 .58808 .60881 .59173 .61312 .59565 .61792 .592 Mtetra
.60931 .58415 .6045 .58781 .60881 .59173 .61362 .58808 Mtetra
.702 .646 .791 r
.60499 .58022 .60019 .58388 .6045 .58781 .60931 .58415 Mtetra
.60067 .57628 .59586 .57995 .60019 .58388 .60499 .58022 Mtetra
.59634 .57234 .59153 .57602 .59586 .57995 .60067 .57628 Mtetra
.592 .5684 .58719 .57208 .59153 .57602 .59634 .57234 Mtetra
.702 .647 .791 r
.58766 .56445 .58285 .56815 .58719 .57208 .592 .5684 Mtetra
.703 .647 .791 r
.58331 .56052 .5785 .56422 .58285 .56815 .58766 .56445 Mtetra
.704 .648 .791 r
.57895 .55659 .57414 .56032 .5785 .56422 .58331 .56052 Mtetra
.706 .65 .792 r
.57459 .5527 .56978 .55645 .57414 .56032 .57895 .55659 Mtetra
.709 .654 .792 r
.57022 .54885 .56541 .55266 .56978 .55645 .57459 .5527 Mtetra
.716 .659 .793 r
.56585 .5451 .56104 .54901 .56541 .55266 .57022 .54885 Mtetra
.727 .67 .794 r
.56147 .54153 .55667 .5456 .56104 .54901 .56585 .5451 Mtetra
.747 .688 .795 r
.5571 .53828 .5523 .54266 .55667 .5456 .56147 .54153 Mtetra
.781 .719 .793 r
.55273 .53559 .54793 .54053 .5523 .54266 .5571 .53828 Mtetra
.839 .768 .783 r
.54837 .53393 .54359 .53989 .54793 .54053 .55273 .53559 Mtetra
.917 .833 .747 r
.54403 .53407 .53926 .54185 .54359 .53989 .54837 .53393 Mtetra
.983 .884 .651 r
.53972 .53727 .53498 .54813 .53926 .54185 .54403 .53407 Mtetra
.972 .873 .488 r
.53545 .54535 .53073 .56083 .53498 .54813 .53972 .53727 Mtetra
.863 .793 .3 r
.53122 .56015 .52649 .58094 .53073 .56083 .53545 .54535 Mtetra
0 0 0 r
.52698 .58138 .52218 .60478 .52649 .58094 .53122 .56015 Mtetra
0 0 .018 r
.52263 .60295 .51768 .62104 .52218 .60478 .52698 .58138 Mtetra
.021 0 .02 r
.51807 .61277 .51299 .61757 .51768 .62104 .52263 .60295 Mtetra
0 0 .53 r
.51333 .60288 .50822 .59534 .51299 .61757 .51807 .61277 Mtetra
.011 0 .483 r
.50856 .57908 .50352 .56759 .50822 .59534 .51333 .60288 Mtetra
.164 .082 .51 r
.50386 .55414 .4989 .54563 .50352 .56759 .50856 .57908 Mtetra
.302 .206 .577 r
.49925 .53652 .49433 .53322 .4989 .54563 .50386 .55414 Mtetra
.512 .443 .716 r
.49465 .52824 .48973 .52962 .49433 .53322 .49925 .53652 Mtetra
.826 .9 .892 r
.49003 .52783 .48508 .5323 .48973 .52962 .49465 .52824 Mtetra
.649 .911 .603 r
.48534 .53202 .48036 .53749 .48508 .5323 .49003 .52783 Mtetra
0 0 0 r
.48061 .53606 .47562 .54024 .48036 .53749 .48534 .53202 Mtetra
.498 .83 .999 r
.4759 .53481 .47094 .53622 .47562 .54024 .48061 .53606 Mtetra
.336 .336 .712 r
.47128 .52559 .46638 .52444 .47094 .53622 .4759 .53481 Mtetra
.323 .232 .594 r
.46679 .50997 .46195 .5078 .46638 .52444 .47128 .52559 Mtetra
.353 .231 .571 r
.46238 .49206 .45758 .49037 .46195 .5078 .46679 .50997 Mtetra
.396 .265 .582 r
.45801 .47539 .45322 .47493 .45758 .49037 .46238 .49206 Mtetra
.447 .318 .611 r
.45361 .46154 .44882 .46235 .45322 .47493 .45801 .47539 Mtetra
.503 .383 .649 r
.44918 .45057 .44439 .45242 .44882 .46235 .45361 .46154 Mtetra
.556 .449 .687 r
.44471 .44188 .43991 .44447 .44439 .45242 .44918 .45057 Mtetra
.602 .508 .72 r
.44021 .43482 .4354 .4379 .43991 .44447 .44471 .44188 Mtetra
.636 .554 .745 r
.43567 .42883 .43085 .43222 .4354 .4379 .44021 .43482 Mtetra
.66 .587 .762 r
.43111 .42353 .42629 .42712 .43085 .43222 .43567 .42883 Mtetra
.676 .609 .773 r
.42653 .41866 .42171 .42237 .42629 .42712 .43111 .42353 Mtetra
.686 .623 .78 r
.42193 .41404 .41711 .41784 .42171 .42237 .42653 .41866 Mtetra
.692 .631 .784 r
.41733 .40957 .4125 .41342 .41711 .41784 .42193 .41404 Mtetra
.695 .637 .787 r
.41271 .4052 .40788 .40908 .4125 .41342 .41733 .40957 Mtetra
.698 .64 .788 r
.40808 .40089 .40325 .40478 .40788 .40908 .41271 .4052 Mtetra
.699 .643 .79 r
.40345 .39661 .39862 .40052 .40325 .40478 .40808 .40089 Mtetra
.7 .644 .79 r
.3988 .39234 .39397 .39627 .39862 .40052 .40345 .39661 Mtetra
.701 .644 .79 r
.39415 .38807 .38932 .39202 .39397 .39627 .3988 .39234 Mtetra
.701 .645 .79 r
.38949 .38381 .38466 .38776 .38932 .39202 .39415 .38807 Mtetra
.701 .645 .791 r
.38482 .37954 .37999 .3835 .38466 .38776 .38949 .38381 Mtetra
.701 .646 .791 r
.38014 .37528 .37531 .37924 .37999 .3835 .38482 .37954 Mtetra
.37546 .37101 .37063 .37498 .37531 .37924 .38014 .37528 Mtetra
.37077 .36673 .36593 .37071 .37063 .37498 .37546 .37101 Mtetra
.701 .645 .79 r
.36607 .36244 .36123 .36643 .36593 .37071 .37077 .36673 Mtetra
.701 .646 .791 r
.36136 .35815 .35653 .36214 .36123 .36643 .36607 .36244 Mtetra
.35665 .35385 .35181 .35785 .35653 .36214 .36136 .35815 Mtetra
.35192 .34955 .34709 .35355 .35181 .35785 .35665 .35385 Mtetra
.34719 .34524 .34236 .34925 .34709 .35355 .35192 .34955 Mtetra
.34245 .34092 .33762 .34494 .34236 .34925 .34719 .34524 Mtetra
.33771 .33659 .33287 .34062 .33762 .34494 .34245 .34092 Mtetra
.33295 .33226 .32812 .33629 .33287 .34062 .33771 .33659 Mtetra
.32819 .32792 .32336 .33196 .32812 .33629 .33295 .33226 Mtetra
.32342 .32357 .31859 .32762 .32336 .33196 .32819 .32792 Mtetra
.31865 .31922 .31381 .32327 .31859 .32762 .32342 .32357 Mtetra
.31386 .31486 .30902 .31891 .31381 .32327 .31865 .31922 Mtetra
.30907 .31049 .30423 .31455 .30902 .31891 .31386 .31486 Mtetra
.30427 .30611 .29943 .31018 .30423 .31455 .30907 .31049 Mtetra
.29946 .30173 .29462 .30581 .29943 .31018 .30427 .30611 Mtetra
.29464 .29734 .2898 .30142 .29462 .30581 .29946 .30173 Mtetra
.28981 .29294 .28498 .29703 .2898 .30142 .29464 .29734 Mtetra
.28498 .28854 .28014 .29263 .28498 .29703 .28981 .29294 Mtetra
.28014 .28412 .2753 .28823 .28014 .29263 .28498 .28854 Mtetra
.27529 .2797 .27045 .28381 .2753 .28823 .28014 .28412 Mtetra
.27043 .27528 .2656 .27939 .27045 .28381 .27529 .2797 Mtetra
.26557 .27084 .26073 .27497 .2656 .27939 .27043 .27528 Mtetra
.2607 .2664 .25586 .27053 .26073 .27497 .26557 .27084 Mtetra
.25581 .26195 .25098 .26609 .25586 .27053 .2607 .2664 Mtetra
.25093 .25749 .24609 .26164 .25098 .26609 .25581 .26195 Mtetra
.24603 .25303 .24119 .25718 .24609 .26164 .25093 .25749 Mtetra
.24112 .24856 .23628 .25272 .24119 .25718 .24603 .25303 Mtetra
.23621 .24408 .23137 .24824 .23628 .25272 .24112 .24856 Mtetra
.68648 .64655 .68168 .65012 .68588 .65394 .69068 .65039 Mtetra
.68228 .64272 .67748 .64628 .68168 .65012 .68648 .64655 Mtetra
.67807 .63887 .67327 .64245 .67748 .64628 .68228 .64272 Mtetra
.67385 .63502 .66905 .6386 .67327 .64245 .67807 .63887 Mtetra
.66963 .63117 .66482 .63475 .66905 .6386 .67385 .63502 Mtetra
.6654 .62731 .66059 .6309 .66482 .63475 .66963 .63117 Mtetra
.66116 .62344 .65636 .62703 .66059 .6309 .6654 .62731 Mtetra
.65692 .61956 .65211 .62317 .65636 .62703 .66116 .62344 Mtetra
.65267 .61568 .64786 .61929 .65211 .62317 .65692 .61956 Mtetra
.64841 .6118 .6436 .61541 .64786 .61929 .65267 .61568 Mtetra
.64415 .60791 .63934 .61153 .6436 .61541 .64841 .6118 Mtetra
.63988 .60401 .63507 .60763 .63934 .61153 .64415 .60791 Mtetra
.6356 .6001 .63079 .60373 .63507 .60763 .63988 .60401 Mtetra
.63132 .59619 .62651 .59983 .63079 .60373 .6356 .6001 Mtetra
.62703 .59228 .62222 .59592 .62651 .59983 .63132 .59619 Mtetra
.62273 .58836 .61792 .592 .62222 .59592 .62703 .59228 Mtetra
.61843 .58443 .61362 .58808 .61792 .592 .62273 .58836 Mtetra
.61412 .58049 .60931 .58415 .61362 .58808 .61843 .58443 Mtetra
.702 .646 .791 r
.6098 .57655 .60499 .58022 .60931 .58415 .61412 .58049 Mtetra
.60548 .57261 .60067 .57628 .60499 .58022 .6098 .57655 Mtetra
.60115 .56866 .59634 .57234 .60067 .57628 .60548 .57261 Mtetra
.59681 .56471 .592 .5684 .59634 .57234 .60115 .56866 Mtetra
.59247 .56076 .58766 .56445 .592 .5684 .59681 .56471 Mtetra
.703 .647 .791 r
.58812 .55681 .58331 .56052 .58766 .56445 .59247 .56076 Mtetra
.703 .648 .791 r
.58376 .55287 .57895 .55659 .58331 .56052 .58812 .55681 Mtetra
.705 .649 .792 r
.5794 .54895 .57459 .5527 .57895 .55659 .58376 .55287 Mtetra
.707 .652 .792 r
.57503 .54506 .57022 .54885 .57459 .5527 .5794 .54895 Mtetra
.712 .656 .793 r
.57066 .54125 .56585 .5451 .57022 .54885 .57503 .54506 Mtetra
.719 .664 .794 r
.56628 .53757 .56147 .54153 .56585 .5451 .57066 .54125 Mtetra
.733 .677 .796 r
.56191 .53411 .5571 .53828 .56147 .54153 .56628 .53757 Mtetra
.758 .7 .797 r
.55753 .53106 .55273 .53559 .5571 .53828 .56191 .53411 Mtetra
.8 .738 .794 r
.55316 .52872 .54837 .53393 .55273 .53559 .55753 .53106 Mtetra
.866 .796 .779 r
.54881 .52765 .54403 .53407 .54837 .53393 .55316 .52872 Mtetra
.946 .864 .727 r
.54448 .52874 .53972 .53727 .54403 .53407 .54881 .52765 Mtetra
.988 .897 .603 r
.54019 .53339 .53545 .54535 .53972 .53727 .54448 .52874 Mtetra
.939 .855 .423 r
.53594 .54339 .53122 .56015 .53545 .54535 .54019 .53339 Mtetra
.807 .759 .244 r
.53172 .55994 .52698 .58138 .53122 .56015 .53594 .54339 Mtetra
0 0 0 r
.52747 .5811 .52263 .60295 .52698 .58138 .53172 .55994 Mtetra
0 0 .016 r
.52306 .5989 .51807 .61277 .52263 .60295 .52747 .5811 Mtetra
.152 0 0 r
.51843 .60212 .51333 .60288 .51807 .61277 .52306 .5989 Mtetra
0 .004 .541 r
.51366 .58736 .50856 .57908 .51333 .60288 .51843 .60212 Mtetra
.11 .053 .506 r
.50889 .56355 .50386 .55414 .50856 .57908 .51366 .58736 Mtetra
.236 .144 .542 r
.50421 .54217 .49925 .53652 .50386 .55414 .50889 .56355 Mtetra
.389 .299 .632 r
.49959 .52909 .49465 .52824 .49925 .53652 .50421 .54217 Mtetra
.659 .639 .819 r
.49498 .52483 .49003 .52783 .49465 .52824 .49959 .52909 Mtetra
.793 .998 .806 r
.49032 .52704 .48534 .53202 .49003 .52783 .49498 .52483 Mtetra
0 0 0 r
.4856 .53149 .48061 .53606 .48534 .53202 .49032 .52704 Mtetra
.402 .855 .806 r
.48088 .53267 .4759 .53481 .48061 .53606 .4856 .53149 Mtetra
.326 .43 .815 r
.47621 .52635 .47128 .52559 .4759 .53481 .48088 .53267 Mtetra
.297 .233 .615 r
.47166 .51239 .46679 .50997 .47128 .52559 .47621 .52635 Mtetra
.326 .214 .569 r
.4672 .49442 .46238 .49206 .46679 .50997 .47166 .51239 Mtetra
.37 .241 .571 r
.46281 .4766 .45801 .47539 .46238 .49206 .4672 .49442 Mtetra
.421 .29 .595 r
.45841 .46134 .45361 .46154 .45801 .47539 .46281 .4766 Mtetra
.477 .353 .632 r
.45399 .44914 .44918 .45057 .45361 .46154 .45841 .46134 Mtetra
.534 .421 .672 r
.44952 .43958 .44471 .44188 .44918 .45057 .45399 .44914 Mtetra
.584 .485 .708 r
.44502 .43192 .44021 .43482 .44471 .44188 .44952 .43958 Mtetra
.623 .537 .736 r
.44049 .42555 .43567 .42883 .44021 .43482 .44502 .43192 Mtetra
.651 .575 .756 r
.43593 .41999 .43111 .42353 .43567 .42883 .44049 .42555 Mtetra
.67 .601 .769 r
.43136 .41497 .42653 .41866 .43111 .42353 .43593 .41999 Mtetra
.682 .618 .778 r
.42676 .41026 .42193 .41404 .42653 .41866 .43136 .41497 Mtetra
.689 .629 .783 r
.42216 .40574 .41733 .40957 .42193 .41404 .42676 .41026 Mtetra
.694 .635 .786 r
.41754 .40133 .41271 .4052 .41733 .40957 .42216 .40574 Mtetra
.697 .639 .788 r
.41292 .39698 .40808 .40089 .41271 .4052 .41754 .40133 Mtetra
.699 .642 .789 r
.40828 .39268 .40345 .39661 .40808 .40089 .41292 .39698 Mtetra
.7 .644 .79 r
.40364 .3884 .3988 .39234 .40345 .39661 .40828 .39268 Mtetra
.39898 .38413 .39415 .38807 .3988 .39234 .40364 .3884 Mtetra
.701 .645 .79 r
.39432 .37986 .38949 .38381 .39415 .38807 .39898 .38413 Mtetra
.38966 .37558 .38482 .37954 .38949 .38381 .39432 .37986 Mtetra
.701 .645 .791 r
.38498 .37131 .38014 .37528 .38482 .37954 .38966 .37558 Mtetra
.702 .646 .791 r
.3803 .36703 .37546 .37101 .38014 .37528 .38498 .37131 Mtetra
.701 .646 .791 r
.37561 .36275 .37077 .36673 .37546 .37101 .3803 .36703 Mtetra
.37091 .35846 .36607 .36244 .37077 .36673 .37561 .36275 Mtetra
.701 .645 .791 r
.3662 .35416 .36136 .35815 .36607 .36244 .37091 .35846 Mtetra
.701 .646 .791 r
.36149 .34985 .35665 .35385 .36136 .35815 .3662 .35416 Mtetra
.702 .646 .791 r
.35676 .34554 .35192 .34955 .35665 .35385 .36149 .34985 Mtetra
.35203 .34122 .34719 .34524 .35192 .34955 .35676 .34554 Mtetra
.701 .646 .791 r
.34729 .3369 .34245 .34092 .34719 .34524 .35203 .34122 Mtetra
.34255 .33256 .33771 .33659 .34245 .34092 .34729 .3369 Mtetra
.3378 .32822 .33295 .33226 .33771 .33659 .34255 .33256 Mtetra
.33303 .32388 .32819 .32792 .33295 .33226 .3378 .32822 Mtetra
.702 .646 .791 r
.32827 .31952 .32342 .32357 .32819 .32792 .33303 .32388 Mtetra
.701 .646 .791 r
.32349 .31516 .31865 .31922 .32342 .32357 .32827 .31952 Mtetra
.3187 .31079 .31386 .31486 .31865 .31922 .32349 .31516 Mtetra
.31391 .30642 .30907 .31049 .31386 .31486 .3187 .31079 Mtetra
.30911 .30204 .30427 .30611 .30907 .31049 .31391 .30642 Mtetra
.3043 .29765 .29946 .30173 .30427 .30611 .30911 .30204 Mtetra
.29948 .29325 .29464 .29734 .29946 .30173 .3043 .29765 Mtetra
.29466 .28884 .28981 .29294 .29464 .29734 .29948 .29325 Mtetra
.28983 .28443 .28498 .28854 .28981 .29294 .29466 .28884 Mtetra
.28499 .28001 .28014 .28412 .28498 .28854 .28983 .28443 Mtetra
.28014 .27559 .27529 .2797 .28014 .28412 .28499 .28001 Mtetra
.27528 .27115 .27043 .27528 .27529 .2797 .28014 .27559 Mtetra
.27042 .26671 .26557 .27084 .27043 .27528 .27528 .27115 Mtetra
.26554 .26226 .2607 .2664 .26557 .27084 .27042 .26671 Mtetra
.26066 .25781 .25581 .26195 .2607 .2664 .26554 .26226 Mtetra
.25577 .25334 .25093 .25749 .25581 .26195 .26066 .25781 Mtetra
.25087 .24887 .24603 .25303 .25093 .25749 .25577 .25334 Mtetra
.24597 .24439 .24112 .24856 .24603 .25303 .25087 .24887 Mtetra
.24105 .23991 .23621 .24408 .24112 .24856 .24597 .24439 Mtetra
.69129 .64298 .68648 .64655 .69068 .65039 .69549 .64682 Mtetra
.68709 .63914 .68228 .64272 .68648 .64655 .69129 .64298 Mtetra
.68288 .63529 .67807 .63887 .68228 .64272 .68709 .63914 Mtetra
.67866 .63144 .67385 .63502 .67807 .63887 .68288 .63529 Mtetra
.67444 .62758 .66963 .63117 .67385 .63502 .67866 .63144 Mtetra
.67021 .62371 .6654 .62731 .66963 .63117 .67444 .62758 Mtetra
.66597 .61984 .66116 .62344 .6654 .62731 .67021 .62371 Mtetra
.66173 .61596 .65692 .61956 .66116 .62344 .66597 .61984 Mtetra
.65748 .61207 .65267 .61568 .65692 .61956 .66173 .61596 Mtetra
.65323 .60818 .64841 .6118 .65267 .61568 .65748 .61207 Mtetra
.64896 .60428 .64415 .60791 .64841 .6118 .65323 .60818 Mtetra
.64469 .60038 .63988 .60401 .64415 .60791 .64896 .60428 Mtetra
.64042 .59647 .6356 .6001 .63988 .60401 .64469 .60038 Mtetra
.63614 .59255 .63132 .59619 .6356 .6001 .64042 .59647 Mtetra
.63185 .58863 .62703 .59228 .63132 .59619 .63614 .59255 Mtetra
.62755 .5847 .62273 .58836 .62703 .59228 .63185 .58863 Mtetra
.62325 .58077 .61843 .58443 .62273 .58836 .62755 .5847 Mtetra
.61894 .57683 .61412 .58049 .61843 .58443 .62325 .58077 Mtetra
.702 .646 .791 r
.61462 .57288 .6098 .57655 .61412 .58049 .61894 .57683 Mtetra
.6103 .56893 .60548 .57261 .6098 .57655 .61462 .57288 Mtetra
.60597 .56498 .60115 .56866 .60548 .57261 .6103 .56893 Mtetra
.60163 .56102 .59681 .56471 .60115 .56866 .60597 .56498 Mtetra
.59729 .55706 .59247 .56076 .59681 .56471 .60163 .56102 Mtetra
.702 .647 .791 r
.59294 .5531 .58812 .55681 .59247 .56076 .59729 .55706 Mtetra
.703 .647 .791 r
.58859 .54914 .58376 .55287 .58812 .55681 .59294 .5531 Mtetra
.704 .649 .792 r
.58422 .5452 .5794 .54895 .58376 .55287 .58859 .54914 Mtetra
.706 .65 .792 r
.57986 .54129 .57503 .54506 .5794 .54895 .58422 .5452 Mtetra
.709 .654 .793 r
.57548 .53743 .57066 .54125 .57503 .54506 .57986 .54129 Mtetra
.715 .659 .794 r
.57111 .53366 .56628 .53757 .57066 .54125 .57548 .53743 Mtetra
.725 .669 .795 r
.56673 .53006 .56191 .53411 .56628 .53757 .57111 .53366 Mtetra
.742 .686 .797 r
.56235 .52676 .55753 .53106 .56191 .53411 .56673 .53006 Mtetra
.773 .715 .798 r
.55797 .52397 .55316 .52872 .55753 .53106 .56235 .52676 Mtetra
.824 .762 .794 r
.55361 .52208 .54881 .52765 .55316 .52872 .55797 .52397 Mtetra
.897 .828 .77 r
.54926 .52174 .54448 .52874 .54881 .52765 .55361 .52208 Mtetra
.969 .891 .695 r
.54495 .52398 .54019 .53339 .54448 .52874 .54926 .52174 Mtetra
.975 .896 .542 r
.54068 .53029 .53594 .54339 .54019 .53339 .54495 .52398 Mtetra
.885 .825 .353 r
.53645 .54223 .53172 .55994 .53594 .54339 .54068 .53029 Mtetra
.727 .715 .185 r
.53224 .56005 .52747 .5811 .53172 .55994 .53645 .54223 Mtetra
0 0 0 r
.52794 .57987 .52306 .5989 .52747 .5811 .53224 .56005 Mtetra
.52346 .59239 .51843 .60212 .52306 .5989 .52794 .57987 Mtetra
.023 .448 .871 r
.51877 .58898 .51366 .58736 .51843 .60212 .52346 .59239 Mtetra
.081 .072 .546 r
.51398 .57112 .50889 .56355 .51366 .58736 .51877 .58898 Mtetra
.192 .113 .532 r
.50923 .54908 .50421 .54217 .50889 .56355 .51398 .57112 Mtetra
.313 .217 .584 r
.50456 .53202 .49959 .52909 .50421 .54217 .50923 .54908 Mtetra
.505 .436 .713 r
.49994 .52352 .49498 .52483 .49959 .52909 .50456 .53202 Mtetra
.805 .894 .907 r
.4953 .52289 .49032 .52704 .49498 .52483 .49994 .52352 Mtetra
.566 .88 .597 r
.49061 .52675 .4856 .53149 .49032 .52704 .4953 .52289 Mtetra
0 0 0 r
.48588 .52979 .48088 .53267 .4856 .53149 .49061 .52675 Mtetra
.29 .605 .953 r
.48118 .52658 .47621 .52635 .48088 .53267 .48588 .52979 Mtetra
.256 .244 .653 r
.47656 .51497 .47166 .51239 .47621 .52635 .48118 .52658 Mtetra
.292 .197 .572 r
.47206 .49748 .4672 .49442 .47166 .51239 .47656 .51497 Mtetra
.34 .216 .562 r
.46763 .47868 .46281 .4766 .4672 .49442 .47206 .49748 Mtetra
.392 .26 .58 r
.46322 .46188 .45841 .46134 .46281 .4766 .46763 .47868 Mtetra
.449 .321 .614 r
.45879 .44828 .45399 .44914 .45841 .46134 .46322 .46188 Mtetra
.508 .39 .654 r
.45434 .43763 .44952 .43958 .45399 .44914 .45879 .44828 Mtetra
.563 .459 .693 r
.44984 .42924 .44502 .43192 .44952 .43958 .45434 .43763 Mtetra
.608 .517 .726 r
.44532 .42239 .44049 .42555 .44502 .43192 .44984 .42924 Mtetra
.641 .561 .749 r
.44076 .41655 .43593 .41999 .44049 .42555 .44532 .42239 Mtetra
.663 .592 .765 r
.43619 .41134 .43136 .41497 .43593 .41999 .44076 .41655 Mtetra
.678 .612 .775 r
.4316 .40651 .42676 .41026 .43136 .41497 .43619 .41134 Mtetra
.687 .625 .781 r
.427 .40192 .42216 .40574 .42676 .41026 .4316 .40651 Mtetra
.693 .633 .785 r
.42238 .39746 .41754 .40133 .42216 .40574 .427 .40192 Mtetra
.696 .638 .787 r
.41776 .39308 .41292 .39698 .41754 .40133 .42238 .39746 Mtetra
.698 .641 .789 r
.41312 .38876 .40828 .39268 .41292 .39698 .41776 .39308 Mtetra
.699 .643 .79 r
.40848 .38447 .40364 .3884 .40828 .39268 .41312 .38876 Mtetra
.7 .644 .79 r
.40383 .38018 .39898 .38413 .40364 .3884 .40848 .38447 Mtetra
.701 .644 .79 r
.39917 .3759 .39432 .37986 .39898 .38413 .40383 .38018 Mtetra
.701 .645 .79 r
.3945 .37162 .38966 .37558 .39432 .37986 .39917 .3759 Mtetra
.701 .645 .791 r
.38983 .36734 .38498 .37131 .38966 .37558 .3945 .37162 Mtetra
.701 .646 .791 r
.38514 .36305 .3803 .36703 .38498 .37131 .38983 .36734 Mtetra
.38045 .35876 .37561 .36275 .3803 .36703 .38514 .36305 Mtetra
.701 .645 .791 r
.37575 .35446 .37091 .35846 .37561 .36275 .38045 .35876 Mtetra
.701 .646 .791 r
.37105 .35015 .3662 .35416 .37091 .35846 .37575 .35446 Mtetra
.36633 .34584 .36149 .34985 .3662 .35416 .37105 .35015 Mtetra
.36161 .34153 .35676 .34554 .36149 .34985 .36633 .34584 Mtetra
.35688 .3372 .35203 .34122 .35676 .34554 .36161 .34153 Mtetra
.35214 .33287 .34729 .3369 .35203 .34122 .35688 .3372 Mtetra
.3474 .32853 .34255 .33256 .34729 .3369 .35214 .33287 Mtetra
.34265 .32418 .3378 .32822 .34255 .33256 .3474 .32853 Mtetra
.33788 .31983 .33303 .32388 .3378 .32822 .34265 .32418 Mtetra
.33312 .31547 .32827 .31952 .33303 .32388 .33788 .31983 Mtetra
.32834 .3111 .32349 .31516 .32827 .31952 .33312 .31547 Mtetra
.32355 .30673 .3187 .31079 .32349 .31516 .32834 .3111 Mtetra
.31876 .30234 .31391 .30642 .3187 .31079 .32355 .30673 Mtetra
.31396 .29795 .30911 .30204 .31391 .30642 .31876 .30234 Mtetra
.30915 .29356 .3043 .29765 .30911 .30204 .31396 .29795 Mtetra
.30434 .28915 .29948 .29325 .3043 .29765 .30915 .29356 Mtetra
.29951 .28474 .29466 .28884 .29948 .29325 .30434 .28915 Mtetra
.29468 .28032 .28983 .28443 .29466 .28884 .29951 .28474 Mtetra
.28984 .2759 .28499 .28001 .28983 .28443 .29468 .28032 Mtetra
.28499 .27146 .28014 .27559 .28499 .28001 .28984 .2759 Mtetra
.28013 .26702 .27528 .27115 .28014 .27559 .28499 .27146 Mtetra
.27527 .26257 .27042 .26671 .27528 .27115 .28013 .26702 Mtetra
.2704 .25812 .26554 .26226 .27042 .26671 .27527 .26257 Mtetra
.26552 .25366 .26066 .25781 .26554 .26226 .2704 .25812 Mtetra
.26063 .24918 .25577 .25334 .26066 .25781 .26552 .25366 Mtetra
.25573 .24471 .25087 .24887 .25577 .25334 .26063 .24918 Mtetra
.25082 .24022 .24597 .24439 .25087 .24887 .25573 .24471 Mtetra
.24591 .23573 .24105 .23991 .24597 .24439 .25082 .24022 Mtetra
.6961 .63941 .69129 .64298 .69549 .64682 .7003 .64325 Mtetra
.6919 .63556 .68709 .63914 .69129 .64298 .6961 .63941 Mtetra
.68769 .63171 .68288 .63529 .68709 .63914 .6919 .63556 Mtetra
.68348 .62785 .67866 .63144 .68288 .63529 .68769 .63171 Mtetra
.67925 .62398 .67444 .62758 .67866 .63144 .68348 .62785 Mtetra
.67503 .62011 .67021 .62371 .67444 .62758 .67925 .62398 Mtetra
.67079 .61623 .66597 .61984 .67021 .62371 .67503 .62011 Mtetra
.66655 .61234 .66173 .61596 .66597 .61984 .67079 .61623 Mtetra
.6623 .60845 .65748 .61207 .66173 .61596 .66655 .61234 Mtetra
.65805 .60455 .65323 .60818 .65748 .61207 .6623 .60845 Mtetra
.65378 .60065 .64896 .60428 .65323 .60818 .65805 .60455 Mtetra
.64952 .59674 .64469 .60038 .64896 .60428 .65378 .60065 Mtetra
.64524 .59283 .64042 .59647 .64469 .60038 .64952 .59674 Mtetra
.64096 .58891 .63614 .59255 .64042 .59647 .64524 .59283 Mtetra
.63667 .58498 .63185 .58863 .63614 .59255 .64096 .58891 Mtetra
.63238 .58104 .62755 .5847 .63185 .58863 .63667 .58498 Mtetra
.62807 .5771 .62325 .58077 .62755 .5847 .63238 .58104 Mtetra
.62376 .57316 .61894 .57683 .62325 .58077 .62807 .5771 Mtetra
.61945 .56921 .61462 .57288 .61894 .57683 .62376 .57316 Mtetra
.702 .646 .791 r
.61513 .56525 .6103 .56893 .61462 .57288 .61945 .56921 Mtetra
.6108 .56129 .60597 .56498 .6103 .56893 .61513 .56525 Mtetra
.60646 .55732 .60163 .56102 .60597 .56498 .6108 .56129 Mtetra
.60212 .55335 .59729 .55706 .60163 .56102 .60646 .55732 Mtetra
.59777 .54939 .59294 .5531 .59729 .55706 .60212 .55335 Mtetra
.703 .647 .791 r
.59342 .54542 .58859 .54914 .59294 .5531 .59777 .54939 Mtetra
.703 .648 .791 r
.58905 .54146 .58422 .5452 .58859 .54914 .59342 .54542 Mtetra
.705 .649 .792 r
.58469 .53753 .57986 .54129 .58422 .5452 .58905 .54146 Mtetra
.707 .652 .792 r
.58031 .53363 .57548 .53743 .57986 .54129 .58469 .53753 Mtetra
.711 .656 .793 r
.57594 .5298 .57111 .53366 .57548 .53743 .58031 .53363 Mtetra
.719 .664 .795 r
.57156 .5261 .56673 .53006 .57111 .53366 .57594 .5298 Mtetra
.732 .677 .797 r
.56717 .52262 .56235 .52676 .56673 .53006 .57156 .5261 Mtetra
.754 .699 .799 r
.56279 .51952 .55797 .52397 .56235 .52676 .56717 .52262 Mtetra
.792 .735 .8 r
.55842 .51707 .55361 .52208 .55797 .52397 .56279 .51952 Mtetra
.852 .792 .793 r
.55406 .51575 .54926 .52174 .55361 .52208 .55842 .51707 Mtetra
.929 .864 .755 r
.54973 .51633 .54495 .52398 .54926 .52174 .55406 .51575 Mtetra
.98 .912 .648 r
.54544 .51994 .54068 .53029 .54495 .52398 .54973 .51633 Mtetra
.942 .881 .47 r
.54119 .52804 .53645 .54223 .54068 .53029 .54544 .51994 Mtetra
.822 .788 .287 r
.53698 .54172 .53224 .56005 .53645 .54223 .54119 .52804 Mtetra
0 0 0 r
.53275 .55985 .52794 .57987 .53224 .56005 .53698 .54172 Mtetra
.5284 .57672 .52346 .59239 .52794 .57987 .53275 .55985 Mtetra
.52384 .58312 .51877 .58898 .52346 .59239 .5284 .57672 Mtetra
.166 .259 .716 r
.5191 .57419 .51398 .57112 .51877 .58898 .52384 .58312 Mtetra
.186 .128 .554 r
.51431 .55518 .50923 .54908 .51398 .57112 .5191 .57419 Mtetra
.279 .183 .564 r
.50958 .53611 .50456 .53202 .50923 .54908 .51431 .55518 Mtetra
.418 .324 .642 r
.50492 .52371 .49994 .52352 .50456 .53202 .50958 .53611 Mtetra
.674 .655 .823 r
.50028 .51967 .4953 .52289 .49994 .52352 .50492 .52371 Mtetra
.747 .989 .789 r
.49561 .52202 .49061 .52675 .4953 .52289 .50028 .51967 Mtetra
0 0 0 r
.4909 .52615 .48588 .52979 .49061 .52675 .49561 .52202 Mtetra
.169 .704 .828 r
.48618 .52601 .48118 .52658 .48588 .52979 .4909 .52615 Mtetra
.19 .279 .726 r
.48151 .51746 .47656 .51497 .48118 .52658 .48618 .52601 Mtetra
.245 .18 .582 r
.47694 .50123 .47206 .49748 .47656 .51497 .48151 .51746 Mtetra
.302 .189 .555 r
.47247 .48177 .46763 .47868 .47206 .49748 .47694 .50123 Mtetra
.358 .229 .566 r
.46804 .46338 .46322 .46188 .46763 .47868 .47247 .48177 Mtetra
.417 .287 .595 r
.46361 .44812 .45879 .44828 .46322 .46188 .46804 .46338 Mtetra
.479 .356 .635 r
.45916 .43616 .45434 .43763 .45879 .44828 .46361 .44812 Mtetra
.538 .428 .677 r
.45467 .42686 .44984 .42924 .45434 .43763 .45916 .43616 Mtetra
.589 .493 .713 r
.45015 .41942 .44532 .42239 .44984 .42924 .45467 .42686 Mtetra
.628 .544 .74 r
.4456 .4132 .44076 .41655 .44532 .42239 .45015 .41942 Mtetra
.655 .581 .759 r
.44103 .40775 .43619 .41134 .44076 .41655 .4456 .4132 Mtetra
.673 .605 .771 r
.43645 .40279 .4316 .40651 .43619 .41134 .44103 .40775 Mtetra
.684 .621 .779 r
.43184 .39811 .427 .40192 .4316 .40651 .43645 .40279 Mtetra
.69 .63 .784 r
.42723 .3936 .42238 .39746 .427 .40192 .43184 .39811 Mtetra
.695 .636 .786 r
.42261 .38919 .41776 .39308 .42238 .39746 .42723 .3936 Mtetra
.698 .64 .788 r
.41797 .38484 .41312 .38876 .41776 .39308 .42261 .38919 Mtetra
.699 .642 .789 r
.41333 .38052 .40848 .38447 .41312 .38876 .41797 .38484 Mtetra
.7 .644 .79 r
.40868 .37623 .40383 .38018 .40848 .38447 .41333 .38052 Mtetra
.40402 .37194 .39917 .3759 .40383 .38018 .40868 .37623 Mtetra
.701 .645 .79 r
.39935 .36765 .3945 .37162 .39917 .3759 .40402 .37194 Mtetra
.701 .645 .791 r
.39468 .36335 .38983 .36734 .3945 .37162 .39935 .36765 Mtetra
.701 .646 .791 r
.39 .35906 .38514 .36305 .38983 .36734 .39468 .36335 Mtetra
.38531 .35476 .38045 .35876 .38514 .36305 .39 .35906 Mtetra
.38061 .35046 .37575 .35446 .38045 .35876 .38531 .35476 Mtetra
.3759 .34615 .37105 .35015 .37575 .35446 .38061 .35046 Mtetra
.37119 .34183 .36633 .34584 .37105 .35015 .3759 .34615 Mtetra
.36647 .3375 .36161 .34153 .36633 .34584 .37119 .34183 Mtetra
.36174 .33317 .35688 .3372 .36161 .34153 .36647 .3375 Mtetra
.357 .32883 .35214 .33287 .35688 .3372 .36174 .33317 Mtetra
.35225 .32449 .3474 .32853 .35214 .33287 .357 .32883 Mtetra
.3475 .32013 .34265 .32418 .3474 .32853 .35225 .32449 Mtetra
.34274 .31577 .33788 .31983 .34265 .32418 .3475 .32013 Mtetra
.33797 .31141 .33312 .31547 .33788 .31983 .34274 .31577 Mtetra
.3332 .30703 .32834 .3111 .33312 .31547 .33797 .31141 Mtetra
.32841 .30265 .32355 .30673 .32834 .3111 .3332 .30703 Mtetra
.32362 .29826 .31876 .30234 .32355 .30673 .32841 .30265 Mtetra
.31882 .29387 .31396 .29795 .31876 .30234 .32362 .29826 Mtetra
.31401 .28946 .30915 .29356 .31396 .29795 .31882 .29387 Mtetra
.3092 .28505 .30434 .28915 .30915 .29356 .31401 .28946 Mtetra
.30437 .28063 .29951 .28474 .30434 .28915 .3092 .28505 Mtetra
.29954 .27621 .29468 .28032 .29951 .28474 .30437 .28063 Mtetra
.2947 .27177 .28984 .2759 .29468 .28032 .29954 .27621 Mtetra
.28985 .26733 .28499 .27146 .28984 .2759 .2947 .27177 Mtetra
.28499 .26289 .28013 .26702 .28499 .27146 .28985 .26733 Mtetra
.28013 .25843 .27527 .26257 .28013 .26702 .28499 .26289 Mtetra
.27526 .25397 .2704 .25812 .27527 .26257 .28013 .25843 Mtetra
.27038 .2495 .26552 .25366 .2704 .25812 .27526 .25397 Mtetra
.26549 .24502 .26063 .24918 .26552 .25366 .27038 .2495 Mtetra
.26059 .24054 .25573 .24471 .26063 .24918 .26549 .24502 Mtetra
.25569 .23604 .25082 .24022 .25573 .24471 .26059 .24054 Mtetra
.25077 .23154 .24591 .23573 .25082 .24022 .25569 .23604 Mtetra
.70093 .63583 .6961 .63941 .7003 .64325 .70512 .63968 Mtetra
.69672 .63198 .6919 .63556 .6961 .63941 .70093 .63583 Mtetra
.69252 .62812 .68769 .63171 .6919 .63556 .69672 .63198 Mtetra
.6883 .62425 .68348 .62785 .68769 .63171 .69252 .62812 Mtetra
.68408 .62038 .67925 .62398 .68348 .62785 .6883 .62425 Mtetra
.67985 .6165 .67503 .62011 .67925 .62398 .68408 .62038 Mtetra
.67562 .61262 .67079 .61623 .67503 .62011 .67985 .6165 Mtetra
.67138 .60872 .66655 .61234 .67079 .61623 .67562 .61262 Mtetra
.66713 .60483 .6623 .60845 .66655 .61234 .67138 .60872 Mtetra
.66287 .60093 .65805 .60455 .6623 .60845 .66713 .60483 Mtetra
.65861 .59702 .65378 .60065 .65805 .60455 .66287 .60093 Mtetra
.65434 .5931 .64952 .59674 .65378 .60065 .65861 .59702 Mtetra
.65007 .58918 .64524 .59283 .64952 .59674 .65434 .5931 Mtetra
.64579 .58525 .64096 .58891 .64524 .59283 .65007 .58918 Mtetra
.6415 .58132 .63667 .58498 .64096 .58891 .64579 .58525 Mtetra
.63721 .57738 .63238 .58104 .63667 .58498 .6415 .58132 Mtetra
.63291 .57343 .62807 .5771 .63238 .58104 .63721 .57738 Mtetra
.6286 .56948 .62376 .57316 .62807 .5771 .63291 .57343 Mtetra
.62428 .56553 .61945 .56921 .62376 .57316 .6286 .56948 Mtetra
.702 .646 .791 r
.61996 .56156 .61513 .56525 .61945 .56921 .62428 .56553 Mtetra
.61563 .5576 .6108 .56129 .61513 .56525 .61996 .56156 Mtetra
.6113 .55362 .60646 .55732 .6108 .56129 .61563 .5576 Mtetra
.60696 .54965 .60212 .55335 .60646 .55732 .6113 .55362 Mtetra
.60261 .54567 .59777 .54939 .60212 .55335 .60696 .54965 Mtetra
.702 .647 .791 r
.59825 .54169 .59342 .54542 .59777 .54939 .60261 .54567 Mtetra
.703 .648 .791 r
.59389 .53772 .58905 .54146 .59342 .54542 .59825 .54169 Mtetra
.704 .649 .792 r
.58952 .53377 .58469 .53753 .58905 .54146 .59389 .53772 Mtetra
.706 .651 .792 r
.58515 .52984 .58031 .53363 .58469 .53753 .58952 .53377 Mtetra
.709 .654 .793 r
.58077 .52597 .57594 .5298 .58031 .53363 .58515 .52984 Mtetra
.715 .66 .794 r
.57639 .52219 .57156 .5261 .57594 .5298 .58077 .52597 Mtetra
.724 .67 .796 r
.57201 .51858 .56717 .52262 .57156 .5261 .57639 .52219 Mtetra
.741 .687 .799 r
.56762 .51526 .56279 .51952 .56717 .52262 .57201 .51858 Mtetra
.769 .715 .802 r
.56325 .51242 .55842 .51707 .56279 .51952 .56762 .51526 Mtetra
.815 .761 .802 r
.55888 .51043 .55406 .51575 .55842 .51707 .56325 .51242 Mtetra
.884 .828 .787 r
.55453 .50983 .54973 .51633 .55406 .51575 .55888 .51043 Mtetra
.957 .899 .727 r
.55022 .51151 .54544 .51994 .54973 .51633 .55453 .50983 Mtetra
.97 .917 .585 r
.54595 .51669 .54119 .52804 .54544 .51994 .55022 .51151 Mtetra
.885 .849 .392 r
.54172 .52664 .53698 .54172 .54119 .52804 .54595 .51669 Mtetra
.745 .743 .226 r
.53752 .54161 .53275 .55985 .53698 .54172 .54172 .52664 Mtetra
0 0 0 r
.53326 .55882 .5284 .57672 .53275 .55985 .53752 .54161 Mtetra
.52883 .57119 .52384 .58312 .5284 .57672 .53326 .55882 Mtetra
.685 .947 .959 r
.52419 .57118 .5191 .57419 .52384 .58312 .52883 .57119 Mtetra
.263 .233 .636 r
.51942 .55826 .51431 .55518 .5191 .57419 .52419 .57118 Mtetra
.281 .191 .572 r
.51464 .53998 .50958 .53611 .51431 .55518 .51942 .55826 Mtetra
.379 .273 .607 r
.50993 .52489 .50492 .52371 .50958 .53611 .51464 .53998 Mtetra
.565 .486 .725 r
.50528 .51734 .50028 .51967 .50492 .52371 .50993 .52489 Mtetra
.836 .934 .893 r
.50063 .51739 .49561 .52202 .50028 .51967 .50528 .51734 Mtetra
0 0 0 r
.49594 .52168 .4909 .52615 .49561 .52202 .50063 .51739 Mtetra
.49121 .52433 .48618 .52601 .4909 .52615 .49594 .52168 Mtetra
.047 .372 .839 r
.4865 .51949 .48151 .51746 .48618 .52601 .49121 .52433 Mtetra
.172 .161 .603 r
.48186 .50554 .47694 .50123 .48151 .51746 .4865 .51949 Mtetra
.254 .159 .55 r
.47734 .48602 .47247 .48177 .47694 .50123 .48186 .50554 Mtetra
.319 .196 .551 r
.47288 .46607 .46804 .46338 .47247 .48177 .47734 .48602 Mtetra
.381 .251 .576 r
.46844 .4489 .46361 .44812 .46804 .46338 .47288 .46607 Mtetra
.446 .319 .614 r
.46399 .43534 .45916 .43616 .46361 .44812 .46844 .4489 Mtetra
.51 .394 .657 r
.4595 .42488 .45467 .42686 .45916 .43616 .46399 .43534 Mtetra
.567 .465 .698 r
.45499 .41668 .45015 .41942 .45467 .42686 .4595 .42488 Mtetra
.612 .524 .73 r
.45045 .40999 .4456 .4132 .45015 .41942 .45499 .41668 Mtetra
.645 .567 .752 r
.44588 .40426 .44103 .40775 .4456 .4132 .45045 .40999 Mtetra
.666 .596 .767 r
.4413 .39911 .43645 .40279 .44103 .40775 .44588 .40426 Mtetra
.68 .615 .776 r
.4367 .39432 .43184 .39811 .43645 .40279 .4413 .39911 Mtetra
.688 .627 .782 r
.43209 .38975 .42723 .3936 .43184 .39811 .4367 .39432 Mtetra
.693 .634 .785 r
.42746 .38529 .42261 .38919 .42723 .3936 .43209 .38975 Mtetra
.697 .639 .788 r
.42283 .38092 .41797 .38484 .42261 .38919 .42746 .38529 Mtetra
.699 .642 .789 r
.41819 .37658 .41333 .38052 .41797 .38484 .42283 .38092 Mtetra
.7 .643 .79 r
.41354 .37227 .40868 .37623 .41333 .38052 .41819 .37658 Mtetra
.7 .644 .79 r
.40888 .36797 .40402 .37194 .40868 .37623 .41354 .37227 Mtetra
.701 .645 .79 r
.40421 .36367 .39935 .36765 .40402 .37194 .40888 .36797 Mtetra
.701 .645 .791 r
.39954 .35937 .39468 .36335 .39935 .36765 .40421 .36367 Mtetra
.39486 .35507 .39 .35906 .39468 .36335 .39954 .35937 Mtetra
.39017 .35076 .38531 .35476 .39 .35906 .39486 .35507 Mtetra
.38547 .34645 .38061 .35046 .38531 .35476 .39017 .35076 Mtetra
.701 .646 .791 r
.38076 .34213 .3759 .34615 .38061 .35046 .38547 .34645 Mtetra
.37605 .33781 .37119 .34183 .3759 .34615 .38076 .34213 Mtetra
.37133 .33348 .36647 .3375 .37119 .34183 .37605 .33781 Mtetra
.3666 .32914 .36174 .33317 .36647 .3375 .37133 .33348 Mtetra
.36186 .32479 .357 .32883 .36174 .33317 .3666 .32914 Mtetra
.35712 .32044 .35225 .32449 .357 .32883 .36186 .32479 Mtetra
.35237 .31608 .3475 .32013 .35225 .32449 .35712 .32044 Mtetra
.34761 .31171 .34274 .31577 .3475 .32013 .35237 .31608 Mtetra
.34284 .30734 .33797 .31141 .34274 .31577 .34761 .31171 Mtetra
.33806 .30296 .3332 .30703 .33797 .31141 .34284 .30734 Mtetra
.33328 .29857 .32841 .30265 .3332 .30703 .33806 .30296 Mtetra
.32849 .29417 .32362 .29826 .32841 .30265 .33328 .29857 Mtetra
.32369 .28977 .31882 .29387 .32362 .29826 .32849 .29417 Mtetra
.31888 .28536 .31401 .28946 .31882 .29387 .32369 .28977 Mtetra
.31406 .28094 .3092 .28505 .31401 .28946 .31888 .28536 Mtetra
.30924 .27652 .30437 .28063 .3092 .28505 .31406 .28094 Mtetra
.30441 .27208 .29954 .27621 .30437 .28063 .30924 .27652 Mtetra
.29957 .26765 .2947 .27177 .29954 .27621 .30441 .27208 Mtetra
.29472 .2632 .28985 .26733 .2947 .27177 .29957 .26765 Mtetra
.28986 .25874 .28499 .26289 .28985 .26733 .29472 .2632 Mtetra
.285 .25428 .28013 .25843 .28499 .26289 .28986 .25874 Mtetra
.28013 .24981 .27526 .25397 .28013 .25843 .285 .25428 Mtetra
.27525 .24533 .27038 .2495 .27526 .25397 .28013 .24981 Mtetra
.27036 .24085 .26549 .24502 .27038 .2495 .27525 .24533 Mtetra
.26546 .23636 .26059 .24054 .26549 .24502 .27036 .24085 Mtetra
.26056 .23186 .25569 .23604 .26059 .24054 .26546 .23636 Mtetra
.25564 .22735 .25077 .23154 .25569 .23604 .26056 .23186 Mtetra
.70575 .63225 .70093 .63583 .70512 .63968 .70995 .6361 Mtetra
.70155 .62839 .69672 .63198 .70093 .63583 .70575 .63225 Mtetra
.69735 .62452 .69252 .62812 .69672 .63198 .70155 .62839 Mtetra
.69313 .62065 .6883 .62425 .69252 .62812 .69735 .62452 Mtetra
.68891 .61677 .68408 .62038 .6883 .62425 .69313 .62065 Mtetra
.68468 .61289 .67985 .6165 .68408 .62038 .68891 .61677 Mtetra
.68045 .609 .67562 .61262 .67985 .6165 .68468 .61289 Mtetra
.67621 .6051 .67138 .60872 .67562 .61262 .68045 .609 Mtetra
.67196 .6012 .66713 .60483 .67138 .60872 .67621 .6051 Mtetra
.66771 .59729 .66287 .60093 .66713 .60483 .67196 .6012 Mtetra
.66345 .59338 .65861 .59702 .66287 .60093 .66771 .59729 Mtetra
.65918 .58946 .65434 .5931 .65861 .59702 .66345 .59338 Mtetra
.65491 .58553 .65007 .58918 .65434 .5931 .65918 .58946 Mtetra
.65063 .5816 .64579 .58525 .65007 .58918 .65491 .58553 Mtetra
.64634 .57766 .6415 .58132 .64579 .58525 .65063 .5816 Mtetra
.64205 .57371 .63721 .57738 .6415 .58132 .64634 .57766 Mtetra
.63775 .56976 .63291 .57343 .63721 .57738 .64205 .57371 Mtetra
.63344 .5658 .6286 .56948 .63291 .57343 .63775 .56976 Mtetra
.62912 .56184 .62428 .56553 .6286 .56948 .63344 .5658 Mtetra
.702 .646 .791 r
.6248 .55787 .61996 .56156 .62428 .56553 .62912 .56184 Mtetra
.62048 .5539 .61563 .5576 .61996 .56156 .6248 .55787 Mtetra
.61614 .54992 .6113 .55362 .61563 .5576 .62048 .5539 Mtetra
.6118 .54593 .60696 .54965 .6113 .55362 .61614 .54992 Mtetra
.60745 .54195 .60261 .54567 .60696 .54965 .6118 .54593 Mtetra
.702 .647 .791 r
.6031 .53796 .59825 .54169 .60261 .54567 .60745 .54195 Mtetra
.703 .647 .791 r
.59874 .53398 .59389 .53772 .59825 .54169 .6031 .53796 Mtetra
.704 .648 .792 r
.59437 .53001 .58952 .53377 .59389 .53772 .59874 .53398 Mtetra
.705 .65 .792 r
.59 .52606 .58515 .52984 .58952 .53377 .59437 .53001 Mtetra
.708 .652 .793 r
.58562 .52215 .58077 .52597 .58515 .52984 .59 .52606 Mtetra
.712 .657 .794 r
.58124 .51832 .57639 .52219 .58077 .52597 .58562 .52215 Mtetra
.719 .665 .796 r
.57685 .51461 .57201 .51858 .57639 .52219 .58124 .51832 Mtetra
.731 .678 .798 r
.57246 .51113 .56762 .51526 .57201 .51858 .57685 .51461 Mtetra
.752 .7 .802 r
.56808 .50802 .56325 .51242 .56762 .51526 .57246 .51113 Mtetra
.788 .736 .805 r
.56371 .50554 .55888 .51043 .56325 .51242 .56808 .50802 Mtetra
.844 .794 .802 r
.55935 .50412 .55453 .50983 .55888 .51043 .56371 .50554 Mtetra
.918 .869 .775 r
.55502 .50443 .55022 .51151 .55453 .50983 .55935 .50412 Mtetra
.97 .927 .682 r
.55073 .50744 .54595 .51669 .55022 .51151 .55502 .50443 Mtetra
.934 .902 .506 r
.54648 .51434 .54172 .52664 .54595 .51669 .55073 .50744 Mtetra
.815 .807 .318 r
.54227 .52594 .53752 .54161 .54172 .52664 .54648 .51434 Mtetra
0 0 0 r
.53806 .54133 .53326 .55882 .53752 .54161 .54227 .52594 Mtetra
.53374 .55605 .52883 .57119 .53326 .55882 .53806 .54133 Mtetra
.68 .847 .432 r
.52923 .56283 .52419 .57118 .52883 .57119 .53374 .55605 Mtetra
.515 .537 .816 r
.52452 .55712 .51942 .55826 .52419 .57118 .52923 .56283 Mtetra
.333 .25 .61 r
.51973 .54217 .51464 .53998 .51942 .55826 .52452 .55712 Mtetra
.378 .265 .597 r
.51498 .52614 .50993 .52489 .51464 .53998 .51973 .54217 Mtetra
.51 .399 .664 r
.51029 .51557 .50528 .51734 .50993 .52489 .51498 .52614 Mtetra
.768 .734 .822 r
.50564 .51282 .50063 .51739 .50528 .51734 .51029 .51557 Mtetra
.706 .953 .678 r
.50097 .51631 .49594 .52168 .50063 .51739 .50564 .51282 Mtetra
0 0 0 r
.49626 .5211 .49121 .52433 .49594 .52168 .50097 .51631 Mtetra
.149 0 0 r
.49153 .52042 .4865 .51949 .49121 .52433 .49626 .5211 Mtetra
.046 .15 .65 r
.48684 .50999 .48186 .50554 .4865 .51949 .49153 .52042 Mtetra
.186 .124 .55 r
.48224 .49143 .47734 .48602 .48186 .50554 .48684 .50999 Mtetra
.27 .159 .538 r
.47774 .47021 .47288 .46607 .47734 .48602 .48224 .49143 Mtetra
.34 .212 .557 r
.47328 .45091 .46844 .4489 .47288 .46607 .47774 .47021 Mtetra
.408 .279 .592 r
.46882 .43537 .46399 .43534 .46844 .4489 .47328 .45091 Mtetra
.476 .355 .636 r
.46434 .42346 .4595 .42488 .46399 .43534 .46882 .43537 Mtetra
.54 .432 .68 r
.45983 .41429 .45499 .41668 .4595 .42488 .46434 .42346 Mtetra
.593 .498 .716 r
.4553 .40698 .45045 .40999 .45499 .41668 .45983 .41429 Mtetra
.632 .549 .744 r
.45074 .40087 .44588 .40426 .45045 .40999 .4553 .40698 Mtetra
.658 .585 .762 r
.44616 .3955 .4413 .39911 .44588 .40426 .45074 .40087 Mtetra
.675 .608 .773 r
.44156 .39057 .4367 .39432 .4413 .39911 .44616 .3955 Mtetra
.685 .623 .78 r
.43695 .38591 .43209 .38975 .4367 .39432 .44156 .39057 Mtetra
.692 .632 .784 r
.43233 .38141 .42746 .38529 .43209 .38975 .43695 .38591 Mtetra
.696 .637 .787 r
.4277 .377 .42283 .38092 .42746 .38529 .43233 .38141 Mtetra
.698 .641 .788 r
.42305 .37264 .41819 .37658 .42283 .38092 .4277 .377 Mtetra
.699 .643 .789 r
.4184 .36831 .41354 .37227 .41819 .37658 .42305 .37264 Mtetra
.7 .644 .79 r
.41375 .364 .40888 .36797 .41354 .37227 .4184 .36831 Mtetra
.701 .644 .79 r
.40908 .35969 .40421 .36367 .40888 .36797 .41375 .364 Mtetra
.701 .645 .791 r
.40441 .35538 .39954 .35937 .40421 .36367 .40908 .35969 Mtetra
.39973 .35107 .39486 .35507 .39954 .35937 .40441 .35538 Mtetra
.39504 .34676 .39017 .35076 .39486 .35507 .39973 .35107 Mtetra
.39034 .34244 .38547 .34645 .39017 .35076 .39504 .34676 Mtetra
.701 .646 .791 r
.38563 .33811 .38076 .34213 .38547 .34645 .39034 .34244 Mtetra
.38092 .33378 .37605 .33781 .38076 .34213 .38563 .33811 Mtetra
.3762 .32944 .37133 .33348 .37605 .33781 .38092 .33378 Mtetra
.37147 .3251 .3666 .32914 .37133 .33348 .3762 .32944 Mtetra
.36673 .32075 .36186 .32479 .3666 .32914 .37147 .3251 Mtetra
.36199 .31639 .35712 .32044 .36186 .32479 .36673 .32075 Mtetra
.35724 .31202 .35237 .31608 .35712 .32044 .36199 .31639 Mtetra
.35248 .30765 .34761 .31171 .35237 .31608 .35724 .31202 Mtetra
.34771 .30327 .34284 .30734 .34761 .31171 .35248 .30765 Mtetra
.34293 .29888 .33806 .30296 .34284 .30734 .34771 .30327 Mtetra
.33815 .29448 .33328 .29857 .33806 .30296 .34293 .29888 Mtetra
.33336 .29008 .32849 .29417 .33328 .29857 .33815 .29448 Mtetra
.32856 .28567 .32369 .28977 .32849 .29417 .33336 .29008 Mtetra
.32375 .28125 .31888 .28536 .32369 .28977 .32856 .28567 Mtetra
.31894 .27683 .31406 .28094 .31888 .28536 .32375 .28125 Mtetra
.31411 .2724 .30924 .27652 .31406 .28094 .31894 .27683 Mtetra
.30928 .26796 .30441 .27208 .30924 .27652 .31411 .2724 Mtetra
.30444 .26351 .29957 .26765 .30441 .27208 .30928 .26796 Mtetra
.2996 .25906 .29472 .2632 .29957 .26765 .30444 .26351 Mtetra
.29474 .25459 .28986 .25874 .29472 .2632 .2996 .25906 Mtetra
.28988 .25013 .285 .25428 .28986 .25874 .29474 .25459 Mtetra
.285 .24565 .28013 .24981 .285 .25428 .28988 .25013 Mtetra
.28012 .24116 .27525 .24533 .28013 .24981 .285 .24565 Mtetra
.27524 .23667 .27036 .24085 .27525 .24533 .28012 .24116 Mtetra
.27034 .23217 .26546 .23636 .27036 .24085 .27524 .23667 Mtetra
.26543 .22767 .26056 .23186 .26546 .23636 .27034 .23217 Mtetra
.26052 .22315 .25564 .22735 .26056 .23186 .26543 .22767 Mtetra
.71059 .62866 .70575 .63225 .70995 .6361 .71478 .63252 Mtetra
.70639 .62479 .70155 .62839 .70575 .63225 .71059 .62866 Mtetra
.70218 .62092 .69735 .62452 .70155 .62839 .70639 .62479 Mtetra
.69797 .61704 .69313 .62065 .69735 .62452 .70218 .62092 Mtetra
.69375 .61316 .68891 .61677 .69313 .62065 .69797 .61704 Mtetra
.68952 .60927 .68468 .61289 .68891 .61677 .69375 .61316 Mtetra
.68529 .60537 .68045 .609 .68468 .61289 .68952 .60927 Mtetra
.68105 .60147 .67621 .6051 .68045 .609 .68529 .60537 Mtetra
.6768 .59756 .67196 .6012 .67621 .6051 .68105 .60147 Mtetra
.67255 .59365 .66771 .59729 .67196 .6012 .6768 .59756 Mtetra
.66829 .58973 .66345 .59338 .66771 .59729 .67255 .59365 Mtetra
.66402 .5858 .65918 .58946 .66345 .59338 .66829 .58973 Mtetra
.65975 .58187 .65491 .58553 .65918 .58946 .66402 .5858 Mtetra
.65547 .57793 .65063 .5816 .65491 .58553 .65975 .58187 Mtetra
.65118 .57399 .64634 .57766 .65063 .5816 .65547 .57793 Mtetra
.64689 .57004 .64205 .57371 .64634 .57766 .65118 .57399 Mtetra
.64259 .56608 .63775 .56976 .64205 .57371 .64689 .57004 Mtetra
.63829 .56212 .63344 .5658 .63775 .56976 .64259 .56608 Mtetra
.63397 .55815 .62912 .56184 .63344 .5658 .63829 .56212 Mtetra
.62965 .55417 .6248 .55787 .62912 .56184 .63397 .55815 Mtetra
.702 .646 .791 r
.62532 .55019 .62048 .5539 .6248 .55787 .62965 .55417 Mtetra
.62099 .54621 .61614 .54992 .62048 .5539 .62532 .55019 Mtetra
.61665 .54222 .6118 .54593 .61614 .54992 .62099 .54621 Mtetra
.6123 .53822 .60745 .54195 .6118 .54593 .61665 .54222 Mtetra
.60795 .53423 .6031 .53796 .60745 .54195 .6123 .53822 Mtetra
.702 .647 .791 r
.60359 .53024 .59874 .53398 .6031 .53796 .60795 .53423 Mtetra
.703 .648 .791 r
.59922 .52625 .59437 .53001 .59874 .53398 .60359 .53024 Mtetra
.704 .649 .792 r
.59485 .52228 .59 .52606 .59437 .53001 .59922 .52625 Mtetra
.706 .651 .792 r
.59047 .51835 .58562 .52215 .59 .52606 .59485 .52228 Mtetra
.71 .655 .793 r
.58609 .51447 .58124 .51832 .58562 .52215 .59047 .51835 Mtetra
.715 .661 .795 r
.5817 .51069 .57685 .51461 .58124 .51832 .58609 .51447 Mtetra
.725 .671 .797 r
.57731 .50708 .57246 .51113 .57685 .51461 .5817 .51069 Mtetra
.741 .689 .801 r
.57293 .50376 .56808 .50802 .57246 .51113 .57731 .50708 Mtetra
.768 .717 .805 r
.56855 .50094 .56371 .50554 .56808 .50802 .57293 .50376 Mtetra
.812 .764 .808 r
.56418 .49892 .55935 .50412 .56371 .50554 .56855 .50094 Mtetra
.877 .833 .799 r
.55983 .49824 .55502 .50443 .55935 .50412 .56418 .49892 Mtetra
.947 .91 .749 r
.55552 .49966 .55073 .50744 .55502 .50443 .55983 .49824 Mtetra
.96 .935 .614 r
.55126 .50421 .54648 .51434 .55073 .50744 .55552 .49966 Mtetra
.869 .865 .418 r
.54704 .51286 .54227 .52594 .54648 .51434 .55126 .50421 Mtetra
.735 .759 .252 r
.54284 .52567 .53806 .54133 .54227 .52594 .54704 .51286 Mtetra
0 0 0 r
.53859 .54026 .53374 .55605 .53806 .54133 .54284 .52567 Mtetra
.53419 .55095 .52923 .56283 .53374 .55605 .53859 .54026 Mtetra
.875 .954 .856 r
.52959 .55166 .52452 .55712 .52923 .56283 .53419 .55095 Mtetra
.46 .385 .686 r
.52483 .54159 .51973 .54217 .52452 .55712 .52959 .55166 Mtetra
.41 .293 .608 r
.52005 .52655 .51498 .52614 .51973 .54217 .52483 .54159 Mtetra
.492 .363 .632 r
.51532 .51393 .51029 .51557 .51498 .52614 .52005 .52655 Mtetra
.687 .582 .732 r
.51066 .50822 .50564 .51282 .51029 .51557 .51532 .51393 Mtetra
.905 .974 .803 r
.50601 .50997 .50097 .51631 .50564 .51282 .51066 .50822 Mtetra
0 0 0 r
.50133 .51588 .49626 .5211 .50097 .51631 .50601 .50997 Mtetra
.104 0 0 r
.49659 .51937 .49153 .52042 .49626 .5211 .50133 .51588 Mtetra
0 .165 .697 r
.49186 .51381 .48684 .50999 .49153 .52042 .49659 .51937 Mtetra
.075 .08 .558 r
.48719 .4978 .48224 .49143 .48684 .50999 .49186 .51381 Mtetra
.206 .116 .527 r
.48263 .47603 .47774 .47021 .48224 .49143 .48719 .4978 Mtetra
.291 .17 .538 r
.47814 .45452 .47328 .45091 .47774 .47021 .48263 .47603 Mtetra
.364 .235 .568 r
.47367 .4366 .46882 .43537 .47328 .45091 .47814 .45452 Mtetra
.436 .311 .611 r
.46919 .4228 .46434 .42346 .46882 .43537 .47367 .4366 Mtetra
.507 .392 .658 r
.46469 .41235 .45983 .41429 .46434 .42346 .46919 .4228 Mtetra
.568 .467 .7 r
.46015 .40424 .4553 .40698 .45983 .41429 .46469 .41235 Mtetra
.615 .527 .732 r
.4556 .39763 .45074 .40087 .4553 .40698 .46015 .40424 Mtetra
.647 .571 .755 r
.45102 .39197 .44616 .3955 .45074 .40087 .4556 .39763 Mtetra
.668 .599 .769 r
.44643 .38687 .44156 .39057 .44616 .3955 .45102 .39197 Mtetra
.681 .617 .777 r
.44182 .3821 .43695 .38591 .44156 .39057 .44643 .38687 Mtetra
.689 .628 .783 r
.4372 .37753 .43233 .38141 .43695 .38591 .44182 .3821 Mtetra
.694 .635 .786 r
.43257 .37308 .4277 .377 .43233 .38141 .4372 .37753 Mtetra
.697 .64 .788 r
.42793 .3687 .42305 .37264 .4277 .377 .43257 .37308 Mtetra
.699 .642 .789 r
.42328 .36435 .4184 .36831 .42305 .37264 .42793 .3687 Mtetra
.7 .643 .79 r
.41862 .36002 .41375 .364 .4184 .36831 .42328 .36435 Mtetra
.7 .644 .79 r
.41396 .3557 .40908 .35969 .41375 .364 .41862 .36002 Mtetra
.701 .645 .79 r
.40928 .35138 .40441 .35538 .40908 .35969 .41396 .3557 Mtetra
.701 .645 .791 r
.4046 .34707 .39973 .35107 .40441 .35538 .40928 .35138 Mtetra
.39991 .34274 .39504 .34676 .39973 .35107 .4046 .34707 Mtetra
.39521 .33842 .39034 .34244 .39504 .34676 .39991 .34274 Mtetra
.701 .646 .791 r
.39051 .33409 .38563 .33811 .39034 .34244 .39521 .33842 Mtetra
.3858 .32975 .38092 .33378 .38563 .33811 .39051 .33409 Mtetra
.38108 .3254 .3762 .32944 .38092 .33378 .3858 .32975 Mtetra
.37635 .32105 .37147 .3251 .3762 .32944 .38108 .3254 Mtetra
.37161 .31669 .36673 .32075 .37147 .3251 .37635 .32105 Mtetra
.36687 .31233 .36199 .31639 .36673 .32075 .37161 .31669 Mtetra
.36212 .30795 .35724 .31202 .36199 .31639 .36687 .31233 Mtetra
.35736 .30357 .35248 .30765 .35724 .31202 .36212 .30795 Mtetra
.35259 .29919 .34771 .30327 .35248 .30765 .35736 .30357 Mtetra
.34781 .29479 .34293 .29888 .34771 .30327 .35259 .29919 Mtetra
.34303 .29039 .33815 .29448 .34293 .29888 .34781 .29479 Mtetra
.33824 .28598 .33336 .29008 .33815 .29448 .34303 .29039 Mtetra
.33344 .28156 .32856 .28567 .33336 .29008 .33824 .28598 Mtetra
.32863 .27714 .32375 .28125 .32856 .28567 .33344 .28156 Mtetra
.32382 .27271 .31894 .27683 .32375 .28125 .32863 .27714 Mtetra
.319 .26827 .31411 .2724 .31894 .27683 .32382 .27271 Mtetra
.31417 .26382 .30928 .26796 .31411 .2724 .319 .26827 Mtetra
.30933 .25937 .30444 .26351 .30928 .26796 .31417 .26382 Mtetra
.30448 .25491 .2996 .25906 .30444 .26351 .30933 .25937 Mtetra
.29962 .25044 .29474 .25459 .2996 .25906 .30448 .25491 Mtetra
.29476 .24596 .28988 .25013 .29474 .25459 .29962 .25044 Mtetra
.28989 .24148 .285 .24565 .28988 .25013 .29476 .24596 Mtetra
.28501 .23699 .28012 .24116 .285 .24565 .28989 .24148 Mtetra
.28012 .23249 .27524 .23667 .28012 .24116 .28501 .23699 Mtetra
.27522 .22798 .27034 .23217 .27524 .23667 .28012 .23249 Mtetra
.27032 .22347 .26543 .22767 .27034 .23217 .27522 .22798 Mtetra
.26541 .21895 .26052 .22315 .26543 .22767 .27032 .22347 Mtetra
.71543 .62506 .71059 .62866 .71478 .63252 .71962 .62893 Mtetra
.71123 .62119 .70639 .62479 .71059 .62866 .71543 .62506 Mtetra
.70703 .61732 .70218 .62092 .70639 .62479 .71123 .62119 Mtetra
.70281 .61343 .69797 .61704 .70218 .62092 .70703 .61732 Mtetra
.69859 .60954 .69375 .61316 .69797 .61704 .70281 .61343 Mtetra
.69437 .60565 .68952 .60927 .69375 .61316 .69859 .60954 Mtetra
.69014 .60175 .68529 .60537 .68952 .60927 .69437 .60565 Mtetra
.6859 .59784 .68105 .60147 .68529 .60537 .69014 .60175 Mtetra
.68165 .59393 .6768 .59756 .68105 .60147 .6859 .59784 Mtetra
.6774 .59001 .67255 .59365 .6768 .59756 .68165 .59393 Mtetra
.67314 .58608 .66829 .58973 .67255 .59365 .6774 .59001 Mtetra
.66887 .58215 .66402 .5858 .66829 .58973 .67314 .58608 Mtetra
.6646 .57821 .65975 .58187 .66402 .5858 .66887 .58215 Mtetra
.66032 .57426 .65547 .57793 .65975 .58187 .6646 .57821 Mtetra
.65604 .57031 .65118 .57399 .65547 .57793 .66032 .57426 Mtetra
.65174 .56636 .64689 .57004 .65118 .57399 .65604 .57031 Mtetra
.64745 .56239 .64259 .56608 .64689 .57004 .65174 .56636 Mtetra
.64314 .55842 .63829 .56212 .64259 .56608 .64745 .56239 Mtetra
.63883 .55445 .63397 .55815 .63829 .56212 .64314 .55842 Mtetra
.63451 .55047 .62965 .55417 .63397 .55815 .63883 .55445 Mtetra
.702 .646 .791 r
.63018 .54648 .62532 .55019 .62965 .55417 .63451 .55047 Mtetra
.62585 .54249 .62099 .54621 .62532 .55019 .63018 .54648 Mtetra
.62151 .53849 .61665 .54222 .62099 .54621 .62585 .54249 Mtetra
.61716 .53449 .6123 .53822 .61665 .54222 .62151 .53849 Mtetra
.61281 .53049 .60795 .53423 .6123 .53822 .61716 .53449 Mtetra
.702 .647 .791 r
.60845 .52649 .60359 .53024 .60795 .53423 .61281 .53049 Mtetra
.703 .647 .791 r
.60408 .52249 .59922 .52625 .60359 .53024 .60845 .52649 Mtetra
.704 .648 .792 r
.59971 .51851 .59485 .52228 .59922 .52625 .60408 .52249 Mtetra
.705 .65 .792 r
.59533 .51455 .59047 .51835 .59485 .52228 .59971 .51851 Mtetra
.708 .653 .793 r
.59095 .51063 .58609 .51447 .59047 .51835 .59533 .51455 Mtetra
.712 .658 .794 r
.58656 .50679 .5817 .51069 .58609 .51447 .59095 .51063 Mtetra
.72 .666 .797 r
.58217 .50309 .57731 .50708 .5817 .51069 .58656 .50679 Mtetra
.732 .68 .8 r
.57778 .49962 .57293 .50376 .57731 .50708 .58217 .50309 Mtetra
.753 .703 .804 r
.5734 .49653 .56855 .50094 .57293 .50376 .57778 .49962 Mtetra
.788 .741 .809 r
.56902 .49408 .56418 .49892 .56855 .50094 .5734 .49653 Mtetra
.842 .8 .81 r
.56467 .49267 .55983 .49824 .56418 .49892 .56902 .49408 Mtetra
.912 .878 .788 r
.56034 .49292 .55552 .49966 .55983 .49824 .56467 .49267 Mtetra
.961 .941 .702 r
.55605 .49567 .55126 .50421 .55552 .49966 .56034 .49292 Mtetra
.915 .916 .526 r
.55182 .50189 .54704 .51286 .55126 .50421 .55605 .49567 Mtetra
.788 .815 .334 r
.54762 .5121 .54284 .52567 .54704 .51286 .55182 .50189 Mtetra
0 0 0 r
.54341 .52527 .53859 .54026 .54284 .52567 .54762 .5121 Mtetra
.5391 .53753 .53419 .55095 .53859 .54026 .54341 .52527 Mtetra
.837 .935 .561 r
.5346 .54298 .52959 .55166 .53419 .55095 .5391 .53753 Mtetra
.666 .614 .787 r
.52992 .5381 .52483 .54159 .52959 .55166 .5346 .54298 Mtetra
.47 .352 .637 r
.52513 .52553 .52005 .52655 .52483 .54159 .52992 .5381 Mtetra
.496 .356 .62 r
.52037 .51204 .51532 .51393 .52005 .52655 .52513 .52553 Mtetra
.633 .493 .673 r
.51568 .5036 .51066 .50822 .51532 .51393 .52037 .51204 Mtetra
.887 .812 .77 r
.51104 .5028 .50601 .50997 .51066 .50822 .51568 .5036 Mtetra
.71 .894 .516 r
.50639 .50847 .50133 .51588 .50601 .50997 .51104 .5028 Mtetra
0 0 0 r
.50168 .51538 .49659 .51937 .50133 .51588 .50639 .50847 Mtetra
.381 0 0 r
.49693 .51567 .49186 .51381 .49659 .51937 .50168 .51538 Mtetra
0 .026 .579 r
.49221 .50429 .48719 .4978 .49186 .51381 .49693 .51567 Mtetra
.113 .064 .518 r
.48757 .48351 .48263 .47603 .48719 .4978 .49221 .50429 Mtetra
.229 .122 .519 r
.48302 .46013 .47814 .45452 .48263 .47603 .48757 .48351 Mtetra
.313 .187 .544 r
.47853 .43944 .47367 .4366 .47814 .45452 .48302 .46013 Mtetra
.39 .263 .584 r
.47405 .42323 .46919 .4228 .47367 .4366 .47853 .43944 Mtetra
.467 .347 .632 r
.46954 .41108 .46469 .41235 .46919 .4228 .47405 .42323 Mtetra
.536 .429 .68 r
.46502 .40188 .46015 .40424 .46469 .41235 .46954 .41108 Mtetra
.592 .5 .718 r
.46046 .39462 .4556 .39763 .46015 .40424 .46502 .40188 Mtetra
.633 .552 .746 r
.45589 .38856 .45102 .39197 .4556 .39763 .46046 .39462 Mtetra
.66 .587 .763 r
.4513 .38323 .44643 .38687 .45102 .39197 .45589 .38856 Mtetra
.676 .61 .774 r
.44669 .37832 .44182 .3821 .44643 .38687 .4513 .38323 Mtetra
.686 .624 .781 r
.44208 .37367 .4372 .37753 .44182 .3821 .44669 .37832 Mtetra
.692 .633 .785 r
.43745 .36917 .43257 .37308 .4372 .37753 .44208 .37367 Mtetra
.696 .638 .787 r
.43281 .36475 .42793 .3687 .43257 .37308 .43745 .36917 Mtetra
.698 .641 .789 r
.42816 .36038 .42328 .36435 .42793 .3687 .43281 .36475 Mtetra
.699 .643 .789 r
.4235 .35604 .41862 .36002 .42328 .36435 .42816 .36038 Mtetra
.7 .644 .79 r
.41884 .35171 .41396 .3557 .41862 .36002 .4235 .35604 Mtetra
.701 .645 .79 r
.41416 .34738 .40928 .35138 .41396 .3557 .41884 .35171 Mtetra
.40948 .34306 .4046 .34707 .40928 .35138 .41416 .34738 Mtetra
.701 .645 .791 r
.40479 .33873 .39991 .34274 .4046 .34707 .40948 .34306 Mtetra
.4001 .33439 .39521 .33842 .39991 .34274 .40479 .33873 Mtetra
.701 .646 .791 r
.39539 .33005 .39051 .33409 .39521 .33842 .4001 .33439 Mtetra
.39068 .32571 .3858 .32975 .39051 .33409 .39539 .33005 Mtetra
.38596 .32136 .38108 .3254 .3858 .32975 .39068 .32571 Mtetra
.38123 .317 .37635 .32105 .38108 .3254 .38596 .32136 Mtetra
.3765 .31263 .37161 .31669 .37635 .32105 .38123 .317 Mtetra
.37176 .30826 .36687 .31233 .37161 .31669 .3765 .31263 Mtetra
.367 .30388 .36212 .30795 .36687 .31233 .37176 .30826 Mtetra
.36224 .29949 .35736 .30357 .36212 .30795 .367 .30388 Mtetra
.35748 .2951 .35259 .29919 .35736 .30357 .36224 .29949 Mtetra
.3527 .2907 .34781 .29479 .35259 .29919 .35748 .2951 Mtetra
.34792 .28629 .34303 .29039 .34781 .29479 .3527 .2907 Mtetra
.34313 .28187 .33824 .28598 .34303 .29039 .34792 .28629 Mtetra
.33833 .27745 .33344 .28156 .33824 .28598 .34313 .28187 Mtetra
.33352 .27302 .32863 .27714 .33344 .28156 .33833 .27745 Mtetra
.32871 .26858 .32382 .27271 .32863 .27714 .33352 .27302 Mtetra
.32389 .26413 .319 .26827 .32382 .27271 .32871 .26858 Mtetra
.31906 .25968 .31417 .26382 .319 .26827 .32389 .26413 Mtetra
.31422 .25522 .30933 .25937 .31417 .26382 .31906 .25968 Mtetra
.30937 .25075 .30448 .25491 .30933 .25937 .31422 .25522 Mtetra
.30451 .24628 .29962 .25044 .30448 .25491 .30937 .25075 Mtetra
.29965 .24179 .29476 .24596 .29962 .25044 .30451 .24628 Mtetra
.29478 .2373 .28989 .24148 .29476 .24596 .29965 .24179 Mtetra
.2899 .23281 .28501 .23699 .28989 .24148 .29478 .2373 Mtetra
.28501 .2283 .28012 .23249 .28501 .23699 .2899 .23281 Mtetra
.28012 .22379 .27522 .22798 .28012 .23249 .28501 .2283 Mtetra
.27521 .21927 .27032 .22347 .27522 .22798 .28012 .22379 Mtetra
.2703 .21474 .26541 .21895 .27032 .22347 .27521 .21927 Mtetra
.72028 .62146 .71543 .62506 .71962 .62893 .72447 .62533 Mtetra
.71608 .61759 .71123 .62119 .71543 .62506 .72028 .62146 Mtetra
.71188 .6137 .70703 .61732 .71123 .62119 .71608 .61759 Mtetra
.70766 .60982 .70281 .61343 .70703 .61732 .71188 .6137 Mtetra
.70345 .60592 .69859 .60954 .70281 .61343 .70766 .60982 Mtetra
.69922 .60202 .69437 .60565 .69859 .60954 .70345 .60592 Mtetra
.69499 .59811 .69014 .60175 .69437 .60565 .69922 .60202 Mtetra
.69075 .5942 .6859 .59784 .69014 .60175 .69499 .59811 Mtetra
.68651 .59028 .68165 .59393 .6859 .59784 .69075 .5942 Mtetra
.68225 .58635 .6774 .59001 .68165 .59393 .68651 .59028 Mtetra
.678 .58242 .67314 .58608 .6774 .59001 .68225 .58635 Mtetra
.67373 .57848 .66887 .58215 .67314 .58608 .678 .58242 Mtetra
.66946 .57454 .6646 .57821 .66887 .58215 .67373 .57848 Mtetra
.66518 .57059 .66032 .57426 .6646 .57821 .66946 .57454 Mtetra
.6609 .56663 .65604 .57031 .66032 .57426 .66518 .57059 Mtetra
.6566 .56267 .65174 .56636 .65604 .57031 .6609 .56663 Mtetra
.65231 .5587 .64745 .56239 .65174 .56636 .6566 .56267 Mtetra
.648 .55473 .64314 .55842 .64745 .56239 .65231 .5587 Mtetra
.64369 .55075 .63883 .55445 .64314 .55842 .648 .55473 Mtetra
.63937 .54676 .63451 .55047 .63883 .55445 .64369 .55075 Mtetra
.63504 .54277 .63018 .54648 .63451 .55047 .63937 .54676 Mtetra
.702 .646 .791 r
.63071 .53877 .62585 .54249 .63018 .54648 .63504 .54277 Mtetra
.62637 .53477 .62151 .53849 .62585 .54249 .63071 .53877 Mtetra
.62203 .53076 .61716 .53449 .62151 .53849 .62637 .53477 Mtetra
.61767 .52675 .61281 .53049 .61716 .53449 .62203 .53076 Mtetra
.702 .647 .791 r
.61331 .52274 .60845 .52649 .61281 .53049 .61767 .52675 Mtetra
.703 .647 .791 r
.60895 .51873 .60408 .52249 .60845 .52649 .61331 .52274 Mtetra
.703 .648 .792 r
.60458 .51473 .59971 .51851 .60408 .52249 .60895 .51873 Mtetra
.705 .649 .792 r
.6002 .51075 .59533 .51455 .59971 .51851 .60458 .51473 Mtetra
.707 .652 .793 r
.59581 .5068 .59095 .51063 .59533 .51455 .6002 .51075 Mtetra
.71 .656 .794 r
.59143 .50292 .58656 .50679 .59095 .51063 .59581 .5068 Mtetra
.716 .662 .796 r
.58704 .49914 .58217 .50309 .58656 .50679 .59143 .50292 Mtetra
.726 .673 .799 r
.58265 .49555 .57778 .49962 .58217 .50309 .58704 .49914 Mtetra
.742 .692 .803 r
.57826 .49227 .5734 .49653 .57778 .49962 .58265 .49555 Mtetra
.77 .722 .808 r
.57388 .48948 .56902 .49408 .5734 .49653 .57826 .49227 Mtetra
.813 .771 .813 r
.56951 .48753 .56467 .49267 .56902 .49408 .57388 .48948 Mtetra
.877 .843 .808 r
.56517 .48689 .56034 .49292 .56467 .49267 .56951 .48753 Mtetra
.942 .923 .762 r
.56087 .48828 .55605 .49567 .56034 .49292 .56517 .48689 Mtetra
.943 .948 .628 r
.55661 .49255 .55182 .50189 .55605 .49567 .56087 .48828 Mtetra
.839 .871 .428 r
.5524 .50045 .54762 .5121 .55182 .50189 .55661 .49255 Mtetra
.704 .763 .267 r
.54821 .51173 .54341 .52527 .54762 .5121 .5524 .50045 Mtetra
0 0 0 r
.54397 .52401 .5391 .53753 .54341 .52527 .54821 .51173 Mtetra
.727 .828 .373 r
.53957 .5324 .5346 .54298 .5391 .53753 .54397 .52401 Mtetra
.88 .877 .828 r
.53497 .53212 .52992 .5381 .5346 .54298 .53957 .5324 Mtetra
.557 .446 .683 r
.53022 .52288 .52513 .52553 .52992 .5381 .53497 .53212 Mtetra
.512 .368 .622 r
.52544 .50971 .52037 .51204 .52513 .52553 .53022 .52288 Mtetra
.599 .442 .639 r
.52071 .49906 .51568 .5036 .52037 .51204 .52544 .50971 Mtetra
.802 .658 .704 r
.51606 .49522 .51104 .5028 .51568 .5036 .52071 .49906 Mtetra
.953 .95 .662 r
.51143 .49915 .50639 .50847 .51104 .5028 .51606 .49522 Mtetra
0 0 0 r
.50677 .50784 .50168 .51538 .50639 .50847 .51143 .49915 Mtetra
.15 0 0 r
.50204 .51397 .49693 .51567 .50168 .51538 .50677 .50784 Mtetra
.519 .009 0 r
.49728 .50939 .49221 .50429 .49693 .51567 .50204 .51397 Mtetra
0 0 .514 r
.49256 .49211 .48757 .48351 .49221 .50429 .49728 .50939 Mtetra
.146 .067 .502 r
.48795 .46799 .48302 .46013 .48757 .48351 .49256 .49211 Mtetra
.252 .136 .52 r
.48341 .4444 .47853 .43944 .48302 .46013 .48795 .46799 Mtetra
.338 .21 .556 r
.47891 .4252 .47405 .42323 .47853 .43944 .48341 .4444 Mtetra
.419 .295 .603 r
.47441 .41078 .46954 .41108 .47405 .42323 .47891 .4252 Mtetra
.497 .383 .654 r
.46989 .40009 .46502 .40188 .46954 .41108 .47441 .41078 Mtetra
.564 .464 .7 r
.46534 .39192 .46046 .39462 .46502 .40188 .46989 .40009 Mtetra
.614 .528 .733 r
.46077 .38533 .45589 .38856 .46046 .39462 .46534 .39192 Mtetra
.648 .572 .756 r
.45618 .37968 .4513 .38323 .45589 .38856 .46077 .38533 Mtetra
.669 .601 .77 r
.45158 .37459 .44669 .37832 .4513 .38323 .45618 .37968 Mtetra
.682 .619 .778 r
.44696 .36984 .44208 .37367 .44669 .37832 .45158 .37459 Mtetra
.69 .63 .783 r
.44233 .36527 .43745 .36917 .44208 .37367 .44696 .36984 Mtetra
.695 .636 .786 r
.43769 .36081 .43281 .36475 .43745 .36917 .44233 .36527 Mtetra
.697 .64 .788 r
.43305 .35642 .42816 .36038 .43281 .36475 .43769 .36081 Mtetra
.699 .642 .789 r
.42839 .35205 .4235 .35604 .42816 .36038 .43305 .35642 Mtetra
.7 .644 .79 r
.42373 .34771 .41884 .35171 .4235 .35604 .42839 .35205 Mtetra
.701 .644 .79 r
.41905 .34338 .41416 .34738 .41884 .35171 .42373 .34771 Mtetra
.701 .645 .79 r
.41437 .33904 .40948 .34306 .41416 .34738 .41905 .34338 Mtetra
.701 .645 .791 r
.40969 .3347 .40479 .33873 .40948 .34306 .41437 .33904 Mtetra
.40499 .33036 .4001 .33439 .40479 .33873 .40969 .3347 Mtetra
.701 .646 .791 r
.40029 .32602 .39539 .33005 .4001 .33439 .40499 .33036 Mtetra
.39557 .32166 .39068 .32571 .39539 .33005 .40029 .32602 Mtetra
.39085 .3173 .38596 .32136 .39068 .32571 .39557 .32166 Mtetra
.38613 .31294 .38123 .317 .38596 .32136 .39085 .3173 Mtetra
.38139 .30857 .3765 .31263 .38123 .317 .38613 .31294 Mtetra
.37665 .30419 .37176 .30826 .3765 .31263 .38139 .30857 Mtetra
.3719 .2998 .367 .30388 .37176 .30826 .37665 .30419 Mtetra
.36714 .29541 .36224 .29949 .367 .30388 .3719 .2998 Mtetra
.36237 .29101 .35748 .2951 .36224 .29949 .36714 .29541 Mtetra
.3576 .2866 .3527 .2907 .35748 .2951 .36237 .29101 Mtetra
.35282 .28218 .34792 .28629 .3527 .2907 .3576 .2866 Mtetra
.34803 .27776 .34313 .28187 .34792 .28629 .35282 .28218 Mtetra
.34323 .27333 .33833 .27745 .34313 .28187 .34803 .27776 Mtetra
.33842 .26889 .33352 .27302 .33833 .27745 .34323 .27333 Mtetra
.33361 .26445 .32871 .26858 .33352 .27302 .33842 .26889 Mtetra
.32878 .25999 .32389 .26413 .32871 .26858 .33361 .26445 Mtetra
.32395 .25553 .31906 .25968 .32389 .26413 .32878 .25999 Mtetra
.31911 .25107 .31422 .25522 .31906 .25968 .32395 .25553 Mtetra
.31427 .24659 .30937 .25075 .31422 .25522 .31911 .25107 Mtetra
.30941 .24211 .30451 .24628 .30937 .25075 .31427 .24659 Mtetra
.30455 .23762 .29965 .24179 .30451 .24628 .30941 .24211 Mtetra
.29968 .23312 .29478 .2373 .29965 .24179 .30455 .23762 Mtetra
.2948 .22862 .2899 .23281 .29478 .2373 .29968 .23312 Mtetra
.28991 .2241 .28501 .2283 .2899 .23281 .2948 .22862 Mtetra
.28502 .21958 .28012 .22379 .28501 .2283 .28991 .2241 Mtetra
.28011 .21506 .27521 .21927 .28012 .22379 .28502 .21958 Mtetra
.2752 .21052 .2703 .21474 .27521 .21927 .28011 .21506 Mtetra
.72514 .61786 .72028 .62146 .72447 .62533 .72933 .62174 Mtetra
.72094 .61398 .71608 .61759 .72028 .62146 .72514 .61786 Mtetra
.71673 .61009 .71188 .6137 .71608 .61759 .72094 .61398 Mtetra
.71252 .60619 .70766 .60982 .71188 .6137 .71673 .61009 Mtetra
.70831 .60229 .70345 .60592 .70766 .60982 .71252 .60619 Mtetra
.70408 .59839 .69922 .60202 .70345 .60592 .70831 .60229 Mtetra
.69985 .59447 .69499 .59811 .69922 .60202 .70408 .59839 Mtetra
.69561 .59055 .69075 .5942 .69499 .59811 .69985 .59447 Mtetra
.69137 .58663 .68651 .59028 .69075 .5942 .69561 .59055 Mtetra
.68712 .5827 .68225 .58635 .68651 .59028 .69137 .58663 Mtetra
.68286 .57876 .678 .58242 .68225 .58635 .68712 .5827 Mtetra
.6786 .57482 .67373 .57848 .678 .58242 .68286 .57876 Mtetra
.67432 .57087 .66946 .57454 .67373 .57848 .6786 .57482 Mtetra
.67005 .56691 .66518 .57059 .66946 .57454 .67432 .57087 Mtetra
.66576 .56295 .6609 .56663 .66518 .57059 .67005 .56691 Mtetra
.66147 .55898 .6566 .56267 .6609 .56663 .66576 .56295 Mtetra
.65717 .55501 .65231 .5587 .6566 .56267 .66147 .55898 Mtetra
.65287 .55103 .648 .55473 .65231 .5587 .65717 .55501 Mtetra
.64856 .54704 .64369 .55075 .648 .55473 .65287 .55103 Mtetra
.64424 .54305 .63937 .54676 .64369 .55075 .64856 .54704 Mtetra
.63991 .53905 .63504 .54277 .63937 .54676 .64424 .54305 Mtetra
.702 .646 .791 r
.63558 .53504 .63071 .53877 .63504 .54277 .63991 .53905 Mtetra
.63124 .53103 .62637 .53477 .63071 .53877 .63558 .53504 Mtetra
.6269 .52702 .62203 .53076 .62637 .53477 .63124 .53103 Mtetra
.62255 .523 .61767 .52675 .62203 .53076 .6269 .52702 Mtetra
.61819 .51898 .61331 .52274 .61767 .52675 .62255 .523 Mtetra
.702 .647 .791 r
.61382 .51496 .60895 .51873 .61331 .52274 .61819 .51898 Mtetra
.703 .648 .791 r
.60945 .51095 .60458 .51473 .60895 .51873 .61382 .51496 Mtetra
.704 .649 .792 r
.60507 .50695 .6002 .51075 .60458 .51473 .60945 .51095 Mtetra
.706 .651 .792 r
.60069 .50298 .59581 .5068 .6002 .51075 .60507 .50695 Mtetra
.709 .654 .793 r
.5963 .49906 .59143 .50292 .59581 .5068 .60069 .50298 Mtetra
.713 .659 .795 r
.59191 .49523 .58704 .49914 .59143 .50292 .5963 .49906 Mtetra
.721 .668 .797 r
.58752 .49154 .58265 .49555 .58704 .49914 .59191 .49523 Mtetra
.734 .683 .801 r
.58313 .4881 .57826 .49227 .58265 .49555 .58752 .49154 Mtetra
.756 .708 .807 r
.57874 .48506 .57388 .48948 .57826 .49227 .58313 .4881 Mtetra
.791 .748 .813 r
.57437 .48268 .56951 .48753 .57388 .48948 .57874 .48506 Mtetra
.845 .81 .816 r
.57001 .48137 .56517 .48689 .56951 .48753 .57437 .48268 Mtetra
.912 .892 .797 r
.5657 .4817 .56087 .48828 .56517 .48689 .57001 .48137 Mtetra
.951 .954 .71 r
.56142 .48444 .55661 .49255 .56087 .48828 .5657 .4817 Mtetra
.886 .921 .529 r
.5572 .49037 .5524 .50045 .55661 .49255 .56142 .48444 Mtetra
.747 .811 .337 r
.55301 .49971 .54821 .51173 .5524 .50045 .5572 .49037 Mtetra
0 0 0 r
.54881 .51117 .54397 .52401 .54821 .51173 .55301 .49971 Mtetra
.655 .764 .287 r
.54449 .52104 .53957 .5324 .54397 .52401 .54881 .51117 Mtetra
.913 .977 .701 r
.53999 .52439 .53497 .53212 .53957 .5324 .54449 .52104 Mtetra
.673 .583 .747 r
.53529 .51876 .53022 .52288 .53497 .53212 .53999 .52439 Mtetra
.536 .396 .637 r
.53051 .5069 .52544 .50971 .53022 .52288 .53529 .51876 Mtetra
.575 .412 .623 r
.52575 .49481 .52071 .49906 .52544 .50971 .53051 .5069 Mtetra
.723 .553 .659 r
.52107 .48784 .51606 .49522 .52071 .49906 .52575 .49481 Mtetra
.95 .824 .685 r
.51645 .48877 .51143 .49915 .51606 .49522 .52107 .48784 Mtetra
.779 .86 .417 r
.51183 .497 .50677 .50784 .51143 .49915 .51645 .48877 Mtetra
0 0 0 r
.50716 .50741 .50204 .51397 .50677 .50784 .51183 .497 Mtetra
.396 0 0 r
.5024 .51084 .49728 .50939 .50204 .51397 .50716 .50741 Mtetra
0 0 .486 r
.49763 .50029 .49256 .49211 .49728 .50939 .5024 .51084 Mtetra
.018 0 .485 r
.49293 .47788 .48795 .46799 .49256 .49211 .49763 .50029 Mtetra
.176 .078 .497 r
.48833 .45199 .48341 .4444 .48795 .46799 .49293 .47788 Mtetra
.276 .154 .527 r
.4838 .42928 .47891 .4252 .48341 .4444 .48833 .45199 Mtetra
.364 .237 .571 r
.47928 .41187 .47441 .41078 .47891 .4252 .4838 .42928 Mtetra
.449 .329 .624 r
.47476 .39914 .46989 .40009 .47441 .41078 .47928 .41187 Mtetra
.527 .42 .676 r
.47022 .3897 .46534 .39192 .46989 .40009 .47476 .39914 Mtetra
.588 .496 .717 r
.46565 .38235 .46077 .38533 .46534 .39192 .47022 .3897 Mtetra
.632 .551 .746 r
.46107 .37627 .45618 .37968 .46077 .38533 .46565 .38235 Mtetra
.66 .588 .764 r
.45647 .37094 .45158 .37459 .45618 .37968 .46107 .37627 Mtetra
.677 .611 .775 r
.45185 .36604 .44696 .36984 .45158 .37459 .45647 .37094 Mtetra
.687 .625 .781 r
.44723 .36139 .44233 .36527 .44696 .36984 .45185 .36604 Mtetra
.693 .634 .785 r
.44259 .35688 .43769 .36081 .44233 .36527 .44723 .36139 Mtetra
.696 .638 .787 r
.43794 .35245 .43305 .35642 .43769 .36081 .44259 .35688 Mtetra
.698 .641 .789 r
.43329 .34807 .42839 .35205 .43305 .35642 .43794 .35245 Mtetra
.7 .643 .79 r
.42862 .34371 .42373 .34771 .42839 .35205 .43329 .34807 Mtetra
.7 .644 .79 r
.42395 .33936 .41905 .34338 .42373 .34771 .42862 .34371 Mtetra
.701 .645 .79 r
.41927 .33502 .41437 .33904 .41905 .34338 .42395 .33936 Mtetra
.701 .645 .791 r
.41458 .33067 .40969 .3347 .41437 .33904 .41927 .33502 Mtetra
.40989 .32632 .40499 .33036 .40969 .3347 .41458 .33067 Mtetra
.701 .646 .791 r
.40518 .32197 .40029 .32602 .40499 .33036 .40989 .32632 Mtetra
.40047 .31761 .39557 .32166 .40029 .32602 .40518 .32197 Mtetra
.39575 .31325 .39085 .3173 .39557 .32166 .40047 .31761 Mtetra
.39103 .30887 .38613 .31294 .39085 .3173 .39575 .31325 Mtetra
.38629 .3045 .38139 .30857 .38613 .31294 .39103 .30887 Mtetra
.38155 .30011 .37665 .30419 .38139 .30857 .38629 .3045 Mtetra
.3768 .29571 .3719 .2998 .37665 .30419 .38155 .30011 Mtetra
.37204 .29131 .36714 .29541 .3719 .2998 .3768 .29571 Mtetra
.36728 .28691 .36237 .29101 .36714 .29541 .37204 .29131 Mtetra
.3625 .28249 .3576 .2866 .36237 .29101 .36728 .28691 Mtetra
.35772 .27807 .35282 .28218 .3576 .2866 .3625 .28249 Mtetra
.35293 .27364 .34803 .27776 .35282 .28218 .35772 .27807 Mtetra
.34813 .2692 .34323 .27333 .34803 .27776 .35293 .27364 Mtetra
.34332 .26476 .33842 .26889 .34323 .27333 .34813 .2692 Mtetra
.33851 .26031 .33361 .26445 .33842 .26889 .34332 .26476 Mtetra
.33369 .25585 .32878 .25999 .33361 .26445 .33851 .26031 Mtetra
.32886 .25138 .32395 .25553 .32878 .25999 .33369 .25585 Mtetra
.32402 .2469 .31911 .25107 .32395 .25553 .32886 .25138 Mtetra
.31917 .24242 .31427 .24659 .31911 .25107 .32402 .2469 Mtetra
.31432 .23793 .30941 .24211 .31427 .24659 .31917 .24242 Mtetra
.30946 .23344 .30455 .23762 .30941 .24211 .31432 .23793 Mtetra
.30459 .22893 .29968 .23312 .30455 .23762 .30946 .23344 Mtetra
.29971 .22442 .2948 .22862 .29968 .23312 .30459 .22893 Mtetra
.29482 .2199 .28991 .2241 .2948 .22862 .29971 .22442 Mtetra
.28993 .21537 .28502 .21958 .28991 .2241 .29482 .2199 Mtetra
.28502 .21084 .28011 .21506 .28502 .21958 .28993 .21537 Mtetra
.28011 .2063 .2752 .21052 .28011 .21506 .28502 .21084 Mtetra
.73 .61425 .72514 .61786 .72933 .62174 .73419 .61813 Mtetra
.7258 .61036 .72094 .61398 .72514 .61786 .73 .61425 Mtetra
.7216 .60647 .71673 .61009 .72094 .61398 .7258 .61036 Mtetra
.71739 .60257 .71252 .60619 .71673 .61009 .7216 .60647 Mtetra
.71317 .59866 .70831 .60229 .71252 .60619 .71739 .60257 Mtetra
.70895 .59475 .70408 .59839 .70831 .60229 .71317 .59866 Mtetra
.70472 .59083 .69985 .59447 .70408 .59839 .70895 .59475 Mtetra
.70048 .58691 .69561 .59055 .69985 .59447 .70472 .59083 Mtetra
.69624 .58297 .69137 .58663 .69561 .59055 .70048 .58691 Mtetra
.69199 .57904 .68712 .5827 .69137 .58663 .69624 .58297 Mtetra
.68773 .57509 .68286 .57876 .68712 .5827 .69199 .57904 Mtetra
.68347 .57114 .6786 .57482 .68286 .57876 .68773 .57509 Mtetra
.6792 .56719 .67432 .57087 .6786 .57482 .68347 .57114 Mtetra
.67492 .56323 .67005 .56691 .67432 .57087 .6792 .56719 Mtetra
.67064 .55926 .66576 .56295 .67005 .56691 .67492 .56323 Mtetra
.66635 .55528 .66147 .55898 .66576 .56295 .67064 .55926 Mtetra
.66205 .5513 .65717 .55501 .66147 .55898 .66635 .55528 Mtetra
.65774 .54732 .65287 .55103 .65717 .55501 .66205 .5513 Mtetra
.65343 .54333 .64856 .54704 .65287 .55103 .65774 .54732 Mtetra
.64912 .53933 .64424 .54305 .64856 .54704 .65343 .54333 Mtetra
.64479 .53532 .63991 .53905 .64424 .54305 .64912 .53933 Mtetra
.702 .646 .791 r
.64046 .53131 .63558 .53504 .63991 .53905 .64479 .53532 Mtetra
.63612 .52729 .63124 .53103 .63558 .53504 .64046 .53131 Mtetra
.63178 .52327 .6269 .52702 .63124 .53103 .63612 .52729 Mtetra
.62743 .51925 .62255 .523 .6269 .52702 .63178 .52327 Mtetra
.62307 .51522 .61819 .51898 .62255 .523 .62743 .51925 Mtetra
.702 .647 .791 r
.6187 .51119 .61382 .51496 .61819 .51898 .62307 .51522 Mtetra
.703 .647 .791 r
.61433 .50717 .60945 .51095 .61382 .51496 .6187 .51119 Mtetra
.704 .648 .792 r
.60995 .50316 .60507 .50695 .60945 .51095 .61433 .50717 Mtetra
.705 .65 .792 r
.60557 .49916 .60069 .50298 .60507 .50695 .60995 .50316 Mtetra
.707 .652 .793 r
.60118 .49521 .5963 .49906 .60069 .50298 .60557 .49916 Mtetra
.711 .657 .794 r
.59679 .49133 .59191 .49523 .5963 .49906 .60118 .49521 Mtetra
.717 .664 .796 r
.5924 .48756 .58752 .49154 .59191 .49523 .59679 .49133 Mtetra
.728 .676 .8 r
.588 .484 .58313 .4881 .58752 .49154 .5924 .48756 Mtetra
.745 .696 .805 r
.58361 .48076 .57874 .48506 .58313 .4881 .588 .484 Mtetra
.773 .729 .811 r
.57923 .47806 .57437 .48268 .57874 .48506 .58361 .48076 Mtetra
.818 .781 .818 r
.57487 .47622 .57001 .48137 .57437 .48268 .57923 .47806 Mtetra
.88 .857 .814 r
.57054 .47572 .5657 .4817 .57001 .48137 .57487 .47622 Mtetra
.939 .938 .767 r
.56625 .47724 .56142 .48444 .5657 .4817 .57054 .47572 Mtetra
.922 .955 .626 r
.56201 .48152 .5572 .49037 .56142 .48444 .56625 .47724 Mtetra
.797 .864 .421 r
.55782 .48906 .55301 .49971 .5572 .49037 .56201 .48152 Mtetra
.661 .756 .271 r
.55364 .49928 .54881 .51117 .55301 .49971 .55782 .48906 Mtetra
0 0 0 r
.54939 .50961 .54449 .52104 .54881 .51117 .55364 .49928 Mtetra
.796 .909 .511 r
.54497 .51558 .53999 .52439 .54449 .52104 .54939 .50961 Mtetra
.81 .769 .814 r
.54035 .51344 .53529 .51876 .53999 .52439 .54497 .51558 Mtetra
.571 .443 .666 r
.53559 .50367 .53051 .5069 .53529 .51876 .54035 .51344 Mtetra
.557 .397 .62 r
.5308 .49104 .52575 .49481 .53051 .5069 .53559 .50367 Mtetra
.658 .48 .632 r
.52608 .4813 .52107 .48784 .52575 .49481 .5308 .49104 Mtetra
.856 .681 .663 r
.52144 .47851 .51645 .48877 .52107 .48784 .52608 .4813 Mtetra
.982 .901 .572 r
.51685 .48414 .51183 .497 .51645 .48877 .52144 .47851 Mtetra
0 0 0 r
.51224 .49594 .50716 .50741 .51183 .497 .51685 .48414 Mtetra
.055 0 .033 r
.50755 .50644 .5024 .51084 .50716 .50741 .51224 .49594 Mtetra
.64 .085 0 r
.50277 .50536 .49763 .50029 .5024 .51084 .50755 .50644 Mtetra
0 0 .461 r
.49799 .48855 .49293 .47788 .49763 .50029 .50277 .50536 Mtetra
.069 .009 .474 r
.49331 .46234 .48833 .45199 .49293 .47788 .49799 .48855 Mtetra
.204 .094 .499 r
.48871 .43613 .4838 .42928 .48833 .45199 .49331 .46234 Mtetra
.302 .177 .538 r
.48417 .41497 .47928 .41187 .4838 .42928 .48871 .43613 Mtetra
.392 .268 .59 r
.47964 .39942 .47476 .39914 .47928 .41187 .48417 .41497 Mtetra
.479 .365 .646 r
.4751 .38818 .47022 .3897 .47476 .39914 .47964 .39942 Mtetra
.554 .454 .696 r
.47054 .37977 .46565 .38235 .47022 .3897 .4751 .38818 Mtetra
.61 .524 .732 r
.46596 .37308 .46107 .37627 .46565 .38235 .47054 .37977 Mtetra
.646 .571 .756 r
.46136 .3674 .45647 .37094 .46107 .37627 .46596 .37308 Mtetra
.669 .601 .77 r
.45675 .3623 .45185 .36604 .45647 .37094 .46136 .3674 Mtetra
.682 .619 .779 r
.45213 .35754 .44723 .36139 .45185 .36604 .45675 .3623 Mtetra
.69 .63 .784 r
.44749 .35296 .44259 .35688 .44723 .36139 .45213 .35754 Mtetra
.695 .636 .787 r
.44285 .3485 .43794 .35245 .44259 .35688 .44749 .35296 Mtetra
.698 .64 .788 r
.43819 .34409 .43329 .34807 .43794 .35245 .44285 .3485 Mtetra
.699 .642 .789 r
.43353 .33971 .42862 .34371 .43329 .34807 .43819 .34409 Mtetra
.7 .644 .79 r
.42886 .33535 .42395 .33936 .42862 .34371 .43353 .33971 Mtetra
.701 .645 .79 r
.42418 .33099 .41927 .33502 .42395 .33936 .42886 .33535 Mtetra
.41949 .32664 .41458 .33067 .41927 .33502 .42418 .33099 Mtetra
.701 .645 .791 r
.41479 .32228 .40989 .32632 .41458 .33067 .41949 .32664 Mtetra
.41009 .31792 .40518 .32197 .40989 .32632 .41479 .32228 Mtetra
.701 .646 .791 r
.40538 .31355 .40047 .31761 .40518 .32197 .41009 .31792 Mtetra
.40066 .30918 .39575 .31325 .40047 .31761 .40538 .31355 Mtetra
.39594 .3048 .39103 .30887 .39575 .31325 .40066 .30918 Mtetra
.3912 .30042 .38629 .3045 .39103 .30887 .39594 .3048 Mtetra
.38646 .29602 .38155 .30011 .38629 .3045 .3912 .30042 Mtetra
.38171 .29162 .3768 .29571 .38155 .30011 .38646 .29602 Mtetra
.37695 .28722 .37204 .29131 .3768 .29571 .38171 .29162 Mtetra
.37219 .2828 .36728 .28691 .37204 .29131 .37695 .28722 Mtetra
.36741 .27838 .3625 .28249 .36728 .28691 .37219 .2828 Mtetra
.36263 .27395 .35772 .27807 .3625 .28249 .36741 .27838 Mtetra
.35784 .26951 .35293 .27364 .35772 .27807 .36263 .27395 Mtetra
.35304 .26507 .34813 .2692 .35293 .27364 .35784 .26951 Mtetra
.34824 .26062 .34332 .26476 .34813 .2692 .35304 .26507 Mtetra
.34342 .25616 .33851 .26031 .34332 .26476 .34824 .26062 Mtetra
.3386 .25169 .33369 .25585 .33851 .26031 .34342 .25616 Mtetra
.33377 .24722 .32886 .25138 .33369 .25585 .3386 .25169 Mtetra
.32893 .24274 .32402 .2469 .32886 .25138 .33377 .24722 Mtetra
.32409 .23825 .31917 .24242 .32402 .2469 .32893 .24274 Mtetra
.31923 .23375 .31432 .23793 .31917 .24242 .32409 .23825 Mtetra
.31437 .22925 .30946 .23344 .31432 .23793 .31923 .23375 Mtetra
.3095 .22474 .30459 .22893 .30946 .23344 .31437 .22925 Mtetra
.30462 .22022 .29971 .22442 .30459 .22893 .3095 .22474 Mtetra
.29974 .21569 .29482 .2199 .29971 .22442 .30462 .22022 Mtetra
.29484 .21116 .28993 .21537 .29482 .2199 .29974 .21569 Mtetra
.28994 .20661 .28502 .21084 .28993 .21537 .29484 .21116 Mtetra
.28503 .20206 .28011 .2063 .28502 .21084 .28994 .20661 Mtetra
.73487 .61063 .73 .61425 .73419 .61813 .73906 .61452 Mtetra
.73067 .60674 .7258 .61036 .73 .61425 .73487 .61063 Mtetra
.72647 .60284 .7216 .60647 .7258 .61036 .73067 .60674 Mtetra
.72226 .59893 .71739 .60257 .7216 .60647 .72647 .60284 Mtetra
.71805 .59502 .71317 .59866 .71739 .60257 .72226 .59893 Mtetra
.71382 .5911 .70895 .59475 .71317 .59866 .71805 .59502 Mtetra
.70959 .58718 .70472 .59083 .70895 .59475 .71382 .5911 Mtetra
.70536 .58325 .70048 .58691 .70472 .59083 .70959 .58718 Mtetra
.70111 .57931 .69624 .58297 .70048 .58691 .70536 .58325 Mtetra
.69686 .57537 .69199 .57904 .69624 .58297 .70111 .57931 Mtetra
.69261 .57142 .68773 .57509 .69199 .57904 .69686 .57537 Mtetra
.68835 .56747 .68347 .57114 .68773 .57509 .69261 .57142 Mtetra
.68408 .56351 .6792 .56719 .68347 .57114 .68835 .56747 Mtetra
.6798 .55954 .67492 .56323 .6792 .56719 .68408 .56351 Mtetra
.67552 .55556 .67064 .55926 .67492 .56323 .6798 .55954 Mtetra
.67123 .55158 .66635 .55528 .67064 .55926 .67552 .55556 Mtetra
.66693 .5476 .66205 .5513 .66635 .55528 .67123 .55158 Mtetra
.66263 .5436 .65774 .54732 .66205 .5513 .66693 .5476 Mtetra
.65832 .53961 .65343 .54333 .65774 .54732 .66263 .5436 Mtetra
.654 .5356 .64912 .53933 .65343 .54333 .65832 .53961 Mtetra
.64968 .53159 .64479 .53532 .64912 .53933 .654 .5356 Mtetra
.64535 .52757 .64046 .53131 .64479 .53532 .64968 .53159 Mtetra
.702 .646 .791 r
.64101 .52355 .63612 .52729 .64046 .53131 .64535 .52757 Mtetra
.63666 .51952 .63178 .52327 .63612 .52729 .64101 .52355 Mtetra
.63231 .51549 .62743 .51925 .63178 .52327 .63666 .51952 Mtetra
.62796 .51146 .62307 .51522 .62743 .51925 .63231 .51549 Mtetra
.62359 .50742 .6187 .51119 .62307 .51522 .62796 .51146 Mtetra
.702 .647 .791 r
.61922 .50338 .61433 .50717 .6187 .51119 .62359 .50742 Mtetra
.703 .648 .791 r
.61484 .49936 .60995 .50316 .61433 .50717 .61922 .50338 Mtetra
.704 .649 .792 r
.61046 .49535 .60557 .49916 .60995 .50316 .61484 .49936 Mtetra
.706 .651 .793 r
.60607 .49137 .60118 .49521 .60557 .49916 .61046 .49535 Mtetra
.709 .655 .794 r
.60168 .48744 .59679 .49133 .60118 .49521 .60607 .49137 Mtetra
.714 .661 .796 r
.59728 .48362 .5924 .48756 .59679 .49133 .60168 .48744 Mtetra
.723 .671 .798 r
.59289 .47995 .588 .484 .5924 .48756 .59728 .48362 Mtetra
.737 .687 .803 r
.5885 .47655 .58361 .48076 .588 .484 .59289 .47995 Mtetra
.76 .714 .809 r
.58411 .47359 .57923 .47806 .58361 .48076 .5885 .47655 Mtetra
.796 .757 .817 r
.57974 .47133 .57487 .47622 .57923 .47806 .58411 .47359 Mtetra
.851 .823 .821 r
.5754 .47018 .57054 .47572 .57487 .47622 .57974 .47133 Mtetra
.916 .908 .8 r
.57109 .47071 .56625 .47724 .57054 .47572 .5754 .47018 Mtetra
.939 .965 .705 r
.56684 .47363 .56201 .48152 .56625 .47724 .57109 .47071 Mtetra
.849 .915 .515 r
.56263 .47954 .55782 .48906 .56201 .48152 .56684 .47363 Mtetra
.697 .797 .328 r
.55846 .48838 .55364 .49928 .55782 .48906 .56263 .47954 Mtetra
0 0 0 r
.55426 .49849 .54939 .50961 .55364 .49928 .55846 .48838 Mtetra
.678 .818 .375 r
.54993 .50617 .54497 .51558 .54939 .50961 .55426 .49849 Mtetra
.907 .947 .818 r
.54539 .50715 .54035 .51344 .54497 .51558 .54993 .50617 Mtetra
.625 .52 .715 r
.54067 .49999 .53559 .50367 .54035 .51344 .54539 .50715 Mtetra
.547 .396 .628 r
.53587 .48776 .5308 .49104 .53559 .50367 .54067 .49999 Mtetra
.604 .429 .618 r
.5311 .47598 .52608 .4813 .5308 .49104 .53587 .48776 Mtetra
.758 .569 .641 r
.52642 .46945 .52144 .47851 .52608 .4813 .5311 .47598 Mtetra
.963 .796 .628 r
.52183 .47106 .51685 .48414 .52144 .47851 .52642 .46945 Mtetra
.873 .853 .397 r
.51727 .48111 .51224 .49594 .51685 .48414 .52183 .47106 Mtetra
0 0 0 r
.51266 .49545 .50755 .50644 .51224 .49594 .51727 .48111 Mtetra
.258 0 .079 r
.50794 .50417 .50277 .50536 .50755 .50644 .51266 .49545 Mtetra
.68 .228 0 r
.50313 .49722 .49799 .48855 .50277 .50536 .50794 .50417 Mtetra
0 0 .447 r
.49836 .47466 .49331 .46234 .49799 .48855 .50313 .49722 Mtetra
.109 .027 .472 r
.49368 .44623 .48871 .43613 .49331 .46234 .49836 .47466 Mtetra
.23 .114 .506 r
.48909 .42082 .48417 .41497 .48871 .43613 .49368 .44623 Mtetra
.328 .203 .553 r
.48454 .40154 .47964 .39942 .48417 .41497 .48909 .42082 Mtetra
.422 .302 .61 r
.48 .38775 .4751 .38818 .47964 .39942 .48454 .40154 Mtetra
.509 .401 .667 r
.47544 .37779 .47054 .37977 .4751 .38818 .48 .38775 Mtetra
.579 .486 .713 r
.47086 .37021 .46596 .37308 .47054 .37977 .47544 .37779 Mtetra
.627 .547 .744 r
.46627 .36403 .46136 .3674 .46596 .37308 .47086 .37021 Mtetra
.658 .587 .764 r
.46166 .35865 .45675 .3623 .46136 .3674 .46627 .36403 Mtetra
.676 .611 .775 r
.45703 .35373 .45213 .35754 .45675 .3623 .46166 .35865 Mtetra
.687 .626 .782 r
.4524 .34907 .44749 .35296 .45213 .35754 .45703 .35373 Mtetra
.693 .634 .786 r
.44775 .34455 .44285 .3485 .44749 .35296 .4524 .34907 Mtetra
.696 .639 .788 r
.4431 .3401 .43819 .34409 .44285 .3485 .44775 .34455 Mtetra
.699 .642 .789 r
.43844 .3357 .43353 .33971 .43819 .34409 .4431 .3401 Mtetra
.7 .643 .79 r
.43377 .33133 .42886 .33535 .43353 .33971 .43844 .3357 Mtetra
.7 .644 .79 r
.42909 .32696 .42418 .33099 .42886 .33535 .43377 .33133 Mtetra
.701 .645 .79 r
.4244 .3226 .41949 .32664 .42418 .33099 .42909 .32696 Mtetra
.701 .645 .791 r
.41971 .31823 .41479 .32228 .41949 .32664 .4244 .3226 Mtetra
.41501 .31386 .41009 .31792 .41479 .32228 .41971 .31823 Mtetra
.701 .646 .791 r
.4103 .30949 .40538 .31355 .41009 .31792 .41501 .31386 Mtetra
.40558 .30511 .40066 .30918 .40538 .31355 .4103 .30949 Mtetra
.40085 .30072 .39594 .3048 .40066 .30918 .40558 .30511 Mtetra
.39612 .29633 .3912 .30042 .39594 .3048 .40085 .30072 Mtetra
.39138 .29193 .38646 .29602 .3912 .30042 .39612 .29633 Mtetra
.38663 .28752 .38171 .29162 .38646 .29602 .39138 .29193 Mtetra
.38187 .28311 .37695 .28722 .38171 .29162 .38663 .28752 Mtetra
.3771 .27869 .37219 .2828 .37695 .28722 .38187 .28311 Mtetra
.37233 .27426 .36741 .27838 .37219 .2828 .3771 .27869 Mtetra
.36755 .26982 .36263 .27395 .36741 .27838 .37233 .27426 Mtetra
.36276 .26538 .35784 .26951 .36263 .27395 .36755 .26982 Mtetra
.35796 .26093 .35304 .26507 .35784 .26951 .36276 .26538 Mtetra
.35316 .25647 .34824 .26062 .35304 .26507 .35796 .26093 Mtetra
.34834 .25201 .34342 .25616 .34824 .26062 .35316 .25647 Mtetra
.34352 .24753 .3386 .25169 .34342 .25616 .34834 .25201 Mtetra
.33869 .24305 .33377 .24722 .3386 .25169 .34352 .24753 Mtetra
.33386 .23856 .32893 .24274 .33377 .24722 .33869 .24305 Mtetra
.32901 .23407 .32409 .23825 .32893 .24274 .33386 .23856 Mtetra
.32416 .22956 .31923 .23375 .32409 .23825 .32901 .23407 Mtetra
.31929 .22505 .31437 .22925 .31923 .23375 .32416 .22956 Mtetra
.31442 .22053 .3095 .22474 .31437 .22925 .31929 .22505 Mtetra
.30955 .21601 .30462 .22022 .3095 .22474 .31442 .22053 Mtetra
.30466 .21147 .29974 .21569 .30462 .22022 .30955 .21601 Mtetra
.29976 .20693 .29484 .21116 .29974 .21569 .30466 .21147 Mtetra
.29486 .20238 .28994 .20661 .29484 .21116 .29976 .20693 Mtetra
.28995 .19783 .28503 .20206 .28994 .20661 .29486 .20238 Mtetra
.73975 .60701 .73487 .61063 .73906 .61452 .74394 .61091 Mtetra
.73555 .60311 .73067 .60674 .73487 .61063 .73975 .60701 Mtetra
.73135 .59921 .72647 .60284 .73067 .60674 .73555 .60311 Mtetra
.72714 .5953 .72226 .59893 .72647 .60284 .73135 .59921 Mtetra
.72293 .59138 .71805 .59502 .72226 .59893 .72714 .5953 Mtetra
.7187 .58746 .71382 .5911 .71805 .59502 .72293 .59138 Mtetra
.71447 .58353 .70959 .58718 .71382 .5911 .7187 .58746 Mtetra
.71024 .57959 .70536 .58325 .70959 .58718 .71447 .58353 Mtetra
.706 .57565 .70111 .57931 .70536 .58325 .71024 .57959 Mtetra
.70175 .5717 .69686 .57537 .70111 .57931 .706 .57565 Mtetra
.69749 .56774 .69261 .57142 .69686 .57537 .70175 .5717 Mtetra
.69323 .56378 .68835 .56747 .69261 .57142 .69749 .56774 Mtetra
.68896 .55982 .68408 .56351 .68835 .56747 .69323 .56378 Mtetra
.68469 .55584 .6798 .55954 .68408 .56351 .68896 .55982 Mtetra
.6804 .55186 .67552 .55556 .6798 .55954 .68469 .55584 Mtetra
.67612 .54788 .67123 .55158 .67552 .55556 .6804 .55186 Mtetra
.67182 .54388 .66693 .5476 .67123 .55158 .67612 .54788 Mtetra
.66752 .53989 .66263 .5436 .66693 .5476 .67182 .54388 Mtetra
.66321 .53588 .65832 .53961 .66263 .5436 .66752 .53989 Mtetra
.65889 .53187 .654 .5356 .65832 .53961 .66321 .53588 Mtetra
.65457 .52785 .64968 .53159 .654 .5356 .65889 .53187 Mtetra
.65024 .52383 .64535 .52757 .64968 .53159 .65457 .52785 Mtetra
.702 .646 .791 r
.6459 .5198 .64101 .52355 .64535 .52757 .65024 .52383 Mtetra
.64156 .51577 .63666 .51952 .64101 .52355 .6459 .5198 Mtetra
.63721 .51173 .63231 .51549 .63666 .51952 .64156 .51577 Mtetra
.63285 .50769 .62796 .51146 .63231 .51549 .63721 .51173 Mtetra
.62849 .50364 .62359 .50742 .62796 .51146 .63285 .50769 Mtetra
.702 .647 .791 r
.62412 .4996 .61922 .50338 .62359 .50742 .62849 .50364 Mtetra
.703 .647 .791 r
.61974 .49556 .61484 .49936 .61922 .50338 .62412 .4996 Mtetra
.704 .648 .792 r
.61536 .49153 .61046 .49535 .61484 .49936 .61974 .49556 Mtetra
.705 .65 .792 r
.61097 .48753 .60607 .49137 .61046 .49535 .61536 .49153 Mtetra
.708 .653 .793 r
.60658 .48357 .60168 .48744 .60607 .49137 .61097 .48753 Mtetra
.712 .658 .795 r
.60218 .47969 .59728 .48362 .60168 .48744 .60658 .48357 Mtetra
.719 .666 .797 r
.59778 .47594 .59289 .47995 .59728 .48362 .60218 .47969 Mtetra
.73 .68 .801 r
.59339 .47241 .5885 .47655 .59289 .47995 .59778 .47594 Mtetra
.749 .701 .807 r
.589 .46924 .58411 .47359 .5885 .47655 .59339 .47241 Mtetra
.779 .737 .814 r
.58462 .46665 .57974 .47133 .58411 .47359 .589 .46924 Mtetra
.826 .794 .822 r
.58027 .46497 .5754 .47018 .57974 .47133 .58462 .46665 Mtetra
.888 .874 .817 r
.57595 .4647 .57109 .47071 .5754 .47018 .58027 .46497 Mtetra
.937 .954 .762 r
.57168 .46648 .56684 .47363 .57109 .47071 .57595 .4647 Mtetra
.894 .953 .608 r
.56746 .47096 .56263 .47954 .56684 .47363 .57168 .46648 Mtetra
.747 .847 .402 r
.56329 .47839 .55846 .48838 .56263 .47954 .56746 .47096 Mtetra
0 0 0 r
.55912 .48786 .55426 .49849 .55846 .48838 .56329 .47839 Mtetra
.55486 .4965 .54993 .50617 .55426 .49849 .55912 .48786 Mtetra
.853 .978 .679 r
.55041 .50009 .54539 .50715 .54993 .50617 .55486 .4965 Mtetra
.709 .648 .787 r
.54575 .4958 .54067 .49999 .54539 .50715 .55041 .50009 Mtetra
.547 .412 .649 r
.54096 .48485 .53587 .48776 .54067 .49999 .54575 .4958 Mtetra
.561 .395 .614 r
.53615 .47193 .5311 .47598 .53587 .48776 .54096 .48485 Mtetra
.672 .485 .625 r
.53142 .46219 .52642 .46945 .5311 .47598 .53615 .47193 Mtetra
.864 .669 .637 r
.52679 .45936 .52183 .47106 .52642 .46945 .53142 .46219 Mtetra
.997 .858 .542 r
.52225 .46538 .51727 .48111 .52183 .47106 .52679 .45936 Mtetra
.702 .742 .233 r
.51771 .47938 .51266 .49545 .51727 .48111 .52225 .46538 Mtetra
0 0 .047 r
.51308 .49488 .50794 .50417 .51266 .49545 .51771 .47938 Mtetra
.478 .016 .077 r
.50833 .49994 .50313 .49722 .50794 .50417 .51308 .49488 Mtetra
0 0 .366 r
.5035 .48643 .49836 .47466 .50313 .49722 .50833 .49994 Mtetra
0 0 .444 r
.49872 .45929 .49368 .44623 .49836 .47466 .5035 .48643 Mtetra
.144 .046 .476 r
.49405 .43013 .48909 .42082 .49368 .44623 .49872 .45929 Mtetra
.257 .136 .517 r
.48946 .40626 .48454 .40154 .48909 .42082 .49405 .43013 Mtetra
.356 .232 .571 r
.4849 .38895 .48 .38775 .48454 .40154 .48946 .40626 Mtetra
.452 .337 .632 r
.48034 .37674 .47544 .37779 .48 .38775 .4849 .38895 Mtetra
.537 .436 .687 r
.47577 .36785 .47086 .37021 .47544 .37779 .48034 .37674 Mtetra
.6 .513 .728 r
.47117 .36093 .46627 .36403 .47086 .37021 .47577 .36785 Mtetra
.642 .566 .754 r
.46657 .35514 .46166 .35865 .46627 .36403 .47117 .36093 Mtetra
.667 .599 .77 r
.46195 .34999 .45703 .35373 .46166 .35865 .46657 .35514 Mtetra
.682 .619 .779 r
.45732 .3452 .4524 .34907 .45703 .35373 .46195 .34999 Mtetra
.69 .63 .784 r
.45267 .34061 .44775 .34455 .4524 .34907 .45732 .3452 Mtetra
.695 .637 .787 r
.44802 .33613 .4431 .3401 .44775 .34455 .45267 .34061 Mtetra
.698 .64 .788 r
.44336 .3317 .43844 .3357 .4431 .3401 .44802 .33613 Mtetra
.699 .643 .789 r
.43869 .32731 .43377 .33133 .43844 .3357 .44336 .3317 Mtetra
.7 .644 .79 r
.43401 .32293 .42909 .32696 .43377 .33133 .43869 .32731 Mtetra
.701 .645 .79 r
.42932 .31855 .4244 .3226 .42909 .32696 .43401 .32293 Mtetra
.42463 .31418 .41971 .31823 .4244 .3226 .42932 .31855 Mtetra
.701 .645 .791 r
.41993 .3098 .41501 .31386 .41971 .31823 .42463 .31418 Mtetra
.41522 .30542 .4103 .30949 .41501 .31386 .41993 .3098 Mtetra
.701 .646 .791 r
.4105 .30103 .40558 .30511 .4103 .30949 .41522 .30542 Mtetra
.40577 .29664 .40085 .30072 .40558 .30511 .4105 .30103 Mtetra
.40104 .29224 .39612 .29633 .40085 .30072 .40577 .29664 Mtetra
.3963 .28783 .39138 .29193 .39612 .29633 .40104 .29224 Mtetra
.39155 .28342 .38663 .28752 .39138 .29193 .3963 .28783 Mtetra
.38679 .279 .38187 .28311 .38663 .28752 .39155 .28342 Mtetra
.38203 .27457 .3771 .27869 .38187 .28311 .38679 .279 Mtetra
.37726 .27014 .37233 .27426 .3771 .27869 .38203 .27457 Mtetra
.37247 .26569 .36755 .26982 .37233 .27426 .37726 .27014 Mtetra
.36769 .26124 .36276 .26538 .36755 .26982 .37247 .26569 Mtetra
.36289 .25678 .35796 .26093 .36276 .26538 .36769 .26124 Mtetra
.35808 .25232 .35316 .25647 .35796 .26093 .36289 .25678 Mtetra
.35327 .24785 .34834 .25201 .35316 .25647 .35808 .25232 Mtetra
.34845 .24337 .34352 .24753 .34834 .25201 .35327 .24785 Mtetra
.34362 .23888 .33869 .24305 .34352 .24753 .34845 .24337 Mtetra
.33878 .23438 .33386 .23856 .33869 .24305 .34362 .23888 Mtetra
.33394 .22988 .32901 .23407 .33386 .23856 .33878 .23438 Mtetra
.32909 .22537 .32416 .22956 .32901 .23407 .33394 .22988 Mtetra
.32422 .22085 .31929 .22505 .32416 .22956 .32909 .22537 Mtetra
.31935 .21633 .31442 .22053 .31929 .22505 .32422 .22085 Mtetra
.31448 .21179 .30955 .21601 .31442 .22053 .31935 .21633 Mtetra
.30959 .20725 .30466 .21147 .30955 .21601 .31448 .21179 Mtetra
.3047 .2027 .29976 .20693 .30466 .21147 .30959 .20725 Mtetra
.29979 .19815 .29486 .20238 .29976 .20693 .3047 .2027 Mtetra
.29488 .19358 .28995 .19783 .29486 .20238 .29979 .19815 Mtetra
.74463 .60339 .73975 .60701 .74394 .61091 .74882 .60729 Mtetra
.74044 .59948 .73555 .60311 .73975 .60701 .74463 .60339 Mtetra
.73624 .59557 .73135 .59921 .73555 .60311 .74044 .59948 Mtetra
.73203 .59165 .72714 .5953 .73135 .59921 .73624 .59557 Mtetra
.72781 .58773 .72293 .59138 .72714 .5953 .73203 .59165 Mtetra
.72359 .5838 .7187 .58746 .72293 .59138 .72781 .58773 Mtetra
.71936 .57987 .71447 .58353 .7187 .58746 .72359 .5838 Mtetra
.71513 .57592 .71024 .57959 .71447 .58353 .71936 .57987 Mtetra
.71089 .57198 .706 .57565 .71024 .57959 .71513 .57592 Mtetra
.70664 .56802 .70175 .5717 .706 .57565 .71089 .57198 Mtetra
.70239 .56406 .69749 .56774 .70175 .5717 .70664 .56802 Mtetra
.69812 .56009 .69323 .56378 .69749 .56774 .70239 .56406 Mtetra
.69386 .55612 .68896 .55982 .69323 .56378 .69812 .56009 Mtetra
.68958 .55214 .68469 .55584 .68896 .55982 .69386 .55612 Mtetra
.6853 .54816 .6804 .55186 .68469 .55584 .68958 .55214 Mtetra
.68101 .54416 .67612 .54788 .6804 .55186 .6853 .54816 Mtetra
.67672 .54017 .67182 .54388 .67612 .54788 .68101 .54416 Mtetra
.67241 .53616 .66752 .53989 .67182 .54388 .67672 .54017 Mtetra
.66811 .53215 .66321 .53588 .66752 .53989 .67241 .53616 Mtetra
.66379 .52813 .65889 .53187 .66321 .53588 .66811 .53215 Mtetra
.65947 .52411 .65457 .52785 .65889 .53187 .66379 .52813 Mtetra
.65514 .52008 .65024 .52383 .65457 .52785 .65947 .52411 Mtetra
.6508 .51605 .6459 .5198 .65024 .52383 .65514 .52008 Mtetra
.702 .646 .791 r
.64646 .51201 .64156 .51577 .6459 .5198 .6508 .51605 Mtetra
.64211 .50796 .63721 .51173 .64156 .51577 .64646 .51201 Mtetra
.63775 .50391 .63285 .50769 .63721 .51173 .64211 .50796 Mtetra
.63339 .49986 .62849 .50364 .63285 .50769 .63775 .50391 Mtetra
.702 .647 .791 r
.62902 .49581 .62412 .4996 .62849 .50364 .63339 .49986 Mtetra
.703 .647 .791 r
.62464 .49175 .61974 .49556 .62412 .4996 .62902 .49581 Mtetra
.703 .648 .792 r
.62026 .48771 .61536 .49153 .61974 .49556 .62464 .49175 Mtetra
.705 .649 .792 r
.61587 .48369 .61097 .48753 .61536 .49153 .62026 .48771 Mtetra
.707 .652 .793 r
.61148 .47971 .60658 .48357 .61097 .48753 .61587 .48369 Mtetra
.71 .656 .794 r
.60708 .47578 .60218 .47969 .60658 .48357 .61148 .47971 Mtetra
.716 .663 .796 r
.60269 .47197 .59778 .47594 .60218 .47969 .60708 .47578 Mtetra
.725 .674 .799 r
.59829 .46833 .59339 .47241 .59778 .47594 .60269 .47197 Mtetra
.74 .692 .804 r
.59389 .46498 .589 .46924 .59339 .47241 .59829 .46833 Mtetra
.765 .721 .812 r
.58951 .46212 .58462 .46665 .589 .46924 .59389 .46498 Mtetra
.804 .768 .82 r
.58515 .46001 .58027 .46497 .58462 .46665 .58951 .46212 Mtetra
.86 .84 .824 r
.58081 .45908 .57595 .4647 .58027 .46497 .58515 .46001 Mtetra
.921 .927 .798 r
.57653 .45991 .57168 .46648 .57595 .4647 .58081 .45908 Mtetra
.923 .971 .688 r
.57229 .46314 .56746 .47096 .57168 .46648 .57653 .45991 Mtetra
.804 .899 .488 r
.56812 .46921 .56329 .47839 .56746 .47096 .57229 .46314 Mtetra
.646 .776 .313 r
.56397 .47777 .55912 .48786 .56329 .47839 .56812 .46921 Mtetra
0 0 0 r
.55976 .48676 .55486 .4965 .55912 .48786 .56397 .47777 Mtetra
.713 .885 .494 r
.55541 .49239 .55041 .50009 .55486 .4965 .55976 .48676 Mtetra
.817 .833 .861 r
.55082 .49099 .54575 .4958 .55041 .50009 .55541 .49239 Mtetra
.565 .454 .687 r
.54606 .48204 .54096 .48485 .54575 .4958 .55082 .49099 Mtetra
.529 .377 .618 r
.54122 .46898 .53615 .47193 .54096 .48485 .54606 .48204 Mtetra
.6 .423 .614 r
.53644 .45687 .53142 .46219 .53615 .47193 .54122 .46898 Mtetra
.755 .559 .631 r
.53176 .44994 .52679 .45936 .53142 .46219 .53644 .45687 Mtetra
.952 .761 .608 r
.52719 .45102 .52225 .46538 .52679 .45936 .53176 .44994 Mtetra
.948 .85 .422 r
.52268 .46134 .51771 .47938 .52225 .46538 .52719 .45102 Mtetra
0 0 0 r
.51815 .47854 .51308 .49488 .51771 .47938 .52268 .46134 Mtetra
.051 0 .111 r
.51351 .49356 .50833 .49994 .51308 .49488 .51815 .47854 Mtetra
.702 .189 .005 r
.50871 .49332 .5035 .48643 .50833 .49994 .51351 .49356 Mtetra
0 0 .391 r
.50386 .47335 .49872 .45929 .5035 .48643 .50871 .49332 Mtetra
.024 0 .445 r
.49908 .44312 .49405 .43013 .49872 .45929 .50386 .47335 Mtetra
.175 .067 .482 r
.49442 .41446 .48946 .40626 .49405 .43013 .49908 .44312 Mtetra
.283 .16 .53 r
.48983 .39254 .4849 .38895 .48946 .40626 .49442 .41446 Mtetra
.385 .264 .59 r
.48525 .37711 .48034 .37674 .4849 .38895 .48983 .39254 Mtetra
.482 .372 .653 r
.48068 .36627 .47577 .36785 .48034 .37674 .48525 .37711 Mtetra
.562 .467 .705 r
.47609 .35825 .47117 .36093 .47577 .36785 .48068 .36627 Mtetra
.618 .537 .74 r
.47149 .35185 .46657 .35514 .47117 .36093 .47609 .35825 Mtetra
.654 .582 .762 r
.46687 .34637 .46195 .34999 .46657 .35514 .47149 .35185 Mtetra
.674 .609 .775 r
.46224 .3414 .45732 .3452 .46195 .34999 .46687 .34637 Mtetra
.686 .625 .782 r
.4576 .3367 .45267 .34061 .45732 .3452 .46224 .3414 Mtetra
.693 .634 .786 r
.45295 .33216 .44802 .33613 .45267 .34061 .4576 .3367 Mtetra
.696 .639 .788 r
.44828 .3277 .44336 .3317 .44802 .33613 .45295 .33216 Mtetra
.699 .642 .789 r
.44362 .32328 .43869 .32731 .44336 .3317 .44828 .3277 Mtetra
.7 .643 .79 r
.43894 .31889 .43401 .32293 .43869 .32731 .44362 .32328 Mtetra
.7 .644 .79 r
.43425 .3145 .42932 .31855 .43401 .32293 .43894 .31889 Mtetra
.701 .645 .79 r
.42956 .31012 .42463 .31418 .42932 .31855 .43425 .3145 Mtetra
.701 .645 .791 r
.42486 .30573 .41993 .3098 .42463 .31418 .42956 .31012 Mtetra
.42015 .30135 .41522 .30542 .41993 .3098 .42486 .30573 Mtetra
.701 .646 .791 r
.41543 .29695 .4105 .30103 .41522 .30542 .42015 .30135 Mtetra
.41071 .29255 .40577 .29664 .4105 .30103 .41543 .29695 Mtetra
.40597 .28814 .40104 .29224 .40577 .29664 .41071 .29255 Mtetra
.40123 .28373 .3963 .28783 .40104 .29224 .40597 .28814 Mtetra
.39648 .27931 .39155 .28342 .3963 .28783 .40123 .28373 Mtetra
.39173 .27488 .38679 .279 .39155 .28342 .39648 .27931 Mtetra
.38696 .27045 .38203 .27457 .38679 .279 .39173 .27488 Mtetra
.38219 .266 .37726 .27014 .38203 .27457 .38696 .27045 Mtetra
.37741 .26155 .37247 .26569 .37726 .27014 .38219 .266 Mtetra
.37262 .2571 .36769 .26124 .37247 .26569 .37741 .26155 Mtetra
.36782 .25263 .36289 .25678 .36769 .26124 .37262 .2571 Mtetra
.36302 .24816 .35808 .25232 .36289 .25678 .36782 .25263 Mtetra
.35821 .24368 .35327 .24785 .35808 .25232 .36302 .24816 Mtetra
.35339 .23919 .34845 .24337 .35327 .24785 .35821 .24368 Mtetra
.34856 .2347 .34362 .23888 .34845 .24337 .35339 .23919 Mtetra
.34372 .2302 .33878 .23438 .34362 .23888 .34856 .2347 Mtetra
.33888 .22569 .33394 .22988 .33878 .23438 .34372 .2302 Mtetra
.33402 .22117 .32909 .22537 .33394 .22988 .33888 .22569 Mtetra
.32916 .21664 .32422 .22085 .32909 .22537 .33402 .22117 Mtetra
.32429 .21211 .31935 .21633 .32422 .22085 .32916 .21664 Mtetra
.31941 .20757 .31448 .21179 .31935 .21633 .32429 .21211 Mtetra
.31453 .20302 .30959 .20725 .31448 .21179 .31941 .20757 Mtetra
.30963 .19847 .3047 .2027 .30959 .20725 .31453 .20302 Mtetra
.30473 .1939 .29979 .19815 .3047 .2027 .30963 .19847 Mtetra
.29982 .18933 .29488 .19358 .29979 .19815 .30473 .1939 Mtetra
.74952 .59976 .74463 .60339 .74882 .60729 .75371 .60366 Mtetra
.74533 .59585 .74044 .59948 .74463 .60339 .74952 .59976 Mtetra
.74113 .59193 .73624 .59557 .74044 .59948 .74533 .59585 Mtetra
.73692 .58801 .73203 .59165 .73624 .59557 .74113 .59193 Mtetra
.73271 .58408 .72781 .58773 .73203 .59165 .73692 .58801 Mtetra
.72849 .58014 .72359 .5838 .72781 .58773 .73271 .58408 Mtetra
.72426 .5762 .71936 .57987 .72359 .5838 .72849 .58014 Mtetra
.72003 .57225 .71513 .57592 .71936 .57987 .72426 .5762 Mtetra
.71579 .5683 .71089 .57198 .71513 .57592 .72003 .57225 Mtetra
.71154 .56434 .70664 .56802 .71089 .57198 .71579 .5683 Mtetra
.70728 .56037 .70239 .56406 .70664 .56802 .71154 .56434 Mtetra
.70302 .5564 .69812 .56009 .70239 .56406 .70728 .56037 Mtetra
.69876 .55242 .69386 .55612 .69812 .56009 .70302 .5564 Mtetra
.69448 .54844 .68958 .55214 .69386 .55612 .69876 .55242 Mtetra
.6902 .54444 .6853 .54816 .68958 .55214 .69448 .54844 Mtetra
.68591 .54045 .68101 .54416 .6853 .54816 .6902 .54444 Mtetra
.68162 .53644 .67672 .54017 .68101 .54416 .68591 .54045 Mtetra
.67732 .53243 .67241 .53616 .67672 .54017 .68162 .53644 Mtetra
.67301 .52842 .66811 .53215 .67241 .53616 .67732 .53243 Mtetra
.6687 .52439 .66379 .52813 .66811 .53215 .67301 .52842 Mtetra
.66437 .52036 .65947 .52411 .66379 .52813 .6687 .52439 Mtetra
.66005 .51633 .65514 .52008 .65947 .52411 .66437 .52036 Mtetra
.65571 .51229 .6508 .51605 .65514 .52008 .66005 .51633 Mtetra
.702 .646 .791 r
.65137 .50824 .64646 .51201 .6508 .51605 .65571 .51229 Mtetra
.64702 .50419 .64211 .50796 .64646 .51201 .65137 .50824 Mtetra
.64266 .50013 .63775 .50391 .64211 .50796 .64702 .50419 Mtetra
.6383 .49607 .63339 .49986 .63775 .50391 .64266 .50013 Mtetra
.63393 .49201 .62902 .49581 .63339 .49986 .6383 .49607 Mtetra
.702 .647 .791 r
.62956 .48795 .62464 .49175 .62902 .49581 .63393 .49201 Mtetra
.703 .648 .791 r
.62517 .48389 .62026 .48771 .62464 .49175 .62956 .48795 Mtetra
.704 .649 .792 r
.62079 .47986 .61587 .48369 .62026 .48771 .62517 .48389 Mtetra
.706 .651 .793 r
.61639 .47584 .61148 .47971 .61587 .48369 .62079 .47986 Mtetra
.709 .654 .794 r
.612 .47188 .60708 .47578 .61148 .47971 .61639 .47584 Mtetra
.713 .66 .795 r
.6076 .46801 .60269 .47197 .60708 .47578 .612 .47188 Mtetra
.721 .669 .798 r
.60319 .46428 .59829 .46833 .60269 .47197 .6076 .46801 Mtetra
.733 .684 .802 r
.5988 .4608 .59389 .46498 .59829 .46833 .60319 .46428 Mtetra
.754 .708 .809 r
.59441 .45771 .58951 .46212 .59389 .46498 .5988 .4608 Mtetra
.786 .747 .817 r
.59004 .45525 .58515 .46001 .58951 .46212 .59441 .45771 Mtetra
.835 .809 .825 r
.58569 .45378 .58081 .45908 .58515 .46001 .59004 .45525 Mtetra
.897 .893 .817 r
.58139 .4538 .57653 .45991 .58081 .45908 .58569 .45378 Mtetra
.932 .967 .749 r
.57714 .45594 .57229 .46314 .57653 .45991 .58139 .4538 Mtetra
.858 .943 .577 r
.57295 .46075 .56812 .46921 .57229 .46314 .57714 .45594 Mtetra
.695 .822 .375 r
.56881 .46823 .56397 .47777 .56812 .46921 .57295 .46075 Mtetra
0 0 0 r
.56465 .47709 .55976 .48676 .56397 .47777 .56881 .46823 Mtetra
.606 .793 .366 r
.56037 .48417 .55541 .49239 .55976 .48676 .56465 .47709 Mtetra
.866 .987 .838 r
.55588 .48548 .55082 .49099 .55541 .49239 .56037 .48417 Mtetra
.61 .538 .748 r
.55117 .47903 .54606 .48204 .55082 .49099 .55588 .48548 Mtetra
.511 .376 .633 r
.54633 .46675 .54122 .46898 .54606 .48204 .55117 .47903 Mtetra
.543 .379 .609 r
.54149 .45324 .53644 .45687 .54122 .46898 .54633 .46675 Mtetra
.658 .472 .621 r
.53675 .443 .53176 .44994 .53644 .45687 .54149 .45324 Mtetra
.846 .644 .63 r
.53212 .4393 .52719 .45102 .53176 .44994 .53675 .443 Mtetra
.997 .822 .547 r
.5276 .44436 .52268 .46134 .52719 .45102 .53212 .4393 Mtetra
.845 .794 .298 r
.52313 .4587 .51815 .47854 .52268 .46134 .5276 .44436 Mtetra
0 0 0 r
.51861 .47811 .51351 .49356 .51815 .47854 .52313 .4587 Mtetra
.233 0 .149 r
.51393 .49084 .50871 .49332 .51351 .49356 .51861 .47811 Mtetra
.785 .321 0 r
.50908 .48414 .50386 .47335 .50871 .49332 .51393 .49084 Mtetra
0 0 .404 r
.50421 .45851 .49908 .44312 .50386 .47335 .50908 .48414 Mtetra
.07 0 .45 r
.49945 .42674 .49442 .41446 .49908 .44312 .50421 .45851 Mtetra
.204 .089 .492 r
.49479 .39947 .48983 .39254 .49442 .41446 .49945 .42674 Mtetra
.311 .188 .546 r
.49019 .37963 .48525 .37711 .48983 .39254 .49479 .39947 Mtetra
.415 .298 .611 r
.4856 .36592 .48068 .36627 .48525 .37711 .49019 .37963 Mtetra
.511 .407 .673 r
.48101 .35623 .47609 .35825 .48068 .36627 .4856 .36592 Mtetra
.585 .496 .72 r
.47641 .34891 .47149 .35185 .47609 .35825 .48101 .35623 Mtetra
.634 .557 .751 r
.4718 .34293 .46687 .34637 .47149 .35185 .47641 .34891 Mtetra
.663 .595 .768 r
.46717 .33768 .46224 .3414 .46687 .34637 .4718 .34293 Mtetra
.68 .617 .778 r
.46253 .33284 .4576 .3367 .46224 .3414 .46717 .33768 Mtetra
.69 .629 .784 r
.45788 .32822 .45295 .33216 .4576 .3367 .46253 .33284 Mtetra
.695 .637 .787 r
.45322 .32371 .44828 .3277 .45295 .33216 .45788 .32822 Mtetra
.698 .64 .788 r
.44855 .31926 .44362 .32328 .44828 .3277 .45322 .32371 Mtetra
.699 .643 .789 r
.44387 .31485 .43894 .31889 .44362 .32328 .44855 .31926 Mtetra
.7 .644 .79 r
.43919 .31045 .43425 .3145 .43894 .31889 .44387 .31485 Mtetra
.701 .645 .79 r
.4345 .30606 .42956 .31012 .43425 .3145 .43919 .31045 Mtetra
.701 .645 .791 r
.42979 .30166 .42486 .30573 .42956 .31012 .4345 .30606 Mtetra
.42509 .29726 .42015 .30135 .42486 .30573 .42979 .30166 Mtetra
.701 .646 .791 r
.42037 .29286 .41543 .29695 .42015 .30135 .42509 .29726 Mtetra
.41564 .28846 .41071 .29255 .41543 .29695 .42037 .29286 Mtetra
.41091 .28404 .40597 .28814 .41071 .29255 .41564 .28846 Mtetra
.40617 .27962 .40123 .28373 .40597 .28814 .41091 .28404 Mtetra
.40142 .27519 .39648 .27931 .40123 .28373 .40617 .27962 Mtetra
.39667 .27076 .39173 .27488 .39648 .27931 .40142 .27519 Mtetra
.3919 .26632 .38696 .27045 .39173 .27488 .39667 .27076 Mtetra
.38713 .26187 .38219 .266 .38696 .27045 .3919 .26632 Mtetra
.38235 .25741 .37741 .26155 .38219 .266 .38713 .26187 Mtetra
.37756 .25294 .37262 .2571 .37741 .26155 .38235 .25741 Mtetra
.37277 .24847 .36782 .25263 .37262 .2571 .37756 .25294 Mtetra
.36796 .24399 .36302 .24816 .36782 .25263 .37277 .24847 Mtetra
.36315 .23951 .35821 .24368 .36302 .24816 .36796 .24399 Mtetra
.35833 .23501 .35339 .23919 .35821 .24368 .36315 .23951 Mtetra
.3535 .23051 .34856 .2347 .35339 .23919 .35833 .23501 Mtetra
.34866 .226 .34372 .2302 .34856 .2347 .3535 .23051 Mtetra
.34382 .22148 .33888 .22569 .34372 .2302 .34866 .226 Mtetra
.33897 .21696 .33402 .22117 .33888 .22569 .34382 .22148 Mtetra
.33411 .21243 .32916 .21664 .33402 .22117 .33897 .21696 Mtetra
.32924 .20789 .32429 .21211 .32916 .21664 .33411 .21243 Mtetra
.32436 .20334 .31941 .20757 .32429 .21211 .32924 .20789 Mtetra
.31947 .19879 .31453 .20302 .31941 .20757 .32436 .20334 Mtetra
.31458 .19422 .30963 .19847 .31453 .20302 .31947 .19879 Mtetra
.30968 .18965 .30473 .1939 .30963 .19847 .31458 .19422 Mtetra
.30477 .18507 .29982 .18933 .30473 .1939 .30968 .18965 Mtetra
.75442 .59612 .74952 .59976 .75371 .60366 .75861 .60003 Mtetra
.75023 .5922 .74533 .59585 .74952 .59976 .75442 .59612 Mtetra
.74603 .58828 .74113 .59193 .74533 .59585 .75023 .5922 Mtetra
.74182 .58435 .73692 .58801 .74113 .59193 .74603 .58828 Mtetra
.73761 .58042 .73271 .58408 .73692 .58801 .74182 .58435 Mtetra
.73339 .57648 .72849 .58014 .73271 .58408 .73761 .58042 Mtetra
.72916 .57253 .72426 .5762 .72849 .58014 .73339 .57648 Mtetra
.72493 .56858 .72003 .57225 .72426 .5762 .72916 .57253 Mtetra
.72069 .56462 .71579 .5683 .72003 .57225 .72493 .56858 Mtetra
.71644 .56065 .71154 .56434 .71579 .5683 .72069 .56462 Mtetra
.71219 .55668 .70728 .56037 .71154 .56434 .71644 .56065 Mtetra
.70793 .5527 .70302 .5564 .70728 .56037 .71219 .55668 Mtetra
.70366 .54872 .69876 .55242 .70302 .5564 .70793 .5527 Mtetra
.69939 .54472 .69448 .54844 .69876 .55242 .70366 .54872 Mtetra
.69511 .54073 .6902 .54444 .69448 .54844 .69939 .54472 Mtetra
.69082 .53672 .68591 .54045 .6902 .54444 .69511 .54073 Mtetra
.68653 .53271 .68162 .53644 .68591 .54045 .69082 .53672 Mtetra
.68223 .5287 .67732 .53243 .68162 .53644 .68653 .53271 Mtetra
.67792 .52468 .67301 .52842 .67732 .53243 .68223 .5287 Mtetra
.67361 .52065 .6687 .52439 .67301 .52842 .67792 .52468 Mtetra
.66929 .51661 .66437 .52036 .6687 .52439 .67361 .52065 Mtetra
.66496 .51257 .66005 .51633 .66437 .52036 .66929 .51661 Mtetra
.66063 .50852 .65571 .51229 .66005 .51633 .66496 .51257 Mtetra
.702 .646 .791 r
.65628 .50447 .65137 .50824 .65571 .51229 .66063 .50852 Mtetra
.65194 .50041 .64702 .50419 .65137 .50824 .65628 .50447 Mtetra
.64758 .49635 .64266 .50013 .64702 .50419 .65194 .50041 Mtetra
.64322 .49228 .6383 .49607 .64266 .50013 .64758 .49635 Mtetra
.63885 .48821 .63393 .49201 .6383 .49607 .64322 .49228 Mtetra
.702 .647 .791 r
.63448 .48414 .62956 .48795 .63393 .49201 .63885 .48821 Mtetra
.703 .647 .791 r
.63009 .48007 .62517 .48389 .62956 .48795 .63448 .48414 Mtetra
.704 .648 .792 r
.62571 .47602 .62079 .47986 .62517 .48389 .63009 .48007 Mtetra
.705 .65 .792 r
.62131 .47199 .61639 .47584 .62079 .47986 .62571 .47602 Mtetra
.707 .653 .793 r
.61691 .46799 .612 .47188 .61639 .47584 .62131 .47199 Mtetra
.711 .657 .795 r
.61251 .46407 .6076 .46801 .612 .47188 .61691 .46799 Mtetra
.717 .665 .797 r
.60811 .46027 .60319 .46428 .6076 .46801 .61251 .46407 Mtetra
.728 .677 .801 r
.60371 .45667 .5988 .4608 .60319 .46428 .60811 .46027 Mtetra
.745 .697 .806 r
.59932 .45339 .59441 .45771 .5988 .4608 .60371 .45667 Mtetra
.772 .73 .814 r
.59494 .45064 .59004 .45525 .59441 .45771 .59932 .45339 Mtetra
.814 .782 .823 r
.59058 .44872 .58569 .45378 .59004 .45525 .59494 .45064 Mtetra
.872 .859 .825 r
.58627 .44807 .58139 .4538 .58569 .45378 .59058 .44872 Mtetra
.925 .946 .79 r
.582 .44926 .57714 .45594 .58139 .4538 .58627 .44807 Mtetra
.9 .97 .66 r
.5778 .4529 .57295 .46075 .57714 .45594 .582 .44926 Mtetra
.755 .874 .452 r
.57365 .45925 .56881 .46823 .57295 .46075 .5778 .4529 Mtetra
0 0 0 r
.56952 .46761 .56465 .47709 .56881 .46823 .57365 .45925 Mtetra
.56531 .47555 .56037 .48417 .56465 .47709 .56952 .46761 Mtetra
.765 .96 .654 r
.56092 .47922 .55588 .48548 .56037 .48417 .56531 .47555 Mtetra
.695 .684 .835 r
.55628 .47553 .55117 .47903 .55588 .48548 .56092 .47922 Mtetra
.511 .398 .661 r
.55146 .46484 .54633 .46675 .55117 .47903 .55628 .47553 Mtetra
.503 .353 .61 r
.54658 .45089 .54149 .45324 .54633 .46675 .55146 .46484 Mtetra
.579 .406 .611 r
.54177 .43826 .53675 .443 .54149 .45324 .54658 .45089 Mtetra
.731 .537 .63 r
.53708 .43054 .53212 .4393 .53675 .443 .54177 .43826 Mtetra
.927 .726 .611 r
.53251 .43027 .5276 .44436 .53212 .4393 .53708 .43054 Mtetra
.988 .839 .462 r
.52804 .43926 .52313 .4587 .5276 .44436 .53251 .43027 Mtetra
.719 .715 .187 r
.5236 .45719 .51861 .47811 .52313 .4587 .52804 .43926 Mtetra
0 0 .072 r
.51907 .47753 .51393 .49084 .51861 .47811 .5236 .45719 Mtetra
.431 .02 .156 r
.51434 .48618 .50908 .48414 .51393 .49084 .51907 .47753 Mtetra
0 0 .266 r
.50945 .47253 .50421 .45851 .50908 .48414 .51434 .48618 Mtetra
0 0 .413 r
.50457 .44252 .49945 .42674 .50421 .45851 .50945 .47253 Mtetra
.109 .015 .457 r
.49981 .41059 .49479 .39947 .49945 .42674 .50457 .44252 Mtetra
.232 .113 .504 r
.49515 .38524 .49019 .37963 .49479 .39947 .49981 .41059 Mtetra
.34 .218 .565 r
.49054 .36746 .4856 .36592 .49019 .37963 .49515 .38524 Mtetra
.445 .333 .632 r
.48594 .35526 .48101 .35623 .4856 .36592 .49054 .36746 Mtetra
.537 .439 .691 r
.48134 .34653 .47641 .34891 .48101 .35623 .48594 .35526 Mtetra
.604 .521 .733 r
.47673 .33978 .4718 .34293 .47641 .34891 .48134 .34653 Mtetra
.646 .574 .759 r
.4721 .33412 .46717 .33768 .4718 .34293 .47673 .33978 Mtetra
.671 .605 .773 r
.46747 .32905 .46253 .33284 .46717 .33768 .4721 .33412 Mtetra
.685 .623 .781 r
.46282 .32431 .45788 .32822 .46253 .33284 .46747 .32905 Mtetra
.692 .633 .785 r
.45816 .31973 .45322 .32371 .45788 .32822 .46282 .32431 Mtetra
.696 .639 .788 r
.45349 .31525 .44855 .31926 .45322 .32371 .45816 .31973 Mtetra
.698 .642 .789 r
.44882 .31081 .44387 .31485 .44855 .31926 .45349 .31525 Mtetra
.7 .643 .79 r
.44413 .30639 .43919 .31045 .44387 .31485 .44882 .31081 Mtetra
.701 .644 .79 r
.43944 .30199 .4345 .30606 .43919 .31045 .44413 .30639 Mtetra
.701 .645 .79 r
.43474 .29758 .42979 .30166 .4345 .30606 .43944 .30199 Mtetra
.701 .645 .791 r
.43003 .29318 .42509 .29726 .42979 .30166 .43474 .29758 Mtetra
.42531 .28877 .42037 .29286 .42509 .29726 .43003 .29318 Mtetra
.701 .646 .791 r
.42059 .28435 .41564 .28846 .42037 .29286 .42531 .28877 Mtetra
.41586 .27993 .41091 .28404 .41564 .28846 .42059 .28435 Mtetra
.41112 .2755 .40617 .27962 .41091 .28404 .41586 .27993 Mtetra
.40637 .27107 .40142 .27519 .40617 .27962 .41112 .2755 Mtetra
.40161 .26663 .39667 .27076 .40142 .27519 .40637 .27107 Mtetra
.39685 .26218 .3919 .26632 .39667 .27076 .40161 .26663 Mtetra
.39208 .25772 .38713 .26187 .3919 .26632 .39685 .26218 Mtetra
.3873 .25326 .38235 .25741 .38713 .26187 .39208 .25772 Mtetra
.38251 .24879 .37756 .25294 .38235 .25741 .3873 .25326 Mtetra
.37772 .24431 .37277 .24847 .37756 .25294 .38251 .24879 Mtetra
.37291 .23982 .36796 .24399 .37277 .24847 .37772 .24431 Mtetra
.3681 .23533 .36315 .23951 .36796 .24399 .37291 .23982 Mtetra
.36328 .23083 .35833 .23501 .36315 .23951 .3681 .23533 Mtetra
.35845 .22632 .3535 .23051 .35833 .23501 .36328 .23083 Mtetra
.35362 .2218 .34866 .226 .3535 .23051 .35845 .22632 Mtetra
.34877 .21728 .34382 .22148 .34866 .226 .35362 .2218 Mtetra
.34392 .21275 .33897 .21696 .34382 .22148 .34877 .21728 Mtetra
.33906 .20821 .33411 .21243 .33897 .21696 .34392 .21275 Mtetra
.33419 .20366 .32924 .20789 .33411 .21243 .33906 .20821 Mtetra
.32931 .1991 .32436 .20334 .32924 .20789 .33419 .20366 Mtetra
.32443 .19454 .31947 .19879 .32436 .20334 .32931 .1991 Mtetra
.31954 .18997 .31458 .19422 .31947 .19879 .32443 .19454 Mtetra
.31463 .1854 .30968 .18965 .31458 .19422 .31954 .18997 Mtetra
.30972 .18081 .30477 .18507 .30968 .18965 .31463 .1854 Mtetra
.75933 .59248 .75442 .59612 .75861 .60003 .76352 .59639 Mtetra
.75514 .58856 .75023 .5922 .75442 .59612 .75933 .59248 Mtetra
.75094 .58463 .74603 .58828 .75023 .5922 .75514 .58856 Mtetra
.74673 .58069 .74182 .58435 .74603 .58828 .75094 .58463 Mtetra
.74252 .57675 .73761 .58042 .74182 .58435 .74673 .58069 Mtetra
.7383 .57281 .73339 .57648 .73761 .58042 .74252 .57675 Mtetra
.73407 .56885 .72916 .57253 .73339 .57648 .7383 .57281 Mtetra
.72984 .56489 .72493 .56858 .72916 .57253 .73407 .56885 Mtetra
.7256 .56093 .72069 .56462 .72493 .56858 .72984 .56489 Mtetra
.72136 .55696 .71644 .56065 .72069 .56462 .7256 .56093 Mtetra
.7171 .55298 .71219 .55668 .71644 .56065 .72136 .55696 Mtetra
.71285 .54899 .70793 .5527 .71219 .55668 .7171 .55298 Mtetra
.70858 .545 .70366 .54872 .70793 .5527 .71285 .54899 Mtetra
.70431 .54101 .69939 .54472 .70366 .54872 .70858 .545 Mtetra
.70003 .537 .69511 .54073 .69939 .54472 .70431 .54101 Mtetra
.69574 .533 .69082 .53672 .69511 .54073 .70003 .537 Mtetra
.69145 .52898 .68653 .53271 .69082 .53672 .69574 .533 Mtetra
.68715 .52496 .68223 .5287 .68653 .53271 .69145 .52898 Mtetra
.68284 .52093 .67792 .52468 .68223 .5287 .68715 .52496 Mtetra
.67853 .51689 .67361 .52065 .67792 .52468 .68284 .52093 Mtetra
.67421 .51285 .66929 .51661 .67361 .52065 .67853 .51689 Mtetra
.66988 .50881 .66496 .51257 .66929 .51661 .67421 .51285 Mtetra
.66555 .50475 .66063 .50852 .66496 .51257 .66988 .50881 Mtetra
.66121 .50069 .65628 .50447 .66063 .50852 .66555 .50475 Mtetra
.702 .646 .791 r
.65686 .49663 .65194 .50041 .65628 .50447 .66121 .50069 Mtetra
.65251 .49256 .64758 .49635 .65194 .50041 .65686 .49663 Mtetra
.64814 .48848 .64322 .49228 .64758 .49635 .65251 .49256 Mtetra
.64378 .4844 .63885 .48821 .64322 .49228 .64814 .48848 Mtetra
.6394 .48033 .63448 .48414 .63885 .48821 .64378 .4844 Mtetra
.703 .647 .791 r
.63502 .47625 .63009 .48007 .63448 .48414 .6394 .48033 Mtetra
.703 .648 .792 r
.63063 .47218 .62571 .47602 .63009 .48007 .63502 .47625 Mtetra
.704 .649 .792 r
.62624 .46813 .62131 .47199 .62571 .47602 .63063 .47218 Mtetra
.706 .652 .793 r
.62184 .46411 .61691 .46799 .62131 .47199 .62624 .46813 Mtetra
.71 .655 .794 r
.61744 .46015 .61251 .46407 .61691 .46799 .62184 .46411 Mtetra
.715 .661 .796 r
.61304 .45629 .60811 .46027 .61251 .46407 .61744 .46015 Mtetra
.723 .672 .799 r
.60863 .45259 .60371 .45667 .60811 .46027 .61304 .45629 Mtetra
.737 .688 .804 r
.60424 .44916 .59932 .45339 .60371 .45667 .60863 .45259 Mtetra
.76 .715 .811 r
.59985 .44616 .59494 .45064 .59932 .45339 .60424 .44916 Mtetra
.795 .759 .82 r
.59549 .44387 .59058 .44872 .59494 .45064 .59985 .44616 Mtetra
.847 .827 .827 r
.59115 .44264 .58627 .44807 .59058 .44872 .59549 .44387 Mtetra
.908 .914 .813 r
.58687 .44302 .582 .44926 .58627 .44807 .59115 .44264 Mtetra
.923 .976 .727 r
.58265 .44559 .5778 .4529 .582 .44926 .58687 .44302 Mtetra
.816 .923 .537 r
.5785 .4508 .57365 .45925 .5778 .4529 .58265 .44559 Mtetra
.644 .794 .346 r
.57438 .45841 .56952 .46761 .57365 .45925 .5785 .4508 Mtetra
0 0 0 r
.57023 .46669 .56531 .47555 .56952 .46761 .57438 .45841 Mtetra
.632 .849 .464 r
.56593 .47222 .56092 .47922 .56531 .47555 .57023 .46669 Mtetra
.801 .888 .907 r
.56138 .47132 .55628 .47553 .56092 .47922 .56593 .47222 Mtetra
.534 .452 .708 r
.5566 .46285 .55146 .46484 .55628 .47553 .56138 .47132 Mtetra
.479 .344 .62 r
.55171 .44936 .54658 .45089 .55146 .46484 .5566 .46285 Mtetra
.52 .361 .605 r
.54684 .43527 .54177 .43826 .54658 .45089 .55171 .44936 Mtetra
.632 .451 .621 r
.54207 .42444 .53708 .43054 .54177 .43826 .54684 .43527 Mtetra
.813 .614 .633 r
.53744 .41957 .53251 .43027 .53708 .43054 .54207 .42444 Mtetra
.982 .788 .568 r
.53293 .42276 .52804 .43926 .53251 .43027 .53744 .41957 Mtetra
.937 .82 .367 r
.5285 .43556 .5236 .45719 .52804 .43926 .53293 .42276 Mtetra
0 0 0 r
.52408 .45646 .51907 .47753 .5236 .45719 .5285 .43556 Mtetra
0 0 .129 r
.51953 .47621 .51434 .48618 .51907 .47753 .52408 .45646 Mtetra
.647 .174 .116 r
.51474 .47923 .50945 .47253 .51434 .48618 .51953 .47621 Mtetra
0 0 .332 r
.50981 .45886 .50457 .44252 .50945 .47253 .51474 .47923 Mtetra
0 0 .422 r
.50492 .42599 .49981 .41059 .50457 .44252 .50981 .45886 Mtetra
.142 .038 .466 r
.50016 .39498 .49515 .38524 .49981 .41059 .50492 .42599 Mtetra
.259 .138 .519 r
.49551 .3718 .49054 .36746 .49515 .38524 .50016 .39498 Mtetra
.369 .25 .584 r
.49089 .35593 .48594 .35526 .49054 .36746 .49551 .3718 Mtetra
.475 .367 .652 r
.48628 .34503 .48134 .34653 .48594 .35526 .49089 .35593 Mtetra
.561 .469 .708 r
.48167 .33709 .47673 .33978 .48134 .34653 .48628 .34503 Mtetra
.621 .542 .744 r
.47705 .33079 .4721 .33412 .47673 .33978 .48167 .33709 Mtetra
.657 .587 .765 r
.47241 .32538 .46747 .32905 .4721 .33412 .47705 .33079 Mtetra
.677 .613 .777 r
.46777 .32045 .46282 .32431 .46747 .32905 .47241 .32538 Mtetra
.688 .628 .783 r
.46311 .31578 .45816 .31973 .46282 .32431 .46777 .32045 Mtetra
.694 .636 .787 r
.45844 .31124 .45349 .31525 .45816 .31973 .46311 .31578 Mtetra
.697 .64 .788 r
.45377 .30677 .44882 .31081 .45349 .31525 .45844 .31124 Mtetra
.699 .643 .789 r
.44908 .30233 .44413 .30639 .44882 .31081 .45377 .30677 Mtetra
.7 .644 .79 r
.44439 .29791 .43944 .30199 .44413 .30639 .44908 .30233 Mtetra
.701 .645 .79 r
.43969 .2935 .43474 .29758 .43944 .30199 .44439 .29791 Mtetra
.43498 .28908 .43003 .29318 .43474 .29758 .43969 .2935 Mtetra
.701 .645 .791 r
.43027 .28467 .42531 .28877 .43003 .29318 .43498 .28908 Mtetra
.701 .646 .791 r
.42554 .28024 .42059 .28435 .42531 .28877 .43027 .28467 Mtetra
.42081 .27582 .41586 .27993 .42059 .28435 .42554 .28024 Mtetra
.41607 .27138 .41112 .2755 .41586 .27993 .42081 .27582 Mtetra
.41132 .26694 .40637 .27107 .41112 .2755 .41607 .27138 Mtetra
.40657 .26249 .40161 .26663 .40637 .27107 .41132 .26694 Mtetra
.40181 .25803 .39685 .26218 .40161 .26663 .40657 .26249 Mtetra
.39704 .25357 .39208 .25772 .39685 .26218 .40181 .25803 Mtetra
.39226 .2491 .3873 .25326 .39208 .25772 .39704 .25357 Mtetra
.38747 .24462 .38251 .24879 .3873 .25326 .39226 .2491 Mtetra
.38267 .24014 .37772 .24431 .38251 .24879 .38747 .24462 Mtetra
.37787 .23564 .37291 .23982 .37772 .24431 .38267 .24014 Mtetra
.37306 .23114 .3681 .23533 .37291 .23982 .37787 .23564 Mtetra
.36824 .22663 .36328 .23083 .3681 .23533 .37306 .23114 Mtetra
.36341 .22212 .35845 .22632 .36328 .23083 .36824 .22663 Mtetra
.35858 .21759 .35362 .2218 .35845 .22632 .36341 .22212 Mtetra
.35373 .21306 .34877 .21728 .35362 .2218 .35858 .21759 Mtetra
.34888 .20852 .34392 .21275 .34877 .21728 .35373 .21306 Mtetra
.34402 .20398 .33906 .20821 .34392 .21275 .34888 .20852 Mtetra
.33915 .19942 .33419 .20366 .33906 .20821 .34402 .20398 Mtetra
.33428 .19486 .32931 .1991 .33419 .20366 .33915 .19942 Mtetra
.32939 .19029 .32443 .19454 .32931 .1991 .33428 .19486 Mtetra
.3245 .18572 .31954 .18997 .32443 .19454 .32939 .19029 Mtetra
.3196 .18113 .31463 .1854 .31954 .18997 .3245 .18572 Mtetra
.31469 .17654 .30972 .18081 .31463 .1854 .3196 .18113 Mtetra
.76424 .58883 .75933 .59248 .76352 .59639 .76843 .59275 Mtetra
.76005 .5849 .75514 .58856 .75933 .59248 .76424 .58883 Mtetra
.75585 .58097 .75094 .58463 .75514 .58856 .76005 .5849 Mtetra
.75165 .57703 .74673 .58069 .75094 .58463 .75585 .58097 Mtetra
.74744 .57308 .74252 .57675 .74673 .58069 .75165 .57703 Mtetra
.74322 .56913 .7383 .57281 .74252 .57675 .74744 .57308 Mtetra
.73899 .56517 .73407 .56885 .7383 .57281 .74322 .56913 Mtetra
.73476 .56121 .72984 .56489 .73407 .56885 .73899 .56517 Mtetra
.73052 .55724 .7256 .56093 .72984 .56489 .73476 .56121 Mtetra
.72628 .55326 .72136 .55696 .7256 .56093 .73052 .55724 Mtetra
.72203 .54927 .7171 .55298 .72136 .55696 .72628 .55326 Mtetra
.71777 .54528 .71285 .54899 .7171 .55298 .72203 .54927 Mtetra
.7135 .54129 .70858 .545 .71285 .54899 .71777 .54528 Mtetra
.70923 .53729 .70431 .54101 .70858 .545 .7135 .54129 Mtetra
.70495 .53328 .70003 .537 .70431 .54101 .70923 .53729 Mtetra
.70067 .52926 .69574 .533 .70003 .537 .70495 .53328 Mtetra
.69637 .52524 .69145 .52898 .69574 .533 .70067 .52926 Mtetra
.69208 .52121 .68715 .52496 .69145 .52898 .69637 .52524 Mtetra
.68777 .51718 .68284 .52093 .68715 .52496 .69208 .52121 Mtetra
.68346 .51314 .67853 .51689 .68284 .52093 .68777 .51718 Mtetra
.67914 .50909 .67421 .51285 .67853 .51689 .68346 .51314 Mtetra
.67481 .50504 .66988 .50881 .67421 .51285 .67914 .50909 Mtetra
.67048 .50098 .66555 .50475 .66988 .50881 .67481 .50504 Mtetra
.66614 .49691 .66121 .50069 .66555 .50475 .67048 .50098 Mtetra
.702 .646 .791 r
.66179 .49284 .65686 .49663 .66121 .50069 .66614 .49691 Mtetra
.65744 .48876 .65251 .49256 .65686 .49663 .66179 .49284 Mtetra
.65308 .48468 .64814 .48848 .65251 .49256 .65744 .48876 Mtetra
.64871 .48059 .64378 .4844 .64814 .48848 .65308 .48468 Mtetra
.64433 .47651 .6394 .48033 .64378 .4844 .64871 .48059 Mtetra
.702 .647 .791 r
.63995 .47242 .63502 .47625 .6394 .48033 .64433 .47651 Mtetra
.703 .647 .791 r
.63557 .46834 .63063 .47218 .63502 .47625 .63995 .47242 Mtetra
.704 .649 .792 r
.63117 .46427 .62624 .46813 .63063 .47218 .63557 .46834 Mtetra
.706 .651 .792 r
.62678 .46023 .62184 .46411 .62624 .46813 .63117 .46427 Mtetra
.708 .654 .793 r
.62237 .45623 .61744 .46015 .62184 .46411 .62678 .46023 Mtetra
.712 .659 .795 r
.61797 .45232 .61304 .45629 .61744 .46015 .62237 .45623 Mtetra
.719 .667 .798 r
.61356 .44854 .60863 .45259 .61304 .45629 .61797 .45232 Mtetra
.731 .681 .802 r
.60916 .44498 .60424 .44916 .60863 .45259 .61356 .44854 Mtetra
.75 .703 .808 r
.60477 .44178 .59985 .44616 .60424 .44916 .60916 .44498 Mtetra
.78 .74 .817 r
.6004 .43917 .59549 .44387 .59985 .44616 .60477 .44178 Mtetra
.825 .798 .826 r
.59605 .43747 .59115 .44264 .59549 .44387 .6004 .43917 Mtetra
.885 .88 .824 r
.59175 .43714 .58687 .44302 .59115 .44264 .59605 .43747 Mtetra
.927 .962 .774 r
.58752 .43875 .58265 .44559 .58687 .44302 .59175 .43714 Mtetra
.87 .96 .621 r
.58335 .44286 .5785 .4508 .58265 .44559 .58752 .43875 Mtetra
.704 .843 .412 r
.57924 .44954 .57438 .45841 .5785 .4508 .58335 .44286 Mtetra
0 0 0 r
.57513 .45771 .57023 .46669 .57438 .45841 .57924 .44954 Mtetra
.57091 .46457 .56593 .47222 .57023 .46669 .57513 .45771 Mtetra
.808 1 .825 r
.56646 .46627 .56138 .47132 .56593 .47222 .57091 .46457 Mtetra
.591 .555 .783 r
.56176 .46043 .5566 .46285 .56138 .47132 .56646 .46627 Mtetra
.471 .355 .64 r
.55687 .4482 .55171 .44936 .5566 .46285 .56176 .46043 Mtetra
.48 .333 .603 r
.55195 .43352 .54684 .43527 .55171 .44936 .55687 .4482 Mtetra
.555 .388 .61 r
.54711 .42046 .54207 .42444 .54684 .43527 .55195 .43352 Mtetra
.698 .512 .633 r
.5424 .41194 .53744 .41957 .54207 .42444 .54711 .42046 Mtetra
.892 .691 .624 r
.53782 .41002 .53293 .42276 .53744 .41957 .5424 .41194 Mtetra
1 .822 .506 r
.53337 .41667 .5285 .43556 .53293 .42276 .53782 .41002 Mtetra
.859 .778 .276 r
.52899 .43308 .52408 .45646 .5285 .43556 .53337 .41667 Mtetra
0 0 0 r
.52458 .4561 .51953 .47621 .52408 .45646 .52899 .43308 Mtetra
.138 0 .169 r
.51998 .47358 .51474 .47923 .51953 .47621 .52458 .4561 Mtetra
.811 .324 .006 r
.51512 .46987 .50981 .45886 .51474 .47923 .51998 .47358 Mtetra
0 0 .365 r
.51016 .44361 .50492 .42599 .50981 .45886 .51512 .46987 Mtetra
.026 0 .43 r
.50527 .40939 .50016 .39498 .50492 .42599 .51016 .44361 Mtetra
.173 .062 .477 r
.50052 .38004 .49551 .3718 .50016 .39498 .50527 .40939 Mtetra
.288 .166 .535 r
.49586 .3591 .49089 .35593 .49551 .3718 .50052 .38004 Mtetra
.399 .284 .604 r
.49124 .34495 .48628 .34503 .49089 .35593 .49586 .3591 Mtetra
.503 .401 .671 r
.48662 .33515 .48167 .33709 .48628 .34503 .49124 .34495 Mtetra
.583 .496 .722 r
.482 .32785 .47705 .33079 .48167 .33709 .48662 .33515 Mtetra
.635 .56 .753 r
.47736 .32191 .47241 .32538 .47705 .33079 .482 .32785 Mtetra
.665 .598 .77 r
.47272 .3167 .46777 .32045 .47241 .32538 .47736 .32191 Mtetra
.682 .62 .78 r
.46806 .31188 .46311 .31578 .46777 .32045 .47272 .3167 Mtetra
.691 .631 .785 r
.4634 .30726 .45844 .31124 .46311 .31578 .46806 .31188 Mtetra
.696 .638 .788 r
.45872 .30274 .45377 .30677 .45844 .31124 .4634 .30726 Mtetra
.698 .641 .789 r
.45404 .29827 .44908 .30233 .45377 .30677 .45872 .30274 Mtetra
.7 .643 .79 r
.44935 .29384 .44439 .29791 .44908 .30233 .45404 .29827 Mtetra
.7 .644 .79 r
.44465 .28941 .43969 .2935 .44439 .29791 .44935 .29384 Mtetra
.701 .645 .79 r
.43994 .28499 .43498 .28908 .43969 .2935 .44465 .28941 Mtetra
.701 .645 .791 r
.43523 .28056 .43027 .28467 .43498 .28908 .43994 .28499 Mtetra
.4305 .27613 .42554 .28024 .43027 .28467 .43523 .28056 Mtetra
.701 .646 .791 r
.42577 .27169 .42081 .27582 .42554 .28024 .4305 .27613 Mtetra
.42103 .26725 .41607 .27138 .42081 .27582 .42577 .27169 Mtetra
.41629 .2628 .41132 .26694 .41607 .27138 .42103 .26725 Mtetra
.41153 .25835 .40657 .26249 .41132 .26694 .41629 .2628 Mtetra
.40677 .25388 .40181 .25803 .40657 .26249 .41153 .25835 Mtetra
.402 .24941 .39704 .25357 .40181 .25803 .40677 .25388 Mtetra
.39722 .24494 .39226 .2491 .39704 .25357 .402 .24941 Mtetra
.39243 .24045 .38747 .24462 .39226 .2491 .39722 .24494 Mtetra
.38764 .23596 .38267 .24014 .38747 .24462 .39243 .24045 Mtetra
.38284 .23146 .37787 .23564 .38267 .24014 .38764 .23596 Mtetra
.37802 .22695 .37306 .23114 .37787 .23564 .38284 .23146 Mtetra
.37321 .22243 .36824 .22663 .37306 .23114 .37802 .22695 Mtetra
.36838 .21791 .36341 .22212 .36824 .22663 .37321 .22243 Mtetra
.36354 .21338 .35858 .21759 .36341 .22212 .36838 .21791 Mtetra
.3587 .20884 .35373 .21306 .35858 .21759 .36354 .21338 Mtetra
.35385 .2043 .34888 .20852 .35373 .21306 .3587 .20884 Mtetra
.34899 .19974 .34402 .20398 .34888 .20852 .35385 .2043 Mtetra
.34412 .19518 .33915 .19942 .34402 .20398 .34899 .19974 Mtetra
.33924 .19061 .33428 .19486 .33915 .19942 .34412 .19518 Mtetra
.33436 .18604 .32939 .19029 .33428 .19486 .33924 .19061 Mtetra
.32947 .18145 .3245 .18572 .32939 .19029 .33436 .18604 Mtetra
.32457 .17686 .3196 .18113 .3245 .18572 .32947 .18145 Mtetra
.31966 .17226 .31469 .17654 .3196 .18113 .32457 .17686 Mtetra
.76916 .58518 .76424 .58883 .76843 .59275 .77335 .58911 Mtetra
.76497 .58125 .76005 .5849 .76424 .58883 .76916 .58518 Mtetra
.76077 .57731 .75585 .58097 .76005 .5849 .76497 .58125 Mtetra
.75657 .57336 .75165 .57703 .75585 .58097 .76077 .57731 Mtetra
.75236 .56941 .74744 .57308 .75165 .57703 .75657 .57336 Mtetra
.74814 .56545 .74322 .56913 .74744 .57308 .75236 .56941 Mtetra
.74392 .56148 .73899 .56517 .74322 .56913 .74814 .56545 Mtetra
.73969 .55751 .73476 .56121 .73899 .56517 .74392 .56148 Mtetra
.73545 .55354 .73052 .55724 .73476 .56121 .73969 .55751 Mtetra
.7312 .54955 .72628 .55326 .73052 .55724 .73545 .55354 Mtetra
.72695 .54556 .72203 .54927 .72628 .55326 .7312 .54955 Mtetra
.7227 .54157 .71777 .54528 .72203 .54927 .72695 .54556 Mtetra
.71843 .53757 .7135 .54129 .71777 .54528 .7227 .54157 Mtetra
.71416 .53356 .70923 .53729 .7135 .54129 .71843 .53757 Mtetra
.70988 .52954 .70495 .53328 .70923 .53729 .71416 .53356 Mtetra
.7056 .52552 .70067 .52926 .70495 .53328 .70988 .52954 Mtetra
.70131 .52149 .69637 .52524 .70067 .52926 .7056 .52552 Mtetra
.69701 .51746 .69208 .52121 .69637 .52524 .70131 .52149 Mtetra
.6927 .51342 .68777 .51718 .69208 .52121 .69701 .51746 Mtetra
.68839 .50937 .68346 .51314 .68777 .51718 .6927 .51342 Mtetra
.68407 .50532 .67914 .50909 .68346 .51314 .68839 .50937 Mtetra
.67975 .50126 .67481 .50504 .67914 .50909 .68407 .50532 Mtetra
.67542 .49719 .67048 .50098 .67481 .50504 .67975 .50126 Mtetra
.67108 .49312 .66614 .49691 .67048 .50098 .67542 .49719 Mtetra
.702 .646 .791 r
.66673 .48904 .66179 .49284 .66614 .49691 .67108 .49312 Mtetra
.66238 .48496 .65744 .48876 .66179 .49284 .66673 .48904 Mtetra
.65802 .48087 .65308 .48468 .65744 .48876 .66238 .48496 Mtetra
.65365 .47678 .64871 .48059 .65308 .48468 .65802 .48087 Mtetra
.64928 .47268 .64433 .47651 .64871 .48059 .65365 .47678 Mtetra
.702 .647 .791 r
.6449 .46859 .63995 .47242 .64433 .47651 .64928 .47268 Mtetra
.703 .647 .791 r
.64051 .4645 .63557 .46834 .63995 .47242 .6449 .46859 Mtetra
.703 .648 .792 r
.63612 .46041 .63117 .46427 .63557 .46834 .64051 .4645 Mtetra
.705 .65 .792 r
.63172 .45635 .62678 .46023 .63117 .46427 .63612 .46041 Mtetra
.707 .652 .793 r
.62732 .45232 .62237 .45623 .62678 .46023 .63172 .45635 Mtetra
.711 .657 .794 r
.62291 .44836 .61797 .45232 .62237 .45623 .62732 .45232 Mtetra
.716 .663 .797 r
.6185 .44452 .61356 .44854 .61797 .45232 .62291 .44836 Mtetra
.726 .675 .8 r
.6141 .44085 .60916 .44498 .61356 .44854 .6185 .44452 Mtetra
.741 .694 .805 r
.6097 .43749 .60477 .44178 .60916 .44498 .6141 .44085 Mtetra
.766 .724 .813 r
.60532 .43461 .6004 .43917 .60477 .44178 .6097 .43749 Mtetra
.805 .773 .823 r
.60096 .4325 .59605 .43747 .6004 .43917 .60532 .43461 Mtetra
.861 .846 .828 r
.59665 .43156 .59175 .43714 .59605 .43747 .60096 .4325 Mtetra
.917 .935 .804 r
.59239 .43233 .58752 .43875 .59175 .43714 .59665 .43156 Mtetra
.907 .977 .695 r
.58821 .4354 .58335 .44286 .58752 .43875 .59239 .43233 Mtetra
.77 .895 .491 r
.58409 .44106 .57924 .44954 .58335 .44286 .58821 .4354 Mtetra
0 0 0 r
.58 .44877 .57513 .45771 .57924 .44954 .58409 .44106 Mtetra
.57585 .45641 .57091 .46457 .57513 .45771 .58 .44877 Mtetra
.685 .923 .604 r
.57151 .46034 .56646 .46627 .57091 .46457 .57585 .45641 Mtetra
.691 .731 .881 r
.5669 .4573 .56176 .46043 .56646 .46627 .57151 .46034 Mtetra
.481 .39 .675 r
.56205 .44701 .55687 .4482 .56176 .46043 .5669 .4573 Mtetra
.454 .321 .609 r
.55711 .43254 .55195 .43352 .55687 .4482 .56205 .44701 Mtetra
.499 .345 .602 r
.5522 .41806 .54711 .42046 .55195 .43352 .55711 .43254 Mtetra
.603 .432 .622 r
.54741 .40679 .5424 .41194 .54711 .42046 .5522 .41806 Mtetra
.773 .583 .641 r
.54276 .40078 .53782 .41002 .5424 .41194 .54741 .40679 Mtetra
.954 .756 .597 r
.53824 .40182 .53337 .41667 .53782 .41002 .54276 .40078 Mtetra
.984 .826 .433 r
.53383 .41188 .52899 .43308 .53337 .41667 .53824 .40182 Mtetra
.766 .723 .192 r
.52949 .4316 .52458 .4561 .52899 .43308 .53383 .41188 Mtetra
0 0 .057 r
.52507 .45566 .51998 .47358 .52458 .4561 .52949 .4316 Mtetra
.319 0 .188 r
.52042 .46917 .51512 .46987 .51998 .47358 .52507 .45566 Mtetra
.774 .385 0 r
.51549 .45822 .51016 .44361 .51512 .46987 .52042 .46917 Mtetra
0 0 .385 r
.5105 .42734 .50527 .40939 .51016 .44361 .51549 .45822 Mtetra
.069 0 .44 r
.50562 .39308 .50052 .38004 .50527 .40939 .5105 .42734 Mtetra
.202 .087 .49 r
.50088 .36585 .49586 .3591 .50052 .38004 .50562 .39308 Mtetra
.317 .196 .553 r
.49621 .34706 .49124 .34495 .49586 .3591 .50088 .36585 Mtetra
.43 .318 .625 r
.49158 .33443 .48662 .33515 .49124 .34495 .49621 .34706 Mtetra
.529 .432 .689 r
.48696 .32554 .482 .32785 .48662 .33515 .49158 .33443 Mtetra
.602 .519 .734 r
.48232 .31876 .47736 .32191 .482 .32785 .48696 .32554 Mtetra
.646 .575 .76 r
.47768 .31311 .47272 .3167 .47736 .32191 .48232 .31876 Mtetra
.672 .607 .774 r
.47303 .30805 .46806 .31188 .47272 .3167 .47768 .31311 Mtetra
.686 .625 .782 r
.46836 .30331 .4634 .30726 .46806 .31188 .47303 .30805 Mtetra
.693 .634 .786 r
.46369 .29873 .45872 .30274 .4634 .30726 .46836 .30331 Mtetra
.697 .639 .788 r
.45901 .29422 .45404 .29827 .45872 .30274 .46369 .29873 Mtetra
.699 .642 .789 r
.45432 .28976 .44935 .29384 .45404 .29827 .45901 .29422 Mtetra
.7 .644 .79 r
.44962 .28532 .44465 .28941 .44935 .29384 .45432 .28976 Mtetra
.701 .645 .79 r
.44491 .28088 .43994 .28499 .44465 .28941 .44962 .28532 Mtetra
.701 .645 .791 r
.4402 .27645 .43523 .28056 .43994 .28499 .44491 .28088 Mtetra
.43547 .27201 .4305 .27613 .43523 .28056 .4402 .27645 Mtetra
.701 .646 .791 r
.43074 .26757 .42577 .27169 .4305 .27613 .43547 .27201 Mtetra
.426 .26312 .42103 .26725 .42577 .27169 .43074 .26757 Mtetra
.42126 .25866 .41629 .2628 .42103 .26725 .426 .26312 Mtetra
.4165 .2542 .41153 .25835 .41629 .2628 .42126 .25866 Mtetra
.41174 .24973 .40677 .25388 .41153 .25835 .4165 .2542 Mtetra
.40697 .24525 .402 .24941 .40677 .25388 .41174 .24973 Mtetra
.40219 .24077 .39722 .24494 .402 .24941 .40697 .24525 Mtetra
.39741 .23627 .39243 .24045 .39722 .24494 .40219 .24077 Mtetra
.39261 .23177 .38764 .23596 .39243 .24045 .39741 .23627 Mtetra
.38781 .22727 .38284 .23146 .38764 .23596 .39261 .23177 Mtetra
.383 .22275 .37802 .22695 .38284 .23146 .38781 .22727 Mtetra
.37818 .21823 .37321 .22243 .37802 .22695 .383 .22275 Mtetra
.37335 .2137 .36838 .21791 .37321 .22243 .37818 .21823 Mtetra
.36852 .20916 .36354 .21338 .36838 .21791 .37335 .2137 Mtetra
.36368 .20462 .3587 .20884 .36354 .21338 .36852 .20916 Mtetra
.35882 .20006 .35385 .2043 .3587 .20884 .36368 .20462 Mtetra
.35397 .1955 .34899 .19974 .35385 .2043 .35882 .20006 Mtetra
.3491 .19093 .34412 .19518 .34899 .19974 .35397 .1955 Mtetra
.34422 .18636 .33924 .19061 .34412 .19518 .3491 .19093 Mtetra
.33934 .18177 .33436 .18604 .33924 .19061 .34422 .18636 Mtetra
.33445 .17718 .32947 .18145 .33436 .18604 .33934 .18177 Mtetra
.32955 .17258 .32457 .17686 .32947 .18145 .33445 .17718 Mtetra
.32464 .16798 .31966 .17226 .32457 .17686 .32955 .17258 Mtetra
.77409 .58152 .76916 .58518 .77335 .58911 .77827 .58545 Mtetra
.7699 .57758 .76497 .58125 .76916 .58518 .77409 .58152 Mtetra
.7657 .57364 .76077 .57731 .76497 .58125 .7699 .57758 Mtetra
.7615 .56968 .75657 .57336 .76077 .57731 .7657 .57364 Mtetra
.75729 .56573 .75236 .56941 .75657 .57336 .7615 .56968 Mtetra
.75307 .56176 .74814 .56545 .75236 .56941 .75729 .56573 Mtetra
.74885 .55779 .74392 .56148 .74814 .56545 .75307 .56176 Mtetra
.74462 .55382 .73969 .55751 .74392 .56148 .74885 .55779 Mtetra
.74038 .54983 .73545 .55354 .73969 .55751 .74462 .55382 Mtetra
.73614 .54584 .7312 .54955 .73545 .55354 .74038 .54983 Mtetra
.73189 .54185 .72695 .54556 .7312 .54955 .73614 .54584 Mtetra
.72763 .53785 .7227 .54157 .72695 .54556 .73189 .54185 Mtetra
.72337 .53384 .71843 .53757 .7227 .54157 .72763 .53785 Mtetra
.7191 .52982 .71416 .53356 .71843 .53757 .72337 .53384 Mtetra
.71482 .5258 .70988 .52954 .71416 .53356 .7191 .52982 Mtetra
.71054 .52178 .7056 .52552 .70988 .52954 .71482 .5258 Mtetra
.70625 .51774 .70131 .52149 .7056 .52552 .71054 .52178 Mtetra
.70195 .5137 .69701 .51746 .70131 .52149 .70625 .51774 Mtetra
.69765 .50966 .6927 .51342 .69701 .51746 .70195 .5137 Mtetra
.69333 .5056 .68839 .50937 .6927 .51342 .69765 .50966 Mtetra
.68902 .50154 .68407 .50532 .68839 .50937 .69333 .5056 Mtetra
.68469 .49748 .67975 .50126 .68407 .50532 .68902 .50154 Mtetra
.68036 .49341 .67542 .49719 .67975 .50126 .68469 .49748 Mtetra
.67602 .48933 .67108 .49312 .67542 .49719 .68036 .49341 Mtetra
.67168 .48525 .66673 .48904 .67108 .49312 .67602 .48933 Mtetra
.702 .646 .791 r
.66732 .48116 .66238 .48496 .66673 .48904 .67168 .48525 Mtetra
.66296 .47706 .65802 .48087 .66238 .48496 .66732 .48116 Mtetra
.6586 .47296 .65365 .47678 .65802 .48087 .66296 .47706 Mtetra
.65422 .46886 .64928 .47268 .65365 .47678 .6586 .47296 Mtetra
.64984 .46475 .6449 .46859 .64928 .47268 .65422 .46886 Mtetra
.702 .647 .791 r
.64546 .46065 .64051 .4645 .6449 .46859 .64984 .46475 Mtetra
.703 .648 .791 r
.64107 .45655 .63612 .46041 .64051 .4645 .64546 .46065 Mtetra
.704 .649 .792 r
.63667 .45247 .63172 .45635 .63612 .46041 .64107 .45655 Mtetra
.706 .651 .793 r
.63227 .44842 .62732 .45232 .63172 .45635 .63667 .45247 Mtetra
.709 .655 .794 r
.62786 .44442 .62291 .44836 .62732 .45232 .63227 .44842 Mtetra
.714 .66 .796 r
.62345 .44052 .6185 .44452 .62291 .44836 .62786 .44442 Mtetra
.722 .67 .799 r
.61904 .43676 .6141 .44085 .6185 .44452 .62345 .44052 Mtetra
.735 .685 .803 r
.61464 .43326 .6097 .43749 .6141 .44085 .61904 .43676 Mtetra
.755 .711 .81 r
.61025 .43016 .60532 .43461 .6097 .43749 .61464 .43326 Mtetra
.789 .752 .819 r
.60589 .4277 .60096 .4325 .60532 .43461 .61025 .43016 Mtetra
.838 .815 .828 r
.60156 .42624 .59665 .43156 .60096 .4325 .60589 .4277 Mtetra
.898 .902 .821 r
.59728 .42628 .59239 .43233 .59665 .43156 .60156 .42624 Mtetra
.924 .974 .752 r
.59308 .42837 .58821 .4354 .59239 .43233 .59728 .42628 Mtetra
.832 .94 .575 r
.58895 .43299 .58409 .44106 .58821 .4354 .59308 .42837 Mtetra
.654 .811 .374 r
.58487 .43999 .58 .44877 .58409 .44106 .58895 .43299 Mtetra
0 0 0 r
.58078 .4479 .57585 .45641 .58 .44877 .58487 .43999 Mtetra
.575 .813 .428 r
.57653 .45356 .57151 .46034 .57585 .45641 .58078 .4479 Mtetra
.789 .939 .927 r
.57203 .45329 .5669 .4573 .57151 .46034 .57653 .45356 Mtetra
.518 .461 .732 r
.56725 .44544 .56205 .44701 .5669 .4573 .57203 .45329 Mtetra
.443 .325 .623 r
.5623 .43193 .55711 .43254 .56205 .44701 .56725 .44544 Mtetra
.462 .318 .599 r
.55734 .41676 .5522 .41806 .55711 .43254 .5623 .43193 Mtetra
.533 .374 .611 r
.55247 .40348 .54741 .40679 .5522 .41806 .55734 .41676 Mtetra
.664 .488 .637 r
.54774 .39435 .54276 .40078 .54741 .40679 .55247 .40348 Mtetra
.85 .656 .641 r
.54314 .39089 .53824 .40182 .54276 .40078 .54774 .39435 Mtetra
.991 .8 .552 r
.53868 .39487 .53383 .41188 .53824 .40182 .54314 .39089 Mtetra
.943 .81 .358 r
.53432 .40828 .52949 .4316 .53383 .41188 .53868 .39487 Mtetra
0 0 0 r
.53001 .43086 .52507 .45566 .52949 .4316 .53432 .40828 Mtetra
0 0 .113 r
.52557 .45462 .52042 .46917 .52507 .45566 .53001 .43086 Mtetra
.518 .095 .178 r
.52084 .46264 .51549 .45822 .52042 .46917 .52557 .45462 Mtetra
0 0 .261 r
.51585 .44458 .5105 .42734 .51549 .45822 .52084 .46264 Mtetra
0 0 .4 r
.51084 .41057 .50562 .39308 .5105 .42734 .51585 .44458 Mtetra
.107 .009 .45 r
.50597 .37729 .50088 .36585 .50562 .39308 .51084 .41057 Mtetra
.231 .113 .504 r
.50123 .3524 .49621 .34706 .50088 .36585 .50597 .37729 Mtetra
.346 .228 .572 r
.49657 .33559 .49158 .33443 .49621 .34706 .50123 .3524 Mtetra
.459 .352 .645 r
.49193 .32426 .48696 .32554 .49158 .33443 .49657 .33559 Mtetra
.553 .461 .705 r
.48729 .31615 .48232 .31876 .48696 .32554 .49193 .32426 Mtetra
.618 .54 .744 r
.48265 .30979 .47768 .31311 .48232 .31876 .48729 .31615 Mtetra
.656 .587 .766 r
.478 .30437 .47303 .30805 .47768 .31311 .48265 .30979 Mtetra
.677 .614 .778 r
.47333 .29943 .46836 .30331 .47303 .30805 .478 .30437 Mtetra
.689 .629 .784 r
.46866 .29474 .46369 .29873 .46836 .30331 .47333 .29943 Mtetra
.695 .637 .787 r
.46398 .29018 .45901 .29422 .46369 .29873 .46866 .29474 Mtetra
.698 .641 .789 r
.45929 .28569 .45432 .28976 .45901 .29422 .46398 .29018 Mtetra
.699 .643 .79 r
.45459 .28123 .44962 .28532 .45432 .28976 .45929 .28569 Mtetra
.7 .644 .79 r
.44989 .27678 .44491 .28088 .44962 .28532 .45459 .28123 Mtetra
.701 .645 .79 r
.44517 .27233 .4402 .27645 .44491 .28088 .44989 .27678 Mtetra
.701 .645 .791 r
.44045 .26788 .43547 .27201 .4402 .27645 .44517 .27233 Mtetra
.43572 .26343 .43074 .26757 .43547 .27201 .44045 .26788 Mtetra
.701 .646 .791 r
.43098 .25898 .426 .26312 .43074 .26757 .43572 .26343 Mtetra
.42624 .25451 .42126 .25866 .426 .26312 .43098 .25898 Mtetra
.42148 .25004 .4165 .2542 .42126 .25866 .42624 .25451 Mtetra
.41672 .24556 .41174 .24973 .4165 .2542 .42148 .25004 Mtetra
.41195 .24108 .40697 .24525 .41174 .24973 .41672 .24556 Mtetra
.40717 .23659 .40219 .24077 .40697 .24525 .41195 .24108 Mtetra
.40239 .23209 .39741 .23627 .40219 .24077 .40717 .23659 Mtetra
.39759 .22758 .39261 .23177 .39741 .23627 .40239 .23209 Mtetra
.39279 .22307 .38781 .22727 .39261 .23177 .39759 .22758 Mtetra
.38798 .21855 .383 .22275 .38781 .22727 .39279 .22307 Mtetra
.38316 .21402 .37818 .21823 .383 .22275 .38798 .21855 Mtetra
.37834 .20948 .37335 .2137 .37818 .21823 .38316 .21402 Mtetra
.3735 .20493 .36852 .20916 .37335 .2137 .37834 .20948 Mtetra
.36866 .20038 .36368 .20462 .36852 .20916 .3735 .20493 Mtetra
.36381 .19582 .35882 .20006 .36368 .20462 .36866 .20038 Mtetra
.35895 .19125 .35397 .1955 .35882 .20006 .36381 .19582 Mtetra
.35408 .18668 .3491 .19093 .35397 .1955 .35895 .19125 Mtetra
.34921 .1821 .34422 .18636 .3491 .19093 .35408 .18668 Mtetra
.34432 .1775 .33934 .18177 .34422 .18636 .34921 .1821 Mtetra
.33943 .17291 .33445 .17718 .33934 .18177 .34432 .1775 Mtetra
.33453 .1683 .32955 .17258 .33445 .17718 .33943 .17291 Mtetra
.32962 .16368 .32464 .16798 .32955 .17258 .33453 .1683 Mtetra
.77902 .57786 .77409 .58152 .77827 .58545 .78321 .5818 Mtetra
.77484 .57391 .7699 .57758 .77409 .58152 .77902 .57786 Mtetra
.77064 .56996 .7657 .57364 .7699 .57758 .77484 .57391 Mtetra
.76644 .566 .7615 .56968 .7657 .57364 .77064 .56996 Mtetra
.76223 .56204 .75729 .56573 .7615 .56968 .76644 .566 Mtetra
.75801 .55807 .75307 .56176 .75729 .56573 .76223 .56204 Mtetra
.75379 .5541 .74885 .55779 .75307 .56176 .75801 .55807 Mtetra
.74956 .55011 .74462 .55382 .74885 .55779 .75379 .5541 Mtetra
.74532 .54612 .74038 .54983 .74462 .55382 .74956 .55011 Mtetra
.74108 .54213 .73614 .54584 .74038 .54983 .74532 .54612 Mtetra
.73683 .53813 .73189 .54185 .73614 .54584 .74108 .54213 Mtetra
.73258 .53412 .72763 .53785 .73189 .54185 .73683 .53813 Mtetra
.72831 .53011 .72337 .53384 .72763 .53785 .73258 .53412 Mtetra
.72404 .52609 .7191 .52982 .72337 .53384 .72831 .53011 Mtetra
.71977 .52206 .71482 .5258 .7191 .52982 .72404 .52609 Mtetra
.71548 .51803 .71054 .52178 .71482 .5258 .71977 .52206 Mtetra
.71119 .51399 .70625 .51774 .71054 .52178 .71548 .51803 Mtetra
.7069 .50994 .70195 .5137 .70625 .51774 .71119 .51399 Mtetra
.70259 .50589 .69765 .50966 .70195 .5137 .7069 .50994 Mtetra
.69828 .50183 .69333 .5056 .69765 .50966 .70259 .50589 Mtetra
.69397 .49776 .68902 .50154 .69333 .5056 .69828 .50183 Mtetra
.68964 .49369 .68469 .49748 .68902 .50154 .69397 .49776 Mtetra
.68531 .48961 .68036 .49341 .68469 .49748 .68964 .49369 Mtetra
.68097 .48553 .67602 .48933 .68036 .49341 .68531 .48961 Mtetra
.67663 .48144 .67168 .48525 .67602 .48933 .68097 .48553 Mtetra
.702 .646 .791 r
.67228 .47734 .66732 .48116 .67168 .48525 .67663 .48144 Mtetra
.66792 .47324 .66296 .47706 .66732 .48116 .67228 .47734 Mtetra
.66355 .46913 .6586 .47296 .66296 .47706 .66792 .47324 Mtetra
.65918 .46502 .65422 .46886 .6586 .47296 .66355 .46913 Mtetra
.6548 .46091 .64984 .46475 .65422 .46886 .65918 .46502 Mtetra
.702 .647 .791 r
.65042 .4568 .64546 .46065 .64984 .46475 .6548 .46091 Mtetra
.703 .647 .791 r
.64602 .45269 .64107 .45655 .64546 .46065 .65042 .4568 Mtetra
.704 .648 .792 r
.64163 .44859 .63667 .45247 .64107 .45655 .64602 .45269 Mtetra
.705 .65 .792 r
.63722 .44452 .63227 .44842 .63667 .45247 .64163 .44859 Mtetra
.708 .653 .793 r
.63282 .44049 .62786 .44442 .63227 .44842 .63722 .44452 Mtetra
.712 .658 .795 r
.62841 .43653 .62345 .44052 .62786 .44442 .63282 .44049 Mtetra
.718 .666 .797 r
.624 .4327 .61904 .43676 .62345 .44052 .62841 .43653 Mtetra
.729 .679 .801 r
.61959 .42908 .61464 .43326 .61904 .43676 .624 .4327 Mtetra
.746 .7 .807 r
.6152 .42579 .61025 .43016 .61464 .43326 .61959 .42908 Mtetra
.774 .734 .816 r
.61082 .42305 .60589 .4277 .61025 .43016 .6152 .42579 Mtetra
.817 .788 .826 r
.60648 .42115 .60156 .42624 .60589 .4277 .61082 .42305 Mtetra
.875 .868 .828 r
.60218 .42053 .59728 .42628 .60156 .42624 .60648 .42115 Mtetra
.923 .954 .79 r
.59796 .42175 .59308 .42837 .59728 .42628 .60218 .42053 Mtetra
.882 .97 .654 r
.59381 .42534 .58895 .43299 .59308 .42837 .59796 .42175 Mtetra
.721 .863 .444 r
.58973 .43146 .58487 .43999 .58895 .43299 .59381 .42534 Mtetra
0 0 0 r
.58567 .43922 .58078 .4479 .58487 .43999 .58973 .43146 Mtetra
.58152 .44608 .57653 .45356 .58078 .4479 .58567 .43922 Mtetra
.751 .988 .774 r
.57713 .4483 .57203 .45329 .57653 .45356 .58152 .44608 Mtetra
.591 .59 .819 r
.57244 .4432 .56725 .44544 .57203 .45329 .57713 .4483 Mtetra
.447 .347 .648 r
.56752 .43133 .5623 .43193 .56725 .44544 .57244 .4432 Mtetra
.438 .305 .601 r
.56252 .41615 .55734 .41676 .5623 .43193 .56752 .43133 Mtetra
.484 .334 .602 r
.55759 .40152 .55247 .40348 .55734 .41676 .56252 .41615 Mtetra
.578 .416 .625 r
.55277 .39002 .54774 .39435 .55247 .40348 .55759 .40152 Mtetra
.733 .554 .651 r
.54809 .38312 .54314 .39089 .54774 .39435 .55277 .39002 Mtetra
.917 .723 .626 r
.54355 .38217 .53868 .39487 .54314 .39089 .54809 .38312 Mtetra
1 .821 .494 r
.53914 .38907 .53432 .40828 .53868 .39487 .54355 .38217 Mtetra
.885 .78 .285 r
.53483 .40573 .53001 .43086 .53432 .40828 .53914 .38907 Mtetra
0 0 0 r
.53054 .43053 .52557 .45462 .53001 .43086 .53483 .40573 Mtetra
.01 0 .158 r
.52606 .45249 .52084 .46264 .52557 .45462 .53054 .43053 Mtetra
.723 .247 .118 r
.52124 .45384 .51585 .44458 .52084 .46264 .52606 .45249 Mtetra
0 0 .322 r
.51619 .42939 .51084 .41057 .51585 .44458 .52124 .45384 Mtetra
0 0 .412 r
.51118 .39372 .50597 .37729 .51084 .41057 .51619 .42939 Mtetra
.14 .034 .462 r
.50632 .36217 .50123 .3524 .50597 .37729 .51118 .39372 Mtetra
.26 .14 .52 r
.50159 .33963 .49657 .33559 .50123 .3524 .50632 .36217 Mtetra
.377 .261 .592 r
.49692 .32461 .49193 .32426 .49657 .33559 .50159 .33963 Mtetra
.488 .385 .664 r
.49227 .3144 .48729 .31615 .49193 .32426 .49692 .32461 Mtetra
.575 .488 .719 r
.48763 .30692 .48265 .30979 .48729 .31615 .49227 .3144 Mtetra
.631 .557 .752 r
.48297 .3009 .478 .30437 .48265 .30979 .48763 .30692 Mtetra
.664 .598 .771 r
.47831 .29566 .47333 .29943 .478 .30437 .48297 .3009 Mtetra
.682 .62 .78 r
.47364 .29081 .46866 .29474 .47333 .29943 .47831 .29566 Mtetra
.691 .632 .785 r
.46896 .28617 .46398 .29018 .46866 .29474 .47364 .29081 Mtetra
.696 .638 .788 r
.46427 .28163 .45929 .28569 .46398 .29018 .46896 .28617 Mtetra
.698 .642 .789 r
.45958 .27713 .45459 .28123 .45929 .28569 .46427 .28163 Mtetra
.7 .644 .79 r
.45487 .27267 .44989 .27678 .45459 .28123 .45958 .27713 Mtetra
.701 .645 .79 r
.45016 .26821 .44517 .27233 .44989 .27678 .45487 .27267 Mtetra
.701 .645 .791 r
.44543 .26375 .44045 .26788 .44517 .27233 .45016 .26821 Mtetra
.44071 .25929 .43572 .26343 .44045 .26788 .44543 .26375 Mtetra
.43597 .25483 .43098 .25898 .43572 .26343 .44071 .25929 Mtetra
.701 .646 .791 r
.43122 .25036 .42624 .25451 .43098 .25898 .43597 .25483 Mtetra
.42647 .24588 .42148 .25004 .42624 .25451 .43122 .25036 Mtetra
.42171 .24139 .41672 .24556 .42148 .25004 .42647 .24588 Mtetra
.41694 .2369 .41195 .24108 .41672 .24556 .42171 .24139 Mtetra
.41216 .2324 .40717 .23659 .41195 .24108 .41694 .2369 Mtetra
.40737 .2279 .40239 .23209 .40717 .23659 .41216 .2324 Mtetra
.40258 .22338 .39759 .22758 .40239 .23209 .40737 .2279 Mtetra
.39778 .21886 .39279 .22307 .39759 .22758 .40258 .22338 Mtetra
.39297 .21433 .38798 .21855 .39279 .22307 .39778 .21886 Mtetra
.38815 .2098 .38316 .21402 .38798 .21855 .39297 .21433 Mtetra
.38333 .20525 .37834 .20948 .38316 .21402 .38815 .2098 Mtetra
.37849 .2007 .3735 .20493 .37834 .20948 .38333 .20525 Mtetra
.37365 .19614 .36866 .20038 .3735 .20493 .37849 .2007 Mtetra
.3688 .19157 .36381 .19582 .36866 .20038 .37365 .19614 Mtetra
.36394 .187 .35895 .19125 .36381 .19582 .3688 .19157 Mtetra
.35907 .18242 .35408 .18668 .35895 .19125 .36394 .187 Mtetra
.3542 .17783 .34921 .1821 .35408 .18668 .35907 .18242 Mtetra
.34932 .17323 .34432 .1775 .34921 .1821 .3542 .17783 Mtetra
.34442 .16862 .33943 .17291 .34432 .1775 .34932 .17323 Mtetra
.33952 .16401 .33453 .1683 .33943 .17291 .34442 .16862 Mtetra
.33462 .15939 .32962 .16368 .33453 .1683 .33952 .16401 Mtetra
.78397 .57419 .77902 .57786 .78321 .5818 .78815 .57813 Mtetra
.77978 .57024 .77484 .57391 .77902 .57786 .78397 .57419 Mtetra
.77558 .56628 .77064 .56996 .77484 .57391 .77978 .57024 Mtetra
.77138 .56232 .76644 .566 .77064 .56996 .77558 .56628 Mtetra
.76717 .55835 .76223 .56204 .76644 .566 .77138 .56232 Mtetra
.76296 .55437 .75801 .55807 .76223 .56204 .76717 .55835 Mtetra
.75874 .55039 .75379 .5541 .75801 .55807 .76296 .55437 Mtetra
.75451 .5464 .74956 .55011 .75379 .5541 .75874 .55039 Mtetra
.75027 .54241 .74532 .54612 .74956 .55011 .75451 .5464 Mtetra
.74603 .53841 .74108 .54213 .74532 .54612 .75027 .54241 Mtetra
.74178 .5344 .73683 .53813 .74108 .54213 .74603 .53841 Mtetra
.73753 .53039 .73258 .53412 .73683 .53813 .74178 .5344 Mtetra
.73326 .52637 .72831 .53011 .73258 .53412 .73753 .53039 Mtetra
.729 .52234 .72404 .52609 .72831 .53011 .73326 .52637 Mtetra
.72472 .51831 .71977 .52206 .72404 .52609 .729 .52234 Mtetra
.72044 .51427 .71548 .51803 .71977 .52206 .72472 .51831 Mtetra
.71615 .51022 .71119 .51399 .71548 .51803 .72044 .51427 Mtetra
.71185 .50617 .7069 .50994 .71119 .51399 .71615 .51022 Mtetra
.70755 .50211 .70259 .50589 .7069 .50994 .71185 .50617 Mtetra
.70324 .49805 .69828 .50183 .70259 .50589 .70755 .50211 Mtetra
.69892 .49398 .69397 .49776 .69828 .50183 .70324 .49805 Mtetra
.6946 .4899 .68964 .49369 .69397 .49776 .69892 .49398 Mtetra
.69027 .48582 .68531 .48961 .68964 .49369 .6946 .4899 Mtetra
.68593 .48173 .68097 .48553 .68531 .48961 .69027 .48582 Mtetra
.68159 .47763 .67663 .48144 .68097 .48553 .68593 .48173 Mtetra
.67724 .47353 .67228 .47734 .67663 .48144 .68159 .47763 Mtetra
.702 .646 .791 r
.67288 .46942 .66792 .47324 .67228 .47734 .67724 .47353 Mtetra
.66851 .4653 .66355 .46913 .66792 .47324 .67288 .46942 Mtetra
.66414 .46119 .65918 .46502 .66355 .46913 .66851 .4653 Mtetra
.65976 .45706 .6548 .46091 .65918 .46502 .66414 .46119 Mtetra
.702 .647 .791 r
.65538 .45294 .65042 .4568 .6548 .46091 .65976 .45706 Mtetra
.703 .647 .791 r
.65099 .44882 .64602 .45269 .65042 .4568 .65538 .45294 Mtetra
.703 .648 .792 r
.64659 .44471 .64163 .44859 .64602 .45269 .65099 .44882 Mtetra
.705 .649 .792 r
.64219 .44062 .63722 .44452 .64163 .44859 .64659 .44471 Mtetra
.707 .652 .793 r
.63778 .43656 .63282 .44049 .63722 .44452 .64219 .44062 Mtetra
.71 .656 .794 r
.63337 .43256 .62841 .43653 .63282 .44049 .63778 .43656 Mtetra
.715 .662 .796 r
.62896 .42867 .624 .4327 .62841 .43653 .63337 .43256 Mtetra
.724 .673 .8 r
.62455 .42495 .61959 .42908 .624 .4327 .62896 .42867 Mtetra
.739 .691 .805 r
.62015 .4215 .6152 .42579 .61959 .42908 .62455 .42495 Mtetra
.762 .719 .812 r
.61576 .41851 .61082 .42305 .6152 .42579 .62015 .4215 Mtetra
.799 .765 .822 r
.61141 .41624 .60648 .42115 .61082 .42305 .61576 .41851 Mtetra
.852 .835 .829 r
.6071 .41506 .60218 .42053 .60648 .42115 .61141 .41624 Mtetra
.909 .924 .813 r
.60285 .41549 .59796 .42175 .60218 .42053 .6071 .41506 Mtetra
.913 .979 .72 r
.59868 .4181 .59381 .42534 .59796 .42175 .60285 .41549 Mtetra
.789 .913 .524 r
.59459 .42325 .58973 .43146 .59381 .42534 .59868 .4181 Mtetra
0 0 0 r
.59055 .43052 .58567 .43922 .58973 .43146 .59459 .42325 Mtetra
.58647 .43804 .58152 .44608 .58567 .43922 .59055 .43052 Mtetra
.627 .882 .545 r
.58219 .44236 .57713 .4483 .58152 .44608 .58647 .43804 Mtetra
.705 .793 .919 r
.57761 .44008 .57244 .4432 .57713 .4483 .58219 .44236 Mtetra
.47 .396 .691 r
.57275 .4304 .56752 .43133 .57244 .4432 .57761 .44008 Mtetra
.426 .304 .61 r
.56774 .4159 .56252 .41615 .56752 .43133 .57275 .4304 Mtetra
.45 .309 .596 r
.56275 .40049 .55759 .40152 .56252 .41615 .56774 .4159 Mtetra
.517 .364 .613 r
.55785 .38721 .55277 .39002 .55759 .40152 .56275 .40049 Mtetra
.633 .469 .643 r
.5531 .37771 .54809 .38312 .55277 .39002 .55785 .38721 Mtetra
.804 .624 .657 r
.54848 .37302 .54355 .38217 .54809 .38312 .5531 .37771 Mtetra
.966 .775 .596 r
.54399 .37452 .53914 .38907 .54355 .38217 .54848 .37302 Mtetra
.986 .823 .432 r
.53963 .38434 .53483 .40573 .53914 .38907 .54399 .37452 Mtetra
.815 .74 .216 r
.53536 .40408 .53054 .43053 .53483 .40573 .53963 .38434 Mtetra
0 0 .02 r
.53107 .43024 .52606 .45249 .53054 .43053 .53536 .40408 Mtetra
.177 0 .188 r
.52653 .44882 .52124 .45384 .52606 .45249 .53107 .43024 Mtetra
.838 .375 0 r
.52162 .44282 .51619 .42939 .52124 .45384 .52653 .44882 Mtetra
0 0 .357 r
.51652 .41313 .51118 .39372 .51619 .42939 .52162 .44282 Mtetra
.026 0 .424 r
.51151 .37712 .50632 .36217 .51118 .39372 .51652 .41313 Mtetra
.171 .059 .474 r
.50667 .34775 .50159 .33963 .50632 .36217 .51151 .37712 Mtetra
.289 .169 .538 r
.50194 .32748 .49692 .32461 .50159 .33963 .50667 .34775 Mtetra
.407 .295 .613 r
.49727 .31404 .49227 .3144 .49692 .32461 .50194 .32748 Mtetra
.515 .417 .682 r
.49261 .30477 .48763 .30692 .49227 .3144 .49727 .31404 Mtetra
.594 .511 .731 r
.48796 .29781 .48297 .3009 .48763 .30692 .49261 .30477 Mtetra
.643 .571 .759 r
.4833 .29207 .47831 .29566 .48297 .3009 .48796 .29781 Mtetra
.671 .606 .774 r
.47863 .28697 .47364 .29081 .47831 .29566 .4833 .29207 Mtetra
.685 .625 .782 r
.47395 .28219 .46896 .28617 .47364 .29081 .47863 .28697 Mtetra
.693 .635 .786 r
.46926 .27758 .46427 .28163 .46896 .28617 .47395 .28219 Mtetra
.697 .64 .788 r
.46457 .27305 .45958 .27713 .46427 .28163 .46926 .27758 Mtetra
.699 .642 .789 r
.45986 .26856 .45487 .27267 .45958 .27713 .46457 .27305 Mtetra
.7 .644 .79 r
.45515 .26408 .45016 .26821 .45487 .27267 .45986 .26856 Mtetra
.701 .645 .79 r
.45043 .25962 .44543 .26375 .45016 .26821 .45515 .26408 Mtetra
.701 .645 .791 r
.4457 .25515 .44071 .25929 .44543 .26375 .45043 .25962 Mtetra
.44096 .25067 .43597 .25483 .44071 .25929 .4457 .25515 Mtetra
.701 .646 .791 r
.43622 .2462 .43122 .25036 .43597 .25483 .44096 .25067 Mtetra
.43146 .24171 .42647 .24588 .43122 .25036 .43622 .2462 Mtetra
.4267 .23722 .42171 .24139 .42647 .24588 .43146 .24171 Mtetra
.42193 .23272 .41694 .2369 .42171 .24139 .4267 .23722 Mtetra
.41716 .22821 .41216 .2324 .41694 .2369 .42193 .23272 Mtetra
.41237 .2237 .40737 .2279 .41216 .2324 .41716 .22821 Mtetra
.40758 .21918 .40258 .22338 .40737 .2279 .41237 .2237 Mtetra
.40278 .21465 .39778 .21886 .40258 .22338 .40758 .21918 Mtetra
.39797 .21012 .39297 .21433 .39778 .21886 .40278 .21465 Mtetra
.39315 .20557 .38815 .2098 .39297 .21433 .39797 .21012 Mtetra
.38832 .20102 .38333 .20525 .38815 .2098 .39315 .20557 Mtetra
.38349 .19646 .37849 .2007 .38333 .20525 .38832 .20102 Mtetra
.37865 .1919 .37365 .19614 .37849 .2007 .38349 .19646 Mtetra
.3738 .18732 .3688 .19157 .37365 .19614 .37865 .1919 Mtetra
.36894 .18274 .36394 .187 .3688 .19157 .3738 .18732 Mtetra
.36407 .17815 .35907 .18242 .36394 .187 .36894 .18274 Mtetra
.3592 .17355 .3542 .17783 .35907 .18242 .36407 .17815 Mtetra
.35432 .16895 .34932 .17323 .3542 .17783 .3592 .17355 Mtetra
.34943 .16433 .34442 .16862 .34932 .17323 .35432 .16895 Mtetra
.34453 .15971 .33952 .16401 .34442 .16862 .34943 .16433 Mtetra
.33962 .15508 .33462 .15939 .33952 .16401 .34453 .15971 Mtetra
.78892 .57052 .78397 .57419 .78815 .57813 .7931 .57447 Mtetra
.78473 .56656 .77978 .57024 .78397 .57419 .78892 .57052 Mtetra
.78053 .5626 .77558 .56628 .77978 .57024 .78473 .56656 Mtetra
.77633 .55863 .77138 .56232 .77558 .56628 .78053 .5626 Mtetra
.77212 .55465 .76717 .55835 .77138 .56232 .77633 .55863 Mtetra
.76791 .55067 .76296 .55437 .76717 .55835 .77212 .55465 Mtetra
.76369 .54668 .75874 .55039 .76296 .55437 .76791 .55067 Mtetra
.75946 .54269 .75451 .5464 .75874 .55039 .76369 .54668 Mtetra
.75523 .53869 .75027 .54241 .75451 .5464 .75946 .54269 Mtetra
.75099 .53468 .74603 .53841 .75027 .54241 .75523 .53869 Mtetra
.74674 .53067 .74178 .5344 .74603 .53841 .75099 .53468 Mtetra
.74248 .52665 .73753 .53039 .74178 .5344 .74674 .53067 Mtetra
.73822 .52262 .73326 .52637 .73753 .53039 .74248 .52665 Mtetra
.73395 .51859 .729 .52234 .73326 .52637 .73822 .52262 Mtetra
.72968 .51455 .72472 .51831 .729 .52234 .73395 .51859 Mtetra
.7254 .51051 .72044 .51427 .72472 .51831 .72968 .51455 Mtetra
.72111 .50646 .71615 .51022 .72044 .51427 .7254 .51051 Mtetra
.71682 .5024 .71185 .50617 .71615 .51022 .72111 .50646 Mtetra
.71251 .49833 .70755 .50211 .71185 .50617 .71682 .5024 Mtetra
.7082 .49426 .70324 .49805 .70755 .50211 .71251 .49833 Mtetra
.70389 .49019 .69892 .49398 .70324 .49805 .7082 .49426 Mtetra
.69957 .4861 .6946 .4899 .69892 .49398 .70389 .49019 Mtetra
.69524 .48201 .69027 .48582 .6946 .4899 .69957 .4861 Mtetra
.6909 .47792 .68593 .48173 .69027 .48582 .69524 .48201 Mtetra
.68656 .47381 .68159 .47763 .68593 .48173 .6909 .47792 Mtetra
.68221 .4697 .67724 .47353 .68159 .47763 .68656 .47381 Mtetra
.702 .646 .791 r
.67785 .46559 .67288 .46942 .67724 .47353 .68221 .4697 Mtetra
.67348 .46147 .66851 .4653 .67288 .46942 .67785 .46559 Mtetra
.66911 .45734 .66414 .46119 .66851 .4653 .67348 .46147 Mtetra
.66474 .45321 .65976 .45706 .66414 .46119 .66911 .45734 Mtetra
.66035 .44908 .65538 .45294 .65976 .45706 .66474 .45321 Mtetra
.702 .647 .791 r
.65596 .44495 .65099 .44882 .65538 .45294 .66035 .44908 Mtetra
.703 .648 .791 r
.65156 .44083 .64659 .44471 .65099 .44882 .65596 .44495 Mtetra
.704 .649 .792 r
.64716 .43672 .64219 .44062 .64659 .44471 .65156 .44083 Mtetra
.706 .651 .793 r
.64275 .43264 .63778 .43656 .64219 .44062 .64716 .43672 Mtetra
.709 .654 .794 r
.63834 .4286 .63337 .43256 .63778 .43656 .64275 .43264 Mtetra
.713 .66 .795 r
.63393 .42465 .62896 .42867 .63337 .43256 .63834 .4286 Mtetra
.72 .668 .798 r
.62952 .42085 .62455 .42495 .62896 .42867 .63393 .42465 Mtetra
.732 .683 .803 r
.62511 .41727 .62015 .4215 .62455 .42495 .62952 .42085 Mtetra
.752 .707 .809 r
.62072 .41408 .61576 .41851 .62015 .4215 .62511 .41727 Mtetra
.783 .745 .818 r
.61635 .41148 .61141 .41624 .61576 .41851 .62072 .41408 Mtetra
.83 .806 .828 r
.61202 .40982 .6071 .41506 .61141 .41624 .61635 .41148 Mtetra
.889 .89 .825 r
.60775 .40956 .60285 .41549 .6071 .41506 .61202 .40982 Mtetra
.924 .969 .769 r
.60356 .41126 .59868 .4181 .60285 .41549 .60775 .40956 Mtetra
.849 .954 .606 r
.59946 .4154 .59459 .42325 .59868 .4181 .60356 .41126 Mtetra
.672 .829 .399 r
.59542 .42195 .59055 .43052 .59459 .42325 .59946 .4154 Mtetra
0 0 0 r
.59139 .42963 .58647 .43804 .59055 .43052 .59542 .42195 Mtetra
.58721 .43554 .58219 .44236 .58647 .43804 .59139 .42963 Mtetra
.778 .978 .911 r
.58276 .43597 .57761 .44008 .58219 .44236 .58721 .43554 Mtetra
.52 .486 .759 r
.57798 .42888 .57275 .4304 .57761 .44008 .58276 .43597 Mtetra
.426 .318 .629 r
.57299 .41569 .56774 .4159 .57275 .4304 .57798 .42888 Mtetra
.429 .295 .596 r
.56795 .40008 .56275 .40049 .56774 .4159 .57299 .41569 Mtetra
.474 .328 .602 r
.56299 .38551 .55785 .38721 .56275 .40049 .56795 .40008 Mtetra
.559 .405 .629 r
.55815 .374 .5531 .37771 .55785 .38721 .56299 .38551 Mtetra
.696 .53 .659 r
.55345 .3665 .54848 .37302 .5531 .37771 .55815 .374 Mtetra
.872 .69 .653 r
.54889 .36392 .54399 .37452 .54848 .37302 .55345 .3665 Mtetra
.993 .808 .553 r
.54445 .36785 .53963 .38434 .54399 .37452 .54889 .36392 Mtetra
.955 .81 .368 r
.54014 .3806 .53536 .40408 .53963 .38434 .54445 .36785 Mtetra
.732 .691 .15 r
.53591 .40315 .53107 .43024 .53536 .40408 .54014 .3806 Mtetra
0 0 .077 r
.53161 .42958 .52653 .44882 .53107 .43024 .53591 .40315 Mtetra
.358 0 .198 r
.52698 .44324 .52162 .44282 .52653 .44882 .53161 .42958 Mtetra
.749 .398 0 r
.52198 .42979 .51652 .41313 .52162 .44282 .52698 .44324 Mtetra
0 0 .378 r
.51685 .39626 .51151 .37712 .51652 .41313 .52198 .42979 Mtetra
.067 0 .435 r
.51185 .361 .50667 .34775 .51151 .37712 .51685 .39626 Mtetra
.2 .084 .488 r
.50702 .33404 .50194 .32748 .50667 .34775 .51185 .361 Mtetra
.319 .2 .557 r
.50229 .31587 .49727 .31404 .50194 .32748 .50702 .33404 Mtetra
.437 .329 .633 r
.49762 .30381 .49261 .30477 .49727 .31404 .50229 .31587 Mtetra
.539 .446 .698 r
.49295 .29533 .48796 .29781 .49261 .30477 .49762 .30381 Mtetra
.61 .531 .741 r
.48829 .2888 .4833 .29207 .48796 .29781 .49295 .29533 Mtetra
.653 .584 .765 r
.48362 .28328 .47863 .28697 .4833 .29207 .48829 .2888 Mtetra
.676 .613 .777 r
.47895 .27829 .47395 .28219 .47863 .28697 .48362 .28328 Mtetra
.688 .629 .784 r
.47426 .27357 .46926 .27758 .47395 .28219 .47895 .27829 Mtetra
.695 .637 .787 r
.46956 .26898 .46457 .27305 .46926 .27758 .47426 .27357 Mtetra
.698 .641 .789 r
.46486 .26445 .45986 .26856 .46457 .27305 .46956 .26898 Mtetra
.7 .643 .79 r
.46015 .25996 .45515 .26408 .45986 .26856 .46486 .26445 Mtetra
.7 .644 .79 r
.45543 .25548 .45043 .25962 .45515 .26408 .46015 .25996 Mtetra
.701 .645 .791 r
.4507 .251 .4457 .25515 .45043 .25962 .45543 .25548 Mtetra
.44596 .24651 .44096 .25067 .4457 .25515 .4507 .251 Mtetra
.44122 .24203 .43622 .2462 .44096 .25067 .44596 .24651 Mtetra
.701 .646 .791 r
.43646 .23754 .43146 .24171 .43622 .2462 .44122 .24203 Mtetra
.4317 .23304 .4267 .23722 .43146 .24171 .43646 .23754 Mtetra
.42694 .22853 .42193 .23272 .4267 .23722 .4317 .23304 Mtetra
.42216 .22402 .41716 .22821 .42193 .23272 .42694 .22853 Mtetra
.41737 .2195 .41237 .2237 .41716 .22821 .42216 .22402 Mtetra
.41258 .21497 .40758 .21918 .41237 .2237 .41737 .2195 Mtetra
.40778 .21043 .40278 .21465 .40758 .21918 .41258 .21497 Mtetra
.40297 .20589 .39797 .21012 .40278 .21465 .40778 .21043 Mtetra
.39816 .20134 .39315 .20557 .39797 .21012 .40297 .20589 Mtetra
.39333 .19678 .38832 .20102 .39315 .20557 .39816 .20134 Mtetra
.3885 .19222 .38349 .19646 .38832 .20102 .39333 .19678 Mtetra
.38366 .18764 .37865 .1919 .38349 .19646 .3885 .19222 Mtetra
.37881 .18306 .3738 .18732 .37865 .1919 .38366 .18764 Mtetra
.37395 .17847 .36894 .18274 .3738 .18732 .37881 .18306 Mtetra
.36908 .17387 .36407 .17815 .36894 .18274 .37395 .17847 Mtetra
.36421 .16927 .3592 .17355 .36407 .17815 .36908 .17387 Mtetra
.35933 .16466 .35432 .16895 .3592 .17355 .36421 .16927 Mtetra
.35444 .16004 .34943 .16433 .35432 .16895 .35933 .16466 Mtetra
.34954 .15541 .34453 .15971 .34943 .16433 .35444 .16004 Mtetra
.34463 .15077 .33962 .15508 .34453 .15971 .34954 .15541 Mtetra
.79387 .56684 .78892 .57052 .7931 .57447 .79805 .57079 Mtetra
.78968 .56287 .78473 .56656 .78892 .57052 .79387 .56684 Mtetra
.78549 .55891 .78053 .5626 .78473 .56656 .78968 .56287 Mtetra
.78129 .55493 .77633 .55863 .78053 .5626 .78549 .55891 Mtetra
.77708 .55095 .77212 .55465 .77633 .55863 .78129 .55493 Mtetra
.77287 .54696 .76791 .55067 .77212 .55465 .77708 .55095 Mtetra
.76865 .54297 .76369 .54668 .76791 .55067 .77287 .54696 Mtetra
.76442 .53897 .75946 .54269 .76369 .54668 .76865 .54297 Mtetra
.76019 .53496 .75523 .53869 .75946 .54269 .76442 .53897 Mtetra
.75595 .53095 .75099 .53468 .75523 .53869 .76019 .53496 Mtetra
.7517 .52693 .74674 .53067 .75099 .53468 .75595 .53095 Mtetra
.74745 .52291 .74248 .52665 .74674 .53067 .7517 .52693 Mtetra
.74319 .51887 .73822 .52262 .74248 .52665 .74745 .52291 Mtetra
.73892 .51484 .73395 .51859 .73822 .52262 .74319 .51887 Mtetra
.73465 .51079 .72968 .51455 .73395 .51859 .73892 .51484 Mtetra
.73037 .50674 .7254 .51051 .72968 .51455 .73465 .51079 Mtetra
.72608 .50268 .72111 .50646 .7254 .51051 .73037 .50674 Mtetra
.72179 .49862 .71682 .5024 .72111 .50646 .72608 .50268 Mtetra
.71748 .49455 .71251 .49833 .71682 .5024 .72179 .49862 Mtetra
.71318 .49047 .7082 .49426 .71251 .49833 .71748 .49455 Mtetra
.70886 .48639 .70389 .49019 .7082 .49426 .71318 .49047 Mtetra
.70454 .4823 .69957 .4861 .70389 .49019 .70886 .48639 Mtetra
.70021 .4782 .69524 .48201 .69957 .4861 .70454 .4823 Mtetra
.69587 .4741 .6909 .47792 .69524 .48201 .70021 .4782 Mtetra
.69153 .46999 .68656 .47381 .6909 .47792 .69587 .4741 Mtetra
.68718 .46587 .68221 .4697 .68656 .47381 .69153 .46999 Mtetra
.68283 .46175 .67785 .46559 .68221 .4697 .68718 .46587 Mtetra
.702 .646 .791 r
.67846 .45763 .67348 .46147 .67785 .46559 .68283 .46175 Mtetra
.67409 .45349 .66911 .45734 .67348 .46147 .67846 .45763 Mtetra
.66971 .44936 .66474 .45321 .66911 .45734 .67409 .45349 Mtetra
.66533 .44522 .66035 .44908 .66474 .45321 .66971 .44936 Mtetra
.702 .647 .791 r
.66094 .44108 .65596 .44495 .66035 .44908 .66533 .44522 Mtetra
.703 .647 .791 r
.65654 .43694 .65156 .44083 .65596 .44495 .66094 .44108 Mtetra
.704 .648 .792 r
.65214 .43282 .64716 .43672 .65156 .44083 .65654 .43694 Mtetra
.705 .65 .792 r
.64773 .42871 .64275 .43264 .64716 .43672 .65214 .43282 Mtetra
.707 .653 .793 r
.64332 .42465 .63834 .4286 .64275 .43264 .64773 .42871 Mtetra
.711 .657 .795 r
.63891 .42066 .63393 .42465 .63834 .4286 .64332 .42465 Mtetra
.717 .665 .797 r
.63449 .41678 .62952 .42085 .63393 .42465 .63891 .42066 Mtetra
.727 .677 .801 r
.63008 .41309 .62511 .41727 .62952 .42085 .63449 .41678 Mtetra
.744 .696 .806 r
.62568 .40972 .62072 .41408 .62511 .41727 .63008 .41309 Mtetra
.77 .729 .815 r
.62131 .40685 .61635 .41148 .62072 .41408 .62568 .40972 Mtetra
.81 .78 .825 r
.61696 .40478 .61202 .40982 .61635 .41148 .62131 .40685 Mtetra
.866 .856 .83 r
.61267 .40392 .60775 .40956 .61202 .40982 .61696 .40478 Mtetra
.918 .945 .801 r
.60846 .40479 .60356 .41126 .60775 .40956 .61267 .40392 Mtetra
.894 .976 .68 r
.60433 .40794 .59946 .4154 .60356 .41126 .60846 .40479 Mtetra
.741 .881 .473 r
.60029 .4136 .59542 .42195 .59946 .4154 .60433 .40794 Mtetra
0 0 0 r
.59628 .42106 .59139 .42963 .59542 .42195 .60029 .4136 Mtetra
.5922 .428 .58721 .43554 .59139 .42963 .59628 .42106 Mtetra
.7 .959 .703 r
.58787 .43082 .58276 .43597 .58721 .43554 .5922 .428 Mtetra
.611 .641 .856 r
.58321 .42655 .57798 .42888 .58276 .43597 .58787 .43082 Mtetra
.439 .351 .66 r
.57826 .41525 .57299 .41569 .57798 .42888 .58321 .42655 Mtetra
.417 .292 .601 r
.5732 .40002 .56795 .40008 .57299 .41569 .57826 .41525 Mtetra
.445 .305 .596 r
.56817 .38461 .56299 .38551 .56795 .40008 .5732 .40002 Mtetra
.507 .36 .616 r
.56326 .37151 .55815 .374 .56299 .38551 .56817 .38461 Mtetra
.609 .456 .649 r
.55848 .36187 .55345 .3665 .55815 .374 .56326 .37151 Mtetra
.761 .595 .672 r
.55384 .35629 .54889 .36392 .55345 .3665 .55848 .36187 Mtetra
.928 .746 .636 r
.54932 .35574 .54445 .36785 .54889 .36392 .55384 .35629 Mtetra
1 .823 .501 r
.54493 .3621 .54014 .3806 .54445 .36785 .54932 .35574 Mtetra
.912 .787 .306 r
.54068 .37778 .53591 .40315 .54014 .3806 .54493 .3621 Mtetra
0 0 0 r
.53648 .4027 .53161 .42958 .53591 .40315 .54068 .37778 Mtetra
0 0 .127 r
.53214 .42811 .52698 .44324 .53161 .42958 .53648 .4027 Mtetra
.558 .128 .179 r
.52741 .43556 .52198 .42979 .52698 .44324 .53214 .42811 Mtetra
0 0 .265 r
.52232 .4151 .51685 .39626 .52198 .42979 .52741 .43556 Mtetra
0 0 .394 r
.51717 .37919 .51185 .361 .51685 .39626 .52232 .4151 Mtetra
.104 .005 .446 r
.51219 .34549 .50702 .33404 .51185 .361 .51717 .37919 Mtetra
.229 .111 .504 r
.50737 .32099 .50229 .31587 .50702 .33404 .51219 .34549 Mtetra
.349 .233 .577 r
.50265 .30474 .49762 .30381 .50229 .31587 .50737 .32099 Mtetra
.466 .362 .652 r
.49797 .29386 .49295 .29533 .49762 .30381 .50265 .30474 Mtetra
.562 .473 .712 r
.4933 .28604 .48829 .2888 .49295 .29533 .49797 .29386 Mtetra
.625 .549 .749 r
.48863 .27986 .48362 .28328 .48829 .2888 .4933 .28604 Mtetra
.661 .594 .769 r
.48395 .27452 .47895 .27829 .48362 .28328 .48863 .27986 Mtetra
.68 .619 .78 r
.47926 .26962 .47426 .27357 .47895 .27829 .48395 .27452 Mtetra
.691 .632 .785 r
.47457 .26494 .46956 .26898 .47426 .27357 .47926 .26962 Mtetra
.696 .638 .788 r
.46987 .26036 .46486 .26445 .46956 .26898 .47457 .26494 Mtetra
.698 .642 .789 r
.46515 .25583 .46015 .25996 .46486 .26445 .46987 .26036 Mtetra
.7 .644 .79 r
.46043 .25133 .45543 .25548 .46015 .25996 .46515 .25583 Mtetra
.701 .645 .79 r
.45571 .24684 .4507 .251 .45543 .25548 .46043 .25133 Mtetra
.701 .645 .791 r
.45097 .24235 .44596 .24651 .4507 .251 .45571 .24684 Mtetra
.44623 .23785 .44122 .24203 .44596 .24651 .45097 .24235 Mtetra
.701 .646 .791 r
.44147 .23335 .43646 .23754 .44122 .24203 .44623 .23785 Mtetra
.43671 .22885 .4317 .23304 .43646 .23754 .44147 .23335 Mtetra
.43195 .22434 .42694 .22853 .4317 .23304 .43671 .22885 Mtetra
.42717 .21981 .42216 .22402 .42694 .22853 .43195 .22434 Mtetra
.42239 .21529 .41737 .2195 .42216 .22402 .42717 .21981 Mtetra
.41759 .21075 .41258 .21497 .41737 .2195 .42239 .21529 Mtetra
.41279 .20621 .40778 .21043 .41258 .21497 .41759 .21075 Mtetra
.40799 .20166 .40297 .20589 .40778 .21043 .41279 .20621 Mtetra
.40317 .1971 .39816 .20134 .40297 .20589 .40799 .20166 Mtetra
.39834 .19254 .39333 .19678 .39816 .20134 .40317 .1971 Mtetra
.39351 .18796 .3885 .19222 .39333 .19678 .39834 .19254 Mtetra
.38867 .18338 .38366 .18764 .3885 .19222 .39351 .18796 Mtetra
.38382 .17879 .37881 .18306 .38366 .18764 .38867 .18338 Mtetra
.37896 .1742 .37395 .17847 .37881 .18306 .38382 .17879 Mtetra
.3741 .16959 .36908 .17387 .37395 .17847 .37896 .1742 Mtetra
.36923 .16498 .36421 .16927 .36908 .17387 .3741 .16959 Mtetra
.36434 .16036 .35933 .16466 .36421 .16927 .36923 .16498 Mtetra
.35945 .15573 .35444 .16004 .35933 .16466 .36434 .16036 Mtetra
.35455 .1511 .34954 .15541 .35444 .16004 .35945 .15573 Mtetra
.34965 .14645 .34463 .15077 .34954 .15541 .35455 .1511 Mtetra
.79884 .56315 .79387 .56684 .79805 .57079 .80301 .56711 Mtetra
.79465 .55918 .78968 .56287 .79387 .56684 .79884 .56315 Mtetra
.79046 .55521 .78549 .55891 .78968 .56287 .79465 .55918 Mtetra
.78626 .55123 .78129 .55493 .78549 .55891 .79046 .55521 Mtetra
.78205 .54724 .77708 .55095 .78129 .55493 .78626 .55123 Mtetra
.77784 .54325 .77287 .54696 .77708 .55095 .78205 .54724 Mtetra
.77362 .53925 .76865 .54297 .77287 .54696 .77784 .54325 Mtetra
.76939 .53524 .76442 .53897 .76865 .54297 .77362 .53925 Mtetra
.76516 .53123 .76019 .53496 .76442 .53897 .76939 .53524 Mtetra
.76092 .52721 .75595 .53095 .76019 .53496 .76516 .53123 Mtetra
.75667 .52319 .7517 .52693 .75595 .53095 .76092 .52721 Mtetra
.75242 .51916 .74745 .52291 .7517 .52693 .75667 .52319 Mtetra
.74816 .51512 .74319 .51887 .74745 .52291 .75242 .51916 Mtetra
.7439 .51107 .73892 .51484 .74319 .51887 .74816 .51512 Mtetra
.73962 .50702 .73465 .51079 .73892 .51484 .7439 .51107 Mtetra
.73534 .50297 .73037 .50674 .73465 .51079 .73962 .50702 Mtetra
.73106 .4989 .72608 .50268 .73037 .50674 .73534 .50297 Mtetra
.72676 .49483 .72179 .49862 .72608 .50268 .73106 .4989 Mtetra
.72246 .49076 .71748 .49455 .72179 .49862 .72676 .49483 Mtetra
.71815 .48667 .71318 .49047 .71748 .49455 .72246 .49076 Mtetra
.71384 .48259 .70886 .48639 .71318 .49047 .71815 .48667 Mtetra
.70952 .47849 .70454 .4823 .70886 .48639 .71384 .48259 Mtetra
.70519 .47439 .70021 .4782 .70454 .4823 .70952 .47849 Mtetra
.70086 .47028 .69587 .4741 .70021 .4782 .70519 .47439 Mtetra
.69651 .46616 .69153 .46999 .69587 .4741 .70086 .47028 Mtetra
.69217 .46204 .68718 .46587 .69153 .46999 .69651 .46616 Mtetra
.68781 .45791 .68283 .46175 .68718 .46587 .69217 .46204 Mtetra
.702 .646 .791 r
.68345 .45378 .67846 .45763 .68283 .46175 .68781 .45791 Mtetra
.67908 .44964 .67409 .45349 .67846 .45763 .68345 .45378 Mtetra
.6747 .4455 .66971 .44936 .67409 .45349 .67908 .44964 Mtetra
.67032 .44135 .66533 .44522 .66971 .44936 .6747 .4455 Mtetra
.66593 .4372 .66094 .44108 .66533 .44522 .67032 .44135 Mtetra
.703 .647 .791 r
.66153 .43305 .65654 .43694 .66094 .44108 .66593 .4372 Mtetra
.703 .648 .792 r
.65713 .42892 .65214 .43282 .65654 .43694 .66153 .43305 Mtetra
.704 .649 .792 r
.65272 .42479 .64773 .42871 .65214 .43282 .65713 .42892 Mtetra
.706 .652 .793 r
.64831 .4207 .64332 .42465 .64773 .42871 .65272 .42479 Mtetra
.709 .655 .794 r
.64389 .41667 .63891 .42066 .64332 .42465 .64831 .4207 Mtetra
.715 .661 .796 r
.63948 .41273 .63449 .41678 .63891 .42066 .64389 .41667 Mtetra
.723 .671 .799 r
.63506 .40895 .63008 .41309 .63449 .41678 .63948 .41273 Mtetra
.736 .688 .804 r
.63066 .40543 .62568 .40972 .63008 .41309 .63506 .40895 Mtetra
.758 .715 .811 r
.62627 .40234 .62131 .40685 .62568 .40972 .63066 .40543 Mtetra
.793 .758 .821 r
.62192 .39991 .61696 .40478 .62131 .40685 .62627 .40234 Mtetra
.844 .825 .83 r
.61761 .39852 .61267 .40392 .61696 .40478 .62192 .39991 Mtetra
.902 .913 .819 r
.61336 .39865 .60846 .40479 .61267 .40392 .61761 .39852 Mtetra
.918 .978 .74 r
.60921 .40087 .60433 .40794 .60846 .40479 .61336 .39865 Mtetra
.809 .929 .554 r
.60515 .40557 .60029 .4136 .60433 .40794 .60921 .40087 Mtetra
.626 .796 .359 r
.60116 .41248 .59628 .42106 .60029 .4136 .60515 .40557 Mtetra
0 0 0 r
.59714 .41994 .5922 .428 .59628 .42106 .60116 .41248 Mtetra
.586 .845 .49 r
.59293 .42469 .58787 .43082 .5922 .428 .59714 .41994 Mtetra
.73 .862 .943 r
.5884 .42323 .58321 .42655 .58787 .43082 .59293 .42469 Mtetra
.473 .414 .71 r
.58354 .41431 .57826 .41525 .58321 .42655 .5884 .42323 Mtetra
.414 .3 .614 r
.57848 .40006 .5732 .40002 .57826 .41525 .58354 .41431 Mtetra
.425 .291 .593 r
.57339 .38426 .56817 .38461 .5732 .40002 .57848 .40006 Mtetra
.47 .328 .605 r
.56841 .36993 .56326 .37151 .56817 .38461 .57339 .38426 Mtetra
.547 .401 .634 r
.56356 .35858 .55848 .36187 .56326 .37151 .56841 .36993 Mtetra
.665 .513 .668 r
.55884 .35075 .55384 .35629 .55848 .36187 .56356 .35858 Mtetra
.826 .659 .676 r
.55425 .34695 .54932 .35574 .55384 .35629 .55884 .35075 Mtetra
.968 .788 .606 r
.54978 .34838 .54493 .3621 .54932 .35574 .55425 .34695 Mtetra
.99 .824 .445 r
.54544 .35722 .54068 .37778 .54493 .3621 .54978 .34838 Mtetra
.858 .757 .246 r
.54123 .37577 .53648 .4027 .54068 .37778 .54544 .35722 Mtetra
0 0 0 r
.53706 .40246 .53214 .42811 .53648 .4027 .54123 .37577 Mtetra
.023 0 .165 r
.53266 .42538 .52741 .43556 .53214 .42811 .53706 .40246 Mtetra
.755 .277 .106 r
.52782 .42569 .52232 .4151 .52741 .43556 .53266 .42538 Mtetra
0 0 .321 r
.52265 .39916 .51717 .37919 .52232 .4151 .52782 .42569 Mtetra
0 0 .408 r
.5175 .36227 .51219 .34549 .51717 .37919 .52265 .39916 Mtetra
.137 .03 .459 r
.51253 .33066 .50737 .32099 .51219 .34549 .5175 .36227 Mtetra
.259 .14 .521 r
.50772 .30855 .50265 .30474 .50737 .32099 .51253 .33066 Mtetra
.38 .266 .597 r
.503 .294 .49797 .29386 .50265 .30474 .50772 .30855 Mtetra
.494 .394 .67 r
.49831 .28413 .4933 .28604 .49797 .29386 .503 .294 Mtetra
.582 .497 .724 r
.49364 .27686 .48863 .27986 .4933 .28604 .49831 .28413 Mtetra
.637 .564 .756 r
.48896 .27097 .48395 .27452 .48863 .27986 .49364 .27686 Mtetra
.668 .603 .773 r
.48428 .26577 .47926 .26962 .48395 .27452 .48896 .27097 Mtetra
.684 .623 .782 r
.47958 .26094 .47457 .26494 .47926 .26962 .48428 .26577 Mtetra
.693 .634 .786 r
.47488 .25629 .46987 .26036 .47457 .26494 .47958 .26094 Mtetra
.697 .64 .788 r
.47017 .25172 .46515 .25583 .46987 .26036 .47488 .25629 Mtetra
.699 .643 .79 r
.46545 .24719 .46043 .25133 .46515 .25583 .47017 .25172 Mtetra
.7 .644 .79 r
.46072 .24268 .45571 .24684 .46043 .25133 .46545 .24719 Mtetra
.701 .645 .79 r
.45599 .23818 .45097 .24235 .45571 .24684 .46072 .24268 Mtetra
.701 .645 .791 r
.45124 .23367 .44623 .23785 .45097 .24235 .45599 .23818 Mtetra
.44649 .22917 .44147 .23335 .44623 .23785 .45124 .23367 Mtetra
.701 .646 .791 r
.44173 .22465 .43671 .22885 .44147 .23335 .44649 .22917 Mtetra
.43696 .22013 .43195 .22434 .43671 .22885 .44173 .22465 Mtetra
.43219 .2156 .42717 .21981 .43195 .22434 .43696 .22013 Mtetra
.42741 .21107 .42239 .21529 .42717 .21981 .43219 .2156 Mtetra
.42261 .20653 .41759 .21075 .42239 .21529 .42741 .21107 Mtetra
.41781 .20198 .41279 .20621 .41759 .21075 .42261 .20653 Mtetra
.41301 .19742 .40799 .20166 .41279 .20621 .41781 .20198 Mtetra
.40819 .19286 .40317 .1971 .40799 .20166 .41301 .19742 Mtetra
.40337 .18828 .39834 .19254 .40317 .1971 .40819 .19286 Mtetra
.39853 .1837 .39351 .18796 .39834 .19254 .40337 .18828 Mtetra
.39369 .17911 .38867 .18338 .39351 .18796 .39853 .1837 Mtetra
.38885 .17452 .38382 .17879 .38867 .18338 .39369 .17911 Mtetra
.38399 .16991 .37896 .1742 .38382 .17879 .38885 .17452 Mtetra
.37912 .1653 .3741 .16959 .37896 .1742 .38399 .16991 Mtetra
.37425 .16068 .36923 .16498 .3741 .16959 .37912 .1653 Mtetra
.36937 .15606 .36434 .16036 .36923 .16498 .37425 .16068 Mtetra
.36448 .15142 .35945 .15573 .36434 .16036 .36937 .15606 Mtetra
.35958 .14678 .35455 .1511 .35945 .15573 .36448 .15142 Mtetra
.35467 .14213 .34965 .14645 .35455 .1511 .35958 .14678 Mtetra
.80381 .55946 .79884 .56315 .80301 .56711 .80798 .56343 Mtetra
.79962 .55549 .79465 .55918 .79884 .56315 .80381 .55946 Mtetra
.79543 .55151 .79046 .55521 .79465 .55918 .79962 .55549 Mtetra
.79123 .54752 .78626 .55123 .79046 .55521 .79543 .55151 Mtetra
.78703 .54353 .78205 .54724 .78626 .55123 .79123 .54752 Mtetra
.78281 .53953 .77784 .54325 .78205 .54724 .78703 .54353 Mtetra
.77859 .53552 .77362 .53925 .77784 .54325 .78281 .53953 Mtetra
.77437 .53151 .76939 .53524 .77362 .53925 .77859 .53552 Mtetra
.77014 .5275 .76516 .53123 .76939 .53524 .77437 .53151 Mtetra
.7659 .52347 .76092 .52721 .76516 .53123 .77014 .5275 Mtetra
.76165 .51944 .75667 .52319 .76092 .52721 .7659 .52347 Mtetra
.7574 .5154 .75242 .51916 .75667 .52319 .76165 .51944 Mtetra
.75314 .51136 .74816 .51512 .75242 .51916 .7574 .5154 Mtetra
.74888 .50731 .7439 .51107 .74816 .51512 .75314 .51136 Mtetra
.74461 .50325 .73962 .50702 .7439 .51107 .74888 .50731 Mtetra
.74033 .49919 .73534 .50297 .73962 .50702 .74461 .50325 Mtetra
.73604 .49512 .73106 .4989 .73534 .50297 .74033 .49919 Mtetra
.73175 .49104 .72676 .49483 .73106 .4989 .73604 .49512 Mtetra
.72745 .48696 .72246 .49076 .72676 .49483 .73175 .49104 Mtetra
.72314 .48287 .71815 .48667 .72246 .49076 .72745 .48696 Mtetra
.71883 .47878 .71384 .48259 .71815 .48667 .72314 .48287 Mtetra
.71451 .47467 .70952 .47849 .71384 .48259 .71883 .47878 Mtetra
.71018 .47057 .70519 .47439 .70952 .47849 .71451 .47467 Mtetra
.70585 .46645 .70086 .47028 .70519 .47439 .71018 .47057 Mtetra
.7015 .46233 .69651 .46616 .70086 .47028 .70585 .46645 Mtetra
.69716 .4582 .69217 .46204 .69651 .46616 .7015 .46233 Mtetra
.6928 .45407 .68781 .45791 .69217 .46204 .69716 .4582 Mtetra
.702 .646 .791 r
.68844 .44993 .68345 .45378 .68781 .45791 .6928 .45407 Mtetra
.68407 .44578 .67908 .44964 .68345 .45378 .68844 .44993 Mtetra
.67969 .44163 .6747 .4455 .67908 .44964 .68407 .44578 Mtetra
.67531 .43748 .67032 .44135 .6747 .4455 .67969 .44163 Mtetra
.67092 .43332 .66593 .4372 .67032 .44135 .67531 .43748 Mtetra
.702 .647 .791 r
.66653 .42916 .66153 .43305 .66593 .4372 .67092 .43332 Mtetra
.703 .647 .791 r
.66212 .42501 .65713 .42892 .66153 .43305 .66653 .42916 Mtetra
.704 .649 .792 r
.65772 .42087 .65272 .42479 .65713 .42892 .66212 .42501 Mtetra
.705 .651 .792 r
.6533 .41676 .64831 .4207 .65272 .42479 .65772 .42087 Mtetra
.708 .654 .793 r
.64889 .41269 .64389 .41667 .64831 .4207 .6533 .41676 Mtetra
.712 .659 .795 r
.64447 .4087 .63948 .41273 .64389 .41667 .64889 .41269 Mtetra
.719 .667 .798 r
.64005 .40484 .63506 .40895 .63948 .41273 .64447 .4087 Mtetra
.731 .681 .802 r
.63564 .4012 .63066 .40543 .63506 .40895 .64005 .40484 Mtetra
.749 .703 .808 r
.63125 .39791 .62627 .40234 .63066 .40543 .63564 .4012 Mtetra
.778 .739 .817 r
.62688 .39519 .62192 .39991 .62627 .40234 .63125 .39791 Mtetra
.823 .797 .827 r
.62255 .39334 .61761 .39852 .62192 .39991 .62688 .39519 Mtetra
.881 .879 .828 r
.61829 .39282 .61336 .39865 .61761 .39852 .62255 .39334 Mtetra
.923 .963 .783 r
.61411 .39417 .60921 .40087 .61336 .39865 .61829 .39282 Mtetra
.865 .964 .633 r
.61003 .39789 .60515 .40557 .60921 .40087 .61411 .39417 Mtetra
.693 .846 .424 r
.60603 .40403 .60116 .41248 .60515 .40557 .61003 .39789 Mtetra
0 0 0 r
.60206 .41154 .59714 .41994 .60116 .41248 .60603 .40403 Mtetra
.59796 .41771 .59293 .42469 .59714 .41994 .60206 .41154 Mtetra
.759 .994 .864 r
.59356 .41886 .5884 .42323 .59293 .42469 .59796 .41771 Mtetra
.537 .524 .789 r
.58881 .41263 .58354 .41431 .5884 .42323 .59356 .41886 Mtetra
.421 .322 .637 r
.58378 .39995 .57848 .40006 .58354 .41431 .58881 .41263 Mtetra
.413 .285 .596 r
.57866 .38426 .57339 .38426 .57848 .40006 .58378 .39995 Mtetra
.444 .305 .597 r
.57361 .36903 .56841 .36993 .57339 .38426 .57866 .38426 Mtetra
.502 .36 .621 r
.56868 .35626 .56356 .35858 .56841 .36993 .57361 .36903 Mtetra
.593 .449 .655 r
.5639 .34666 .55884 .35075 .56356 .35858 .56868 .35626 Mtetra
.724 .572 .683 r
.55923 .3405 .55425 .34695 .55884 .35075 .5639 .34666 Mtetra
.883 .715 .669 r
.55468 .33837 .54978 .34838 .55425 .34695 .55923 .3405 Mtetra
.992 .814 .565 r
.55026 .34178 .54544 .35722 .54978 .34838 .55468 .33837 Mtetra
.968 .814 .389 r
.54597 .35317 .54123 .37577 .54544 .35722 .55026 .34178 Mtetra
.793 .721 .188 r
.54181 .37448 .53706 .40246 .54123 .37577 .54597 .35317 Mtetra
0 0 .031 r
.53764 .40208 .53266 .42538 .53706 .40246 .54181 .37448 Mtetra
.19 0 .19 r
.53316 .42103 .52782 .42569 .53266 .42538 .53764 .40208 Mtetra
.84 .389 0 r
.52819 .41376 .52265 .39916 .52782 .42569 .53316 .42103 Mtetra
0 0 .354 r
.52297 .38243 .5175 .36227 .52265 .39916 .52819 .41376 Mtetra
.024 0 .42 r
.51782 .34573 .51253 .33066 .5175 .36227 .52297 .38243 Mtetra
.168 .056 .472 r
.51287 .31651 .50772 .30855 .51253 .33066 .51782 .34573 Mtetra
.288 .17 .539 r
.50807 .29666 .503 .294 .50772 .30855 .51287 .31651 Mtetra
.411 .3 .617 r
.50335 .2836 .49831 .28413 .503 .294 .50807 .29666 Mtetra
.52 .425 .687 r
.49866 .27458 .49364 .27686 .49831 .28413 .50335 .2836 Mtetra
.599 .519 .735 r
.49398 .26777 .48896 .27097 .49364 .27686 .49866 .27458 Mtetra
.647 .577 .762 r
.4893 .26211 .48428 .26577 .48896 .27097 .49398 .26777 Mtetra
.673 .61 .776 r
.4846 .25703 .47958 .26094 .48428 .26577 .4893 .26211 Mtetra
.687 .627 .783 r
.4799 .25225 .47488 .25629 .47958 .26094 .4846 .25703 Mtetra
.694 .636 .787 r
.47519 .24762 .47017 .25172 .47488 .25629 .4799 .25225 Mtetra
.698 .641 .789 r
.47047 .24306 .46545 .24719 .47017 .25172 .47519 .24762 Mtetra
.699 .643 .79 r
.46575 .23852 .46072 .24268 .46545 .24719 .47047 .24306 Mtetra
.7 .644 .79 r
.46101 .23401 .45599 .23818 .46072 .24268 .46575 .23852 Mtetra
.701 .645 .791 r
.45627 .22949 .45124 .23367 .45599 .23818 .46101 .23401 Mtetra
.45152 .22497 .44649 .22917 .45124 .23367 .45627 .22949 Mtetra
.44676 .22045 .44173 .22465 .44649 .22917 .45152 .22497 Mtetra
.701 .646 .791 r
.44199 .21592 .43696 .22013 .44173 .22465 .44676 .22045 Mtetra
.43722 .21139 .43219 .2156 .43696 .22013 .44199 .21592 Mtetra
.43243 .20685 .42741 .21107 .43219 .2156 .43722 .21139 Mtetra
.42764 .2023 .42261 .20653 .42741 .21107 .43243 .20685 Mtetra
.42284 .19774 .41781 .20198 .42261 .20653 .42764 .2023 Mtetra
.41804 .19318 .41301 .19742 .41781 .20198 .42284 .19774 Mtetra
.41322 .1886 .40819 .19286 .41301 .19742 .41804 .19318 Mtetra
.4084 .18402 .40337 .18828 .40819 .19286 .41322 .1886 Mtetra
.40356 .17944 .39853 .1837 .40337 .18828 .4084 .18402 Mtetra
.39872 .17484 .39369 .17911 .39853 .1837 .40356 .17944 Mtetra
.39388 .17024 .38885 .17452 .39369 .17911 .39872 .17484 Mtetra
.38902 .16563 .38399 .16991 .38885 .17452 .39388 .17024 Mtetra
.38415 .16101 .37912 .1653 .38399 .16991 .38902 .16563 Mtetra
.37928 .15638 .37425 .16068 .37912 .1653 .38415 .16101 Mtetra
.3744 .15175 .36937 .15606 .37425 .16068 .37928 .15638 Mtetra
.36951 .1471 .36448 .15142 .36937 .15606 .3744 .15175 Mtetra
.36461 .14245 .35958 .14678 .36448 .15142 .36951 .1471 Mtetra
.35971 .13779 .35467 .14213 .35958 .14678 .36461 .14245 Mtetra
.80878 .55577 .80381 .55946 .80798 .56343 .81296 .55974 Mtetra
.8046 .55179 .79962 .55549 .80381 .55946 .80878 .55577 Mtetra
.80041 .5478 .79543 .55151 .79962 .55549 .8046 .55179 Mtetra
.79621 .54381 .79123 .54752 .79543 .55151 .80041 .5478 Mtetra
.79201 .53981 .78703 .54353 .79123 .54752 .79621 .54381 Mtetra
.7878 .53581 .78281 .53953 .78703 .54353 .79201 .53981 Mtetra
.78358 .53179 .77859 .53552 .78281 .53953 .7878 .53581 Mtetra
.77935 .52778 .77437 .53151 .77859 .53552 .78358 .53179 Mtetra
.77512 .52375 .77014 .5275 .77437 .53151 .77935 .52778 Mtetra
.77088 .51972 .7659 .52347 .77014 .5275 .77512 .52375 Mtetra
.76664 .51569 .76165 .51944 .7659 .52347 .77088 .51972 Mtetra
.76239 .51164 .7574 .5154 .76165 .51944 .76664 .51569 Mtetra
.75813 .50759 .75314 .51136 .7574 .5154 .76239 .51164 Mtetra
.75387 .50354 .74888 .50731 .75314 .51136 .75813 .50759 Mtetra
.74959 .49947 .74461 .50325 .74888 .50731 .75387 .50354 Mtetra
.74532 .4954 .74033 .49919 .74461 .50325 .74959 .49947 Mtetra
.74103 .49133 .73604 .49512 .74033 .49919 .74532 .4954 Mtetra
.73674 .48725 .73175 .49104 .73604 .49512 .74103 .49133 Mtetra
.73244 .48316 .72745 .48696 .73175 .49104 .73674 .48725 Mtetra
.72813 .47906 .72314 .48287 .72745 .48696 .73244 .48316 Mtetra
.72382 .47496 .71883 .47878 .72314 .48287 .72813 .47906 Mtetra
.7195 .47085 .71451 .47467 .71883 .47878 .72382 .47496 Mtetra
.71518 .46674 .71018 .47057 .71451 .47467 .7195 .47085 Mtetra
.71084 .46262 .70585 .46645 .71018 .47057 .71518 .46674 Mtetra
.7065 .45849 .7015 .46233 .70585 .46645 .71084 .46262 Mtetra
.70215 .45436 .69716 .4582 .7015 .46233 .7065 .45849 Mtetra
.6978 .45022 .6928 .45407 .69716 .4582 .70215 .45436 Mtetra
.702 .646 .791 r
.69344 .44607 .68844 .44993 .6928 .45407 .6978 .45022 Mtetra
.68907 .44192 .68407 .44578 .68844 .44993 .69344 .44607 Mtetra
.6847 .43776 .67969 .44163 .68407 .44578 .68907 .44192 Mtetra
.68031 .4336 .67531 .43748 .67969 .44163 .6847 .43776 Mtetra
.67593 .42943 .67092 .43332 .67531 .43748 .68031 .4336 Mtetra
.702 .647 .791 r
.67153 .42526 .66653 .42916 .67092 .43332 .67593 .42943 Mtetra
.703 .647 .791 r
.66713 .4211 .66212 .42501 .66653 .42916 .67153 .42526 Mtetra
.703 .648 .792 r
.66272 .41695 .65772 .42087 .66212 .42501 .66713 .4211 Mtetra
.705 .65 .792 r
.65831 .41281 .6533 .41676 .65772 .42087 .66272 .41695 Mtetra
.707 .652 .793 r
.65389 .40872 .64889 .41269 .6533 .41676 .65831 .41281 Mtetra
.71 .656 .794 r
.64947 .40468 .64447 .4087 .64889 .41269 .65389 .40872 Mtetra
.716 .663 .797 r
.64505 .40076 .64005 .40484 .64447 .4087 .64947 .40468 Mtetra
.726 .675 .8 r
.64064 .39701 .63564 .4012 .64005 .40484 .64505 .40076 Mtetra
.741 .693 .806 r
.63624 .39356 .63125 .39791 .63564 .4012 .64064 .39701 Mtetra
.766 .724 .814 r
.63186 .39058 .62688 .39519 .63125 .39791 .63624 .39356 Mtetra
.804 .772 .824 r
.62751 .38835 .62255 .39334 .62688 .39519 .63186 .39058 Mtetra
.858 .845 .83 r
.62322 .38726 .61829 .39282 .62255 .39334 .62751 .38835 Mtetra
.914 .935 .809 r
.61902 .38782 .61411 .39417 .61829 .39282 .62322 .38726 Mtetra
.904 .98 .703 r
.61491 .39057 .61003 .39789 .61411 .39417 .61902 .38782 Mtetra
.763 .898 .5 r
.6109 .39582 .60603 .40403 .61003 .39789 .61491 .39057 Mtetra
0 0 0 r
.60695 .403 .60206 .41154 .60603 .40403 .6109 .39582 Mtetra
.60293 .41004 .59796 .41771 .60206 .41154 .60695 .403 Mtetra
.655 .923 .629 r
.59868 .41345 .59356 .41886 .59796 .41771 .60293 .41004 Mtetra
.643 .706 .893 r
.59406 .41005 .58881 .41263 .59356 .41886 .59868 .41345 Mtetra
.442 .365 .674 r
.5891 .39945 .58378 .39995 .58881 .41263 .59406 .41005 Mtetra
.407 .288 .604 r
.58397 .38441 .57866 .38426 .58378 .39995 .5891 .39945 Mtetra
.425 .29 .593 r
.57885 .36863 .57361 .36903 .57866 .38426 .58397 .38441 Mtetra
.47 .331 .609 r
.57385 .35469 .56868 .35626 .57361 .36903 .57885 .36863 Mtetra
.54 .401 .641 r
.56899 .34362 .5639 .34666 .56868 .35626 .57385 .35469 Mtetra
.643 .502 .676 r
.56426 .33566 .55923 .3405 .5639 .34666 .56899 .34362 Mtetra
.783 .631 .693 r
.55964 .33101 .55468 .33837 .55923 .3405 .56426 .33566 Mtetra
.93 .761 .651 r
.55513 .33048 .55026 .34178 .55468 .33837 .55964 .33101 Mtetra
1 .826 .518 r
.55076 .3359 .54597 .35317 .55026 .34178 .55513 .33048 Mtetra
.935 .797 .334 r
.54653 .34991 .54181 .37448 .54597 .35317 .55076 .3359 Mtetra
.716 .677 .131 r
.54241 .37373 .53764 .40208 .54181 .37448 .54653 .34991 Mtetra
0 0 .083 r
.53822 .40118 .53316 .42103 .53764 .40208 .54241 .37373 Mtetra
.372 0 .196 r
.53363 .41476 .52819 .41376 .53316 .42103 .53822 .40118 Mtetra
.726 .396 0 r
.52854 .40001 .52297 .38243 .52819 .41376 .53363 .41476 Mtetra
0 0 .376 r
.52328 .36529 .51782 .34573 .52297 .38243 .52854 .40001 Mtetra
.065 0 .432 r
.51814 .32973 .51287 .31651 .51782 .34573 .52328 .36529 Mtetra
.197 .082 .487 r
.51322 .30303 .50807 .29666 .51287 .31651 .51814 .32973 Mtetra
.319 .201 .558 r
.50843 .28524 .50335 .2836 .50807 .29666 .51322 .30303 Mtetra
.441 .334 .637 r
.50371 .27347 .49866 .27458 .50335 .2836 .50843 .28524 Mtetra
.544 .453 .702 r
.49901 .26518 .49398 .26777 .49866 .27458 .50371 .27347 Mtetra
.615 .537 .744 r
.49432 .25875 .4893 .26211 .49398 .26777 .49901 .26518 Mtetra
.656 .588 .767 r
.48963 .25327 .4846 .25703 .4893 .26211 .49432 .25875 Mtetra
.678 .616 .779 r
.48493 .24829 .4799 .25225 .4846 .25703 .48963 .25327 Mtetra
.69 .63 .785 r
.48022 .24355 .47519 .24762 .4799 .25225 .48493 .24829 Mtetra
.695 .638 .788 r
.4755 .23893 .47047 .24306 .47519 .24762 .48022 .24355 Mtetra
.698 .642 .789 r
.47078 .23437 .46575 .23852 .47047 .24306 .4755 .23893 Mtetra
.7 .644 .79 r
.46604 .22983 .46101 .23401 .46575 .23852 .47078 .23437 Mtetra
.701 .645 .79 r
.4613 .2253 .45627 .22949 .46101 .23401 .46604 .22983 Mtetra
.701 .645 .791 r
.45655 .22078 .45152 .22497 .45627 .22949 .4613 .2253 Mtetra
.45179 .21624 .44676 .22045 .45152 .22497 .45655 .22078 Mtetra
.701 .646 .791 r
.44703 .21171 .44199 .21592 .44676 .22045 .45179 .21624 Mtetra
.44225 .20717 .43722 .21139 .44199 .21592 .44703 .21171 Mtetra
.43747 .20262 .43243 .20685 .43722 .21139 .44225 .20717 Mtetra
.43268 .19806 .42764 .2023 .43243 .20685 .43747 .20262 Mtetra
.42788 .1935 .42284 .19774 .42764 .2023 .43268 .19806 Mtetra
.42307 .18892 .41804 .19318 .42284 .19774 .42788 .1935 Mtetra
.41826 .18435 .41322 .1886 .41804 .19318 .42307 .18892 Mtetra
.41343 .17976 .4084 .18402 .41322 .1886 .41826 .18435 Mtetra
.4086 .17516 .40356 .17944 .4084 .18402 .41343 .17976 Mtetra
.40376 .17056 .39872 .17484 .40356 .17944 .4086 .17516 Mtetra
.39892 .16595 .39388 .17024 .39872 .17484 .40376 .17056 Mtetra
.39406 .16133 .38902 .16563 .39388 .17024 .39892 .16595 Mtetra
.38919 .1567 .38415 .16101 .38902 .16563 .39406 .16133 Mtetra
.38432 .15207 .37928 .15638 .38415 .16101 .38919 .1567 Mtetra
.37944 .14743 .3744 .15175 .37928 .15638 .38432 .15207 Mtetra
.37455 .14278 .36951 .1471 .3744 .15175 .37944 .14743 Mtetra
.36965 .13812 .36461 .14245 .36951 .1471 .37455 .14278 Mtetra
.36475 .13345 .35971 .13779 .36461 .14245 .36965 .13812 Mtetra
.81377 .55207 .80878 .55577 .81296 .55974 .81795 .55605 Mtetra
.80959 .54808 .8046 .55179 .80878 .55577 .81377 .55207 Mtetra
.8054 .54409 .80041 .5478 .8046 .55179 .80959 .54808 Mtetra
.8012 .54009 .79621 .54381 .80041 .5478 .8054 .54409 Mtetra
.797 .53609 .79201 .53981 .79621 .54381 .8012 .54009 Mtetra
.79279 .53208 .7878 .53581 .79201 .53981 .797 .53609 Mtetra
.78857 .52806 .78358 .53179 .7878 .53581 .79279 .53208 Mtetra
.78434 .52404 .77935 .52778 .78358 .53179 .78857 .52806 Mtetra
.78011 .52 .77512 .52375 .77935 .52778 .78434 .52404 Mtetra
.77588 .51597 .77088 .51972 .77512 .52375 .78011 .52 Mtetra
.77163 .51193 .76664 .51569 .77088 .51972 .77588 .51597 Mtetra
.76738 .50788 .76239 .51164 .76664 .51569 .77163 .51193 Mtetra
.76313 .50382 .75813 .50759 .76239 .51164 .76738 .50788 Mtetra
.75886 .49976 .75387 .50354 .75813 .50759 .76313 .50382 Mtetra
.75459 .49569 .74959 .49947 .75387 .50354 .75886 .49976 Mtetra
.75031 .49161 .74532 .4954 .74959 .49947 .75459 .49569 Mtetra
.74603 .48753 .74103 .49133 .74532 .4954 .75031 .49161 Mtetra
.74174 .48345 .73674 .48725 .74103 .49133 .74603 .48753 Mtetra
.73744 .47935 .73244 .48316 .73674 .48725 .74174 .48345 Mtetra
.73314 .47525 .72813 .47906 .73244 .48316 .73744 .47935 Mtetra
.72882 .47114 .72382 .47496 .72813 .47906 .73314 .47525 Mtetra
.72451 .46703 .7195 .47085 .72382 .47496 .72882 .47114 Mtetra
.72018 .46291 .71518 .46674 .7195 .47085 .72451 .46703 Mtetra
.71585 .45878 .71084 .46262 .71518 .46674 .72018 .46291 Mtetra
.71151 .45465 .7065 .45849 .71084 .46262 .71585 .45878 Mtetra
.70716 .4505 .70215 .45436 .7065 .45849 .71151 .45465 Mtetra
.70281 .44636 .6978 .45022 .70215 .45436 .70716 .4505 Mtetra
.69845 .4422 .69344 .44607 .6978 .45022 .70281 .44636 Mtetra
.702 .646 .791 r
.69408 .43805 .68907 .44192 .69344 .44607 .69845 .4422 Mtetra
.6897 .43388 .6847 .43776 .68907 .44192 .69408 .43805 Mtetra
.68532 .42971 .68031 .4336 .6847 .43776 .6897 .43388 Mtetra
.68094 .42554 .67593 .42943 .68031 .4336 .68532 .42971 Mtetra
.67654 .42136 .67153 .42526 .67593 .42943 .68094 .42554 Mtetra
.702 .647 .791 r
.67214 .41719 .66713 .4211 .67153 .42526 .67654 .42136 Mtetra
.703 .648 .791 r
.66773 .41302 .66272 .41695 .66713 .4211 .67214 .41719 Mtetra
.704 .649 .792 r
.66332 .40887 .65831 .41281 .66272 .41695 .66773 .41302 Mtetra
.706 .651 .793 r
.6589 .40475 .65389 .40872 .65831 .41281 .66332 .40887 Mtetra
.709 .655 .794 r
.65448 .40068 .64947 .40468 .65389 .40872 .6589 .40475 Mtetra
.714 .66 .796 r
.65006 .3967 .64505 .40076 .64947 .40468 .65448 .40068 Mtetra
.722 .67 .799 r
.64564 .39286 .64064 .39701 .64505 .40076 .65006 .3967 Mtetra
.734 .685 .803 r
.64123 .38927 .63624 .39356 .64064 .39701 .64564 .39286 Mtetra
.755 .711 .81 r
.63684 .38608 .63186 .39058 .63624 .39356 .64123 .38927 Mtetra
.788 .751 .82 r
.63249 .38352 .62751 .38835 .63186 .39058 .63684 .38608 Mtetra
.836 .815 .829 r
.62818 .38193 .62322 .38726 .62751 .38835 .63249 .38352 Mtetra
.895 .902 .823 r
.62394 .38178 .61902 .38782 .62322 .38726 .62818 .38193 Mtetra
.921 .975 .757 r
.6198 .38363 .61491 .39057 .61902 .38782 .62394 .38178 Mtetra
.828 .943 .581 r
.61577 .38792 .6109 .39582 .61491 .39057 .6198 .38363 Mtetra
.646 .812 .38 r
.61183 .39448 .60695 .403 .6109 .39582 .61577 .38792 Mtetra
0 0 0 r
.60788 .40189 .60293 .41004 .60695 .403 .61183 .39448 Mtetra
.557 .814 .442 r
.60374 .40707 .59868 .41345 .60293 .41004 .60788 .40189 Mtetra
.753 .926 .947 r
.59927 .40643 .59406 .41005 .59868 .41345 .60374 .40707 Mtetra
.485 .441 .733 r
.59441 .39834 .5891 .39945 .59406 .41005 .59927 .40643 Mtetra
.41 .302 .62 r
.5893 .38451 .58397 .38441 .5891 .39945 .59441 .39834 Mtetra
.412 .282 .593 r
.58414 .36859 .57885 .36863 .58397 .38441 .5893 .38451 Mtetra
.446 .309 .6 r
.57907 .3537 .57385 .35469 .57885 .36863 .58414 .36859 Mtetra
.502 .365 .627 r
.57414 .34136 .56899 .34362 .57385 .35469 .57907 .3537 Mtetra
.582 .447 .662 r
.56934 .33193 .56426 .33566 .56899 .34362 .57414 .34136 Mtetra
.695 .556 .693 r
.56465 .32543 .55964 .33101 .56426 .33566 .56934 .33193 Mtetra
.837 .685 .694 r
.56008 .32216 .55513 .33048 .55964 .33101 .56465 .32543 Mtetra
.965 .796 .622 r
.55561 .32321 .55076 .3359 .55513 .33048 .56008 .32216 Mtetra
.995 .828 .468 r
.55128 .33073 .54653 .34991 .55076 .3359 .55561 .32321 Mtetra
.894 .774 .28 r
.54711 .34741 .54241 .37373 .54653 .34991 .55128 .33073 Mtetra
0 0 0 r
.54302 .37334 .53822 .40118 .54241 .37373 .54711 .34741 Mtetra
0 0 .128 r
.53878 .39937 .53363 .41476 .53822 .40118 .54302 .37334 Mtetra
.575 .136 .17 r
.53406 .40641 .52854 .40001 .53363 .41476 .53878 .39937 Mtetra
0 0 .271 r
.52887 .38479 .52328 .36529 .52854 .40001 .53406 .40641 Mtetra
0 0 .392 r
.52358 .34812 .51814 .32973 .52328 .36529 .52887 .38479 Mtetra
.101 .001 .444 r
.51847 .31437 .51322 .30303 .51814 .32973 .52358 .34812 Mtetra
.227 .11 .503 r
.51357 .29016 .50843 .28524 .51322 .30303 .51847 .31437 Mtetra
.35 .234 .578 r
.50879 .27423 .50371 .27347 .50843 .28524 .51357 .29016 Mtetra
.47 .367 .656 r
.50407 .26357 .49901 .26518 .50371 .27347 .50879 .27423 Mtetra
.566 .479 .716 r
.49937 .25589 .49432 .25875 .49901 .26518 .50407 .26357 Mtetra
.628 .554 .752 r
.49467 .24977 .48963 .25327 .49432 .25875 .49937 .25589 Mtetra
.663 .597 .771 r
.48997 .24445 .48493 .24829 .48963 .25327 .49467 .24977 Mtetra
.682 .621 .781 r
.48526 .23954 .48022 .24355 .48493 .24829 .48997 .24445 Mtetra
.692 .633 .786 r
.48054 .23484 .4755 .23893 .48022 .24355 .48526 .23954 Mtetra
.696 .639 .788 r
.47582 .23023 .47078 .23437 .4755 .23893 .48054 .23484 Mtetra
.699 .642 .789 r
.47108 .22566 .46604 .22983 .47078 .23437 .47582 .23023 Mtetra
.7 .644 .79 r
.46634 .22111 .4613 .2253 .46604 .22983 .47108 .22566 Mtetra
.701 .645 .791 r
.46159 .21657 .45655 .22078 .4613 .2253 .46634 .22111 Mtetra
.45683 .21203 .45179 .21624 .45655 .22078 .46159 .21657 Mtetra
.45207 .20749 .44703 .21171 .45179 .21624 .45683 .21203 Mtetra
.701 .646 .791 r
.44729 .20294 .44225 .20717 .44703 .21171 .45207 .20749 Mtetra
.44251 .19838 .43747 .20262 .44225 .20717 .44729 .20294 Mtetra
.43772 .19382 .43268 .19806 .43747 .20262 .44251 .19838 Mtetra
.43292 .18925 .42788 .1935 .43268 .19806 .43772 .19382 Mtetra
.42812 .18467 .42307 .18892 .42788 .1935 .43292 .18925 Mtetra
.4233 .18008 .41826 .18435 .42307 .18892 .42812 .18467 Mtetra
.41848 .17549 .41343 .17976 .41826 .18435 .4233 .18008 Mtetra
.41365 .17088 .4086 .17516 .41343 .17976 .41848 .17549 Mtetra
.40881 .16627 .40376 .17056 .4086 .17516 .41365 .17088 Mtetra
.40396 .16166 .39892 .16595 .40376 .17056 .40881 .16627 Mtetra
.39911 .15703 .39406 .16133 .39892 .16595 .40396 .16166 Mtetra
.39424 .1524 .38919 .1567 .39406 .16133 .39911 .15703 Mtetra
.38937 .14775 .38432 .15207 .38919 .1567 .39424 .1524 Mtetra
.38449 .1431 .37944 .14743 .38432 .15207 .38937 .14775 Mtetra
.3796 .13845 .37455 .14278 .37944 .14743 .38449 .1431 Mtetra
.3747 .13378 .36965 .13812 .37455 .14278 .3796 .13845 Mtetra
.3698 .12911 .36475 .13345 .36965 .13812 .3747 .13378 Mtetra
.81876 .54836 .81377 .55207 .81795 .55605 .82294 .55235 Mtetra
.81458 .54437 .80959 .54808 .81377 .55207 .81876 .54836 Mtetra
.81039 .54037 .8054 .54409 .80959 .54808 .81458 .54437 Mtetra
.80619 .53637 .8012 .54009 .8054 .54409 .81039 .54037 Mtetra
.80199 .53236 .797 .53609 .8012 .54009 .80619 .53637 Mtetra
.79778 .52834 .79279 .53208 .797 .53609 .80199 .53236 Mtetra
.79357 .52432 .78857 .52806 .79279 .53208 .79778 .52834 Mtetra
.78934 .52029 .78434 .52404 .78857 .52806 .79357 .52432 Mtetra
.78511 .51625 .78011 .52 .78434 .52404 .78934 .52029 Mtetra
.78088 .51221 .77588 .51597 .78011 .52 .78511 .51625 Mtetra
.77664 .50816 .77163 .51193 .77588 .51597 .78088 .51221 Mtetra
.77239 .50411 .76738 .50788 .77163 .51193 .77664 .50816 Mtetra
.76813 .50004 .76313 .50382 .76738 .50788 .77239 .50411 Mtetra
.76387 .49598 .75886 .49976 .76313 .50382 .76813 .50004 Mtetra
.7596 .4919 .75459 .49569 .75886 .49976 .76387 .49598 Mtetra
.75532 .48782 .75031 .49161 .75459 .49569 .7596 .4919 Mtetra
.75104 .48373 .74603 .48753 .75031 .49161 .75532 .48782 Mtetra
.74675 .47964 .74174 .48345 .74603 .48753 .75104 .48373 Mtetra
.74245 .47554 .73744 .47935 .74174 .48345 .74675 .47964 Mtetra
.73814 .47143 .73314 .47525 .73744 .47935 .74245 .47554 Mtetra
.73383 .46732 .72882 .47114 .73314 .47525 .73814 .47143 Mtetra
.72952 .4632 .72451 .46703 .72882 .47114 .73383 .46732 Mtetra
.72519 .45907 .72018 .46291 .72451 .46703 .72952 .4632 Mtetra
.72086 .45493 .71585 .45878 .72018 .46291 .72519 .45907 Mtetra
.71652 .45079 .71151 .45465 .71585 .45878 .72086 .45493 Mtetra
.71217 .44665 .70716 .4505 .71151 .45465 .71652 .45079 Mtetra
.70782 .44249 .70281 .44636 .70716 .4505 .71217 .44665 Mtetra
.70346 .43833 .69845 .4422 .70281 .44636 .70782 .44249 Mtetra
.702 .646 .791 r
.69909 .43417 .69408 .43805 .69845 .4422 .70346 .43833 Mtetra
.69472 .43 .6897 .43388 .69408 .43805 .69909 .43417 Mtetra
.69034 .42582 .68532 .42971 .6897 .43388 .69472 .43 Mtetra
.68595 .42164 .68094 .42554 .68532 .42971 .69034 .42582 Mtetra
.68156 .41746 .67654 .42136 .68094 .42554 .68595 .42164 Mtetra
.702 .647 .791 r
.67716 .41327 .67214 .41719 .67654 .42136 .68156 .41746 Mtetra
.703 .647 .791 r
.67275 .40909 .66773 .41302 .67214 .41719 .67716 .41327 Mtetra
.704 .648 .792 r
.66834 .40493 .66332 .40887 .66773 .41302 .67275 .40909 Mtetra
.705 .65 .792 r
.66392 .40078 .6589 .40475 .66332 .40887 .66834 .40493 Mtetra
.708 .653 .793 r
.6595 .39668 .65448 .40068 .6589 .40475 .66392 .40078 Mtetra
.712 .658 .795 r
.65508 .39265 .65006 .3967 .65448 .40068 .6595 .39668 Mtetra
.718 .666 .797 r
.65066 .38874 .64564 .39286 .65006 .3967 .65508 .39265 Mtetra
.729 .679 .801 r
.64624 .38504 .64123 .38927 .64564 .39286 .65066 .38874 Mtetra
.746 .7 .807 r
.64184 .38166 .63684 .38608 .64123 .38927 .64624 .38504 Mtetra
.774 .734 .816 r
.63747 .37882 .63249 .38352 .63684 .38608 .64184 .38166 Mtetra
.816 .788 .826 r
.63314 .3768 .62818 .38193 .63249 .38352 .63747 .37882 Mtetra
.873 .867 .829 r
.62888 .37603 .62394 .38178 .62818 .38193 .63314 .3768 Mtetra
.921 .955 .793 r
.62471 .37705 .6198 .38363 .62394 .38178 .62888 .37603 Mtetra
.88 .972 .659 r
.62065 .38037 .61577 .38792 .6198 .38363 .62471 .37705 Mtetra
.715 .864 .448 r
.6167 .38613 .61183 .39448 .61577 .38792 .62065 .38037 Mtetra
0 0 0 r
.61279 .39345 .60788 .40189 .61183 .39448 .6167 .38613 Mtetra
.60876 .39987 .60374 .40707 .60788 .40189 .61279 .39345 Mtetra
.731 .987 .795 r
.60444 .40174 .59927 .40643 .60374 .40707 .60876 .39987 Mtetra
.564 .573 .822 r
.59971 .3964 .59441 .39834 .59927 .40643 .60444 .40174 Mtetra
.422 .331 .647 r
.59466 .38434 .5893 .38451 .59441 .39834 .59971 .3964 Mtetra
.405 .281 .597 r
.58947 .36876 .58414 .36859 .5893 .38451 .59466 .38434 Mtetra
.428 .293 .594 r
.58433 .35318 .57907 .3537 .58414 .36859 .58947 .36876 Mtetra
.473 .337 .614 r
.57932 .33972 .57414 .34136 .57907 .3537 .58433 .35318 Mtetra
.538 .405 .648 r
.57445 .32902 .56934 .33193 .57414 .34136 .57932 .33972 Mtetra
.627 .496 .683 r
.56971 .32107 .56465 .32543 .56934 .33193 .57445 .32902 Mtetra
.746 .609 .706 r
.56507 .31586 .56008 .32216 .56465 .32543 .56971 .32107 Mtetra
.886 .732 .686 r
.56053 .31388 .55561 .32321 .56008 .32216 .56507 .31586 Mtetra
.988 .818 .585 r
.5561 .31653 .55128 .33073 .55561 .32321 .56053 .31388 Mtetra
.98 .821 .417 r
.55183 .32626 .54711 .34741 .55128 .33073 .5561 .31653 Mtetra
.843 .745 .227 r
.54771 .3456 .54302 .37334 .54711 .34741 .55183 .32626 Mtetra
0 0 0 r
.54364 .37303 .53878 .39937 .54302 .37334 .54771 .3456 Mtetra
.024 0 .163 r
.53933 .39625 .53406 .40641 .53878 .39937 .54364 .37303 Mtetra
.767 .285 .089 r
.53447 .39596 .52887 .38479 .53406 .40641 .53933 .39625 Mtetra
0 0 .323 r
.52918 .36849 .52358 .34812 .52887 .38479 .53447 .39596 Mtetra
0 0 .405 r
.52389 .33118 .51847 .31437 .52358 .34812 .52918 .36849 Mtetra
.134 .027 .457 r
.51881 .29967 .51357 .29016 .51847 .31437 .52389 .33118 Mtetra
.257 .139 .521 r
.51392 .27786 .50879 .27423 .51357 .29016 .51881 .29967 Mtetra
.381 .268 .599 r
.50915 .26357 .50407 .26357 .50879 .27423 .51392 .27786 Mtetra
.497 .399 .674 r
.50442 .25386 .49937 .25589 .50407 .26357 .50915 .26357 Mtetra
.585 .502 .727 r
.49972 .24669 .49467 .24977 .49937 .25589 .50442 .25386 Mtetra
.639 .568 .758 r
.49501 .24083 .48997 .24445 .49467 .24977 .49972 .24669 Mtetra
.669 .605 .774 r
.4903 .23564 .48526 .23954 .48997 .24445 .49501 .24083 Mtetra
.685 .625 .783 r
.48559 .23079 .48054 .23484 .48526 .23954 .4903 .23564 Mtetra
.693 .635 .787 r
.48086 .2261 .47582 .23023 .48054 .23484 .48559 .23079 Mtetra
.697 .64 .789 r
.47613 .22149 .47108 .22566 .47582 .23023 .48086 .2261 Mtetra
.699 .643 .79 r
.47139 .21692 .46634 .22111 .47108 .22566 .47613 .22149 Mtetra
.7 .644 .79 r
.46664 .21237 .46159 .21657 .46634 .22111 .47139 .21692 Mtetra
.701 .645 .79 r
.46188 .20782 .45683 .21203 .46159 .21657 .46664 .21237 Mtetra
.701 .645 .791 r
.45712 .20326 .45207 .20749 .45683 .21203 .46188 .20782 Mtetra
.701 .646 .791 r
.45234 .1987 .44729 .20294 .45207 .20749 .45712 .20326 Mtetra
.44756 .19414 .44251 .19838 .44729 .20294 .45234 .1987 Mtetra
.44277 .18957 .43772 .19382 .44251 .19838 .44756 .19414 Mtetra
.43797 .18499 .43292 .18925 .43772 .19382 .44277 .18957 Mtetra
.43317 .1804 .42812 .18467 .43292 .18925 .43797 .18499 Mtetra
.42835 .17581 .4233 .18008 .42812 .18467 .43317 .1804 Mtetra
.42353 .17121 .41848 .17549 .4233 .18008 .42835 .17581 Mtetra
.4187 .1666 .41365 .17088 .41848 .17549 .42353 .17121 Mtetra
.41386 .16198 .40881 .16627 .41365 .17088 .4187 .1666 Mtetra
.40902 .15735 .40396 .16166 .40881 .16627 .41386 .16198 Mtetra
.40416 .15272 .39911 .15703 .40396 .16166 .40902 .15735 Mtetra
.3993 .14808 .39424 .1524 .39911 .15703 .40416 .15272 Mtetra
.39443 .14343 .38937 .14775 .39424 .1524 .3993 .14808 Mtetra
.38955 .13877 .38449 .1431 .38937 .14775 .39443 .14343 Mtetra
.38466 .13411 .3796 .13845 .38449 .1431 .38955 .13877 Mtetra
.37976 .12944 .3747 .13378 .3796 .13845 .38466 .13411 Mtetra
.37486 .12476 .3698 .12911 .3747 .13378 .37976 .12944 Mtetra
.82376 .54465 .81876 .54836 .82294 .55235 .82794 .54864 Mtetra
.81958 .54065 .81458 .54437 .81876 .54836 .82376 .54465 Mtetra
.81539 .53665 .81039 .54037 .81458 .54437 .81958 .54065 Mtetra
.8112 .53264 .80619 .53637 .81039 .54037 .81539 .53665 Mtetra
.80699 .52862 .80199 .53236 .80619 .53637 .8112 .53264 Mtetra
.80279 .5246 .79778 .52834 .80199 .53236 .80699 .52862 Mtetra
.79857 .52057 .79357 .52432 .79778 .52834 .80279 .5246 Mtetra
.79435 .51653 .78934 .52029 .79357 .52432 .79857 .52057 Mtetra
.79012 .51249 .78511 .51625 .78934 .52029 .79435 .51653 Mtetra
.78589 .50844 .78088 .51221 .78511 .51625 .79012 .51249 Mtetra
.78164 .50439 .77664 .50816 .78088 .51221 .78589 .50844 Mtetra
.7774 .50033 .77239 .50411 .77664 .50816 .78164 .50439 Mtetra
.77314 .49626 .76813 .50004 .77239 .50411 .7774 .50033 Mtetra
.76888 .49219 .76387 .49598 .76813 .50004 .77314 .49626 Mtetra
.76461 .48811 .7596 .4919 .76387 .49598 .76888 .49219 Mtetra
.76033 .48402 .75532 .48782 .7596 .4919 .76461 .48811 Mtetra
.75605 .47992 .75104 .48373 .75532 .48782 .76033 .48402 Mtetra
.75176 .47582 .74675 .47964 .75104 .48373 .75605 .47992 Mtetra
.74746 .47172 .74245 .47554 .74675 .47964 .75176 .47582 Mtetra
.74316 .4676 .73814 .47143 .74245 .47554 .74746 .47172 Mtetra
.73885 .46348 .73383 .46732 .73814 .47143 .74316 .4676 Mtetra
.73453 .45936 .72952 .4632 .73383 .46732 .73885 .46348 Mtetra
.73021 .45522 .72519 .45907 .72952 .4632 .73453 .45936 Mtetra
.72588 .45108 .72086 .45493 .72519 .45907 .73021 .45522 Mtetra
.72154 .44694 .71652 .45079 .72086 .45493 .72588 .45108 Mtetra
.71719 .44279 .71217 .44665 .71652 .45079 .72154 .44694 Mtetra
.71284 .43863 .70782 .44249 .71217 .44665 .71719 .44279 Mtetra
.70848 .43446 .70346 .43833 .70782 .44249 .71284 .43863 Mtetra
.702 .646 .791 r
.70412 .43029 .69909 .43417 .70346 .43833 .70848 .43446 Mtetra
.69974 .42611 .69472 .43 .69909 .43417 .70412 .43029 Mtetra
.69536 .42193 .69034 .42582 .69472 .43 .69974 .42611 Mtetra
.69098 .41774 .68595 .42164 .69034 .42582 .69536 .42193 Mtetra
.68658 .41355 .68156 .41746 .68595 .42164 .69098 .41774 Mtetra
.702 .647 .791 r
.68218 .40935 .67716 .41327 .68156 .41746 .68658 .41355 Mtetra
.703 .647 .791 r
.67778 .40516 .67275 .40909 .67716 .41327 .68218 .40935 Mtetra
.703 .648 .792 r
.67337 .40098 .66834 .40493 .67275 .40909 .67778 .40516 Mtetra
.705 .649 .792 r
.66895 .39682 .66392 .40078 .66834 .40493 .67337 .40098 Mtetra
.707 .652 .793 r
.66453 .39269 .6595 .39668 .66392 .40078 .66895 .39682 Mtetra
.71 .656 .794 r
.6601 .38861 .65508 .39265 .6595 .39668 .66453 .39269 Mtetra
.715 .662 .796 r
.65568 .38464 .65066 .38874 .65508 .39265 .6601 .38861 Mtetra
.724 .673 .8 r
.65126 .38084 .64624 .38504 .65066 .38874 .65568 .38464 Mtetra
.739 .69 .805 r
.64685 .37731 .64184 .38166 .64624 .38504 .65126 .38084 Mtetra
.762 .719 .812 r
.64247 .37423 .63747 .37882 .64184 .38166 .64685 .37731 Mtetra
.798 .765 .822 r
.63813 .37185 .63314 .3768 .63747 .37882 .64247 .37423 Mtetra
.851 .835 .83 r
.63384 .37054 .62888 .37603 .63314 .3768 .63813 .37185 Mtetra
.908 .925 .815 r
.62964 .3708 .62471 .37705 .62888 .37603 .63384 .37054 Mtetra
.911 .98 .723 r
.62555 .37318 .62065 .38037 .62471 .37705 .62964 .3708 Mtetra
.785 .914 .527 r
.62157 .37803 .6167 .38613 .62065 .38037 .62555 .37318 Mtetra
0 0 0 r
.61767 .38493 .61279 .39345 .6167 .38613 .62157 .37803 Mtetra
.61373 .39204 .60876 .39987 .61279 .39345 .61767 .38493 Mtetra
.617 .885 .561 r
.60955 .39601 .60444 .40174 .60876 .39987 .61373 .39204 Mtetra
.681 .78 .925 r
.60498 .39349 .59971 .3964 .60444 .40174 .60955 .39601 Mtetra
.451 .384 .691 r
.60002 .38367 .59466 .38434 .59971 .3964 .60498 .39349 Mtetra
.404 .289 .608 r
.59483 .36896 .58947 .36876 .59466 .38434 .60002 .38367 Mtetra
.415 .283 .592 r
.58964 .35303 .58433 .35318 .58947 .36876 .59483 .36896 Mtetra
.451 .315 .604 r
.58455 .33858 .57932 .33972 .58433 .35318 .58964 .35303 Mtetra
.505 .372 .634 r
.57961 .32673 .57445 .32902 .57932 .33972 .58455 .33858 Mtetra
.578 .45 .67 r
.57481 .31756 .56971 .32107 .57445 .32902 .57961 .32673 Mtetra
.673 .546 .702 r
.57011 .3109 .56507 .31586 .56971 .32107 .57481 .31756 Mtetra
.795 .659 .712 r
.56551 .30683 .56053 .31388 .56507 .31586 .57011 .3109 Mtetra
.926 .77 .668 r
.561 .3061 .5561 .31653 .56053 .31388 .56551 .30683 Mtetra
.998 .83 .543 r
.55662 .31042 .55183 .32626 .5561 .31653 .561 .3061 Mtetra
.956 .808 .366 r
.5524 .32248 .54771 .3456 .55183 .32626 .55662 .31042 Mtetra
.782 .711 .174 r
.54833 .34438 .54364 .37303 .54771 .3456 .5524 .32248 Mtetra
0 0 .034 r
.54427 .3725 .53933 .39625 .54364 .37303 .54833 .34438 Mtetra
.19 0 .185 r
.53985 .39147 .53447 .39596 .53933 .39625 .54427 .3725 Mtetra
.833 .389 0 r
.53484 .38355 .52918 .36849 .53447 .39596 .53985 .39147 Mtetra
0 0 .354 r
.52948 .35153 .52389 .33118 .52918 .36849 .53484 .38355 Mtetra
.022 0 .417 r
.5242 .31467 .51881 .29967 .52389 .33118 .52948 .35153 Mtetra
.164 .053 .47 r
.51914 .28564 .51392 .27786 .51881 .29967 .5242 .31467 Mtetra
.287 .169 .539 r
.51427 .26606 .50915 .26357 .51392 .27786 .51914 .28564 Mtetra
.412 .302 .619 r
.50951 .2532 .50442 .25386 .50915 .26357 .51427 .26606 Mtetra
.523 .429 .69 r
.50478 .24431 .49972 .24669 .50442 .25386 .50951 .2532 Mtetra
.602 .522 .737 r
.50007 .23755 .49501 .24083 .49972 .24669 .50478 .24431 Mtetra
.649 .58 .764 r
.49536 .23191 .4903 .23564 .49501 .24083 .50007 .23755 Mtetra
.675 .612 .777 r
.49064 .22682 .48559 .23079 .4903 .23564 .49536 .23191 Mtetra
.688 .628 .784 r
.48592 .22201 .48086 .2261 .48559 .23079 .49064 .22682 Mtetra
.695 .637 .787 r
.48119 .21734 .47613 .22149 .48086 .2261 .48592 .22201 Mtetra
.698 .641 .789 r
.47645 .21274 .47139 .21692 .47613 .22149 .48119 .21734 Mtetra
.7 .643 .79 r
.4717 .20816 .46664 .21237 .47139 .21692 .47645 .21274 Mtetra
.701 .645 .79 r
.46694 .20359 .46188 .20782 .46664 .21237 .4717 .20816 Mtetra
.701 .645 .791 r
.46218 .19903 .45712 .20326 .46188 .20782 .46694 .20359 Mtetra
.4574 .19446 .45234 .1987 .45712 .20326 .46218 .19903 Mtetra
.45262 .18989 .44756 .19414 .45234 .1987 .4574 .19446 Mtetra
.701 .646 .791 r
.44783 .18531 .44277 .18957 .44756 .19414 .45262 .18989 Mtetra
.44303 .18072 .43797 .18499 .44277 .18957 .44783 .18531 Mtetra
.43823 .17613 .43317 .1804 .43797 .18499 .44303 .18072 Mtetra
.43342 .17153 .42835 .17581 .43317 .1804 .43823 .17613 Mtetra
.42859 .16692 .42353 .17121 .42835 .17581 .43342 .17153 Mtetra
.42376 .1623 .4187 .1666 .42353 .17121 .42859 .16692 Mtetra
.41893 .15768 .41386 .16198 .4187 .1666 .42376 .1623 Mtetra
.41408 .15305 .40902 .15735 .41386 .16198 .41893 .15768 Mtetra
.40923 .14841 .40416 .15272 .40902 .15735 .41408 .15305 Mtetra
.40436 .14376 .3993 .14808 .40416 .15272 .40923 .14841 Mtetra
.39949 .1391 .39443 .14343 .3993 .14808 .40436 .14376 Mtetra
.39461 .13444 .38955 .13877 .39443 .14343 .39949 .1391 Mtetra
.38972 .12976 .38466 .13411 .38955 .13877 .39461 .13444 Mtetra
.38483 .12508 .37976 .12944 .38466 .13411 .38972 .12976 Mtetra
.37992 .1204 .37486 .12476 .37976 .12944 .38483 .12508 Mtetra
.82877 .54093 .82376 .54465 .82794 .54864 .83294 .54493 Mtetra
.82459 .53693 .81958 .54065 .82376 .54465 .82877 .54093 Mtetra
.8204 .53292 .81539 .53665 .81958 .54065 .82459 .53693 Mtetra
.81621 .5289 .8112 .53264 .81539 .53665 .8204 .53292 Mtetra
.81201 .52488 .80699 .52862 .8112 .53264 .81621 .5289 Mtetra
.8078 .52085 .80279 .5246 .80699 .52862 .81201 .52488 Mtetra
.80358 .51682 .79857 .52057 .80279 .5246 .8078 .52085 Mtetra
.79936 .51278 .79435 .51653 .79857 .52057 .80358 .51682 Mtetra
.79514 .50873 .79012 .51249 .79435 .51653 .79936 .51278 Mtetra
.7909 .50467 .78589 .50844 .79012 .51249 .79514 .50873 Mtetra
.78666 .50061 .78164 .50439 .78589 .50844 .7909 .50467 Mtetra
.78241 .49655 .7774 .50033 .78164 .50439 .78666 .50061 Mtetra
.77816 .49247 .77314 .49626 .7774 .50033 .78241 .49655 Mtetra
.7739 .48839 .76888 .49219 .77314 .49626 .77816 .49247 Mtetra
.76963 .48431 .76461 .48811 .76888 .49219 .7739 .48839 Mtetra
.76535 .48021 .76033 .48402 .76461 .48811 .76963 .48431 Mtetra
.76107 .47611 .75605 .47992 .76033 .48402 .76535 .48021 Mtetra
.75678 .47201 .75176 .47582 .75605 .47992 .76107 .47611 Mtetra
.75249 .46789 .74746 .47172 .75176 .47582 .75678 .47201 Mtetra
.74818 .46377 .74316 .4676 .74746 .47172 .75249 .46789 Mtetra
.74387 .45965 .73885 .46348 .74316 .4676 .74818 .46377 Mtetra
.73956 .45551 .73453 .45936 .73885 .46348 .74387 .45965 Mtetra
.73523 .45137 .73021 .45522 .73453 .45936 .73956 .45551 Mtetra
.7309 .44723 .72588 .45108 .73021 .45522 .73523 .45137 Mtetra
.72657 .44308 .72154 .44694 .72588 .45108 .7309 .44723 Mtetra
.72222 .43892 .71719 .44279 .72154 .44694 .72657 .44308 Mtetra
.71787 .43475 .71284 .43863 .71719 .44279 .72222 .43892 Mtetra
.71351 .43058 .70848 .43446 .71284 .43863 .71787 .43475 Mtetra
.70915 .4264 .70412 .43029 .70848 .43446 .71351 .43058 Mtetra
.702 .646 .791 r
.70478 .42222 .69974 .42611 .70412 .43029 .70915 .4264 Mtetra
.7004 .41802 .69536 .42193 .69974 .42611 .70478 .42222 Mtetra
.69601 .41383 .69098 .41774 .69536 .42193 .7004 .41802 Mtetra
.69162 .40963 .68658 .41355 .69098 .41774 .69601 .41383 Mtetra
.68722 .40543 .68218 .40935 .68658 .41355 .69162 .40963 Mtetra
.702 .647 .791 r
.68281 .40123 .67778 .40516 .68218 .40935 .68722 .40543 Mtetra
.703 .648 .791 r
.6784 .39703 .67337 .40098 .67778 .40516 .68281 .40123 Mtetra
.704 .649 .792 r
.67398 .39285 .66895 .39682 .67337 .40098 .6784 .39703 Mtetra
.706 .651 .793 r
.66956 .3887 .66453 .39269 .66895 .39682 .67398 .39285 Mtetra
.708 .654 .794 r
.66513 .38459 .6601 .38861 .66453 .39269 .66956 .3887 Mtetra
.713 .66 .795 r
.66071 .38057 .65568 .38464 .6601 .38861 .66513 .38459 Mtetra
.72 .668 .798 r
.65629 .37668 .65126 .38084 .65568 .38464 .66071 .38057 Mtetra
.732 .683 .803 r
.65187 .37302 .64685 .37731 .65126 .38084 .65629 .37668 Mtetra
.752 .707 .809 r
.64748 .36974 .64247 .37423 .64685 .37731 .65187 .37302 Mtetra
.783 .745 .819 r
.64312 .36704 .63813 .37185 .64247 .37423 .64748 .36974 Mtetra
.829 .806 .828 r
.63881 .36526 .63384 .37054 .63813 .37185 .64312 .36704 Mtetra
.888 .89 .826 r
.63458 .36485 .62964 .3708 .63384 .37054 .63881 .36526 Mtetra
.923 .97 .771 r
.63045 .36636 .62555 .37318 .62964 .3708 .63458 .36485 Mtetra
.846 .954 .608 r
.62645 .37025 .62157 .37803 .62555 .37318 .63045 .36636 Mtetra
.667 .828 .401 r
.62255 .37647 .61767 .38493 .62157 .37803 .62645 .37025 Mtetra
0 0 0 r
.61866 .38379 .61373 .39204 .61767 .38493 .62255 .37647 Mtetra
.61461 .38935 .60955 .39601 .61373 .39204 .61866 .38379 Mtetra
.763 .972 .923 r
.6102 .38953 .60498 .39349 .60955 .39601 .61461 .38935 Mtetra
.505 .477 .759 r
.60537 .3823 .60002 .38367 .60498 .39349 .6102 .38953 Mtetra
.41 .308 .628 r
.60022 .369 .59483 .36896 .60002 .38367 .60537 .3823 Mtetra
.406 .279 .593 r
.59499 .35312 .58964 .35303 .59483 .36896 .60022 .369 Mtetra
.433 .298 .597 r
.58982 .33789 .58455 .33858 .58964 .35303 .59499 .35312 Mtetra
.479 .345 .621 r
.58481 .32496 .57961 .32673 .58455 .33858 .58982 .33789 Mtetra
.54 .413 .655 r
.57994 .31469 .57481 .31756 .57961 .32673 .58481 .32496 Mtetra
.618 .496 .691 r
.57519 .30685 .57011 .3109 .57481 .31756 .57994 .31469 Mtetra
.718 .594 .716 r
.57053 .30129 .56551 .30683 .57011 .3109 .57519 .30685 Mtetra
.841 .703 .711 r
.56596 .29827 .561 .3061 .56551 .30683 .57053 .30129 Mtetra
.958 .799 .643 r
.56149 .29879 .55662 .31042 .561 .3061 .56596 .29827 Mtetra
.998 .832 .497 r
.55716 .30488 .5524 .32248 .55662 .31042 .56149 .29879 Mtetra
.924 .789 .315 r
.553 .31938 .54833 .34438 .5524 .32248 .55716 .30488 Mtetra
.709 .669 .121 r
.54898 .34363 .54427 .3725 .54833 .34438 .553 .31938 Mtetra
0 0 .083 r
.54489 .37138 .53985 .39147 .54427 .3725 .54898 .34363 Mtetra
.374 0 .187 r
.54034 .38479 .53484 .38355 .53985 .39147 .54489 .37138 Mtetra
.707 .387 0 r
.53518 .36942 .52948 .35153 .53484 .38355 .54034 .38479 Mtetra
0 0 .374 r
.52978 .33427 .5242 .31467 .52948 .35153 .53518 .36942 Mtetra
.062 0 .429 r
.52451 .29873 .51914 .28564 .5242 .31467 .52978 .33427 Mtetra
.194 .079 .486 r
.51949 .27225 .51427 .26606 .51914 .28564 .52451 .29873 Mtetra
.318 .201 .559 r
.51463 .25469 .50951 .2532 .51427 .26606 .51949 .27225 Mtetra
.442 .336 .639 r
.50987 .24308 .50478 .24431 .50951 .2532 .51463 .25469 Mtetra
.546 .456 .704 r
.50514 .23487 .50007 .23755 .50478 .24431 .50987 .24308 Mtetra
.617 .54 .746 r
.50042 .22847 .49536 .23191 .50007 .23755 .50514 .23487 Mtetra
.657 .59 .768 r
.4957 .223 .49064 .22682 .49536 .23191 .50042 .22847 Mtetra
.679 .617 .78 r
.49098 .218 .48592 .22201 .49064 .22682 .4957 .223 Mtetra
.69 .631 .785 r
.48625 .21322 .48119 .21734 .48592 .22201 .49098 .218 Mtetra
.696 .638 .788 r
.48151 .20856 .47645 .21274 .48119 .21734 .48625 .21322 Mtetra
.698 .642 .789 r
.47676 .20395 .4717 .20816 .47645 .21274 .48151 .20856 Mtetra
.7 .644 .79 r
.47201 .19937 .46694 .20359 .4717 .20816 .47676 .20395 Mtetra
.701 .645 .79 r
.46724 .19479 .46218 .19903 .46694 .20359 .47201 .19937 Mtetra
.701 .645 .791 r
.46247 .19021 .4574 .19446 .46218 .19903 .46724 .19479 Mtetra
.45769 .18563 .45262 .18989 .4574 .19446 .46247 .19021 Mtetra
.701 .646 .791 r
.4529 .18105 .44783 .18531 .45262 .18989 .45769 .18563 Mtetra
.4481 .17645 .44303 .18072 .44783 .18531 .4529 .18105 Mtetra
.4433 .17185 .43823 .17613 .44303 .18072 .4481 .17645 Mtetra
.43848 .16724 .43342 .17153 .43823 .17613 .4433 .17185 Mtetra
.43366 .16263 .42859 .16692 .43342 .17153 .43848 .16724 Mtetra
.42883 .158 .42376 .1623 .42859 .16692 .43366 .16263 Mtetra
.424 .15337 .41893 .15768 .42376 .1623 .42883 .158 Mtetra
.41915 .14873 .41408 .15305 .41893 .15768 .424 .15337 Mtetra
.4143 .14408 .40923 .14841 .41408 .15305 .41915 .14873 Mtetra
.40943 .13943 .40436 .14376 .40923 .14841 .4143 .14408 Mtetra
.40456 .13476 .39949 .1391 .40436 .14376 .40943 .13943 Mtetra
.39968 .13009 .39461 .13444 .39949 .1391 .40456 .13476 Mtetra
.3948 .12541 .38972 .12976 .39461 .13444 .39968 .13009 Mtetra
.3899 .12073 .38483 .12508 .38972 .12976 .3948 .12541 Mtetra
.385 .11603 .37992 .1204 .38483 .12508 .3899 .12073 Mtetra
.83378 .53721 .82877 .54093 .83294 .54493 .83796 .54121 Mtetra
.8296 .5332 .82459 .53693 .82877 .54093 .83378 .53721 Mtetra
.82542 .52919 .8204 .53292 .82459 .53693 .8296 .5332 Mtetra
.82122 .52516 .81621 .5289 .8204 .53292 .82542 .52919 Mtetra
.81702 .52114 .81201 .52488 .81621 .5289 .82122 .52516 Mtetra
.81282 .5171 .8078 .52085 .81201 .52488 .81702 .52114 Mtetra
.8086 .51306 .80358 .51682 .8078 .52085 .81282 .5171 Mtetra
.80438 .50901 .79936 .51278 .80358 .51682 .8086 .51306 Mtetra
.80016 .50496 .79514 .50873 .79936 .51278 .80438 .50901 Mtetra
.79592 .5009 .7909 .50467 .79514 .50873 .80016 .50496 Mtetra
.79168 .49683 .78666 .50061 .7909 .50467 .79592 .5009 Mtetra
.78744 .49276 .78241 .49655 .78666 .50061 .79168 .49683 Mtetra
.78318 .48868 .77816 .49247 .78241 .49655 .78744 .49276 Mtetra
.77892 .48459 .7739 .48839 .77816 .49247 .78318 .48868 Mtetra
.77465 .4805 .76963 .48431 .7739 .48839 .77892 .48459 Mtetra
.77038 .4764 .76535 .48021 .76963 .48431 .77465 .4805 Mtetra
.7661 .47229 .76107 .47611 .76535 .48021 .77038 .4764 Mtetra
.76181 .46818 .75678 .47201 .76107 .47611 .7661 .47229 Mtetra
.75752 .46406 .75249 .46789 .75678 .47201 .76181 .46818 Mtetra
.75321 .45994 .74818 .46377 .75249 .46789 .75752 .46406 Mtetra
.74891 .4558 .74387 .45965 .74818 .46377 .75321 .45994 Mtetra
.74459 .45166 .73956 .45551 .74387 .45965 .74891 .4558 Mtetra
.74027 .44752 .73523 .45137 .73956 .45551 .74459 .45166 Mtetra
.73594 .44337 .7309 .44723 .73523 .45137 .74027 .44752 Mtetra
.7316 .43921 .72657 .44308 .7309 .44723 .73594 .44337 Mtetra
.72726 .43504 .72222 .43892 .72657 .44308 .7316 .43921 Mtetra
.72291 .43087 .71787 .43475 .72222 .43892 .72726 .43504 Mtetra
.71855 .42669 .71351 .43058 .71787 .43475 .72291 .43087 Mtetra
.71419 .42251 .70915 .4264 .71351 .43058 .71855 .42669 Mtetra
.702 .646 .791 r
.70982 .41832 .70478 .42222 .70915 .4264 .71419 .42251 Mtetra
.70544 .41412 .7004 .41802 .70478 .42222 .70982 .41832 Mtetra
.70105 .40992 .69601 .41383 .7004 .41802 .70544 .41412 Mtetra
.69666 .40571 .69162 .40963 .69601 .41383 .70105 .40992 Mtetra
.69226 .4015 .68722 .40543 .69162 .40963 .69666 .40571 Mtetra
.702 .647 .791 r
.68785 .39729 .68281 .40123 .68722 .40543 .69226 .4015 Mtetra
.703 .647 .791 r
.68344 .39308 .6784 .39703 .68281 .40123 .68785 .39729 Mtetra
.704 .648 .792 r
.67902 .38888 .67398 .39285 .6784 .39703 .68344 .39308 Mtetra
.705 .65 .792 r
.6746 .38471 .66956 .3887 .67398 .39285 .67902 .38888 Mtetra
.707 .653 .793 r
.67018 .38057 .66513 .38459 .66956 .3887 .6746 .38471 Mtetra
.711 .657 .795 r
.66575 .3765 .66071 .38057 .66513 .38459 .67018 .38057 Mtetra
.717 .665 .797 r
.66132 .37255 .65629 .37668 .66071 .38057 .66575 .3765 Mtetra
.727 .677 .801 r
.65691 .36878 .65187 .37302 .65629 .37668 .66132 .37255 Mtetra
.743 .696 .807 r
.6525 .36532 .64748 .36974 .65187 .37302 .65691 .36878 Mtetra
.769 .729 .815 r
.64813 .36236 .64312 .36704 .64748 .36974 .6525 .36532 Mtetra
.81 .78 .825 r
.6438 .36018 .63881 .36526 .64312 .36704 .64813 .36236 Mtetra
.866 .856 .83 r
.63954 .35918 .63458 .36485 .63881 .36526 .6438 .36018 Mtetra
.918 .946 .802 r
.63538 .35989 .63045 .36636 .63458 .36485 .63954 .35918 Mtetra
.892 .977 .682 r
.63134 .36282 .62645 .37025 .63045 .36636 .63538 .35989 Mtetra
.738 .881 .474 r
.62742 .3682 .62255 .37647 .62645 .37025 .63134 .36282 Mtetra
0 0 0 r
.62357 .37533 .61866 .38379 .62255 .37647 .62742 .3682 Mtetra
.61962 .38194 .61461 .38935 .61866 .38379 .62357 .37533 Mtetra
.696 .962 .717 r
.61537 .38448 .6102 .38953 .61461 .38935 .61962 .38194 Mtetra
.598 .633 .857 r
.61069 .38005 .60537 .3823 .6102 .38953 .61537 .38448 Mtetra
.428 .345 .66 r
.60562 .36868 .60022 .369 .60537 .3823 .61069 .38005 Mtetra
.402 .281 .6 r
.60037 .35333 .59499 .35312 .60022 .369 .60562 .36868 Mtetra
.419 .286 .592 r
.59515 .33756 .58982 .33789 .59499 .35312 .60037 .35333 Mtetra
.457 .323 .61 r
.59005 .32365 .58481 .32496 .58982 .33789 .59515 .33756 Mtetra
.511 .382 .641 r
.58511 .31232 .57994 .31469 .58481 .32496 .59005 .32365 Mtetra
.577 .456 .678 r
.5803 .30345 .57519 .30685 .57994 .31469 .58511 .31232 Mtetra
.658 .541 .71 r
.5756 .29676 .57053 .30129 .57519 .30685 .5803 .30345 Mtetra
.76 .638 .725 r
.57097 .29215 .56596 .29827 .57053 .30129 .5756 .29676 Mtetra
.881 .741 .703 r
.56643 .29012 .56149 .29879 .56596 .29827 .57097 .29215 Mtetra
.981 .819 .61 r
.562 .29193 .55716 .30488 .56149 .29879 .56643 .29012 Mtetra
.99 .828 .449 r
.55772 .29993 .553 .31938 .55716 .30488 .562 .29193 Mtetra
.883 .766 .265 r
.55362 .31695 .54898 .34363 .553 .31938 .55772 .29993 Mtetra
0 0 0 r
.54964 .34316 .54489 .37138 .54898 .34363 .55362 .31695 Mtetra
0 0 .125 r
.54549 .36931 .54034 .38479 .54489 .37138 .54964 .34316 Mtetra
.579 .133 .156 r
.54079 .37605 .53518 .36942 .54034 .38479 .54549 .36931 Mtetra
0 0 .279 r
.5355 .35393 .52978 .33427 .53518 .36942 .54079 .37605 Mtetra
0 0 .39 r
.53006 .31705 .52451 .29873 .52978 .33427 .5355 .35393 Mtetra
.098 0 .441 r
.52483 .28342 .51949 .27225 .52451 .29873 .53006 .31705 Mtetra
.224 .107 .502 r
.51983 .25945 .51463 .25469 .51949 .27225 .52483 .28342 Mtetra
.349 .234 .579 r
.515 .2437 .50987 .24308 .51463 .25469 .51983 .25945 Mtetra
.471 .369 .657 r
.51023 .23316 .50514 .23487 .50987 .24308 .515 .2437 Mtetra
.567 .481 .717 r
.5055 .22553 .50042 .22847 .50514 .23487 .51023 .23316 Mtetra
.629 .556 .753 r
.50078 .21943 .4957 .223 .50042 .22847 .5055 .22553 Mtetra
.664 .599 .772 r
.49605 .2141 .49098 .218 .4957 .223 .50078 .21943 Mtetra
.683 .622 .781 r
.49132 .20916 .48625 .21322 .49098 .218 .49605 .2141 Mtetra
.692 .634 .786 r
.48658 .20441 .48151 .20856 .48625 .21322 .49132 .20916 Mtetra
.697 .64 .789 r
.48183 .19976 .47676 .20395 .48151 .20856 .48658 .20441 Mtetra
.699 .643 .79 r
.47708 .19515 .47201 .19937 .47676 .20395 .48183 .19976 Mtetra
.7 .644 .79 r
.47231 .19055 .46724 .19479 .47201 .19937 .47708 .19515 Mtetra
.701 .645 .791 r
.46754 .18596 .46247 .19021 .46724 .19479 .47231 .19055 Mtetra
.46276 .18137 .45769 .18563 .46247 .19021 .46754 .18596 Mtetra
.45797 .17678 .4529 .18105 .45769 .18563 .46276 .18137 Mtetra
.701 .646 .791 r
.45318 .17217 .4481 .17645 .4529 .18105 .45797 .17678 Mtetra
.44837 .16757 .4433 .17185 .4481 .17645 .45318 .17217 Mtetra
.44356 .16295 .43848 .16724 .4433 .17185 .44837 .16757 Mtetra
.43874 .15833 .43366 .16263 .43848 .16724 .44356 .16295 Mtetra
.43391 .1537 .42883 .158 .43366 .16263 .43874 .15833 Mtetra
.42908 .14906 .424 .15337 .42883 .158 .43391 .1537 Mtetra
.42423 .14441 .41915 .14873 .424 .15337 .42908 .14906 Mtetra
.41938 .13975 .4143 .14408 .41915 .14873 .42423 .14441 Mtetra
.41451 .13509 .40943 .13943 .4143 .14408 .41938 .13975 Mtetra
.40964 .13042 .40456 .13476 .40943 .13943 .41451 .13509 Mtetra
.40477 .12574 .39968 .13009 .40456 .13476 .40964 .13042 Mtetra
.39988 .12105 .3948 .12541 .39968 .13009 .40477 .12574 Mtetra
.39498 .11636 .3899 .12073 .3948 .12541 .39988 .12105 Mtetra
.39008 .11166 .385 .11603 .3899 .12073 .39498 .11636 Mtetra
.83881 .53348 .83378 .53721 .83796 .54121 .84298 .53749 Mtetra
.83463 .52947 .8296 .5332 .83378 .53721 .83881 .53348 Mtetra
.83044 .52545 .82542 .52919 .8296 .5332 .83463 .52947 Mtetra
.82625 .52142 .82122 .52516 .82542 .52919 .83044 .52545 Mtetra
.82205 .51738 .81702 .52114 .82122 .52516 .82625 .52142 Mtetra
.81784 .51334 .81282 .5171 .81702 .52114 .82205 .51738 Mtetra
.81363 .5093 .8086 .51306 .81282 .5171 .81784 .51334 Mtetra
.80941 .50524 .80438 .50901 .8086 .51306 .81363 .5093 Mtetra
.80519 .50118 .80016 .50496 .80438 .50901 .80941 .50524 Mtetra
.80095 .49712 .79592 .5009 .80016 .50496 .80519 .50118 Mtetra
.79671 .49304 .79168 .49683 .79592 .5009 .80095 .49712 Mtetra
.79247 .48896 .78744 .49276 .79168 .49683 .79671 .49304 Mtetra
.78822 .48488 .78318 .48868 .78744 .49276 .79247 .48896 Mtetra
.78396 .48079 .77892 .48459 .78318 .48868 .78822 .48488 Mtetra
.77969 .47669 .77465 .4805 .77892 .48459 .78396 .48079 Mtetra
.77542 .47258 .77038 .4764 .77465 .4805 .77969 .47669 Mtetra
.77114 .46847 .7661 .47229 .77038 .4764 .77542 .47258 Mtetra
.76685 .46435 .76181 .46818 .7661 .47229 .77114 .46847 Mtetra
.76255 .46023 .75752 .46406 .76181 .46818 .76685 .46435 Mtetra
.75825 .45609 .75321 .45994 .75752 .46406 .76255 .46023 Mtetra
.75395 .45196 .74891 .4558 .75321 .45994 .75825 .45609 Mtetra
.74963 .44781 .74459 .45166 .74891 .4558 .75395 .45196 Mtetra
.74531 .44366 .74027 .44752 .74459 .45166 .74963 .44781 Mtetra
.74098 .4395 .73594 .44337 .74027 .44752 .74531 .44366 Mtetra
.73664 .43533 .7316 .43921 .73594 .44337 .74098 .4395 Mtetra
.7323 .43116 .72726 .43504 .7316 .43921 .73664 .43533 Mtetra
.72795 .42698 .72291 .43087 .72726 .43504 .7323 .43116 Mtetra
.7236 .4228 .71855 .42669 .72291 .43087 .72795 .42698 Mtetra
.71923 .41861 .71419 .42251 .71855 .42669 .7236 .4228 Mtetra
.71486 .41441 .70982 .41832 .71419 .42251 .71923 .41861 Mtetra
.702 .646 .791 r
.71048 .41021 .70544 .41412 .70982 .41832 .71486 .41441 Mtetra
.7061 .406 .70105 .40992 .70544 .41412 .71048 .41021 Mtetra
.70171 .40178 .69666 .40571 .70105 .40992 .7061 .406 Mtetra
.69731 .39756 .69226 .4015 .69666 .40571 .70171 .40178 Mtetra
.6929 .39334 .68785 .39729 .69226 .4015 .69731 .39756 Mtetra
.703 .647 .791 r
.68849 .38913 .68344 .39308 .68785 .39729 .6929 .39334 Mtetra
.703 .648 .792 r
.68408 .38492 .67902 .38888 .68344 .39308 .68849 .38913 Mtetra
.704 .649 .792 r
.67965 .38072 .6746 .38471 .67902 .38888 .68408 .38492 Mtetra
.706 .652 .793 r
.67523 .37656 .67018 .38057 .6746 .38471 .67965 .38072 Mtetra
.709 .655 .794 r
.6708 .37245 .66575 .3765 .67018 .38057 .67523 .37656 Mtetra
.715 .661 .796 r
.66637 .36843 .66132 .37255 .66575 .3765 .6708 .37245 Mtetra
.723 .671 .799 r
.66195 .36458 .65691 .36878 .66132 .37255 .66637 .36843 Mtetra
.736 .688 .804 r
.65754 .36097 .6525 .36532 .65691 .36878 .66195 .36458 Mtetra
.758 .715 .811 r
.65315 .35779 .64813 .36236 .6525 .36532 .65754 .36097 Mtetra
.793 .758 .821 r
.6488 .35526 .6438 .36018 .64813 .36236 .65315 .35779 Mtetra
.843 .825 .83 r
.64452 .35375 .63954 .35918 .6438 .36018 .6488 .35526 Mtetra
.902 .914 .82 r
.64032 .35373 .63538 .35989 .63954 .35918 .64452 .35375 Mtetra
.917 .979 .741 r
.63624 .35575 .63134 .36282 .63538 .35989 .64032 .35373 Mtetra
.806 .929 .554 r
.6323 .36021 .62742 .3682 .63134 .36282 .63624 .35575 Mtetra
.623 .795 .36 r
.62845 .36682 .62357 .37533 .62742 .3682 .6323 .36021 Mtetra
0 0 0 r
.62458 .37396 .61962 .38194 .62357 .37533 .62845 .36682 Mtetra
.586 .85 .501 r
.62048 .37843 .61537 .38448 .61962 .38194 .62458 .37396 Mtetra
.719 .855 .946 r
.61597 .37679 .61069 .38005 .61537 .38448 .62048 .37843 Mtetra
.465 .409 .71 r
.61102 .36779 .60562 .36868 .61069 .38005 .61597 .37679 Mtetra
.404 .293 .613 r
.60579 .35349 .60037 .35333 .60562 .36868 .61102 .36779 Mtetra
.409 .279 .591 r
.60051 .33752 .59515 .33756 .60037 .35333 .60579 .35349 Mtetra
.44 .306 .601 r
.59534 .32275 .59005 .32365 .59515 .33756 .60051 .33752 Mtetra
.486 .356 .628 r
.59032 .31039 .58511 .31232 .59005 .32365 .59534 .32275 Mtetra
.545 .422 .663 r
.58545 .30055 .5803 .30345 .58511 .31232 .59032 .31039 Mtetra
.614 .499 .699 r
.5807 .2929 .5756 .29676 .5803 .30345 .58545 .30055 Mtetra
.697 .583 .725 r
.57603 .28715 .57097 .29215 .5756 .29676 .5807 .2929 Mtetra
.8 .678 .729 r
.57143 .2834 .56643 .29012 .57097 .29215 .57603 .28715 Mtetra
.917 .773 .687 r
.56692 .28233 .562 .29193 .56643 .29012 .57143 .2834 Mtetra
.994 .831 .571 r
.56253 .28553 .55772 .29993 .562 .29193 .56692 .28233 Mtetra
.973 .818 .401 r
.5583 .29558 .55362 .31695 .55772 .29993 .56253 .28553 Mtetra
.834 .738 .216 r
.55426 .31514 .54964 .34316 .55362 .31695 .5583 .29558 Mtetra
0 0 0 r
.5503 .34272 .54549 .36931 .54964 .34316 .55426 .31514 Mtetra
.018 0 .157 r
.54607 .3659 .54079 .37605 .54549 .36931 .5503 .34272 Mtetra
.77 .282 .069 r
.5412 .36527 .5355 .35393 .54079 .37605 .54607 .3659 Mtetra
0 0 .326 r
.5358 .33745 .53006 .31705 .5355 .35393 .5412 .36527 Mtetra
0 0 .403 r
.53036 .30009 .52483 .28342 .53006 .31705 .5358 .33745 Mtetra
.13 .024 .455 r
.52516 .26877 .51983 .25945 .52483 .28342 .53036 .30009 Mtetra
.254 .137 .52 r
.52019 .24718 .515 .2437 .51983 .25945 .52516 .26877 Mtetra
.38 .268 .599 r
.51536 .23304 .51023 .23316 .515 .2437 .52019 .24718 Mtetra
.498 .4 .675 r
.5106 .22342 .5055 .22553 .51023 .23316 .51536 .23304 Mtetra
.586 .504 .729 r
.50586 .21627 .50078 .21943 .5055 .22553 .5106 .22342 Mtetra
.64 .57 .759 r
.50113 .21041 .49605 .2141 .50078 .21943 .50586 .21627 Mtetra
.67 .606 .775 r
.4964 .2052 .49132 .20916 .49605 .2141 .50113 .21041 Mtetra
.686 .626 .783 r
.49166 .20031 .48658 .20441 .49132 .20916 .4964 .2052 Mtetra
.694 .636 .787 r
.48691 .19559 .48183 .19976 .48658 .20441 .49166 .20031 Mtetra
.697 .641 .789 r
.48216 .19093 .47708 .19515 .48183 .19976 .48691 .19559 Mtetra
.699 .643 .79 r
.4774 .18631 .47231 .19055 .47708 .19515 .48216 .19093 Mtetra
.7 .644 .79 r
.47263 .18171 .46754 .18596 .47231 .19055 .4774 .18631 Mtetra
.701 .645 .791 r
.46785 .17711 .46276 .18137 .46754 .18596 .47263 .18171 Mtetra
.46306 .1725 .45797 .17678 .46276 .18137 .46785 .17711 Mtetra
.701 .646 .791 r
.45826 .16789 .45318 .17217 .45797 .17678 .46306 .1725 Mtetra
.45346 .16328 .44837 .16757 .45318 .17217 .45826 .16789 Mtetra
.44865 .15865 .44356 .16295 .44837 .16757 .45346 .16328 Mtetra
.44383 .15402 .43874 .15833 .44356 .16295 .44865 .15865 Mtetra
.439 .14938 .43391 .1537 .43874 .15833 .44383 .15402 Mtetra
.43416 .14473 .42908 .14906 .43391 .1537 .439 .14938 Mtetra
.42932 .14008 .42423 .14441 .42908 .14906 .43416 .14473 Mtetra
.42446 .13542 .41938 .13975 .42423 .14441 .42932 .14008 Mtetra
.4196 .13075 .41451 .13509 .41938 .13975 .42446 .13542 Mtetra
.41473 .12607 .40964 .13042 .41451 .13509 .4196 .13075 Mtetra
.40985 .12138 .40477 .12574 .40964 .13042 .41473 .12607 Mtetra
.40497 .11669 .39988 .12105 .40477 .12574 .40985 .12138 Mtetra
.40007 .11199 .39498 .11636 .39988 .12105 .40497 .11669 Mtetra
.39517 .10727 .39008 .11166 .39498 .11636 .40007 .11199 Mtetra
.84384 .52975 .83881 .53348 .84298 .53749 .84801 .53376 Mtetra
.83966 .52573 .83463 .52947 .83881 .53348 .84384 .52975 Mtetra
.83547 .5217 .83044 .52545 .83463 .52947 .83966 .52573 Mtetra
.83128 .51767 .82625 .52142 .83044 .52545 .83547 .5217 Mtetra
.82708 .51363 .82205 .51738 .82625 .52142 .83128 .51767 Mtetra
.82288 .50958 .81784 .51334 .82205 .51738 .82708 .51363 Mtetra
.81867 .50553 .81363 .5093 .81784 .51334 .82288 .50958 Mtetra
.81445 .50147 .80941 .50524 .81363 .5093 .81867 .50553 Mtetra
.81022 .4974 .80519 .50118 .80941 .50524 .81445 .50147 Mtetra
.80599 .49333 .80095 .49712 .80519 .50118 .81022 .4974 Mtetra
.80175 .48925 .79671 .49304 .80095 .49712 .80599 .49333 Mtetra
.79751 .48517 .79247 .48896 .79671 .49304 .80175 .48925 Mtetra
.79326 .48107 .78822 .48488 .79247 .48896 .79751 .48517 Mtetra
.789 .47697 .78396 .48079 .78822 .48488 .79326 .48107 Mtetra
.78473 .47287 .77969 .47669 .78396 .48079 .789 .47697 Mtetra
.78046 .46876 .77542 .47258 .77969 .47669 .78473 .47287 Mtetra
.77618 .46464 .77114 .46847 .77542 .47258 .78046 .46876 Mtetra
.77189 .46052 .76685 .46435 .77114 .46847 .77618 .46464 Mtetra
.7676 .45638 .76255 .46023 .76685 .46435 .77189 .46052 Mtetra
.7633 .45225 .75825 .45609 .76255 .46023 .7676 .45638 Mtetra
.75899 .4481 .75395 .45196 .75825 .45609 .7633 .45225 Mtetra
.75468 .44395 .74963 .44781 .75395 .45196 .75899 .4481 Mtetra
.75036 .43979 .74531 .44366 .74963 .44781 .75468 .44395 Mtetra
.74603 .43563 .74098 .4395 .74531 .44366 .75036 .43979 Mtetra
.7417 .43146 .73664 .43533 .74098 .4395 .74603 .43563 Mtetra
.73735 .42728 .7323 .43116 .73664 .43533 .7417 .43146 Mtetra
.733 .42309 .72795 .42698 .7323 .43116 .73735 .42728 Mtetra
.72865 .4189 .7236 .4228 .72795 .42698 .733 .42309 Mtetra
.72429 .4147 .71923 .41861 .7236 .4228 .72865 .4189 Mtetra
.71992 .4105 .71486 .41441 .71923 .41861 .72429 .4147 Mtetra
.702 .646 .791 r
.71554 .40629 .71048 .41021 .71486 .41441 .71992 .4105 Mtetra
.71116 .40207 .7061 .406 .71048 .41021 .71554 .40629 Mtetra
.70676 .39785 .70171 .40178 .7061 .406 .71116 .40207 Mtetra
.70237 .39362 .69731 .39756 .70171 .40178 .70676 .39785 Mtetra
.69796 .3894 .6929 .39334 .69731 .39756 .70237 .39362 Mtetra
.702 .647 .791 r
.69355 .38517 .68849 .38913 .6929 .39334 .69796 .3894 Mtetra
.703 .647 .791 r
.68913 .38094 .68408 .38492 .68849 .38913 .69355 .38517 Mtetra
.704 .649 .792 r
.68471 .37673 .67965 .38072 .68408 .38492 .68913 .38094 Mtetra
.705 .651 .792 r
.68028 .37255 .67523 .37656 .67965 .38072 .68471 .37673 Mtetra
.708 .654 .793 r
.67585 .3684 .6708 .37245 .67523 .37656 .68028 .37255 Mtetra
.712 .659 .795 r
.67142 .36434 .66637 .36843 .6708 .37245 .67585 .3684 Mtetra
.719 .667 .798 r
.667 .3604 .66195 .36458 .66637 .36843 .67142 .36434 Mtetra
.731 .681 .802 r
.66258 .35668 .65754 .36097 .66195 .36458 .667 .3604 Mtetra
.749 .703 .808 r
.65818 .3533 .65315 .35779 .65754 .36097 .66258 .35668 Mtetra
.778 .739 .817 r
.65382 .35048 .6488 .35526 .65315 .35779 .65818 .3533 Mtetra
.822 .797 .827 r
.64951 .34853 .64452 .35375 .6488 .35526 .65382 .35048 Mtetra
.881 .879 .828 r
.64528 .34787 .64032 .35373 .64452 .35375 .64951 .34853 Mtetra
.922 .963 .783 r
.64117 .34904 .63624 .35575 .64032 .35373 .64528 .34787 Mtetra
.863 .964 .633 r
.63718 .35254 .6323 .36021 .63624 .35575 .64117 .34904 Mtetra
.69 .845 .423 r
.63333 .35841 .62845 .36682 .6323 .36021 .63718 .35254 Mtetra
0 0 0 r
.6295 .36562 .62458 .37396 .62845 .36682 .63333 .35841 Mtetra
.62553 .3715 .62048 .37843 .62458 .37396 .6295 .36562 Mtetra
.757 .993 .873 r
.6212 .37245 .61597 .37679 .62048 .37843 .62553 .3715 Mtetra
.531 .52 .789 r
.6164 .36612 .61102 .36779 .61597 .37679 .6212 .37245 Mtetra
.414 .318 .637 r
.61123 .35341 .60579 .35349 .61102 .36779 .6164 .36612 Mtetra
.403 .278 .595 r
.60592 .33766 .60051 .33752 .60579 .35349 .61123 .35341 Mtetra
.425 .292 .595 r
.60067 .32221 .59534 .32275 .60051 .33752 .60592 .33766 Mtetra
.466 .334 .616 r
.59558 .30887 .59032 .31039 .59534 .32275 .60067 .32221 Mtetra
.518 .393 .649 r
.59064 .29807 .58545 .30055 .59032 .31039 .59558 .30887 Mtetra
.58 .464 .686 r
.58583 .28954 .5807 .2929 .58545 .30055 .59064 .29807 Mtetra
.649 .54 .717 r
.58111 .28289 .57603 .28715 .5807 .2929 .58583 .28954 Mtetra
.733 .622 .735 r
.57647 .27794 .57143 .2834 .57603 .28715 .58111 .28289 Mtetra
.837 .713 .727 r
.5719 .27498 .56692 .28233 .57143 .2834 .57647 .27794 Mtetra
.947 .799 .665 r
.56742 .2749 .56253 .28553 .56692 .28233 .5719 .27498 Mtetra
.999 .836 .529 r
.56307 .27959 .5583 .29558 .56253 .28553 .56742 .2749 Mtetra
.948 .803 .352 r
.55891 .29185 .55426 .31514 .5583 .29558 .56307 .27959 Mtetra
.775 .705 .166 r
.55493 .31387 .5503 .34272 .55426 .31514 .55891 .29185 Mtetra
0 0 .034 r
.55097 .34201 .54607 .3659 .5503 .34272 .55493 .31387 Mtetra
.184 0 .177 r
.54662 .36084 .5412 .36527 .54607 .3659 .55097 .34201 Mtetra
.823 .381 0 r
.54157 .35259 .5358 .33745 .5412 .36527 .54662 .36084 Mtetra
0 0 .355 r
.53608 .32037 .53036 .30009 .5358 .33745 .54157 .35259 Mtetra
.02 0 .415 r
.53065 .28359 .52516 .26877 .53036 .30009 .53608 .32037 Mtetra
.161 .05 .469 r
.52549 .25478 .52019 .24718 .52516 .26877 .53065 .28359 Mtetra
.285 .167 .538 r
.52055 .23538 .51536 .23304 .52019 .24718 .52549 .25478 Mtetra
.411 .302 .62 r
.51573 .22265 .5106 .22342 .51536 .23304 .52055 .23538 Mtetra
.524 .43 .691 r
.51097 .21381 .50586 .21627 .5106 .22342 .51573 .22265 Mtetra
.603 .524 .738 r
.50623 .20707 .50113 .21041 .50586 .21627 .51097 .21381 Mtetra
.65 .581 .765 r
.50149 .20141 .4964 .2052 .50113 .21041 .50623 .20707 Mtetra
.675 .613 .778 r
.49675 .19629 .49166 .20031 .4964 .2052 .50149 .20141 Mtetra
.688 .629 .784 r
.492 .19145 .48691 .19559 .49166 .20031 .49675 .19629 Mtetra
.695 .637 .788 r
.48725 .18673 .48216 .19093 .48691 .19559 .492 .19145 Mtetra
.698 .641 .789 r
.48249 .18208 .4774 .18631 .48216 .19093 .48725 .18673 Mtetra
.7 .643 .79 r
.47772 .17745 .47263 .18171 .4774 .18631 .48249 .18208 Mtetra
.701 .645 .79 r
.47294 .17284 .46785 .17711 .47263 .18171 .47772 .17745 Mtetra
.701 .645 .791 r
.46815 .16822 .46306 .1725 .46785 .17711 .47294 .17284 Mtetra
.46335 .1636 .45826 .16789 .46306 .1725 .46815 .16822 Mtetra
.45855 .15898 .45346 .16328 .45826 .16789 .46335 .1636 Mtetra
.701 .646 .791 r
.45374 .15435 .44865 .15865 .45346 .16328 .45855 .15898 Mtetra
.44892 .14971 .44383 .15402 .44865 .15865 .45374 .15435 Mtetra
.44409 .14506 .439 .14938 .44383 .15402 .44892 .14971 Mtetra
.43926 .14041 .43416 .14473 .439 .14938 .44409 .14506 Mtetra
.43441 .13574 .42932 .14008 .43416 .14473 .43926 .14041 Mtetra
.42956 .13107 .42446 .13542 .42932 .14008 .43441 .13574 Mtetra
.4247 .1264 .4196 .13075 .42446 .13542 .42956 .13107 Mtetra
.41983 .12171 .41473 .12607 .4196 .13075 .4247 .1264 Mtetra
.41495 .11702 .40985 .12138 .41473 .12607 .41983 .12171 Mtetra
.41007 .11232 .40497 .11669 .40985 .12138 .41495 .11702 Mtetra
.40517 .10761 .40007 .11199 .40497 .11669 .41007 .11232 Mtetra
.40027 .10289 .39517 .10727 .40007 .11199 .40517 .10761 Mtetra
.84887 .52601 .84384 .52975 .84801 .53376 .85304 .53003 Mtetra
.8447 .52198 .83966 .52573 .84384 .52975 .84887 .52601 Mtetra
.84051 .51795 .83547 .5217 .83966 .52573 .8447 .52198 Mtetra
.83632 .51391 .83128 .51767 .83547 .5217 .84051 .51795 Mtetra
.83212 .50986 .82708 .51363 .83128 .51767 .83632 .51391 Mtetra
.82792 .50581 .82288 .50958 .82708 .51363 .83212 .50986 Mtetra
.82371 .50175 .81867 .50553 .82288 .50958 .82792 .50581 Mtetra
.81949 .49769 .81445 .50147 .81867 .50553 .82371 .50175 Mtetra
.81527 .49361 .81022 .4974 .81445 .50147 .81949 .49769 Mtetra
.81104 .48954 .80599 .49333 .81022 .4974 .81527 .49361 Mtetra
.8068 .48545 .80175 .48925 .80599 .49333 .81104 .48954 Mtetra
.80255 .48136 .79751 .48517 .80175 .48925 .8068 .48545 Mtetra
.7983 .47726 .79326 .48107 .79751 .48517 .80255 .48136 Mtetra
.79404 .47316 .789 .47697 .79326 .48107 .7983 .47726 Mtetra
.78978 .46905 .78473 .47287 .789 .47697 .79404 .47316 Mtetra
.78551 .46493 .78046 .46876 .78473 .47287 .78978 .46905 Mtetra
.78123 .4608 .77618 .46464 .78046 .46876 .78551 .46493 Mtetra
.77694 .45667 .77189 .46052 .77618 .46464 .78123 .4608 Mtetra
.77265 .45254 .7676 .45638 .77189 .46052 .77694 .45667 Mtetra
.76835 .44839 .7633 .45225 .7676 .45638 .77265 .45254 Mtetra
.76405 .44424 .75899 .4481 .7633 .45225 .76835 .44839 Mtetra
.75973 .44008 .75468 .44395 .75899 .4481 .76405 .44424 Mtetra
.75541 .43592 .75036 .43979 .75468 .44395 .75973 .44008 Mtetra
.75109 .43175 .74603 .43563 .75036 .43979 .75541 .43592 Mtetra
.74675 .42757 .7417 .43146 .74603 .43563 .75109 .43175 Mtetra
.74241 .42339 .73735 .42728 .7417 .43146 .74675 .42757 Mtetra
.73806 .41919 .733 .42309 .73735 .42728 .74241 .42339 Mtetra
.73371 .415 .72865 .4189 .733 .42309 .73806 .41919 Mtetra
.72935 .41079 .72429 .4147 .72865 .4189 .73371 .415 Mtetra
.72498 .40658 .71992 .4105 .72429 .4147 .72935 .41079 Mtetra
.7206 .40236 .71554 .40629 .71992 .4105 .72498 .40658 Mtetra
.702 .646 .791 r
.71622 .39814 .71116 .40207 .71554 .40629 .7206 .40236 Mtetra
.71183 .39391 .70676 .39785 .71116 .40207 .71622 .39814 Mtetra
.70743 .38968 .70237 .39362 .70676 .39785 .71183 .39391 Mtetra
.70303 .38544 .69796 .3894 .70237 .39362 .70743 .38968 Mtetra
.702 .647 .791 r
.69862 .3812 .69355 .38517 .69796 .3894 .70303 .38544 Mtetra
.703 .647 .791 r
.6942 .37697 .68913 .38094 .69355 .38517 .69862 .3812 Mtetra
.703 .648 .792 r
.68978 .37274 .68471 .37673 .68913 .38094 .6942 .37697 Mtetra
.705 .65 .792 r
.68535 .36854 .68028 .37255 .68471 .37673 .68978 .37274 Mtetra
.707 .652 .793 r
.68092 .36437 .67585 .3684 .68028 .37255 .68535 .36854 Mtetra
.71 .656 .794 r
.67649 .36026 .67142 .36434 .67585 .3684 .68092 .36437 Mtetra
.716 .663 .797 r
.67206 .35625 .667 .3604 .67142 .36434 .67649 .36026 Mtetra
.726 .675 .8 r
.66763 .35243 .66258 .35668 .667 .3604 .67206 .35625 Mtetra
.741 .693 .806 r
.66323 .34889 .65818 .3533 .66258 .35668 .66763 .35243 Mtetra
.766 .724 .814 r
.65885 .34582 .65382 .35048 .65818 .3533 .66323 .34889 Mtetra
.804 .772 .824 r
.65452 .34348 .64951 .34853 .65382 .35048 .65885 .34582 Mtetra
.858 .846 .831 r
.65026 .34226 .64528 .34787 .64951 .34853 .65452 .34348 Mtetra
.913 .936 .809 r
.64611 .34267 .64117 .34904 .64528 .34787 .65026 .34226 Mtetra
.902 .98 .703 r
.64208 .34523 .63718 .35254 .64117 .34904 .64611 .34267 Mtetra
.76 .897 .499 r
.6382 .35023 .63333 .35841 .63718 .35254 .64208 .34523 Mtetra
0 0 0 r
.6344 .35712 .6295 .36562 .63333 .35841 .6382 .35023 Mtetra
.63053 .36388 .62553 .3715 .6295 .36562 .6344 .35712 Mtetra
.658 .927 .64 r
.62637 .36705 .6212 .37245 .62553 .3715 .63053 .36388 Mtetra
.638 .702 .892 r
.62174 .36352 .6164 .36612 .6212 .37245 .62637 .36705 Mtetra
.438 .362 .674 r
.61667 .3529 .61123 .35341 .6164 .36612 .62174 .36352 Mtetra
.401 .284 .603 r
.61136 .33785 .60592 .33766 .61123 .35341 .61667 .3529 Mtetra
.414 .282 .591 r
.60605 .32199 .60067 .32221 .60592 .33766 .61136 .33785 Mtetra
.448 .315 .606 r
.60087 .30774 .59558 .30887 .60067 .32221 .60605 .32199 Mtetra
.495 .368 .636 r
.59586 .29597 .59064 .29807 .59558 .30887 .60087 .30774 Mtetra
.552 .433 .672 r
.59099 .28658 .58583 .28954 .59064 .29807 .59586 .29597 Mtetra
.613 .504 .706 r
.58623 .27913 .58111 .28289 .58583 .28954 .59099 .28658 Mtetra
.682 .578 .732 r
.58155 .2733 .57647 .27794 .58111 .28289 .58623 .27913 Mtetra
.767 .657 .741 r
.57693 .26906 .5719 .27498 .57647 .27794 .58155 .2733 Mtetra
.872 .744 .719 r
.57239 .26684 .56742 .2749 .5719 .27498 .57693 .26906 Mtetra
.97 .818 .636 r
.56794 .26782 .56307 .27959 .56742 .2749 .57239 .26684 Mtetra
.996 .834 .484 r
.56364 .27415 .55891 .29185 .56307 .27959 .56794 .26782 Mtetra
.916 .784 .304 r
.55954 .28875 .55493 .31387 .55891 .29185 .56364 .27415 Mtetra
.704 .665 .116 r
.55562 .31301 .55097 .34201 .55493 .31387 .55954 .28875 Mtetra
0 0 .08 r
.55164 .34069 .54662 .36084 .55097 .34201 .55562 .31301 Mtetra
.37 0 .176 r
.54713 .35388 .54157 .35259 .54662 .36084 .55164 .34069 Mtetra
.69 .377 0 r
.5419 .33826 .53608 .32037 .54157 .35259 .54713 .35388 Mtetra
0 0 .374 r
.53635 .30305 .53065 .28359 .53608 .32037 .5419 .33826 Mtetra
.059 0 .427 r
.53095 .26767 .52549 .25478 .53065 .28359 .53635 .30305 Mtetra
.191 .077 .484 r
.52583 .2414 .52055 .23538 .52549 .25478 .53095 .26767 Mtetra
.316 .2 .558 r
.52091 .224 .51573 .22265 .52055 .23538 .52583 .2414 Mtetra
.442 .336 .639 r
.5161 .21248 .51097 .21381 .51573 .22265 .52091 .224 Mtetra
.547 .458 .705 r
.51134 .20431 .50623 .20707 .51097 .21381 .5161 .21248 Mtetra
.618 .542 .747 r
.50659 .19791 .50149 .20141 .50623 .20707 .51134 .20431 Mtetra
.658 .591 .769 r
.50185 .19241 .49675 .19629 .50149 .20141 .50659 .19791 Mtetra
.679 .618 .78 r
.4971 .18738 .492 .19145 .49675 .19629 .50185 .19241 Mtetra
.69 .632 .785 r
.49235 .18256 .48725 .18673 .492 .19145 .4971 .18738 Mtetra
.696 .639 .788 r
.48758 .17786 .48249 .18208 .48725 .18673 .49235 .18256 Mtetra
.699 .642 .789 r
.48281 .1732 .47772 .17745 .48249 .18208 .48758 .17786 Mtetra
.7 .644 .79 r
.47804 .16856 .47294 .17284 .47772 .17745 .48281 .1732 Mtetra
.701 .645 .79 r
.47325 .16394 .46815 .16822 .47294 .17284 .47804 .16856 Mtetra
.701 .645 .791 r
.46845 .15931 .46335 .1636 .46815 .16822 .47325 .16394 Mtetra
.46365 .15467 .45855 .15898 .46335 .1636 .46845 .15931 Mtetra
.701 .646 .791 r
.45884 .15003 .45374 .15435 .45855 .15898 .46365 .15467 Mtetra
.45402 .14539 .44892 .14971 .45374 .15435 .45884 .15003 Mtetra
.44919 .14073 .44409 .14506 .44892 .14971 .45402 .14539 Mtetra
.44436 .13607 .43926 .14041 .44409 .14506 .44919 .14073 Mtetra
.43951 .1314 .43441 .13574 .43926 .14041 .44436 .13607 Mtetra
.43466 .12673 .42956 .13107 .43441 .13574 .43951 .1314 Mtetra
.4298 .12204 .4247 .1264 .42956 .13107 .43466 .12673 Mtetra
.42493 .11735 .41983 .12171 .4247 .1264 .4298 .12204 Mtetra
.42006 .11265 .41495 .11702 .41983 .12171 .42493 .11735 Mtetra
.41517 .10794 .41007 .11232 .41495 .11702 .42006 .11265 Mtetra
.41028 .10322 .40517 .10761 .41007 .11232 .41517 .10794 Mtetra
.40537 .09849 .40027 .10289 .40517 .10761 .41028 .10322 Mtetra
.85392 .52227 .84887 .52601 .85304 .53003 .85809 .52629 Mtetra
.84974 .51823 .8447 .52198 .84887 .52601 .85392 .52227 Mtetra
.84556 .51419 .84051 .51795 .8447 .52198 .84974 .51823 Mtetra
.84137 .51015 .83632 .51391 .84051 .51795 .84556 .51419 Mtetra
.83717 .5061 .83212 .50986 .83632 .51391 .84137 .51015 Mtetra
.83297 .50204 .82792 .50581 .83212 .50986 .83717 .5061 Mtetra
.82876 .49797 .82371 .50175 .82792 .50581 .83297 .50204 Mtetra
.82454 .4939 .81949 .49769 .82371 .50175 .82876 .49797 Mtetra
.82032 .48982 .81527 .49361 .81949 .49769 .82454 .4939 Mtetra
.81609 .48574 .81104 .48954 .81527 .49361 .82032 .48982 Mtetra
.81185 .48165 .8068 .48545 .81104 .48954 .81609 .48574 Mtetra
.80761 .47755 .80255 .48136 .8068 .48545 .81185 .48165 Mtetra
.80336 .47345 .7983 .47726 .80255 .48136 .80761 .47755 Mtetra
.7991 .46933 .79404 .47316 .7983 .47726 .80336 .47345 Mtetra
.79484 .46522 .78978 .46905 .79404 .47316 .7991 .46933 Mtetra
.79057 .46109 .78551 .46493 .78978 .46905 .79484 .46522 Mtetra
.78629 .45696 .78123 .4608 .78551 .46493 .79057 .46109 Mtetra
.782 .45283 .77694 .45667 .78123 .4608 .78629 .45696 Mtetra
.77771 .44868 .77265 .45254 .77694 .45667 .782 .45283 Mtetra
.77341 .44453 .76835 .44839 .77265 .45254 .77771 .44868 Mtetra
.76911 .44037 .76405 .44424 .76835 .44839 .77341 .44453 Mtetra
.7648 .43621 .75973 .44008 .76405 .44424 .76911 .44037 Mtetra
.76048 .43204 .75541 .43592 .75973 .44008 .7648 .43621 Mtetra
.75615 .42786 .75109 .43175 .75541 .43592 .76048 .43204 Mtetra
.75182 .42368 .74675 .42757 .75109 .43175 .75615 .42786 Mtetra
.74748 .41949 .74241 .42339 .74675 .42757 .75182 .42368 Mtetra
.74313 .41529 .73806 .41919 .74241 .42339 .74748 .41949 Mtetra
.73878 .41109 .73371 .415 .73806 .41919 .74313 .41529 Mtetra
.73442 .40688 .72935 .41079 .73371 .415 .73878 .41109 Mtetra
.73005 .40266 .72498 .40658 .72935 .41079 .73442 .40688 Mtetra
.72567 .39843 .7206 .40236 .72498 .40658 .73005 .40266 Mtetra
.702 .646 .791 r
.72129 .3942 .71622 .39814 .7206 .40236 .72567 .39843 Mtetra
.7169 .38997 .71183 .39391 .71622 .39814 .72129 .3942 Mtetra
.7125 .38573 .70743 .38968 .71183 .39391 .7169 .38997 Mtetra
.7081 .38148 .70303 .38544 .70743 .38968 .7125 .38573 Mtetra
.70369 .37724 .69862 .3812 .70303 .38544 .7081 .38148 Mtetra
.702 .647 .791 r
.69927 .37299 .6942 .37697 .69862 .3812 .70369 .37724 Mtetra
.703 .648 .791 r
.69485 .36875 .68978 .37274 .6942 .37697 .69927 .37299 Mtetra
.704 .649 .792 r
.69042 .36453 .68535 .36854 .68978 .37274 .69485 .36875 Mtetra
.706 .651 .793 r
.68599 .36033 .68092 .36437 .68535 .36854 .69042 .36453 Mtetra
.709 .655 .794 r
.68156 .35618 .67649 .36026 .68092 .36437 .68599 .36033 Mtetra
.714 .66 .796 r
.67713 .35213 .67206 .35625 .67649 .36026 .68156 .35618 Mtetra
.722 .67 .799 r
.6727 .34821 .66763 .35243 .67206 .35625 .67713 .35213 Mtetra
.734 .685 .803 r
.66828 .34454 .66323 .34889 .66763 .35243 .6727 .34821 Mtetra
.755 .711 .81 r
.66389 .34126 .65885 .34582 .66323 .34889 .66828 .34454 Mtetra
.788 .751 .82 r
.65954 .3386 .65452 .34348 .65885 .34582 .66389 .34126 Mtetra
.836 .815 .829 r
.65526 .33689 .65026 .34226 .65452 .34348 .65954 .3386 Mtetra
.895 .902 .824 r
.65107 .3366 .64611 .34267 .65026 .34226 .65526 .33689 Mtetra
.921 .976 .757 r
.647 .33828 .64208 .34523 .64611 .34267 .65107 .3366 Mtetra
.826 .942 .58 r
.64308 .34234 .6382 .35023 .64208 .34523 .647 .33828 Mtetra
.644 .811 .379 r
.63928 .34864 .6344 .35712 .6382 .35023 .64308 .34234 Mtetra
0 0 0 r
.63548 .35576 .63053 .36388 .6344 .35712 .63928 .34864 Mtetra
.561 .819 .451 r
.63147 .36068 .62637 .36705 .63053 .36388 .63548 .35576 Mtetra
.749 .921 .948 r
.62703 .35988 .62174 .36352 .62637 .36705 .63147 .36068 Mtetra
.483 .439 .733 r
.6221 .35174 .61667 .3529 .62174 .36352 .62703 .35988 Mtetra
.406 .299 .62 r
.61683 .33792 .61136 .33785 .61667 .3529 .6221 .35174 Mtetra
.405 .277 .592 r
.61148 .322 .60605 .32199 .61136 .33785 .61683 .33792 Mtetra
.433 .299 .598 r
.60622 .30697 .60087 .30774 .60605 .32199 .61148 .322 Mtetra
.475 .345 .623 r
.60113 .29424 .59586 .29597 .60087 .30774 .60622 .30697 Mtetra
.527 .406 .658 r
.59619 .28397 .59099 .28658 .59586 .29597 .60113 .29424 Mtetra
.584 .474 .694 r
.59138 .27577 .58623 .27913 .59099 .28658 .59619 .28397 Mtetra
.645 .542 .724 r
.58666 .26921 .58155 .2733 .58623 .27913 .59138 .27577 Mtetra
.713 .612 .743 r
.58201 .26406 .57693 .26906 .58155 .2733 .58666 .26921 Mtetra
.799 .689 .743 r
.57741 .26044 .57239 .26684 .57693 .26906 .58201 .26406 Mtetra
.904 .771 .705 r
.57289 .25898 .56794 .26782 .57239 .26684 .57741 .26044 Mtetra
.987 .83 .601 r
.56848 .26111 .56364 .27415 .56794 .26782 .57289 .25898 Mtetra
.986 .827 .437 r
.56423 .26923 .55954 .28875 .56364 .27415 .56848 .26111 Mtetra
.877 .761 .256 r
.5602 .28626 .55562 .31301 .55954 .28875 .56423 .26923 Mtetra
0 0 0 r
.55633 .3124 .55164 .34069 .55562 .31301 .5602 .28626 Mtetra
0 0 .119 r
.55228 .3384 .54713 .35388 .55164 .34069 .55633 .3124 Mtetra
.577 .124 .14 r
.54759 .3449 .5419 .33826 .54713 .35388 .55228 .3384 Mtetra
0 0 .287 r
.54221 .32262 .53635 .30305 .5419 .33826 .54759 .3449 Mtetra
0 0 .389 r
.53662 .28579 .53095 .26767 .53635 .30305 .54221 .32262 Mtetra
.095 0 .439 r
.53126 .25237 .52583 .2414 .53095 .26767 .53662 .28579 Mtetra
.221 .105 .5 r
.52618 .2286 .52091 .224 .52583 .2414 .53126 .25237 Mtetra
.347 .233 .578 r
.52128 .21299 .5161 .21248 .52091 .224 .52618 .2286 Mtetra
.471 .369 .658 r
.51647 .20251 .51134 .20431 .5161 .21248 .52128 .21299 Mtetra
.568 .482 .718 r
.51171 .1949 .50659 .19791 .51134 .20431 .51647 .20251 Mtetra
.63 .557 .754 r
.50696 .18878 .50185 .19241 .50659 .19791 .51171 .1949 Mtetra
.665 .6 .772 r
.50221 .18342 .4971 .18738 .50185 .19241 .50696 .18878 Mtetra
.683 .622 .782 r
.49745 .17845 .49235 .18256 .4971 .18738 .50221 .18342 Mtetra
.692 .634 .786 r
.49269 .17366 .48758 .17786 .49235 .18256 .49745 .17845 Mtetra
.697 .64 .789 r
.48792 .16896 .48281 .1732 .48758 .17786 .49269 .17366 Mtetra
.699 .643 .79 r
.48314 .16429 .47804 .16856 .48281 .1732 .48792 .16896 Mtetra
.7 .644 .79 r
.47836 .15965 .47325 .16394 .47804 .16856 .48314 .16429 Mtetra
.701 .645 .791 r
.47356 .15501 .46845 .15931 .47325 .16394 .47836 .15965 Mtetra
.46876 .15036 .46365 .15467 .46845 .15931 .47356 .15501 Mtetra
.46395 .14571 .45884 .15003 .46365 .15467 .46876 .15036 Mtetra
.701 .646 .791 r
.45913 .14106 .45402 .14539 .45884 .15003 .46395 .14571 Mtetra
.4543 .1364 .44919 .14073 .45402 .14539 .45913 .14106 Mtetra
.44947 .13173 .44436 .13607 .44919 .14073 .4543 .1364 Mtetra
.44463 .12705 .43951 .1314 .44436 .13607 .44947 .13173 Mtetra
.43977 .12237 .43466 .12673 .43951 .1314 .44463 .12705 Mtetra
.43491 .11768 .4298 .12204 .43466 .12673 .43977 .12237 Mtetra
.43005 .11297 .42493 .11735 .4298 .12204 .43491 .11768 Mtetra
.42517 .10827 .42006 .11265 .42493 .11735 .43005 .11297 Mtetra
.42028 .10355 .41517 .10794 .42006 .11265 .42517 .10827 Mtetra
.41539 .09882 .41028 .10322 .41517 .10794 .42028 .10355 Mtetra
.41049 .09409 .40537 .09849 .41028 .10322 .41539 .09882 Mtetra
.85897 .51852 .85392 .52227 .85809 .52629 .86314 .52255 Mtetra
.85479 .51448 .84974 .51823 .85392 .52227 .85897 .51852 Mtetra
.85061 .51043 .84556 .51419 .84974 .51823 .85479 .51448 Mtetra
.84642 .50638 .84137 .51015 .84556 .51419 .85061 .51043 Mtetra
.84223 .50232 .83717 .5061 .84137 .51015 .84642 .50638 Mtetra
.83802 .49826 .83297 .50204 .83717 .5061 .84223 .50232 Mtetra
.83382 .49419 .82876 .49797 .83297 .50204 .83802 .49826 Mtetra
.8296 .49011 .82454 .4939 .82876 .49797 .83382 .49419 Mtetra
.82538 .48602 .82032 .48982 .82454 .4939 .8296 .49011 Mtetra
.82115 .48193 .81609 .48574 .82032 .48982 .82538 .48602 Mtetra
.81691 .47784 .81185 .48165 .81609 .48574 .82115 .48193 Mtetra
.81267 .47373 .80761 .47755 .81185 .48165 .81691 .47784 Mtetra
.80842 .46962 .80336 .47345 .80761 .47755 .81267 .47373 Mtetra
.80416 .46551 .7991 .46933 .80336 .47345 .80842 .46962 Mtetra
.7999 .46138 .79484 .46522 .7991 .46933 .80416 .46551 Mtetra
.79563 .45725 .79057 .46109 .79484 .46522 .7999 .46138 Mtetra
.79135 .45312 .78629 .45696 .79057 .46109 .79563 .45725 Mtetra
.78707 .44897 .782 .45283 .78629 .45696 .79135 .45312 Mtetra
.78278 .44482 .77771 .44868 .782 .45283 .78707 .44897 Mtetra
.77848 .44067 .77341 .44453 .77771 .44868 .78278 .44482 Mtetra
.77418 .4365 .76911 .44037 .77341 .44453 .77848 .44067 Mtetra
.76987 .43233 .7648 .43621 .76911 .44037 .77418 .4365 Mtetra
.76555 .42816 .76048 .43204 .7648 .43621 .76987 .43233 Mtetra
.76122 .42397 .75615 .42786 .76048 .43204 .76555 .42816 Mtetra
.75689 .41978 .75182 .42368 .75615 .42786 .76122 .42397 Mtetra
.75255 .41558 .74748 .41949 .75182 .42368 .75689 .41978 Mtetra
.74821 .41138 .74313 .41529 .74748 .41949 .75255 .41558 Mtetra
.74385 .40717 .73878 .41109 .74313 .41529 .74821 .41138 Mtetra
.73949 .40295 .73442 .40688 .73878 .41109 .74385 .40717 Mtetra
.73512 .39873 .73005 .40266 .73442 .40688 .73949 .40295 Mtetra
.73075 .3945 .72567 .39843 .73005 .40266 .73512 .39873 Mtetra
.702 .646 .791 r
.72637 .39026 .72129 .3942 .72567 .39843 .73075 .3945 Mtetra
.72198 .38602 .7169 .38997 .72129 .3942 .72637 .39026 Mtetra
.71758 .38177 .7125 .38573 .7169 .38997 .72198 .38602 Mtetra
.71318 .37752 .7081 .38148 .7125 .38573 .71758 .38177 Mtetra
.70877 .37326 .70369 .37724 .7081 .38148 .71318 .37752 Mtetra
.702 .647 .791 r
.70436 .36901 .69927 .37299 .70369 .37724 .70877 .37326 Mtetra
.703 .647 .791 r
.69993 .36476 .69485 .36875 .69927 .37299 .70436 .36901 Mtetra
.704 .648 .792 r
.69551 .36052 .69042 .36453 .69485 .36875 .69993 .36476 Mtetra
.705 .65 .792 r
.69108 .3563 .68599 .36033 .69042 .36453 .69551 .36052 Mtetra
.708 .653 .793 r
.68664 .35212 .68156 .35618 .68599 .36033 .69108 .3563 Mtetra
.712 .658 .795 r
.6822 .34801 .67713 .35213 .68156 .35618 .68664 .35212 Mtetra
.718 .666 .797 r
.67777 .34403 .6727 .34821 .67713 .35213 .6822 .34801 Mtetra
.729 .679 .801 r
.67335 .34024 .66828 .34454 .6727 .34821 .67777 .34403 Mtetra
.746 .7 .807 r
.66895 .33678 .66389 .34126 .66828 .34454 .67335 .34024 Mtetra
.774 .734 .816 r
.66458 .33384 .65954 .3386 .66389 .34126 .66895 .33678 Mtetra
.816 .788 .826 r
.66027 .33171 .65526 .33689 .65954 .3386 .66458 .33384 Mtetra
.873 .868 .83 r
.65605 .33081 .65107 .3366 .65526 .33689 .66027 .33171 Mtetra
.921 .955 .793 r
.65194 .33167 .647 .33828 .65107 .3366 .65605 .33081 Mtetra
.878 .971 .657 r
.64798 .33479 .64308 .34234 .647 .33828 .65194 .33167 Mtetra
.712 .862 .447 r
.64415 .3403 .63928 .34864 .64308 .34234 .64798 .33479 Mtetra
0 0 0 r
.64039 .34735 .63548 .35576 .63928 .34864 .64415 .3403 Mtetra
.63651 .3535 .63147 .36068 .63548 .35576 .64039 .34735 Mtetra
.734 .989 .804 r
.63226 .35517 .62703 .35988 .63147 .36068 .63651 .3535 Mtetra
.562 .572 .821 r
.6275 .34975 .6221 .35174 .62703 .35988 .63226 .35517 Mtetra
.42 .33 .647 r
.62232 .33769 .61683 .33792 .6221 .35174 .6275 .34975 Mtetra
.401 .278 .597 r
.61694 .32214 .61148 .322 .61683 .33792 .62232 .33769 Mtetra
.42 .287 .593 r
.61161 .30654 .60622 .30697 .61148 .322 .61694 .32214 Mtetra
.457 .325 .612 r
.60643 .29287 .60113 .29424 .60622 .30697 .61161 .30654 Mtetra
.506 .381 .644 r
.60143 .28169 .59619 .28397 .60113 .29424 .60643 .29287 Mtetra
.559 .446 .68 r
.59656 .27272 .59138 .27577 .59619 .28397 .60143 .28169 Mtetra
.615 .512 .713 r
.5918 .2655 .58666 .26921 .59138 .27577 .59656 .27272 Mtetra
.673 .576 .738 r
.58711 .25966 .58201 .26406 .58666 .26921 .5918 .2655 Mtetra
.741 .642 .75 r
.58248 .25509 .57741 .26044 .58201 .26406 .58711 .25966 Mtetra
.83 .717 .74 r
.5779 .25205 .57289 .25898 .57741 .26044 .58248 .25509 Mtetra
.932 .794 .686 r
.5734 .25139 .56848 .26111 .57289 .25898 .5779 .25205 Mtetra
.997 .837 .563 r
.56903 .25477 .56423 .26923 .56848 .26111 .5734 .25139 Mtetra
.968 .815 .39 r
.56485 .26486 .5602 .28626 .56423 .26923 .56903 .25477 Mtetra
.828 .733 .208 r
.56089 .28435 .55633 .3124 .5602 .28626 .56485 .26486 Mtetra
0 0 0 r
.55704 .31179 .55228 .3384 .55633 .3124 .56089 .28435 Mtetra
.009 0 .149 r
.55289 .33477 .54759 .3449 .55228 .3384 .55704 .31179 Mtetra
.767 .273 .047 r
.548 .33392 .54221 .32262 .54759 .3449 .55289 .33477 Mtetra
0 0 .33 r
.54249 .30604 .53662 .28579 .54221 .32262 .548 .33392 Mtetra
0 0 .402 r
.5369 .26883 .53126 .25237 .53662 .28579 .54249 .30604 Mtetra
.127 .021 .453 r
.53158 .23773 .52618 .2286 .53126 .25237 .5369 .26883 Mtetra
.252 .134 .518 r
.52653 .21631 .52128 .21299 .52618 .2286 .53158 .23773 Mtetra
.379 .267 .599 r
.52165 .20228 .51647 .20251 .52128 .21299 .52653 .21631 Mtetra
.498 .401 .675 r
.51685 .1927 .51171 .1949 .51647 .20251 .52165 .20228 Mtetra
.587 .505 .729 r
.51208 .18556 .50696 .18878 .51171 .1949 .51685 .1927 Mtetra
.641 .57 .76 r
.50732 .17968 .50221 .18342 .50696 .18878 .51208 .18556 Mtetra
.671 .607 .775 r
.50257 .17443 .49745 .17845 .50221 .18342 .50732 .17968 Mtetra
.686 .626 .783 r
.4978 .1695 .49269 .17366 .49745 .17845 .50257 .17443 Mtetra
.694 .636 .787 r
.49303 .16473 .48792 .16896 .49269 .17366 .4978 .1695 Mtetra
.697 .641 .789 r
.48826 .16003 .48314 .16429 .48792 .16896 .49303 .16473 Mtetra
.699 .643 .79 r
.48347 .15536 .47836 .15965 .48314 .16429 .48826 .16003 Mtetra
.701 .645 .79 r
.47868 .1507 .47356 .15501 .47836 .15965 .48347 .15536 Mtetra
.701 .645 .791 r
.47388 .14605 .46876 .15036 .47356 .15501 .47868 .1507 Mtetra
.46907 .14139 .46395 .14571 .46876 .15036 .47388 .14605 Mtetra
.701 .646 .791 r
.46425 .13673 .45913 .14106 .46395 .14571 .46907 .14139 Mtetra
.45942 .13206 .4543 .1364 .45913 .14106 .46425 .13673 Mtetra
.45459 .12738 .44947 .13173 .4543 .1364 .45942 .13206 Mtetra
.44975 .1227 .44463 .12705 .44947 .13173 .45459 .12738 Mtetra
.44489 .118 .43977 .12237 .44463 .12705 .44975 .1227 Mtetra
.44003 .1133 .43491 .11768 .43977 .12237 .44489 .118 Mtetra
.43517 .1086 .43005 .11297 .43491 .11768 .44003 .1133 Mtetra
.43029 .10388 .42517 .10827 .43005 .11297 .43517 .1086 Mtetra
.42541 .09916 .42028 .10355 .42517 .10827 .43029 .10388 Mtetra
.42051 .09442 .41539 .09882 .42028 .10355 .42541 .09916 Mtetra
.41561 .08968 .41049 .09409 .41539 .09882 .42051 .09442 Mtetra
.86403 .51476 .85897 .51852 .86314 .52255 .8682 .5188 Mtetra
.85985 .51071 .85479 .51448 .85897 .51852 .86403 .51476 Mtetra
.85567 .50666 .85061 .51043 .85479 .51448 .85985 .51071 Mtetra
.85148 .50261 .84642 .50638 .85061 .51043 .85567 .50666 Mtetra
.84729 .49854 .84223 .50232 .84642 .50638 .85148 .50261 Mtetra
.84309 .49447 .83802 .49826 .84223 .50232 .84729 .49854 Mtetra
.83888 .49039 .83382 .49419 .83802 .49826 .84309 .49447 Mtetra
.83467 .48631 .8296 .49011 .83382 .49419 .83888 .49039 Mtetra
.83044 .48222 .82538 .48602 .8296 .49011 .83467 .48631 Mtetra
.82622 .47812 .82115 .48193 .82538 .48602 .83044 .48222 Mtetra
.82198 .47402 .81691 .47784 .82115 .48193 .82622 .47812 Mtetra
.81774 .46991 .81267 .47373 .81691 .47784 .82198 .47402 Mtetra
.81349 .46579 .80842 .46962 .81267 .47373 .81774 .46991 Mtetra
.80924 .46167 .80416 .46551 .80842 .46962 .81349 .46579 Mtetra
.80497 .45754 .7999 .46138 .80416 .46551 .80924 .46167 Mtetra
.8007 .45341 .79563 .45725 .7999 .46138 .80497 .45754 Mtetra
.79643 .44926 .79135 .45312 .79563 .45725 .8007 .45341 Mtetra
.79215 .44511 .78707 .44897 .79135 .45312 .79643 .44926 Mtetra
.78786 .44096 .78278 .44482 .78707 .44897 .79215 .44511 Mtetra
.78356 .43679 .77848 .44067 .78278 .44482 .78786 .44096 Mtetra
.77926 .43263 .77418 .4365 .77848 .44067 .78356 .43679 Mtetra
.77495 .42845 .76987 .43233 .77418 .4365 .77926 .43263 Mtetra
.77063 .42427 .76555 .42816 .76987 .43233 .77495 .42845 Mtetra
.7663 .42008 .76122 .42397 .76555 .42816 .77063 .42427 Mtetra
.76197 .41588 .75689 .41978 .76122 .42397 .7663 .42008 Mtetra
.75763 .41168 .75255 .41558 .75689 .41978 .76197 .41588 Mtetra
.75329 .40747 .74821 .41138 .75255 .41558 .75763 .41168 Mtetra
.74894 .40325 .74385 .40717 .74821 .41138 .75329 .40747 Mtetra
.74458 .39902 .73949 .40295 .74385 .40717 .74894 .40325 Mtetra
.74021 .39479 .73512 .39873 .73949 .40295 .74458 .39902 Mtetra
.73584 .39056 .73075 .3945 .73512 .39873 .74021 .39479 Mtetra
.73145 .38631 .72637 .39026 .73075 .3945 .73584 .39056 Mtetra
.702 .646 .791 r
.72707 .38206 .72198 .38602 .72637 .39026 .73145 .38631 Mtetra
.72267 .37781 .71758 .38177 .72198 .38602 .72707 .38206 Mtetra
.71827 .37355 .71318 .37752 .71758 .38177 .72267 .37781 Mtetra
.71386 .36929 .70877 .37326 .71318 .37752 .71827 .37355 Mtetra
.702 .647 .791 r
.70945 .36502 .70436 .36901 .70877 .37326 .71386 .36929 Mtetra
.703 .647 .791 r
.70502 .36076 .69993 .36476 .70436 .36901 .70945 .36502 Mtetra
.703 .648 .792 r
.7006 .3565 .69551 .36052 .69993 .36476 .70502 .36076 Mtetra
.705 .649 .792 r
.69617 .35226 .69108 .3563 .69551 .36052 .7006 .3565 Mtetra
.707 .652 .793 r
.69173 .34806 .68664 .35212 .69108 .3563 .69617 .35226 Mtetra
.71 .656 .794 r
.68729 .34391 .6822 .34801 .68664 .35212 .69173 .34806 Mtetra
.715 .662 .796 r
.68286 .33986 .67777 .34403 .6822 .34801 .68729 .34391 Mtetra
.724 .673 .8 r
.67843 .33598 .67335 .34024 .67777 .34403 .68286 .33986 Mtetra
.739 .691 .805 r
.67402 .33237 .66895 .33678 .67335 .34024 .67843 .33598 Mtetra
.762 .719 .813 r
.66964 .32919 .66458 .33384 .66895 .33678 .67402 .33237 Mtetra
.798 .765 .823 r
.6653 .32671 .66027 .33171 .66458 .33384 .66964 .32919 Mtetra
.851 .835 .831 r
.66105 .32527 .65605 .33081 .66027 .33171 .6653 .32671 Mtetra
.908 .925 .815 r
.6569 .32539 .65194 .33167 .65605 .33081 .66105 .32527 Mtetra
.91 .981 .722 r
.65289 .32759 .64798 .33479 .65194 .33167 .6569 .32539 Mtetra
.782 .913 .525 r
.64903 .33221 .64415 .3403 .64798 .33479 .65289 .32759 Mtetra
0 0 0 r
.64528 .33884 .64039 .34735 .64415 .3403 .64903 .33221 Mtetra
.64149 .34568 .63651 .3535 .64039 .34735 .64528 .33884 Mtetra
.623 .891 .57 r
.63742 .34942 .63226 .35517 .63651 .3535 .64149 .34568 Mtetra
.68 .776 .924 r
.63286 .34678 .6275 .34975 .63226 .35517 .63742 .34942 Mtetra
.45 .384 .691 r
.6278 .33695 .62232 .33769 .6275 .34975 .63286 .34678 Mtetra
.401 .287 .608 r
.62244 .32228 .61694 .32214 .62232 .33769 .6278 .33695 Mtetra
.41 .279 .591 r
.61705 .30637 .61161 .30654 .61694 .32214 .62244 .32228 Mtetra
.441 .308 .603 r
.61178 .29186 .60643 .29287 .61161 .30654 .61705 .30637 Mtetra
.486 .358 .631 r
.6067 .27974 .60143 .28169 .60643 .29287 .61178 .29186 Mtetra
.537 .42 .667 r
.60177 .26997 .59656 .27272 .60143 .28169 .6067 .27974 Mtetra
.59 .484 .702 r
.59697 .26209 .5918 .2655 .59656 .27272 .60177 .26997 Mtetra
.643 .546 .73 r
.59224 .25566 .58711 .25966 .5918 .2655 .59697 .26209 Mtetra
.699 .606 .749 r
.58757 .2504 .58248 .25509 .58711 .25966 .59224 .25566 Mtetra
.768 .669 .754 r
.58296 .24633 .5779 .25205 .58248 .25509 .58757 .2504 Mtetra
.859 .743 .733 r
.5784 .24387 .5734 .25139 .5779 .25205 .58296 .24633 Mtetra
.956 .813 .661 r
.57393 .24407 .56903 .25477 .5734 .25139 .5784 .24387 Mtetra
.999 .838 .52 r
.56961 .24885 .56485 .26486 .56903 .25477 .57393 .24407 Mtetra
.943 .799 .343 r
.5655 .26108 .56089 .28435 .56485 .26486 .56961 .24885 Mtetra
.77 .701 .16 r
.56161 .28296 .55704 .31179 .56089 .28435 .5655 .26108 Mtetra
0 0 .031 r
.55775 .31089 .55289 .33477 .55704 .31179 .56161 .28296 Mtetra
.175 0 .166 r
.55347 .32949 .548 .33392 .55289 .33477 .55775 .31089 Mtetra
.812 .37 0 r
.54837 .32108 .54249 .30604 .548 .33392 .55347 .32949 Mtetra
0 0 .357 r
.54275 .2889 .5369 .26883 .54249 .30604 .54837 .32108 Mtetra
.017 0 .413 r
.53718 .25233 .53158 .23773 .5369 .26883 .54275 .2889 Mtetra
.158 .047 .467 r
.53191 .22373 .52653 .21631 .53158 .23773 .53718 .25233 Mtetra
.283 .165 .537 r
.52689 .20449 .52165 .20228 .52653 .21631 .53191 .22373 Mtetra
.41 .302 .62 r
.52202 .19183 .51685 .1927 .52165 .20228 .52689 .20449 Mtetra
.524 .431 .691 r
.51722 .18302 .51208 .18556 .51685 .1927 .52202 .19183 Mtetra
.603 .525 .739 r
.51245 .17627 .50732 .17968 .51208 .18556 .51722 .18302 Mtetra
.65 .582 .765 r
.50769 .17058 .50257 .17443 .50732 .17968 .51245 .17627 Mtetra
.675 .613 .778 r
.50293 .16543 .4978 .1695 .50257 .17443 .50769 .17058 Mtetra
.688 .629 .784 r
.49816 .16054 .49303 .16473 .4978 .1695 .50293 .16543 Mtetra
.695 .638 .788 r
.49338 .15578 .48826 .16003 .49303 .16473 .49816 .16054 Mtetra
.698 .642 .789 r
.4886 .15107 .48347 .15536 .48826 .16003 .49338 .15578 Mtetra
.7 .644 .79 r
.4838 .1464 .47868 .1507 .48347 .15536 .4886 .15107 Mtetra
.701 .645 .79 r
.479 .14173 .47388 .14605 .47868 .1507 .4838 .1464 Mtetra
.701 .645 .791 r
.47419 .13706 .46907 .14139 .47388 .14605 .479 .14173 Mtetra
.46938 .13239 .46425 .13673 .46907 .14139 .47419 .13706 Mtetra
.701 .646 .791 r
.46455 .12771 .45942 .13206 .46425 .13673 .46938 .13239 Mtetra
.45972 .12303 .45459 .12738 .45942 .13206 .46455 .12771 Mtetra
.45487 .11833 .44975 .1227 .45459 .12738 .45972 .12303 Mtetra
.45002 .11363 .44489 .118 .44975 .1227 .45487 .11833 Mtetra
.44516 .10893 .44003 .1133 .44489 .118 .45002 .11363 Mtetra
.4403 .10421 .43517 .1086 .44003 .1133 .44516 .10893 Mtetra
.43542 .09949 .43029 .10388 .43517 .1086 .4403 .10421 Mtetra
.43054 .09475 .42541 .09916 .43029 .10388 .43542 .09949 Mtetra
.42564 .09001 .42051 .09442 .42541 .09916 .43054 .09475 Mtetra
.42074 .08527 .41561 .08968 .42051 .09442 .42564 .09001 Mtetra
.86909 .511 .86403 .51476 .8682 .5188 .87326 .51504 Mtetra
.86492 .50695 .85985 .51071 .86403 .51476 .86909 .511 Mtetra
.86074 .50289 .85567 .50666 .85985 .51071 .86492 .50695 Mtetra
.85655 .49883 .85148 .50261 .85567 .50666 .86074 .50289 Mtetra
.85236 .49476 .84729 .49854 .85148 .50261 .85655 .49883 Mtetra
.84816 .49068 .84309 .49447 .84729 .49854 .85236 .49476 Mtetra
.84395 .4866 .83888 .49039 .84309 .49447 .84816 .49068 Mtetra
.83974 .48251 .83467 .48631 .83888 .49039 .84395 .4866 Mtetra
.83552 .47841 .83044 .48222 .83467 .48631 .83974 .48251 Mtetra
.83129 .47431 .82622 .47812 .83044 .48222 .83552 .47841 Mtetra
.82706 .4702 .82198 .47402 .82622 .47812 .83129 .47431 Mtetra
.82282 .46608 .81774 .46991 .82198 .47402 .82706 .4702 Mtetra
.81857 .46196 .81349 .46579 .81774 .46991 .82282 .46608 Mtetra
.81431 .45783 .80924 .46167 .81349 .46579 .81857 .46196 Mtetra
.81005 .4537 .80497 .45754 .80924 .46167 .81431 .45783 Mtetra
.80578 .44955 .8007 .45341 .80497 .45754 .81005 .4537 Mtetra
.80151 .4454 .79643 .44926 .8007 .45341 .80578 .44955 Mtetra
.79723 .44125 .79215 .44511 .79643 .44926 .80151 .4454 Mtetra
.79294 .43709 .78786 .44096 .79215 .44511 .79723 .44125 Mtetra
.78864 .43292 .78356 .43679 .78786 .44096 .79294 .43709 Mtetra
.78434 .42874 .77926 .43263 .78356 .43679 .78864 .43292 Mtetra
.78003 .42456 .77495 .42845 .77926 .43263 .78434 .42874 Mtetra
.77571 .42037 .77063 .42427 .77495 .42845 .78003 .42456 Mtetra
.77139 .41617 .7663 .42008 .77063 .42427 .77571 .42037 Mtetra
.76706 .41197 .76197 .41588 .7663 .42008 .77139 .41617 Mtetra
.76272 .40776 .75763 .41168 .76197 .41588 .76706 .41197 Mtetra
.75838 .40354 .75329 .40747 .75763 .41168 .76272 .40776 Mtetra
.75403 .39932 .74894 .40325 .75329 .40747 .75838 .40354 Mtetra
.74967 .39509 .74458 .39902 .74894 .40325 .75403 .39932 Mtetra
.7453 .39085 .74021 .39479 .74458 .39902 .74967 .39509 Mtetra
.74093 .38661 .73584 .39056 .74021 .39479 .7453 .39085 Mtetra
.73655 .38236 .73145 .38631 .73584 .39056 .74093 .38661 Mtetra
.702 .646 .791 r
.73216 .3781 .72707 .38206 .73145 .38631 .73655 .38236 Mtetra
.72777 .37384 .72267 .37781 .72707 .38206 .73216 .3781 Mtetra
.72337 .36957 .71827 .37355 .72267 .37781 .72777 .37384 Mtetra
.71896 .3653 .71386 .36929 .71827 .37355 .72337 .36957 Mtetra
.71454 .36103 .70945 .36502 .71386 .36929 .71896 .3653 Mtetra
.702 .647 .791 r
.71012 .35675 .70502 .36076 .70945 .36502 .71454 .36103 Mtetra
.703 .648 .791 r
.7057 .35249 .7006 .3565 .70502 .36076 .71012 .35675 Mtetra
.704 .649 .792 r
.70126 .34823 .69617 .35226 .7006 .3565 .7057 .35249 Mtetra
.706 .651 .793 r
.69683 .344 .69173 .34806 .69617 .35226 .70126 .34823 Mtetra
.708 .654 .794 r
.69239 .33982 .68729 .34391 .69173 .34806 .69683 .344 Mtetra
.713 .66 .795 r
.68795 .33572 .68286 .33986 .68729 .34391 .69239 .33982 Mtetra
.72 .668 .798 r
.68352 .33176 .67843 .33598 .68286 .33986 .68795 .33572 Mtetra
.732 .683 .803 r
.6791 .32801 .67402 .33237 .67843 .33598 .68352 .33176 Mtetra
.752 .707 .809 r
.6747 .32464 .66964 .32919 .67402 .33237 .6791 .32801 Mtetra
.783 .745 .819 r
.67035 .32184 .6653 .32671 .66964 .32919 .6747 .32464 Mtetra
.829 .806 .829 r
.66606 .31995 .66105 .32527 .6653 .32671 .67035 .32184 Mtetra
.888 .891 .826 r
.66187 .31941 .6569 .32539 .66105 .32527 .66606 .31995 Mtetra
.922 .971 .771 r
.65782 .32074 .65289 .32759 .6569 .32539 .66187 .31941 Mtetra
.845 .954 .606 r
.65392 .32442 .64903 .33221 .65289 .32759 .65782 .32074 Mtetra
.665 .827 .4 r
.65016 .33039 .64528 .33884 .64903 .33221 .65392 .32442 Mtetra
0 0 0 r
.64643 .33745 .64149 .34568 .64528 .33884 .65016 .33039 Mtetra
.64251 .34276 .63742 .34942 .64149 .34568 .64643 .33745 Mtetra
.764 .97 .925 r
.63816 .34277 .63286 .34678 .63742 .34942 .64251 .34276 Mtetra
.505 .476 .759 r
.63326 .33549 .6278 .33695 .63286 .34678 .63816 .34277 Mtetra
.409 .308 .628 r
.62796 .32223 .62244 .32228 .6278 .33695 .63326 .33549 Mtetra
.403 .277 .593 r
.62253 .30641 .61705 .30637 .62244 .32228 .62796 .32223 Mtetra
.427 .294 .596 r
.61718 .29118 .61178 .29186 .61705 .30637 .62253 .30641 Mtetra
.467 .337 .619 r
.61201 .27813 .6067 .27974 .61178 .29186 .61718 .29118 Mtetra
.516 .395 .653 r
.60702 .26751 .60177 .26997 .6067 .27974 .61201 .27813 Mtetra
.568 .459 .689 r
.60216 .25895 .59697 .26209 .60177 .26997 .60702 .26751 Mtetra
.619 .52 .72 r
.5974 .25195 .59224 .25566 .59697 .26209 .60216 .25895 Mtetra
.668 .577 .744 r
.5927 .24615 .58757 .2504 .59224 .25566 .5974 .25195 Mtetra
.723 .632 .756 r
.58805 .24137 .58296 .24633 .58757 .2504 .5927 .24615 Mtetra
.794 .694 .754 r
.58345 .23776 .5784 .24387 .58296 .24633 .58805 .24137 Mtetra
.888 .766 .722 r
.57891 .2359 .57393 .24407 .5784 .24387 .58345 .23776 Mtetra
.976 .827 .631 r
.57448 .23704 .56961 .24885 .57393 .24407 .57891 .2359 Mtetra
.994 .834 .476 r
.57021 .24339 .5655 .26108 .56961 .24885 .57448 .23704 Mtetra
.911 .78 .296 r
.56617 .25788 .56161 .28296 .5655 .26108 .57021 .24339 Mtetra
.701 .662 .112 r
.56234 .28195 .55775 .31089 .56161 .28296 .56617 .25788 Mtetra
0 0 .075 r
.55846 .30938 .55347 .32949 .55775 .31089 .56234 .28195 Mtetra
.362 0 .162 r
.554 .32233 .54837 .32108 .55347 .32949 .55846 .30938 Mtetra
.673 .365 0 r
.5487 .30662 .54275 .2889 .54837 .32108 .554 .32233 Mtetra
0 0 .374 r
.54301 .27154 .53718 .25233 .54275 .2889 .5487 .30662 Mtetra
.056 0 .425 r
.53747 .23639 .53191 .22373 .53718 .25233 .54301 .27154 Mtetra
.188 .074 .482 r
.53224 .21034 .52689 .20449 .53191 .22373 .53747 .23639 Mtetra
.314 .198 .557 r
.52726 .19307 .52202 .19183 .52689 .20449 .53224 .21034 Mtetra
.441 .336 .639 r
.5224 .1816 .51722 .18302 .52202 .19183 .52726 .19307 Mtetra
.547 .458 .706 r
.5176 .17344 .51245 .17627 .51722 .18302 .5224 .1816 Mtetra
.618 .542 .747 r
.51283 .16702 .50769 .17058 .51245 .17627 .5176 .17344 Mtetra
.658 .592 .769 r
.50806 .1615 .50293 .16543 .50769 .17058 .51283 .16702 Mtetra
.68 .618 .78 r
.50329 .15642 .49816 .16054 .50293 .16543 .50806 .1615 Mtetra
.691 .632 .786 r
.49851 .15156 .49338 .15578 .49816 .16054 .50329 .15642 Mtetra
.696 .639 .788 r
.49373 .1468 .4886 .15107 .49338 .15578 .49851 .15156 Mtetra
.699 .642 .789 r
.48894 .14209 .4838 .1464 .4886 .15107 .49373 .1468 Mtetra
.7 .644 .79 r
.48413 .13741 .479 .14173 .4838 .1464 .48894 .14209 Mtetra
.701 .645 .79 r
.47933 .13273 .47419 .13706 .479 .14173 .48413 .13741 Mtetra
.701 .645 .791 r
.47451 .12804 .46938 .13239 .47419 .13706 .47933 .13273 Mtetra
.46968 .12336 .46455 .12771 .46938 .13239 .47451 .12804 Mtetra
.701 .646 .791 r
.46485 .11866 .45972 .12303 .46455 .12771 .46968 .12336 Mtetra
.46001 .11396 .45487 .11833 .45972 .12303 .46485 .11866 Mtetra
.45516 .10926 .45002 .11363 .45487 .11833 .46001 .11396 Mtetra
.4503 .10454 .44516 .10893 .45002 .11363 .45516 .10926 Mtetra
.44543 .09982 .4403 .10421 .44516 .10893 .4503 .10454 Mtetra
.44056 .09509 .43542 .09949 .4403 .10421 .44543 .09982 Mtetra
.43568 .09035 .43054 .09475 .43542 .09949 .44056 .09509 Mtetra
.43078 .0856 .42564 .09001 .43054 .09475 .43568 .09035 Mtetra
.42588 .08084 .42074 .08527 .42564 .09001 .43078 .0856 Mtetra
.87417 .50723 .86909 .511 .87326 .51504 .87833 .51128 Mtetra
.87 .50318 .86492 .50695 .86909 .511 .87417 .50723 Mtetra
.86582 .49911 .86074 .50289 .86492 .50695 .87 .50318 Mtetra
.86163 .49504 .85655 .49883 .86074 .50289 .86582 .49911 Mtetra
.85744 .49097 .85236 .49476 .85655 .49883 .86163 .49504 Mtetra
.85324 .48688 .84816 .49068 .85236 .49476 .85744 .49097 Mtetra
.84903 .48279 .84395 .4866 .84816 .49068 .85324 .48688 Mtetra
.84482 .4787 .83974 .48251 .84395 .4866 .84903 .48279 Mtetra
.8406 .4746 .83552 .47841 .83974 .48251 .84482 .4787 Mtetra
.83637 .47049 .83129 .47431 .83552 .47841 .8406 .4746 Mtetra
.83214 .46637 .82706 .4702 .83129 .47431 .83637 .47049 Mtetra
.8279 .46225 .82282 .46608 .82706 .4702 .83214 .46637 Mtetra
.82365 .45812 .81857 .46196 .82282 .46608 .8279 .46225 Mtetra
.8194 .45399 .81431 .45783 .81857 .46196 .82365 .45812 Mtetra
.81514 .44984 .81005 .4537 .81431 .45783 .8194 .45399 Mtetra
.81087 .4457 .80578 .44955 .81005 .4537 .81514 .44984 Mtetra
.8066 .44154 .80151 .4454 .80578 .44955 .81087 .4457 Mtetra
.80232 .43738 .79723 .44125 .80151 .4454 .8066 .44154 Mtetra
.79803 .43321 .79294 .43709 .79723 .44125 .80232 .43738 Mtetra
.79374 .42903 .78864 .43292 .79294 .43709 .79803 .43321 Mtetra
.78943 .42485 .78434 .42874 .78864 .43292 .79374 .42903 Mtetra
.78512 .42066 .78003 .42456 .78434 .42874 .78943 .42485 Mtetra
.78081 .41647 .77571 .42037 .78003 .42456 .78512 .42066 Mtetra
.77649 .41226 .77139 .41617 .77571 .42037 .78081 .41647 Mtetra
.77216 .40806 .76706 .41197 .77139 .41617 .77649 .41226 Mtetra
.76782 .40384 .76272 .40776 .76706 .41197 .77216 .40806 Mtetra
.76348 .39962 .75838 .40354 .76272 .40776 .76782 .40384 Mtetra
.75913 .39539 .75403 .39932 .75838 .40354 .76348 .39962 Mtetra
.75477 .39115 .74967 .39509 .75403 .39932 .75913 .39539 Mtetra
.7504 .38691 .7453 .39085 .74967 .39509 .75477 .39115 Mtetra
.74603 .38266 .74093 .38661 .7453 .39085 .7504 .38691 Mtetra
.74165 .3784 .73655 .38236 .74093 .38661 .74603 .38266 Mtetra
.702 .646 .791 r
.73726 .37414 .73216 .3781 .73655 .38236 .74165 .3784 Mtetra
.73287 .36987 .72777 .37384 .73216 .3781 .73726 .37414 Mtetra
.72847 .36559 .72337 .36957 .72777 .37384 .73287 .36987 Mtetra
.72406 .36131 .71896 .3653 .72337 .36957 .72847 .36559 Mtetra
.71965 .35703 .71454 .36103 .71896 .3653 .72406 .36131 Mtetra
.702 .647 .791 r
.71523 .35275 .71012 .35675 .71454 .36103 .71965 .35703 Mtetra
.703 .647 .791 r
.7108 .34847 .7057 .35249 .71012 .35675 .71523 .35275 Mtetra
.704 .648 .792 r
.70637 .3442 .70126 .34823 .7057 .35249 .7108 .34847 Mtetra
.705 .65 .792 r
.70193 .33995 .69683 .344 .70126 .34823 .70637 .3442 Mtetra
.707 .653 .793 r
.69749 .33574 .69239 .33982 .69683 .344 .70193 .33995 Mtetra
.711 .657 .795 r
.69305 .33159 .68795 .33572 .69239 .33982 .69749 .33574 Mtetra
.717 .665 .797 r
.68862 .32756 .68352 .33176 .68795 .33572 .69305 .33159 Mtetra
.727 .677 .801 r
.68419 .32371 .6791 .32801 .68352 .33176 .68862 .32756 Mtetra
.743 .696 .807 r
.67978 .32016 .6747 .32464 .6791 .32801 .68419 .32371 Mtetra
.77 .729 .815 r
.67541 .31711 .67035 .32184 .6747 .32464 .67978 .32016 Mtetra
.81 .78 .825 r
.6711 .31482 .66606 .31995 .67035 .32184 .67541 .31711 Mtetra
.866 .857 .83 r
.66687 .31369 .66187 .31941 .66606 .31995 .6711 .31482 Mtetra
.918 .946 .802 r
.66277 .31424 .65782 .32074 .66187 .31941 .66687 .31369 Mtetra
.891 .977 .68 r
.65883 .31698 .65392 .32442 .65782 .32074 .66277 .31424 Mtetra
.735 .879 .472 r
.65504 .32213 .65016 .33039 .65392 .32442 .65883 .31698 Mtetra
0 0 0 r
.65134 .32899 .64643 .33745 .65016 .33039 .65504 .32213 Mtetra
.64754 .33533 .64251 .34276 .64643 .33745 .65134 .32899 Mtetra
.702 .966 .726 r
.64338 .33768 .63816 .34277 .64251 .34276 .64754 .33533 Mtetra
.598 .632 .856 r
.63868 .33316 .63326 .33549 .63816 .34277 .64338 .33768 Mtetra
.428 .345 .66 r
.63349 .3218 .62796 .32223 .63326 .33549 .63868 .33316 Mtetra
.4 .28 .6 r
.62805 .30652 .62253 .30641 .62796 .32223 .63349 .3218 Mtetra
.416 .284 .592 r
.62263 .29081 .61718 .29118 .62253 .30641 .62805 .30652 Mtetra
.451 .318 .609 r
.61737 .27686 .61201 .27813 .61718 .29118 .62263 .29081 Mtetra
.497 .371 .64 r
.6123 .26535 .60702 .26751 .61201 .27813 .61737 .27686 Mtetra
.547 .434 .676 r
.60738 .25606 .60216 .25895 .60702 .26751 .6123 .26535 Mtetra
.597 .496 .709 r
.60258 .24849 .5974 .25195 .60216 .25895 .60738 .25606 Mtetra
.644 .552 .736 r
.59785 .24219 .5927 .24615 .5974 .25195 .60258 .24849 Mtetra
.69 .603 .754 r
.59317 .23688 .58805 .24137 .5927 .24615 .59785 .24219 Mtetra
.745 .655 .761 r
.58854 .23251 .58345 .23776 .58805 .24137 .59317 .23688 Mtetra
.82 .716 .751 r
.58395 .22934 .57891 .2359 .58345 .23776 .58854 .23251 Mtetra
.914 .787 .706 r
.57944 .22812 .57448 .23704 .57891 .2359 .58395 .22934 Mtetra
.99 .836 .596 r
.57504 .23032 .57021 .24339 .57448 .23704 .57944 .22812 Mtetra
.983 .826 .429 r
.57083 .2384 .56617 .25788 .57021 .24339 .57504 .23032 Mtetra
.872 .757 .249 r
.56687 .25527 .56234 .28195 .56617 .25788 .57083 .2384 Mtetra
0 0 0 r
.56309 .28116 .55846 .30938 .56234 .28195 .56687 .25527 Mtetra
0 0 .112 r
.55914 .30688 .554 .32233 .55846 .30938 .56309 .28116 Mtetra
.572 .112 .122 r
.55447 .31318 .5487 .30662 .554 .32233 .55914 .30688 Mtetra
0 0 .295 r
.54899 .29089 .54301 .27154 .5487 .30662 .55447 .31318 Mtetra
0 0 .388 r
.54326 .25426 .53747 .23639 .54301 .27154 .54899 .29089 Mtetra
.091 0 .437 r
.53777 .22109 .53224 .21034 .53747 .23639 .54326 .25426 Mtetra
.218 .102 .499 r
.53259 .1975 .52726 .19307 .53224 .21034 .53777 .22109 Mtetra
.346 .232 .578 r
.52763 .18199 .5224 .1816 .52726 .19307 .53259 .1975 Mtetra
.47 .369 .658 r
.52278 .17156 .5176 .17344 .5224 .1816 .52763 .18199 Mtetra
.568 .483 .718 r
.51798 .16395 .51283 .16702 .5176 .17344 .52278 .17156 Mtetra
.63 .558 .754 r
.5132 .15781 .50806 .1615 .51283 .16702 .51798 .16395 Mtetra
.665 .6 .773 r
.50843 .15241 .50329 .15642 .50806 .1615 .5132 .15781 Mtetra
.683 .623 .782 r
.50365 .14739 .49851 .15156 .50329 .15642 .50843 .15241 Mtetra
.692 .634 .786 r
.49887 .14255 .49373 .1468 .49851 .15156 .50365 .14739 Mtetra
.697 .64 .789 r
.49408 .1378 .48894 .14209 .49373 .1468 .49887 .14255 Mtetra
.699 .643 .79 r
.48928 .13308 .48413 .13741 .48894 .14209 .49408 .1378 Mtetra
.7 .644 .79 r
.48447 .12839 .47933 .13273 .48413 .13741 .48928 .13308 Mtetra
.701 .645 .791 r
.47965 .12369 .47451 .12804 .47933 .13273 .48447 .12839 Mtetra
.47483 .119 .46968 .12336 .47451 .12804 .47965 .12369 Mtetra
.46999 .11429 .46485 .11866 .46968 .12336 .47483 .119 Mtetra
.701 .646 .791 r
.46515 .10959 .46001 .11396 .46485 .11866 .46999 .11429 Mtetra
.4603 .10487 .45516 .10926 .46001 .11396 .46515 .10959 Mtetra
.45545 .10015 .4503 .10454 .45516 .10926 .4603 .10487 Mtetra
.45058 .09542 .44543 .09982 .4503 .10454 .45545 .10015 Mtetra
.4457 .09068 .44056 .09509 .44543 .09982 .45058 .09542 Mtetra
.44082 .08593 .43568 .09035 .44056 .09509 .4457 .09068 Mtetra
.43593 .08118 .43078 .0856 .43568 .09035 .44082 .08593 Mtetra
.43103 .07641 .42588 .08084 .43078 .0856 .43593 .08118 Mtetra
.87925 .50346 .87417 .50723 .87833 .51128 .88342 .50752 Mtetra
.87508 .4994 .87 .50318 .87417 .50723 .87925 .50346 Mtetra
.8709 .49533 .86582 .49911 .87 .50318 .87508 .4994 Mtetra
.86672 .49125 .86163 .49504 .86582 .49911 .8709 .49533 Mtetra
.86252 .48717 .85744 .49097 .86163 .49504 .86672 .49125 Mtetra
.85832 .48308 .85324 .48688 .85744 .49097 .86252 .48717 Mtetra
.85412 .47899 .84903 .48279 .85324 .48688 .85832 .48308 Mtetra
.84991 .47488 .84482 .4787 .84903 .48279 .85412 .47899 Mtetra
.84569 .47078 .8406 .4746 .84482 .4787 .84991 .47488 Mtetra
.84146 .46666 .83637 .47049 .8406 .4746 .84569 .47078 Mtetra
.83723 .46254 .83214 .46637 .83637 .47049 .84146 .46666 Mtetra
.83299 .45841 .8279 .46225 .83214 .46637 .83723 .46254 Mtetra
.82875 .45428 .82365 .45812 .8279 .46225 .83299 .45841 Mtetra
.82449 .45013 .8194 .45399 .82365 .45812 .82875 .45428 Mtetra
.82023 .44599 .81514 .44984 .8194 .45399 .82449 .45013 Mtetra
.81597 .44183 .81087 .4457 .81514 .44984 .82023 .44599 Mtetra
.8117 .43767 .8066 .44154 .81087 .4457 .81597 .44183 Mtetra
.80742 .4335 .80232 .43738 .8066 .44154 .8117 .43767 Mtetra
.80313 .42933 .79803 .43321 .80232 .43738 .80742 .4335 Mtetra
.79883 .42515 .79374 .42903 .79803 .43321 .80313 .42933 Mtetra
.79453 .42096 .78943 .42485 .79374 .42903 .79883 .42515 Mtetra
.79023 .41676 .78512 .42066 .78943 .42485 .79453 .42096 Mtetra
.78591 .41256 .78081 .41647 .78512 .42066 .79023 .41676 Mtetra
.78159 .40835 .77649 .41226 .78081 .41647 .78591 .41256 Mtetra
.77726 .40414 .77216 .40806 .77649 .41226 .78159 .40835 Mtetra
.77292 .39991 .76782 .40384 .77216 .40806 .77726 .40414 Mtetra
.76858 .39568 .76348 .39962 .76782 .40384 .77292 .39991 Mtetra
.76423 .39145 .75913 .39539 .76348 .39962 .76858 .39568 Mtetra
.75987 .3872 .75477 .39115 .75913 .39539 .76423 .39145 Mtetra
.75551 .38295 .7504 .38691 .75477 .39115 .75987 .3872 Mtetra
.75114 .3787 .74603 .38266 .7504 .38691 .75551 .38295 Mtetra
.74676 .37443 .74165 .3784 .74603 .38266 .75114 .3787 Mtetra
.74238 .37016 .73726 .37414 .74165 .3784 .74676 .37443 Mtetra
.702 .646 .791 r
.73798 .36589 .73287 .36987 .73726 .37414 .74238 .37016 Mtetra
.73358 .36161 .72847 .36559 .73287 .36987 .73798 .36589 Mtetra
.72918 .35732 .72406 .36131 .72847 .36559 .73358 .36161 Mtetra
.72476 .35303 .71965 .35703 .72406 .36131 .72918 .35732 Mtetra
.72034 .34874 .71523 .35275 .71965 .35703 .72476 .35303 Mtetra
.703 .647 .791 r
.71592 .34444 .7108 .34847 .71523 .35275 .72034 .34874 Mtetra
.703 .648 .792 r
.71148 .34016 .70637 .3442 .7108 .34847 .71592 .34444 Mtetra
.704 .649 .792 r
.70705 .33589 .70193 .33995 .70637 .3442 .71148 .34016 Mtetra
.706 .652 .793 r
.70261 .33165 .69749 .33574 .70193 .33995 .70705 .33589 Mtetra
.709 .655 .794 r
.69816 .32747 .69305 .33159 .69749 .33574 .70261 .33165 Mtetra
.715 .661 .796 r
.69372 .32338 .68862 .32756 .69305 .33159 .69816 .32747 Mtetra
.723 .671 .799 r
.68929 .31944 .68419 .32371 .68862 .32756 .69372 .32338 Mtetra
.736 .688 .804 r
.68488 .31575 .67978 .32016 .68419 .32371 .68929 .31944 Mtetra
.758 .715 .812 r
.68049 .31247 .67541 .31711 .67978 .32016 .68488 .31575 Mtetra
.793 .758 .821 r
.67615 .30984 .6711 .31482 .67541 .31711 .68049 .31247 Mtetra
.843 .825 .83 r
.67189 .30821 .66687 .31369 .6711 .31482 .67615 .30984 Mtetra
.902 .914 .82 r
.66775 .30805 .66277 .31424 .66687 .31369 .67189 .30821 Mtetra
.916 .979 .74 r
.66375 .30989 .65883 .31698 .66277 .31424 .66775 .30805 Mtetra
.804 .928 .552 r
.65992 .31413 .65504 .32213 .65883 .31698 .66375 .30989 Mtetra
.621 .794 .359 r
.65622 .32048 .65134 .32899 .65504 .32213 .65992 .31413 Mtetra
0 0 0 r
.65251 .32735 .64754 .33533 .65134 .32899 .65622 .32048 Mtetra
.593 .856 .509 r
.64853 .3316 .64338 .33768 .64754 .33533 .65251 .32735 Mtetra
.719 .851 .944 r
.64405 .32983 .63868 .33316 .64338 .33768 .64853 .3316 Mtetra
.465 .409 .711 r
.63901 .32081 .63349 .3218 .63868 .33316 .64405 .32983 Mtetra
.403 .293 .613 r
.63361 .30657 .62805 .30652 .63349 .3218 .63901 .32081 Mtetra
.407 .278 .591 r
.62813 .29068 .62263 .29081 .62805 .30652 .63361 .30657 Mtetra
.436 .302 .6 r
.62278 .27593 .61737 .27686 .62263 .29081 .62813 .29068 Mtetra
.478 .35 .627 r
.61762 .2635 .6123 .26535 .61737 .27686 .62278 .27593 Mtetra
.527 .409 .662 r
.61263 .25342 .60738 .25606 .6123 .26535 .61762 .2635 Mtetra
.577 .472 .697 r
.60778 .24524 .60258 .24849 .60738 .25606 .61263 .25342 Mtetra
.623 .529 .727 r
.60302 .23847 .59785 .24219 .60258 .24849 .60778 .24524 Mtetra
.665 .579 .749 r
.59832 .23272 .59317 .23688 .59785 .24219 .60302 .23847 Mtetra
.71 .625 .761 r
.59366 .22781 .58854 .23251 .59317 .23688 .59832 .23272 Mtetra
.766 .676 .763 r
.58904 .2238 .58395 .22934 .58854 .23251 .59366 .22781 Mtetra
.845 .738 .745 r
.58447 .22108 .57944 .22812 .58395 .22934 .58904 .2238 Mtetra
.939 .805 .685 r
.57998 .22056 .57504 .23032 .57944 .22812 .58447 .22108 Mtetra
.998 .84 .557 r
.57562 .22396 .57083 .2384 .57504 .23032 .57998 .22056 Mtetra
.964 .813 .383 r
.57148 .23395 .56687 .25527 .57083 .2384 .57562 .22396 Mtetra
.824 .73 .203 r
.5676 .25322 .56309 .28116 .56687 .25527 .57148 .23395 Mtetra
0 0 0 r
.56385 .28037 .55914 .30688 .56309 .28116 .5676 .25322 Mtetra
0 0 .14 r
.55979 .30305 .55447 .31318 .55914 .30688 .56385 .28037 Mtetra
.762 .261 .024 r
.55489 .30205 .54899 .29089 .55447 .31318 .55979 .30305 Mtetra
0 0 .335 r
.54926 .27425 .54326 .25426 .54899 .29089 .55489 .30205 Mtetra
0 0 .4 r
.54352 .23728 .53777 .22109 .54326 .25426 .54926 .27425 Mtetra
.124 .018 .451 r
.53808 .20643 .53259 .1975 .53777 .22109 .54352 .23728 Mtetra
.249 .132 .517 r
.53294 .18518 .52763 .18199 .53259 .1975 .53808 .20643 Mtetra
.378 .266 .599 r
.528 .17122 .52278 .17156 .52763 .18199 .53294 .18518 Mtetra
.498 .401 .676 r
.52316 .16167 .51798 .16395 .52278 .17156 .528 .17122 Mtetra
.587 .505 .73 r
.51837 .15452 .5132 .15781 .51798 .16395 .52316 .16167 Mtetra
.641 .571 .76 r
.51358 .1486 .50843 .15241 .5132 .15781 .51837 .15452 Mtetra
.671 .607 .776 r
.5088 .14332 .50365 .14739 .50843 .15241 .51358 .1486 Mtetra
.686 .626 .783 r
.50402 .13835 .49887 .14255 .50365 .14739 .5088 .14332 Mtetra
.694 .636 .787 r
.49922 .13352 .49408 .1378 .49887 .14255 .50402 .13835 Mtetra
.698 .641 .789 r
.49443 .12877 .48928 .13308 .49408 .1378 .49922 .13352 Mtetra
.699 .643 .79 r
.48962 .12405 .48447 .12839 .48928 .13308 .49443 .12877 Mtetra
.701 .645 .79 r
.4848 .11934 .47965 .12369 .48447 .12839 .48962 .12405 Mtetra
.701 .645 .791 r
.47998 .11463 .47483 .119 .47965 .12369 .4848 .11934 Mtetra
.47515 .10992 .46999 .11429 .47483 .119 .47998 .11463 Mtetra
.701 .646 .791 r
.4703 .1052 .46515 .10959 .46999 .11429 .47515 .10992 Mtetra
.46546 .10048 .4603 .10487 .46515 .10959 .4703 .1052 Mtetra
.4606 .09575 .45545 .10015 .4603 .10487 .46546 .10048 Mtetra
.45573 .09101 .45058 .09542 .45545 .10015 .4606 .09575 Mtetra
.45086 .08627 .4457 .09068 .45058 .09542 .45573 .09101 Mtetra
.44598 .08151 .44082 .08593 .4457 .09068 .45086 .08627 Mtetra
.44109 .07675 .43593 .08118 .44082 .08593 .44598 .08151 Mtetra
.43619 .07198 .43103 .07641 .43593 .08118 .44109 .07675 Mtetra
.88434 .49968 .87925 .50346 .88342 .50752 .8885 .50374 Mtetra
.88017 .49561 .87508 .4994 .87925 .50346 .88434 .49968 Mtetra
.87599 .49154 .8709 .49533 .87508 .4994 .88017 .49561 Mtetra
.87181 .48746 .86672 .49125 .8709 .49533 .87599 .49154 Mtetra
.86762 .48337 .86252 .48717 .86672 .49125 .87181 .48746 Mtetra
.86342 .47927 .85832 .48308 .86252 .48717 .86762 .48337 Mtetra
.85921 .47517 .85412 .47899 .85832 .48308 .86342 .47927 Mtetra
.855 .47106 .84991 .47488 .85412 .47899 .85921 .47517 Mtetra
.85079 .46695 .84569 .47078 .84991 .47488 .855 .47106 Mtetra
.84656 .46283 .84146 .46666 .84569 .47078 .85079 .46695 Mtetra
.84233 .4587 .83723 .46254 .84146 .46666 .84656 .46283 Mtetra
.83809 .45457 .83299 .45841 .83723 .46254 .84233 .4587 Mtetra
.83385 .45043 .82875 .45428 .83299 .45841 .83809 .45457 Mtetra
.8296 .44628 .82449 .45013 .82875 .45428 .83385 .45043 Mtetra
.82534 .44212 .82023 .44599 .82449 .45013 .8296 .44628 Mtetra
.82107 .43796 .81597 .44183 .82023 .44599 .82534 .44212 Mtetra
.8168 .43379 .8117 .43767 .81597 .44183 .82107 .43796 Mtetra
.81252 .42962 .80742 .4335 .8117 .43767 .8168 .43379 Mtetra
.80823 .42544 .80313 .42933 .80742 .4335 .81252 .42962 Mtetra
.80394 .42125 .79883 .42515 .80313 .42933 .80823 .42544 Mtetra
.79964 .41706 .79453 .42096 .79883 .42515 .80394 .42125 Mtetra
.79533 .41285 .79023 .41676 .79453 .42096 .79964 .41706 Mtetra
.79102 .40865 .78591 .41256 .79023 .41676 .79533 .41285 Mtetra
.7867 .40443 .78159 .40835 .78591 .41256 .79102 .40865 Mtetra
.78237 .40021 .77726 .40414 .78159 .40835 .7867 .40443 Mtetra
.77804 .39598 .77292 .39991 .77726 .40414 .78237 .40021 Mtetra
.77369 .39174 .76858 .39568 .77292 .39991 .77804 .39598 Mtetra
.76935 .3875 .76423 .39145 .76858 .39568 .77369 .39174 Mtetra
.76499 .38325 .75987 .3872 .76423 .39145 .76935 .3875 Mtetra
.76063 .379 .75551 .38295 .75987 .3872 .76499 .38325 Mtetra
.75626 .37473 .75114 .3787 .75551 .38295 .76063 .379 Mtetra
.75188 .37046 .74676 .37443 .75114 .3787 .75626 .37473 Mtetra
.74749 .36619 .74238 .37016 .74676 .37443 .75188 .37046 Mtetra
.702 .646 .791 r
.7431 .3619 .73798 .36589 .74238 .37016 .74749 .36619 Mtetra
.7387 .35761 .73358 .36161 .73798 .36589 .7431 .3619 Mtetra
.7343 .35332 .72918 .35732 .73358 .36161 .7387 .35761 Mtetra
.72988 .34902 .72476 .35303 .72918 .35732 .7343 .35332 Mtetra
.72546 .34472 .72034 .34874 .72476 .35303 .72988 .34902 Mtetra
.702 .647 .791 r
.72104 .34042 .71592 .34444 .72034 .34874 .72546 .34472 Mtetra
.703 .647 .791 r
.71661 .33612 .71148 .34016 .71592 .34444 .72104 .34042 Mtetra
.704 .649 .792 r
.71217 .33184 .70705 .33589 .71148 .34016 .71661 .33612 Mtetra
.705 .651 .792 r
.70773 .32757 .70261 .33165 .70705 .33589 .71217 .33184 Mtetra
.708 .654 .793 r
.70328 .32336 .69816 .32747 .70261 .33165 .70773 .32757 Mtetra
.712 .659 .795 r
.69884 .31921 .69372 .32338 .69816 .32747 .70328 .32336 Mtetra
.719 .667 .798 r
.6944 .3152 .68929 .31944 .69372 .32338 .69884 .31921 Mtetra
.731 .681 .802 r
.68998 .31139 .68488 .31575 .68929 .31944 .6944 .3152 Mtetra
.749 .703 .808 r
.68558 .30793 .68049 .31247 .68488 .31575 .68998 .31139 Mtetra
.778 .74 .818 r
.68122 .30501 .67615 .30984 .68049 .31247 .68558 .30793 Mtetra
.823 .797 .828 r
.67693 .30294 .67189 .30821 .67615 .30984 .68122 .30501 Mtetra
.881 .88 .828 r
.67275 .30214 .66775 .30805 .67189 .30821 .67693 .30294 Mtetra
.922 .964 .783 r
.6687 .30316 .66375 .30989 .66775 .30805 .67275 .30214 Mtetra
.862 .963 .631 r
.66482 .30645 .65992 .31413 .66375 .30989 .6687 .30316 Mtetra
.688 .844 .422 r
.6611 .31208 .65622 .32048 .65992 .31413 .66482 .30645 Mtetra
0 0 0 r
.65744 .31902 .65251 .32735 .65622 .32048 .6611 .31208 Mtetra
.65361 .32465 .64853 .3316 .65251 .32735 .65744 .31902 Mtetra
.761 .993 .877 r
.64934 .32543 .64405 .32983 .64853 .3316 .65361 .32465 Mtetra
.532 .52 .788 r
.64449 .31904 .63901 .32081 .64405 .32983 .64934 .32543 Mtetra
.414 .318 .637 r
.63918 .30637 .63361 .30657 .63901 .32081 .64449 .31904 Mtetra
.401 .277 .594 r
.63368 .29071 .62813 .29068 .63361 .30657 .63918 .30637 Mtetra
.423 .29 .594 r
.62824 .27532 .62278 .27593 .62813 .29068 .63368 .29071 Mtetra
.461 .33 .615 r
.62299 .26198 .61762 .2635 .62278 .27593 .62824 .27532 Mtetra
.508 .386 .648 r
.61792 .25105 .61263 .25342 .61762 .2635 .62299 .26198 Mtetra
.558 .448 .684 r
.61301 .24221 .60778 .24524 .61263 .25342 .61792 .25105 Mtetra
.605 .507 .717 r
.60821 .23494 .60302 .23847 .60778 .24524 .61301 .24221 Mtetra
.646 .558 .742 r
.60348 .22878 .59832 .23272 .60302 .23847 .60821 .23494 Mtetra
.684 .602 .758 r
.5988 .22346 .59366 .22781 .59832 .23272 .60348 .22878 Mtetra
.728 .645 .766 r
.59415 .21888 .58904 .2238 .59366 .22781 .5988 .22346 Mtetra
.787 .695 .763 r
.58954 .21521 .58447 .22108 .58904 .2238 .59415 .21888 Mtetra
.87 .758 .736 r
.58499 .21296 .57998 .22056 .58447 .22108 .58954 .21521 Mtetra
.961 .82 .659 r
.58053 .21323 .57562 .22396 .57998 .22056 .58499 .21296 Mtetra
.999 .839 .514 r
.57623 .21797 .57148 .23395 .57562 .22396 .58053 .21323 Mtetra
.939 .797 .336 r
.57216 .23004 .5676 .25322 .57148 .23395 .57623 .21797 Mtetra
.767 .698 .156 r
.56836 .25166 .56385 .28037 .5676 .25322 .57216 .23004 Mtetra
0 0 .028 r
.56461 .27928 .55979 .30305 .56385 .28037 .56836 .25166 Mtetra
.164 0 .154 r
.56039 .29759 .55489 .30205 .55979 .30305 .56461 .27928 Mtetra
.799 .357 0 r
.55526 .28909 .54926 .27425 .55489 .30205 .56039 .29759 Mtetra
0 0 .358 r
.54951 .25707 .54352 .23728 .54926 .27425 .55526 .28909 Mtetra
.015 0 .412 r
.54379 .22077 .53808 .20643 .54352 .23728 .54951 .25707 Mtetra
.155 .044 .465 r
.5384 .1924 .53294 .18518 .53808 .20643 .54379 .22077 Mtetra
.28 .163 .536 r
.53331 .1733 .528 .17122 .53294 .18518 .5384 .1924 Mtetra
.409 .301 .619 r
.52839 .1607 .52316 .16167 .528 .17122 .53331 .1733 Mtetra
.523 .431 .692 r
.52355 .1519 .51837 .15452 .52316 .16167 .52839 .1607 Mtetra
.603 .525 .739 r
.51875 .14514 .51358 .1486 .51837 .15452 .52355 .1519 Mtetra
.65 .582 .765 r
.51396 .13942 .5088 .14332 .51358 .1486 .51875 .14514 Mtetra
.676 .613 .778 r
.50917 .13422 .50402 .13835 .5088 .14332 .51396 .13942 Mtetra
.689 .629 .784 r
.50438 .12928 .49922 .13352 .50402 .13835 .50917 .13422 Mtetra
.695 .638 .788 r
.49958 .12447 .49443 .12877 .49922 .13352 .50438 .12928 Mtetra
.698 .642 .789 r
.49478 .11971 .48962 .12405 .49443 .12877 .49958 .12447 Mtetra
.7 .644 .79 r
.48996 .11498 .4848 .11934 .48962 .12405 .49478 .11971 Mtetra
.701 .645 .79 r
.48514 .11026 .47998 .11463 .4848 .11934 .48996 .11498 Mtetra
.701 .645 .791 r
.48031 .10554 .47515 .10992 .47998 .11463 .48514 .11026 Mtetra
.47547 .10081 .4703 .1052 .47515 .10992 .48031 .10554 Mtetra
.701 .646 .791 r
.47062 .09608 .46546 .10048 .4703 .1052 .47547 .10081 Mtetra
.46576 .09134 .4606 .09575 .46546 .10048 .47062 .09608 Mtetra
.46089 .0866 .45573 .09101 .4606 .09575 .46576 .09134 Mtetra
.45602 .08184 .45086 .08627 .45573 .09101 .46089 .0866 Mtetra
.45114 .07708 .44598 .08151 .45086 .08627 .45602 .08184 Mtetra
.44625 .07231 .44109 .07675 .44598 .08151 .45114 .07708 Mtetra
.44135 .06753 .43619 .07198 .44109 .07675 .44625 .07231 Mtetra
.88944 .4959 .88434 .49968 .8885 .50374 .8936 .49997 Mtetra
.88527 .49182 .88017 .49561 .88434 .49968 .88944 .4959 Mtetra
.88109 .48774 .87599 .49154 .88017 .49561 .88527 .49182 Mtetra
.87691 .48365 .87181 .48746 .87599 .49154 .88109 .48774 Mtetra
.87272 .47956 .86762 .48337 .87181 .48746 .87691 .48365 Mtetra
.86852 .47546 .86342 .47927 .86762 .48337 .87272 .47956 Mtetra
.86432 .47135 .85921 .47517 .86342 .47927 .86852 .47546 Mtetra
.86011 .46724 .855 .47106 .85921 .47517 .86432 .47135 Mtetra
.85589 .46312 .85079 .46695 .855 .47106 .86011 .46724 Mtetra
.85167 .45899 .84656 .46283 .85079 .46695 .85589 .46312 Mtetra
.84744 .45486 .84233 .4587 .84656 .46283 .85167 .45899 Mtetra
.8432 .45072 .83809 .45457 .84233 .4587 .84744 .45486 Mtetra
.83896 .44657 .83385 .45043 .83809 .45457 .8432 .45072 Mtetra
.8347 .44241 .8296 .44628 .83385 .45043 .83896 .44657 Mtetra
.83045 .43825 .82534 .44212 .8296 .44628 .8347 .44241 Mtetra
.82618 .43409 .82107 .43796 .82534 .44212 .83045 .43825 Mtetra
.82191 .42991 .8168 .43379 .82107 .43796 .82618 .43409 Mtetra
.81763 .42573 .81252 .42962 .8168 .43379 .82191 .42991 Mtetra
.81335 .42154 .80823 .42544 .81252 .42962 .81763 .42573 Mtetra
.80906 .41735 .80394 .42125 .80823 .42544 .81335 .42154 Mtetra
.80476 .41315 .79964 .41706 .80394 .42125 .80906 .41735 Mtetra
.80045 .40894 .79533 .41285 .79964 .41706 .80476 .41315 Mtetra
.79614 .40473 .79102 .40865 .79533 .41285 .80045 .40894 Mtetra
.79182 .4005 .7867 .40443 .79102 .40865 .79614 .40473 Mtetra
.78749 .39628 .78237 .40021 .7867 .40443 .79182 .4005 Mtetra
.78316 .39204 .77804 .39598 .78237 .40021 .78749 .39628 Mtetra
.77882 .3878 .77369 .39174 .77804 .39598 .78316 .39204 Mtetra
.77447 .38355 .76935 .3875 .77369 .39174 .77882 .3878 Mtetra
.77011 .37929 .76499 .38325 .76935 .3875 .77447 .38355 Mtetra
.76575 .37503 .76063 .379 .76499 .38325 .77011 .37929 Mtetra
.76138 .37076 .75626 .37473 .76063 .379 .76575 .37503 Mtetra
.757 .36649 .75188 .37046 .75626 .37473 .76138 .37076 Mtetra
.75262 .3622 .74749 .36619 .75188 .37046 .757 .36649 Mtetra
.702 .646 .791 r
.74823 .35791 .7431 .3619 .74749 .36619 .75262 .3622 Mtetra
.74383 .35362 .7387 .35761 .7431 .3619 .74823 .35791 Mtetra
.73943 .34931 .7343 .35332 .7387 .35761 .74383 .35362 Mtetra
.73501 .34501 .72988 .34902 .7343 .35332 .73943 .34931 Mtetra
.73059 .3407 .72546 .34472 .72988 .34902 .73501 .34501 Mtetra
.702 .647 .791 r
.72617 .33639 .72104 .34042 .72546 .34472 .73059 .3407 Mtetra
.703 .647 .791 r
.72174 .33208 .71661 .33612 .72104 .34042 .72617 .33639 Mtetra
.703 .648 .792 r
.7173 .32778 .71217 .33184 .71661 .33612 .72174 .33208 Mtetra
.705 .65 .792 r
.71286 .3235 .70773 .32757 .71217 .33184 .7173 .32778 Mtetra
.707 .652 .793 r
.70841 .31925 .70328 .32336 .70773 .32757 .71286 .3235 Mtetra
.71 .656 .794 r
.70397 .31506 .69884 .31921 .70328 .32336 .70841 .31925 Mtetra
.716 .663 .797 r
.69953 .31098 .6944 .3152 .69884 .31921 .70397 .31506 Mtetra
.726 .675 .8 r
.6951 .30708 .68998 .31139 .6944 .3152 .69953 .31098 Mtetra
.741 .693 .806 r
.69069 .30345 .68558 .30793 .68998 .31139 .6951 .30708 Mtetra
.766 .724 .814 r
.68631 .30029 .68122 .30501 .68558 .30793 .69069 .30345 Mtetra
.804 .773 .824 r
.68199 .29784 .67693 .30294 .68122 .30501 .68631 .30029 Mtetra
.858 .846 .831 r
.67777 .2965 .67275 .30214 .67693 .30294 .68199 .29784 Mtetra
.913 .936 .809 r
.67367 .29675 .6687 .30316 .67275 .30214 .67777 .2965 Mtetra
.901 .98 .701 r
.66974 .29912 .66482 .30645 .6687 .30316 .67367 .29675 Mtetra
.758 .896 .497 r
.66598 .30389 .6611 .31208 .66482 .30645 .66974 .29912 Mtetra
0 0 0 r
.66234 .31052 .65744 .31902 .6611 .31208 .66598 .30389 Mtetra
.65862 .31702 .65361 .32465 .65744 .31902 .66234 .31052 Mtetra
.666 .933 .649 r
.65456 .31998 .64934 .32543 .65361 .32465 .65862 .31702 Mtetra
.638 .7 .891 r
.64993 .31635 .64449 .31904 .64934 .32543 .65456 .31998 Mtetra
.439 .363 .674 r
.64475 .30574 .63918 .30637 .64449 .31904 .64993 .31635 Mtetra
.401 .283 .603 r
.63926 .29078 .63368 .29071 .63918 .30637 .64475 .30574 Mtetra
.412 .281 .591 r
.63375 .275 .62824 .27532 .63368 .29071 .63926 .29078 Mtetra
.445 .312 .606 r
.6284 .26079 .62299 .26198 .62824 .27532 .63375 .275 Mtetra
.489 .363 .635 r
.62325 .24898 .61792 .25105 .62299 .26198 .6284 .26079 Mtetra
.539 .424 .671 r
.61828 .23941 .61301 .24221 .61792 .25105 .62325 .24898 Mtetra
.587 .485 .705 r
.61343 .23159 .60821 .23494 .61301 .24221 .61828 .23941 Mtetra
.629 .538 .733 r
.60867 .22502 .60348 .22878 .60821 .23494 .61343 .23159 Mtetra
.665 .583 .753 r
.60397 .21934 .5988 .22346 .60348 .22878 .60867 .22502 Mtetra
.701 .622 .765 r
.5993 .21436 .59415 .21888 .5988 .22346 .60397 .21934 Mtetra
.745 .662 .769 r
.59466 .21007 .58954 .21521 .59415 .21888 .5993 .21436 Mtetra
.808 .713 .76 r
.59006 .20674 .58499 .21296 .58954 .21521 .59466 .21007 Mtetra
.895 .777 .723 r
.58552 .205 .58053 .21323 .58499 .21296 .59006 .20674 Mtetra
.979 .831 .628 r
.5811 .20616 .57623 .21797 .58053 .21323 .58552 .205 Mtetra
.993 .834 .469 r
.57685 .21241 .57216 .23004 .57623 .21797 .5811 .20616 Mtetra
.907 .777 .29 r
.57287 .22671 .56836 .25166 .57216 .23004 .57685 .21241 Mtetra
0 0 0 r
.56914 .25048 .56461 .27928 .56836 .25166 .57287 .22671 Mtetra
0 0 .069 r
.56536 .27756 .56039 .29759 .56461 .27928 .56914 .25048 Mtetra
.352 0 .147 r
.56094 .29026 .55526 .28909 .56039 .29759 .56536 .27756 Mtetra
0 0 .239 r
.55558 .27455 .54951 .25707 .55526 .28909 .56094 .29026 Mtetra
0 0 .375 r
.54974 .2397 .54379 .22077 .54951 .25707 .55558 .27455 Mtetra
.053 0 .423 r
.54406 .20482 .5384 .1924 .54379 .22077 .54974 .2397 Mtetra
.185 .071 .48 r
.53873 .17897 .53331 .1733 .5384 .1924 .54406 .20482 Mtetra
.312 .196 .556 r
.53368 .16182 .52839 .1607 .53331 .1733 .53873 .17897 Mtetra
.44 .335 .639 r
.52877 .1504 .52355 .1519 .52839 .1607 .53368 .16182 Mtetra
.547 .458 .706 r
.52394 .14224 .51875 .14514 .52355 .1519 .52877 .1504 Mtetra
.618 .543 .747 r
.51914 .1358 .51396 .13942 .51875 .14514 .52394 .14224 Mtetra
.658 .592 .769 r
.51434 .13023 .50917 .13422 .51396 .13942 .51914 .1358 Mtetra
.68 .618 .78 r
.50955 .12511 .50438 .12928 .50917 .13422 .51434 .13023 Mtetra
.691 .632 .786 r
.50475 .1202 .49958 .12447 .50438 .12928 .50955 .12511 Mtetra
.696 .639 .788 r
.49994 .11539 .49478 .11971 .49958 .12447 .50475 .1202 Mtetra
.699 .642 .789 r
.49513 .11063 .48996 .11498 .49478 .11971 .49994 .11539 Mtetra
.7 .644 .79 r
.4903 .10589 .48514 .11026 .48996 .11498 .49513 .11063 Mtetra
.701 .645 .79 r
.48547 .10116 .48031 .10554 .48514 .11026 .4903 .10589 Mtetra
.701 .645 .791 r
.48063 .09642 .47547 .10081 .48031 .10554 .48547 .10116 Mtetra
.47579 .09168 .47062 .09608 .47547 .10081 .48063 .09642 Mtetra
.701 .646 .791 r
.47093 .08693 .46576 .09134 .47062 .09608 .47579 .09168 Mtetra
.46607 .08218 .46089 .0866 .46576 .09134 .47093 .08693 Mtetra
.46119 .07742 .45602 .08184 .46089 .0866 .46607 .08218 Mtetra
.45631 .07265 .45114 .07708 .45602 .08184 .46119 .07742 Mtetra
.45142 .06787 .44625 .07231 .45114 .07708 .45631 .07265 Mtetra
.44652 .06308 .44135 .06753 .44625 .07231 .45142 .06787 Mtetra
.89454 .49211 .88944 .4959 .8936 .49997 .8987 .49618 Mtetra
.89037 .48803 .88527 .49182 .88944 .4959 .89454 .49211 Mtetra
.8862 .48394 .88109 .48774 .88527 .49182 .89037 .48803 Mtetra
.88201 .47985 .87691 .48365 .88109 .48774 .8862 .48394 Mtetra
.87783 .47575 .87272 .47956 .87691 .48365 .88201 .47985 Mtetra
.87363 .47164 .86852 .47546 .87272 .47956 .87783 .47575 Mtetra
.86943 .46753 .86432 .47135 .86852 .47546 .87363 .47164 Mtetra
.86522 .46341 .86011 .46724 .86432 .47135 .86943 .46753 Mtetra
.861 .45928 .85589 .46312 .86011 .46724 .86522 .46341 Mtetra
.85678 .45515 .85167 .45899 .85589 .46312 .861 .45928 Mtetra
.85255 .45101 .84744 .45486 .85167 .45899 .85678 .45515 Mtetra
.84831 .44686 .8432 .45072 .84744 .45486 .85255 .45101 Mtetra
.84407 .44271 .83896 .44657 .8432 .45072 .84831 .44686 Mtetra
.83982 .43855 .8347 .44241 .83896 .44657 .84407 .44271 Mtetra
.83557 .43438 .83045 .43825 .8347 .44241 .83982 .43855 Mtetra
.8313 .43021 .82618 .43409 .83045 .43825 .83557 .43438 Mtetra
.82703 .42603 .82191 .42991 .82618 .43409 .8313 .43021 Mtetra
.82275 .42184 .81763 .42573 .82191 .42991 .82703 .42603 Mtetra
.81847 .41764 .81335 .42154 .81763 .42573 .82275 .42184 Mtetra
.81418 .41344 .80906 .41735 .81335 .42154 .81847 .41764 Mtetra
.80988 .40924 .80476 .41315 .80906 .41735 .81418 .41344 Mtetra
.80557 .40502 .80045 .40894 .80476 .41315 .80988 .40924 Mtetra
.80126 .4008 .79614 .40473 .80045 .40894 .80557 .40502 Mtetra
.79694 .39657 .79182 .4005 .79614 .40473 .80126 .4008 Mtetra
.79262 .39234 .78749 .39628 .79182 .4005 .79694 .39657 Mtetra
.78828 .3881 .78316 .39204 .78749 .39628 .79262 .39234 Mtetra
.78394 .38385 .77882 .3878 .78316 .39204 .78828 .3881 Mtetra
.7796 .37959 .77447 .38355 .77882 .3878 .78394 .38385 Mtetra
.77524 .37533 .77011 .37929 .77447 .38355 .7796 .37959 Mtetra
.77088 .37106 .76575 .37503 .77011 .37929 .77524 .37533 Mtetra
.76651 .36678 .76138 .37076 .76575 .37503 .77088 .37106 Mtetra
.76214 .3625 .757 .36649 .76138 .37076 .76651 .36678 Mtetra
.75775 .35821 .75262 .3622 .757 .36649 .76214 .3625 Mtetra
.75336 .35392 .74823 .35791 .75262 .3622 .75775 .35821 Mtetra
.702 .646 .791 r
.74897 .34961 .74383 .35362 .74823 .35791 .75336 .35392 Mtetra
.74456 .3453 .73943 .34931 .74383 .35362 .74897 .34961 Mtetra
.74015 .34099 .73501 .34501 .73943 .34931 .74456 .3453 Mtetra
.73573 .33667 .73059 .3407 .73501 .34501 .74015 .34099 Mtetra
.73131 .33235 .72617 .33639 .73059 .3407 .73573 .33667 Mtetra
.702 .647 .791 r
.72688 .32803 .72174 .33208 .72617 .33639 .73131 .33235 Mtetra
.703 .648 .791 r
.72244 .32372 .7173 .32778 .72174 .33208 .72688 .32803 Mtetra
.704 .649 .792 r
.718 .31942 .71286 .3235 .7173 .32778 .72244 .32372 Mtetra
.706 .651 .793 r
.71355 .31515 .70841 .31925 .71286 .3235 .718 .31942 Mtetra
.709 .655 .794 r
.7091 .31092 .70397 .31506 .70841 .31925 .71355 .31515 Mtetra
.714 .66 .796 r
.70466 .30679 .69953 .31098 .70397 .31506 .7091 .31092 Mtetra
.722 .67 .799 r
.70022 .30279 .6951 .30708 .69953 .31098 .70466 .30679 Mtetra
.734 .685 .803 r
.6958 .29904 .69069 .30345 .6951 .30708 .70022 .30279 Mtetra
.755 .711 .81 r
.69141 .29566 .68631 .30029 .69069 .30345 .6958 .29904 Mtetra
.788 .752 .82 r
.68707 .2929 .68199 .29784 .68631 .30029 .69141 .29566 Mtetra
.836 .816 .83 r
.68281 .29107 .67777 .2965 .68199 .29784 .68707 .2929 Mtetra
.895 .903 .824 r
.67866 .29064 .67367 .29675 .67777 .2965 .68281 .29107 Mtetra
.92 .976 .756 r
.67468 .29214 .66974 .29912 .67367 .29675 .67866 .29064 Mtetra
.824 .941 .578 r
.67087 .29599 .66598 .30389 .66974 .29912 .67468 .29214 Mtetra
.642 .81 .378 r
.66722 .30204 .66234 .31052 .66598 .30389 .67087 .29599 Mtetra
0 0 0 r
.66358 .30889 .65862 .31702 .66234 .31052 .66722 .30204 Mtetra
.568 .825 .459 r
.6597 .31358 .65456 .31998 .65862 .31702 .66358 .30889 Mtetra
.751 .918 .947 r
.6553 .31264 .64993 .31635 .65456 .31998 .6597 .31358 Mtetra
.484 .44 .733 r
.65029 .30447 .64475 .30574 .64993 .31635 .6553 .31264 Mtetra
.406 .3 .62 r
.64486 .29072 .63926 .29078 .64475 .30574 .65029 .30447 Mtetra
.404 .277 .592 r
.63931 .27489 .63375 .275 .63926 .29078 .64486 .29072 Mtetra
.431 .298 .598 r
.63387 .25993 .6284 .26079 .63375 .275 .63931 .27489 Mtetra
.471 .342 .623 r
.62862 .24721 .62325 .24898 .6284 .26079 .63387 .25993 Mtetra
.52 .4 .657 r
.62358 .23685 .61828 .23941 .62325 .24898 .62862 .24721 Mtetra
.569 .462 .693 r
.61868 .22842 .61343 .23159 .61828 .23941 .62358 .23685 Mtetra
.612 .518 .724 r
.61388 .22141 .60867 .22502 .61343 .23159 .61868 .22842 Mtetra
.649 .565 .747 r
.60915 .21539 .60397 .21934 .60867 .22502 .61388 .22141 Mtetra
.681 .603 .762 r
.60446 .21008 .5993 .21436 .60397 .21934 .60915 .21539 Mtetra
.715 .638 .77 r
.5998 .20538 .59466 .21007 .5993 .21436 .60446 .21008 Mtetra
.761 .678 .77 r
.59517 .20135 .59006 .20674 .59466 .21007 .5998 .20538 Mtetra
.83 .731 .755 r
.59058 .19837 .58552 .205 .59006 .20674 .59517 .20135 Mtetra
.92 .794 .705 r
.58607 .19721 .5811 .20616 .58552 .205 .59058 .19837 Mtetra
.991 .839 .592 r
.58169 .19938 .57685 .21241 .5811 .20616 .58607 .19721 Mtetra
.98 .824 .423 r
.57751 .20732 .57287 .22671 .57685 .21241 .58169 .19938 Mtetra
.867 .754 .244 r
.57361 .22395 .56914 .25048 .57287 .22671 .57751 .20732 Mtetra
0 0 0 r
.56994 .2495 .56536 .27756 .56914 .25048 .57361 .22395 Mtetra
0 0 .104 r
.56609 .27487 .56094 .29026 .56536 .27756 .56994 .2495 Mtetra
.565 .097 .103 r
.56143 .28097 .55558 .27455 .56094 .29026 .56609 .27487 Mtetra
0 0 .304 r
.55586 .25876 .54974 .2397 .55558 .27455 .56143 .28097 Mtetra
0 0 .388 r
.54998 .2224 .54406 .20482 .54974 .2397 .55586 .25876 Mtetra
.088 0 .436 r
.54435 .1895 .53873 .17897 .54406 .20482 .54998 .2224 Mtetra
.215 .099 .497 r
.53908 .1661 .53368 .16182 .53873 .17897 .54435 .1895 Mtetra
.344 .23 .577 r
.53405 .15068 .52877 .1504 .53368 .16182 .53908 .1661 Mtetra
.469 .369 .658 r
.52916 .14027 .52394 .14224 .52877 .1504 .53405 .15068 Mtetra
.568 .483 .719 r
.52433 .13265 .51914 .1358 .52394 .14224 .52916 .14027 Mtetra
.63 .558 .754 r
.51953 .12648 .51434 .13023 .51914 .1358 .52433 .13265 Mtetra
.665 .6 .773 r
.51473 .12105 .50955 .12511 .51434 .13023 .51953 .12648 Mtetra
.683 .623 .782 r
.50992 .11598 .50475 .1202 .50955 .12511 .51473 .12105 Mtetra
.692 .634 .786 r
.50512 .11109 .49994 .11539 .50475 .1202 .50992 .11598 Mtetra
.697 .64 .789 r
.5003 .10629 .49513 .11063 .49994 .11539 .50512 .11109 Mtetra
.699 .643 .79 r
.49548 .10152 .4903 .10589 .49513 .11063 .5003 .10629 Mtetra
.7 .644 .79 r
.49065 .09677 .48547 .10116 .4903 .10589 .49548 .10152 Mtetra
.701 .645 .791 r
.48581 .09202 .48063 .09642 .48547 .10116 .49065 .09677 Mtetra
.48096 .08727 .47579 .09168 .48063 .09642 .48581 .09202 Mtetra
.47611 .08251 .47093 .08693 .47579 .09168 .48096 .08727 Mtetra
.701 .646 .791 r
.47124 .07775 .46607 .08218 .47093 .08693 .47611 .08251 Mtetra
.46637 .07298 .46119 .07742 .46607 .08218 .47124 .07775 Mtetra
.46149 .0682 .45631 .07265 .46119 .07742 .46637 .07298 Mtetra
.4566 .06342 .45142 .06787 .45631 .07265 .46149 .0682 Mtetra
.4517 .05862 .44652 .06308 .45142 .06787 .4566 .06342 Mtetra
.89965 .48832 .89454 .49211 .8987 .49618 .90381 .4924 Mtetra
.89548 .48423 .89037 .48803 .89454 .49211 .89965 .48832 Mtetra
.89131 .48013 .8862 .48394 .89037 .48803 .89548 .48423 Mtetra
.88713 .47604 .88201 .47985 .8862 .48394 .89131 .48013 Mtetra
.88294 .47193 .87783 .47575 .88201 .47985 .88713 .47604 Mtetra
.87875 .46782 .87363 .47164 .87783 .47575 .88294 .47193 Mtetra
.87455 .4637 .86943 .46753 .87363 .47164 .87875 .46782 Mtetra
.87034 .45957 .86522 .46341 .86943 .46753 .87455 .4637 Mtetra
.86612 .45544 .861 .45928 .86522 .46341 .87034 .45957 Mtetra
.8619 .4513 .85678 .45515 .861 .45928 .86612 .45544 Mtetra
.85767 .44715 .85255 .45101 .85678 .45515 .8619 .4513 Mtetra
.85344 .443 .84831 .44686 .85255 .45101 .85767 .44715 Mtetra
.8492 .43884 .84407 .44271 .84831 .44686 .85344 .443 Mtetra
.84495 .43467 .83982 .43855 .84407 .44271 .8492 .43884 Mtetra
.84069 .4305 .83557 .43438 .83982 .43855 .84495 .43467 Mtetra
.83643 .42632 .8313 .43021 .83557 .43438 .84069 .4305 Mtetra
.83216 .42213 .82703 .42603 .8313 .43021 .83643 .42632 Mtetra
.82788 .41794 .82275 .42184 .82703 .42603 .83216 .42213 Mtetra
.8236 .41374 .81847 .41764 .82275 .42184 .82788 .41794 Mtetra
.81931 .40953 .81418 .41344 .81847 .41764 .8236 .41374 Mtetra
.81501 .40532 .80988 .40924 .81418 .41344 .81931 .40953 Mtetra
.81071 .4011 .80557 .40502 .80988 .40924 .81501 .40532 Mtetra
.8064 .39687 .80126 .4008 .80557 .40502 .81071 .4011 Mtetra
.80208 .39264 .79694 .39657 .80126 .4008 .8064 .39687 Mtetra
.79775 .38839 .79262 .39234 .79694 .39657 .80208 .39264 Mtetra
.79342 .38415 .78828 .3881 .79262 .39234 .79775 .38839 Mtetra
.78908 .37989 .78394 .38385 .78828 .3881 .79342 .38415 Mtetra
.78473 .37563 .7796 .37959 .78394 .38385 .78908 .37989 Mtetra
.78038 .37136 .77524 .37533 .7796 .37959 .78473 .37563 Mtetra
.77602 .36708 .77088 .37106 .77524 .37533 .78038 .37136 Mtetra
.77165 .3628 .76651 .36678 .77088 .37106 .77602 .36708 Mtetra
.76728 .35851 .76214 .3625 .76651 .36678 .77165 .3628 Mtetra
.7629 .35422 .75775 .35821 .76214 .3625 .76728 .35851 Mtetra
.75851 .34991 .75336 .35392 .75775 .35821 .7629 .35422 Mtetra
.702 .646 .791 r
.75411 .3456 .74897 .34961 .75336 .35392 .75851 .34991 Mtetra
.74971 .34129 .74456 .3453 .74897 .34961 .75411 .3456 Mtetra
.7453 .33697 .74015 .34099 .74456 .3453 .74971 .34129 Mtetra
.74088 .33264 .73573 .33667 .74015 .34099 .7453 .33697 Mtetra
.73645 .32831 .73131 .33235 .73573 .33667 .74088 .33264 Mtetra
.702 .647 .791 r
.73202 .32398 .72688 .32803 .73131 .33235 .73645 .32831 Mtetra
.703 .647 .791 r
.72759 .31965 .72244 .32372 .72688 .32803 .73202 .32398 Mtetra
.704 .648 .792 r
.72314 .31534 .718 .31942 .72244 .32372 .72759 .31965 Mtetra
.705 .65 .792 r
.7187 .31104 .71355 .31515 .718 .31942 .72314 .31534 Mtetra
.708 .653 .793 r
.71425 .30679 .7091 .31092 .71355 .31515 .7187 .31104 Mtetra
.712 .658 .795 r
.7098 .30261 .70466 .30679 .7091 .31092 .71425 .30679 Mtetra
.718 .666 .797 r
.70536 .29854 .70022 .30279 .70466 .30679 .7098 .30261 Mtetra
.729 .679 .801 r
.70093 .29467 .6958 .29904 .70022 .30279 .70536 .29854 Mtetra
.746 .7 .808 r
.69653 .29112 .69141 .29566 .6958 .29904 .70093 .29467 Mtetra
.774 .734 .816 r
.69217 .28808 .68707 .2929 .69141 .29566 .69653 .29112 Mtetra
.816 .789 .827 r
.68787 .28584 .68281 .29107 .68707 .2929 .69217 .28808 Mtetra
.874 .869 .83 r
.68368 .28481 .67866 .29064 .68281 .29107 .68787 .28584 Mtetra
.921 .956 .793 r
.67964 .28551 .67468 .29214 .67866 .29064 .68368 .28481 Mtetra
.877 .971 .656 r
.67578 .28842 .67087 .29599 .67468 .29214 .67964 .28551 Mtetra
.71 .861 .445 r
.6721 .2937 .66722 .30204 .67087 .29599 .67578 .28842 Mtetra
0 0 0 r
.6685 .30048 .66358 .30889 .66722 .30204 .6721 .2937 Mtetra
.66476 .30638 .6597 .31358 .66358 .30889 .6685 .30048 Mtetra
.74 .991 .81 r
.66059 .30786 .6553 .31264 .6597 .31358 .66476 .30638 Mtetra
.563 .572 .82 r
.6558 .30237 .65029 .30447 .6553 .31264 .66059 .30786 Mtetra
.421 .331 .648 r
.65048 .29035 .64486 .29072 .65029 .30447 .6558 .30237 Mtetra
.401 .278 .597 r
.64491 .2749 .63931 .27489 .64486 .29072 .65048 .29035 Mtetra
.419 .286 .593 r
.63939 .25938 .63387 .25993 .63931 .27489 .64491 .2749 Mtetra
.455 .323 .612 r
.63404 .24576 .62862 .24721 .63387 .25993 .63939 .25938 Mtetra
.501 .377 .644 r
.62891 .23455 .62358 .23685 .62862 .24721 .63404 .24576 Mtetra
.55 .439 .68 r
.62395 .22546 .61868 .22842 .62358 .23685 .62891 .23455 Mtetra
.596 .498 .713 r
.61911 .21796 .61388 .22141 .61868 .22842 .62395 .22546 Mtetra
.634 .547 .739 r
.61435 .21159 .60915 .21539 .61388 .22141 .61911 .21796 Mtetra
.666 .587 .757 r
.60964 .20598 .60446 .21008 .60915 .21539 .61435 .21159 Mtetra
.695 .62 .769 r
.60497 .20096 .5998 .20538 .60446 .21008 .60964 .20598 Mtetra
.729 .653 .773 r
.60031 .19649 .59517 .20135 .5998 .20538 .60497 .20096 Mtetra
.778 .693 .769 r
.59569 .19272 .59058 .19837 .59517 .20135 .60031 .19649 Mtetra
.852 .748 .747 r
.59112 .19011 .58607 .19721 .59058 .19837 .59569 .19272 Mtetra
.943 .81 .684 r
.58663 .1896 .58169 .19938 .58607 .19721 .59112 .19011 Mtetra
.998 .842 .553 r
.58229 .19292 .57751 .20732 .58169 .19938 .58663 .1896 Mtetra
.961 .811 .377 r
.57819 .20274 .57361 .22395 .57751 .20732 .58229 .19292 Mtetra
.82 .727 .198 r
.57439 .22174 .56994 .2495 .57361 .22395 .57819 .20274 Mtetra
0 0 0 r
.57075 .24851 .56609 .27487 .56994 .2495 .57439 .22174 Mtetra
0 0 .129 r
.56677 .27085 .56143 .28097 .56609 .27487 .57075 .24851 Mtetra
.755 .248 0 r
.56186 .26973 .55586 .25876 .56143 .28097 .56677 .27085 Mtetra
0 0 .339 r
.55611 .24208 .54998 .2224 .55586 .25876 .56186 .26973 Mtetra
0 0 .399 r
.55022 .20541 .54435 .1895 .54998 .2224 .55611 .24208 Mtetra
.12 .015 .449 r
.54465 .17481 .53908 .1661 .54435 .1895 .55022 .20541 Mtetra
.246 .129 .515 r
.53943 .15372 .53405 .15068 .53908 .1661 .54465 .17481 Mtetra
.376 .265 .598 r
.53444 .13983 .52916 .14027 .53405 .15068 .53943 .15372 Mtetra
.497 .4 .676 r
.52955 .1303 .52433 .13265 .52916 .14027 .53444 .13983 Mtetra
.587 .505 .73 r
.52473 .12313 .51953 .12648 .52433 .13265 .52955 .1303 Mtetra
.641 .571 .76 r
.51992 .11718 .51473 .12105 .51953 .12648 .52473 .12313 Mtetra
.671 .607 .776 r
.51511 .11185 .50992 .11598 .51473 .12105 .51992 .11718 Mtetra
.686 .626 .783 r
.5103 .10683 .50512 .11109 .50992 .11598 .51511 .11185 Mtetra
.694 .636 .787 r
.50549 .10196 .5003 .10629 .50512 .11109 .5103 .10683 Mtetra
.698 .641 .789 r
.50066 .09715 .49548 .10152 .5003 .10629 .50549 .10196 Mtetra
.7 .643 .79 r
.49583 .09238 .49065 .09677 .49548 .10152 .50066 .09715 Mtetra
.701 .645 .79 r
.491 .08761 .48581 .09202 .49065 .09677 .49583 .09238 Mtetra
.701 .645 .791 r
.48615 .08285 .48096 .08727 .48581 .09202 .491 .08761 Mtetra
.48129 .07809 .47611 .08251 .48096 .08727 .48615 .08285 Mtetra
.701 .646 .791 r
.47643 .07332 .47124 .07775 .47611 .08251 .48129 .07809 Mtetra
.47156 .06854 .46637 .07298 .47124 .07775 .47643 .07332 Mtetra
.46668 .06375 .46149 .0682 .46637 .07298 .47156 .06854 Mtetra
.46179 .05896 .4566 .06342 .46149 .0682 .46668 .06375 Mtetra
.45689 .05416 .4517 .05862 .4566 .06342 .46179 .05896 Mtetra
.90477 .48451 .89965 .48832 .90381 .4924 .90893 .4886 Mtetra
.90061 .48042 .89548 .48423 .89965 .48832 .90477 .48451 Mtetra
.89643 .47632 .89131 .48013 .89548 .48423 .90061 .48042 Mtetra
.89225 .47222 .88713 .47604 .89131 .48013 .89643 .47632 Mtetra
.88806 .4681 .88294 .47193 .88713 .47604 .89225 .47222 Mtetra
.88387 .46398 .87875 .46782 .88294 .47193 .88806 .4681 Mtetra
.87967 .45986 .87455 .4637 .87875 .46782 .88387 .46398 Mtetra
.87546 .45573 .87034 .45957 .87455 .4637 .87967 .45986 Mtetra
.87125 .45159 .86612 .45544 .87034 .45957 .87546 .45573 Mtetra
.86703 .44744 .8619 .4513 .86612 .45544 .87125 .45159 Mtetra
.8628 .44329 .85767 .44715 .8619 .4513 .86703 .44744 Mtetra
.85857 .43913 .85344 .443 .85767 .44715 .8628 .44329 Mtetra
.85433 .43496 .8492 .43884 .85344 .443 .85857 .43913 Mtetra
.85008 .43079 .84495 .43467 .8492 .43884 .85433 .43496 Mtetra
.84582 .42661 .84069 .4305 .84495 .43467 .85008 .43079 Mtetra
.84156 .42243 .83643 .42632 .84069 .4305 .84582 .42661 Mtetra
.83729 .41823 .83216 .42213 .83643 .42632 .84156 .42243 Mtetra
.83302 .41403 .82788 .41794 .83216 .42213 .83729 .41823 Mtetra
.82874 .40983 .8236 .41374 .82788 .41794 .83302 .41403 Mtetra
.82445 .40561 .81931 .40953 .8236 .41374 .82874 .40983 Mtetra
.82015 .40139 .81501 .40532 .81931 .40953 .82445 .40561 Mtetra
.81585 .39717 .81071 .4011 .81501 .40532 .82015 .40139 Mtetra
.81154 .39293 .8064 .39687 .81071 .4011 .81585 .39717 Mtetra
.80722 .38869 .80208 .39264 .8064 .39687 .81154 .39293 Mtetra
.80289 .38444 .79775 .38839 .80208 .39264 .80722 .38869 Mtetra
.79856 .38019 .79342 .38415 .79775 .38839 .80289 .38444 Mtetra
.79422 .37593 .78908 .37989 .79342 .38415 .79856 .38019 Mtetra
.78988 .37166 .78473 .37563 .78908 .37989 .79422 .37593 Mtetra
.78553 .36738 .78038 .37136 .78473 .37563 .78988 .37166 Mtetra
.78117 .3631 .77602 .36708 .78038 .37136 .78553 .36738 Mtetra
.7768 .35881 .77165 .3628 .77602 .36708 .78117 .3631 Mtetra
.77243 .35452 .76728 .35851 .77165 .3628 .7768 .35881 Mtetra
.76804 .35021 .7629 .35422 .76728 .35851 .77243 .35452 Mtetra
.76366 .3459 .75851 .34991 .7629 .35422 .76804 .35021 Mtetra
.75926 .34159 .75411 .3456 .75851 .34991 .76366 .3459 Mtetra
.702 .646 .791 r
.75486 .33726 .74971 .34129 .75411 .3456 .75926 .34159 Mtetra
.75045 .33293 .7453 .33697 .74971 .34129 .75486 .33726 Mtetra
.74603 .3286 .74088 .33264 .7453 .33697 .75045 .33293 Mtetra
.74161 .32426 .73645 .32831 .74088 .33264 .74603 .3286 Mtetra
.702 .647 .791 r
.73718 .31992 .73202 .32398 .73645 .32831 .74161 .32426 Mtetra
.703 .647 .791 r
.73274 .31559 .72759 .31965 .73202 .32398 .73718 .31992 Mtetra
.703 .648 .792 r
.7283 .31126 .72314 .31534 .72759 .31965 .73274 .31559 Mtetra
.705 .649 .792 r
.72385 .30694 .7187 .31104 .72314 .31534 .7283 .31126 Mtetra
.707 .652 .793 r
.7194 .30266 .71425 .30679 .7187 .31104 .72385 .30694 Mtetra
.71 .656 .794 r
.71495 .29844 .7098 .30261 .71425 .30679 .7194 .30266 Mtetra
.715 .662 .796 r
.71051 .29431 .70536 .29854 .7098 .30261 .71495 .29844 Mtetra
.724 .673 .8 r
.70607 .29035 .70093 .29467 .70536 .29854 .71051 .29431 Mtetra
.739 .691 .805 r
.70165 .28665 .69653 .29112 .70093 .29467 .70607 .29035 Mtetra
.762 .719 .813 r
.69728 .28337 .69217 .28808 .69653 .29112 .70165 .28665 Mtetra
.798 .765 .823 r
.69295 .28078 .68787 .28584 .69217 .28808 .69728 .28337 Mtetra
.851 .836 .831 r
.68873 .27923 .68368 .28481 .68787 .28584 .69295 .28078 Mtetra
.908 .926 .815 r
.68463 .27919 .67964 .28551 .68368 .28481 .68873 .27923 Mtetra
.91 .981 .721 r
.68071 .2812 .67578 .28842 .67964 .28551 .68463 .27919 Mtetra
.78 .912 .523 r
.67698 .2856 .6721 .2937 .67578 .28842 .68071 .2812 Mtetra
0 0 0 r
.67339 .29197 .6685 .30048 .6721 .2937 .67698 .2856 Mtetra
.66976 .29855 .66476 .30638 .6685 .30048 .67339 .29197 Mtetra
.631 .896 .579 r
.6658 .30207 .66059 .30786 .66476 .30638 .66976 .29855 Mtetra
.68 .774 .921 r
.66125 .29932 .6558 .30237 .66059 .30786 .6658 .30207 Mtetra
.451 .385 .691 r
.65608 .28948 .65048 .29035 .6558 .30237 .66125 .29932 Mtetra
.402 .288 .608 r
.65055 .2749 .64491 .2749 .65048 .29035 .65608 .28948 Mtetra
.409 .279 .591 r
.64496 .25909 .63939 .25938 .64491 .2749 .65055 .2749 Mtetra
.44 .307 .603 r
.63952 .24465 .63404 .24576 .63939 .25938 .64496 .25909 Mtetra
.483 .356 .631 r
.63429 .23254 .62891 .23455 .63404 .24576 .63952 .24465 Mtetra
.532 .415 .666 r
.62926 .22271 .62395 .22546 .62891 .23455 .63429 .23254 Mtetra
.579 .476 .701 r
.62437 .21467 .61911 .21796 .62395 .22546 .62926 .22271 Mtetra
.62 .529 .73 r
.61958 .20791 .61435 .21159 .61911 .21796 .62437 .21467 Mtetra
.653 .572 .751 r
.61484 .20201 .60964 .20598 .61435 .21159 .61958 .20791 Mtetra
.68 .605 .765 r
.61015 .19673 .60497 .20096 .60964 .20598 .61484 .20201 Mtetra
.707 .634 .773 r
.60548 .19194 .60031 .19649 .60497 .20096 .61015 .19673 Mtetra
.742 .665 .775 r
.60083 .18767 .59569 .19272 .60031 .19649 .60548 .19194 Mtetra
.796 .708 .767 r
.59622 .18416 .59112 .19011 .59569 .19272 .60083 .18767 Mtetra
.876 .765 .737 r
.59166 .18196 .58663 .1896 .59112 .19011 .59622 .18416 Mtetra
.964 .824 .657 r
.58721 .1822 .58229 .19292 .58663 .1896 .59166 .18196 Mtetra
.998 .84 .51 r
.58292 .18683 .57819 .20274 .58229 .19292 .58721 .1822 Mtetra
.935 .794 .33 r
.57891 .19869 .57439 .22174 .57819 .20274 .58292 .18683 Mtetra
.763 .695 .153 r
.57519 .21999 .57075 .24851 .57439 .22174 .57891 .19869 Mtetra
0 0 .025 r
.57155 .24721 .56677 .27085 .57075 .24851 .57519 .21999 Mtetra
.151 0 .141 r
.5674 .26522 .56186 .26973 .56677 .27085 .57155 .24721 Mtetra
.784 .343 0 r
.56223 .25668 .55611 .24208 .56186 .26973 .5674 .26522 Mtetra
0 0 .36 r
.55634 .22488 .55022 .20541 .55611 .24208 .56223 .25668 Mtetra
.012 0 .41 r
.55047 .18888 .54465 .17481 .55022 .20541 .55634 .22488 Mtetra
.151 .041 .463 r
.54497 .16075 .53943 .15372 .54465 .17481 .55047 .18888 Mtetra
.277 .16 .535 r
.5398 .14178 .53444 .13983 .53943 .15372 .54497 .16075 Mtetra
.408 .3 .619 r
.53482 .12924 .52955 .1303 .53444 .13983 .5398 .14178 Mtetra
.523 .43 .692 r
.52995 .12044 .52473 .12313 .52955 .1303 .53482 .12924 Mtetra
.603 .525 .739 r
.52512 .11365 .51992 .11718 .52473 .12313 .52995 .12044 Mtetra
.65 .582 .765 r
.52031 .10789 .51511 .11185 .51992 .11718 .52512 .11365 Mtetra
.676 .613 .778 r
.51549 .10265 .5103 .10683 .51511 .11185 .52031 .10789 Mtetra
.689 .63 .785 r
.51068 .09766 .50549 .10196 .5103 .10683 .51549 .10265 Mtetra
.695 .638 .788 r
.50586 .0928 .50066 .09715 .50549 .10196 .51068 .09766 Mtetra
.698 .642 .789 r
.50103 .08799 .49583 .09238 .50066 .09715 .50586 .0928 Mtetra
.7 .644 .79 r
.49619 .08321 .491 .08761 .49583 .09238 .50103 .08799 Mtetra
.701 .645 .79 r
.49134 .07843 .48615 .08285 .491 .08761 .49619 .08321 Mtetra
.701 .645 .791 r
.48649 .07366 .48129 .07809 .48615 .08285 .49134 .07843 Mtetra
.48163 .06888 .47643 .07332 .48129 .07809 .48649 .07366 Mtetra
.701 .646 .791 r
.47675 .06409 .47156 .06854 .47643 .07332 .48163 .06888 Mtetra
.47188 .0593 .46668 .06375 .47156 .06854 .47675 .06409 Mtetra
.46699 .05449 .46179 .05896 .46668 .06375 .47188 .0593 Mtetra
.46209 .04968 .45689 .05416 .46179 .05896 .46699 .05449 Mtetra
.9099 .48071 .90477 .48451 .90893 .4886 .91406 .4848 Mtetra
.90573 .47661 .90061 .48042 .90477 .48451 .9099 .48071 Mtetra
.90156 .4725 .89643 .47632 .90061 .48042 .90573 .47661 Mtetra
.89738 .46839 .89225 .47222 .89643 .47632 .90156 .4725 Mtetra
.8932 .46427 .88806 .4681 .89225 .47222 .89738 .46839 Mtetra
.889 .46015 .88387 .46398 .88806 .4681 .8932 .46427 Mtetra
.8848 .45602 .87967 .45986 .88387 .46398 .889 .46015 Mtetra
.8806 .45188 .87546 .45573 .87967 .45986 .8848 .45602 Mtetra
.87638 .44773 .87125 .45159 .87546 .45573 .8806 .45188 Mtetra
.87217 .44358 .86703 .44744 .87125 .45159 .87638 .44773 Mtetra
.86794 .43942 .8628 .44329 .86703 .44744 .87217 .44358 Mtetra
.86371 .43526 .85857 .43913 .8628 .44329 .86794 .43942 Mtetra
.85947 .43108 .85433 .43496 .85857 .43913 .86371 .43526 Mtetra
.85522 .4269 .85008 .43079 .85433 .43496 .85947 .43108 Mtetra
.85096 .42272 .84582 .42661 .85008 .43079 .85522 .4269 Mtetra
.8467 .41853 .84156 .42243 .84582 .42661 .85096 .42272 Mtetra
.84244 .41433 .83729 .41823 .84156 .42243 .8467 .41853 Mtetra
.83816 .41012 .83302 .41403 .83729 .41823 .84244 .41433 Mtetra
.83388 .40591 .82874 .40983 .83302 .41403 .83816 .41012 Mtetra
.82959 .40169 .82445 .40561 .82874 .40983 .83388 .40591 Mtetra
.8253 .39746 .82015 .40139 .82445 .40561 .82959 .40169 Mtetra
.82099 .39323 .81585 .39717 .82015 .40139 .8253 .39746 Mtetra
.81668 .38899 .81154 .39293 .81585 .39717 .82099 .39323 Mtetra
.81237 .38474 .80722 .38869 .81154 .39293 .81668 .38899 Mtetra
.80804 .38049 .80289 .38444 .80722 .38869 .81237 .38474 Mtetra
.80371 .37623 .79856 .38019 .80289 .38444 .80804 .38049 Mtetra
.79938 .37196 .79422 .37593 .79856 .38019 .80371 .37623 Mtetra
.79503 .36768 .78988 .37166 .79422 .37593 .79938 .37196 Mtetra
.79068 .3634 .78553 .36738 .78988 .37166 .79503 .36768 Mtetra
.78632 .35911 .78117 .3631 .78553 .36738 .79068 .3634 Mtetra
.78196 .35482 .7768 .35881 .78117 .3631 .78632 .35911 Mtetra
.77758 .35051 .77243 .35452 .7768 .35881 .78196 .35482 Mtetra
.7732 .3462 .76804 .35021 .77243 .35452 .77758 .35051 Mtetra
.76881 .34189 .76366 .3459 .76804 .35021 .7732 .3462 Mtetra
.76442 .33756 .75926 .34159 .76366 .3459 .76881 .34189 Mtetra
.702 .646 .791 r
.76002 .33323 .75486 .33726 .75926 .34159 .76442 .33756 Mtetra
.75561 .3289 .75045 .33293 .75486 .33726 .76002 .33323 Mtetra
.75119 .32456 .74603 .3286 .75045 .33293 .75561 .3289 Mtetra
.74677 .32021 .74161 .32426 .74603 .3286 .75119 .32456 Mtetra
.74234 .31586 .73718 .31992 .74161 .32426 .74677 .32021 Mtetra
.702 .647 .791 r
.7379 .31152 .73274 .31559 .73718 .31992 .74234 .31586 Mtetra
.703 .648 .791 r
.73346 .30717 .7283 .31126 .73274 .31559 .7379 .31152 Mtetra
.704 .649 .792 r
.72902 .30284 .72385 .30694 .7283 .31126 .73346 .30717 Mtetra
.706 .651 .793 r
.72457 .29854 .7194 .30266 .72385 .30694 .72902 .30284 Mtetra
.708 .654 .794 r
.72011 .29428 .71495 .29844 .7194 .30266 .72457 .29854 Mtetra
.713 .66 .795 r
.71566 .2901 .71051 .29431 .71495 .29844 .72011 .29428 Mtetra
.72 .668 .798 r
.71122 .28605 .70607 .29035 .71051 .29431 .71566 .2901 Mtetra
.732 .683 .803 r
.7068 .28223 .70165 .28665 .70607 .29035 .71122 .28605 Mtetra
.752 .707 .809 r
.7024 .27876 .69728 .28337 .70165 .28665 .7068 .28223 Mtetra
.783 .746 .819 r
.69806 .27586 .69295 .28078 .69728 .28337 .7024 .27876 Mtetra
.829 .806 .829 r
.69379 .27385 .68873 .27923 .69295 .28078 .69806 .27586 Mtetra
.889 .892 .826 r
.68965 .27317 .68463 .27919 .68873 .27923 .69379 .27385 Mtetra
.922 .971 .77 r
.68567 .27433 .68071 .2812 .68463 .27919 .68965 .27317 Mtetra
.843 .953 .604 r
.68188 .2778 .67698 .2856 .68071 .2812 .68567 .27433 Mtetra
.664 .826 .398 r
.67827 .28352 .67339 .29197 .67698 .2856 .68188 .2778 Mtetra
0 0 0 r
.6747 .2903 .66976 .29855 .67339 .29197 .67827 .28352 Mtetra
.67092 .29537 .6658 .30207 .66976 .29855 .6747 .2903 Mtetra
.767 .967 .926 r
.66662 .29522 .66125 .29932 .6658 .30207 .67092 .29537 Mtetra
.507 .477 .759 r
.66166 .28791 .65608 .28948 .66125 .29932 .66662 .29522 Mtetra
.41 .308 .628 r
.65621 .27471 .65055 .2749 .65608 .28948 .66166 .28791 Mtetra
.403 .276 .593 r
.65058 .25899 .64496 .25909 .65055 .2749 .65621 .27471 Mtetra
.426 .293 .596 r
.64504 .24385 .63952 .24465 .64496 .25909 .65058 .25899 Mtetra
.465 .335 .619 r
.63971 .23085 .63429 .23254 .63952 .24465 .64504 .24385 Mtetra
.513 .392 .653 r
.6346 .22021 .62926 .22271 .63429 .23254 .63971 .23085 Mtetra
.562 .454 .688 r
.62965 .21156 .62437 .21467 .62926 .22271 .6346 .22021 Mtetra
.605 .51 .72 r
.62482 .20436 .61958 .20791 .62437 .21467 .62965 .21156 Mtetra
.64 .556 .744 r
.62006 .19816 .61484 .20201 .61958 .20791 .62482 .20436 Mtetra
.667 .592 .761 r
.61535 .19263 .61015 .19673 .61484 .20201 .62006 .19816 Mtetra
.691 .62 .771 r
.61066 .18759 .60548 .19194 .61015 .19673 .61535 .19263 Mtetra
.718 .646 .776 r
.606 .18299 .60083 .18767 .60548 .19194 .61066 .18759 Mtetra
.756 .678 .775 r
.60136 .17891 .59622 .18416 .60083 .18767 .606 .18299 Mtetra
.815 .722 .763 r
.59676 .17567 .59166 .18196 .59622 .18416 .60136 .17891 Mtetra
.899 .782 .723 r
.59222 .17395 .58721 .1822 .59166 .18196 .59676 .17567 Mtetra
.98 .834 .626 r
.5878 .17504 .58292 .18683 .58721 .1822 .59222 .17395 Mtetra
.992 .834 .464 r
.58358 .18116 .57891 .19869 .58292 .18683 .5878 .17504 Mtetra
.903 .774 .284 r
.57965 .19521 .57519 .21999 .57891 .19869 .58358 .18116 Mtetra
0 0 0 r
.57602 .21862 .57155 .24721 .57519 .21999 .57965 .19521 Mtetra
0 0 .063 r
.57235 .2453 .5674 .26522 .57155 .24721 .57602 .21862 Mtetra
.34 0 .131 r
.56798 .25774 .56223 .25668 .5674 .26522 .57235 .2453 Mtetra
0 0 .254 r
.56254 .24207 .55634 .22488 .56223 .25668 .56798 .25774 Mtetra
0 0 .375 r
.55656 .20749 .55047 .18888 .55634 .22488 .56254 .24207 Mtetra
.051 0 .422 r
.55074 .17291 .54497 .16075 .55047 .18888 .55656 .20749 Mtetra
.182 .068 .479 r
.5453 .14728 .5398 .14178 .54497 .16075 .55074 .17291 Mtetra
.309 .194 .555 r
.54017 .13023 .53482 .12924 .5398 .14178 .5453 .14728 Mtetra
.439 .334 .639 r
.53522 .11885 .52995 .12044 .53482 .12924 .54017 .13023 Mtetra
.547 .458 .706 r
.53035 .11068 .52512 .11365 .52995 .12044 .53522 .11885 Mtetra
.618 .543 .747 r
.52552 .10421 .52031 .10789 .52512 .11365 .53035 .11068 Mtetra
.658 .592 .769 r
.5207 .09861 .51549 .10265 .52031 .10789 .52552 .10421 Mtetra
.68 .619 .78 r
.51588 .09344 .51068 .09766 .51549 .10265 .5207 .09861 Mtetra
.691 .632 .786 r
.51106 .08848 .50586 .0928 .51068 .09766 .51588 .09344 Mtetra
.696 .639 .788 r
.50623 .08362 .50103 .08799 .50586 .0928 .51106 .08848 Mtetra
.699 .642 .79 r
.50139 .0788 .49619 .08321 .50103 .08799 .50623 .08362 Mtetra
.7 .644 .79 r
.49655 .07401 .49134 .07843 .49619 .08321 .50139 .0788 Mtetra
.701 .645 .79 r
.49169 .06922 .48649 .07366 .49134 .07843 .49655 .07401 Mtetra
.701 .645 .791 r
.48683 .06443 .48163 .06888 .48649 .07366 .49169 .06922 Mtetra
.48196 .05963 .47675 .06409 .48163 .06888 .48683 .06443 Mtetra
.701 .646 .791 r
.47708 .05483 .47188 .0593 .47675 .06409 .48196 .05963 Mtetra
.47219 .05002 .46699 .05449 .47188 .0593 .47708 .05483 Mtetra
.4673 .0452 .46209 .04968 .46699 .05449 .47219 .05002 Mtetra
.91503 .4769 .9099 .48071 .91406 .4848 .91919 .481 Mtetra
.91087 .47279 .90573 .47661 .9099 .48071 .91503 .4769 Mtetra
.9067 .46868 .90156 .4725 .90573 .47661 .91087 .47279 Mtetra
.90252 .46456 .89738 .46839 .90156 .4725 .9067 .46868 Mtetra
.89833 .46044 .8932 .46427 .89738 .46839 .90252 .46456 Mtetra
.89414 .45631 .889 .46015 .8932 .46427 .89833 .46044 Mtetra
.88994 .45217 .8848 .45602 .889 .46015 .89414 .45631 Mtetra
.88574 .44802 .8806 .45188 .8848 .45602 .88994 .45217 Mtetra
.88153 .44387 .87638 .44773 .8806 .45188 .88574 .44802 Mtetra
.87731 .43971 .87217 .44358 .87638 .44773 .88153 .44387 Mtetra
.87308 .43555 .86794 .43942 .87217 .44358 .87731 .43971 Mtetra
.86885 .43138 .86371 .43526 .86794 .43942 .87308 .43555 Mtetra
.86461 .4272 .85947 .43108 .86371 .43526 .86885 .43138 Mtetra
.86037 .42301 .85522 .4269 .85947 .43108 .86461 .4272 Mtetra
.85611 .41882 .85096 .42272 .85522 .4269 .86037 .42301 Mtetra
.85185 .41462 .8467 .41853 .85096 .42272 .85611 .41882 Mtetra
.84759 .41042 .84244 .41433 .8467 .41853 .85185 .41462 Mtetra
.84331 .4062 .83816 .41012 .84244 .41433 .84759 .41042 Mtetra
.83903 .40198 .83388 .40591 .83816 .41012 .84331 .4062 Mtetra
.83474 .39776 .82959 .40169 .83388 .40591 .83903 .40198 Mtetra
.83045 .39353 .8253 .39746 .82959 .40169 .83474 .39776 Mtetra
.82615 .38929 .82099 .39323 .8253 .39746 .83045 .39353 Mtetra
.82184 .38504 .81668 .38899 .82099 .39323 .82615 .38929 Mtetra
.81753 .38079 .81237 .38474 .81668 .38899 .82184 .38504 Mtetra
.8132 .37653 .80804 .38049 .81237 .38474 .81753 .38079 Mtetra
.80887 .37226 .80371 .37623 .80804 .38049 .8132 .37653 Mtetra
.80454 .36798 .79938 .37196 .80371 .37623 .80887 .37226 Mtetra
.80019 .3637 .79503 .36768 .79938 .37196 .80454 .36798 Mtetra
.79584 .35941 .79068 .3634 .79503 .36768 .80019 .3637 Mtetra
.79148 .35512 .78632 .35911 .79068 .3634 .79584 .35941 Mtetra
.78712 .35082 .78196 .35482 .78632 .35911 .79148 .35512 Mtetra
.78275 .34651 .77758 .35051 .78196 .35482 .78712 .35082 Mtetra
.77837 .34219 .7732 .3462 .77758 .35051 .78275 .34651 Mtetra
.77398 .33787 .76881 .34189 .7732 .3462 .77837 .34219 Mtetra
.76959 .33354 .76442 .33756 .76881 .34189 .77398 .33787 Mtetra
.702 .646 .791 r
.76519 .3292 .76002 .33323 .76442 .33756 .76959 .33354 Mtetra
.76078 .32486 .75561 .3289 .76002 .33323 .76519 .3292 Mtetra
.75636 .32051 .75119 .32456 .75561 .3289 .76078 .32486 Mtetra
.75194 .31615 .74677 .32021 .75119 .32456 .75636 .32051 Mtetra
.74751 .3118 .74234 .31586 .74677 .32021 .75194 .31615 Mtetra
.702 .647 .791 r
.74308 .30744 .7379 .31152 .74234 .31586 .74751 .3118 Mtetra
.703 .647 .791 r
.73863 .30308 .73346 .30717 .7379 .31152 .74308 .30744 Mtetra
.704 .648 .792 r
.73419 .29874 .72902 .30284 .73346 .30717 .73863 .30308 Mtetra
.705 .65 .792 r
.72974 .29441 .72457 .29854 .72902 .30284 .73419 .29874 Mtetra
.707 .653 .793 r
.72528 .29012 .72011 .29428 .72457 .29854 .72974 .29441 Mtetra
.711 .657 .795 r
.72083 .2859 .71566 .2901 .72011 .29428 .72528 .29012 Mtetra
.717 .665 .797 r
.71638 .28178 .71122 .28605 .71566 .2901 .72083 .2859 Mtetra
.727 .677 .801 r
.71195 .27785 .7068 .28223 .71122 .28605 .71638 .28178 Mtetra
.743 .697 .807 r
.70754 .27422 .7024 .27876 .7068 .28223 .71195 .27785 Mtetra
.77 .729 .815 r
.70317 .27106 .69806 .27586 .7024 .27876 .70754 .27422 Mtetra
.81 .781 .825 r
.69888 .26866 .69379 .27385 .69806 .27586 .70317 .27106 Mtetra
.866 .858 .831 r
.69469 .26741 .68965 .27317 .69379 .27385 .69888 .26866 Mtetra
.918 .947 .802 r
.69065 .2678 .68567 .27433 .68965 .27317 .69469 .26741 Mtetra
.889 .976 .679 r
.6868 .27034 .68188 .2778 .68567 .27433 .69065 .2678 Mtetra
.733 .878 .469 r
.68315 .27525 .67827 .28352 .68188 .2778 .6868 .27034 Mtetra
0 0 0 r
.67961 .28184 .6747 .2903 .67827 .28352 .68315 .27525 Mtetra
.67597 .28793 .67092 .29537 .6747 .2903 .67961 .28184 Mtetra
.709 .97 .733 r
.6719 .29008 .66662 .29522 .67092 .29537 .67597 .28793 Mtetra
.599 .631 .854 r
.66718 .28548 .66166 .28791 .66662 .29522 .6719 .29008 Mtetra
.429 .346 .66 r
.66186 .27415 .65621 .27471 .66166 .28791 .66718 .28548 Mtetra
.4 .28 .6 r
.65624 .25896 .65058 .25899 .65621 .27471 .66186 .27415 Mtetra
.415 .283 .592 r
.65062 .24335 .64504 .24385 .65058 .25899 .65624 .25896 Mtetra
.449 .317 .608 r
.64519 .22947 .63971 .23085 .64504 .24385 .65062 .24335 Mtetra
.494 .37 .639 r
.63998 .21798 .6346 .22021 .63971 .23085 .64519 .22947 Mtetra
.543 .431 .675 r
.63497 .20864 .62965 .21156 .6346 .22021 .63998 .21798 Mtetra
.589 .49 .709 r
.63009 .20095 .62482 .20436 .62965 .21156 .63497 .20864 Mtetra
.627 .54 .736 r
.6253 .1944 .62006 .19816 .62482 .20436 .63009 .20095 Mtetra
.656 .578 .756 r
.62057 .18863 .61535 .19263 .62006 .19816 .6253 .1944 Mtetra
.68 .608 .768 r
.61587 .18338 .61066 .18759 .61535 .19263 .62057 .18863 Mtetra
.701 .632 .776 r
.61119 .17853 .606 .18299 .61066 .18759 .61587 .18338 Mtetra
.728 .657 .778 r
.60653 .17409 .60136 .17891 .606 .18299 .61119 .17853 Mtetra
.77 .69 .775 r
.60189 .1702 .59676 .17567 .60136 .17891 .60653 .17409 Mtetra
.835 .738 .757 r
.5973 .16726 .59222 .17395 .59676 .17567 .60189 .1702 Mtetra
.923 .798 .705 r
.59279 .16608 .5878 .17504 .59222 .17395 .5973 .16726 Mtetra
.992 .84 .589 r
.58841 .16816 .58358 .18116 .5878 .17504 .59279 .16608 Mtetra
.979 .823 .418 r
.58426 .17593 .57965 .19521 .58358 .18116 .58841 .16816 Mtetra
.864 .751 .239 r
.58044 .19228 .57602 .21862 .57965 .19521 .58426 .17593 Mtetra
0 0 0 r
.57686 .21744 .57235 .2453 .57602 .21862 .58044 .19228 Mtetra
0 0 .096 r
.57311 .24241 .56798 .25774 .57235 .2453 .57686 .21744 Mtetra
.556 .081 .082 r
.56848 .24833 .56254 .24207 .56798 .25774 .57311 .24241 Mtetra
0 0 .313 r
.56281 .22623 .55656 .20749 .56254 .24207 .56848 .24833 Mtetra
0 0 .387 r
.55678 .19018 .55074 .17291 .55656 .20749 .56281 .22623 Mtetra
.085 0 .434 r
.55101 .15756 .5453 .14728 .55074 .17291 .55678 .19018 Mtetra
.212 .096 .496 r
.54564 .13435 .54017 .13023 .5453 .14728 .55101 .15756 Mtetra
.342 .228 .576 r
.54055 .11902 .53522 .11885 .54017 .13023 .54564 .13435 Mtetra
.468 .368 .658 r
.53562 .10864 .53035 .11068 .53522 .11885 .54055 .11902 Mtetra
.568 .483 .719 r
.53075 .101 .52552 .10421 .53035 .11068 .53562 .10864 Mtetra
.63 .558 .754 r
.52592 .0948 .5207 .09861 .52552 .10421 .53075 .101 Mtetra
.665 .6 .773 r
.52109 .08932 .51588 .09344 .5207 .09861 .52592 .0948 Mtetra
.683 .623 .782 r
.51627 .0842 .51106 .08848 .51588 .09344 .52109 .08932 Mtetra
.692 .634 .787 r
.51144 .07926 .50623 .08362 .51106 .08848 .51627 .0842 Mtetra
.697 .64 .789 r
.5066 .07441 .50139 .0788 .50623 .08362 .51144 .07926 Mtetra
.699 .643 .79 r
.50176 .06958 .49655 .07401 .50139 .0788 .5066 .07441 Mtetra
.7 .644 .79 r
.4969 .06478 .49169 .06922 .49655 .07401 .50176 .06958 Mtetra
.701 .645 .791 r
.49204 .05998 .48683 .06443 .49169 .06922 .4969 .06478 Mtetra
.48717 .05517 .48196 .05963 .48683 .06443 .49204 .05998 Mtetra
.48229 .05036 .47708 .05483 .48196 .05963 .48717 .05517 Mtetra
.701 .646 .791 r
.47741 .04554 .47219 .05002 .47708 .05483 .48229 .05036 Mtetra
.47251 .04072 .4673 .0452 .47219 .05002 .47741 .04554 Mtetra
.92018 .47308 .91503 .4769 .91919 .481 .92433 .47719 Mtetra
.91601 .46897 .91087 .47279 .91503 .4769 .92018 .47308 Mtetra
.91184 .46485 .9067 .46868 .91087 .47279 .91601 .46897 Mtetra
.90766 .46073 .90252 .46456 .9067 .46868 .91184 .46485 Mtetra
.90348 .4566 .89833 .46044 .90252 .46456 .90766 .46073 Mtetra
.89929 .45246 .89414 .45631 .89833 .46044 .90348 .4566 Mtetra
.89509 .44831 .88994 .45217 .89414 .45631 .89929 .45246 Mtetra
.89089 .44416 .88574 .44802 .88994 .45217 .89509 .44831 Mtetra
.88668 .44 .88153 .44387 .88574 .44802 .89089 .44416 Mtetra
.88246 .43584 .87731 .43971 .88153 .44387 .88668 .44 Mtetra
.87824 .43167 .87308 .43555 .87731 .43971 .88246 .43584 Mtetra
.874 .42749 .86885 .43138 .87308 .43555 .87824 .43167 Mtetra
.86977 .42331 .86461 .4272 .86885 .43138 .874 .42749 Mtetra
.86552 .41911 .86037 .42301 .86461 .4272 .86977 .42331 Mtetra
.86127 .41492 .85611 .41882 .86037 .42301 .86552 .41911 Mtetra
.85701 .41071 .85185 .41462 .85611 .41882 .86127 .41492 Mtetra
.85274 .4065 .84759 .41042 .85185 .41462 .85701 .41071 Mtetra
.84847 .40228 .84331 .4062 .84759 .41042 .85274 .4065 Mtetra
.84419 .39806 .83903 .40198 .84331 .4062 .84847 .40228 Mtetra
.83991 .39382 .83474 .39776 .83903 .40198 .84419 .39806 Mtetra
.83561 .38958 .83045 .39353 .83474 .39776 .83991 .39382 Mtetra
.83131 .38534 .82615 .38929 .83045 .39353 .83561 .38958 Mtetra
.827 .38108 .82184 .38504 .82615 .38929 .83131 .38534 Mtetra
.82269 .37682 .81753 .38079 .82184 .38504 .827 .38108 Mtetra
.81837 .37256 .8132 .37653 .81753 .38079 .82269 .37682 Mtetra
.81404 .36828 .80887 .37226 .8132 .37653 .81837 .37256 Mtetra
.8097 .364 .80454 .36798 .80887 .37226 .81404 .36828 Mtetra
.80536 .35971 .80019 .3637 .80454 .36798 .8097 .364 Mtetra
.80101 .35542 .79584 .35941 .80019 .3637 .80536 .35971 Mtetra
.79665 .35112 .79148 .35512 .79584 .35941 .80101 .35542 Mtetra
.79229 .34681 .78712 .35082 .79148 .35512 .79665 .35112 Mtetra
.78792 .34249 .78275 .34651 .78712 .35082 .79229 .34681 Mtetra
.78354 .33817 .77837 .34219 .78275 .34651 .78792 .34249 Mtetra
.77915 .33384 .77398 .33787 .77837 .34219 .78354 .33817 Mtetra
.77476 .3295 .76959 .33354 .77398 .33787 .77915 .33384 Mtetra
.702 .646 .791 r
.77036 .32516 .76519 .3292 .76959 .33354 .77476 .3295 Mtetra
.76595 .32081 .76078 .32486 .76519 .3292 .77036 .32516 Mtetra
.76154 .31645 .75636 .32051 .76078 .32486 .76595 .32081 Mtetra
.75712 .31209 .75194 .31615 .75636 .32051 .76154 .31645 Mtetra
.75269 .30773 .74751 .3118 .75194 .31615 .75712 .31209 Mtetra
.74826 .30336 .74308 .30744 .74751 .3118 .75269 .30773 Mtetra
.703 .647 .791 r
.74381 .29899 .73863 .30308 .74308 .30744 .74826 .30336 Mtetra
.703 .648 .792 r
.73937 .29463 .73419 .29874 .73863 .30308 .74381 .29899 Mtetra
.704 .649 .792 r
.73492 .29029 .72974 .29441 .73419 .29874 .73937 .29463 Mtetra
.706 .652 .793 r
.73046 .28597 .72528 .29012 .72974 .29441 .73492 .29029 Mtetra
.709 .655 .794 r
.72601 .28171 .72083 .2859 .72528 .29012 .73046 .28597 Mtetra
.715 .661 .796 r
.72155 .27754 .71638 .28178 .72083 .2859 .72601 .28171 Mtetra
.723 .671 .799 r
.71711 .27351 .71195 .27785 .71638 .28178 .72155 .27754 Mtetra
.736 .688 .804 r
.71269 .26974 .70754 .27422 .71195 .27785 .71711 .27351 Mtetra
.758 .715 .812 r
.70831 .26637 .70317 .27106 .70754 .27422 .71269 .26974 Mtetra
.793 .758 .822 r
.70398 .26363 .69888 .26866 .70317 .27106 .70831 .26637 Mtetra
.844 .826 .83 r
.69975 .26188 .69469 .26741 .69888 .26866 .70398 .26363 Mtetra
.902 .915 .82 r
.69566 .26157 .69065 .2678 .69469 .26741 .69975 .26188 Mtetra
.916 .98 .739 r
.69174 .26323 .6868 .27034 .69065 .2678 .69566 .26157 Mtetra
.802 .926 .55 r
.68804 .26724 .68315 .27525 .6868 .27034 .69174 .26323 Mtetra
.62 .793 .358 r
.6845 .27334 .67961 .28184 .68315 .27525 .68804 .26724 Mtetra
0 0 0 r
.68095 .27994 .67597 .28793 .67961 .28184 .6845 .27334 Mtetra
.601 .862 .517 r
.67709 .28396 .6719 .29008 .67597 .28793 .68095 .27994 Mtetra
.72 .848 .942 r
.67263 .28205 .66718 .28548 .6719 .29008 .67709 .28396 Mtetra
.467 .411 .711 r
.6675 .27302 .66186 .27415 .66718 .28548 .67263 .28205 Mtetra
.404 .293 .614 r
.66193 .25887 .65624 .25896 .66186 .27415 .6675 .27302 Mtetra
.406 .277 .591 r
.65625 .24309 .65062 .24335 .65624 .25896 .66193 .25887 Mtetra
.435 .302 .6 r
.65072 .22842 .64519 .22947 .65062 .24335 .65625 .24309 Mtetra
.477 .348 .627 r
.64541 .21604 .63998 .21798 .64519 .22947 .65072 .22842 Mtetra
.525 .407 .662 r
.64032 .20595 .63497 .20864 .63998 .21798 .64541 .21604 Mtetra
.573 .468 .697 r
.63538 .1977 .63009 .20095 .63497 .20864 .64032 .20595 Mtetra
.613 .522 .727 r
.63056 .19076 .6253 .1944 .63009 .20095 .63538 .1977 Mtetra
.645 .564 .749 r
.6258 .18472 .62057 .18863 .6253 .1944 .63056 .19076 Mtetra
.67 .596 .764 r
.62109 .17926 .61587 .18338 .62057 .18863 .6258 .18472 Mtetra
.69 .62 .774 r
.61639 .17422 .61119 .17853 .61587 .18338 .62109 .17926 Mtetra
.71 .642 .779 r
.61172 .16953 .60653 .17409 .61119 .17853 .61639 .17422 Mtetra
.739 .666 .779 r
.60706 .16524 .60189 .1702 .60653 .17409 .61172 .16953 Mtetra
.784 .702 .773 r
.60244 .16155 .5973 .16726 .60189 .1702 .60706 .16524 Mtetra
.856 .753 .748 r
.59785 .15894 .59279 .16608 .5973 .16726 .60244 .16155 Mtetra
.945 .813 .683 r
.59337 .15839 .58841 .16816 .59279 .16608 .59785 .15894 Mtetra
.998 .842 .549 r
.58904 .16159 .58426 .17593 .58841 .16816 .59337 .15839 Mtetra
.959 .809 .371 r
.58498 .1712 .58044 .19228 .58426 .17593 .58904 .16159 Mtetra
.816 .724 .194 r
.58125 .18988 .57686 .21744 .58044 .19228 .58498 .1712 Mtetra
0 0 0 r
.57772 .21624 .57311 .24241 .57686 .21744 .58125 .18988 Mtetra
0 0 .119 r
.57384 .23821 .56848 .24833 .57311 .24241 .57772 .21624 Mtetra
.747 .233 0 r
.56892 .23698 .56281 .22623 .56848 .24833 .57384 .23821 Mtetra
0 0 .344 r
.56305 .20953 .55678 .19018 .56281 .22623 .56892 .23698 Mtetra
0 0 .398 r
.557 .17317 .55101 .15756 .55678 .19018 .56305 .20953 Mtetra
.117 .012 .447 r
.55131 .14285 .54564 .13435 .55101 .15756 .557 .17317 Mtetra
.243 .126 .514 r
.546 .12191 .54055 .11902 .54564 .13435 .55131 .14285 Mtetra
.374 .263 .597 r
.54094 .10809 .53562 .10864 .54055 .11902 .546 .12191 Mtetra
.496 .4 .676 r
.53602 .09857 .53075 .101 .53562 .10864 .54094 .10809 Mtetra
.587 .505 .73 r
.53116 .09138 .52592 .0948 .53075 .101 .53602 .09857 Mtetra
.641 .571 .76 r
.52632 .0854 .52109 .08932 .52592 .0948 .53116 .09138 Mtetra
.671 .607 .776 r
.52149 .08002 .51627 .0842 .52109 .08932 .52632 .0854 Mtetra
.686 .626 .783 r
.51666 .07495 .51144 .07926 .51627 .0842 .52149 .08002 Mtetra
.694 .636 .787 r
.51182 .07003 .5066 .07441 .51144 .07926 .51666 .07495 Mtetra
.698 .641 .789 r
.50698 .06517 .50176 .06958 .5066 .07441 .51182 .07003 Mtetra
.7 .643 .79 r
.50212 .06034 .4969 .06478 .50176 .06958 .50698 .06517 Mtetra
.701 .645 .79 r
.49726 .05552 .49204 .05998 .4969 .06478 .50212 .06034 Mtetra
.701 .645 .791 r
.49239 .0507 .48717 .05517 .49204 .05998 .49726 .05552 Mtetra
.48751 .04588 .48229 .05036 .48717 .05517 .49239 .0507 Mtetra
.701 .646 .791 r
.48263 .04106 .47741 .04554 .48229 .05036 .48751 .04588 Mtetra
.47773 .03622 .47251 .04072 .47741 .04554 .48263 .04106 Mtetra
.92533 .46926 .92018 .47308 .92433 .47719 .92948 .47337 Mtetra
.92116 .46514 .91601 .46897 .92018 .47308 .92533 .46926 Mtetra
.91699 .46102 .91184 .46485 .91601 .46897 .92116 .46514 Mtetra
.91282 .45689 .90766 .46073 .91184 .46485 .91699 .46102 Mtetra
.90864 .45275 .90348 .4566 .90766 .46073 .91282 .45689 Mtetra
.90445 .4486 .89929 .45246 .90348 .4566 .90864 .45275 Mtetra
.90025 .44445 .89509 .44831 .89929 .45246 .90445 .4486 Mtetra
.89605 .4403 .89089 .44416 .89509 .44831 .90025 .44445 Mtetra
.89184 .43613 .88668 .44 .89089 .44416 .89605 .4403 Mtetra
.88762 .43196 .88246 .43584 .88668 .44 .89184 .43613 Mtetra
.8834 .42778 .87824 .43167 .88246 .43584 .88762 .43196 Mtetra
.87917 .4236 .874 .42749 .87824 .43167 .8834 .42778 Mtetra
.87493 .41941 .86977 .42331 .874 .42749 .87917 .4236 Mtetra
.87068 .41521 .86552 .41911 .86977 .42331 .87493 .41941 Mtetra
.86643 .41101 .86127 .41492 .86552 .41911 .87068 .41521 Mtetra
.86218 .4068 .85701 .41071 .86127 .41492 .86643 .41101 Mtetra
.85791 .40258 .85274 .4065 .85701 .41071 .86218 .4068 Mtetra
.85364 .39835 .84847 .40228 .85274 .4065 .85791 .40258 Mtetra
.84936 .39412 .84419 .39806 .84847 .40228 .85364 .39835 Mtetra
.84508 .38988 .83991 .39382 .84419 .39806 .84936 .39412 Mtetra
.84078 .38564 .83561 .38958 .83991 .39382 .84508 .38988 Mtetra
.83648 .38138 .83131 .38534 .83561 .38958 .84078 .38564 Mtetra
.83218 .37712 .827 .38108 .83131 .38534 .83648 .38138 Mtetra
.82786 .37286 .82269 .37682 .827 .38108 .83218 .37712 Mtetra
.82354 .36858 .81837 .37256 .82269 .37682 .82786 .37286 Mtetra
.81921 .3643 .81404 .36828 .81837 .37256 .82354 .36858 Mtetra
.81488 .36002 .8097 .364 .81404 .36828 .81921 .3643 Mtetra
.81054 .35572 .80536 .35971 .8097 .364 .81488 .36002 Mtetra
.80619 .35142 .80101 .35542 .80536 .35971 .81054 .35572 Mtetra
.80183 .34711 .79665 .35112 .80101 .35542 .80619 .35142 Mtetra
.79747 .34279 .79229 .34681 .79665 .35112 .80183 .34711 Mtetra
.7931 .33847 .78792 .34249 .79229 .34681 .79747 .34279 Mtetra
.78872 .33414 .78354 .33817 .78792 .34249 .7931 .33847 Mtetra
.78434 .32981 .77915 .33384 .78354 .33817 .78872 .33414 Mtetra
.77994 .32546 .77476 .3295 .77915 .33384 .78434 .32981 Mtetra
.77555 .32111 .77036 .32516 .77476 .3295 .77994 .32546 Mtetra
.702 .646 .791 r
.77114 .31675 .76595 .32081 .77036 .32516 .77555 .32111 Mtetra
.76673 .31239 .76154 .31645 .76595 .32081 .77114 .31675 Mtetra
.76231 .30802 .75712 .31209 .76154 .31645 .76673 .31239 Mtetra
.75788 .30365 .75269 .30773 .75712 .31209 .76231 .30802 Mtetra
.75344 .29927 .74826 .30336 .75269 .30773 .75788 .30365 Mtetra
.702 .647 .791 r
.749 .2949 .74381 .29899 .74826 .30336 .75344 .29927 Mtetra
.703 .647 .791 r
.74456 .29052 .73937 .29463 .74381 .29899 .749 .2949 Mtetra
.704 .649 .792 r
.7401 .28616 .73492 .29029 .73937 .29463 .74456 .29052 Mtetra
.705 .651 .792 r
.73565 .28182 .73046 .28597 .73492 .29029 .7401 .28616 Mtetra
.708 .654 .793 r
.73119 .27753 .72601 .28171 .73046 .28597 .73565 .28182 Mtetra
.712 .659 .795 r
.72674 .27331 .72155 .27754 .72601 .28171 .73119 .27753 Mtetra
.719 .667 .798 r
.72229 .26921 .71711 .27351 .72155 .27754 .72674 .27331 Mtetra
.731 .681 .802 r
.71786 .26532 .71269 .26974 .71711 .27351 .72229 .26921 Mtetra
.749 .703 .808 r
.71346 .26176 .70831 .26637 .71269 .26974 .71786 .26532 Mtetra
.778 .74 .818 r
.70911 .25874 .70398 .26363 .70831 .26637 .71346 .26176 Mtetra
.823 .797 .828 r
.70484 .25655 .69975 .26188 .70398 .26363 .70911 .25874 Mtetra
.881 .88 .829 r
.70069 .25562 .69566 .26157 .69975 .26188 .70484 .25655 Mtetra
.922 .965 .782 r
.69672 .25646 .69174 .26323 .69566 .26157 .70069 .25562 Mtetra
.86 .963 .629 r
.69295 .25955 .68804 .26724 .69174 .26323 .69672 .25646 Mtetra
.686 .843 .42 r
.68937 .26493 .6845 .27334 .68804 .26724 .69295 .25955 Mtetra
0 0 0 r
.68588 .2716 .68095 .27994 .6845 .27334 .68937 .26493 Mtetra
.6822 .27698 .67709 .28396 .68095 .27994 .68588 .2716 Mtetra
.765 .992 .88 r
.678 .27758 .67263 .28205 .67709 .28396 .6822 .27698 Mtetra
.533 .521 .787 r
.6731 .27114 .6675 .27302 .67263 .28205 .678 .27758 Mtetra
.415 .319 .637 r
.66764 .25853 .66193 .25887 .6675 .27302 .6731 .27114 Mtetra
.401 .277 .594 r
.66194 .24297 .65625 .24309 .66193 .25887 .66764 .25853 Mtetra
.422 .289 .594 r
.65631 .22769 .65072 .22842 .65625 .24309 .66194 .24297 Mtetra
.46 .329 .615 r
.65089 .21441 .64541 .21604 .65072 .22842 .65631 .22769 Mtetra
.506 .384 .648 r
.6457 .2035 .64032 .20595 .64541 .21604 .65089 .21441 Mtetra
.555 .446 .684 r
.64071 .19462 .63538 .1977 .64032 .20595 .6457 .2035 Mtetra
.599 .503 .716 r
.63584 .18724 .63056 .19076 .63538 .1977 .64071 .19462 Mtetra
.634 .55 .742 r
.63105 .18089 .6258 .18472 .63056 .19076 .63584 .18724 Mtetra
.66 .585 .759 r
.62632 .17523 .62109 .17926 .6258 .18472 .63105 .18089 Mtetra
.68 .61 .771 r
.62162 .17001 .61639 .17422 .62109 .17926 .62632 .17523 Mtetra
.698 .631 .778 r
.61693 .16513 .61172 .16953 .61639 .17422 .62162 .17001 Mtetra
.719 .65 .781 r
.61226 .16057 .60706 .16524 .61172 .16953 .61693 .16513 Mtetra
.75 .676 .779 r
.60761 .15641 .60244 .16155 .60706 .16524 .61226 .16057 Mtetra
.801 .714 .769 r
.60298 .15294 .59785 .15894 .60244 .16155 .60761 .15641 Mtetra
.879 .769 .737 r
.59842 .15073 .59337 .15839 .59785 .15894 .60298 .15294 Mtetra
.965 .826 .656 r
.59396 .15089 .58904 .16159 .59337 .15839 .59842 .15073 Mtetra
.998 .84 .506 r
.5897 .15538 .58498 .1712 .58904 .16159 .59396 .15089 Mtetra
.932 .792 .325 r
.58573 .167 .58125 .18988 .58498 .1712 .5897 .15538 Mtetra
.76 .693 .149 r
.5821 .18794 .57772 .21624 .58125 .18988 .58573 .167 Mtetra
0 0 .021 r
.57858 .21474 .57384 .23821 .57772 .21624 .5821 .18794 Mtetra
.138 0 .128 r
.5745 .23241 .56892 .23698 .57384 .23821 .57858 .21474 Mtetra
.769 .328 0 r
.56928 .22385 .56305 .20953 .56892 .23698 .5745 .23241 Mtetra
0 0 .363 r
.56326 .1923 .557 .17317 .56305 .20953 .56928 .22385 Mtetra
.01 0 .409 r
.55724 .15663 .55131 .14285 .557 .17317 .56326 .1923 Mtetra
.148 .037 .461 r
.55162 .12874 .546 .12191 .55131 .14285 .55724 .15663 Mtetra
.275 .158 .533 r
.54637 .1099 .54094 .10809 .546 .12191 .55162 .12874 Mtetra
.406 .298 .618 r
.54134 .09741 .53602 .09857 .54094 .10809 .54637 .1099 Mtetra
.522 .43 .692 r
.53643 .08862 .53116 .09138 .53602 .09857 .54134 .09741 Mtetra
.603 .525 .739 r
.53157 .08181 .52632 .0854 .53116 .09138 .53643 .08862 Mtetra
.65 .582 .765 r
.52672 .07601 .52149 .08002 .52632 .0854 .53157 .08181 Mtetra
.676 .613 .778 r
.52189 .07072 .51666 .07495 .52149 .08002 .52672 .07601 Mtetra
.689 .63 .785 r
.51705 .06568 .51182 .07003 .51666 .07495 .52189 .07072 Mtetra
.695 .638 .788 r
.5122 .06076 .50698 .06517 .51182 .07003 .51705 .06568 Mtetra
.698 .642 .789 r
.50735 .0559 .50212 .06034 .50698 .06517 .5122 .06076 Mtetra
.7 .644 .79 r
.50249 .05106 .49726 .05552 .50212 .06034 .50735 .0559 Mtetra
.701 .645 .79 r
.49762 .04623 .49239 .0507 .49726 .05552 .50249 .05106 Mtetra
.701 .645 .791 r
.49274 .0414 .48751 .04588 .49239 .0507 .49762 .04623 Mtetra
.48786 .03656 .48263 .04106 .48751 .04588 .49274 .0414 Mtetra
.701 .646 .791 r
.48296 .03172 .47773 .03622 .48263 .04106 .48786 .03656 Mtetra
.93048 .46543 .92533 .46926 .92948 .47337 .93464 .46955 Mtetra
.92632 .46131 .92116 .46514 .92533 .46926 .93048 .46543 Mtetra
.92215 .45718 .91699 .46102 .92116 .46514 .92632 .46131 Mtetra
.91798 .45304 .91282 .45689 .91699 .46102 .92215 .45718 Mtetra
.9138 .44889 .90864 .45275 .91282 .45689 .91798 .45304 Mtetra
.90961 .44474 .90445 .4486 .90864 .45275 .9138 .44889 Mtetra
.90541 .44059 .90025 .44445 .90445 .4486 .90961 .44474 Mtetra
.90121 .43642 .89605 .4403 .90025 .44445 .90541 .44059 Mtetra
.897 .43225 .89184 .43613 .89605 .4403 .90121 .43642 Mtetra
.89279 .42808 .88762 .43196 .89184 .43613 .897 .43225 Mtetra
.88856 .42389 .8834 .42778 .88762 .43196 .89279 .42808 Mtetra
.88433 .4197 .87917 .4236 .8834 .42778 .88856 .42389 Mtetra
.8801 .41551 .87493 .41941 .87917 .4236 .88433 .4197 Mtetra
.87586 .4113 .87068 .41521 .87493 .41941 .8801 .41551 Mtetra
.87161 .40709 .86643 .41101 .87068 .41521 .87586 .4113 Mtetra
.86735 .40287 .86218 .4068 .86643 .41101 .87161 .40709 Mtetra
.86308 .39865 .85791 .40258 .86218 .4068 .86735 .40287 Mtetra
.85881 .39442 .85364 .39835 .85791 .40258 .86308 .39865 Mtetra
.85454 .39018 .84936 .39412 .85364 .39835 .85881 .39442 Mtetra
.85025 .38593 .84508 .38988 .84936 .39412 .85454 .39018 Mtetra
.84596 .38168 .84078 .38564 .84508 .38988 .85025 .38593 Mtetra
.84166 .37742 .83648 .38138 .84078 .38564 .84596 .38168 Mtetra
.83736 .37316 .83218 .37712 .83648 .38138 .84166 .37742 Mtetra
.83304 .36888 .82786 .37286 .83218 .37712 .83736 .37316 Mtetra
.82872 .3646 .82354 .36858 .82786 .37286 .83304 .36888 Mtetra
.8244 .36032 .81921 .3643 .82354 .36858 .82872 .3646 Mtetra
.82006 .35602 .81488 .36002 .81921 .3643 .8244 .36032 Mtetra
.81572 .35172 .81054 .35572 .81488 .36002 .82006 .35602 Mtetra
.81137 .34741 .80619 .35142 .81054 .35572 .81572 .35172 Mtetra
.80702 .3431 .80183 .34711 .80619 .35142 .81137 .34741 Mtetra
.80266 .33877 .79747 .34279 .80183 .34711 .80702 .3431 Mtetra
.79829 .33445 .7931 .33847 .79747 .34279 .80266 .33877 Mtetra
.79391 .33011 .78872 .33414 .7931 .33847 .79829 .33445 Mtetra
.78953 .32577 .78434 .32981 .78872 .33414 .79391 .33011 Mtetra
.78514 .32142 .77994 .32546 .78434 .32981 .78953 .32577 Mtetra
.78074 .31706 .77555 .32111 .77994 .32546 .78514 .32142 Mtetra
.702 .646 .791 r
.77633 .31269 .77114 .31675 .77555 .32111 .78074 .31706 Mtetra
.77192 .30832 .76673 .31239 .77114 .31675 .77633 .31269 Mtetra
.7675 .30395 .76231 .30802 .76673 .31239 .77192 .30832 Mtetra
.76307 .29957 .75788 .30365 .76231 .30802 .7675 .30395 Mtetra
.75864 .29518 .75344 .29927 .75788 .30365 .76307 .29957 Mtetra
.702 .647 .791 r
.7542 .29079 .749 .2949 .75344 .29927 .75864 .29518 Mtetra
.703 .647 .791 r
.74975 .28641 .74456 .29052 .749 .2949 .7542 .29079 Mtetra
.703 .648 .792 r
.7453 .28203 .7401 .28616 .74456 .29052 .74975 .28641 Mtetra
.705 .65 .792 r
.74084 .27768 .73565 .28182 .7401 .28616 .7453 .28203 Mtetra
.707 .652 .793 r
.73639 .27335 .73119 .27753 .73565 .28182 .74084 .27768 Mtetra
.71 .656 .794 r
.73193 .26909 .72674 .27331 .73119 .27753 .73639 .27335 Mtetra
.716 .663 .797 r
.72748 .26492 .72229 .26921 .72674 .27331 .73193 .26909 Mtetra
.726 .675 .8 r
.72304 .26093 .71786 .26532 .72229 .26921 .72748 .26492 Mtetra
.741 .694 .806 r
.71862 .25722 .71346 .26176 .71786 .26532 .72304 .26093 Mtetra
.766 .724 .814 r
.71425 .25396 .70911 .25874 .71346 .26176 .71862 .25722 Mtetra
.804 .773 .824 r
.70995 .2514 .70484 .25655 .70911 .25874 .71425 .25396 Mtetra
.859 .847 .831 r
.70576 .24993 .70069 .25562 .70484 .25655 .70995 .2514 Mtetra
.913 .937 .809 r
.70172 .25002 .69672 .25646 .70069 .25562 .70576 .24993 Mtetra
.9 .98 .7 r
.69788 .2522 .69295 .25955 .69672 .25646 .70172 .25002 Mtetra
.756 .894 .495 r
.69426 .25674 .68937 .26493 .69295 .25955 .69788 .2522 Mtetra
0 0 0 r
.69078 .2631 .68588 .2716 .68937 .26493 .69426 .25674 Mtetra
.68722 .26932 .6822 .27698 .68588 .2716 .69078 .2631 Mtetra
.674 .938 .657 r
.68327 .27208 .678 .27758 .6822 .27698 .68722 .26932 Mtetra
.64 .699 .889 r
.67863 .26835 .6731 .27114 .678 .27758 .68327 .27208 Mtetra
.44 .364 .675 r
.67333 .25776 .66764 .25853 .6731 .27114 .67863 .26835 Mtetra
.401 .284 .604 r
.66766 .24289 .66194 .24297 .66764 .25853 .67333 .25776 Mtetra
.412 .281 .591 r
.66195 .22722 .65631 .22769 .66194 .24297 .66766 .24289 Mtetra
.444 .312 .605 r
.65642 .2131 .65089 .21441 .65631 .22769 .66195 .22722 Mtetra
.488 .362 .635 r
.65114 .20132 .6457 .2035 .65089 .21441 .65642 .2131 Mtetra
.537 .423 .671 r
.64606 .19174 .64071 .19462 .6457 .2035 .65114 .20132 Mtetra
.583 .482 .705 r
.64114 .18386 .63584 .18724 .64071 .19462 .64606 .19174 Mtetra
.622 .533 .733 r
.63632 .17717 .63105 .18089 .63584 .18724 .64114 .18386 Mtetra
.651 .572 .754 r
.63157 .17126 .62632 .17523 .63105 .18089 .63632 .17717 Mtetra
.672 .601 .767 r
.62685 .16587 .62162 .17001 .62632 .17523 .63157 .17126 Mtetra
.689 .622 .776 r
.62215 .16084 .61693 .16513 .62162 .17001 .62685 .16587 Mtetra
.705 .639 .78 r
.61747 .15609 .61226 .16057 .61693 .16513 .62215 .16084 Mtetra
.727 .658 .782 r
.6128 .15164 .60761 .15641 .61226 .16057 .61747 .15609 Mtetra
.761 .685 .778 r
.60815 .14763 .60298 .15294 .60761 .15641 .6128 .15164 Mtetra
.818 .727 .764 r
.60354 .14439 .59842 .15073 .60298 .15294 .60815 .14763 Mtetra
.902 .785 .723 r
.59899 .14263 .59396 .15089 .59842 .15073 .60354 .14439 Mtetra
.982 .836 .624 r
.59458 .14362 .5897 .15538 .59396 .15089 .59899 .14263 Mtetra
.991 .833 .46 r
.59038 .14957 .58573 .167 .5897 .15538 .59458 .14362 Mtetra
.899 .771 .279 r
.58652 .16335 .5821 .18794 .58573 .167 .59038 .14957 Mtetra
0 0 0 r
.58298 .18637 .57858 .21474 .5821 .18794 .58652 .16335 Mtetra
0 0 .057 r
.57942 .21261 .5745 .23241 .57858 .21474 .58298 .18637 Mtetra
.328 0 .114 r
.5751 .22479 .56928 .22385 .5745 .23241 .57942 .21261 Mtetra
0 0 .27 r
.56959 .20918 .56326 .1923 .56928 .22385 .5751 .22479 Mtetra
0 0 .376 r
.56346 .1749 .55724 .15663 .56326 .1923 .56959 .20918 Mtetra
.048 0 .42 r
.55749 .14064 .55162 .12874 .55724 .15663 .56346 .1749 Mtetra
.178 .064 .477 r
.55194 .11522 .54637 .1099 .55162 .12874 .55749 .14064 Mtetra
.307 .191 .554 r
.54674 .09828 .54134 .09741 .54637 .1099 .55194 .11522 Mtetra
.437 .333 .638 r
.54174 .08694 .53643 .08862 .54134 .09741 .54674 .09828 Mtetra
.546 .458 .706 r
.53684 .07877 .53157 .08181 .53643 .08862 .54174 .08694 Mtetra
.618 .543 .748 r
.53198 .07227 .52672 .07601 .53157 .08181 .53684 .07877 Mtetra
.658 .592 .769 r
.52713 .06662 .52189 .07072 .52672 .07601 .53198 .07227 Mtetra
.68 .619 .78 r
.52229 .0614 .51705 .06568 .52189 .07072 .52713 .06662 Mtetra
.691 .632 .786 r
.51744 .05639 .5122 .06076 .51705 .06568 .52229 .0614 Mtetra
.696 .639 .788 r
.51259 .05147 .50735 .0559 .5122 .06076 .51744 .05639 Mtetra
.699 .642 .79 r
.50773 .04661 .50249 .05106 .50735 .0559 .51259 .05147 Mtetra
.7 .644 .79 r
.50286 .04176 .49762 .04623 .50249 .05106 .50773 .04661 Mtetra
.701 .645 .79 r
.49798 .03691 .49274 .0414 .49762 .04623 .50286 .04176 Mtetra
.701 .645 .791 r
.4931 .03206 .48786 .03656 .49274 .0414 .49798 .03691 Mtetra
.4882 .02721 .48296 .03172 .48786 .03656 .4931 .03206 Mtetra
.93565 .4616 .93048 .46543 .93464 .46955 .9398 .46572 Mtetra
.701 .646 .791 r
.93149 .45747 .92632 .46131 .93048 .46543 .93565 .4616 Mtetra
.92732 .45333 .92215 .45718 .92632 .46131 .93149 .45747 Mtetra
.92315 .44919 .91798 .45304 .92215 .45718 .92732 .45333 Mtetra
.91897 .44504 .9138 .44889 .91798 .45304 .92315 .44919 Mtetra
.91478 .44088 .90961 .44474 .9138 .44889 .91897 .44504 Mtetra
.91058 .43672 .90541 .44059 .90961 .44474 .91478 .44088 Mtetra
.90638 .43255 .90121 .43642 .90541 .44059 .91058 .43672 Mtetra
.90218 .42837 .897 .43225 .90121 .43642 .90638 .43255 Mtetra
.89796 .42419 .89279 .42808 .897 .43225 .90218 .42837 Mtetra
.89374 .42 .88856 .42389 .89279 .42808 .89796 .42419 Mtetra
.88951 .4158 .88433 .4197 .88856 .42389 .89374 .42 Mtetra
.88528 .4116 .8801 .41551 .88433 .4197 .88951 .4158 Mtetra
.88103 .40739 .87586 .4113 .8801 .41551 .88528 .4116 Mtetra
.87678 .40317 .87161 .40709 .87586 .4113 .88103 .40739 Mtetra
.87253 .39894 .86735 .40287 .87161 .40709 .87678 .40317 Mtetra
.86827 .39471 .86308 .39865 .86735 .40287 .87253 .39894 Mtetra
.864 .39048 .85881 .39442 .86308 .39865 .86827 .39471 Mtetra
.85972 .38623 .85454 .39018 .85881 .39442 .864 .39048 Mtetra
.85544 .38198 .85025 .38593 .85454 .39018 .85972 .38623 Mtetra
.85115 .37772 .84596 .38168 .85025 .38593 .85544 .38198 Mtetra
.84685 .37345 .84166 .37742 .84596 .38168 .85115 .37772 Mtetra
.84254 .36918 .83736 .37316 .84166 .37742 .84685 .37345 Mtetra
.83823 .3649 .83304 .36888 .83736 .37316 .84254 .36918 Mtetra
.83391 .36062 .82872 .3646 .83304 .36888 .83823 .3649 Mtetra
.82959 .35632 .8244 .36032 .82872 .3646 .83391 .36062 Mtetra
.82525 .35202 .82006 .35602 .8244 .36032 .82959 .35632 Mtetra
.82091 .34771 .81572 .35172 .82006 .35602 .82525 .35202 Mtetra
.81657 .3434 .81137 .34741 .81572 .35172 .82091 .34771 Mtetra
.81221 .33908 .80702 .3431 .81137 .34741 .81657 .3434 Mtetra
.80785 .33475 .80266 .33877 .80702 .3431 .81221 .33908 Mtetra
.80348 .33041 .79829 .33445 .80266 .33877 .80785 .33475 Mtetra
.79911 .32607 .79391 .33011 .79829 .33445 .80348 .33041 Mtetra
.79472 .32172 .78953 .32577 .79391 .33011 .79911 .32607 Mtetra
.79033 .31736 .78514 .32142 .78953 .32577 .79472 .32172 Mtetra
.78594 .313 .78074 .31706 .78514 .32142 .79033 .31736 Mtetra
.78153 .30863 .77633 .31269 .78074 .31706 .78594 .313 Mtetra
.702 .646 .791 r
.77712 .30425 .77192 .30832 .77633 .31269 .78153 .30863 Mtetra
.7727 .29987 .7675 .30395 .77192 .30832 .77712 .30425 Mtetra
.76828 .29548 .76307 .29957 .7675 .30395 .7727 .29987 Mtetra
.76384 .29108 .75864 .29518 .76307 .29957 .76828 .29548 Mtetra
.7594 .28669 .7542 .29079 .75864 .29518 .76384 .29108 Mtetra
.702 .647 .791 r
.75496 .28229 .74975 .28641 .7542 .29079 .7594 .28669 Mtetra
.703 .648 .791 r
.75051 .2779 .7453 .28203 .74975 .28641 .75496 .28229 Mtetra
.704 .649 .792 r
.74605 .27353 .74084 .27768 .7453 .28203 .75051 .2779 Mtetra
.706 .651 .793 r
.74159 .26918 .73639 .27335 .74084 .27768 .74605 .27353 Mtetra
.709 .655 .794 r
.73713 .26488 .73193 .26909 .73639 .27335 .74159 .26918 Mtetra
.714 .66 .796 r
.73267 .26066 .72748 .26492 .73193 .26909 .73713 .26488 Mtetra
.722 .67 .799 r
.72823 .25658 .72304 .26093 .72748 .26492 .73267 .26066 Mtetra
.734 .685 .803 r
.7238 .25274 .71862 .25722 .72304 .26093 .72823 .25658 Mtetra
.755 .711 .811 r
.71941 .24927 .71425 .25396 .71862 .25722 .7238 .25274 Mtetra
.788 .752 .82 r
.71508 .2464 .70995 .2514 .71425 .25396 .71941 .24927 Mtetra
.837 .816 .83 r
.71085 .24445 .70576 .24993 .70995 .2514 .71508 .2464 Mtetra
.896 .904 .824 r
.70675 .24388 .70172 .25002 .70576 .24993 .71085 .24445 Mtetra
.92 .977 .755 r
.70284 .2452 .69788 .2522 .70172 .25002 .70675 .24388 Mtetra
.822 .94 .576 r
.69916 .24883 .69426 .25674 .69788 .2522 .70284 .2452 Mtetra
.641 .809 .376 r
.69566 .25461 .69078 .2631 .69426 .25674 .69916 .24883 Mtetra
0 0 0 r
.69219 .26119 .68722 .26932 .69078 .2631 .69566 .25461 Mtetra
.575 .831 .466 r
.68844 .26564 .68327 .27208 .68722 .26932 .69219 .26119 Mtetra
.752 .915 .946 r
.68408 .26455 .67863 .26835 .68327 .27208 .68844 .26564 Mtetra
.486 .442 .733 r
.679 .25636 .67333 .25776 .67863 .26835 .68408 .26455 Mtetra
.407 .3 .62 r
.6734 .24268 .66766 .24289 .67333 .25776 .679 .25636 Mtetra
.404 .277 .592 r
.66764 .22697 .66195 .22722 .66766 .24289 .6734 .24268 Mtetra
.43 .297 .598 r
.66201 .21211 .65642 .2131 .66195 .22722 .66764 .22697 Mtetra
.471 .341 .623 r
.65662 .19944 .65114 .20132 .65642 .2131 .66201 .21211 Mtetra
.519 .399 .657 r
.65146 .1891 .64606 .19174 .65114 .20132 .65662 .19944 Mtetra
.567 .46 .693 r
.64647 .18064 .64114 .18386 .64606 .19174 .65146 .1891 Mtetra
.608 .515 .724 r
.64162 .17354 .63632 .17717 .64114 .18386 .64647 .18064 Mtetra
.64 .559 .747 r
.63683 .16737 .63157 .17126 .63632 .17717 .64162 .17354 Mtetra
.664 .591 .763 r
.6321 .1618 .62685 .16587 .63157 .17126 .63683 .16737 Mtetra
.681 .613 .773 r
.62739 .15662 .62215 .16084 .62685 .16587 .6321 .1618 Mtetra
.696 .631 .779 r
.6227 .15172 .61747 .15609 .62215 .16084 .62739 .15662 Mtetra
.712 .646 .782 r
.61802 .14707 .6128 .15164 .61747 .15609 .6227 .15172 Mtetra
.735 .666 .782 r
.61335 .14273 .60815 .14763 .6128 .15164 .61802 .14707 Mtetra
.774 .695 .777 r
.6087 .13887 .60354 .14439 .60815 .14763 .61335 .14273 Mtetra
.838 .741 .758 r
.6041 .13591 .59899 .14263 .60354 .14439 .6087 .13887 Mtetra
.925 .801 .705 r
.59958 .13466 .59458 .14362 .59899 .14263 .6041 .13591 Mtetra
.993 .841 .587 r
.59521 .13663 .59038 .14957 .59458 .14362 .59958 .13466 Mtetra
.977 .822 .413 r
.5911 .1442 .58652 .16335 .59038 .14957 .59521 .13663 Mtetra
.86 .748 .234 r
.58734 .16023 .58298 .18637 .58652 .16335 .5911 .1442 Mtetra
0 0 0 r
.58387 .18498 .57942 .21261 .58298 .18637 .58734 .16023 Mtetra
0 0 .087 r
.58023 .20953 .5751 .22479 .57942 .21261 .58387 .18498 Mtetra
.547 .063 .06 r
.57562 .21525 .56959 .20918 .5751 .22479 .58023 .20953 Mtetra
0 0 .322 r
.56985 .1933 .56346 .1749 .56959 .20918 .57562 .21525 Mtetra
0 0 .387 r
.56366 .15757 .55749 .14064 .56346 .1749 .56985 .1933 Mtetra
.082 0 .432 r
.55776 .12526 .55194 .11522 .55749 .14064 .56366 .15757 Mtetra
.209 .093 .494 r
.55229 .10223 .54674 .09828 .55194 .11522 .55776 .12526 Mtetra
.34 .226 .575 r
.54713 .08699 .54174 .08694 .54674 .09828 .55229 .10223 Mtetra
.467 .367 .658 r
.54215 .07664 .53684 .07877 .54174 .08694 .54713 .08699 Mtetra
.567 .483 .719 r
.53725 .06899 .53198 .07227 .53684 .07877 .54215 .07664 Mtetra
.63 .558 .755 r
.53239 .06275 .52713 .06662 .53198 .07227 .53725 .06899 Mtetra
.665 .6 .773 r
.52754 .05723 .52229 .0614 .52713 .06662 .53239 .06275 Mtetra
.683 .623 .782 r
.52269 .05206 .51744 .05639 .52229 .0614 .52754 .05723 Mtetra
.692 .634 .787 r
.51783 .04707 .51259 .05147 .51744 .05639 .52269 .05206 Mtetra
.697 .64 .789 r
.51297 .04216 .50773 .04661 .51259 .05147 .51783 .04707 Mtetra
.699 .643 .79 r
.50811 .03728 .50286 .04176 .50773 .04661 .51297 .04216 Mtetra
.7 .644 .79 r
.50323 .03242 .49798 .03691 .50286 .04176 .50811 .03728 Mtetra
.701 .645 .791 r
.49835 .02756 .4931 .03206 .49798 .03691 .50323 .03242 Mtetra
.49345 .0227 .4882 .02721 .4931 .03206 .49835 .02756 Mtetra
.94082 .45776 .93565 .4616 .9398 .46572 .94498 .46189 Mtetra
.701 .646 .791 r
.93666 .45362 .93149 .45747 .93565 .4616 .94082 .45776 Mtetra
.9325 .44948 .92732 .45333 .93149 .45747 .93666 .45362 Mtetra
.92832 .44533 .92315 .44919 .92732 .45333 .9325 .44948 Mtetra
.92414 .44117 .91897 .44504 .92315 .44919 .92832 .44533 Mtetra
.91996 .43701 .91478 .44088 .91897 .44504 .92414 .44117 Mtetra
.91576 .43284 .91058 .43672 .91478 .44088 .91996 .43701 Mtetra
.91156 .42866 .90638 .43255 .91058 .43672 .91576 .43284 Mtetra
.90736 .42448 .90218 .42837 .90638 .43255 .91156 .42866 Mtetra
.90314 .42029 .89796 .42419 .90218 .42837 .90736 .42448 Mtetra
.89892 .41609 .89374 .42 .89796 .42419 .90314 .42029 Mtetra
.8947 .41189 .88951 .4158 .89374 .42 .89892 .41609 Mtetra
.89046 .40768 .88528 .4116 .88951 .4158 .8947 .41189 Mtetra
.88622 .40346 .88103 .40739 .88528 .4116 .89046 .40768 Mtetra
.88197 .39924 .87678 .40317 .88103 .40739 .88622 .40346 Mtetra
.87772 .39501 .87253 .39894 .87678 .40317 .88197 .39924 Mtetra
.87346 .39077 .86827 .39471 .87253 .39894 .87772 .39501 Mtetra
.86919 .38653 .864 .39048 .86827 .39471 .87346 .39077 Mtetra
.86491 .38228 .85972 .38623 .864 .39048 .86919 .38653 Mtetra
.86063 .37802 .85544 .38198 .85972 .38623 .86491 .38228 Mtetra
.85634 .37375 .85115 .37772 .85544 .38198 .86063 .37802 Mtetra
.85204 .36948 .84685 .37345 .85115 .37772 .85634 .37375 Mtetra
.84774 .3652 .84254 .36918 .84685 .37345 .85204 .36948 Mtetra
.84343 .36092 .83823 .3649 .84254 .36918 .84774 .3652 Mtetra
.83911 .35662 .83391 .36062 .83823 .3649 .84343 .36092 Mtetra
.83479 .35232 .82959 .35632 .83391 .36062 .83911 .35662 Mtetra
.83045 .34802 .82525 .35202 .82959 .35632 .83479 .35232 Mtetra
.82611 .3437 .82091 .34771 .82525 .35202 .83045 .34802 Mtetra
.82177 .33938 .81657 .3434 .82091 .34771 .82611 .3437 Mtetra
.81742 .33505 .81221 .33908 .81657 .3434 .82177 .33938 Mtetra
.81305 .33072 .80785 .33475 .81221 .33908 .81742 .33505 Mtetra
.80869 .32637 .80348 .33041 .80785 .33475 .81305 .33072 Mtetra
.80431 .32202 .79911 .32607 .80348 .33041 .80869 .32637 Mtetra
.79993 .31767 .79472 .32172 .79911 .32607 .80431 .32202 Mtetra
.79554 .3133 .79033 .31736 .79472 .32172 .79993 .31767 Mtetra
.79114 .30893 .78594 .313 .79033 .31736 .79554 .3133 Mtetra
.78674 .30456 .78153 .30863 .78594 .313 .79114 .30893 Mtetra
.702 .646 .791 r
.78233 .30017 .77712 .30425 .78153 .30863 .78674 .30456 Mtetra
.77791 .29578 .7727 .29987 .77712 .30425 .78233 .30017 Mtetra
.77349 .29138 .76828 .29548 .7727 .29987 .77791 .29578 Mtetra
.76905 .28698 .76384 .29108 .76828 .29548 .77349 .29138 Mtetra
.76462 .28258 .7594 .28669 .76384 .29108 .76905 .28698 Mtetra
.702 .647 .791 r
.76017 .27817 .75496 .28229 .7594 .28669 .76462 .28258 Mtetra
.703 .647 .791 r
.75572 .27377 .75051 .2779 .75496 .28229 .76017 .27817 Mtetra
.704 .648 .792 r
.75126 .26938 .74605 .27353 .75051 .2779 .75572 .27377 Mtetra
.705 .65 .792 r
.7468 .26501 .74159 .26918 .74605 .27353 .75126 .26938 Mtetra
.708 .653 .793 r
.74234 .26067 .73713 .26488 .74159 .26918 .7468 .26501 Mtetra
.712 .658 .795 r
.73788 .25641 .73267 .26066 .73713 .26488 .74234 .26067 Mtetra
.718 .666 .797 r
.73343 .25226 .72823 .25658 .73267 .26066 .73788 .25641 Mtetra
.729 .679 .801 r
.72899 .24831 .7238 .25274 .72823 .25658 .73343 .25226 Mtetra
.746 .7 .808 r
.72458 .24466 .71941 .24927 .7238 .25274 .72899 .24831 Mtetra
.774 .734 .816 r
.72023 .24152 .71508 .2464 .71941 .24927 .72458 .24466 Mtetra
.816 .789 .827 r
.71596 .23917 .71085 .24445 .71508 .2464 .72023 .24152 Mtetra
.874 .869 .83 r
.71181 .238 .70675 .24388 .71085 .24445 .71596 .23917 Mtetra
.921 .957 .793 r
.70783 .23853 .70284 .2452 .70675 .24388 .71181 .238 Mtetra
.875 .97 .654 r
.70408 .24124 .69916 .24883 .70284 .2452 .70783 .23853 Mtetra
.708 .859 .443 r
.70054 .24627 .69566 .25461 .69916 .24883 .70408 .24124 Mtetra
0 0 0 r
.69711 .25278 .69219 .26119 .69566 .25461 .70054 .24627 Mtetra
.69353 .25841 .68844 .26564 .69219 .26119 .69711 .25278 Mtetra
.747 .992 .815 r
.68944 .25971 .68408 .26455 .68844 .26564 .69353 .25841 Mtetra
.565 .572 .819 r
.68462 .25415 .679 .25636 .68408 .26455 .68944 .25971 Mtetra
.422 .332 .648 r
.67915 .24218 .6734 .24268 .679 .25636 .68462 .25415 Mtetra
.401 .278 .597 r
.67339 .22683 .66764 .22697 .6734 .24268 .67915 .24218 Mtetra
.418 .286 .593 r
.66766 .21142 .66201 .21211 .66764 .22697 .67339 .22683 Mtetra
.454 .323 .612 r
.66215 .19788 .65662 .19944 .66201 .21211 .66766 .21142 Mtetra
.5 .377 .643 r
.65689 .1867 .65146 .1891 .65662 .19944 .66215 .19788 Mtetra
.549 .438 .68 r
.65184 .1776 .64647 .18064 .65146 .1891 .65689 .1867 Mtetra
.593 .496 .713 r
.64693 .17004 .64162 .17354 .64647 .18064 .65184 .1776 Mtetra
.629 .544 .739 r
.64212 .16356 .63683 .16737 .64162 .17354 .64693 .17004 Mtetra
.656 .58 .758 r
.63736 .15778 .6321 .1618 .63683 .16737 .64212 .16356 Mtetra
.674 .605 .77 r
.63264 .15245 .62739 .15662 .6321 .1618 .63736 .15778 Mtetra
.689 .623 .778 r
.62794 .14743 .6227 .15172 .62739 .15662 .63264 .15245 Mtetra
.702 .638 .782 r
.62325 .14264 .61802 .14707 .6227 .15172 .62794 .14743 Mtetra
.718 .653 .784 r
.61857 .13807 .61335 .14273 .61802 .14707 .62325 .14264 Mtetra
.744 .673 .782 r
.6139 .13383 .6087 .13887 .61335 .14273 .61857 .13807 Mtetra
.787 .706 .774 r
.60926 .13014 .6041 .13591 .6087 .13887 .6139 .13383 Mtetra
.858 .756 .749 r
.60467 .1275 .59958 .13466 .6041 .13591 .60926 .13014 Mtetra
.947 .815 .682 r
.60018 .12686 .59521 .13663 .59958 .13466 .60467 .1275 Mtetra
.999 .843 .546 r
.59587 .12993 .5911 .1442 .59521 .13663 .60018 .12686 Mtetra
.956 .807 .366 r
.59185 .13932 .58734 .16023 .5911 .1442 .59587 .12993 Mtetra
.813 .721 .189 r
.5882 .15765 .58387 .18498 .58734 .16023 .59185 .13932 Mtetra
0 0 0 r
.58478 .18356 .58023 .20953 .58387 .18498 .5882 .15765 Mtetra
0 0 .108 r
.58099 .20515 .57562 .21525 .58023 .20953 .58478 .18356 Mtetra
.737 .216 0 r
.57606 .2038 .56985 .1933 .57562 .21525 .58099 .20515 Mtetra
0 0 .348 r
.57007 .17657 .56366 .15757 .56985 .1933 .57606 .2038 Mtetra
0 0 .397 r
.56387 .14056 .55776 .12526 .56366 .15757 .57007 .17657 Mtetra
.114 .008 .445 r
.55804 .11051 .55229 .10223 .55776 .12526 .56387 .14056 Mtetra
.24 .123 .512 r
.55264 .08973 .54713 .08699 .55229 .10223 .55804 .11051 Mtetra
.372 .261 .596 r
.54752 .07599 .54215 .07664 .54713 .08699 .55264 .08973 Mtetra
.496 .399 .675 r
.54256 .06648 .53725 .06899 .54215 .07664 .54752 .07599 Mtetra
.586 .505 .73 r
.53767 .05927 .53239 .06275 .53725 .06899 .54256 .06648 Mtetra
.641 .571 .76 r
.5328 .05325 .52754 .05723 .53239 .06275 .53767 .05927 Mtetra
.671 .607 .776 r
.52795 .04783 .52269 .05206 .52754 .05723 .5328 .05325 Mtetra
.686 .626 .783 r
.52309 .0427 .51783 .04707 .52269 .05206 .52795 .04783 Mtetra
.694 .636 .787 r
.51823 .03772 .51297 .04216 .51783 .04707 .52309 .0427 Mtetra
.698 .641 .789 r
.51336 .03281 .50811 .03728 .51297 .04216 .51823 .03772 Mtetra
.7 .643 .79 r
.50849 .02793 .50323 .03242 .50811 .03728 .51336 .03281 Mtetra
.701 .645 .79 r
.5036 .02305 .49835 .02756 .50323 .03242 .50849 .02793 Mtetra
.701 .645 .791 r
.49871 .01818 .49345 .0227 .49835 .02756 .5036 .02305 Mtetra
.94601 .45392 .94082 .45776 .94498 .46189 .95016 .45806 Mtetra
.94185 .44977 .93666 .45362 .94082 .45776 .94601 .45392 Mtetra
.701 .646 .791 r
.93768 .44562 .9325 .44948 .93666 .45362 .94185 .44977 Mtetra
.93351 .44146 .92832 .44533 .9325 .44948 .93768 .44562 Mtetra
.92933 .4373 .92414 .44117 .92832 .44533 .93351 .44146 Mtetra
.92514 .43313 .91996 .43701 .92414 .44117 .92933 .4373 Mtetra
.92095 .42896 .91576 .43284 .91996 .43701 .92514 .43313 Mtetra
.91675 .42477 .91156 .42866 .91576 .43284 .92095 .42896 Mtetra
.91255 .42058 .90736 .42448 .91156 .42866 .91675 .42477 Mtetra
.90833 .41639 .90314 .42029 .90736 .42448 .91255 .42058 Mtetra
.90411 .41219 .89892 .41609 .90314 .42029 .90833 .41639 Mtetra
.89989 .40798 .8947 .41189 .89892 .41609 .90411 .41219 Mtetra
.89565 .40376 .89046 .40768 .8947 .41189 .89989 .40798 Mtetra
.89141 .39954 .88622 .40346 .89046 .40768 .89565 .40376 Mtetra
.88717 .39531 .88197 .39924 .88622 .40346 .89141 .39954 Mtetra
.88291 .39107 .87772 .39501 .88197 .39924 .88717 .39531 Mtetra
.87865 .38683 .87346 .39077 .87772 .39501 .88291 .39107 Mtetra
.87439 .38258 .86919 .38653 .87346 .39077 .87865 .38683 Mtetra
.87011 .37832 .86491 .38228 .86919 .38653 .87439 .38258 Mtetra
.86583 .37405 .86063 .37802 .86491 .38228 .87011 .37832 Mtetra
.86154 .36978 .85634 .37375 .86063 .37802 .86583 .37405 Mtetra
.85725 .3655 .85204 .36948 .85634 .37375 .86154 .36978 Mtetra
.85294 .36122 .84774 .3652 .85204 .36948 .85725 .3655 Mtetra
.84863 .35692 .84343 .36092 .84774 .3652 .85294 .36122 Mtetra
.84432 .35263 .83911 .35662 .84343 .36092 .84863 .35692 Mtetra
.83999 .34832 .83479 .35232 .83911 .35662 .84432 .35263 Mtetra
.83566 .344 .83045 .34802 .83479 .35232 .83999 .34832 Mtetra
.83132 .33968 .82611 .3437 .83045 .34802 .83566 .344 Mtetra
.82698 .33536 .82177 .33938 .82611 .3437 .83132 .33968 Mtetra
.82263 .33102 .81742 .33505 .82177 .33938 .82698 .33536 Mtetra
.81827 .32668 .81305 .33072 .81742 .33505 .82263 .33102 Mtetra
.8139 .32233 .80869 .32637 .81305 .33072 .81827 .32668 Mtetra
.80953 .31797 .80431 .32202 .80869 .32637 .8139 .32233 Mtetra
.80514 .31361 .79993 .31767 .80431 .32202 .80953 .31797 Mtetra
.80076 .30924 .79554 .3133 .79993 .31767 .80514 .31361 Mtetra
.79636 .30486 .79114 .30893 .79554 .3133 .80076 .30924 Mtetra
.79196 .30048 .78674 .30456 .79114 .30893 .79636 .30486 Mtetra
.702 .646 .791 r
.78755 .29609 .78233 .30017 .78674 .30456 .79196 .30048 Mtetra
.78313 .29169 .77791 .29578 .78233 .30017 .78755 .29609 Mtetra
.77871 .28728 .77349 .29138 .77791 .29578 .78313 .29169 Mtetra
.77427 .28287 .76905 .28698 .77349 .29138 .77871 .28728 Mtetra
.76984 .27846 .76462 .28258 .76905 .28698 .77427 .28287 Mtetra
.702 .647 .791 r
.76539 .27404 .76017 .27817 .76462 .28258 .76984 .27846 Mtetra
.703 .647 .791 r
.76094 .26963 .75572 .27377 .76017 .27817 .76539 .27404 Mtetra
.703 .648 .792 r
.75648 .26522 .75126 .26938 .75572 .27377 .76094 .26963 Mtetra
.705 .649 .792 r
.75202 .26083 .7468 .26501 .75126 .26938 .75648 .26522 Mtetra
.707 .652 .793 r
.74756 .25647 .74234 .26067 .7468 .26501 .75202 .26083 Mtetra
.71 .656 .794 r
.7431 .25217 .73788 .25641 .74234 .26067 .74756 .25647 Mtetra
.715 .662 .796 r
.73864 .24796 .73343 .25226 .73788 .25641 .7431 .25217 Mtetra
.724 .673 .8 r
.73419 .24391 .72899 .24831 .73343 .25226 .73864 .24796 Mtetra
.739 .691 .805 r
.72977 .24012 .72458 .24466 .72899 .24831 .73419 .24391 Mtetra
.762 .719 .813 r
.7254 .23675 .72023 .24152 .72458 .24466 .72977 .24012 Mtetra
.798 .766 .823 r
.72109 .23405 .71596 .23917 .72023 .24152 .7254 .23675 Mtetra
.851 .836 .831 r
.7169 .23237 .71181 .238 .71596 .23917 .72109 .23405 Mtetra
.908 .927 .815 r
.71286 .23218 .70783 .23853 .71181 .238 .7169 .23237 Mtetra
.909 .981 .72 r
.70903 .234 .70408 .24124 .70783 .23853 .71286 .23218 Mtetra
.778 .91 .521 r
.70543 .23816 .70054 .24627 .70408 .24124 .70903 .234 Mtetra
0 0 0 r
.702 .24427 .69711 .25278 .70054 .24627 .70543 .23816 Mtetra
.69854 .25057 .69353 .25841 .69711 .25278 .702 .24427 Mtetra
.639 .902 .587 r
.69469 .25387 .68944 .25971 .69353 .25841 .69854 .25057 Mtetra
.682 .772 .919 r
.69015 .251 .68462 .25415 .68944 .25971 .69469 .25387 Mtetra
.453 .386 .692 r
.68489 .24117 .67915 .24218 .68462 .25415 .69015 .251 Mtetra
.402 .288 .608 r
.67917 .22667 .67339 .22683 .67915 .24218 .68489 .24117 Mtetra
.409 .279 .591 r
.67337 .21099 .66766 .21142 .67339 .22683 .67917 .22667 Mtetra
.439 .306 .602 r
.66775 .19664 .66215 .19788 .66766 .21142 .67337 .21099 Mtetra
.482 .355 .631 r
.66238 .18458 .65689 .1867 .66215 .19788 .66775 .19664 Mtetra
.531 .415 .666 r
.65724 .17476 .65184 .1776 .65689 .1867 .66238 .18458 Mtetra
.578 .475 .701 r
.65227 .16669 .64693 .17004 .65184 .1776 .65724 .17476 Mtetra
.617 .527 .73 r
.64742 .15985 .64212 .16356 .64693 .17004 .65227 .16669 Mtetra
.646 .567 .751 r
.64265 .15383 .63736 .15778 .64212 .16356 .64742 .15985 Mtetra
.668 .596 .766 r
.63791 .14834 .63264 .15245 .63736 .15778 .64265 .15383 Mtetra
.683 .616 .775 r
.6332 .14319 .62794 .14743 .63264 .15245 .63791 .14834 Mtetra
.695 .631 .781 r
.6285 .13828 .62325 .14264 .62794 .14743 .6332 .14319 Mtetra
.707 .644 .784 r
.62381 .13357 .61857 .13807 .62325 .14264 .6285 .13828 Mtetra
.724 .659 .784 r
.61913 .12909 .6139 .13383 .61857 .13807 .62381 .13357 Mtetra
.753 .681 .781 r
.61446 .12495 .60926 .13014 .6139 .13383 .61913 .12909 Mtetra
.803 .717 .77 r
.60983 .12146 .60467 .1275 .60926 .13014 .61446 .12495 Mtetra
.88 .772 .738 r
.60525 .11919 .60018 .12686 .60467 .1275 .60983 .12146 Mtetra
.966 .828 .654 r
.6008 .11926 .59587 .12993 .60018 .12686 .60525 .11919 Mtetra
.997 .84 .502 r
.59656 .12358 .59185 .13932 .59587 .12993 .6008 .11926 Mtetra
.929 .789 .319 r
.59264 .13495 .5882 .15765 .59185 .13932 .59656 .12358 Mtetra
.757 .69 .146 r
.58909 .15551 .58478 .18356 .5882 .15765 .59264 .13495 Mtetra
0 0 .017 r
.58569 .18185 .58099 .20515 .58478 .18356 .58909 .15551 Mtetra
.125 0 .114 r
.58168 .19919 .57606 .2038 .58099 .20515 .58569 .18185 Mtetra
.753 .312 0 r
.57642 .1906 .57007 .17657 .57606 .2038 .58168 .19919 Mtetra
0 0 .365 r
.57026 .15933 .56387 .14056 .57007 .17657 .57642 .1906 Mtetra
.007 0 .407 r
.56409 .124 .55804 .11051 .56387 .14056 .57026 .15933 Mtetra
.145 .034 .459 r
.55835 .09636 .55264 .08973 .55804 .11051 .56409 .124 Mtetra
.272 .155 .532 r
.55301 .07766 .54752 .07599 .55264 .08973 .55835 .09636 Mtetra
.405 .297 .618 r
.54793 .06522 .54256 .06648 .54752 .07599 .55301 .07766 Mtetra
.522 .429 .692 r
.54298 .05643 .53767 .05927 .54256 .06648 .54793 .06522 Mtetra
.603 .525 .74 r
.53809 .04959 .5328 .05325 .53767 .05927 .54298 .05643 Mtetra
.65 .582 .765 r
.53322 .04375 .52795 .04783 .5328 .05325 .53809 .04959 Mtetra
.676 .613 .778 r
.52836 .03841 .52309 .0427 .52795 .04783 .53322 .04375 Mtetra
.689 .63 .785 r
.52349 .03333 .51823 .03772 .52309 .0427 .52836 .03841 Mtetra
.695 .638 .788 r
.51863 .02835 .51336 .03281 .51823 .03772 .52349 .03333 Mtetra
.698 .642 .789 r
.51375 .02343 .50849 .02793 .51336 .03281 .51863 .02835 Mtetra
.7 .644 .79 r
.50887 .01854 .5036 .02305 .50849 .02793 .51375 .02343 Mtetra
.701 .645 .79 r
.50397 .01365 .49871 .01818 .5036 .02305 .50887 .01854 Mtetra
.9512 .45007 .94601 .45392 .95016 .45806 .95535 .45423 Mtetra
.701 .645 .791 r
.94704 .44592 .94185 .44977 .94601 .45392 .9512 .45007 Mtetra
.94287 .44176 .93768 .44562 .94185 .44977 .94704 .44592 Mtetra
.701 .646 .791 r
.9387 .43759 .93351 .44146 .93768 .44562 .94287 .44176 Mtetra
.93452 .43342 .92933 .4373 .93351 .44146 .9387 .43759 Mtetra
.93034 .42925 .92514 .43313 .92933 .4373 .93452 .43342 Mtetra
.92615 .42507 .92095 .42896 .92514 .43313 .93034 .42925 Mtetra
.92195 .42088 .91675 .42477 .92095 .42896 .92615 .42507 Mtetra
.91774 .41668 .91255 .42058 .91675 .42477 .92195 .42088 Mtetra
.91353 .41248 .90833 .41639 .91255 .42058 .91774 .41668 Mtetra
.90931 .40827 .90411 .41219 .90833 .41639 .91353 .41248 Mtetra
.90509 .40406 .89989 .40798 .90411 .41219 .90931 .40827 Mtetra
.90086 .39983 .89565 .40376 .89989 .40798 .90509 .40406 Mtetra
.89662 .3956 .89141 .39954 .89565 .40376 .90086 .39983 Mtetra
.89237 .39137 .88717 .39531 .89141 .39954 .89662 .3956 Mtetra
.88812 .38712 .88291 .39107 .88717 .39531 .89237 .39137 Mtetra
.88386 .38287 .87865 .38683 .88291 .39107 .88812 .38712 Mtetra
.87959 .37862 .87439 .38258 .87865 .38683 .88386 .38287 Mtetra
.87532 .37435 .87011 .37832 .87439 .38258 .87959 .37862 Mtetra
.87104 .37008 .86583 .37405 .87011 .37832 .87532 .37435 Mtetra
.86675 .3658 .86154 .36978 .86583 .37405 .87104 .37008 Mtetra
.86246 .36152 .85725 .3655 .86154 .36978 .86675 .3658 Mtetra
.85815 .35723 .85294 .36122 .85725 .3655 .86246 .36152 Mtetra
.85384 .35293 .84863 .35692 .85294 .36122 .85815 .35723 Mtetra
.84953 .34862 .84432 .35263 .84863 .35692 .85384 .35293 Mtetra
.84521 .34431 .83999 .34832 .84432 .35263 .84953 .34862 Mtetra
.84088 .33999 .83566 .344 .83999 .34832 .84521 .34431 Mtetra
.83654 .33566 .83132 .33968 .83566 .344 .84088 .33999 Mtetra
.83219 .33133 .82698 .33536 .83132 .33968 .83654 .33566 Mtetra
.82784 .32698 .82263 .33102 .82698 .33536 .83219 .33133 Mtetra
.82348 .32263 .81827 .32668 .82263 .33102 .82784 .32698 Mtetra
.81912 .31828 .8139 .32233 .81827 .32668 .82348 .32263 Mtetra
.81475 .31392 .80953 .31797 .8139 .32233 .81912 .31828 Mtetra
.81037 .30955 .80514 .31361 .80953 .31797 .81475 .31392 Mtetra
.80598 .30517 .80076 .30924 .80514 .31361 .81037 .30955 Mtetra
.80158 .30078 .79636 .30486 .80076 .30924 .80598 .30517 Mtetra
.79718 .29639 .79196 .30048 .79636 .30486 .80158 .30078 Mtetra
.79277 .29199 .78755 .29609 .79196 .30048 .79718 .29639 Mtetra
.702 .646 .791 r
.78836 .28759 .78313 .29169 .78755 .29609 .79277 .29199 Mtetra
.78393 .28318 .77871 .28728 .78313 .29169 .78836 .28759 Mtetra
.7795 .27876 .77427 .28287 .77871 .28728 .78393 .28318 Mtetra
.77506 .27434 .76984 .27846 .77427 .28287 .7795 .27876 Mtetra
.77062 .26991 .76539 .27404 .76984 .27846 .77506 .27434 Mtetra
.702 .647 .791 r
.76617 .26549 .76094 .26963 .76539 .27404 .77062 .26991 Mtetra
.703 .648 .791 r
.76171 .26107 .75648 .26522 .76094 .26963 .76617 .26549 Mtetra
.704 .649 .792 r
.75725 .25666 .75202 .26083 .75648 .26522 .76171 .26107 Mtetra
.706 .651 .793 r
.75279 .25228 .74756 .25647 .75202 .26083 .75725 .25666 Mtetra
.708 .654 .794 r
.74832 .24794 .7431 .25217 .74756 .25647 .75279 .25228 Mtetra
.713 .66 .795 r
.74386 .24368 .73864 .24796 .7431 .25217 .74832 .24794 Mtetra
.72 .668 .798 r
.73941 .23955 .73419 .24391 .73864 .24796 .74386 .24368 Mtetra
.732 .683 .803 r
.73498 .23564 .72977 .24012 .73419 .24391 .73941 .23955 Mtetra
.752 .707 .81 r
.73058 .23207 .7254 .23675 .72977 .24012 .73498 .23564 Mtetra
.783 .746 .819 r
.72625 .22907 .72109 .23405 .7254 .23675 .73058 .23207 Mtetra
.83 .807 .829 r
.72201 .22694 .7169 .23237 .72109 .23405 .72625 .22907 Mtetra
.889 .892 .827 r
.71791 .22611 .71286 .23218 .7169 .23237 .72201 .22694 Mtetra
.922 .972 .769 r
.71401 .2271 .70903 .234 .71286 .23218 .71791 .22611 Mtetra
.841 .952 .602 r
.71034 .23035 .70543 .23816 .70903 .234 .71401 .2271 Mtetra
.662 .825 .396 r
.70688 .23581 .702 .24427 .70543 .23816 .71034 .23035 Mtetra
0 0 0 r
.70348 .24231 .69854 .25057 .702 .24427 .70688 .23581 Mtetra
.69985 .24713 .69469 .25387 .69854 .25057 .70348 .24231 Mtetra
.77 .965 .927 r
.6956 .24682 .69015 .251 .69469 .25387 .69985 .24713 Mtetra
.508 .478 .758 r
.69058 .23948 .68489 .24117 .69015 .251 .6956 .24682 Mtetra
.411 .309 .628 r
.68496 .22634 .67917 .22667 .68489 .24117 .69058 .23948 Mtetra
.403 .276 .593 r
.67913 .21074 .67337 .21099 .67917 .22667 .68496 .22634 Mtetra
.426 .293 .596 r
.6734 .19571 .66775 .19664 .67337 .21099 .67913 .21074 Mtetra
.465 .335 .619 r
.66791 .18277 .66238 .18458 .66775 .19664 .6734 .19571 Mtetra
.512 .392 .652 r
.66268 .17216 .65724 .17476 .66238 .18458 .66791 .18277 Mtetra
.561 .453 .688 r
.65765 .16349 .65227 .16669 .65724 .17476 .66268 .17216 Mtetra
.603 .509 .72 r
.65275 .15624 .64742 .15985 .65227 .16669 .65765 .16349 Mtetra
.636 .554 .744 r
.64794 .14994 .64265 .15383 .64742 .15985 .65275 .15624 Mtetra
.66 .586 .761 r
.64319 .14427 .63791 .14834 .64265 .15383 .64794 .14994 Mtetra
.677 .609 .772 r
.63847 .139 .6332 .14319 .63791 .14834 .64319 .14427 Mtetra
.689 .625 .779 r
.63376 .13398 .6285 .13828 .6332 .14319 .63847 .139 Mtetra
.7 .637 .783 r
.62906 .12916 .62381 .13357 .6285 .13828 .63376 .13398 Mtetra
.712 .649 .785 r
.62437 .12452 .61913 .12909 .62381 .13357 .62906 .12916 Mtetra
.731 .664 .784 r
.61969 .12011 .61446 .12495 .61913 .12909 .62437 .12452 Mtetra
.764 .689 .78 r
.61503 .11609 .60983 .12146 .61446 .12495 .61969 .12011 Mtetra
.82 .73 .765 r
.6104 .11282 .60525 .11919 .60983 .12146 .61503 .11609 Mtetra
.903 .787 .723 r
.60585 .11099 .6008 .11926 .60525 .11919 .6104 .11282 Mtetra
.982 .837 .622 r
.60144 .11187 .59656 .12358 .6008 .11926 .60585 .11099 Mtetra
.99 .832 .456 r
.59727 .11763 .59264 .13495 .59656 .12358 .60144 .11187 Mtetra
.896 .768 .273 r
.59346 .13111 .58909 .15551 .59264 .13495 .59727 .11763 Mtetra
0 0 0 r
.59002 .15372 .58569 .18185 .58909 .15551 .59346 .13111 Mtetra
0 0 .051 r
.58657 .17952 .58168 .19919 .58569 .18185 .59002 .15372 Mtetra
.315 0 .096 r
.5823 .19142 .57642 .1906 .58168 .19919 .58657 .17952 Mtetra
0 0 .286 r
.57673 .17588 .57026 .15933 .57642 .1906 .5823 .19142 Mtetra
0 0 .376 r
.57044 .14191 .56409 .124 .57026 .15933 .57673 .17588 Mtetra
.045 0 .418 r
.56432 .10799 .55835 .09636 .56409 .124 .57044 .14191 Mtetra
.175 .061 .475 r
.55867 .08279 .55301 .07766 .55835 .09636 .56432 .10799 Mtetra
.304 .189 .553 r
.55339 .06597 .54793 .06522 .55301 .07766 .55867 .08279 Mtetra
.436 .332 .638 r
.54834 .05466 .54298 .05643 .54793 .06522 .55339 .06597 Mtetra
.546 .457 .706 r
.5434 .04648 .53809 .04959 .54298 .05643 .54834 .05466 Mtetra
.618 .543 .748 r
.53851 .03995 .53322 .04375 .53809 .04959 .5434 .04648 Mtetra
.658 .592 .769 r
.53364 .03426 .52836 .03841 .53322 .04375 .53851 .03995 Mtetra
.68 .619 .78 r
.52877 .02899 .52349 .03333 .52836 .03841 .53364 .03426 Mtetra
.691 .632 .786 r
.5239 .02392 .51863 .02835 .52349 .03333 .52877 .02899 Mtetra
.696 .639 .788 r
.51902 .01895 .51375 .02343 .51863 .02835 .5239 .02392 Mtetra
.699 .642 .79 r
.51414 .01403 .50887 .01854 .51375 .02343 .51902 .01895 Mtetra
.7 .644 .79 r
.50925 .00912 .50397 .01365 .50887 .01854 .51414 .01403 Mtetra
.95639 .44622 .9512 .45007 .95535 .45423 .96055 .4504 Mtetra
.701 .645 .79 r
.95223 .44206 .94704 .44592 .9512 .45007 .95639 .44622 Mtetra
.701 .645 .791 r
.94807 .43789 .94287 .44176 .94704 .44592 .95223 .44206 Mtetra
.9439 .43372 .9387 .43759 .94287 .44176 .94807 .43789 Mtetra
.701 .646 .791 r
.93972 .42954 .93452 .43342 .9387 .43759 .9439 .43372 Mtetra
.93554 .42536 .93034 .42925 .93452 .43342 .93972 .42954 Mtetra
.93135 .42117 .92615 .42507 .93034 .42925 .93554 .42536 Mtetra
.92715 .41698 .92195 .42088 .92615 .42507 .93135 .42117 Mtetra
.92295 .41278 .91774 .41668 .92195 .42088 .92715 .41698 Mtetra
.91874 .40857 .91353 .41248 .91774 .41668 .92295 .41278 Mtetra
.91452 .40435 .90931 .40827 .91353 .41248 .91874 .40857 Mtetra
.9103 .40013 .90509 .40406 .90931 .40827 .91452 .40435 Mtetra
.90607 .3959 .90086 .39983 .90509 .40406 .9103 .40013 Mtetra
.90183 .39166 .89662 .3956 .90086 .39983 .90607 .3959 Mtetra
.89758 .38742 .89237 .39137 .89662 .3956 .90183 .39166 Mtetra
.89333 .38317 .88812 .38712 .89237 .39137 .89758 .38742 Mtetra
.88907 .37891 .88386 .38287 .88812 .38712 .89333 .38317 Mtetra
.88481 .37465 .87959 .37862 .88386 .38287 .88907 .37891 Mtetra
.88053 .37038 .87532 .37435 .87959 .37862 .88481 .37465 Mtetra
.87625 .3661 .87104 .37008 .87532 .37435 .88053 .37038 Mtetra
.87197 .36182 .86675 .3658 .87104 .37008 .87625 .3661 Mtetra
.86767 .35753 .86246 .36152 .86675 .3658 .87197 .36182 Mtetra
.86337 .35323 .85815 .35723 .86246 .36152 .86767 .35753 Mtetra
.85907 .34892 .85384 .35293 .85815 .35723 .86337 .35323 Mtetra
.85475 .34461 .84953 .34862 .85384 .35293 .85907 .34892 Mtetra
.85043 .34029 .84521 .34431 .84953 .34862 .85475 .34461 Mtetra
.8461 .33596 .84088 .33999 .84521 .34431 .85043 .34029 Mtetra
.84176 .33163 .83654 .33566 .84088 .33999 .8461 .33596 Mtetra
.83742 .32729 .83219 .33133 .83654 .33566 .84176 .33163 Mtetra
.83307 .32294 .82784 .32698 .83219 .33133 .83742 .32729 Mtetra
.82871 .31858 .82348 .32263 .82784 .32698 .83307 .32294 Mtetra
.82435 .31422 .81912 .31828 .82348 .32263 .82871 .31858 Mtetra
.81998 .30985 .81475 .31392 .81912 .31828 .82435 .31422 Mtetra
.8156 .30547 .81037 .30955 .81475 .31392 .81998 .30985 Mtetra
.81121 .30109 .80598 .30517 .81037 .30955 .8156 .30547 Mtetra
.80682 .2967 .80158 .30078 .80598 .30517 .81121 .30109 Mtetra
.80241 .2923 .79718 .29639 .80158 .30078 .80682 .2967 Mtetra
.79801 .2879 .79277 .29199 .79718 .29639 .80241 .2923 Mtetra
.702 .646 .791 r
.79359 .28348 .78836 .28759 .79277 .29199 .79801 .2879 Mtetra
.78917 .27906 .78393 .28318 .78836 .28759 .79359 .28348 Mtetra
.78474 .27464 .7795 .27876 .78393 .28318 .78917 .27906 Mtetra
.7803 .27021 .77506 .27434 .7795 .27876 .78474 .27464 Mtetra
.77586 .26578 .77062 .26991 .77506 .27434 .7803 .27021 Mtetra
.702 .647 .791 r
.77141 .26134 .76617 .26549 .77062 .26991 .77586 .26578 Mtetra
.703 .647 .791 r
.76695 .25691 .76171 .26107 .76617 .26549 .77141 .26134 Mtetra
.704 .648 .792 r
.76249 .25249 .75725 .25666 .76171 .26107 .76695 .25691 Mtetra
.705 .65 .792 r
.75802 .24808 .75279 .25228 .75725 .25666 .76249 .25249 Mtetra
.707 .653 .793 r
.75356 .24371 .74832 .24794 .75279 .25228 .75802 .24808 Mtetra
.711 .657 .795 r
.74909 .23941 .74386 .24368 .74832 .24794 .75356 .24371 Mtetra
.717 .665 .797 r
.74464 .23521 .73941 .23955 .74386 .24368 .74909 .23941 Mtetra
.727 .677 .801 r
.74019 .23119 .73498 .23564 .73941 .23955 .74464 .23521 Mtetra
.743 .697 .807 r
.73578 .22747 .73058 .23207 .73498 .23564 .74019 .23119 Mtetra
.77 .729 .815 r
.73142 .22421 .72625 .22907 .73058 .23207 .73578 .22747 Mtetra
.81 .781 .826 r
.72714 .2217 .72201 .22694 .72625 .22907 .73142 .22421 Mtetra
.866 .858 .831 r
.72299 .22031 .71791 .22611 .72201 .22694 .72714 .2217 Mtetra
.918 .948 .801 r
.71902 .22053 .71401 .2271 .71791 .22611 .72299 .22031 Mtetra
.888 .976 .677 r
.71527 .22287 .71034 .23035 .71401 .2271 .71902 .22053 Mtetra
.731 .876 .467 r
.71176 .22754 .70688 .23581 .71034 .23035 .71527 .22287 Mtetra
0 0 0 r
.70839 .23385 .70348 .24231 .70688 .23581 .71176 .22754 Mtetra
.70491 .23967 .69985 .24713 .70348 .24231 .70839 .23385 Mtetra
.717 .973 .741 r
.70094 .24162 .6956 .24682 .69985 .24713 .70491 .23967 Mtetra
.601 .631 .853 r
.6962 .23693 .69058 .23948 .6956 .24682 .70094 .24162 Mtetra
.431 .347 .661 r
.69075 .22564 .68496 .22634 .69058 .23948 .6962 .23693 Mtetra
.401 .281 .6 r
.68493 .21056 .67913 .21074 .68496 .22634 .69075 .22564 Mtetra
.415 .283 .591 r
.67911 .19506 .6734 .19571 .67913 .21074 .68493 .21056 Mtetra
.449 .317 .608 r
.67351 .18127 .66791 .18277 .6734 .19571 .67911 .19506 Mtetra
.494 .369 .639 r
.66817 .16981 .66268 .17216 .66791 .18277 .67351 .18127 Mtetra
.543 .43 .675 r
.66305 .16048 .65765 .16349 .66268 .17216 .66817 .16981 Mtetra
.588 .489 .709 r
.6581 .15275 .65275 .15624 .65765 .16349 .66305 .16048 Mtetra
.625 .538 .736 r
.65326 .14614 .64794 .14994 .65275 .15624 .6581 .15275 Mtetra
.652 .575 .756 r
.64849 .14025 .64319 .14427 .64794 .14994 .65326 .14614 Mtetra
.671 .601 .769 r
.64375 .13484 .63847 .139 .64319 .14427 .64849 .14025 Mtetra
.684 .619 .777 r
.63903 .12972 .63376 .13398 .63847 .139 .64375 .13484 Mtetra
.694 .632 .782 r
.63433 .12481 .62906 .12916 .63376 .13398 .63903 .12972 Mtetra
.704 .642 .785 r
.62963 .12005 .62437 .12452 .62906 .12916 .63433 .12481 Mtetra
.717 .654 .786 r
.62494 .11547 .61969 .12011 .62437 .12452 .62963 .12005 Mtetra
.738 .67 .784 r
.62026 .11113 .61503 .11609 .61969 .12011 .62494 .11547 Mtetra
.776 .698 .778 r
.61559 .10725 .6104 .11282 .61503 .11609 .62026 .11113 Mtetra
.839 .743 .758 r
.61098 .10424 .60585 .11099 .6104 .11282 .61559 .10725 Mtetra
.926 .803 .704 r
.60645 .10291 .60144 .11187 .60585 .11099 .61098 .10424 Mtetra
.994 .842 .585 r
.6021 .10474 .59727 .11763 .60144 .11187 .60645 .10291 Mtetra
.975 .821 .408 r
.59802 .11211 .59346 .13111 .59727 .11763 .6021 .10474 Mtetra
.856 .745 .229 r
.59433 .12781 .59002 .15372 .59346 .13111 .59802 .11211 Mtetra
0 0 0 r
.59097 .15212 .58657 .17952 .59002 .15372 .59433 .12781 Mtetra
0 0 .079 r
.58743 .17623 .5823 .19142 .58657 .17952 .59097 .15212 Mtetra
.536 .045 .037 r
.58284 .18176 .57673 .17588 .5823 .19142 .58743 .17623 Mtetra
0 0 .33 r
.57697 .15997 .57044 .14191 .57673 .17588 .58284 .18176 Mtetra
0 0 .387 r
.57063 .12458 .56432 .10799 .57044 .14191 .57697 .15997 Mtetra
.079 0 .43 r
.56458 .09258 .55867 .08279 .56432 .10799 .57063 .12458 Mtetra
.206 .09 .492 r
.55901 .06975 .55339 .06597 .55867 .08279 .56458 .09258 Mtetra
.337 .224 .574 r
.55378 .0546 .54834 .05466 .55339 .06597 .55901 .06975 Mtetra
.466 .366 .657 r
.54875 .04427 .5434 .04648 .54834 .05466 .55378 .0546 Mtetra
.567 .482 .719 r
.54382 .0366 .53851 .03995 .5434 .04648 .54875 .04427 Mtetra
.63 .558 .755 r
.53893 .03033 .53364 .03426 .53851 .03995 .54382 .0366 Mtetra
.665 .601 .773 r
.53406 .02476 .52877 .02899 .53364 .03426 .53893 .03033 Mtetra
.683 .623 .782 r
.52918 .01954 .5239 .02392 .52877 .02899 .53406 .02476 Mtetra
.692 .634 .786 r
.52431 .01449 .51902 .01895 .5239 .02392 .52918 .01954 Mtetra
.697 .64 .789 r
.51942 .00953 .51414 .01403 .51902 .01895 .52431 .01449 Mtetra
.699 .643 .79 r
.51453 .0046 .50925 .00912 .51414 .01403 .51942 .00953 Mtetra
.7 .643 .79 r
.9616 .44238 .95639 .44622 .96055 .4504 .96576 .44658 Mtetra
.701 .644 .79 r
.95744 .4382 .95223 .44206 .95639 .44622 .9616 .44238 Mtetra
.701 .645 .791 r
.95328 .43402 .94807 .43789 .95223 .44206 .95744 .4382 Mtetra
.94911 .42984 .9439 .43372 .94807 .43789 .95328 .43402 Mtetra
.701 .646 .791 r
.94493 .42566 .93972 .42954 .9439 .43372 .94911 .42984 Mtetra
.94075 .42147 .93554 .42536 .93972 .42954 .94493 .42566 Mtetra
.93656 .41727 .93135 .42117 .93554 .42536 .94075 .42147 Mtetra
.93236 .41307 .92715 .41698 .93135 .42117 .93656 .41727 Mtetra
.92816 .40886 .92295 .41278 .92715 .41698 .93236 .41307 Mtetra
.92395 .40465 .91874 .40857 .92295 .41278 .92816 .40886 Mtetra
.91974 .40043 .91452 .40435 .91874 .40857 .92395 .40465 Mtetra
.91551 .3962 .9103 .40013 .91452 .40435 .91974 .40043 Mtetra
.91128 .39196 .90607 .3959 .9103 .40013 .91551 .3962 Mtetra
.90705 .38772 .90183 .39166 .90607 .3959 .91128 .39196 Mtetra
.9028 .38347 .89758 .38742 .90183 .39166 .90705 .38772 Mtetra
.89855 .37921 .89333 .38317 .89758 .38742 .9028 .38347 Mtetra
.89429 .37495 .88907 .37891 .89333 .38317 .89855 .37921 Mtetra
.89003 .37068 .88481 .37465 .88907 .37891 .89429 .37495 Mtetra
.88576 .3664 .88053 .37038 .88481 .37465 .89003 .37068 Mtetra
.88148 .36212 .87625 .3661 .88053 .37038 .88576 .3664 Mtetra
.87719 .35783 .87197 .36182 .87625 .3661 .88148 .36212 Mtetra
.8729 .35353 .86767 .35753 .87197 .36182 .87719 .35783 Mtetra
.8686 .34922 .86337 .35323 .86767 .35753 .8729 .35353 Mtetra
.86429 .34491 .85907 .34892 .86337 .35323 .8686 .34922 Mtetra
.85998 .34059 .85475 .34461 .85907 .34892 .86429 .34491 Mtetra
.85566 .33627 .85043 .34029 .85475 .34461 .85998 .34059 Mtetra
.85133 .33193 .8461 .33596 .85043 .34029 .85566 .33627 Mtetra
.847 .32759 .84176 .33163 .8461 .33596 .85133 .33193 Mtetra
.84265 .32324 .83742 .32729 .84176 .33163 .847 .32759 Mtetra
.8383 .31889 .83307 .32294 .83742 .32729 .84265 .32324 Mtetra
.83395 .31453 .82871 .31858 .83307 .32294 .8383 .31889 Mtetra
.82958 .31016 .82435 .31422 .82871 .31858 .83395 .31453 Mtetra
.82521 .30578 .81998 .30985 .82435 .31422 .82958 .31016 Mtetra
.82083 .3014 .8156 .30547 .81998 .30985 .82521 .30578 Mtetra
.81645 .29701 .81121 .30109 .8156 .30547 .82083 .3014 Mtetra
.81206 .29261 .80682 .2967 .81121 .30109 .81645 .29701 Mtetra
.80766 .2882 .80241 .2923 .80682 .2967 .81206 .29261 Mtetra
.80325 .28379 .79801 .2879 .80241 .2923 .80766 .2882 Mtetra
.79883 .27937 .79359 .28348 .79801 .2879 .80325 .28379 Mtetra
.702 .646 .791 r
.79441 .27495 .78917 .27906 .79359 .28348 .79883 .27937 Mtetra
.78998 .27051 .78474 .27464 .78917 .27906 .79441 .27495 Mtetra
.78555 .26608 .7803 .27021 .78474 .27464 .78998 .27051 Mtetra
.7811 .26163 .77586 .26578 .7803 .27021 .78555 .26608 Mtetra
.77665 .25719 .77141 .26134 .77586 .26578 .7811 .26163 Mtetra
.703 .647 .791 r
.7722 .25275 .76695 .25691 .77141 .26134 .77665 .25719 Mtetra
.703 .648 .792 r
.76774 .24831 .76249 .25249 .76695 .25691 .7722 .25275 Mtetra
.704 .649 .792 r
.76327 .24389 .75802 .24808 .76249 .25249 .76774 .24831 Mtetra
.706 .652 .793 r
.7588 .23949 .75356 .24371 .75802 .24808 .76327 .24389 Mtetra
.709 .655 .794 r
.75433 .23515 .74909 .23941 .75356 .24371 .7588 .23949 Mtetra
.715 .661 .796 r
.74987 .23089 .74464 .23521 .74909 .23941 .75433 .23515 Mtetra
.723 .671 .799 r
.74542 .22679 .74019 .23119 .74464 .23521 .74987 .23089 Mtetra
.736 .688 .804 r
.741 .22292 .73578 .22747 .74019 .23119 .74542 .22679 Mtetra
.758 .715 .812 r
.73661 .21945 .73142 .22421 .73578 .22747 .741 .22292 Mtetra
.793 .759 .822 r
.7323 .21661 .72714 .2217 .73142 .22421 .73661 .21945 Mtetra
.844 .826 .831 r
.7281 .21473 .72299 .22031 .72714 .2217 .7323 .21661 Mtetra
.902 .916 .82 r
.72406 .21426 .71902 .22053 .72299 .22031 .7281 .21473 Mtetra
.915 .98 .738 r
.72024 .21574 .71527 .22287 .71902 .22053 .72406 .21426 Mtetra
.8 .925 .547 r
.71666 .21952 .71176 .22754 .71527 .22287 .72024 .21574 Mtetra
.619 .792 .357 r
.71328 .22534 .70839 .23385 .71176 .22754 .71666 .21952 Mtetra
0 0 0 r
.7099 .23166 .70491 .23967 .70839 .23385 .71328 .22534 Mtetra
.608 .868 .525 r
.70617 .23545 .70094 .24162 .70491 .23967 .7099 .23166 Mtetra
.722 .845 .94 r
.70174 .23341 .6962 .23693 .70094 .24162 .70617 .23545 Mtetra
.469 .412 .711 r
.69652 .22438 .69075 .22564 .6962 .23693 .70174 .23341 Mtetra
.404 .294 .614 r
.69077 .21031 .68493 .21056 .69075 .22564 .69652 .22438 Mtetra
.406 .277 .591 r
.68488 .19465 .67911 .19506 .68493 .21056 .69077 .21031 Mtetra
.434 .301 .6 r
.67916 .18008 .67351 .18127 .67911 .19506 .68488 .19465 Mtetra
.476 .348 .626 r
.6737 .16776 .66817 .16981 .67351 .18127 .67916 .18008 Mtetra
.524 .407 .661 r
.6685 .15768 .66305 .16048 .66817 .16981 .6737 .16776 Mtetra
.572 .467 .697 r
.66348 .14941 .6581 .15275 .66305 .16048 .6685 .15768 Mtetra
.612 .521 .727 r
.6586 .14243 .65326 .14614 .6581 .15275 .66348 .14941 Mtetra
.643 .563 .749 r
.6538 .1363 .64849 .14025 .65326 .14614 .6586 .14243 Mtetra
.664 .592 .765 r
.64905 .13072 .64375 .13484 .64849 .14025 .6538 .1363 Mtetra
.679 .613 .774 r
.64432 .1255 .63903 .12972 .64375 .13484 .64905 .13072 Mtetra
.69 .627 .781 r
.63961 .12049 .63433 .12481 .63903 .12972 .64432 .1255 Mtetra
.698 .637 .784 r
.6349 .11565 .62963 .12005 .63433 .12481 .63961 .12049 Mtetra
.708 .646 .786 r
.6302 .11095 .62494 .11547 .62963 .12005 .6349 .11565 Mtetra
.722 .658 .786 r
.62551 .10641 .62026 .11113 .62494 .11547 .6302 .11095 Mtetra
.746 .677 .783 r
.62083 .10216 .61559 .10725 .62026 .11113 .62551 .10641 Mtetra
.789 .708 .775 r
.61617 .09844 .61098 .10424 .61559 .10725 .62083 .10216 Mtetra
.859 .758 .749 r
.61157 .09574 .60645 .10291 .61098 .10424 .61617 .09844 Mtetra
.948 .817 .681 r
.60708 .095 .6021 .10474 .60645 .10291 .61157 .09574 Mtetra
.999 .843 .543 r
.60278 .09791 .59802 .11211 .6021 .10474 .60708 .095 Mtetra
.954 .805 .361 r
.5988 .10706 .59433 .12781 .59802 .11211 .60278 .09791 Mtetra
.809 .718 .185 r
.59523 .12503 .59097 .15212 .59433 .12781 .5988 .10706 Mtetra
0 0 0 r
.59193 .15048 .58743 .17623 .59097 .15212 .59523 .12503 Mtetra
0 0 .097 r
.58823 .17167 .58284 .18176 .58743 .17623 .59193 .15048 Mtetra
.727 .199 0 r
.58329 .17022 .57697 .15997 .58284 .18176 .58823 .17167 Mtetra
0 0 .353 r
.57717 .14321 .57063 .12458 .57697 .15997 .58329 .17022 Mtetra
0 0 .396 r
.57081 .10755 .56458 .09258 .57063 .12458 .57717 .14321 Mtetra
.11 .005 .443 r
.56485 .07779 .55901 .06975 .56458 .09258 .57081 .10755 Mtetra
.237 .121 .511 r
.55936 .05718 .55378 .0546 .55901 .06975 .56485 .07779 Mtetra
.37 .26 .596 r
.55418 .04351 .54875 .04427 .55378 .0546 .55936 .05718 Mtetra
.495 .399 .675 r
.54918 .03401 .54382 .0366 .54875 .04427 .55418 .04351 Mtetra
.586 .505 .73 r
.54425 .02678 .53893 .03033 .54382 .0366 .54918 .03401 Mtetra
.641 .571 .76 r
.53936 .02072 .53406 .02476 .53893 .03033 .54425 .02678 Mtetra
.671 .608 .776 r
.53448 .01525 .52918 .01954 .53406 .02476 .53936 .02072 Mtetra
.686 .626 .783 r
.5296 .01008 .52431 .01449 .52918 .01954 .53448 .01525 Mtetra
.694 .636 .787 r
.52471 .00504 .51942 .00953 .52431 .01449 .5296 .01008 Mtetra
.698 .641 .789 r
.51982 7e-005 .51453 .0046 .51942 .00953 .52471 .00504 Mtetra
0 g
.51982 0 m
.5213 .12454 L
s
.5213 .12454 m
0 .5631 L
s
0 .5631 m
.03466 .41753 L
s
.03466 .41753 m
.51982 0 L
s
.51982 0 m
.5213 .12454 L
s
.5213 .12454 m
1 .59332 L
s
1 .59332 m
.96574 .44649 L
s
.96574 .44649 m
.51982 0 L
s
.51982 0 m
.96574 .44649 L
s
.51982 0 m
.51506 .0041 L
s
gsave
.52934 -0.0082 -61 -14.1752 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.63839 .11872 m
.63355 .12272 L
s
gsave
.64807 .11071 -61 -13.9931 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.75203 .23251 m
.74712 .23642 L
s
gsave
.76186 .22468 -61 -13.8246 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.86106 .34167 m
.85608 .3455 L
s
gsave
.87102 .33402 -61 -13.6681 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.96574 .44649 m
.96069 .45023 L
s
gsave
.97583 .43901 -61 -13.5226 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.125 Mabswid
.54394 .02415 m
.54108 .0266 L
s
.56786 .0481 m
.56498 .05053 L
s
.59157 .07184 m
.58868 .07426 L
s
.61508 .09538 m
.61218 .09779 L
s
.6615 .14186 m
.65859 .14425 L
s
.68442 .16481 m
.6815 .16719 L
s
.70714 .18756 m
.70421 .18993 L
s
.72968 .21013 m
.72674 .21249 L
s
.7742 .2547 m
.77124 .25704 L
s
.79618 .27671 m
.79322 .27904 L
s
.81798 .29854 m
.81501 .30086 L
s
.83961 .3202 m
.83663 .3225 L
s
.88233 .36298 m
.87934 .36526 L
s
.90344 .38411 m
.90043 .38638 L
s
.92437 .40507 m
.92136 .40733 L
s
.94514 .42586 m
.94212 .42812 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[94]:=",
  ImageSize->{249.875, 240.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005f0001J2000`400?l00000o`00003oo`3ooomg
0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg
0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg
0?ooo`00[`3oool01@3ookl0M00000000000B9`0gooo0<80oooo002^0?ooo`060?oog`2LB000B9cO
0?ooo`3OW4P007Bo`P3oool00:h0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00d0oooo
00D0oono07@00000000004RL0=ooo`2_0?ooo`00[P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol0303oool01P3ooml0W4P004RLg`3oool0gia8001d_jl0oooo002^0?ooo`070?noM000B9`0
gooo0?ooo`3ookl0M01809cOo`0<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`2^0?oo
o`00[P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0303oool01`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0[P3oool00:h0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00`0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0:h0oooo002^0?ooo`060?oog`2LB000M;oo
0?ooo`3OW4P007Bo3@3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0[P3oool00:l0oooo
00D0oono07@00000000004RL0=ooo`0=0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`2^
0?ooo`00`@3oool01P3ooml0W4P007Boo`3oool0gia8001d_jl0oooo00320?ooo`050?oo_`1d0000
00000018W03Oool0[`3oool00?l0ooooM`3oool00?l0ooooM`3oool00?l0ooooM`3oool00?l0oooo
M`3oool00;/0oooo00<000000?ooo`3oool0^03oool00;T0oooo00<0/ZC90000000000000P00002h
0?ooo`00^@3oool01@000000/ZC90000002aX/T000000;P0oooo002g0?ooo`8000000P2bY<X01000
0000/J;90;6Rb@00002g0?ooo`00]P3oool00`000000/jC:0;>TbP020;:Sb@050000002bXlT0[j38
0:nPb0000000]P3oool00;D0oooo00<000000;>UbP2cY<X00P2bY<X0102bXlT000000;6Rb@2aX/T2
0:nPb0030000003oool0oooo0;<0oooo002d0?ooo`030000002cYLX0/jG:00@0/ZC:00<000000;6R
b@2aX/T00`2[VlH00`000000oooo0?ooo`2b0?ooo`00/P3oool0102cYLX000000;>UbP2cYLX20;>T
bP80/ZC:00D0/Z?90000002aX/T0/J;90:jOb0030:^KaP030000003oool0oooo0;40oooo002a0?oo
o`030;>UbP000000/jG:00<0/jG:0P2cY<X20;:Sb@030000002bXlT0[Yo80080[Yo80`2TT/800`00
0000oooo0?ooo`2`0?ooo`00/03oool2000000D0/jG:102bY<T00`000000/:790;2Qb@030:ZIa@04
0:BB`P000000oooo00000;40oooo002_0?ooo`030000002cYLX0/jG:00D0/jG:00H0/jC:0;:Tb@2b
Y<T0/J?90000002`XLT20:jNa`<0ZYW50P2FPKX00`3oool000000?ooo`2_0?ooo`00[P3oool00`00
0000/jG:0;>UbP050;>UbP<0/jC:0P2aXlT00`000000[Yk70:jNa`020:jNa`<0XHk10P2FPKX00`3o
ool000000?ooo`2^0?ooo`00[@3oool00`000000/jG:0;>UbP040;>UbP<0/jC:102bY<T010000000
/:780:jNa`2^W/L20:RGa080XHk10`1nIZ`00`3oool000000?ooo`2]0?ooo`00Z`3oool00`2cYLX0
00000;>UbP070;>UbP030;>TbP2bY<X0/ZC:0080/ZC900@0/J;90000002`XLP0/:78102XUl@2095k
^0<0OVJ/00<0oooo0000003oool0[03oool00:X0oooo00<0/jG:0000002cYLX0202cYLX40;:TbP80
/J;900<000000:fLa`2]W<L00P2]W<L309j;_`80TG^h0P1nIZ`20?ooo`030000003oool0oooo0:X0
oooo002Y0?ooo`8000002@2cYLX30;>TbP<0/Z?900<0/J;90000002_X<P00P2]W<L20:JD``80WX^o
0P2ANkP305i2V080oooo00<000000?ooo`3oool0Z@3oool008/0oooo00<0gia80000000000000`00
00000`1d_ol0oooo0?ooo`0D0?ooo`030000002cYLX0/jG:00X0/jG:00<0/jC:0;:TbP2bY<X00P2b
XlT0102_X<P000000:nPb02_X<P30:JD``<0RgBd0P1gGJP205i2V0<0oooo00<000000?ooo`3oool0
Z03oool008/0oooo00<0omnL04P0001d_ol06@3oool00`000000/jG:0;>UbP0;0;>UbP@0/ZC:0P2a
X/T010000000Zi_60:^KaP2[VlH20:JD``0409Z6_@2;M;@0RgBd08]d]080MefX0P1N@YP20?ooo`80
0000Z@3oool008`0oooo00<0omnL04P0001d_ol05`3oool00`000000/jG:0;>UbP0:0;>UbP<0/jC:
0P2bY<X20;:Sb@030;6Rb@000000[Yo800<0Zi_60`2JQ[d208]d]080MefX0P1N@YP40?ooo`030000
003oool0oooo0:H0oooo002=0?ooo`030?oo_`1d0000B9cO01@0oooo00<0/jG:0000002cYLX03@2c
YLX30;>TbP<0/Z?900@0[Yo80000002^WlP0[Yo80`2TT/8209Z6_@<0KeBS0P1F>I800`0l7X80oooo
0?ooo`030?ooo`030000003oool0oooo0:D0oooo002>0?ooo`030?oog`2LB000B9cO0180oooo00<0
/jG:0000002cYLX03`2cYLX40;:Tb@80/:7900@000000:ZIa@2ZVLD0ZYW50P2TT/8308E]/@80KeBS
0P1F>I8203`NPPD0oooo00<000000?ooo`3oool0Y03oool008l0oooo00<0oono07@0B02Lgol0403o
ool00`2cYLX000000;>UbP0?0;>UbP80/jC:0P2bY<T20;6Sb@030;2Qb@000000[Yk70080ZYW50`2F
PKX308E]/@80KeBS00<0ESVB03`NPP0l7X801P3oool00`000000oooo0?ooo`2S0?ooo`00R`3oool0
0`3o_g@007Bo0?ooo`020?ooo`030;md001d_ol0oooo00h0oooo0P00000@0;>UbP@0/jC:0`2aXlT2
0:jNa`040000002^W/L0XHk10:6>`@<0UX6j0P25KK4206mDX`0305HiTP0l7X80?1j200L0oooo00<0
00000?ooo`3oool0XP3oool008/0oooo00L0oono07@0B02Lgol0oooo0?oOW01804P0W=oo00h0oooo
00<000000;>UbP2cYLX03`2cYLX30;>TbP<0/ZC90`2`XLP0102^W/L000000:RGa02XUl@20:6>`@<0
OVJ/0P1WC9h204d`S@80?1j2203oool00`000000oooo0?ooo`2Q0?ooo`00S03oool01@3ogi`0B000
000000000000M;oo00h0oooo00<000000;>UbP2cYLX04@2cYLX00`2cY<X0/ZC:0;:TbP020;:Tb@05
0;6Rb@2`XLP0/:780;2Qb00000000P2XUl@3095k^0<0OVJ/00D0IdbN04d`S@1=<8d0=1Mm03`NPP09
0?ooo`800000X@3oool009h0oooo00<000000;>UbP2cYLX04P2cYLX40;:TbP<0/J;90P2]W<L01000
0000WX^o09j;_`2NRkl3095k^080OVJ/00D0IdbN04d`S@1=<8d0=1Mm01`1L@090?ooo`800000X@3o
ool009d0oooo00<000000;>UbP2cYLX04@2cYLX40;>TbP<0/Z?900H0/J;90:nPb02_X<P0[Ic70000
002VU<<309j;_`80TG^h0`1O@YP204d`S@0303@GO@0L0G40oooo00X0oooo00<000000?ooo`3oool0
WP3oool009/0oooo00<0/jG:0000002cYLX0502cYLX20;>TbP80/ZC:0P2bXlT40:nPb0030000002V
U<<0YYC300<0RgFd0P1gGJP205m2V00304DWR01=<8d0=1Mm0080705a2`3oool00`000000oooo0?oo
o`0D0?ooo`030?o4G`0D03D0Sooo0080oooo00D0oon?03D00000000001AO0<Coo`1o0?ooo`00VP3o
ool2000001L0/jG:102bY<X30;6Rb@80Zi_600@000000:JD``2JQ[d0VXJm0`2;MK@01@1gGJP0Gd:H
05m2V0159hP0;0mi0080=1Mm00<0705a0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`0:
0?o4G`0D03D0Sooo0?ooo`3ool@0Ga@001AOa03oool0a5lD000eSgl0oooo002I0?ooo`030000002c
YLX0/jG:01D0/jG:102cY<X30;:Sb@050;6Rb@2^WlP0[Yo80:^KaP000000102JQ[d208]e]00407MM
Z01O@YP0Gd:H04DWR080;0mi00<0=1Mm01`1L@3oool0303oool00`000000oooo0?ooo`0B0?ooo`0;
0?o4G`0D03D0Sooo0?ooo`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0OP3oool009P0oooo00<0
00000;>UbP2cYLX05`2cYLX20;>TbP80/ZC90P2bXlT40:jOb0030000002TT/80VXJm0080VXJm0`1_
EJ<01`1G>I<0?An304DWR0159hP0;0mi01@0KP0L0G403P3oool00`000000oooo0?ooo`0A0?ooo`0;
0?o4G`0D03D0Sooo0?ooo`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l0OP3oool009L0oooo00<0
00000;>UbP2cYLX06@2cYLX30;:Tb@@0/:790P2ZVLD00`000000Y9;20:BB`P0308E^/@80KeFS00L0
EcVC03dOP`0m7h<0ABN802`?N@0D06h0705a00l0oooo00<000000?ooo`3oool0403oool02`3oa5l0
500e08ooo`3oool0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo07h0oooo002F0?ooo`030000002c
YLX0/jG:01P0/jG:0`2cY<X20;:Tb@030;6Sb@2`XLT0/:790080[Yk700<0ZYW50000002FPKX00P2F
PKX208E^/@80KeFS0P1G>I<00`0m7h<09@Qe02`?N@0201@0KP0301`1L@3oool0oooo00d0oooo0P00
000@0?ooo`0;0?o4G`0D03D0Sooo0?ooo`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l0OP3oool0
09@0oooo00<0/jG:0000002cYLX06@2cYLX50;>TbP<0/J?90`2^W/L00`2QS/4000000:6>`@0309J1
^P0308E^/@1_EJ<0KeFS0080EcVC00H0?An302D8M@0U27D0;0mi01@0KP0L0G4;0?ooo`80omN;00@0
l]6^0=_2_`00000000003P3oool03@2?=@00000D05n?G`0D03D0Sooo0?ooo`3oohl0=@0e08ooo`3o
ool0olAO01@0=@2?ool0OP3oool009<0oooo0P00000J0;>UbP@0/jC:0`2bY<T40;2Qb080Z9O400<0
00000:6>`@2QS/400`1nIZd0101WC9h0CS2=04h`S@0e5gh203dOP`0402D8M@0/3gT0501^0000I@/0
oooo00@0omN;0?;A[P3bdJh0fl:o0P39]LH00`000000oooo0?ooo`0<0?ooo`0;0?n?=@000000000e
08ooo`3oool0ooo405lD000eSol0oooo0<AO5000=Hl0O`3oool00980oooo00<000000;>UbP2cYLX0
6`2cYLX20;>TbP80/ZC:0P2bY<T00`2aX/T0/:780;2Qb0020:fLa`030:RGa0000000TG^h0080TG^h
0P1nIZd00`1WC9h0CS2=04h`S@0203DGOP0503dOP`0U27D02`1[01@0KP0006D02`3oool20?;A[P06
0=_2_`39]LH0bKG60<VeaP2n[LP000003P3oool00`3oa5l0500e08ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0O`3oool00940oooo00<000000;>UbP2cYLX07@2cYLX40;:TbP<0/J;90`2]W<L0
0`2NRkl0000009j;_`03095k^00407iV[@1WC9h0IdbN04h`S@80=AMn00D07@9a02D8M@0;06/0501^
0000I@0:0?ooo`030?C>G03neiD0o]NE00<0e[k20`2n[LP00`000000oooo0?ooo`2D0?ooo`00S`3o
ool2000001h0/jG:102cY<X30;:Sb@<0[j380P2]W<L0102VU<<0000009j;_`2NRkl2095k^080Gd>H
00H0ARR804h`S@1><8d0=AMn01d2L@0U27D200/0J`0301@0KP0006D0oooo00P0oooo00<0m<iL0?kG
U@3F_/800P3F_/820<Jba`<0^:S900<000000?ooo`3oool0T`3oool008l0oooo00<000000;>UbP2c
YLX07P2cYLX20;>TbP80/ZC900<0/Z?90;6Rb@2aX/T00`2_X<P20:JD``040000002<MK@0S7Fd08ae
]080MejX00D0Gd>H04HXR016:8P0CS2=03DGOP0201d2L@0402D8M@0;06/0501^0000I@T0oooo00@0
o]NE0?_FW`3WbKT0ilVi0`36//L01@2lZlP0^:S90;RXb@2eYLT0000009@0oooo002=0?ooo`030;>U
bP000000/jG:0240/jG:0`2bY<T40;6Rb@<0Zi_600<0VXJm0000002JQ[d00P2<MK@207MNZ080Gd>H
00T0ARR802d@NP0e5gh0=AMn01d2L@0U27D02`1[01@0KP0006D02@3oool00`3me7@0nmJO0>O9^@03
0=6j``<0_:_80`2eYLT00`000000oooo0?ooo`2A0?ooo`00S03oool200000240/jG:102cY<X30;:S
b@<0[Yo800@0Zi_60:BB`P2TT/8000000P2JQ[d00`2<MK@0MejX07MNZ00205m3V00904HXR00]47X0
;A1j03DGOP0M0W400@1X00/0J`0006<0001U00P0oooo00<0ckL_0?_FW`3WbKT00`3A^/<20<>`a`@0
]jO90P2bXlP00`000000oooo0?ooo`2@0?ooo`00R`3oool00`000000/jG:0;>UbP0R0;>UbP80/jC:
0P2bY<T00`2bXlT0/:790;2Qb@020:jOb0<0Y9;200<0000009Z6_@2JQ[d00P1`EJ<205LjT`0903hP
P`16:8P0ARR802d@NP0D06h07@9a0040J00;06/0001S0080001U1`3oool00`3?]bl0omN00?OCY`02
0>75_080`k370P2kZLP20;NWb@80]:C800<000000;:Sb0000000T@3oool008X0oooo00<000000;>U
bP2cYLX0902cYLX30;:Tb@@0/:790P2ZVLD20:BB`P050000002FPKX0QFja08E^/@1`EJ<00P1G>Y<2
03hPP`0704HXR00]47X0501^01d2L@0106P02`1[0000H`020000I@L0oooo00@0omN00?OCY`3QaK`0
hLFl0P3=]lD40;^Yb0<0]:C80`2`X<L00`000000oooo0?ooo`2>0?ooo`00R03oool00`2cYLX00000
0;>UbP0T0;>UbP@0/ZC:0P2aXlT20;2Qb@80[Yk70P2ZVLD00`000000UX6j0000000208E^/@80L5FS
0P1G>Y<00`0n88<09@Uf02d@NP0201@0KP0501d2L@0106P02`1[0000H`0006D01P3oool0103?]bl0
omN00>75_03QaK`30<fga@80`:k70`2fY/P30;6Qb080/:3700<0[Ic60000003oool0SP3oool008L0
oooo00<0/jG:0000002cYLX0902cYLX20;>TbP80/ZC:0P2bY<T20;6Sb@<0[Yk700<0XHk10000002Q
S/400P2FPKX010000000QFja071EX`1`EJ<205LjT`0:03hPP`0U2GH09@Uf02d@NP0D06h07@9a0040
J00;06/0001S0000I@H0oooo00<0ckL_0?oGR`3bd:h00`3K`Kl20<2^a`80^JS80P2fY/P0102cXlP0
/J780;6Qb02aXLP30:fLaP030000003oool0oooo08`0oooo001/0?ooo`030?oog`2LB000M;oo01L0
oooo00<0/jG:0000002cYLX0902cYLX40;>TbP<0/ZC9102`XLP2000000<0XHk10P1oIZd01@000000
J4bN04laSP1?<Hh0=QQn0080?R2300T09@Uf02d@NP0D06h0001U0040J00;06/0001S0000FP0006D0
1@3oool00`3?]bl0omN;0=_1_`020=_1_`80bKC6102iZ<P30;>Sb0<0[ik60`2YUl<00`000000oooo
0?ooo`2;0?ooo`00K03oool00`3ooml0W4P007Boo`0F0?ooo`800000:02cYLX30;:TbP<0/J;90P2`
XLP010000000[Ic70:RGa02XUl@3095k^080OfJ]00<0000004laSP1?<Hh00P0f67h02P0n88<09@Uf
00`0J`0D06h0001U0040J0000600001S0000FP0006D50?ooo`040<ng;`3neiH0k<fd0>c=]080bKC6
0P2n[<P20;VXb080]:C800<0/j?80;2Oa`2`WlL00P2_W/H01@2[VL@0ZIO30:VG``2YUl<0000008`0
oooo001Y0?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool04P3oool00`000000/jG:
0;>UbP0W0;>UbP80/jC:0P2bY<X01@2bXlT0/J;90;6Rb@2aX/T000000080[Ic70`2NRkl2095k^080
OfJ]00<0J4bN0000001?<Hh00P0f67h01`0M0g809@Uf00`0J`0D06h0001U0040J00006000P0006<0
0`0005X0oooo0?ooo`030?ooo`030000003neiH0k<fd0080e[g2102n[<P30;BTb0@0/9o70`2[VL@3
0:B@_`030000003oool0oooo08T0oooo001Y0?ooo`060?oOW018B9`0gooo0?oog`2LB000M;oo503o
ool00`000000/jG:0;>UbP0W0;>UbP@0/jC:0`2bXlT00`2_X<P000000:nPb0030:JD``<0WX^o0P1h
GZP20613V@0604HXR0000000Cc6>03HHOP0M0g809@Uf0P0<06/00`0D06h0001U0000H0020000H`03
0000FP3oool0oooo00<0oooo00<000000>c=]03F_L800P3F_L820<JaaP<0]jO8102aXLL30:fKa@03
0:^Ia02VTl40YY?10080Y92o00<0oooo0000003oool0R@3oool006X0oooo00D0gia804RLg`3ooml0
W4P007Boo`0B0?ooo`030;>UbP000000/jG:02/0/jG:0`2bY<T20;6Rb@040000002_X<P0[j380:^K
aP<0YYC30`2<MK@00`1hGZP0H4>I0613V@0204HXR00;0000000f67h07@=b01d3LP0U2GH0301[01@0
KP0006D00@1X0000H00006<00P0005X30?ooo`030<6`9@000000nmJO0080i/Ri0P36/LH20;bZb080
]jO800<0/j?80;6Qa`2aXLL00P2^WLH20:fKa@@0YY?100@0W8Fj0000003oool00000R@3oool006X0
oooo00D0oooO09a8B02Lgml0W4P007Boo`0B0?ooo`030000002cYLX0/jG:02X0/jG:0P2cY<X20;:T
b@8000000P2aX/T30:^KaP<0VXJm0P2<MK@207QNZ080H4>I00`0ARR802hANP000000=QQn01d3LP0U
2GH0301[01@0KP0006D00@1X0000H00006<20000FP<0oooo00@0`K0U0000003Vb;T0i/Ri0P3A^/<4
0;bZb0<0/j?80`2^WLH30:RF`P80YY?10P2ORK`209b5^P030?ooo`000000oooo08L0oooo001[0?oo
o`040?oOW018B7@0M4P007Booa40oooo00<000000;>UbP2cYLX0:P2cYLX40;>TbP030000002bXlT0
/Z?900<0[Yo80`2TT/8209Z6_@80S7Fd0P1hGZP20613V@0>04HXR00^4GX0;Q5j0000000M0g800P1X
00`0J`0006<0001U0000G@000600001D0000H`0005X30?ooo`030000003Vb;T0i/Ri0080dK[30`32
[lL30;JUb0@0/9o70P2[V<@30:RF`P<0WhVl00D0W8Fj099g/P2BMk80oooo000000270?ooo`00K03o
ool00`3OW4P0000007Boo`0?0?ooo`800000;`2cYLX0102bY<T000000;:Tb@2bXlT20;2Qb@80[Yo8
00@0ZYW50:BB`P2TT/80Y9;20P25K[42071EX`80F3ZC00/0?R6304HXR016:8P0;Q5j01D0K`000000
0P1X00`0J`0006<0001U0000G@020000H0030000H`0005X0oooo0080oooo00@000000?OCY`3Qa;`0
hLBl0`32[lL20;ZXb0030;JUb02bXLL0/Z770080/9o70P2/V/D20:^Ha0<0XXfn0P2ORK`4099g/P03
0?ooo`000000oooo08D0oooo001/0?ooo`030?oog`2LB000M;oo00h0oooo00<000000;>UbP2cYLX0
;P2cYLX0102bY<X000000;:Tb@2bY<T40;2Qb@<0ZYW50`2FPKX208E^/@03071EX`1H>Y<0F3ZC0080
?R6300T0ARR802hANP0E06l07@=b0000000<06/0001S0000I@0005d00P0006001P0005@0001J0000
FP3oool0`K0U000000<0hLBl0P3=]/@30;ZXb0@0/Z770`2/V/D30:FA`080XXfn0`2FOKD3099g/P80
oooo00<000000?ooo`3oool0P`3oool007`0oooo00<000000;>UbP2cYLX0;P2cYLX00`2bY<X00000
0;:TbP040;6Sb@<0[Yk70`2QS/4209J1^P80QFja0P1`EJ<205PjT`0303hQP`0V2WH0;Q5j00805@1_
00D07@=b0000000<06/0001S0000I@020000H0060000E00005X0001J0?ooo`31/2D000000P3ad:h2
0<ffa0<0_jg70`2dXlL30:jLa@030:bJa@2WU<80YiC200<0YI700P2JP[P309Im]@<0QVRY0P3oool0
0`000000oooo0?ooo`220?ooo`00NP3oool00`2cYLX000000;>UbP0^0;>UbP040;>TbP0000000000
0;>TbP80/ZC90P2aXlT20;2Qb0030:jNa`2XUl@0Z9O400<0XHk100D0UX6j06Q=WP1XCIh0J4fN04lb
SP0205PjT`0<03hQP`0V2WH09PYf02hANP0E06l07@=b0080J0000000001S0000I@0005d0001P0P00
05@01@0005X0oooo0<6`9@0001P0lM2^0080fl2o0`2o[LL20;RVa`030;BSa`2`WlH0/9o60080[Yc5
102WU<8309f6^P80VX:h0`2;KZ`208IXZ@<0oooo00<000000?ooo`3oool0P@3oool007X0oooo00<0
00000;>UbP2cYLX0;P2cYLX00`000000/jC:0;>TbP020;:TbP80/ZC90`2`XLP40:RGa0<0TG^g00<0
OfJ]06Q=WP1XCIh00P1?<Xh04`0g6Gl0?R6303hQP`0V2WH0;Q5j01D0K`0006D00P1X00`0J`000000
001U0000G@0004T0001P0000E02j<P00oooo0<6`9@3ad:h00P3K`;l30<Rca@<0^:K7102`WlH30:VG
``<0XH^m0P2MQ[X308mc/0<0Rfj/0P26J:T20?ooo`800000PP3oool007T0oooo00<000000;>UbP2c
YLX0;P2cYLX00`000000/jG:0;>UbP030;:TbP@0/J;90P2/W<L20:RGa080WXZo0P2ANkL207mV[@80
J4fN01@0Cc:>03LIO`0g6Gl0?R6302H:MP0=06`05@1_0000I@0206P0001P0000H`000000001M0000
B@000600001D0;Xb003oool000040?gGUP80k<bd00@0eKc10;fZa`2mZ/L0_J[7102bXLL30:bIa003
0:VG``2SSkl0Xhno0080XH^m0`2CNK<308mc/080Rfj/0P26J:T40?ooo`030000003oool0oooo07l0
oooo001g0?ooo`030;>UbP000000/jG:02l0/jG:00<000000;>UbP2cY<X00`2cY<X20;:Sb@80/J;9
0P2_X<P20:bLa`<0WXZo0P2ANkL207mV[@80J4fN0P1?<Xh02`0g6Gl07P=b02H:MP0=06`05@1_0000
I@0206P0001P0000H`0005T00000008000190P0005@01@2j<P00000H0>c<]03/c;@0eKc10080aK36
0P2mZ/L00`2eY<L0/Z770;:Qa`020:jLa@80[9W4102SSkl00`2QRkd0Ugjf09=i/`0209=i/`80Sg>`
0`1nGZ<207UIX0@0oooo00<000000?ooo`3oool0OP3oool007H0oooo0P00000`0;>UbP040000002c
YLX0/jG:0;>UbP80/jC:0P2bY<T20;:Sb@<0[j380`2VU<<209j:_`<0N5jX0P1PA9T01P17:HT0Cc:>
04lbSP0g6Gl07P=b02H:MP803@1/00P05@1_0000I@000600001S0000F@0005d000000000B@80001D
00@0^S800000603/c;@0eKc11035/<H30;FTa`<0[Yc50`2VT/430:>?_`<0Ugjf0P2CNK<308=TYP80
OUjS0P1iFJ050?ooo`030000003oool0oooo07d0oooo001e0?ooo`030000002cYLX0/jG:02h0/jG:
0P0000050;>UbP<0/ZC9102aX/T20:^KaP<0YYC30P2<MK@307QNZ0050614V@17:HT0AbV902lBNP0g
6Gl00P0N0g801`0V2WH03@1/01D0K`0006D00P1X0000H00006<00P0005d01`00000000190000E02j
<P00000D0?[EX03Vb;T00P3@^<<30;ZXa`<0/9k60P2^W<D0102XUL80YY;10:JB`@2VT/4309^3^@80
Ugjf0`27JZX208=TYP80OUjS0P1iFJ060?ooo`030000003oool0oooo07`0oooo001d0?ooo`030000
002cYLX0/jG:02h0/jG:00<000000;>UbP2cYLX00`2cYLX30;>TbP030;:Tb@2bXlT0/Z?90080/J;9
0P2^WlP20:^KaP<0VXJm0P2<MK@207QNZ080H4BI00<0AbV902lBNP0_4WX00P0N0g802`0V2WH03@1/
01D0K`0006D00P1X0000H00006<0001I0000G@0004T000000080R@/900@0n]FP0>K8^@3@^<<0d;S3
0P31[LH00`2jZ<L0/j760;>QaP030;2NaP<0Z9G20`2OR;/209^3^@<0S72^0`27JZX208=TYP0307iN
X`1iFJ00NEVP00L0oooo00<000000?ooo`3oool0N`3oool007<0oooo00<000000;>UbP2cYLX0;P2c
YLX00`000000/jG:0;>UbP030;>UbP@0/jC:102bXlT30:jOb0<0Y9720P2JQ[d3071FX`80F3^C00@0
H4BI04LYR@0_4WX0;a9j0P0N0g802@0306P03@1/0000H`0006D0001L0000H00006<0001I0000G@02
0000B@8000000P3fdZP0103P`k`0`Jg60<6]aP31[LH40;>QaP<0ZiS30`2RS;d209n8^`<0TGFa0`2<
L:h208MZZP80PfBV0P1bDI/206m=V@L0oooo00<000000?ooo`3oool0NP3oool00780oooo00<00000
0;>UbP2cYLX0;P2cYLX00`000000/jG:0;>UbP030;>UbP@0/jC:0`2bY<T30;2Qb0<0ZYW50`2TTL82
08I^/080L5JS0P1H>i<0100o8H@0AbV902lBNP0_4WX201h3LP0900<0J00=06`0001S0000I@0005`0
001P0000DP0005T0`4l00080001900@0R@/9050060000000h<>l0`3;]L@30;NUaP<0[Y_400<0ZiS3
0:F@_`2UT;l00`2RS;d209Ek]0<0TGFa0P2<L:h307]JX@80MeFN00<0LU6K06m=V@1_CIT0203oool2
000007X0oooo001`0?ooo`030;>UbP000000/jG:02l0/jG:00<000000;>UbP2cYLX01P2cYLX30;:T
bP030;:Tb@2aXlT0/J?90080/:7800@0[Ik70:ZIa@2ZVLD0ZYW50`2FPKX208I^/080L5JS00<0F3^C
03lQQ00o8H@00P0_4WX201h3LP0900<0J00=06`0001S0000I@0005`0001P0000DP0005T0`4l00080
001900@0R@/901l07@3P`k`000000P3;]L@20;fZaP030;NUaP2`W/D0/9k50080[Y_4102UT;l309V0
]`80UG^d0P2AMK4307mPY080NeZQ0P1gEIh2079AV`80KdfI1`3oool2000007X0oooo001_0?ooo`80
0000;`2cYLX2000000P0/jG:0P2cY<X20;:TbP@0/J?90`2]W/L30:6>`@80UX6j0P26K[02071FX`03
05PkT`0o8H@0?b640080;a9j00T05P1_01h3LP0306P00`1X00d0K00006<0001U0000H00005800P00
05T01`30C`00D00H0500603oehd0lLn_0=Zo_`0000000`2mZ/H40;2Na@80Yi?10P2UT;l209b5^P80
VH2g0P2ENk@308AVZ080Of2T0P1kFZ4207MEWP80LU6K0P1_CIT90?ooo`030000003oool0oooo07L0
oooo001^0?ooo`030000002cYLX0/jG:02h0/jG:00<000000;>UbP2cYLX01`2cYLX40;>TbP<0/ZC9
0`2`XLP30:RGa080XHk10`1oIZ`206Q=WP80D3:>0P0o8H@0100W2gL0;a9j01H0K`0N0g8200<0J007
00d0K00006<0001U0000G0000600001B0000F@020<1?00070500603acjl0lLn_0=Zo_`37/L@00000
0<Naa0030;BRa@<0ZYO20P2WTl4309b5^P80VH2g0`29K:/308AVZ080Of2T00<0NeZQ07MEWP1gEIh0
0P1bDI/206m=V@X0oooo00<000000?ooo`3oool0403oool00`34Ga@00000000000030000000703F?
o`3oool0oon?03D00000000001AO0<Coo`1I0?ooo`00K@3oool00`000000/jG:0;>UbP0^0;>UbP03
0000002cYLX0/jG:00X0/jG:0`2bY<X00`2bY<T0/J;90;6Rb@020;2Qb0040:bLa`2XUl@0Z9O40:RG
a080TG^g0`1oIZ`00`1XCIh0D3:>050bSP0203lQQ00402L;M`0_4WX05P1_0000IP800`1X00L03@1/
0000H`0006D0001L0000H0000580001I0080`4l000<07`0M0?7?[`3J_kl00`37/L@00`000000^ZO5
0;BRa@020:jJ``80ZYO20`2PR[`209b5^P<0SW:_0`29K:/208AVZ080Of2T0P1`CYX206e;V080JTRG
0P1WAYL:0?ooo`030000003oool0oooo00l0oooo00<0olAO01@0000eSol0103oool01P3ool@0Ga@0
01AOa03oool0a5lD000eSeT0oooo001[0?ooo`030;>UbP000000/jG:02l0/jG:00<000000;>UbP2c
YLX02P2cYLX20;>TbP80/ZC:102aX/T30:bLa`<0WXZo0P2ANkL207mV[080J4fN00L0D3:>03LJO`0o
8H@09`]g00d0K00F06l0001V00800`1X00P0001O0000H`0005P0001L0000H0000580_3L00<1?0080
7`0M00@0oMJG0=Bk`@3D^l40e;_10P2jYlD010000000[Y[30:jJ``2^V/<30:>>_P<0X8Zl0P2BMk83
08ib[`80RFb[0`1hEil207ABW003071>VP1]BiP0KD^H0080JTRG0P1WAYL;0?ooo`030000003oool0
oooo00l0oooo00<0olAO01@0000eSol00`3oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0
F03oool006/0oooo00<000000;>UbP2cYLX0;P2cYLX00`000000/jG:0;>UbP0:0;>UbP<0/jC:102b
XlT30:nPb0<0YYC30P2NR[l307QNZ080HDBI00P0B2Z9050bSP0g6Wl07`Ac02L;M`0=06`05P1_0000
IP800`1X00L0001O0000H`0005P0001L0000A@000580_3L000807`0M00@0000K0=Bk`@3D^l40e;_1
0P32[LD20;6Na0040000002^V/<0[Y[30:NB`0<0Xhjn0`2FOKD2099g/P80SW:_0`1lG:8207QGW`80
M5:L0P1`CYX206e;V080JTRG0P1WAYL;0?ooo`030000003oool0oooo00l0oooo00<0oon?03D0000D
Gl@00P3oool01`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l0F03oool006X0oooo00<000000;>U
bP2cYLX0;@2cYLX2000000l0/jG:0P2bY<T20;:Sb@80/J;900<0[j380:^KaP2[VlH00`2VU<<208ae
]080N5jX0P1QA9T204PZR@0303LJO`0O17<09`]g00803@1/00P05P1_0000IP0306P0001O0000H`00
05P0001L0000A@80001B0P2l=`000`0001/0iLJi0>G6^@030<:]a@040;NSa@2aW/@0/Ik4000000<0
Yi;00`2JP[P209Im]@80TWNb0`21HZD207aLXP<0N5NO00<0M5:L071>VP1`CYX00P1]BiP206Y8U`80
IdJG303oool00`000000oooo0?ooo`0?0?ooo`0;0?ooa01O500055o40?ooo`3oScD001AO0<Coo`3o
ool0oon?03D0501Oa?l0F03oool006P0oooo0P00000_0;>UbP030000002cYLX0/jG:00h0/jG:0P2c
Y<X20;:Tb@<0/J;9102[VlH309Z6_080S7Fd0P1hGZP0101QA9T0B2Z904PZR@0g6Wl201l4L`0402L;
M`0=06`05P1_0000IP800`1X00@0001O0000H`0005`0001L0P000580102l=`00000K0?[DX03Ua[T3
0<jf`P<0]j?50P2ZU/4010000000Yi;009j7^P2NQkX309Z2^00409Im]@26J:T0QVRY08IXZ@80PF:U
0`1lG:8207QGW`0307ABW01`CYX0L4jJ0080KD^H0P1ZB9L206M6U`d0oooo0P00000@0?ooo`0:0?oo
S`0e01@0GlCo0?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4oeP0oooo001W0?ooo`030000002cYLX0
/jG:02h0/jG:00<000000;>UbP2cYLX03P2cYLX30;>TbP@0/Z?90`2^WlL30:>A`P80VXJl0P2<MK@2
07QNZ00E0654V@18:XT0B2Z9030BN`0g6Wl07`Ac02L;M`0=06`05P1_0000IP0005`00`1X0000G`00
06<0001H0000G00004D0001B0;`g002<40l0iLJi00<0c[K20P2nZL@30:jJ``80ZYK100@0000009j7
^P2NQkX0WXNj0P2JP[P208]^[0<0QVRY0P21HZD207aLXP80N5NO0P1[BIL206Q7U`80IdJG0P1VAiT2
06M;W@`0oooo0P00000<0?ooo`030?n?=@00=Hl0oooo0080oooo00T0ScD003F?o`3oohl0=@0e08oo
o`3oool0olAO01@0=@2?ool0F03oool006D0oooo0P00000`0;>UbP030000002cYLX0/jG:00d0/jG:
102cY<X30;:Tb@<0/:7800<0[Yo70:VIa@2YVLD00P2STL8308I^/080LEJS0P1H>i<204PZR@0>030B
N`0g6Wl07`Ac00<0J@0=06`0001S0000IP0005`00`1X0000G`0006<0001H0000G00004D308`@3`03
0?KAZ03N`[`0g/:l0080_ZW40P2cWl<30:jJ``80XXbm00<0000009j7^P2NQkX00`2?M;0208]^[080
QVRY0P21HZD3075?VP80KTbI00<0JdVG06Q7U`1XAiL00P1WAYL206I7V@80Id^M2@3oool20>[j_004
0>KZd@3oool0oooo000000/0oooo00d0oon?03D0501Oa?l0oooo0?o4G`0D01@0GlCo0?ooa01O5000
=Hoo0?ooo`34Ga@003F?05T0oooo00190?ooo`050?oo_`1d000000000000M02oool05`3oool00`00
0000/jG:0;>UbP0^0;>UbP030000002cYLX0/jG:00l0/jG:0P2cY<X20;:TbP030;:Tb@2aXlT0/J?9
0080/:78102YVLD209J1^P<0QVj`00`0LEJS05PkT`1H>i<0@2:404PZR@0`4W/05`1_01l4L`0306T0
3@1/0000H`0006H20000G0040000G`000500001H0<AC0080001500@0S10?0?KAZ03fdJP0g/:l0P39
/L<40;>O``<0YY2o0P2RS;d00`000000U7Vc09Ai/`0208md/080Rfj/0`1jFJ0207EDW@80LDnJ0P1^
C9T00`1[BIL0J4NG06Q7U`0206M6U`<0ITNI0P1WBid70?ooo`030<c/S03Zn[`0i^[A0080f=?D0P3;
`]800`000000oooo0?ooo`090?ooo`050?o4G`0D000000000000000eSol00P3oool01@3oohl0=@00
0000000055l0a?oo05T0oooo00190?ooo`060;md001d_ol0oooo0?oOW018B9`0gooo503oool00`2c
YLX000000;>UbP0^0;>UbP8000004`2cYLX30;:TbP@0/J?90`2]WLL30:6>`080UX6j0P26K[02075F
X`0:05PkT`108X@0:0ag030BN`0G06l07`Ac00<0J@0=06`0001S0000IP80001L00@0001O0000D000
05P0a5<00P0004D00`2<40l0m]6X0=k2_0030<Va``030;ZUa02cWl<0/io30080ZYG00P2VT;l309Qo
]P030000002DNK<0PfBW0080PfBW0P1nGZ<207YIX080MEBM0`1aCiX00`1^C9T0JdVG06]9U`0206Q7
U`80IdJG0P1VAiT206M;W@L0oooo00@0j_Zl0>KZd@3Hdm@0f=?D0P3;`]820<:gc`030000003oool0
oooo06d0oooo00180?ooo`070?oo_`1dB9`0gooo0?ooo`3ookl0M01809cOo`0C0?ooo`030;>UbP00
0000/jG:02h0/jG:00<000000;>UbP2cYLX04@2cYLX40;>TbP<0/Z?90`2`X<P00`2]WLL0Z9O40:RG
a0020:6>`080UX6j0`1YCIh0101@<hh0F3^C040RQ00X37L2030BN`0901L0K`0O17<00`1Y00d0K000
06<0001V0000G00005l0001@0080001H0P0004D00`1C01d0omN>0=Rl_P020=Rl_P<0^ZG40`2ZUL03
09b4^@<0V7nf00@0000008QZZP23I:L0PfBW0P1nGZ<307YIX080MEBM0P1aCiX00`1^C9T0JdVG06]9
U`0206Q7U`80IdJG0P1VAiT206M;W@H0oooo00@0^n1g0>_bc@3Mfm@0gM_D0P3?am<30<:gc`030;b`
c@000000000006d0oooo00180?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0B0?ooo`80
0000;`2cYLX00`000000/jG:0;>UbP0C0;>UbP80/jC:0P2bY<T00`2bXlT0/J;90;6Rb@020;2Pb0@0
Z9O40P2ANkL207mV[080JDfN0P1@<hh2040RQ00802P<M`0`4W/05`1_01l4L`0306T03@1/0000H`00
06H20000G0040000G`0005P0001H0<AC0080D`0M0`3H_;h20<B]``@0[i[20P2QRK/309b4^@<0S72^
00@0000008=TY`23I:L0PfBW0P1nGZ<207YIX080MEBM0P1aCiX00`1^C9T0JdVG06]9U`0206Q7U`80
IdJG0`1^F:T207QY]P@0oooo00D0W/YK0>cha03/n<@0hnCC0<o7d`040<Fjd0<0_;3=00<0oooo0000
003oool0J`3oool004P0oooo00L0omnL04P0001d_ol0oooo0?oOW018B9`0gooo0140oooo00<00000
0;>UbP2cYLX0;P2cYLX00`000000/jG:0;>UbP0E0;>UbP<0/ZC90`2aX/T40:bLaP<0WHZn0P2ANkL2
07mV[00=06U=WP1@<hh0D3>>03PJO`108X@0:0ag030BN`0G06l0001V00<0J@0=06`0001S0000IP02
0000G0030000G`000500001H0080a5<000<0D`0M0>W9]03YbK@00`34[L<00`2eWl80[i[20:nJ`P02
0:F>_@80XHVk0`2AM[4208a`[P0408QZZP000000PfBW08=TY`80OUjS0`1_CIT206a9V080JDNG00<0
IdJG06I7V01VAiP00P1VBI/206U?X080KURY0`1hJKH30?ooo`030=OcVP3/n<@0hnCC0080e<kD00<0
b;kA0<Fjd035^]000P2n//h30;V[c0030?ooo`000000oooo06X0oooo00180?ooo`060?oOW018B9`0
W7@00000000004P0W=oo4@3oool00`000000/jG:0;>UbP0^0;>UbP030000002cYLX0/jG:01@0/jG:
0`2cY<X40;:Sb@80[io80P2/W<H20:JD``80WHZn0P2ANkL207mV[00=06U=WP1@<hh0D3>>03PJO`0P
1G<0:0ag00h0K00G06l0001V00<0J@0005l0001S0000EP020000G0030000G`000500_c/00080a5<0
00<08`0P0>W9]03A]l000P3A]l030;FO`P<0YHjm0`2FO;@2095f/@80S72^0P28JZX00`000000MeFN
07MEWP02079AV`80KdfI0P1/BIP206U7U`0306M6U`1VAiP0ITNH0080ITVK0P1YCj0306iHZ@80N6Vf
0P3oool00`000000k?S40>?Td`020=C>e0<0b;kA0P2n//h20;Z]c@80^J_<00<0]jW;000000000000
JP3oool004P0oooo00<0oono07@0M02oool04P3oool200000300/jG:00<000000;>UbP2cYLX0502c
YLX40;>TbP030;:Tb@2bXlT0/Z?90080/J;90P2_WlP30:JD``<0RgBd0P1hGZP20654V@80D3>>00X0
>1Yo0205L`0X37L03P1/01L0K`0006H00`1Y0000G`0006<0001F0P0005`00`000440001@0;lk0003
02<08080dKO00`2nYl830:ZD_`030:F>_@2JPKL0VX6g00<0UWbd00@0TGJa081PY020H:@0P62T0P1k
Fj4010000000MeFN079AV`1bDI/306m=V@80K4VH00<0JDNG06M6U`1WAYL00P1VAiP206I9V`80JDnP
0P1^F:T40;SHl0040<OXQ@3XkM00fMKD0=WFe080c<CB0`30]<l40;Z]c@80000000<0]jW;0?ooo`00
0000J@3oool004T0oooo00H0_g@007Boo`3oool0okmd0018W03Oool=0?ooo`030;>UbP000000/jG:
02h0/jG:0P00000F0;>UbP@0/jC:0`2bY<T30;6Rb@@0Zi[60P2JQK`308]d]080N5jX00@0HDBI04PZ
R@1@<hh0>1Yo0P0P1G<01`0X37L03P1/01L0K`0006H0001O0000H`0005H00P0005`00`000440001@
0000D0020;lk00050?WCX@3Sa;P0hlBh0<^a`@2nYl800P2`V/420:ZD_`@0VX6g0P2FO;@208EVZ080
P62T0P1kFj400`1gEIh0000007MEWP02079AV`80KdfI0P1/BIP00`1YAiL0IdJG06M6U`0206I7V080
ITVK0P1YCj0309VQfP80^=S`00@000000>S]d03Ie]@0fMKD0P3<a=830<>hd0<0^jk=0`2gZ/`30;FW
b`030?ooo`000000oooo06L0oooo00190?ooo`050?oog`2LB00000000000B02Lgol03P3oool00`00
0000/jG:0;>UbP0]0;>UbP030000002cYLX0/jG:01P0/jG:0`2bY<X40;6Sb@80[Yk70P2[V/H20:>A
`P80VXFl0P2;M;@207QNZ0030654V@18:XT0<1=k0080>1Yo00P080Ec02P<M`0>06`05`1_0000IP03
06T0001O0000H`<0001L0P0005020;lk00040?WCX@3Sa;P0bk710<^a`@@0/9[10P2OQkX309Z1]`<0
RFb[00@0QFJX081PY020H:@0P62T0P1kFj40101gEIh00000079AV`1bDI/206m=V@80K4VH00<0JDNG
06M6U`1WAYL00P1VAiP206I9V`<0PW[20`2IXMX0102gnKd0joC;0>_db`3Og]@20=39d`<0`kS@0P2m
/<h00`2k[/d0^:_<0;R[c0040;JXb`80]:K;00<0oooo0000003oool0IP3oool005X0oooo0P00000_
0;>UbP030000002cYLX0/jG:01P0/jG:0P2cY<X20;:TbP030;:Tb@2aXlT0/J?90080/:780P2^W/L3
0:>A`P80VXFl0`1aEZ<205TkU00=04PZR@0`4g/0<1=k03PJO`0P1G<0101Y00h0K00G06l0001V00<0
J@0005l0001S0000EP020000G0050000@@000500_c/00000403Sa;P00P3;/L430;VQ`@<0Y8fl0P2O
QkX308ib[`80RFb[0P25IZP2081PY080Ne^Q0P1gEIh00`000000JTRG06Y8U`0206M6U`80ITJH00<0
ITRJ06Q<WP1XC9h00P1/E:D207=R/@<0PW[200D0VJ7J0;Oi_@000000joC;0=oNe0020=39d`<0a[_@
0`2m/<h30;R[c0<0]ZS;0P2dYl/20;BVb`030?ooo`000000oooo06D0oooo001I0?ooo`030000002c
YLX0/jG:02h0/jG:00<000000;>UbP2cYLX0602cYLX40;>TbP<0/ZC90`2`XLP30:VHa@80Xi7200<0
UH2j08E]/025KK000P1aEZ<205TkU080B2Z900h0<1=k01P0L00P1G<0101Y00h0K00006<0001V0000
F`0005l0001S0000EP38E`00001L0000@@80SQ@D00<0omJ50=^n^`3K_[/00P34Zl400`2iXL40Zi>n
0:^C_P020:B=_0<0TgRb0`2>LZl00`29K:/0QFJX08EVZ00307ABW080L4jJ0P1]BiP010000000JTRG
06M6U`1WAYL206I6V00306I8VP1XC9h0J4bN0080K5BU0`1cH[42089j`P040;Oi_@000000jo[10>GW
dP80e]3D0P39`=430;jccP@0^Jc<0`2fZ</30;BWb`<0]:K:00<0oooo0000003oool0I03oool005L0
oooo00<0/jG:0000002cYLX0;`2cYLX00`000000/jG:0;>UbP0K0;>UbP<0/ZC:102aX/T20:fMa`<0
ZIS50`2EP;X208E]/00B075FX`1I>i@0FC^D044SQ@18:XT0<1=k01P0L00P1G<0101Y00h0K00006<0
001V0000F`0005l0001=0000EP38E`00001L0P0004400`2>51@0fkjk0=^n^`030<B[`@@0Zi>n0P2H
O[D309=h/P80SW:_0P1mG:8207QGW`80M5:L0P1`CYX206e;V00406Y8U`000000IdJG06M6U`80ITJH
0P1VB9X206Q<WP80K5BU0P1cH[430<Ggk@040>_j`@3Uim80e]3D0=K@e080bL3A0P31]/l20;jccP80
^Zg=0`2gZL/30;FWb`@0]:K:0P2cYLX00`3oool000000?ooo`1S0?ooo`00E`3oool00`000000/jG:
0;>UbP0]0;>UbP800000702cYLX30;>TbP80/ZC:00<0/Z?90;6Rb@2aX/T00P2_X<P20:fMa`<0X8g0
0P2EP;X208E]/006075FX`1I>i@0FC^D044SQ@0Y37P0<1=k0P0H0700200P1G<0101Y0000H`0006H0
001K0000G`0004d0001F0P38E`020000@@0408hD503^bjl0k/^_0=Bg_@<0/Y^o0P2[Tkh209j5^080
V7je0P2CN;83089RY@0307eLXP1hEil0N5NO00<0M5:L0P1`CYX206e;V00306Y8U`000000IdJG0080
ITJH0P1VB9X206Q<WP80K5BU102^aN/01031i7h0jNo?0>W_c`3Kf=@20<g5dP@0`KK?0P2j[Ld20;NZ
c0030;NYb`2eYl/0]JO;0080]JO;00<0]:K;0;BVbP2dY/X00P2dYLX20;>UbP030?ooo`000000oooo
0680oooo001E0?ooo`800000;`2cYLX00`000000/jG:0;>UbP0L0;>UbP@0/jC:0`2bXlT30:nPb0<0
YiK40P2PSL0307mV[080JDfN00<0DC>?05TkU0118hD00P0Y37P02@0`4g/0601`0205L`0406T03P1/
0000H`0006H0001O0000C@020000EP050<QG00000440001102H0903^bjl00P3D]kd0102mY;l0/Y^o
0;:K_`2bVkl309j5^080V7je0`26J:T2089RY@80OEbR0P1hEil207ABW080L4jJ0P1]BiP206Y8U`03
0000001VAYP0ITJH0080ITRJ0P1XC9h3092Bd@80[/G[00@000000>W_c`3Ykll0fmSD0`3=aM820<Bi
d0<0^jo=0`2gZ/`40;FWb`<0]:K;0`2dYLX20;>UbP030000002cYLX000000680oooo001D0?ooo`03
0;>UbP000000/jG:02h0/jG:00<000000;>UbP2cYLX0702cYLX30;>TbP<0/ZC90`2aX/T30:bLaP80
YiK40`2@N[L307mV[00306U=WP1A<hl0>A^00080@B>500X0:@ah030CN`0H070080Ec00@0J@0>06`0
001S0000IP0005/0001O0P0005H20<QG000405L08@3^bjl0e;Nm0=Bg_@<0_JBo0`2TRkX209j5^0<0
S6n]0P26J:T2089RY@80OEbR0P1hEil207ABW080L4jJ0P1]BiP206Y8U`0306M6U`000000ITJH00<0
L5f/0P1lLK/3092Bd@040;omd03LmZ40k?O80>7Qe0<0d/cC0P34^M020;facP@0^:_<0`2fZ</30;BV
b`<0]:K:1`2cYLX00`000000oooo0?ooo`1O0?ooo`00D`3oool00`2cYLX000000;>UbP0^0;>UbP03
0000002cYLX0/jG:01h0/jG:0`2cY<X00`2bY<T0/Z?90;:Sb@020;6Rb@040:nOb02/W<H0[9c60:bL
aP80WHVn0`2@N[L207mV[00A06U=WP1A<hl0>A^003TKP0118hD0:@ah00l0K@0H0700001V00@0J@00
05l0001S0000IP0005/0001O0000C@0005H00P38E`000`1G0240o=BI0>O5]0020<b`_P<0[9>l0P2T
RkX3095e/0<0S6n]00<0QVRY089RY@22HZD00`1aCi/206i<V@80JdVG0P1XAiL206M6U`80ITNI00<0
Id^M0000001ZDJ<00P1`GJ`307aa^`05092Bd@2ooM00_og@0>cgb03QhM@00P3Bc=<30<Nmd@<0_K7>
00<0^Jc<0;R[c02hZl`00`2fZ</20;FWb`030;BVb`2dY/X0]:K:0080]:K:1`2cYLX00`3oool00000
0?ooo`1O0?ooo`00DP3oool2000002l0/jG:00<000000;>UbP2cYLX07P2cYLX40;>TbP@0/Z?90`2_
WlP30:FC``80WHVn0`1hGJL20654V@80DC>?00h0>A^00246M00Y37P03`1]01P0L00006H0101Y0000
G`0006<0001E0000F`0005l0001=0<4o0080b5L000<09P0T0?cDV@3</;h00P3</;h0102fW;h0[9>l
0:bC_02/Tk`209Mk/`<0TGF`0P2<Kjd207YIX080MUBM0P1aCi/206i<V@80JdVG0P1XAiL206M6U`80
ITNI00<0Id^M06YAX`0000000`1`GJ`207aa^`80_og@00@0cNf<0>KZd@3Vj]40f=?D0P3;`]840;nc
cP<0^Jc<0`2fZ</30;FWb`@0]:K:2P2cYLX00`000000oooo0?ooo`1M0?ooo`00D@3oool00`000000
/jG:0;>UbP0]0;>UbP800000802cYLX40;>TbP<0/ZC90`2`XLP30:^Ja@80YI?30`2;Lk<207QMY`80
HDBI0100BB^9054cS`0i6h008@Id02T<N00?06d0601`0000IP0406T0001O0000H`0005D0001K0000
?@0004d0`Cl00`0V02@00`3hdJ80gkjh0=nn^0030;JL_P<0WH>f0P2GNk<2095e/0<0OejS00<0NUVP
07IDW@1fE9d00`1aCi/206i<V@80JdVG0P1XAiL206M6U`0506I7V@1WBid0Id^M06YAX`0000000P1`
GJ`30<3ZlP040000003Vj]40i^[A0=SCe0<0bl;B0P32]ll30;^^c@<0]jW<102eYl/30;BVbPd0/jG:
00<000000?ooo`3oool0G03oool004l0oooo00<0/jG:0000002cYLX0;P2cYLX00`000000/jG:0;>U
bP0R0;>UbP<0/ZC90`2aXlT20;2Qb0040:jNa`2[V/D0Zi[50:^Ja@80VHBl0`2;Lk<01P1hGJL0HDBI
0654V@19:hT0<AAl03TKP0808@Id00T0:@ah00l0K@0H0700001V00@0J@0006<0001E0000F`0003d0
0P0004d20<4o000300008@3O_[P0gkjh0080a:Rm00<0]Ybn0:F:^@2UR[T00P2MPkH308U[ZP80Q6FW
0P1oGZ<207YIX080MUBM0P1aCi/206i<V@80JdVG0P1XAiL206M6U`0306I7V@1WBid0Id^M0080JU6S
00H000000:>bh`2S/^<0Xk;S0:c`Z03SnJd20=gKe0<0clOC0P32]ll20;b`c@030;^^c@2hZ/`0^:[<
0080]jW<0`2eYl/20;BVb`030;BVbP2dYLX0]:G:00`0/jG:00<0oooo0000003oool0G03oool004l0
oooo00<000000;>UbP2cYLX0;@2cYLX00`000000/jG:0;>UbP0R0;>UbP80/jC:0P2bY<T0102bXlT0
/J?90;6Sb@2aXlT30:jNa`<0Xi310P2IQ;`208]c/`0407QMY`1QA9T0HDBI04T[R@80<AAl00T0>A^0
0246M00Y37P03`1]01P0L00006H0101Y0000G`0006<00P0005/20000C@80`Cl000<0000J0=nn^034
Z;d00P34Z;d30:F:^@<0Sg:^0P29JjX308AUY`0307mNX`1jFJ00NUVP0080MUBM0P1aCi/206i<V@80
JdVG0P1XAiL206M6U`0406I7V@1gJKH0MfVf07MY]P80R8G900H000000:>bh`2/l:P000000>cha@3S
i=<20<o7d`<0aK[@0`2l/<d40;RZc0<0]JO;0`2dY//30;BUbPh0/jG:00<000000?ooo`3oool0FP3o
ool004d0oooo0P00000_0;>UbP030000002cYLX0/jG:0280/jG:102cY<X30;:Sb@<0/:780`2YV<@2
0:>@`@<0QFb_0P1`EJ<0501I>i<0@B>504T[R@19:hT0<AAl03TKP00Q1W@01@1Z00l0K@0H0700001V
00@0J@0005l0001S0000E@0005/0000m0000C@31?`00T1PJ0P3bc:X0103F][X0[Y>k0:jC^`2^Tk/2
0:F:^@0409Ei/@2?LZh0Sg:^08mb[P80RF^Z0P24IJL0101oGZ<0KdfI06m=V@1_CIT206a:V080JDNG
0P1WAYL206I7V080ITVK0P1XCZ000`1]F:P0MfVf07MY]P0308R5b@80000000@0k?S50>?Td`3Si=<0
e<kD0P38_]440;jbcP<0^J_<0`2fZ</30;BVb`@0]:K:3P2cYLX3000005/0oooo001<0?ooo`030;>U
bP000000/jG:02h0/jG:00<000000;>UbP2cYLX08P2cYLX30;>TbP<0/ZC90`2aX/T20;2Qb0040:fL
aP2YV<@0ZIS40:VHa080U7ni0`25K:l04P1`EJ<0FC^C044SQ@118hD0BB^9034DO00I07008@Id00D0
JP0?06d0001S0000IP0005/0001O0000H`0005D0001K0000?@<0T1PJ00@0l/bZ0=Jf^P3F][X0^inl
0`2^Tk/309Ei/@80Sg:^0P29JjX307MFWP0307=AV`1_CIT0KdfI0080K4ZH0P1YAiL206M6U`80ITNH
0P1VBI/206Q>X00506eHZ01gJKH0MfVf07MY]P28QLT00P33oN4010000000hnCC0>?Td`3Dc]@30<Rn
d@030<2dc`2n//h0_[;>0080^Zg=0`2gZL/40;FWb`@0]:K:4@2cYLX00`3oool000000?ooo`1I0?oo
o`00B`3oool2000002h0/jG:0P00000V0;>UbP030;>TbP2bY<X0/ZC:0080/ZC900@0/Z?90;6Rb@2a
X/T0/J;90`2]W<H309n<_`80U7ni0P25K:l04@1`EJ<0FC^C05TkT`118hD0:@eh034DO00I07008@Id
00D0JP0?06d0001S0000IP0005/0001O0000B`0005D0c5/00080000m00@0T1PJ05X09@3F][X0e[Jj
0`2kWk`309b1]080UGVa0`21HJ@207aKX@80MeJN00@0Le6K06m=V@1_CIT0KdfI0P1/BYP206U7U`80
IdJG0P1VAiP206I9V`0306Q>X01]F:P0KERX0080MfVf0P33oN40102Ig8@0j?^h0000003Ie]@30<c3
dP<0`;C?0P2j[Ld20;NZc080]jW;0`2eYl/40;BVbQ@0/jG:00<000000?ooo`3oool0E`3oool004X0
oooo00<000000;>UbP2cYLX0;@2cYLX00`000000/jG:0;>UbP0V0;>UbP@0/ZC:0`2bXlT30:nOb0<0
YiG30P2OS;l307iTZ`80JDbM0P1I>i<03P118hD0:@eh034DO00a57`06@1`0246M00506X0001S0000
IP0005/0001O0000B`0005D0c5/00P0003d00`2@61X0FP0U0>[5[`020<b]^P<0YXZg0P2LPK@308IW
Z080PF6T0P1lFj4207MFWP80Le6K0P1_CIT206a:V080JDNG0P1WAYL206I7V080ITVK00<0J4jP06eH
Z01]F:P00`2hfO401@2Ig8@0j?^h0=oNe03Og]@000000080c<?B0P33^=030;^^c@@0]j[<0`2eYl/3
0;BVbQL0/jG:00<000000?ooo`3oool0EP3oool004T0oooo00<000000;>UbP2cYLX0;@2cYLX00`00
0000/jG:0;>UbP0V0;>UbP<0/jC:0`2bY<T30;2Qb0<0Zi_60P2WUL<308mi]P80OVB[0P1YC9d00`1A
<hh0>Qb0044SQ@0202T=N009034DO00I07008@Id00D0JP0?06d0001S0000IP0005l0001;0080001E
0P0003d00`1J02D0j/F_0<b]^P020<b]^P040;:E^@2VR[L0YXZg0:J:]`80SFj/0P26IjP3085QY003
07aKX@1gEYh0MeJN0080Le6K0P1_CIT206a:V080JDNG0P1WAYL206I7V080ITVK00<0J4jP09VQfP2I
XMX00P2IXMX00`2Ig8@0h?RW0=oNe0020=oNe0040=39d`000000`kS@0<>hd0<0_K3>0`2hZl`30;JX
b`<0]:K;102dY/XE0;>UbP030?ooo`000000oooo05H0oooo00170?ooo`030;>UbP000000/jG:02h0
/jG:00<000000;>UbP2cYLX09@2cYLX40;>TbP<0/ZC90P2aXlT20;2Qb0040:jNa`2[VlH0Zi_60:^K
aP80W8Nm0`2?NKH0101nI:/0JDbM06U<W@1A<hh203XLP00;044SQ@0Y3GP0<AAl01T0L00Q1W@01@1Z
00l0K@0006<0001V0000F`0005l00P0005D0103<F`00FP0U05X09@3kdI`20>6m/`<0/YFi0`2DMZl2
08e^[080QVNX0P21HJ@00`1lFj40MeJN07MFWP0306Y8U`80J4NG0P1VAYP206I8VP80IdbN0P1[E:D2
07=R/003085j`P2IXMX0VJ7J0080]ORk00@0joW10>GWdP3Uim80d<WC0P36^m0010000000_K3>0;f`
cP2m/<h20;V/c0040;R[c02fZ</0]ZS;0;JXb`80]:O;0P2dY//30;BVbQP0/jG:00<000000?ooo`3o
ool0E03oool004H0oooo00<0/jG:0000002cYLX0;P2cYLX00`000000/jG:0;>UbP0W0;>UbP80/jC:
0`2bY<T40;6Sb@<0[Yk70`2TT/8209b7_@80SgVf00@0OVB[06U<W@1YC9d0DC>>0P0j78003@118hD0
:@eh00l0K@0I0700001W00D0JP0005l0001S0000IP0005/0001O0000B`0005D00P3<F`000`1J02D0
hKfc0>6m/`020<:S^@030;:E^@2MOk80WGnb0080U7J_0P2=KZ`208IWZ0<0M5>L00<0L4jJ06e;V01]
BiP00P1ZB9L206Q7U`80ITJH0P1VB9X206M<WP80JeBU0P1cH[02085j`P80]ORk00@0joW10>GWdP3F
d=@0e]3D0`39`=400`2n/lh000000;jccP030;V/c0<0]ZS;102dYl/30;BVbQX0/jG:00<000000?oo
o`3oool0D`3oool004D0oooo00<0/jG:0000002cYLX0;@2cYLX2000002X0/jG:102cY<X30;:Sb@<0
/:780`2YVLD20:BB`P<0RG:b0P1gG:H04P1QA9P0BB^904T[R@1A<hh0>Qb00286M00Y3GP03`1]01T0
L00006L01@1Z0000G`0006<0001D0000F`0005l0001;0<=21P80c5/000<0:@0W0>6m/`32XkT00P32
XkT309eo/P80U7J_0`1nGZ8207UHW`80M5>L00<0L4jJ06e;V01]BiP00P1ZB9L206Q7U`80ITJH0P1V
B9X306M<WP0306]DY@1cH[00Lf:`00<0a?O]00@000000>W_c`3Kf=@0fmSD0`39`=420<6fc`030;Z]
c@000000^Zg=00@0]jW;0`2eYl/30;BVbQ`0/jG:00<0oooo0000003oool0D`3oool002T0oooo00D0
okmd000000000000001809cOo`0F0?ooo`800000;P2cYLX00`000000/jG:0;>UbP0Y0;>UbP<0/jC:
0`2bY<T00`2bXlT0/J;90;6Rb@020;2Qb0040:fMa`2YVLD0ZIW50:VIa@80V8:k0`29L[80201gG:H0
HDBH04T[R@19:hT0<QAl03XLP00R1W@0:@eh0P0?06d02@0I07001@1Z0000G`0006<0001D0000F`2/
G@00001;0<=21P0302T09`030?G<Y03G/kH0Z8Ze0080Z8Ze0P2MOk8308ATYP80OUjR0P1iF9l207AC
W080L4jJ0P1]BiP206Y8U`80J4NG0P1VAYP206I8VP80IdbN00<0JeBU0:k6j`2^a^/00P2^a^/00`2Q
iI@0i_Zc0=_He0020=_He080cLGB0P31]/l20;^_c@030;Z]c@00000000000080]jW;0`2eYl/20;BV
b`030;BVbP2dYLX0]:G:01/0/jG:00<000000;>UbP000000D`3oool002P0oooo00L0omnL04P0B02L
gol0oooo0?noM00007@0_ooo01@0oooo00<000000;>UbP2cYLX0;@2cYLX00`000000/jG:0;>UbP0Y
0;>UbP<0/jC:102bY<T40;6Rb@<0[Ig70`2QS/0209R2^`80RG:b00D0MebV0654V01QA9P0BB^9038D
O00203XLP00:0286M00Y3GP03`1]01T0L00006L01@1Z0000H`0005@0001K0:aM0080001;0P33@PH0
100002<0ek>f0=Nc]P2gV;L30:R:]@80RfbY0P24I:H307iNXP80NERO00<0M5>L071>VP1`CYX00P1]
BiP206Y8U`80J4NG0P1VAYP206I8VP80IdbN0P2@T]420:k6j`030:7UU0000000hN7C0080hN7C00@0
cLGB0<Bid034^M00a;W@102k[ld20;NZc0040000002eYl/0]JO;0;FWb`<0]:K;102dYLXM0;>UbP03
0000003oool0oooo0500oooo000X0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0C0?oo
o`030000002cYLX0/jG:02d0/jG:00<000000;>UbP2cYLX0:@2cYLX30;>TbP@0/ZC90`2bXlT30:nO
b0<0YiK40P2QS/0308=Z[P80KeBR00h0FC^C0654V019:hT0BB^9038DO00j78008PId02T=N00?06d0
6@1`0000I`0506X0001O0000H`80001K0P0004/20<=21P80ek>f0`2gV;L309=d[@80RfbY0P24I:H2
07iNXP80NERO00<0M5>L071>VP1`CYX00P1]BiP206Y8U`80J4NG0P1VAYP206I8VP<0Ng2k0P2@T]40
102QiI@000000>7Qd`3QhM<20=;<d`<0akgA0`2m/Lh30;R[c080]ZS;00<000000;BVb`2dY//00P2d
Y//30;BVbQl0/jG:00<0oooo0000003oool04@3oool01@34Ga@000000000000001@0GlCo0080oooo
00D0oon?03D00000000001AO0<Coo`0c0?ooo`00:03oool01`3ogi`0B01809cOo`3oool0okmd0000
M02oool04P3oool00`000000/jG:0;>UbP0]0;>UbP030000002cYLX0/jG:02`0/jG:0`2cY<X30;:S
b@<0/:780P2_WlP00`2/VlH0YiK40:NFa00309=l^080PfZ^0P1_E:805@1I>i<0@R>504T[R@19:hT0
<QAl03XLP00R1W@01@1Z00l0K@0006<0001W00D0JP0005l0001S0000E00005/0[5d00000B`33@PH0
TQ`O0>g5Z`020<^X]P<0WWj`0P2CM:d208]/Z@80Q6BV0`1bD9/206i<V@0306]9U`1XAiL0J4NG0080
IdJG0P1VAiT206M;W080JE6S0P1`G:`207]`^`05092Bd@2moLl0_Og?0>[j_@3VjM400P3Gdm@30<Nm
d@80_k?>0`2i[<`40;JXb`030;FWb`000000]JO;00<0]:K:8`2cYLX00`000000oooo0?ooo`0>0?oo
o`0=0?n?=@0055l0a?oo0?ooo`3oohl0=@0D05o4o`3ool@0Ga@001AOa03oool0a5lD000eS`0c0?oo
o`00:@3oool01@3ookl0M00000000000B9`0gooo0140oooo00<0/jG:0000002cYLX0;@2cYLX20000
02h0/jG:0`2cY<X20;:Tb@80/Z?900@0/J;90;2Qb02`XLP0/:780`2/VlH209j:_P<0Tgbh00@0PfZ^
06mDXP1_E:80FC^C0P128hD03P19:hT0<QAl01T0L@0R1W@01@1Z00l0K@0006<0001W0000FP0005l0
001S0000E00005/0[5d00`2B71l30<^X]P050:b;/`2NO[00WWj`09in/02CM:d00`1lFj0207MEW@80
LU2K0P1^C9T00`1[BIL0J4NG06Q7U`0206M6U`80ITNI0P1WBi`206UAX`80L5b/0P1kL;/20;gmc`03
0000003VjM40em?D0080em?D0P3;`]820;nccP80^jk=0P2i[<`00`2gZL`0]ZS;0;JXb`030;FWb`03
0000002dY/X0]:K:02D0/jG:00<000000?ooo`3oool04P3oool02@2?=@00=Hoo0?ooS`0e03D0Sooo
0?ooo`3oa5l0500e08ooo`0b0?ooo`00:03oool01`3ookl0M01809cOo`3oool0gia80018W03Oool0
3`3oool00`2cYLX000000;>UbP0]0;>UbP030000002cYLX0/jG:02d0/jG:0`2cY<X40;:Tb@<0/J;9
0`2^W/L30:FC`P80WXZn0P2CO;P206Q;W00A054cSP1I>i<0FC^C048SQ@0[3WP0<QAl01T0L@0R1W@0
1@1Z00l0K@0006<0001W0000FP0005l000190000E03?GP000P2/G@00102B71l0o=6E0>:k[`3R^jl3
0:b;/`80WWj`0P22HJ@207aKX080MeFM0P1bD9/206i<V@80JdVG0P1XAiL206M6U`80ITNI0P1WBi`2
06UAX`06071L[030jo80`>_b0<3[lP000000i?Z^0`3Mfm@0103;`]80`[O?0<:gc`32]ll40;^^c@<0
]jW<0`2eYl/20;BVbP030000002cYLX0/jG:02@0/jG:00<0oooo0000003oool04@3oool02P3oohl0
=@0D05o4o`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?lb0?ooo`00:03oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0M02oool03P3oool2000002h0/jG:00<000000;>UbP2cYLX0;02cYLX40;>TbP<0
/ZC90`2bXlT30;2Pb0030:jNa`2ZVLD0ZYW50080YI?20`2=M[@207aRZ@0506Q;W01A<hh0DC>>05Tk
T`128hD00P0[3WP02`0b57`06@1a0286M00506X03`1]0000H`0005X0001O0000B@0005@0ceh00080
[5d000<0TQ`O0>:k[`3R^jl00P2nVk@20:b;/`<0RVVW00@0PV6T07aKX01lFj00O5^P0P1gEId00`1b
D9/0KTbI06i<V@0206]9U`80J4NG0P1WAYL206I7V@80Id^L0P1YDJ<30:>ci0040:[^YP000000gM_D
0=gKe080clOC0`35^]030;b`c@<0^:[<0`2eYl/40;BVb`030;BUbP000000]:G:02H0/jG:00<00000
0?ooo`3oool03@3oool0303oa5l050000000501Oa?l0oooo0?n?=@0055l0a?oo0?ooo`3oohl0=@0D
05o4oc80oooo000X0?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P004RL0=ooo`0=0?ooo`030000002c
YLX0/jG:02d0/jG:00<000000;>UbP2cYLX0;`2cYLX30;>TbP040;:Tb@2bXlT0/Z?90;:Sb@80/J;8
0P2`X<P40:ZIa@80VXBk0`2=M[@01@1lHZT0J4^L06Q;W01A<hh0>Qb10080@R>500X0:`ih038DO00I
07408PId00D0JP0?06d0001S0000I`0005l000190P0005@20:aM000305`0:@3R^jl0_Y^d0080_Y^d
0`2CLj/208YYY`80PV6T0P1lFj0207MEW@03079@V`1^C9T0KTbI0080JdVG0P1XAiL206M6U`80ITNI
0P1WBi`308R5b@050:>ci02ZkZH0Z^jV0>cha@3Si=<00P3Dc]@30<Fjd080_[;>00@0_;3=0;V[c02i
Zl`0^:[<0P2fZ</20;FWb`<0]:K;0P2dY/X00`2dYLX000000;>UbP0T0;>UbP030000002cYLX00000
0100oooo00X0a5lD000eS`3oool0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo<P3oool002T0oooo
00D0omnL04P000000000001d0;ooo`0=0?ooo`030000002cYLX0/jG:02d0/jG:00<000000;>UbP2c
YLX0;`2cYLX40;>TbP<0/Z?9102aX/P30:fLaP<0XXo00P2JQ;/208ef]00407aRZ@1XBi`0J4^L054c
SP80>Qb100h0@R>502/>N00@06h06@1a0000I`0506X03`1]0000H`0006L0001J0000G`0004T0001D
0<mN0080G00Y00<0ml^O0=J_/@2POZh00P2POZh209=cZ`80RVVW0P22HJ@3071>V@80K4ZH00<0JDRG
06M6U`1WAYL00P1VAiP206I9V`80J4jP0P1]F:P207MX]P80R8G90P2ZkZH00`3/n<D0hnCC0=C>e002
0=C>e080b;kA0`2n//h30;V[c0@0]ZS;0`2dY//30;BVbP80/jG:00<000000;>UbP2cYLX0902cYLX0
0`3oool000000?ooo`0>0?ooo`0:0?o4G`0D03D0Sooo0?ooS`0e03D0Sooo0?ooo`3oa5l0500e08oo
oc80oooo000j0?ooo`030000002cYLX0/jG:02`0/jG:0P00000a0;>UbP@0/jC:0`2bY<T30;6Sb@<0
[io700<0[Ic60:RF``2XU/<00P2RSl0308M^/080MEZU0180H4:G04T[R@1A<hh0DC>>03XLP@0S1gD0
:`ih0100KP0I0740001W00D0JP0005l0001S0000D`0005X0001O0000B@0005@20<mN000405`0:@3F
[k40eZna0;6>/@<0X7j^00@0Tg>[07YHWP1jF9h0NURN0P1dDY`2071>V@80K4ZH00<0JDRG06M6U`1W
AYL00P1VAiP206I9V`80J4jP0P1]F:P207MX]P0508R5b@32o^00`_kP0:[CIP3Xk=000`3IeM@20<Rn
d@80`;C?102j[Ld30;NYb`<0]JO;0`2dY/X50;>UbP030000002cYLX0/jG:02@0/jG:00<0oooo0000
003oool02@3oool03@3oa5l0500e08ooo`3oool0a5lD000eS`3oool0ooo405lD000eSol0oooo0<AO
5000=Hl0<`3oool003T0oooo00<000000;>UbP2cYLX0;02cYLX00`000000/jG:0;>UbP0`0;>UbP<0
/jC:0`2bY<T30;:Sb@030;6Sb@2`XLP0/:780080[io7102XU/<209En^0<0Qfj`01<0MEZU0612U`19
:hT0BB^9054cSP0j78408`Me02/>N00@06h06@1a0000I`0506X0001O0000H`0005<0001J0000G`00
04T0a4D<0080ceh00P3F[k430;6>/@<0RFNU00<0PEnR07YHWP1jF9h00P1dDY`3071>V@0406a:V01Y
B9L0IdJG06M6U`<0ITNH0P1VBI/206Q>X080KERX00D0MfRf0<;nh032o^00Um^20>S/d0020=WEe0<0
c<?B0`30]<l20;^^c@<0]j[<0`2eYl/40;BVbPL0/jG:00<000000;>UbP2cYLX09@2cYLX00`000000
oooo0?ooo`080?ooo`050?n?=@00000000000000=@2?ool00P3oool01@3oohl0=@000000000055l0
a?oo03<0oooo000g0?ooo`030;>UbP000000/jG:02d0/jG:00<000000;>UbP2cYLX0<P2cYLX30;>T
bP030;:Tb@2bXlT0/Z?90080/Z?9102`XLP30:^Ja@<0WXZn0P2EO[P208M^/00607EJY@1P@YL0H4:G
04T[R@0c5G`0>Qb10P0S1gD20100KP80001W00T0001O0000H`0005<0001J0;1P000004T0a4D<02`0
:P0202H00P3^`ZH01038XK40/Hja09AbZ@2DLZT208UWY@04085OXP1jF9h0NURN07YHWP80M5:L0P1`
CYT00`1/BYP0JDRG06U8U`0206M6U`80ITNH0P1VBI/206Q>X080KERX0P2hfO4209OKPP040>_db`3O
g]@0d<WC0=39d`@0`kS@0P2k[/d20;R[c0030;NZc02fZ</0]ZS;0080]JO;00<0]:K;0;BVbP2dY/X0
0P2dY/X70;>UbP030000002cYLX0/jG:02D0/jG:00<000000?ooo`3oool0AP3oool003H0oooo0P00
000^0;>UbP030000002cYLX0/jG:03<0/jG:0`2cY<X40;:Sb@<0/J;90`2^WLL30:FB`P80WXZn0P2E
O[P306iAW`80H4:G00D0BB^903<EO00c5G`0>Qb102<7M@020100KP80001W0P0005l00`0005<0001J
0;1P00020000B@030<A5300202H0k/:V0080b:6a0`2DLZT208UWY@80PEnR0P1jF9h207ABW080L4jI
00<0K4ZH06U8U`1YB9L00P1WAYL206I7V080ITVK0P1XCZ0309VQf`80Um^200<0joC;0=oNe03@bM<0
0P3@bM<20<Jkd0<0_K3>0`2hZl`40;JXb`<0]:K;0`2dY/X80;>UbP030000002cYLX0/jG:02@0/jG:
00<0oooo0000003oool0AP3oool003D0oooo00<000000;>UbP2cYLX0;@2cYLX00`000000/jG:0;>U
bP0c0;>UbP<0/jC:0`2bY<T30;6Sb@<0[io80P2^WLL00`2YV<@0YI;20:FB`P0308mh]@80P6J[0P1^
DIl01`1H>Y80@R>504T[R@19:hT0<aEl03XLP@0S1gD00P0@06h20000I`80001O0P0005<01@0005X0
00190000B@34A@`0000D0080b:6a0P2TP:d309AbZ@0308UWY@21Gj80PEnR0080NURN0`1[BIL206Q7
U`0406M7V01VB9X0IdJG06M6U`<0JeBU0P1cH[02085i`P0409VQf`2cmkT0/oNi0>_i`@80iNKB0P3F
d=@20<Jkd080_[?>102i[<`30;JXb`<0]:O;0`2dY/X;0;>UbP030000002cYLX0/jG:02D0/jG:00<0
00000?ooo`3oool0A03oool003@0oooo00<000000;>UbP2cYLX0;@2cYLX00`000000/jG:0;>UbP0b
0;>UbP<0/jC:102bY<T20;:Sb@80/J?900@0/:780:nOb02_WlP0[io80`2YV<@209Z5^`<0SgRe00@0
P6J[06iAW`1^DIl0F3ZB0P128hD01019:hT0<aEl01X1LP0S1gD20100KP80001W0P0005l20000D`05
0000FP2`H00000190<A5303md9000P3R]j/00`2iTZh0Y82]0:B0[@0209AbZ@80NEJM0P1cD9X206i<
V080JdVG0P1XAiL00`1WAiP0ITRJ06I8VP0206M<WP80JeBU0P1cH[02085i`P80/oNi00@000000>GV
dP3Ui]80e]3D0`39`=430;jccP030;Z]c@2i[<`0^Jc<0080]jW;00@0]ZS;0;FWb`2eYl/0]:O;102d
Y/X<0;>UbP030000002cYLX0/jG:02@0/jG:0P0000150?ooo`00<P3oool00`2cYLX000000;>UbP0]
0;>UbP800000=02cYLX50;>TbP80/ZC9102bXlT30;2Qb0<0[9_60`2RS/0209Z5^`80SgRe00<0P6J[
06iAW`1^DIl00P1H>Y801@128hD0:`mi03<EO00J0G808`Me0080401^0P0006L20000G`80001C00@0
001J0;1P002C7b<0TalS0P3R]j/20;VB[P<0RVJT0P20GJ000`1iEYd0Le2J07=@VP0206i<V080JdVG
0P1XAiL00`1WAiP0ITRJ06I8VP0206M<WP<0JeBU0P1cH[000`21NL80`oS/000000020>W_c`030=_H
e03=aM80cLGB00@0`KK?0`2j[Ld30;NYb`<0]JO;102dY/X>0;>UbP030000002cYLX0/jG:0280/jG:
00@000000;>UbP3oool00000A03oool00380oooo00<000000;>UbP2cYLX0;02cYLX00`000000/jG:
0;>UbP0c0;>UbPL0/jC:0`2bXlT30;6Rb@<0[Yk700<0[9_60:ND``2WU<<00P2RS/0308U`/080NEfV
00L0ITRJ054bS@1H>Y80F3ZB048SQ@0[3gT0<aEl00806P5b00@01P1[0100KP0006L0001W0P0005l2
0000D`050=9Q002`H000TalS05h0;@3R]j/00P2iTZh209MbY`80RVJT0P20GJ0207UFW@80Le2J0P1^
C9P206]9U`0306Q7U`1WAiP0IdNH0080ITRJ0P1WC9h206]DY@80Lf:`00D0`oS/09oTT@2Oi940jNo?
0=_He0030<g5dP80a;W@0`2k[ld30;NZc0@0]JO;0`2dY//30;BUbPh0/jG:00<000000;>UbP2cYLX0
9@2cYLX00`000000oooo0?ooo`110?ooo`00<@3oool00`000000/jG:0;>UbP0/0;>UbP030000002c
YLX0/jG:03H0/jG:0`2cY<X30;:Tb@D0/J;900<0[j380:jNa`2^W/L0102WU<<209En^0<0RG2`00H0
NEfV06I8VP1A<Xd0DC:=03/LP@128hD202/?N@806P5b00@01P1[0100KP0006@0001W0P0005l20000
D`060=9Q002`H000TalS02l0;@3gbI/0djR]0`2GLZL308YVY003081MX01iEYd0NEJM0080Le2J0P1^
C9P206]9U`0306Q7U`1WAiP0IdNH0080ITRJ0P1WC9h206]DY@80[/K/0P2Oi9400`3/m/P0hN7C0>7Q
d`020=;<d`80a;W@0P2m/Lh40;R[c0<0]ZS;0`2dY//30;BVbQ40/jG:00<000000;>UbP2cYLX09@2c
YLX00`000000oooo0?ooo`100?ooo`00;`3oool2000002h0/jG:00<000000;>UbP2cYLX0=P2cYLX3
0;>TbP@0/ZC900@0/Z?90;6Rb@2aX/T0/J;90`2_X<P30:ZIa@<0WXVm0P2EO[P208U`/00407UMYP1V
B9X0ITRJ054bS@80>ab100X0@R>502/?N@0J0G806P5b00H0J`0@06h0001T0000I`0005X0001O0P00
05<0103BH@00/60005h0;@0402P20=>X[@040:Z3Z`2GLZL0Ug:W09MbY`80RVJT00<0P5fP07UFW@1i
EYd00P1cD9X206i<V080JdVG00<0J4NG06M7V01WAiP00P1VB9X307]`^`80Si;B0P2Oi940103LmZ80
hN7C0>7Qd`3Bc=<30<Nmd@<0_K7>00<0^Jc<0;R[c02hZl`00`2fZ</20;FWb`030;BVb`2dY/X0]:K:
0080]:K:4P2cYLX00`000000/jG:0;>UbP0T0;>UbP030?ooo`000000oooo0400oooo000]0?ooo`03
0;>UbP000000/jG:02h0/jG:00<000000;>UbP2cYLX0=P2cYLX30;>TbP@0/ZC90`2bXlT30;2Qb0<0
[Ic600<0ZYW50:B@`@2TT<400P2NRKd209En^0<0LEFQ0P1VB9X01@1A<Xd0>ab103/LP@128hD0:`mi
00806P5b00P01P1[0000H00006@0001W0000FP0005l000170000D`80dV4000<0GP0]0=>X[@3CZ:d0
0`2ZPj/209MbY`<0N5BK00<0LTnI06e;V01]BiP00P1ZB9L206M7U`80ITNI00<0Id^L06UAX`1YDJ<0
0P1`G:`307]`^`0308nBdP2koLd0g?JR0080i^WA00@0em?D0<_2dP3;`]80bl;B0`2o/lh30;V/c0<0
]ZS;0`2eYl/40;BVbQ@0/jG:00<000000;>UbP2cYLX09@2cYLX00`000000oooo0?ooo`0n0?ooo`00
;@3oool00`000000/jG:0;>UbP0/0;>UbP800000=`2cYLX40;>TbP<0/ZC90`2bXlT30;6Rb0030;2Q
b02^W/L0[Yk70080[Ic6102TT<4208mg]080PVR/0P1aEJ401`1N?iD0BBZ8054bS@1A<Xd0>ab102<8
MP0[3gT00P0J0G80200606/0001P0000I0000580001J0000G`0004L0001C0P3BH@00100_02d0kKjR
0<:H[032V:`20:Z3Z`<0P5bN0P1hE9/00`1bCiT0KD^H06e;V00206Y8U`80IdNG0P1VAiT00`1WBi`0
JE6S06UAX`03071L[080Ng2k00D0^og=08oAL`3VjM40i^WA0=OCe0030<_2dP80`[O?0`2k[/d30;NY
c0@0]JO;0`2dY/XG0;>UbP030000002cYLX0/jG:02D0/jG:00<000000?ooo`3oool0?@3oool002`0
oooo00<000000;>UbP2cYLX0;02cYLX00`000000/jG:0;>UbP0f0;>UbPH0/jC:0`2bY<T20;:Sb@03
0;6Rb@2aX/P0/J;800@0[Yk70`2XU/<309V3^P80SgNd0P22J:`04`1aEJ40GSnE04TZR019:XP0DC:=
03/LP@0S27H0:`mi0140K`0J0G801P1[0000H00006@0001B0000FP2dH`0000170<E84@3BH@000P0_
02d30<:H[0<0S6JR0P20G9h207QDV`80LTnI0P1]BiP206Y8U`80IdNG00<0ITNI06M;W01WBi`00P1Y
DJ<2071L[080_n_b00<0Sm5c0>Cj[P3[l/d00P3Mfm@20<o7d`80`[O?0P2l/<d20;^^c@030;RZc02g
ZL`0]jW<00<0]JO;0P2dY//00`2dY/X0]:G:0;BUbP0G0;>UbP030000002cYLX0/jG:02@0/jG:0P00
000n0?ooo`00:P3oool00`2cYLX000000;>UbP0]0;>UbP030000002cYLX0/jG:03P0/jG:1@2cY<X4
0;:Tb@<0/J;90`2_WlL30:^Ia@030:RF``2PS;h0X8bn0080VH>j0P2?Mk@2089X[006075EX@1N?iD0
GSnE04TZR00c5Wd0>ab10P0S27H0200A06l06P5b0000J00606/0001T0000DP0005X0]6<00P0004L2
02l0;@0300@0:03O/:L0gk2W0080VgBV0`2<IZ800`20G9h0N5BK07QDV`02079?V@80KD^H0P1ZB9L2
06M7U`0306I7V@1WBi`0Id^L0080JE6S0`2S/n@20:S]X`040>_bc@3Mfm@0gM_D0<o7d`<0a;[@102l
/<d30;RZc0<0]JO;0`2dY//30;BUbQP0/jG:00<000000;>UbP2cYLX08P2cYLX010000000/jG:0;>U
bP00000m0?ooo`00:P3oool00`000000/jG:0;>UbP0/0;>UbP030000002cYLX0/jG:03T0/jG:102c
Y<X30;:Tb@<0/Z?90`2`XLP30:fLaP80ZiW50`2PS;h209V3^P<0NenW0P1ZC9`205hoU@0304TZR00c
5Wd0<aIm00808`Qf00H04@1_01X1LP0006P01P1[0000H00006@20000FP8000170P35B140100001l0
gk2W0;:7Z02bQjP209]dYP80S6JR00<0P5bN07QDV`1hE9/00P1bCiT206e;V080JTRG0P1WAiL00`1V
AiT0Id^L06M;W00308N5b@80Xk?T00D0Z>fS0=SdV`3/n<D0hn?C0=C>d`030<Rnd@<0_[;>0`2iZl`3
0;JXb`<0]:K;102dY/XJ0;>UbP030000002cYLX0/jG:02D0/jG:00<000000?ooo`3oool0>P3oool0
02T0oooo00<000000;>UbP2cYLX0;02cYLX00`000000/jG:0;>UbP0i0;>UbP<0/jC:0`2bY<T30;:S
b@<0/J;80P2`XLP0102^W/L0[Ic60:fLaP2]W<H30:FB`@040:2<_P29Kjl0RFn_08U_[`80NenW0P1Z
C9`01@1G=i00@R>404TZR019:XP0<aIm00808`Qf00d04@1_0000I00006P01P1[0000H00006@0001B
0000FP2dH`0000170<E84@2D8RL0gk2W00<0/XNX0P2KM:H307QCVP03075>V01/BYL0K4ZG0080JDRG
0P1WAiP206M9V`80J4jP00<0KERX07MX]@1gJ;D00`27QLT01@2XkJ<000000>cha@3Shm<0e<kC00<0
b;kA0P30]<l30;Z]c@@0]jW;0`2eYl/30;BVbQd0/jG:00<000000;>UbP2cYLX0902cYLX00`3oool0
00000?ooo`0j0?ooo`009`3oool2000002d0/jG:0P00000j0;>UbPH0/jC:0`2bY<T20;:Sb@040;6R
b@2aX/P0/J;80;6Rb0<0[Yk70`2XU/<0102UT/40W8Jk09b6^`2DO;H308U_[`0407]OY`1ZC9`0JTbL
05LgT080@R>400d0BBZ803<FO@0S27H08`Qf0140K`0006@0001X0000FP000600001T0000DP0005X0
]6<000<0U28W00@0mlJH0<fOZ02bQjP0/XNX0`21G9d207QCVP03075>V01/BYL0K4ZG0080JDRG0P1W
AiP206M9V`80J4jP00P0KERX07MX]@1gJ;D0MfRe08N5b@31o]l000000>Wj^@<0fMGD0P3<`m820<2d
c`80^jk=0P2j[Ld00`2gZ/`0]jW;0;NYb`030;FWb`<0]:K:7`2cYLX00`000000/jG:0;>UbP0U0;>U
bP030000003oool0oooo03P0oooo000U0?ooo`800000;P2cYLX00`000000/jG:0;>UbP0i0;>UbPP0
/jC:0`2bY<T30;6Rb@<0[io70`2[VLD20:RF``<0W8Jk0P2DO;H208U_[`0407]OY`1ZC9`0JTbL05Lg
T080@R>400`0;0mj03<FO@0S27H08`Qf0140K`0006@0001X0000FP00060000150000DP3EH`020;AS
000409@R9`1O02l0cInX0<fOZ0<0SfNQ0P21G9d207QCVP80LDjH0P1/BYL206U8U`80IdNH00<0IdVK
06Q>X01XCZ000P1]F:P207MX]@040<7ng`2FfH00U]V00>_db`80gmgD00@0c<?B0<>hc`33^<l0`kS?
102k[/d30;NZc0<0]JO;0`2dY/XQ0;>UbP030000002cYLX0/jG:02D0/jG:00<000000?ooo`3oool0
=`3oool000H0oooo00<0omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo01D0oooo
00<000000;>UbP2cYLX0;02cYLX00`000000/jG:0;>UbP0i0;>UbPL0/jC:0`2bY<T30;:Sb@<0/:38
0P2_WlL00`2]W<H0ZiW50:^Ia@030:6=_P80W8Jk0`22IZX207=FX@0A0693U`1?<8/0EcN@05LgT012
8h@0;0mj03<FO@0K0W<08`Qf00H0K00A06l0001X0000FP00060000150000DP3EH`000P2dH`001@2D
8RL0G`0_0<fOZ03=WjP0XWRT0080SfNQ0`21G9d00`1hDiX0LDjH075>V00206a:U`80JDRG0P1WAiP0
0`1WBI/0J4jP06Q>X00206eHZ0<0^=[b00D0U]V00>_db`3OgM@0gmgD0=39d`030<Jkd0<0_K3>0`2h
Zl`30;JXb`@0]:K;0`2dY/XP0;>UbP030000002cYLX0/jG:02@0/jG:00<0oooo0000003oool0=`3o
ool000H0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo503oool00`00
0000/jG:0;>UbP0/0;>UbP030000002cYLX0/jG:03`0/jG:0`2cY<X30;:Tb@D0/Z?900@0/J780;2P
b02`X<P0/:380`2]W<H20:FB`@<0XHfn0P2=M;83089VZP0607=FX@1R@iL0Cc2;04l`R`1G=i00@R>4
0P0/3gX0200K0W<08`Qf00H0K00A06l0001T0000J000060000150P0005820;AS000305l0;`3=WjP0
cInX00<0XWRT0P2?Ij42085LW@0307QCVP1aCYP0LDjH0080K4ZG0P1YB9L206M7V00306M9V`1XCZ00
J4jP00@0VJ;K00D0U]V00>_i`@3[nL40iNKB0=39d`030<Jkd080_[?>00<0_K3>0;V/c02i[<`0102f
Z</30;BWb`@0]:K:8P2cYLX00`000000/jG:0;>UbP0T0;>UbP030?ooo`000000oooo03H0oooo0006
0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool04@3oool00`2c
YLX000000;>UbP0]0;>UbP030000002cYLX0/jG:03`0/jG:102cY<X00`2bY<X0/ZC90;:Tb@040;:S
b@<0/J780`2^WLH30:RF``80YI;10`2FO[L208ed/P80PVJZ00H0LeJQ0693U`1R@iL0Cc2;03/LP@12
8h@202`?NP0;01/2L`0S27H01P1/0140K`0006@0001X0000FP00060000150000DP3EH`000P1O02l2
0>ZiX0030;^=YP2RN:@0XWRT0080SfNQ0`1aCYP00`1/BYL0JDRH06U8V00206Q9VP80J4fN0P1/E:D0
0`1cH[00PG[2085j`P0209VRf`030;;f]`000000joW100<0e]3D0P39`=430;jccP<0^Jc<00<0]jW;
0;JXb`2fZ</00P2eYl/00`2dYl/0]:K:0;BVbP020;BVbR@0/jG:00<000000;>UbP2cYLX08`2cYLX0
0`000000/jG:0000000f0?ooo`001P3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo0100oooo00<0/jG:0000002cYLX0;02cYLX2000003h0/jG:102cY<X30;:TbP<0
/Z?90`2aX/P40:nOa`80ZiW40P2XU/<309f7^`80UWjg0P2=M;8306a=W080HT>G00<0Cc2;03/LP@0k
78400P0/3gX02P0K0W<0001Y00H0K0000600001T0000J00005X0001P0000A@0005820=ES000405l0
;`3Z^J00^hfV0;^=YP<0Q5fL0P1iDiX2075>V00306a:U`1YB9P0JDRH0080J4VJ0P1XCIh206aDY@80
Lf:`0P21N/80102bm[L000000>_i`@3Ykll20=_He0040<W0d@31]/l0`KK?0<6fc`@0^Zg=0`2gZL/3
0;FWb`<0]:K:9`2cYLX00`000000/jG:0;>UbP0U0;>UbP030000003oool0oooo03<0oooo00060?oo
o`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol03`3oool2000002d0
/jG:00<000000;>UbP2cYLX0?@2cYLX60;>TbP<0/ZC9102aX/T20;2Pb080[io70P2/VlD20:^Ia080
XXfn0`2MQk/208I[[@80NUfU0P1/CI`01@1K>i80B2R704l`R`1?<8/0>ab10080;0mj00X06`9c0000
J@0606`0001P0000I0000580001J0000H00004D0a4PF0P3EH`001@0`02l0^hfV0;^=YP2kSJH0TfZO
0080Q5fL0P1iDiX2075>V00306a:U`1YB9P0JDRH00<0J4VJ0P1XCIh00`1/E:D0Lf:`07=R/0030<?h
k0030>Oj/`3Ykll0fmSD00<0cLGB0P34^M030;^_c@<0]j[<0`2eYl/40;BVb`<0]:G:9P2cYLX00`00
0000/jG:0;>UbP0T0;>UbP030?ooo`000000oooo03<0oooo00060?ooo`0;0?oOW01807@0_ooo0?oo
o`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol03P3oool010000000]:G:0;BUbP2dYLX[0;>UbP03
0000002cYLX0/jG:03l0/jG:102cY<X40;:Tb@030;:Sb@2aX/T0/J;90080/:780P2`X<P30:bKa@<0
YI;10P2RSKh3091f/`80QV^]00@0NUfU06a=W01/CI`0Fc^B0P18:8L03P1?<8/0>ab102`?NP0/3gX0
4@1`01/2L`0606`0001P0000I0000580001J0;UU000004D0a4PF0P0`02l00`0602T0fJNT0=VWY002
09=ZW`<0Q5fL0P1iDiX00`1aCYP0K4ZG06a:U`0206U8V080J4VJ0P1XCIh00`1/E:D0[/O/0:k7k002
0:k7k00309gRS`3/m/P0hN7C00<0d/cC0P34^M020;facP040;^_c@2hZl`0^:_<0;NZc080]ZS;0P2e
Yl/30;BVb`80]:K:00<0]:G:0;>UbP2cYLX09P2cYLX00`000000/jG:0;>UbP0U0;>UbP030000003o
ool0oooo0340oooo00040?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`0=0?ooo`030000002dY/X0]:K:02`0/jG:00<000000;>UbP2cYLX0@02cYLX3
0;>TbP80/ZC:0P2bY<T30;:Sb@<0/:780`2^WLH30:RE``80YI;10`2GOkL2091f/`80QV^]00@0NUfU
06a=W01/CI`0Fc^B0P18:8L0300d5Wd0>ab102@9M`0/3gX04@1`01/2L`0006T01P1/0000H0000580
001J0;UU008000150P34B1H20=VWY080ZGbS0P2CJYl208AMW080NE>J00<0LDjH06a:U`1/BYL00P1Y
B9P206Q9VP80J4fN0P2@T]820:k7k00309gRS`3MmZ80hN7C00<0d/cC0P37_M430;facP<0^:_<102f
Z</30;BVb`<0]:K::P2cYLX00`000000/jG:0;>UbP0U0;>UbP030000003oool0oooo0300oooo0005
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0303oool00`2e
Y/T000000;FVb@040;BUbRT0/jG:00<000000;>UbP2cYLX0@02cYLX30;>TbP<0/ZC:0`2bXlT40;6R
b080[ik70P2^WLH0102ZV<@0Z9G30:RE``2XUL<209f6^`80Ugng0P2@M[<3079DW`0506A4U`1C<hd0
Fc^B05/kTP18:8L00P0d5Wd02P0T2GL0;0mj0140L00K0W<0001Y00H0K0000600001T0000DP0005X2
0000A@030<A85P0602T0fJNT00<0ZGbS0P2CJYl208AMW080NE>J00<0LDjH06a:U`1/BYL00P1YB9P3
075M[080O72k0P2@T]80102MhXl000000>KYd@3VjM420=SCe0030<Nmd@2o/lh0_k?>0080_k?>0`2i
[<`30;JXb`<0]JO;0`2dY/X]0;>UbP030000002cYLX0/jG:02@0/jG:00<0oooo0000003oool0<03o
ool000H0oooo00<0omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00`0oooo00<0
00000;FVb@2eY/T00`2dYLXX0;>UbP800000A02cYLX30;>TbP@0/Z?90P2aX/T20;6Rb080[io70P2_
W/L30:ZHa0<0XHbn0P2MQ[/208U][P80Of:W0P1bE9l01@1TA9L0Dc>=05<cS@1K>i80B2R70080=1Im
010090Ug00H0KP0A0700001V0000J@0606`0001P0000I0000580001J0;UU000004D0a4PF09<R:`3d
`IP0aIFT0P2YO:<307]EVP80LdnH0P1]BiP00`1ZBYT0JDbM06U<W@0206]BX`80LEf/0P1lL;/00`2@
T]80^oc;0;_lb`020>KYd@040=SCe03;`]80bl;B0<_2dP80`[O?0`2k[/d30;NYc0<0]JO;102dY/X_
0;>UbP030000002cYLX0/jG:02D0/jG:00<000000?ooo`3oool0;P3oool001/0oooo00<000000;NW
b@2gYlT00`2dYLXX0;>UbP030000002cYLX0/jG:03l0/jG:202cY<X00`2bY<T0/Z?90;:Sb@020;6S
b@80/J;90`2_WlL30:bJa@<0YI700P2QS;h3095g/`80RFf^0P1oHZL01@1bE9l0I4BG05<cS@1C<hd0
@B:40080B2R700`0=1Im02@9M`0606h04@1`0000IP0006T0001K0000H00004<0001B0=MS002iI@02
09<R:`040?C1V035UJ@0aIFT0<FEY080R5nL0P1kEIX207=?V080KD^H00<0JTZI06U<W@1YC9d00P1[
DZ<2075M[080O72k0P2ko</010000000jo7=0=gKe03Mfm@20<o7d`80`[O?0P2l/<d00`2k[/d0^:[<
0;RZc0020;NYc0<0]JO;00<0]:K;0;BVbP2dY/X00P2dYLX_0;>UbP030000002cYLX0/jG:02<0/jG:
00<000000;>UbP000000;`3oool001T0oooo0P0000000`2iZLT0]JK90;FVb@020;FVb@<0]:G:9@2c
YLX00`000000/jG:0;>UbP110;>UbPH0/jC:0`2bY<T30;6Sb@<0/:780`2]W<H20:bJa@040:ND`P2U
TL00YI700:FA`080Ugng0P2AMk<208U][P80Of:W00@0LUBO06A4U`1TA9L0Dc>=0P118X@03018:8L0
=1Im02@9M`0606h04@1`0000IP0006T0001K0000H00004<0001B0=MS0080^FD000@0Tb8[0<FEY035
UJ@0aIFT0P2JKYl01@28Gi`0NeFJ07]EVP1kEIX0LdnH0080KD^H0P1ZBYT206U<W@80Je:S00H0LEf/
0<3]lP30kO80`>gb0000003[lLd20=gKe080clOC0P35^]030;b`c@@0^:[<0`2eYl/30;BVb`<0]:G:
<02cYLX00`000000/jG:0;>UbP0T0;>UbP030?ooo`000000oooo02d0oooo000H0?ooo`050000002m
ZlP0^JW90;VYb@2fYlT00P2eY/T30;BUbRD0/jG:00<000000;>UbP2cYLX0@`2cYLX30;>TbP<0/ZC9
102bXlT30;6Qb080[Yk70`2]W<H30:ND`P<0W8Jj0P2GOkL0102AMk<0MeRQ07MHX@1gF:4206];VP80
I4BG0P1C<hd02`118X@0;15k03@FO@0K0g@090Ug00H0KP0A0700001V0000F`00060000130080001B
0P2iI@000`2C8R/0i;2O0>B`W`0309Y^W`80R5nL0P1kEIX00`1cCiP0KD^H06e;V00206Y:V@80JDbM
0P1[DZ<30:Bdi0040:O/X@3Im9/0hn?C0>?Sd`80e<kC00<0aK[@0;jbcP2n//h00P2n//h30;V[c0<0
]ZS;0`2dY//30;BVbS<0/jG:00<000000;>UbP2cYLX09@2cYLX00`000000oooo0?ooo`0?0?ooo`05
0?oo_`1d000000000005000_Sol00P3oool01@3ookl0M00000000000B9`0gooo0100oooo000G0?oo
o`040000002mZlP0_J_80;f[b0<0]ZO90`2dYLXU0;>UbP030000002cYLX0/jG:0480/jG:102cY<X3
0;:TbP@0/Z?90P2aX/P00`2aXLP0[io70:nOa`020:jNa`<0ZIO30`2PRkd209b6^P80Ugng0P21I:P2
07MHX@80Jd^J00l0GCbB04d]R@1C<hd0Dc>=044RQ00/4G/0=1Im01/3M00T2GL01P1^0140L00006H0
001Y0000F`0006000P000580103GH`00G`0b05l0<P3T/9l20;:3XP80VVjO0P28Gi`207]EVP0307=?
V01]BiP0KD^H0080JTZI0P1YC9d308V6b@030:Bdi02Wk:40YnbQ0080hn?C00D0e<kC0<Rnd@38_]40
b;kA0<2dc`020;jbcP80^Zg=0`2gZL/40;FWb`<0]:K:=@2cYLX2000002H0/jG:00<000000?ooo`3o
ool03@3oool03@3ooml0W4P004RLg`3ool@0E0d00011_`3oool0oooO09a80018W=l0oooo0=nLB000
M;l0403oool001H0oooo00<000000<>_aP33[lH00`2hZ<T40;FVbR@0/jG:0P0000140;>UbP@0/jC:
0P2cY<T00`2bY<X0/ZC90;:Tb@020;:Sb@<0/J;80`2_WlL40:^Ia080Y8no0P2PRkd3095g/P80RVj^
0P21I:P207MHX@0606];VP1M?980CBf904d]R@1C<hd0@B:40P0/4G/02P0K0g@0001/00H0KP0A0700
001V0000J@0005/0001P0000@`0005820=MS000405l0<P2bPj80/X>R0;:3XP80VVjO0`1fDIT2071>
V@0306e=W01]DJ40KE6Q0080L5VX0P1iJKD208V6b@80YnbQ00@0jOZh0>S/d03JeM@0f]GD0P3<`m83
0<2dc`80^Zg=0P2gZ/`20;NYb`<0]JO;0`2dY/Xh0;>UbP030000002cYLX0/jG:02<0/jG:00<0oooo
0000003oool03@3oool00`34G`l00000000000030000000800mOa03ookl0M01d0;ooo`3oool0omnL
04P0M02oool?0?ooo`005P3oool00`000000`jo60<>_aP020;bZb0<0]ZK90`2dYLTR0;>UbP030000
002cYLX0/jG:04D0/jG:0P2cY<X30;>Tb@<0/ZC9102aX/T30;2Pb080[I_50P2[VL@20:JC`@80Y8no
0P2FO[H3095g/P0308Y^[P21I:P0PFBX0080MeRQ00H0Jd^J05dlTP1=;HT0CBf903XMP@118X@202`A
N`0:01/3M00006`01P1^0000HP0006H0001B0000F`00060000130<566`80ef<000@0<00`0=2MXP2b
Pj80/X>R0`1oF9X207IAV@80L4jI00<0KDfL06eAX@1]DJ400P1`FJP207UY]@0508V6b@32o]d0`_kM
0:cDIP3Xk=000P3JeM@0103<`m80`kS?0<>hc`33^<l30;^^c@@0]j[<0`2eYl/30;BVbSX0/jG:00<0
00000;>UbP2cYLX08`2cYLX00`3oool000000?ooo`0<0?ooo`0>0?n/>P051CX0[?oo0?ooa01O5000
5`1809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol?0?ooo`005P3oool010000000oooo0;bZ
b02lZ/P20;NXb@80]ZK900<0]:K:0;BUb@2dYLT08@2cYLX00`000000/jG:0;>UbP160;>UbP@0/jC:
0`2bY<T30;:Sb@<0/:7800<0/:380:jMaP2^WLH00P2]VlD30:JC`@<0VhBi0P2FO[H2095g/P0608Y^
[P1_Ci`0KdnL06m?W01S@iD0Jd^J0P1M?9800`1=;HT0>Qf103XMP@0202`AN`0:01/3M00006`01P1^
0000HP0006H0001B0000F`2oI@0000130<566`80<00`0`3@WJ8208iSW080OeRJ0P1fDIT2071>V@80
KDfL0P1]DJ42071IZ00407UY]@32o]d0`_kM09KHO@80k?C:00<0gmkC0=79d`36^m000P36^m030;f`
cP<0^:_<0`2fZ</30;BVb`@0]:K:>@2cYLX00`000000/jG:0;>UbP0T0;>UbP030000003oool0oooo
00X0oooo00h0okmd000K3@0BGl@0ooo405lD000G04P0W=oo0?noM000B9`0gooo0?ooo`3ookl0M018
09cOo`l0oooo000E0?ooo`040000003oool0oooo0?ooo`@0]jS90`2dY/XQ0;>UbP030000002cYLX0
/jG:04H0/jG:0`2cY<X30;:TbP@0/Z?90P2aXLP20;2Qb0<0[Yg6102XU/<209n9_080VhBi0P2FO[H3
089TZ00307UJXP1_Ci`0KdnL0080Hd>E00D0ESF>05dlTP1=;HT0CBf903XMP@0202`AN`806`=d00H0
001/00H0KP0006H0001B0000F`2oI@020000@`80`DHK0P3@WJ820:5cWP0408iSW01oF9X0OeRJ07mH
VP80MU6I00<0L4jI06e=W01]CI`00P1]DJ42071IZ080^]ca00D0U]Qm0>cdbP3/m<X0gmkC0=79d`03
0<Jkd080_[?>00<0_K3>0;V/c02i[<`00`2fZ</40;BWb`<0]:K:?02cYLX00`000000/jG:0;>UbP0R
0;>UbP030000002cYLX0000000/0oooo00h0omnL04Q8M`1D51@0GlC405lD000G04P0W=oo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`l0oooo000E0?ooo`030000003oool0oooo00<0oooo0`2eY/X3
0;BUbQl0/jG:00<000000;>UbP2cYLX0AP2cYLX30;>TbP80/jC900<0/ZC:0;:Sb@2bXlT00P2bXlT3
0;6Qb0@0[ik70P2ZV<@20:RF``80XXfn0P2ORK`0102KQ;T0RFf]08U][@29KJd2089TZ00307UJXP1_
Ci`0KdnL0080Hd>E00D0ESF>04HWQP1=;HT0CBf903XMP@0202`AN`060140L`0K0g@0001/00H0KP00
0680001V0P0005/20000@`030<566`3@WJ80d9fR00<0XG>N0P2>Hi`207mHVP80MU6I00<0L4jI06e=
W01]CI`00`25O<8209bTf`80/oFc00@0k?W00=K@d`3Fd=<0e]3C0P39`=430;jccP<0^Jc<00@0]jW;
0;JXb`2fZ</0]JO;0P2dYl/30;BVbSh0/jG:00<000000;>UbP2cYLX08`2cYLX00`3oool000000?oo
o`090?ooo`0>0?oo_`1d07@0_lAO01@D=@0e4P003`1d0;ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool?0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`040000002dY/X0]:K:0;BVbQh0/jG:
0P0000180;>UbP<0/jC:0`2cY<T40;:Sb@<0/J;90`2_WlL30:bJa@80ZYS40`2RSKh209n9_080T7Fa
0`29KJd01022I:P0NEZR07UJXP1_Ci`206=3U@0B05HeSP169hH0ARN604d]R@0j7H4090]i02`AN`0A
07<06`=d0000K00606h0001R0000IP000580001K0;mU000004<0`DHK0P3]^I`00`2kRJ40XG>N0:5c
WP0208iSW080OeRJ0P1fDIT2079HY@80N6F`0`25O<80102LY=/0/oFc0>ci`03Zkld20=cHd`040<W0
d@31]/l0`KK?0<6fc`@0^Zg=0`2gZL/30;FWb`<0]:K:@02cYLX00`000000/jG:0;>UbP0T0;>UbP03
0000003oool0oooo00L0oooo00d0oooO09a8001d_ol0a5lD00000000@Kl0oooo0?oog`2LB000M;oo
0?ooo`3OW4P007Bo0100oooo000E0?ooo`030000003oool0oooo00D0oooo00@000000;BVbP2dYLX0
]:G:702cYLX00`000000/jG:0;>UbP1:0;>UbP<0/jC:0`2bY<T30;6Sb@<0/:3800<0[io70:fLaP2]
W<H00P2/V/D30:FA`0030::=_P2JP[P0VX:h0080UGbe0P2@MK4208U][@04089TZ01iFZ80NEZR06m?
W080Hd>E0P1F=Hh03P169hH0=1Qo03XMP@0T2gT0;15k0140L`0006T0001/0000G@000680001V0000
DP0005/0_fD00P2>82d01@3]^I`0^hVQ0;^9X@2kRJ40XG>N00<0NUFJ0P1dDY/2075CW`04079HY@1h
IK00N6F`07QU/080QGc200@0/oFc0000003Zkld0g=SC0`3>aM820<Bid0<0_:o=0`2gZ/`30;FWb`<0
]:K;102dYLXo0;>UbP030000002cYLX0/jG:02@0/jG:00<000000?ooo`3oool01`3oool01@3ookl0
M000000000001@00;hoo0080oooo00D0oono07@00000000004RL0=ooo`0@0?ooo`00503oool00`00
0000oooo0?ooo`070?ooo`@0]:G:6P2cYLX00`000000/jG:0;>UbP160;>UbPH0/jC:102bY<T20;:S
b@80/J?900<0/:780;2Pb02`X<P0102]W<H20:ND`P80YI70102JP[P0102EO;D0PV>W089SY`22HjL2
07YKXP05079AW@1XAiL0J4NG05dlT@1@;h/00P1F=Hh03@169hH0=1Qo03@HO`0T2gT01P1a0140L`00
06T0001/0000G@00068000120000DP3FG`000P2oI@000`2>82d0^hVQ0;^9X@020;^9X@80QEbJ0P1j
EIX207ABV`80LE>O0P1bF:D207QU/080ao[Y00<000000>gfaP3RhM800`3Cc=<20<Bid080_K7>00<0
_:o=0;R[c02hZl`0102fZ</30;BVb`80]:K:0P2dYLY10;>UbP030000002cYLX0/jG:02<0/jG:00<0
oooo0000003oool02@3oool00`3OW4P00000000000030000000307Boo`3oool0oooo0140oooo000D
0?ooo`030000003oool0oooo00P0oooo00<000000;>UbP2cYLX06@2cYLX00`000000/jG:0;>UbP18
0;>UbPD0/jC:0`2bY<T40;:Sb@<0/:780`2^WLH30:VG``80YiC20P2MQk/309Z2^080R6^/0P22HjL2
07YKXP04079AW@1XAiL0J4NG05dlT@80D2n;00h0ESF>04HWQP0d67l0=1Qo02@;N@0607404@1c0000
J@0006`0001M0000HP000480001B0=IO0080_fD000<0000L0=RTX@3HY:400`2DIi`01025G9X0NUFJ
07YEVP1jEIX207ABV`03075CW`1bF:D0LURU00<0]<_[00<0X>6;0000003RhM800`3Cc=<20<Nmd@<0
_K7>0`2hZl`30;JXb`80]JO;00<0]:K;0;BVbP2dY/X00P2dY/Y30;>UbP030000002cYLX0/jG:0200
/jG:0`2cY<X00`3oool000000?ooo`080?ooo`030?oOW0180000M;oo01L0oooo000D0?ooo`030000
003oool0oooo00T0oooo00<000000;>UbP2cYLX05`2cYLX00`000000/jG:0;>UbP190;>UbP@0/jC:
0`2bY<T30;:Sb@<0/J;80`2_W/L30:^Ia080ZIO30`2QRkd209f7^`<0SW:_0P28Jj`00`22HjL0NU^R
07YKXP02079AW@0606Q7U`1M?940D2n;050_R`108XD0ARN60P0d67l0200T2gT01P1a00H0L@0A07<0
001Y0000K00005d0001R0P0005800`3FG`00F`0b0?oBS0020=RTX@030:QhWP2DIi`0U6NL0080QEbJ
0P1jEIX207ABV`04075CW`2GUm40UiOA09NGd@80]<_[00<000000>SYd03XjM000P3Hdm<00`37_M40
_k?>0;nccP020;nccP<0^Jc<0`2fZ</30;FWb`<0]:K:AP2cYLX00`000000/jG:0;>UbP0Q0;>UbP<0
/jC:00<000000?ooo`3oool01`3oool00`3ogi`0B00007Boo`0F0?ooo`00503oool00`000000oooo
0?ooo`0;0?oooaH0/jG:0P00001;0;>UbP<0/jC:0`2bY<X30;:Sb@@0/J;90P2`X<P20:nNa`040:bK
a@2[VL@0ZiW40:^Ia080Y8no0P2QRkd309=i/`80SW:_0P28Jj`00`22HjL0NU^R07YKXP02079AW@04
06Q7U`1M?940GCbA050_R`80@2:50P0d67l03P0K1WP090]i00H0L@0A07<0001Y0000K00005d0001R
0000@P000580eUl002d0<03odX`0f:BQ0P2XN9h209AWW080QEbJ0P1jEIX207ABV`80Q7Jk0`2GUm40
1030o<H0d>b90>SYd03Hdm<30<_2d@80`[O?0`2k[/d30;NYc0<0]JO;102dY/Y80;>UbP030000002c
YLX0/jG:01l0/jG:0`2cY<X2000000X0oooo00<0oono07@00018W=l05@3oool001<0oooo00<00000
0?ooo`3oool03@3ooolD0;>UbP030000002cYLX0/jG:04`0/jG:102cY<X20;:Tb@80/Z?900<0/J?9
0;6Rb@2aX/T00P2`XLP20;2Pb0<0[9_50`2VT/420:B?_`80V7ng0P2CNK<208ib[`<0NUZQ00<0LU:M
06Y9V01ZBIP00P1Q@9<205dlT@80D2n;0100@2:503@HO`0d67l06`Ih02@;N@0607404@1c0000J@00
06`0001M0<IR00000480^ClN0=IO000]0300f:BQ102XN9h0102DIi`0NURN07YHWP1jF9h207QJX`80
Nf>/0P24M[/0102GUm40`?c609?@K@3/l/X20=oKd`80d<SB0P32]ll20;b`c@040;^^c@2hZ/`0^:[<
0;RZc0<0]ZS;0P2dY//20;BVbP80]:G:B02cYLX00`000000/jG:0;>UbP0M0;>UbP<0/jC:00<00000
0?ooo`0000002`3oool00`3ooml0W4P004RLg`0D0?ooo`004`3oool00`000000oooo0?ooo`0>0?oo
o`030000002cYLX0/jG:00l0/jG:00<000000;>UbP2cYLX0C@2cYLX30;>TbP@0/ZC90`2aXlT30;2Q
b0<0[Ig60`2XUL<20:JB`@<0W8Bi0P2HOkL208IYZP80P6:V0P1jFZ400`1bDYd0JTVH06Y9V0020650
T`0E05LfSP1::hT0D2n;050_R`108XD0;A=o03@HO`0K1WP0001a00H0L@0006L0001Y0000E00005d0
aV800000@P2i?ah0;@0`0000703c`Y/0`HnQ00<0Z7RN0P20FY`207YHWP80N5ZS0P1kHj`208Af^`03
0<3laP2Cd6d0i_RX0080gm_C00@0d<SB0<Fjd035^]00aK[@0`2l/<d30;RZc0<0]ZS;102dY//30;BU
bTT0/jG:00<000000;>UbP2cYLX07@2cYLX010000000oooo0?ooo`3oool2000000/0oooo00<0oono
07@0B02Lgol04`3oool001<0oooo00<000000?ooo`3oool03`3oool00`000000/jG:0;>UbP0=0;>U
bP030000002cYLX0/jG:04d0/jG:0`2cY<X30;:Tb@<0/Z?90`2aXLP30:jNa`80[Ig600<0ZYS40:RE
``2XUL<00`2ORK`209b4^@<0S72^00<0QVVZ081RYP20HZH00P1jFZ42079BW@80JTVH00h0HD2C05Lf
SP1::hT0BR^9050_R`108XD0;A=o03@HO`0K1WP0001a00H0L@0006L0001Y0000E080001M00D00012
0;To7P2i?ah0l]U/0??2V`020<6?X@<0Rf6K00D0P5ZL07YHWP1jF9h0NURN07QJX`0207]S[0<0bO3]
00@000000>GTd@3Ui=40eLoC0`39_m430;jbcP<0^Jc<0`2fZ</30;BVb`<0]:K:C02cYLX00`000000
/jG:0;>UbP0K0;>UbP070000003oool0oooo0?ooo`000000oooo000000070?ooo`030?noM000M;l0
oooo0080oooo00<0_g@007Boo`3oool04P3oool001<0oooo00<000000?ooo`3oool0403oool00`00
0000/jG:0;>UbP0;0;>UbP030000002cYLX0/jG:04`0/jG:0`2cY<X30;:Tb@@0/Z?90P2aX/P20;6Q
b0040:nOa`2^W/L0[Yk70:jNa`<0ZYS40P2RSKh309n9_080TGJa0P2<L:h208IYZP80P6:V00<0NUZQ
079BW@1bDYd00P1ZBIP02P1Q@9<0EcJ>04X[R@1::hT0>Qn4040RQ@0]4gl04@9i01/6N000074200H0
L@80001Y0P0005d01036HP00^ClN08@H;@3c`Y/20<6?X@80VFbM0P2;HI/2081JW080NURN00<0N5ZS
0;2kh@2`^n400P2`^n40102_k9X0iNCA0>GTd@3Ecm<30<Vod@80`KG?0`2j[Ld30;NYb`@0]JO;0`2d
Y/Y>0;>UbP030000002cYLX0/jG:01T0/jG:1`3oool00`000000oooo0?ooo`050?ooo`070?oo_`1d
04P0W=oo0?ooo`3ogi`0B01809cOo`0C0?ooo`004P3oool00`000000oooo0?ooo`0C0?ooo`/0/jG:
00<000000;>UbP2cYLX0C02cYLX30;>TbP<0/ZC:0P2bY<T20;:Sb@80/J;90P2aX/P30:nOa`<0Zi[5
0`2UT<020::=_P<0UGbe0P2AM[400`2<L:h0QVVZ08IYZP02081RYP0307YJX@1bDYd0LU:M0080JTVH
00@0HD2C05LfSP1G=Xh0BR^90P0j7h@03`0]4gl04@9i01/6N00K1WP0001a00H0L@0006L0001Y0000
E00005d0aV8008@H;@1A0300om^:0=f[X`0309U/W@80Rf6K0P20FY`207YHWP80Uhk80P2`^n420:o/
VP030>_]c03Lem80g=OB0080cLCA0P31]Ll20;^_c@80^Zg=0P2gZ/`30;FWb`@0]:K:D02cYLX00`00
0000/jG:0;>UbP0G0;>UbPL0oooo0P0000080?ooo`050?oOW018000000000000001d_ol0503oool0
0180oooo00<000000?ooo`3oool0503oool80;>UbP800000D02cYLX0102cY<X0/jC90;>Tb@2bY<X4
0;:Tb@<0/J;90`2`X<P40:fLa@80Yi?20P2UT<0309V1^080UGbe0P2AM[4207iOY080N5RP0P1bDI`0
0`1[BYP0I4:D06A2U00205/jT080EcJ>00<0BR^903XOQ00j7h@00P0]4gl0300A0WT06`Ih0000L@06
0740001W0000J@0005@0ce810<IR002462d08`0[0=f[X`80[7bO0P2IK9d208]QV`80P5ZL0`28LkD2
09N>b080[nbJ00@0jng<0=cGdP3Lem80cLCA0`33^<l40;^_c@80]j[<0P2fZ</00`2eYl/0]:K;0;BV
b`020;BVbU80/jG:00<000000;>UbP2cYLX0502cYLX00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01h0oooo000B0?ooo`030000003oool0oooo01D0oooo1P2cYLX00`000000/jG:0;>UbP1@
0;>UbP<0/jC90`2bY<T40;:Sb@<0/:780P2^WLH20:fLa@80ZIK30P2WTl8209f6^P80VH6h0P2EO;D3
08AVZ00307iOY01hF:00N5RP0080LU6L00<0JdZH06A2U01T@Y@00P1K>Y000`1A<Xd0EcJ>04X[R@02
03XOQ080;A=o00/04@9i01/6N0000740001T0000I`0004@0001D0<mB0@36HP00D@0`0?oKRP040:al
W`0409U/W@22H:80PV2R089PXP80PVFY0P28LkD01P2GS/P0c_oC0<kod`3Tli/0koC30>?Od@80dl_B
0P37_=030;fac@<0^:_<0`2fZ</30;BVb`@0]:K:D@2cYLX00`000000/jG:0;>UbP0A0;>UbP030000
003oool0oooo00P0oooo0`00000;0?ooo`030?oog`2LB000M;oo0180oooo000B0?ooo`030000003o
ool0oooo01H0oooo00D000000;>UbP2cYLX0/jG:0000001A0;>UbP@0/jC:0`2bY<T30;:Sb@<0/J;8
00<0/:780:nNa`2_W/L00P2^WLH30:VF``<0X8Zm0P2MQ[X208ib[`80RFb/0P24IZP207iOY00307QH
X01bDI`0LU6L0080JdZH00H0I4:D05/jT01K>Y00DC:=04DXR@1::hT203XOQ00902DAP00]4gl04@9i
0000LP000740001T0000I`0004@0001D0080ce8100<0D@0`0?K;X032TJ@00`2/O9l208MPWP80PV2R
0`22IJT01P28LkD0c_oC0<kod`2QfGH0koC30>?Od@80dl_B0P37_=020;nccP<0^Jc<102fZ</30;BW
b`<0]:K:E02cYLX00`000000/jG:0;>UbP0@0;>UbPd0oooo00<000000?ooo`3oool02@3oool00`3o
oml0W4P007Boo`0B0?ooo`004@3oool00`000000oooo0?ooo`0H0?ooo`030000002cYLX000000540
/jG:0`2cY<X30;>Tb@@0/Z?90P2aX/T20;6Rb0<0[ik70`2[VL@30:>>_`80X8Zm0`2CNK<208ib[`80
RFb/00@0Q6JX07iOY01nGj@0N5RP0P1bDI`206]:V00406A2U01K>Y00FcZ@054bS@80ABR90P0j7h@0
100U4H00101l0142N@0007820000L@030000I`0004@000140080ce8100D08`0[0?K;X032TJ@0`Y6T
0:alW`0208mUW@0408MPWP22H:80PV2R089PXP80PVFY0`3=hnP0103`mk@0fM;B0=WBdP3Id]820<_1
d@<0_k?>0P2j[/d30;NYb`<0]JO;102dY/YF0;>UbP030000002cYLX0/jG:00h0/jG:3P3oool00`00
0000oooo0?ooo`060?ooo`030=nLB0000000000000<0000000<0B9cO0?ooo`3oool03`3oool00140
oooo00<000000?ooo`3oool06@3oool00`000000/jG:0;>UbP1A0;>UbP<0/jC:0P2cY<T00`2bY<T0
/Z?90;:Sb@040;6Rb@<0[io70`2/V/D20:JB`0<0Xhjo0P2GO[H209=i/`80SW:_0P29K:`207MFWP80
LDnK00D0JdVH06E3U01U@i@0GSfB06A2U00205/jT080DC:=00D0ABR903XOQ00j7h@09A6000@0O002
0142N@030000LP000740001T0080001400<0ce8102<0:`3fbj000`32TJ@308mUW@80Qf2N0P22H:80
1P22IJT0/JoE0;6_e@3=hnP0`oFW0?3`a080hM_@00<0bl7A0<:fc`32]/l00P32]/l20;Z^c@80^:[<
00@0]jW;0;FWb`2eYl/0]JO;0P2dY//20;BVbUP0/jG:00<000000;>UbP2cYLX02`2cYLX>0?ooo`80
000000<0oooo0000003oool01P3oool01P3ogi`0B4RL0=ooo`3ooml0W4P007Booa80oooo000A0?oo
o`030000003oool0oooo01L0oooo0P0000020?oooe80/jG:102cY<X30;:Tb@<0/Z?90`2`X<P30:fL
aP030:bJa@2XU<80Z9C20080YY;00`2KPkT209Mn]P0409=i/`21HZH0PF:V085RYP80O5bR00@0MeJN
075?V`1aCi/0JdVH0P1U@i@205hmTP0805LgS`1=<8h0DC:=054bS@15:8T0=1f603XOQ00U4H0200@0
O0040142N@000780001a0000I08000140P2U;1d00`3kiY80fjjY09Y]WP0209Y]WP80SfFM0P27H9h2
089PXP<0/JoE00<0`oFW0?3`a03Qfm000`3Aam420<Fjc`<0_:o=0`2hZ/`30;FWb`<0]:K;102dYLYG
0;>UbP030000002cYLX0/jG:00P0/jG:00<000000?ooo`3oool0403oool00`000000oooo0?ooo`06
0?ooo`050=nLB018W=l0oooO09a8001d_ol04P3oool00140oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`030000002cYLX0/jG:04d0/jG:0`2cY<X30;:Tb@<0/Z?90`2aXLP0
0`2`X<P0[Yg60:jMaP020:fLaP<0Z9C20`2NR;/209^3^@80Ugjf0P26JJT2085RYP80O5bR0P1gEYh0
101aCi/0JdVH06]9V01U@i@205hmTP0705LgS`1=<8h0CC2>054bS@15:8T0=1f601`@Q00202DAP005
00@0O00A0WT0001b0000G@0006@00P0004@01@2U;1d0KPDW0=^^Z@3K[ZT0Z7ZQ0080VVfN0P2?IId2
08MPWP<0W8Vo00D0/JoE0<?eY`2Kbed0loBe0>WTc0020=S?d080aK[?0P2n//h40;V[c0<0]ZS;0`2d
Y//30;BVbUX0/jG:00<000000;>UbP2cYLX01P2cYLX00`000000oooo0?ooo`0@0?ooo`800000203o
ool01@3ooml0W4Q809cOg`2LB000M;oo0180oooo000@0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01@3oool00`000000/jG:0;>UbP170;>UbPH0/jC:102bY<T40;:Sb@030;6Rb@2a
XLP0/J7800@0[Yg60`2YUl<20:6<_@<0WXRk00@0Vh>i08]_[@2;Kjd0Rfn]0P26JJT00`21HZH0O5bR
07aLXP0207MFWP03075?V`1[BIP0JdVH0080ID>D00L0GSfB05LgS`1=<8h0CC2>044XS015:8T0=1f6
0080712400L09A6000@0O00007H0001b0000G@0006@0b5800080KPDW00@0nnJB0=^^Z@3K[ZT0Z7ZQ
0`2JKIh0102?IId0T7B_091d[`2@M:l209b9_`80gOcF00<000000>WTc03Hcm000`3:_m030;jbcP80
^Zg<0`2fZL/30;FWb`<0]:K:G@2cYLX00`000000/jG:0;>UbP040;>UbQD0oooo00<000000?ooo`3o
ool01`3oool0103ogi`0B4Qd07A8001d_olB0?ooo`00403oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00L0ooooBP2cYLX50;>TbP030;>Tb@2bY<T0/ZC900@0/Z?90`2aX/T30:nNa`<0
ZiW400<0ZIO30:B?_`2TSkl00P2QS;d309Ak]003091e/@2;Kjd0Rfn]0080QVVY00<0PF:V07aLXP1l
G:800P1gEYh00`1aCi/0JdVH06]9V00206E3U00405hmTP1G=hl0EcN?04d`SP80@BR<0P0d7HH01@0L
48@0002300@0O00007H0001b0080001M0P38DP000`1^1BL0fjjY0=^^Z@030:QjX@80VVfN0P2<JJH3
091d[`0509b9_`3Mo=H0]^9n0?7/``3Pelh00`3@aM030<6ecP80^Zg<0P2gZL/0102fZL/0]JO;0;FW
b`2eYl/40;BVbUh0/jG:00<000000;>UbP2cYLX00P2cYLXE0?ooo`<000002@3oool00`3OW4P00000
07Boo`0B0?ooo`00403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<0
00000;>UbP2cYLX0A`2cYLX30;>TbP<0/jC90`2bXlT30;6Rb@<0/:380`2/VlD20:^Ia0<0Y8no0`2H
P;L209Ak]080T7Fa00D0Rfn]07UIX01iFJ00NEVP07ACW@0206m>VP80JTRG00D0ID>E060oT`1P?i<0
FS^B05hmTP0205LgS`80CC2>00D0@BR<03@MQP0d7HH071240000P`0200@0O0030000MP0005d0001M
0080b58000@03@0L0??B[`2iSJP0^HfX0P2XNZ4308aUX080S6VV0P2@M:l0103Mo=H0]^9n0000003P
elh30=35d080aKS>0`2k[/d30;NYb`<0]JO;102dY/YP0;>UbP030000002cYLX0000001P0oooo00<0
00000?ooo`3oool01`3oool00`3ooml0W4P007Boo`0B0?ooo`00403oool00`000000oooo0?ooo`0B
0?ooo`8000003@3oool00`000000/jG:0;>UbP170;>UbP<0/ZC:102bY<T30;:Sb@80/:780P2`X<P0
102]WLH0[9_50:bKa@2/VlD30:JC`@80W8Fj0P2HP;L209Ak]0<0Q6FW00@0OUnT07UIX01iFJ00M5>M
0P1_CYX206Y8U`0306E3U@1P?i<0H3nC0080FS^B0P1G=hl204d`SP03044XS00_7h`0=1f600807124
00<0002300@0O00007H00P0005d20;<`0@040??B[`2iSJP0^HfX0;V=Z0<0SVFN0P2<IJ0208aYYP<0
dMGL00<000000?K`/`3Yh<T00P3Gc<l00`35^<h0_K7=0;fac@020;fac@<0^:_<0`2fZ</30;BVb`<0
]:G:G`2cYLX2000001T0oooo00<000000?ooo`3oool0703oool000l0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0?0?oood<0/jG:1`2cY<X30;:TbP@0/Z?90P2aXLP20;2Qb0<0[Ig6
0`2XU/<00`2VTl40WhVl09n9_00209b5^P0409R0]`28Jj/0R6^[08Q[Z`80Q6FW00<0OUnT07UIX01i
FJ000P1dDid206m>VP0406Y8U`1U@iD0H3nC060oT`80FS^B00L0DcJA04XbTP1=<8h0CC2>044XS00_
7h`04aB>0080712400<000230000O00007H00P0005d0102c<040NP@C0??cZ@3=Z;@309=YW`80SVFN
0P2<IJ000`2<JJH0]JG90;FUb@020=7Eg0030?K`/`3Yh<T0elc?00<0bKg?00<0`;?=0;fac@2m/Ld0
0P2i[<`30;JXb`<0]:K;0`2dY/YP0;>UbP040000003oool0oooo000001L0oooo0P0000090?ooo`05
0?oo_`1d000000000000M02oool0403oool000l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?oood@0/jG:102cY<X20;>Tb@030;:TbP2bXlT0/Z?90080/Z?90`2aXLP30:jNa`<0
ZYS40P2XU/<309n9_080W8Fj0P2=LJh308Q[Z`0408AUY`1nGj@0OUnT07UIX080M5>M0P1_CYX0101Z
B9L0ID>E06E3U@1P?i<205XkTP0605<fT@1:<Y80BS:B03h^U011:8`0;an<0P0C58h01@0L48@00023
0000O00007H0[SX00080NP@C00@0lo>Y0<fX]03=Z;@0VG6S0P2CJIl308iUWP0308aUX02eYLT0]JG9
0080]JG900@000000?;X_`3PeL`0h=G<0P3?`lh30<2cc@80^Jc<0P2gZL/20;JXb`030;FWb`2dY//0
]:K;00<0]:K:G`2cYLX00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01P3oool01P2oM000M;oo0?ooo`3ogi`0B4RL0=ooo`l0oooo000?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000/jG:0;>UbP0o0;>UbP@0/jC:0`2c
Y<T30;:Sb@@0/J;90`2_WlL20:^Ja@<0ZYS40P2RSKh209n9_0<0TWNb0P2=LJh208Q[Z`0408AUY`1n
Gj@0OUnT07UIX080M5>M0P1_CYX0101ZB9L0ID>E06E3U@1P?i<205XkTP0305<fT@1:<Y80BS:B0080
?RjD0P0_7h`00`0C58h000JD0000P`020000O080[SX000<0@P0D0<fX]03=Z;@00P2ILJ<309=YW`80
SVFN0P2OQKL20;FUb@040=[j[@3ekid0h=G<0>3Ec080cl?>0P34]lh30;^^c0@0]jW;0`2eYl/30;BV
bUl0/jG:1`3oool00`000000oooo0?ooo`0D0?ooo`8000001`3oool01`3ookl0M4RL0=ooo`3oool0
oono07@0B02Lgol03`3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0E
0?ooo`030000002cYLX0/jG:03d0/jG:1`2cY<X30;:Tb@<0/J;80`2`X<P00`2_WlL0[Ic60:fLaP02
0:^Ja@<0YI300P2RSKh209Il]@80TWNb0P2=LJh307aKXP0407MFWP1bD9/0LU2K06e<V@80JDNF0P1U
@iD00`1Q@9@0G3fD060oT`0205XkTP80DcJA00<0BS:B03h^U00n;Y@00P0_7h`201<DSP030006U000
07`0001l0080XaD000@000000:9n[02ROZ`0XWj/0P2ILJ<209=YW`<0TW6Z0P2OQKL0103JnZd0[M5O
0?S][P3[g/H20=S;c@80a;O>0`2m/<d30;RZc0<0]JO;0`2dY/X30;BUbU`0/jG:00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000L0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00l0oooo000>0?ooo`030000003oool0oooo00h0oooo0P00000I0?oo
o`030000002cYLX0/jG:03h0/jG:0`2cY<X30;:Tb@<0/Z?900<0/J;80;2Qb02`XLP00P2`X<P30:fL
aP<0Yi?20P2UT<0309Z2^080UWbe0P25IjT2085QY@80O5^R00@0MeJN079@V`1bD9/0KDbI0P1YAiH2
06E3U@050650U01L?I@0G3fD05PlU@1B>iP00P1C=Y401@1:<Y80?RjD03h^U00/:IX02bJV00804aB>
00D000JD0000O00007`0I@0002H000020:nD^`80XWj/0P2ILJ<308UUX`80TW6Z00H0WhFg0>Sbd@3X
l]4000000>_NaP3Hbld30<VlcP80`;?=0`2iZl`30;JXb`<0]:K;102dY/YL0;>UbP030000003oool0
oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`070?oOW0180000
M;oo0?ooo`3ogi`0B4RL0=ooo`0?0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01/0oooo?@2cYLX50;>TbP<0/ZC90`2bXlT40;2Qb0<0[Yg60P2YU/<20:NC`P<0WHJj0P2J
P[P308Y][00308EWZ@21HJD0PF6U0080O5^R0P1gEYh0101bD9/0KDbI06e<V@1YAiH206E3U@040650
U01L?I@0G3fD05PlU@80DS^H00D0C3^M04XbTP0n;Y@0?RjD02`YVP0200/VYP05000Z/P001Y@0Q080
08@2000V0000102_U;/0102ROZ`0PejO08=NW`23GYl208UUX`80TW6Z0`3Xl]400`3di[X0h]?90>;C
b@020=32c@80`;?=0P2k[L`20;V[c0040;NYb`2fZ</0]ZS;0;FWb`80]:K;0`2dY/YL0;>UbPh0oooo
00<000000?ooo`3oool04@3oool00`000000oooo000000060?ooo`060?oOW018B9`0W7@000000000
04P0W=oo403oool000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0M0?oooc`0
/jG:102cY<X30;:Tb@<0/Z?90`2aX/P30:nNa`<0ZiS40P2YU/<20:2;_@<0WHJj0P2?Lk0208Y][080
QFNY00<0PF6U07aKXP1lFj800P1gEYh0101bD9/0KDbI06e<V@1YAiH206E3U@80HD2D00@0G3fD05Pl
U@1B>iP0DS^H0P1<>id203h^U080;2VJ00<02bJV000Z/P00:[800P0V00000`2dljd0a;_B0<BkdP03
07eLX@0307iKWP23GYl0PejO0080RFFS00D0TW6Z0<o4d03?a=00clC@0<_XPP020>;Cb@040=32c@34
]ld0a;O=0<Bgc@@0^jg<0`2gZL/30;FWb`<0]:K:F`2cYLX00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`3ookl0M01d0;ooo`0C0?ooo`003P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo>P2cYLX30;>TbP<0/ZC:0`2b
XlT30;6Rb@<0[io70P2_W/L00`2/VlD0ZiS40:^Ha0030:>>_`80X8^m0`2CNK<208mc/00408Y][025
IjT0QFNY085QY@<0L4jJ0P1[BIP206e<V@0306U7UP1U@iD0ID>E0080HD2D00<0G3fD05PlU@1H?9D0
0P1B>iP00`1<>id0@CjW0317^@0202`YVP802bJV00@002Zb01X0002dljd0a;_B0`22IZT207eLX@05
07iKWP23GYl0PejO08=NW`29IJ<0103?a=00103;j880kMg10=[:b`3Jb//20<Zlc0<0_Jo<0`2hZ//3
0;FWb`<0]:K:G02cYLX00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo0`000007
0?ooo`060;md001d_ol0oooo0?noM000B9`0gooo3`3oool000d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0Q0?ooocL0/jG:1`2cY<X30;:Tb@<0/J;90P2`X<P30:nOa`<0[9_50P2U
TL420:>>_`<0Ugjf0P2CNK<208mc/080OEjS0P1iF9l00`1dDi`0L4jJ071>VP0206]9V00506Q6UP1T
@iD0I4>E0651U@1N@9H00P1Q@9@00`1L?I@0F3bE05PlU@02058kV00404`kW@11?ZL0<4Ni0317^@80
35oF00@09P0001X0002/Ym80[:OB0P2@O;T2089VZ@80OEbQ0P1nFih208=NW`80[9Fo0P3?a=00103;
j880n^VU0=[:b`3Jb//20<Zlc080`K;<0`2iZl/40;JXb`<0]:K:0`2dYLYH0;>UbP030000003oool0
oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`050?oog`2LB000
00000000B02Lgol0403oool000d0oooo00<000000?ooo`3oool02@3oool2000002D0oooo00<00000
0;>UbP2cYLX0=@2cYLX30;>TbP@0/ZC90P2bXlT00`2aX/T0/:780;2Qb0020;2Pb0<0[Ic60`2XU<82
0:FA`@80Vh>i0P2GO[H308MYZP80PV>V00@0OEjS07UHW`1iF9l0M5>L0P1`CYX206]9V00406Q6UP1T
@iD0I4>E0651U@80GT2F0P1K@IT205PlU@80DS^H00<0C3^M044nY`11?ZL00P0`AkT0100<GmH00000
0<kTj03>i>P20:bWdP80T7bi00<0PVJY07eLX@1mG:400P1nFih308ib[P80[9Fo0P3Yn[<0103hi;40
iM?50=;3b`3B`l/30<6bc0040;^]c02iZl/0^J_;0;NXb`80]ZS;0P2eY//30;BVbP030;BUbP2cYLX0
/jG:05H0/jG:00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01X0oooo000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool00`00
0000/jG:0;>UbP0c0;>UbP<0/jC:102bY<T30;:Sb@<0/:780`2^WLH30:VG``80Z9C20`2NR;/209^3
^@80S6n]0P27JJX2089SYP80OEjS00@0NERO07ACW01dDi`0L4jJ0P1[BIP206Q6UP0406A3U@1Q@ID0
GT2F05i0UP80Fd6I00<0FDBN05M:YP1GBZH00P1FE[H2044nY`80<4Ni00D000000:RSd@2XXm40Z:?A
085_]P0206]BY080HDFK0P1mG:4307QJX`80SW:^0P2/UKl0103Yn[<0nNF:0>GCa@3B`l/40<Fgc0<0
^jg<0`2gZ</30;FVb`<0]:K:F02cYLX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`0000002@3oool01@3o_g@000000000000004P0W=oo00d0oooo000=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3ooolc0;>UbP<0/jC:0`2bY<T40;:Sb@<0
/J;80`2_WlL20:^Ia0<0ZIO30P2QS;d209j8^`<0T7Fa0P2<Kjd208MYZP04089SYP1mGZ<0OEjS07UH
W`80M5>L00<0L4jJ06]9V01[BIP00P1XAYH00`1T@iD0HD6E0651U@0205i0UP0405]1V@1IA9h0EdZV
05M:YP80EUJf00D0Dfk@04ZJl`1:V_<0BY[c0=?Vi00308=a]`80PFnf00@0Je:T0655V`1QAI/0H4>H
0P1XBi/207QJX`80SW:^00@0[9Fo0>Wj/`3Yn[<0o>FJ0P3MblL20<blb`<0_Jo<0`2hZL/30;FWb`@0
]:K:F02cYLXL0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool01`3ogi`0
B01809cOo`3oool0okmd0000M02oool0303oool000`0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0[0?oooc40/jG:1P2cY<X30;:Sb@<0/J;90`2`X<L00`2_WlL0[9_50:bKa@020:^I
a0<0Y8no0P2QS;d209Ek]080T7Fa0P2<Kjd208MYZP05089SYP1aD9/0LE2K075@V`1]BiP00P1YB9L0
1@1VAIH0Hd>E06Q6UP1XAYH0I4>E0080HD6E0P1N@9H00`1K@IT0FDBN05U4WP0205M:YP0405IF]P1C
K]00Dfk@06KJcP<0/ZgC0P23LKL01P1SC:40D3NE06]BY01[DZ@0HDFK0613V080J4^K0`1hFZ<0102>
LZh0jOZc0>Wj/`2jdel20=g;a`80c;c;0P32/l`40;V[b`<0]ZO;0`2dY/X30;BUbUD0/jG:00<00000
0?ooo`3oool0703oool2000000h0oooo00<000000?ooo`3oool01P3oool01`3o_g@004RL0=ooo`3o
ool0oono07@0B02Lgol0303oool000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0]0?ooo`030000002cYLX0/jG:02h0/jG:0`2cY<X30;:Tb@030;:Sb@2aXlT0/J?90080/J;900<0
/:780;2Pa`2`X<L00`2/VlD30:JC`@80Y8no0`2IP;L209Ek]004091e/@1oGj@0OenT07mOY080NUZQ
00@0MUBN075@V`1aD9/0KD^H0P1YB9L00`1VAIH0Hd>E06=3U@020652UP050613V@1OAid0GT2F05i0
UP1K@IT00P1IA9h205M:YP0405IF]P1Vf/h0I][>08[CN`<0Sgjl00<0J56T04ddT`1SC:400P1@=iD0
1017;Y00HDFK0613V01P@iP206Q;V`80N5ZS00D0SW:^0>7Pd`3Qh=<000000>[E_`020=K4b0<0`[?<
0P2k[L/30;NXb`H0]:K:00<0]:G:0;>UbP2cYLX0DP2cYLX200000240oooo00<000000?ooo`3oool0
2@3oool3000000P0oooo00L0omnL04P0B02Lgol0oooo0?noM00007@0_ooo00`0oooo000<0?ooo`03
0000003oool0oooo00@0oooo0P00000a0?ooo`030000002cYLX0/jG:02P0/jG:0`2cY<X20;>UbP<0
/jC:0`2bY<T40;6Sb@<0/:780`2]WLH20:RF`P<0YY?10P2LQKX209V0]`<0RFb[00<0Q6FX07mOY01o
Gj@00P1jFZ400`1fE9h0LE2K075@V`0206e;V00406U8U`1VAIH0Hd>E06=3U@80HD:F00<0H4>I05m7
W@1OAid00P1QCZD00`1TF[80Jg;806]bb00207RLj003087Q[P2:dg/0`[kF00<0MEjZ00D0J56T04dd
T`1==9<0HdbQ050gU@0204L^T080H4>H0P1XBi/207QJX`80hN3C00@0e^n?0?_RYP3Fa<P0e/C80`37
^</20;^]b`80^:W;00<0]jS;0;FWb`2eYl/01@2dY/YD0;>UbP030000003oool0oooo0280oooo00<0
00000?ooo`3oool02P3oool2000000P0oooo00D0oono07@00000000004RL0=ooo`0=0?ooo`00303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0380oooo00<000000;>UbP2cYLX0:02c
YLX60;>TbP<0/ZC90`2bXlT30;6Qb0<0[Yk70`2ZV<@20:RF`P<0WhVl0P2LQKX208ea[`80RFb[0P24
IJP00`1oGj@0NUZQ07YJX@0207IDWP04075@V`1]BiP0KD^H06U8U`80ITFF00@0Hd>E0652UP1Q@YH0
H4>I0P1OAid2065>Y@0606AJ/P1[L/P0Jg;807RLj021hJh00000102QTL<01@1eGZX0E3^F06QAY01=
=9<0?2B:0080D3NE00<0Abj@04L`TP1E?i`00P1XBi/30:ZMb@80e^n?00@0mmf`0>?>`P3@_/T0d;k9
0`2o/</30;RYb`@0]JO;0`2dY/YD0;>UbP030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool00`000000oooo000000070?ooo`070?oo_`1d04P0W=oo0?ooo`3OW4P004RL0=ooo`0<0?oo
o`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000;>UbP2c
YLX0:02cYLX30;>TbP<0/jC90`2bXlT40;6Rb080[io70P2^W/L00`2/V/D0ZYS40:ZHa0030::=_P80
WhVl0`2BMk8208ea[`0408U/Z`24IJP0Q6FX07mOY080NUZQ0P1fE9h0101aD9/0KD^H06e;V01YB9L2
06I5UP0306=3U@1Q@YH0HD:F0080H4>I00<0GdNM065>Y@1QCZD00P1TF[80101[L/P0W??Z0000003@
c]L308I_/P80HDNL00<0E3^F03dTR@1==9<00P0l98X00`1@=iD0Abj@04L`TP0205DoW080MF:_0P2Z
WLT00`3Fkhl000000?OM/0030=2nb@80a;?;0`2jZl/30;JWb`<0]:K:E@2cYLX00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0M02oool0303oool000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0g0?ooobL0/jG:1`2cY<X30;:Sb@80/J;90P2aX/P20;2Pb080[io70`2/V/D20:FA`080XXfn
0`2FOKD2099g/P80SG6_00D0RFb[07MFW`1gEYl0MeJO07=AW00206m=V@80JdVG00<0J4JF06E4UP1U
A9H00P1VAIH00`1S@iD0HD:F0652UP020613V@0305m7W@1QCZD0HDjU0080I5Zb00<0W??Z08SISP3X
mlh00`2bY<X01026Kk80HDNL0657W01D>iH203dTR@0504ddT`0l98X0<Ab804L^T017<9800P1E?i`2
07ER[`050:ZMb@3Fkhl0e^n?0?OM/03aekL00P3Lal@20<Bcb`80_:g;0`2gZ</70;BVbU40/jG:00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`8000001`3oool01`3ookl0M01809cO
o`3oool0gia80018W03Oool0303oool000/0oooo00D000000?ooo`3oool0oooo0000000k0?ooobP0
/jG:102cY<X20;:Tb@<0/Z?90P2aX/T30;2Pb0<0[Ic50`2WU<820:FA`080VX:h0`2FOKD01@2BMk80
PF:U085RY@21HZD0O5bR0080MeJO00<0Le6L06m=V@1_CIT00P1[BIL0101XAYH0IDBF06E4UP1S@iH2
0694V0050697W01SCZ<0H4>I0613V@1OAid00`24U]d209_@nP040=cj[03Kf]H0V8>k09R3^`80LERU
0P1QAi`01@16:hd0E3^F03dTR@0Y5880?2B:0080<Ab80P17<98205DoW00507ER[`3Fkhl0e^n?0000
003nh9T00P3Lal@20<^ib@<0_:g;00@0^:W;0;NXb`2gZ</0]JO:1@2dY/Y@0;>UbP030?ooo`000000
oooo02`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`050?oOW0180000
00000000M02oool03@3oool000/0oooo00@000000?ooo`0000000000?@3ooolS0;>UbP80/jC:00<0
/jG:0;>TbP2cY<X00P2cY<X30;:Tb@<0/Z?9102`XLP30:jMaP80ZIK30P2WU<8309f6^P80VX:h0`2;
KZ`01026J:T0PF:U085RY@1lG:8207MFW`80Le6L00@0KdfI06]9U`1[BIL0J4JF0P1UA9H0101S@iH0
HTBH0694V01RAi`206=>X`80J5Z^00H0LW3108BFg@24U]d0Q9KM09ka_P3Zn<T20<6ecP80V8>k00P0
LERU05<gTP1QAi`0AR^=02lGPP0m98T0:AB203`TRP80<Ab80P17<98205DoW00407ER[`3Om=/0goCK
00000080g<O400<0bkW90<6`bP31/<X00P31/<X30;RYb`<0]JO:0`2dY/YA0;>UbP030000003oool0
oooo02d0oooo00<000000?ooo`3oool01P3oool2000001T0oooo000:0?ooo`030000003oool00000
0400oooo8@2cYLX70;>TbP<0/ZC:0`2bXlT30;6Rb0<0[ik700<0[Yg60:^Ia02[VL@00P2YU/<20:6;
_@80WHJj0`2?Lk0208]^[080QVRY00@0PF:U07aLXP1lG:80MeJO0P1cDI`00`1_CIT0JdVG06]9U`02
06Q6UP0406E4UP1S@iH0Hd>F0694V080HTNL00<0HdjS06QJ[P1XFZh00P1bL<4209ka_P0300000031
]Lh0PfZ^0080PfZ^0P1RAYX01@1C=i80>An504H[S@0_5h80?BB90080:AB20P0a78P0100_88d0@c^R
05DoW01E?i`20=odf`80000000<0j]6l0=G1aP3E`LH00P37]LT30;Z[b`<0]ZO;0`2dY/YB0;>UbS80
oooo00<000000?ooo`3oool0103oool00`000000oooo0000000I0?ooo`002P3oool200000480oooo
00<000000;>UbP2cYLX07`2cYLX30;>TbP<0/jC90`2bXlT30;6Rb@<0[io70P2_W/L30:^Ia0<0Xhjo
0P2QRkd209=i/`80Sg>`0P2;KZ`208IXZ@04085RY@1lG:80O5bR07MFW`80Le6L00<0KdfI06]9U`1[
BIL00P1XAYH0101UA9H0Hd>F06=3UP1RA9P20697W080HdjS00H0J5Z^0;7dl`2am?<0/OCc0000003Q
hM@30:RE``80PfZ^00P0HTJJ05<gTP0i7hD0>An504H[S@0_5h80?BB902TDPP80<Ab800<0;b2=04<k
XP13>j800P23RM000`3Om=/0[]Q^0>[A_0020=G1aP80akG90P2n[/X40;NXbP<0]JK:0`2dYLY>0;>U
bP030000003oool0oooo0380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`002P3oool00`00
0000oooo0?ooo`130?ooob40/jG:102bY<X20;:Tb@80/Z?900@0/Z;90;6Rb@2aX/T0/:380P2_WlL4
0:bJa@80YY;00P2SS[l309Mn]P80TgVc00<0Sg>`08]^[02;KZ`00`1iF:00101dDid0L4jJ071>VP1]
BiP206U7U`0506I5UP1TA9H0I4BF0694V01UA9H00P1S@iH00`1RA9P0HTNL0697W00206=>X`<0X<;a
00<0U^:F0<_2d@3;`]400P2CO;L2079GY00905DhTP1RAYX0Ab^;05<gTP0i7hD0AR^=02lGPP0m98T0
:AB20080<Ab800<0;b2=04<kXP13>j800P23RM020:kHKP040?OI[03Sbkl0d;c70=2la`<0_Zk:0P2i
Z/X30;FWbP<0]:K:00<0]:G:0;>UbP2cYLX0B`2cYLX2000003H0oooo00<000000?ooo`3oool0103o
ool2000000X0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool0
00/0oooo00<000000?ooo`3oool0@`3ooolL0;>UbP80/jC:0P2cYLX00`2cY<X0/ZC:0;:TbP040;:T
b@<0/Z;90`2`X<P30:fLaP<0Z9C20P2VT/0209^3^@80Ugjf0P2CNK<208=TYP80OUjS0P1iF:00101d
Did0L4jJ071>VP1]BiP206U7U`0306I5UP1TA9H0I4BF0080HTBH00@0HTJK06A<X@1TC:40JEN[0P1b
J[X208F<d`040:32l@2FhYH0bNb<0>CTd`80]JG80P2CO;L0301bEj@0ECRB05DhTP17:h/0;aEo03TO
Q@0S3G`0;aN201X8O00Y588070f1034LR080;b2=0P13>j801023RM00[]Q^0000003Sbkl20=2la`<0
`k;90P2iZ/X20;JXbP030;FWbP2dY/X0]:K:0080]:K:CP2cYLXi0?ooo`040000003oool0oooo0?oo
o`80000000<0oooo0000003oool02@3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02oool0oooo
0?oOW01807@0_ooo00<0oooo000<0?ooo`800000A03ooolL0;>UbPD0/jC:0`2bY<T30;:Sb@<0/:78
0`2^WLH30:VG``80Z9C20`2NR;/209^3^@80S72^0P27JJX00`23I:H0OUjS07iNX`0207UHX00307AC
W@1`CYX0L4jJ0080KD^H00@0JDNG06I5UP1TA9H0I4BF0P1RA9P0101RAY/0I4bQ06A<X@1YEj/3079Z
^P0408F<d`2`n/l0S]=i0>CTd`<0]JG80P2CO;L2079GY00:05DhTP17:h/0;aEo03TOQ@0S3G`0;aN2
01X8O00Y588070f101@BR`80;b2=0P13>j801@23RM00[]Q^0000003ae;<0g<G20080bkS80`2l[<X3
0;JXbP<0]:K:C`2cYLXk0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
2`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000>0?ooo`03
0000003oool0oooo0480oooo00<000000;>UbP2cYLX0602cYLX30;>TbP@0/ZC90`2bXlT30;6Rb080
[io70P2^WLH0102[VL@0ZIO30:VG``2YUl<20::<_@80WXRk0`2AMK400`2<L:h0QfVZ08MYZP0208=T
YP0407iNX`1iF:00NERP07ACW@80L4jJ0P1]BiP0101YAiL0ITFF06I5UP1TA9H20694V080HTJK00<0
I4bQ06UGZ`1YEj/00P1bJ[X0102`n/l0S]=i0=3`T`3BbM830::=_`06089Y[@1UB9/0IDRK04/^S01E
>980Ab^;0P0_5Gl01P0i7hD08`el01X8O00J27`070f101@BR`80;b2=0P13>j80102^f6h000000?7D
/`3LaL830<^hb080`;390`2hZLX30;FVbP<0]:G:B`2cYLX00`000000oooo0?ooo`0k0?ooo`040000
003oool0oooo0?ooo`8000002P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo
_`1d04P0W=oo00<0oooo000?0?ooo`030000003oool0oooo0480oooo00<000000;>UbP2cYLX06@2c
YLX30;:TbP<0/Z?9102aX/P20;2Pa`80[io70`2[VL@30:B?_`80XXbm0P2ENk@2095e/@80S72^00@0
QfVZ08=TYP23I:H0OUjS0P1iF:000`1dDid0L4jJ071>VP0206e;V00406U7U`1VAIH0ITFF06A4UP80
HTBH0P1RAY/00`1TC:40JEN[06UGZ`020;K[mP0308kCN@3@l9<0i>GB00<0_[3<00@0XXfo089Y[@22
JJd0IDRK0P1;;X`01@0l88D0Ab^;02lEO`0i7hD08`el00806PQl00@070f101@BR`0D4X/0:T:g0`2_
l_D00`000000o=ZN0=O0a0020=O0a080`;390P2jZlX30;JWbP<0]:K:B`2cYLX00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool02`3ogi`0B01d0;oo
o`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000@0?ooo`030000003oool0oooo
0480oooo5P2cYLX60;>TbP<0/ZC90P2bXlT00`2aXlT0/J;80;6Rb0030;2Pa`<0[9_50`2VTl420:B?
_`<0VH2g0P2ENk@00`2AMK40S72^08a`[P0207]JX@80MUFN00@0LU2K06i<V@1^C9T0JTRG0P1WAIH2
06E4UP0306=4U`1SAYX0I4BF0080HTBH0P1RAY/01`1TC:40Vk7W09^ai`2K/NL0XN^T0000003TiM80
0P2n/<`3095j]P0307EIY@1J?I@0IDRK0080Bbj<00D0?22504L[R`0_5Gl0509g02<=O00201X8O080
70f100<051:;02Y2]`0Z@[L00P2_l_D00`000000el340=O0a0030<Neb080^Z_:0P2gZ<X20;JWbP<0
]:K:00<0]:G:0;>UbP2cYLX0AP2cYLX00`3oool000000?ooo`110?ooo`030000003oool0oooo0080
00001`3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool00`3oool00140oooo00<000000?ooo`3oool0@`3ooolE0;>UbPD0/jC:00@0/jC90;:Tb@2bY<T0
/ZC90`2aXlT30;2Qb0<0[Ic60P2XU/820:JC`@<0W8Fj0P2IP;L209Ek]080Q6JX0P1oH:@0101kFZ40
MUFN07IEWP1bD9/206i<V@0306Y8U`1WAIH0IdFF0080IDBF00@0HdBG06=6VP1SAYX0I4ZN0P1XDjL2
071T]0060821bP2K/NL0Vk7W0000003Gm9/0eLkB0`2]Vl@2095j]P0307EIY@1J?I@0FSfD0080Bbj<
00D0?22502@<NP0_5Gl0509g02<=O00201X8O08070f100L051:;02Y2]`0Z@[L0:T:g0:obm@3iejL0
iLZl0080dKc50`2n[/T40;NXbP<0]:K:0`2dYLY70;>UbP030000003oool0oooo0480oooo0P000000
0`3oool000000?ooo`070?ooo`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nL
B000M;l0103oool00180oooo0P0000140?ooo`030000002cYLX0/jG:0180/jG:0`2cY<X30;>Tb@<0
/Z?90`2aXLP30:jNa`030:fLaP2ZV<@0ZYS40080Z9K20P2ORK`309b5^P80SW6_0P29K:/00`24IZP0
Of2T07mPY00207]JX@0407IEWP1bD9/0LU2K06i<V@80JTRG00@0IdFF06E4UP1UA9H0HdBG0P1SAYX0
0`1TBYh0J5>W06QCY`02071T]080P87:00@0^_gO0=OdV`3Ti=80i>CB0P34^<h20:fKa004095j]P1e
FJD0MEVU05XmU080Bbj<00D0<aR002@<NP0_5Gl0509g02<=O00201X8O0040080N`0L3H4051:;01@B
R`80:T:g00<000000?WGY`3A_<D00P3A_<D20<Bbb0<0^JW:0`2eYlX30;BUbTP0/jG:A`3oool00`00
0000oooo000000090?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`04
0?ooo`00503oool00`000000oooo0?ooo`120?ooo`030000002cYLX0/jG:00l0/jG:0`2cY<X30;:T
bP@0/Z?90`2aX/P20:nOa`80[Yk70`2ZV<@30::=_P80WhVl0`2BMk800`2>LJl0RFb[08U/Z`0208AV
Z00407mPY01kFZ40NeZQ07IEWP80LU2K00@0KTbI06Y8U`1ZB9L0IdFF0P1UA9H206=4U`0406=6VP1T
BYh0I4ZN06QCY`80L6Bd0`2joMl20>CTdP040<BhcP2NRKd0WXVm09j9_@80Q6^^00h0JDfM050cSP1J
?I@0@RF604/^S00c6800?22502@<NP0_5Gl0509g00H0MP0J27`00P1k0001RP8051:;00@0:T:g0000
00000000m=>^0P3OaKl01034//P0_:c90;b/b@2l[<T30;JWbP@0]:K:A`2cYLX00`000000oooo0?oo
o`170?ooo`<000005P3oool001D0oooo00<000000?ooo`3oool0@P3ooolC0;>UbP<0/ZC:0`2bY<T3
0;6Rb@030;6Rb02`X<L0/:370080[io70`2[V/D20:FA`080XXfn0`2FOKD2099g/P0308ia[`29K:/0
RFb[0080Q6JX0P1cDY`206m=V@0306]9U`1XAYH0KTbI0080JTRG00<0IdFF06E4UP1UA9H00P1SA9L0
101SAYX0I4ZN06A:WP1XDjL40;;Lm@030000003[l//0e]3C00<0]ZG800@0WXVm08A[[P24Jjh0JDfM
0P1@<hh02P129HH0Bbj<03<HP00I0gH090aj02lEO`0D0WL01P1f01X8O00207/20001RP0600EbgP00
000000000000103ddjh0glFo0P3=^<H00`31/<T0_:c90;b/b@020;RYbP<0]JK:0`2dYLY40;>UbP80
0000BP3oool3000001H0oooo000F0?ooo`030000003oool0oooo0480oooo00<000000;>UbP2cYLX0
3@2cYLX30;>Tb@040;:TbP2bY<T0/ZC90;:Tb@80/Z?90P2aX/T30;2Pa`<0[I_50`2WU<820:FA`080
VX:h0P2FOKD2099g/P80PF:U0P1lG:8207QGW`0407=BW01_CIT0KdfI06]9U`80J4JF00D0IDBF06A4
U`1TA9L0HdFI06=8W@0206=4U`0306=6VP1TBYh0I4ZN0080Tj3M0P2bg?D00`2/m;H0g_NU0>?RdP02
0<Rmd0<0TWZf00l0NEjW05m2U`1YCId0JDfM050cSP129HH0:Q1k03<HP00I0gH090aj00H0L@0D0WL0
1P1f0000M00207/00P000HX200EbgP030000003ddjh0glFo0080cKS60`31/<T20;RYbP80]ZO:00<0
]JK:0;BVbP2dY/X00P2dYLY30;>UbP030000003oool0oooo04`0oooo00<000000?ooo`3oool0503o
ool001L0oooo00<000000?ooo`3oool0@P3oool00`000000/jG:0;>UbP0<0;>UbP030;>TbP2cY<T0
/jC900<0/ZC90`2bXlT40;2Qb0<0[Yg60P2YU/<20:ND`P<0WHJj0P2JP[P01@2FOKD0QVRY08IXZ@26
J:T0PF:U0080O5bR0P1hEil0101cDY`0KdfI06m=V@1[BIL206Q6UP0406E4UP1TA9L0I4BG06=5V@80
HdRM0P1VD:@00`1]GJl0NgK207]f`P0209>Pg@030:cd]P2cfg40hn;B0080b;g@0P2XU/82099j]P0>
07UNY`1O@YL0Gd:G06U=W@1@<hh0@RF602X@N`0c68006@=f02@<NP060740509g00H0MP0007@20080
N`80006:00D01G;N0000003mfIP0k/nd0=W1`P020<Vea`<0^Z_:0`2fYlX30;BVbT<0/jG:00<0oooo
0000003oool0C03oool2000001L0oooo000H0?ooo`800000A03oool<0;>UbP<0/jC:0`2bY<T30;:S
b@<0/J780`2_W/L00`2^WLH0ZYW40:ZIa0020:VF``80XH^m0P2MQ[X308mc/00308]^[026J:T0QVRY
0080PF:U00@0O5bR07QGW`1hEil0Le:L0P1_CIT206]9U`0506Q6UP1UA9H0IDBF06A4U`1SAIT00P1S
B9d206I@Y080KEf_00D0NgK20:cd]P2/m;H0/m]a0>Gj[`020=K?d`80^jc;0P2XU/803P2BN[H0NEjW
07UNY`1O@YL0B2Z9050cSP0i7880@RF602X@N`0c68006@=f00H0L@0D0WL01P1f0P0007@01`0207/0
006:0001RP05L]h000040>k?]03I`L800P39]LL30;n^b@<0]jS:0`2dY/Y30;>UbP800000C@3oool2
000001P0oooo000J0?ooo`030000003oool0oooo0480oooo2@2cYLX30;>TbP<0/jC90`2bXlT30;6R
b0<0[io70P2_W/L30:ZIa0<0Xhjo0P2QRkd209=i/`80Sg>`0P2;KZ`01026J:T0PF:U085RY@1lG:82
07QGW`0307=BW01_CIT0KdfI0080JdVG00@0J4JF06E4UP1UA9H0I4BG0P1SAIT00`1SB9d0IU2T06I@
Y00206eM[`80_OW/00@0Vn6?0>Gj[`3Fcm<0e/oC0P2k[</209f8_@80Qfj`00<0Ke:Q05LiTP1O@YL0
0P18:XT01@0i7880@RF602X@N`0c68006@=f00801P1a00@0001`00H0MP0007@000270P000HX00`0V
000000040?_GX@020=Bm``80aK;80`2iZLT30;FVbP<0]:G:@@2cYLX00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo01P0oooo000K0?ooo`030000003oool0oooo0480oooo2P2cYLX30;>TbP<0
/ZC90P2aXlT20;6Rb0040;2Pb02_WlL0[io70:nOa`<0[9[50P2VT/420:>>_`<0V7jf0P2CNK<00`2?
Lk00Rfj/08]^[00207UHX080ME>M00@0LDnJ06e;V01]BiP0JDNG0P1VAIH01@1TA9H0J4JF06E4UP1U
A9H0I4BG0080HdFI00<0HdRM06I@Y01VD:@00`2Yb?000`2KhHl0iOZ_0>cga@030<Vod080/9k60P2M
R;d01027K[00Ke:Q05LiTP1G>I8204PZR@0503TLPP0P27L0:Q1k00`0L@0I0gH00P06074010000700
1P1f0000M00008L302H000030000003D_L<0e;g30080aK;80P2m[<T00`2iZLT0]ZO:0;JWbP020;FV
bP030;BVbP2dYLX0]:G:0400/jG:00<000000?ooo`3oool0B`3oool2000001/0oooo000L0?ooo`03
0000003oool0oooo0480oooo00<000000;>UbP2cYLX0102cYLX40;>TbP<0/ZC90P2bXlT20;6Sb@<0
/:380`2]W<H30:RD`P80YY;10P2KPkT209Qn]P80TgVc0P23I:L207iNX`0407UHX01eDid0ME>M075?
VP80KD^H00<0JDNG06I5UP1VAIH00P1TA9H00`1SA9P0HdNK06=7V`0206=5V@0406=8W@2;T=<0Ri3C
08^@d`80ZLS`00<0fOBK0>cga@3Xjm000P3Ec]<30;2NaP80WHRm00@0Qfj`06mBX@1_DZ40EcVB0P18
:XT01@0i788080Qg02X@N`0<07406@=f00801P1a00<0001`0000JP0007@00P0008L202H000040?OD
Z03Rak`0ck[50<nja@<0_Jc9102fYlX30;BVbSl0/jG:0P00001=0?ooo`030000003oool0oooo01/0
oooo000M0?ooo`800000@`3oool00`000000/jG:0;>UbP030;>UbP<0/jC:0`2bY<T30;:Sb@<0/J78
102^WLL20:VG``80Z9C20`2NR;/209^3^@80S72^0P27JZX00`23I:L0OUjS07iNX`0207UHX00507EC
W@1aCiX0LDnJ06e;V01YAiL00P1VAIH206A4UP0406=4V01SAi/0HdNK06E=X@80JeR[00P0MVfk08^@
d`2;T=<0Ri3C0;Cjb@3Yn[L0j>_@0=G>d`<0_[7=0`2CO;L207eSZP0:06I8V`1?<8d0EcVB040RQ@18
:XT0<AEn03TLPP0P27L0301a01T3MP801P1a00@0001`0000JP0007@0001d0P0008L0100V0000mmBX
0<nja@3?^/D30<>`b0<0^:W:0`2eY/X30;BUbS`0/jG:00<0oooo0000003oool0C03oool2000001h0
oooo000O0?ooo`030000003oool0oooo0440oooo102cYLX30;>TbP<0/ZC90`2bXlT30;6Rb080[io7
0P2^WLL20:^Ia080ZIO30P2QS;d209j8^`<0T7Fa00<0S72^08MZZP27JZX00P23I:L0101nGZ<0NERP
07UHX01eDid2075?VP0406e;V01YAiL0JDNG06I5UP80I4BF00@0HdBH06=7V`1SAi/0IDfQ0P1[F:/2
07I]^`80]?[900@0Sm9d0>cdb@3Nfm<0g]_C0P3:_m020:JC`P<0Tgbg00/0OF>Z06I8V`1?<8d0Cc2=
040RQ@18:XT0<AEn03TLPP0P27L0:Q1k00`0L@0200H0L@040000L00006X0001d0000M080002700<0
000L0?;@[`3M`kl00P3;]/H30;^[b@<0]ZO:0`2dY/Xn0;>UbP030000003oool0oooo04/0oooo00<0
00000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool0@P3oool30;>TbP<0/jC90`2bXlT3
0;6Rb@<0/:380P2_WlL30:^Ia0<0Y8no0P2QS;d209Ek]080T7Fa0P2<L:h01027JZX0PfBW08=TY`1n
GZ<207UHX00407ECW@1aCiX0LDnJ06e;V080JDNG00@0ITFF06A4UP1TA9H0HdBH0P1SAi/206E=X@06
06]HZ`2kko@0^nod0;__m02?dW@0h?RW0P3Nfm<0103:_m00]JG90;FUb@2eYLT20:JC`P<0M5VT0P1V
B9/02P1?<8d0@2:502P>NP0a5Gh05@1c0208M`0Z47/0301a0000K00607420000L0060000JP0007@0
002700D01@000000gL>o0`3;]/H20<2^b0<0]jS90`2dY/Xn0;>UbP030000003oool0oooo04/0oooo
00<000000?ooo`3oool07`3oool00240oooo00<000000?ooo`3oool0@P3oool010000000/jC:0;>T
bP2cY<X20;:Tb@<0/Z?90P2aX/T00`2`XLP0/:380;2Pb0030:bKa@<0YY?10P2TSkl309V0]`80UG^d
00<0T7Fa08a`[P2<L:h00P1kFZ4207IEWP04079@V`1^C9T0KTbI06Y8U`80IdJF00<0IDBF06=4U`1V
AIH00P1TA9H00`1SA9P0HdNK06=7V`0206E=X@<0WkCW0P2RjIl0103/nKl0dlcC0=?<d`3Cc=<20<2c
c@80WHVm0P2;L[8207AIY00@05doUP1VB9/0Cc2=040RQ@0X3WX0<AEn01D0L`0P27L0001]00`0L@00
06`01P1a0000J0000700001Z0:`Q00801@0500@0oMNJ0>c=]03H_l40f;o10P30[/P20;ZZb@040;NX
b@2eY/X0]JK:0;BVbP80]:G:>`2cYLX00`000000oooo0?ooo`1;0?ooo`8000008P3oool00280oooo
00<000000?ooo`3oool0@P3oool00`000000/jC:0;:Tb@030;:Tb@<0/Z?90`2`XLP30:fMaP80Z9K3
0`2VTl4209b5^P80VH2g0P2ENk@208AVZ080Of2T00@0NeZQ07IEWP1fEIh0LU2K0P1^C9T0101ZB9L0
IdJF06M6UP1UA9H206=4U`0306=6VP1TBil0I4^O00<0LFFe0P23PlX01@2O]>L0X^VO0:;YW`3/nKl0
jo3=0080fmOC00@0`;?=0:fKa@2]VlD0[I_50P2MRKd04P2;L[80M5VT07AIY01M?iH0AbV804l`S@0h
6h40@2:5034EOP0E07<080Qg0000K@0<0740001/00H0L@0006P0001`0000JP80[24000@0000L0>c=
]03/cK@0f;o10P38]<L30;ZZb@<0]JK:0`2dYLXi0;>UbP030?ooo`000000oooo04`0oooo00<00000
0?ooo`3oool08P3oool002<0oooo0P0000130?ooo`<0/ZC90`2bXlT30;6Qb0<0[Yk70`2ZV<@20:RF
``<0WhVl0P2LQKX208ib[`80RFb[00<0Q6JX07mPY01oH:@00P1kFZ40101fEIh0LU2K079@V`1^C9T2
06Y8U`0506M6UP1UA9H0HdBG06=4U`1SAYX00P1TBil01@1XE:L0LFFe075U]@1aIKD0Ph?:0080X^VO
00<0i_Za0>_`c@3Kem<00`39_m420;RYbP070:fKa@22J:d0PVR]089X[@1/Cil0M5VT05doUP0204LY
R00;03PKP@108XD0:0ij034EOP0E07<0001]00`0L@0006`0001K0000J00004l00P0006X0102/8@00
000L0>c=]03H_l420<Rda`<0_Zg80`2gYlX30;BVbST0/jG:0P00001<0?ooo`8000009@3oool002D0
oooo00<000000?ooo`3oool0@@3oool010000000/Z?90;:Sb@2bXlT30;6Rb@80[io70P2^W/L00`2/
V/D0ZYS40:ZHa0030::=_P80WhVl0`2BMk800`2>LZl0RFb[08U/Z`0208AVZ00407mPY01kFZ40NeZQ
07IEWP80LU2K00@0KTbI06Y8U`1ZB9L0IdJF0P1UA9H0101SA9L0HdJJ06=6VP1TBil206QDY`80LFFe
0P2koM/00`2Cf7h0k?O50>;QdP030=79dP80^:W:0P2UT/401@2FOkT0PVR]089X[@1/Cil0ESNA0080
GCnF00`0AbV803PKP@0O1WH0:0ij034EOP0E07<0001]00`0L@0006`0001K0000J00004l20000JP03
0:`Q000001`0ilVh0080dk_30P34/LL30;VYb@<0]JK:0`2dYLXg0;>UbP030000003oool0oooo04/0
oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0@P3oool30;6Rb@<0/:38
0P2_WlL30:bJa@80YI700P2RSKh309Im]@80TWNb00<0SW:_08U/Z`29K:/00P24IZP207=BW080KdfI
0P1bD9/0101^C9T0JTRG06Y8U`1WAYH206E4UP0406=4U`1SAYX0HdJJ06A;W`80J5BW0`2eg_D00`2C
f7h0k?O50>;QdP020=79dP<0`KC>0`2UT/4209Io^@0;089X[@1/Cil0K4nO05HgT@1M?iH0AbV803PK
P@0O1WH0:0ij034EOP0E07<00P0006d01@0006`0001K0000J00006P0001?0080P0D<00<0ilVh0=>k
``3C^l<00P34/LL20;b/b@@0]ZO:0`2dYLXg0;>UbP030000003oool0oooo04/0oooo00<000000?oo
o`3oool09P3oool002L0oooo00<000000?ooo`3oool0@P3oool20;6Rb@030;2Qb02`X<P0/:3800<0
[Ic60`2WU<820:FA`080VX:h0P2FOKD2099g/P80PF:U0P1lG:8207QGW`0407=BW01_CIT0KdfI06a9
V080J4JF00<0ITFF06A4U`1TA9L00P1UA9H0101SA9L0HdJJ06=6VP1TBil309BRg@80]Mke00@0j_Zj
0>S[d03Xjm00f=?C0`38_]030;6Qa`80SWNd0P1jGjP206a?W`0805HgT@108X@0AbV803PKP@0O1WH0
:0ij00P0K`0E07<20000K@050000I@0006`0001K0000J00004l00P201@`0103fdZT0hLFl0<jha@3>
^<D30;b/b@030;RXb@2fYlX0]ZO:0080]:K:00<0]:G:0;>UbP2cYLX0=02cYLX2000004`0oooo0P00
000Y0?ooo`00:03oool00`000000oooo0?ooo`120?ooo`<0/:780`2^WLH20:VF``80YiC20`2MQ[X2
09Z2^080Rfj/0P26J:T00`21HZD0O5bR07aLXP0207QGW`0407=BW01_CIT0KdfI06a9V080J4JF00@0
ITFF06A4U`1TA9L0HdFI0P1SB9d0101VD:@0KUj_06iN[`1lMl8309BRg@040:_b/P3Xjm00j>_@0=SC
d`80b;k@0`2j[<`309n:_P80SWNd00@0NUnX06A7VP1><8`0ESNA0P108X@01@0`57d0>1^101l6MP08
06l05@1c0080001]00@0001U0000K00005/0001X0P0004l010201@`0hLFl0<jha@3>^<D30<:_b0<0
^:S90`2dY/Xf0;>UbP030000003oool0oooo04/0oooo00<000000?ooo`3oool0:@3oool002T0oooo
0P0000130?ooo`<0[Yk70`2[VL@20:VF``80XH^m0P2MQ[X308mc/00308]^[026J:T0QVRY0080PF:U
00@0O5bR07QGW`1hEil0Le:L0P1_CIT0101/BIP0J4JF06Q6UP1VAIH206A4U`0406=5V@1SB9d0HdRM
06I@Y080KUj_0P1lMl820:_b/P030000003Og=<0gmcC0080clKB0P31]<h40:^Ja@0509n:_P2>Mk@0
SWNd07YOZ01TAiX00P1><8`2040RQ005030DO@0h6h407`If02P>NP0E07<00P0006d0100006D0001/
0000F`3?F@020000C`030805303acjl0g<6o0080bkK60`2kZ/T30;JWbP<0]:G:<`2cYLX00`3oool0
00000?ooo`1;0?ooo`800000;03oool002/0oooo00<000000?ooo`3oool0@@3oool00`000000[9_5
0:bKa@020:^Ia0<0Xhjo0P2QRkd209=i/`80Sg>`0P2;KZ`01026J:T0PF:U085RY@1lG:8207QGW`04
07=BW01_CIT0KdfI06a9V080J4JF00@0ITFF06A4U`1TA9L0HdFI0P1SB9d206I@Y00706iN[`1lMl80
__[[0;kjj`000000k?S20>GUd@020=G?d`80`KC>0`2dYLT309R3^P0308M^/01bEj<0LUNS0080I4NJ
00P0CS2<040RQ0108X@0<1Am01@0LP0O1WH0:0ij00P0K`80001]00@0001U0000A00005/0ceT00P00
04l00`0002l0g<6o0<^faP020<^faP80_jk80`2gZ<T30;BVbS<0/jG:0P00001<0?ooo`030000003o
ool0oooo02`0oooo000/0?ooo`030000003oool0oooo0440oooo00<000000:bKa@2/VlD00P2VT/42
0:>>_`<0Ugjf0P2CNK<00`2?Lk00Rfj/08]^[00207UIX080ME>M00H0LDnJ06e;V01]BiP0JDNG06I5
UP1/BIP206Q6UP0406I5UP1TA9L0I4BG06=5V@80HdRM0P1VD:@01P1^GZl0__[[0;kjj`2Jgh`0eo>I
0>GUd@80eLoC0P37_=020;^]c0<0YI?20P2HPkX208M^/004079GX`1M?YD0I4NJ04h`S080@2:400T0
<1Am01@0LP0O1WH0001[00P0K`0006L0001]0000I@0004@00P0005/0103?F@00C`0^0?cFV`3[c;@2
0=Nn`@80_jk80P2jZLT30;FVbP<0]:G:<@2cYLX00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo02d0oooo000]0?ooo`030000003oool0oooo0440oooo0`2XU<820:JB`@80Vh>i0P2GO[H209=i
/`80PfBW0P1nGZ<0101iFJ00ME>M07ECW@1aCiX206e;V00406U7U`1VAIH0ITFF06A4UP80HdBH0P1T
A9L00`1SAIT0HdRM06=8W@0308^Ae0060:_:l02Jgh`0eo>I0>Sj]P3Yk/h0fmOC0P3<`m430;^]c003
0:nOa`2UTl80YI?20080V8>j0P27K[003@1bEj<0GCjE04LXR01><8`0>1^0040RQ00X3GT0501b01l6
MP0006/0201_0000I`0006d00P0006D20000F`040<mI000T0380jlbd0=Nn`@<0ak?60`2jZLT0102g
YlT0]JK:0;FVbP2dY/X20;BUbS00/jG:00<000000?ooo`3oool0BP3oool200000300oooo000^0?oo
o`800000@P3oool20:RD`P<0WXRk0P2KPkT208a`[P80QfZZ00<0PfBW07iNX`1nGZ<00P1iFJ001@1e
Did0LDnJ075?VP1]BiP0JDNG0080ITFF00@0I4BF06=4V01SA9P0HdNK0P1UCJ400`1[F:/0MVfk07I]
^`0208^Ae080/o[600<0j?Zf0>W^cP3Kem<00P3<`m430<2dcP<0[io70P2BNkL2081VZ`80JdjN01<0
GCjE04LXR017:8P0>1^0040RQ00X3GT0<1Am01@0LP0006/0201_0000I`0006d0001K0000I@0004@0
001K0<mI000T0380nM>R00<0d[_30`2n[<P30;NWb@<0]:K:;`2cYLX2000004`0oooo00<000000?oo
o`3oool0<03oool00300oooo00<000000?ooo`3oool0@03oool20::<_@80WXRk0`2AM[4208a`[P04
08MZZP23I:L0PfBW07iNX`80NEVP00@0ME>M075?VP1aCiX0KD^H0P1YAiL01@1VAIH0I4BF06=4V01S
A9P0HdNK0080IDfQ00T0JeR[07I]^`1fKK/0MVfk08^Ae02cn/H0j?Zf0>ceb03Qh=<00P3Bbm<20<Fj
d0<0]ZO:0`2QSKl2099k]`0E081VZ`1[CYh0JdjN05DgT01M?YD0AbR803PKP00O1WH0:0ei030DO@0D
0780001[00P0K`0006L000190000F`0006D000140;Q1900T0380000_00<0d[_30P34/LL30;VYb@<0
]JK:0`2dYLX]0;>UbP030000003oool0oooo04X0oooo0P00000c0?ooo`00<@3oool00`000000oooo
0?ooo`100?ooo`80XXbm0P2ENk@2095f/@80S72^00@0QfZZ08=TY`23I:L0OUjS0P1iFJ00101eDid0
LDnJ075?VP1]BiP206U7U`0406I5UP1TA9H0I4BF06=4V080HdNK00<0IDfQ06]HZ`1[F:/00P1fKK/0
102cn/H0goNU0>ceb03WjM420=SCd`80aK[@0`2k[/d30:ZIa@040:6=_`2BNkL0TW^g081VZ`80JdjN
00P0ECN@040RQ017:8P0>1^001l6MP0X3GT01`1^01@0LP80001[00D0001W0000B@0005/0cfl00000
A0020;Q190040000:03Pa;`0h<Bl0<Baa`<0_:_9102fYlX30;BUbR`0/jG:00<0oooo0000003oool0
B`3oool00`000000oooo0?ooo`0c0?ooo`00<P3oool00`000000oooo0?ooo`0o0?ooo`<0VH2g0P2E
Nk@01@2AM[40P62T081PY020H:@0NeZQ0080MUFN00@0LU2K06i<V@1^C9T0JdRG0P1WAYH00`1UA9H0
HdBG06I5UP0206A4UP0406=4V01SAi/0HdNK06E=X@80JeR[0`2kl?<0103/nKh0inWA0=SCd`3Hdm<2
0<[1d@80_k?>0`2bX/P309^6_00=08ad/`1iGZL0NEjW06A6V@1[CYh0ECN@040RQ017:8P0>1^001l6
MP0X3GT01`1^01@0LP020000J`040000I`0004T0001K0<m_0080001400<0^44T0?GAZ@3Pa;`00P3>
^<@20<:_b0<0^:S90`2dY/X/0;>UbP030?ooo`000000000004`0oooo00<000000?ooo`3oool0=03o
ool003<0oooo00<000000?ooo`3oool0?`3oool209V0]`<0RFb[00@0Q6JX081PY020H:@0NeZQ0P1f
EIh0101bD9/0KTbI06i<V@1[B9L206M6UP0606E4UP1SA9L0HdBG06=6VP1TBYh0HdBH0P1SAi/208:3
b`<0WkGX00@0XNRM0>_ac03Nfm<0g]_C0P3?am820;nccP<0]jW;0P2VU<8209^6_080S7Bc00<0NEjW
06A6V@1><8`00P1E=i001P108X@0<AAm03PKP00O1WH01`1^01@0LP80001[00@0001O0000I`0005/0
cfl00P0004@0102h@B@0h<Bl0<jha03>^<@20<:_b080^j[900@0^:S90;JVbP2fY/X0]:K:0P2dYLX[
0;>UbP030000003oool0oooo04X0oooo0P00000g0?ooo`00=03oool200000400oooo0P2>LZl208U/
Z`80Q6JX00D0P62T07]JX@1kFZ40MUFN079@V`0206i<V@0406]8U`1WAYH0IdJF06E4UP80HdBG00@0
HdJJ06A:WP1TBYh0J5BW0P1aI;D208:3b`80XNRM00<0i_Z`0=kKd`3Nfm<00P3?am820<Bhc`80^jk=
0`2^W/L20:JD`P0509^6_02<M;<0S7Bc07UNY`1TAYT00P1><8`01`1E=i00@2:4034DO@0h6h007`If
02P=N@0D07800P0006/02@0005l0001W0000B@0005/0cfl008<O?@0002P0l<j_0=_1_`020<Zea@<0
^j[90`2fY/X30;BUbRX0/jG:00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0g0?ooo`00
=P3oool00`000000oooo0?ooo`0n0?ooo`80SW:_00@0RFb[08AVZ024IZP0P62T0P1kFZ401@1fEIh0
LU2K06i<V@1^C9T0JdRG0080IdJF00@0IDBF06=4U`1SA9L0HdJJ0P1TBYh0101XE:L0LFBe075T]@22
Pl/20;[mfP0309;FO03]mlD0e<kC0080e<kC0P38_]430;^^c@030;>Ub@2^W/L0[Yk700<0UX2i00d0
QVf_079FXP1bEZ80GCjD06A6V@1><8`0>A^0040RQ00a57d0>1^001l6MP0X3GT01`1^0080001[00P0
001O0000I`0004T0001K0<m_00237cd0D`520=_1_`80b[G50`2o[/P30;NXb@<0]:K::@2cYLX20000
04/0oooo0P00000j0?ooo`00=`3oool00`000000oooo0?ooo`0m0?ooo`80SW:_00D0RFb[07QGW`1h
Eil0N5NO07=BW00206m=V@0406a9V01^C9T0KTbI06]8U`80IdJF00@0IDBF06=4U`1SA9L0HdJJ0P1T
BYh206QDY`06075T]@2joMX0^_gJ09;FO03]mlD0j>c?0P3Je]<00`38_]40_k;>0;nbcP020;nbcP<0
/jG90P2RSl0209J0^@80QVf_00/0LUJR05dnU017:HP0CS2<03TKP0108X@0<AAm01@0LP0O1WH0001Z
00L0KP020000J`090000G`2bK00000190=YW7`3?K`00Palm0?cEV`3[bk@0e[g10080ak;60`2iZLT3
0;FVbP<0]:G:9`2cYLX00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03X0oooo000h0?oo
o`030000003oool0oooo03`0oooo0`21HZD0101mG:80N5NO07QGW`1cDY`206m=V@0706a9V01XAiH0
ITFF06I5UP1TA9L0HdFI06E4UP0206=4U`0306=6VP1TBYh0I4ZN0080J5BW0P2dgoD0102BeW`0j_Zj
0>S/c`3Je]<30<c3dP80`[O?0`2hZL/30:^Ja@80XXo00P1oIJ/01@1[CYh0LUJR05dnU017:HP0CS2<
0080>A^000l0:0ei01@0LP0O1WH0001Z00L0KP0006D0001[0000G`2bK00000190=YW7`3?K`00D`52
0>_;]03F_L400`37//H20;f/b0<0]ZO90`2dYLXV0;>UbP030?ooo`000000oooo04/0oooo00<00000
0?ooo`3oool0>`3oool003T0oooo00<000000?ooo`3oool0?03oool2085RY@0407eLXP1hEil0N5NO
07=BW080KdfI00D0K4VH06Q7UP1VAIH0ITFF06A4U`0206=5V@0406=8W@1VD:@0IU2T06eM[`80NgK2
0P2DX]h00`2XlJl000000>ccbP020>3Md`80dLWC00@0`[O?0;^^c02k[/`0^jk<102`XLP209j:_P80
T7Vf00<0OfF[06]>WP1[CYh00P1M?Y@03017:HP0>A^003TKP00X3GT0<AAm01l6MP0006X01`1^0000
I@0006/0001O0;9/008000190P1C0D80103idj<0iLNi0=:j``3B^/<20;f/b080^:W900@0]ZO90;FV
bP2eY/X0]:G:9@2cYLX00`3oool000000000001;0?ooo`800000?P3oool003X0oooo0P00000l0?oo
o`80PF:U00@0OEbR07QGW`1hEil0Le:L0P1_CIT01@1/BIP0J4NF06Q7UP1VAIH0I4BG0080HdFI00@0
HdRM06I@Y01VD:@0KEf_0`1kM/800`2DX]h000000<k]S@020>3Md`040=79d`36^m00a[_@0<Jkd080
_[7>0`2dY/X30:NF``80WXZn00L0T7Vf07mUZ`1oIJ/0JdjN05DgT01M?Y@0AbV80080>A^000T0:0ei
034DO@0D0780001Z00L0KP0006D0001[0000D`0005l00P0004T0103JIal0:P0o0>G7^@3B^/<30<Ba
a`<0^:W90`2eY/XV0;>UbP030000003oool0oooo04X0oooo00<000000?ooo`3oool0?P3oool003`0
oooo00<000000?ooo`3oool0>@3oool2085RY@0407eLXP1hEil0N5NO07=BW080KdfI00@0K4VH06Q7
UP1XAiH0ITFF0P1TA9L0101SAIT0HdRM06=8W@1VD:@206eM[`80NgK200<0_O[Z0<k]S@3/nL800`3F
d=<20<[0d@80_[7>0P2hZ//30:jNa`80YiK30`2;Lk801P1hGJH0I4JI06]>WP1E=i00@B:404LYR080
>A^000<0:0ei00L0KP0D07800P0006X02@0006D0000n0000D`0005l0/V`00000B@3JIal0100g0?C@
Z@020<jga0@0_:_90`2fYlX30;BUbR<0/jG:00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0o0?ooo`00?@3oool00`000000oooo0?ooo`0i0?ooo`80ME>M00@0LDnJ06e;V01]BiP0JDNG0P1V
AIH206Q7UP0406I5UP1TA9L0I4BG06=5V@80HdRM00<0IU2T06eM[`1]GJl00P2mn^X00`2GgHT0k?W2
0>[^cP020=cHd`040<[0d@31]Ll0`KG?0<6ec`<0^:[;00<0/Z?90:jNa`2^W/L00`2IQ;/208]c/P06
07QMYP1TAYT0I4JI05DgT0118X@0AbV80P0i6h000`0X3GT01`1^01@0LP020000JP080000I@0003h0
001C0000G`2bK000/DHo0=YW7`3dd:T30<jga080`Zo80`2hZ<T30;BVbR<0/jG:0P00001;0?ooo`80
0000@P3oool003h0oooo00<000000?ooo`3oool0>03oool207ECW@04075?VP1]BiP0KD^H06U7U`80
ITFF00<0I4BF06=4V01SA9P00P1TA9L00`1SAIT0HdRM06=8W@0208ZAe080Zl[`00@0Umf90>Sj]P3Z
k/h0g=SC0P3>a]830<Bic`<0^Zg=0`2bXlT20:BA`P80VHBk0P2;Lk8207QMYP0906A6V@1E=i00ECN@
044RQ00a57d0>A^001l6MP0706h0501b0080001Z00D0001U0000?P0005<0hG/70;9/00020;56?`03
0>o=[`3K`;l0fl2o0080`Zo80P2jZ/T30;FVbP<0]:G:802cYLX00`3oool000000?ooo`1;0?ooo`03
0000003oool0oooo0480oooo000o0?ooo`030000003oool0oooo03P0oooo00D0ME>M075?VP1aCiX0
KD^H06U7U`0206I5UP0406A4UP1SA9P0HdBH06=7V`80IDfQ00<0JUR[07I/^`1fK;/00P2:TM@20;7i
a0040>ceb03RhM<0h^7C0=?<d`80akgA0`2m/<d30;FWbP<0Zi[50P2TTL8208E/[`80LEFR00X0GCjE
06A6V@1?<8`0ECN@044RQ00a57d0>A^001l6MP0X3GT0501b0P0006X0100005`0001U0000D`3QN`L2
0;9/00030;56?`3_cJl0b[G50080b[G50`2jZ/T0102gYlT0]JK:0;FVbP2dY/X20;BUbQl0/jG:00<0
oooo0000003oool0BP3oool2000004D0oooo00100?ooo`800000>03oool0101eDid0LDnJ075?VP1]
BiP206U7U`0506I5UP1TA9H0I4BF06=4V01SAi/00P1UCJ40101ZF:/0MVbk07I/^`2:TM@20;7ia004
0>ceb03RhM<0h^7C0=?<d`<0akgA0P2o/lh30;RZc0<0/:380P2QSKl209Eo^@80QFb_00/0LEFR05dn
U@1M?YD0Cc2<03TLP@118X@0<AAm01@0LP0O1WH0:0ei00L0KP020000JP040000G00006D0000n0000
D`80/V`000@0/DHo0>[:]03F_L40e[g10`2o[LP30;NWb@<0]:K:7P2cYLX00`3oool000000000001;
0?ooo`030000003oool0oooo04D0oooo00120?ooo`030000003oool0oooo03H0oooo0P1aCiX0101]
BiP0JDNG06U7U`1VAIH206A4UP0406=4V01SAi/0HdNK06E=X@80JUR[00@0MVbk0;7ia02anL@0joZn
0P3WjM020=SCd`80bl;A00@0_k?>0;Z]c02j[L`0^Zg<0`2cYLX30:VGa080XHfo00@0UGni08E/[`25
K:l0LEFR0P1M?YD0201?<8`0>Ab1044RQ00a57d0501b01l6MP0X3GT01`1^0P0006X02@0005`0001U
0000?P0005<0hG/7088VBP0]04@0j/Zd0=Jm`@020<NbaP<0^JW90`2eY/X30;BUbQd0/jG:00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`160?ooo`00@`3oool00`000000oooo0?ooo`0e0?oo
o`0606]9U`1WAYH0IdJF06E4UP1SA9L0ITFF0P1TA9H0101SA9P0HdNK06=7V`1UCJ4206YHZ`80^o3c
00<0W^JJ0>OYd03WjM000P3Hdm<0103;`]40`[O?0<:gc`32]ll20;b_c@<0]ZO;0P2^W/L20:VGa0<0
T7Vf00<0OfB[06]>WP1[CYh00P1M?YD04P18:HP0Cc2<03TLP@0Y3WX0501b01l6MP0006T01`1^0000
H`0006X0001L0<=g000003h0f6Xc0>5k1`229TX0j/Zd0=Jm`@80ak;60`2m[<P30;JWb@<0]:G:7@2c
YLX00`000000oooo0?ooo`190?ooo`800000B@3oool004@0oooo00<000000?ooo`3oool0=03oool0
101[BIL0IdJF06M6UP1UA9H206=4U`0306=6VP1TBYh0I4ZN0080HdNK0P22P//209nfj00409kVVP2L
bU`0g]_C0=kKd`80d<SB0`35^]020;b_c@80^:[;00<0]ZO;0;6Rb@2aX/T00P2^W/L209f8_@80T7Vf
0P1oI:/05P1[CYh0GCjE05dnU@18:HP0Cc2<03TLP@0Y3WX0<AAm01@0LP0006T01`1^0000H`0006X0
001L0<=g000003h0f6Xc0>5k1`1F1dX0n=:S0>G7^@3A^/<20<Baa`<0^:W90`2dY/X30;BUbQX0/jG:
0P00001;0?ooo`030000003oool0oooo04T0oooo00150?ooo`800000=03oool0101[BIL0IdJF06M6
UP1UA9H206=4U`0406=6VP1TBYh0I4ZN06QCY`80LFBd0P22P//0102NiYX0W<YL0>gga@3Thm820=G>
d`80b;oA0`2n//h30;RZb`<0/J;90`2VU<<209f8_@0B091i]P1oI:/0OfB[06]>WP1F=i00GCjE04PY
R00b5Gd0>Ab102T>NP0a57d0501b0000J@0706h0001S0000JP0004h0`gL00P0003h205H7BP030>G7
^@3A^/<0a;770080a;770P2lZlP30;JWbP<0]:G:6@2cYLX00`3oool000000?ooo`1:0?ooo`800000
C03oool004L0oooo00<000000?ooo`3oool0<@3oool0101[BIL0IdJF06M6UP1UA9H206=4U`0406=6
VP1TBYh0I4ZN06QCY`80LFBd00D0PX;;0;Smf02hoMP0W<YL0>CSdP020=G>d`80b;oA0`30]Ll30;V/
c0<0]:G:0`2/VlH209V4^`80RW:b0140N5fV06A6V@1TAYT0ESN@044SQ018:HP0<QEm03TLP@0Y3WX0
1`1^01@0LP0006T01`1^0000H`0006X0001>0000G0020000?P030=QZ<`0]04@0h<>l00<0cKO40P2l
ZlP20;RXb@040;JWbP2dY/X0]:K:0;BUbQT0/jG:00<0oooo0000003oool0BP3oool00`000000oooo
0?ooo`1<0?ooo`00B03oool00`000000oooo0?ooo`0`0?ooo`0406]9U`1WAYH0IdJF06E4UP80HdBG
00@0HdJJ06A:WP1TBYh0J5>W0P1aI;@20;Smf00408oDN@3Xk<l0j>c?0=[Fd`80cLCB0P33^<l30;^^
c@<0]ZS;0`2`X<P30:>@`@80VHBk00D0RW:b07QMYP1TAYT0I4JI05HgT002044SQ080<QEm00<0:@ij
00L0KP0D07800P0006T0200006<0000g0000CP0005`0`gL00000?P3HJS<0h<>l0P3=]l@30<6_a`<0
^:S90`2dY/XH0;>UbP030?ooo`000000000004/0oooo00<000000?ooo`3oool0C@3oool004T0oooo
00<000000?ooo`3oool0<03oool00`1TA9H0HdFH06E4UP0206=4U`0406=6VP1TBYh0I4ZN06QCY`<0
]=of00@0SmAi0>S/c`3Xk<l0f]KC0P3=a=820<>hc`<0_K3=0`2gZL/30;:Tb@80ZYW50P2ST<4209V4
^`0708Yb/P1hGJH0N5fV06A6V@1?<8`0ESN@044SQ002038EO@0301l6MP0706h0501b0080001Y00T0
001S0000=`0004h0iX0G0<=g002_BDT0f6Xc0>o=/03K`;l00P3:]LD30;ZZb@<0]JK:0`2dYLXG0;>U
bP030000003oool0oooo04T0oooo0P00001@0?ooo`00BP3oool00`000000oooo0?ooo`0_0?ooo`04
06A4UP1SAIP0HdFH06=8W080ITnT00<0KEf_07Yf`P1jM/800P2DX]h01@2Wl:d0cnj>0>ccbP3PgM<0
dL[B00<0a[c@0`2m/<d20;V/c0<0]:K:0`2^W/L20:ZIa@80U7jh0P25Jjh01P1bEZ80GCnE06A6V@1?
<8`0ESN@044SQ080<QEm00<07`If02T>NP0D07800P0006T01@0005X0001S0000CP3VP1L0`gL00080
[dU900@0fl2o0<Zea@3:]LD0b[G50P2o[LP30;NWb@<0]:K:5`2cYLX00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0500oooo001;0?ooo`800000;`3oool0101TA9H0HdFH06=5V01SB9`206I?
Y00306eM[`1jM/80NWK20080Yo2]00<0cnj>0>?i[03oool0103oool30;nccP80^Jc<0P2fZ</00`2d
Y/X0/J;90;6Rb@020:jNa`<0X8bo0P2DO[P01`25Jjh0LUJR05doU@1M?iD0Cc2<03XLP@118h@00P0b
5Gd00`0O1WH0:@ij00L0KP020000J@080000FP0006<0001>0000CP33M`00[dU9088YD03Zb[@20=Jl
`@040;n]b02iZLT0^JW90;VYb@<0]JK:0`2dYLXD0;>UbP800000BP3oool2000005<0oooo001=0?oo
o`030000003oool0oooo02`0oooo0P1TA9H0101SAIP0HdRL06=8W01VCj@206eM[`0407Yf`P2knnT0
UMb70<o^SPL0oooo0`2j[Ld30;JXb`@0/J;90`2XU/@0102PS;l0U7jh09An^025Jjh2079FXP0405do
U@1?<8`0>Qb1044SQ080<QEm00<07`If02T>NP0706h00P0006T0200005X0001S0000=`0004h0`gL0
0:m9B@0_04L0e[c10`36//H0102m[<P0^JW90;VYb@2fYlT20;FVbP<0]:G:4P2cYLX00`3oool00000
0?ooo`1:0?ooo`030000003oool0oooo05<0oooo001>0?ooo`030000003oool0oooo02/0oooo0P1T
A9H0101SAIP0HdRL06=8W01VCj@206eM[`030;_kj@2Eg8L0000000X0oooo0`2gZL/30;>UbP<0[Ig7
0`2LR;d0602@N;D0OVB[07iTZ`1[CYh0EcRA05doU@18:HP0Cc2<03XLP@0Y3WX0<QEm01l6MP0006T0
1`1^0000H`0006T0001J0<am000003L0001>0>J05`22:E00n=:T0>G6^@80dK[30`2m[<P30;JWb@<0
]:G:4P2cYLX00`3oool000000?ooo`1:0?ooo`030000003oool0oooo05@0oooo001?0?ooo`030000
003oool0oooo02/0oooo00@0I4bQ06=5V01SB9`0HdRL0P2:TM@20:[;l@030000003oool0oooo00X0
oooo0`2dY/X30;2Qb0<0YI?20P2LR;d0102@N;D0OVB[07iTZ`1[CYh205LhT@0A04PYR01?<8`0>Qb1
02T>NP0b5Gd0501b0000J@0706h0001S0000J@0005X0c7d00000=`3FJcd0iX0G088YD03Ua[T00P3A
^/<20<B`a`<0^:W90`2dY/XB0;>UbP030?ooo`000000000004X0oooo0P00001G0?ooo`00D03oool0
0`000000oooo0?ooo`0Z0?ooo`80I4bQ00<0JUR[07E/^`1eK;/00P2:TM@00`2_n<8000000?ooo`0=
0?ooo`<0/Z?90P2[V/D20:FC`P<0RW:b00<0N5fV06A6V@1[CYh00P1G>9404P18:HP0<QIm03XLP@0Y
3WX0<QEm01@0LP0006T01`1^0000H`0006T0001J0<am000003L0eV/m0>J05`1H2dh0m=2Z0=o3_080
a;370`2lZlT30;JWbP<0]:G:3`2cYLX00`3oool000000?ooo`1:0?ooo`030000003oool0oooo05L0
oooo001A0?ooo`800000:P3oool206A<X@80JUR[00@0MFbk0:oh`P2_n<800000403oool30:nOb080
Zi[50P2IPk/208Yb/P0307QMYP1TAYT0I4JI0080EcRA00`0B2V8038FO@0j7840:@ij00L0KP0D0780
001Y00L0KP0006<0001Y0000B`0005X20000=`0305P;CP0_04L0gl>l0080cKO40P31[lL30;RXb@<0
]:K:402cYLX00`3oool000000?ooo`190?ooo`800000FP3oool005<0oooo00<000000?ooo`3oool0
9`3oool206A<X@80JUR[0P2jlO<00`000000oooo0?ooo`0@0?ooo`80[io80`2ST<4209V3^`0408Yb
/P1hGJH0N5fV06A6V@80EcRA00H0@B>504PYR00b5Wd0:@ij00L0KP0D07820000J@0:0000H`000380
001;0000FP3<O@00000g0=I[?@0803d0klf`0=[0_`<0`Jo70P2jZ/T30;FVbP<0]:G:3@2cYLX20000
04X0oooo00<000000?ooo`3oool0FP3oool005@0oooo00<000000?ooo`3oool09P3oool206A<X@<0
W[KY00<0VnBG0000003oool04P3oool30:VHa@0?0:>@`@25Jjh0QF^^08E[[P1bEZ80GCnE06A6V@1@
<Hd0EcRA044SQ@18:HP0<QIm0207MP0706h0501b0080001Y00T0001S0000<P0004/0001J0<am002^
Bdl0eV/m0>o=/03J`;l00`3:]<D20;ZZb@80]jO900@0]JK:0;BVbP2dY/X0]:G:3@2cYLX00`000000
oooo0?ooo`190?ooo`030000003oool0oooo05/0oooo001E0?ooo`030000003oool0oooo02H0oooo
0P21P//209jfj@030000003oool0oooo01<0oooo0`2PS;l0102DO[P0QF^^08E[[P1bEZ8205doU@08
050aS@0j7H40@B>502X?NP0b5Wd080Mf02T>NP0D07820000J@050000F@000380001;0>V3803<O@00
0P2^Bdl00`3J`;l0b[C50<Zda@030;n]b0<0]jO90`2dY/X<0;>UbP030?ooo`000000oooo04T0oooo
0P00001N0?ooo`00EP3oool2000002L0oooo0P21P//00`2go=L0oooo0?ooo`0E0?ooo`80X8bo0P2D
O[P03025Jjh0LUJR079FXP1M?iD0D36=03XMP@118hD0:Pmj038FO@0P1gH0:@ij00L0KP80001Y00T0
001I0000H`0004/0jH<P0<am002^Bdl0PbaD0>[9]03F_<400P36//H30;VYb@<0]JK:0`2dYLX90;>U
bP030?ooo`000000000004X0oooo00<000000?ooo`3oool0GP3oool005P0oooo00<000000?ooo`3o
ool0903oool30;OleaP0oooo0P2@N;D207mTZ`0406]>WP1bEZ80GCnE050aS@80>Qf100D0:Pmj038F
O@0P1gH0001Y00L0KP020000J@080000F@0006<0000b0000B`3<O@00[T]?05X>D@3F_<420<JbaP<0
_Jc80`2fYlT30;BUbPT0/jG:00<0oooo0000003oool0B@3oool200000640oooo001I0?ooo`030000
003oool0oooo03l0oooo0P2@N;D01`1oI:/0JdjN05LhT@1M?iD0BBZ9050aS@0j7H400P0Z3gX03P0P
1gH0001Y00L0KP000680001Y0000F@0006<0000b0000B`3YPb00PbaD0?SBY03Ua[T0dKW30P34/<L3
0;RXb@<0]:K:2@2cYLX20?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0H@3oool0
05X0oooo00<000000?ooo`3oool0?P3oool2091h]@0707mTZ`1[CYh0JdjN05LhT@19:XT0D36=03XM
P@0202X?NP0=01D0L`0006T01`1^0000HP0006T0001I0=6200000380eVe30>V38023;5@0iLJi0=6i
``030<B`a`80_:_90`2fY/T30;BUbPL0/jG:0P00001:0?ooo`030000003oool0oooo0680oooo001K
0?ooo`030000003oool0oooo03h0oooo0P1hGJH206]>WP0405LhT@19:XT0<aIn03XMP@80:Pmj00/0
5@1c0207MP0706h0001R0000J@0005T0dH800000<P3FKD<0jH<P05X>D@020=o3_080cKO40P2lZlT2
0;RXb@040;JVb@2dY/X0]:K:0;BUbPL0/jG:00<000000?ooo`3oool0B03oool2000006D0oooo001L
0?ooo`800000?`3oool01`1hGJH0IDNI050aS@1G>940BBZ903<FOP0j7H400P0Z3gX01`0E07<080Mf
0000J@000680001Y0000B@0005T00P00038205X>D@030=o3_03=]l@0`Jo70080`Jo70`2hZ<T30;BV
bPH0/jG:00<0oooo0000003oool0B@3oool00`000000oooo0?ooo`1U0?ooo`00GP3oool00`000000
oooo0?ooo`0l0?ooo`0707QMYP1UAiT0D36=050aS@1298D0BBZ903<FOP0202X?NP0701D0L`0P1gH0
001Y0000HP0002l000190000F@020000<P040=I]@`0903l0f[no0=Zo_`80b[C50`2jZ/T30;FVb@<0
]:G:0`2cYLX2000004T0oooo0P00001X0?ooo`00G`3oool00`000000oooo0?ooo`0l0?ooo`80IDNI
0100D36=048TQ@19:XT0<aIn0248M`0Z3gX05@1c0000HP0006T0001R0000;`0004T0001I0=620000
0380eVe30P3J_kl0103:]<D0_jg80;n]b02o[LP30;NWb@<0]:G:0`2cYLX00`3oool000000?ooo`19
0?ooo`030000003oool0oooo06P0oooo001P0?ooo`030000003oool0oooo03/0oooo01<0GSnE06E7
V@1@<Hd0@RB502/?N`0c5Wh08@Qg02X?NP0E07<0001R0000J@0005P0000_0000B@3[QBH0dH800:e=
D`3FKD<0jLVd0080e[c10P36//H30;VYb@80]JK:0`2cYLX20?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0J@3oool00640oooo00<000000?ooo`3oool0>P3oool04P1N?iD0BR^9050a
S@1298D0:`mk03<FOP0Q27L0:Pmj00L0K`000680001Y0000F000068000190>^59P3APP00[DeC00T0
?`80e[c10P36//H20;f/b0<0]ZO:0`2dYLX00`3oool00000000000190?ooo`800000K03oool00680
oooo0P00000j0?ooo`0C05hoU@1::hT0BR^903/MPP1298D0:`mk0248M`0006T01`1_0000HP0006T0
001H0000HP0002l000190=62002]CE<0Q2iG0>C6^@020=6i``80_Jc80P2hZ<T01P2fYlX0]JK:0;FV
bP2dYLX0oooo000004X0oooo00<000000?ooo`3oool0K03oool006@0oooo00<000000?ooo`3oool0
>03oool204X[R@0603/MPP1298D0:`mk0248M`0006T01`1_0P000680200005P0001R0000;`0004T0
jhDV0:e=D`3Ta[T0dKW30`34/<L30;RXb@<0]JK:00<0oooo0000003oool0B03oool2000006l0oooo
001U0?ooo`030000003oool0oooo03L0oooo0P1::hT01P0k7H808@Qg02/?N`0F07<0001Y00L0K`80
001R00P0001H0=F5000002l0eFi70>^59P24;UL0lln[0=o3_080cKO40`2lZlT30;JWb@800000B@3o
ool00`000000oooo0?ooo`1_0?ooo`00IP3oool00`000000oooo0?ooo`0f0?ooo`80BR^900H0>af2
0248M`0[3g/05P1c0248M`0706l20000HP070000F03EQ@00000_0=E^A`3[QBH0Q2iG0=o3_0020<fg
a080`Jo70`2hZ<T00`3oool000000?ooo`190?ooo`030000003oool0oooo0700oooo001W0?ooo`80
0000=P3oool0201398D0BR^903<GOP0Q27L0:`mk01H0L`0Q27L0001Y0P000680200004P0001H0000
;`0002l0jhDV05`AE03_c;00f[no0P31[lL30;ZZb@030?ooo`000000oooo04P0oooo0P00001c0?oo
o`00J@3oool00`000000oooo0?ooo`0c0?ooo`0304<TQ@1::hT0<aMn00808@Qg00<05P1c0248M`00
06T00P0006801`0004P0001H0000;`0002l0eFi703@0C03J_kl00P3:]<D20;n]b0030?ooo`000000
000004T0oooo00<000000?ooo`3oool0L`3oool006X0oooo00<000000?ooo`3oool0<P3oool00`13
98D0:a1k03<GOP020248M`0301H0L`000680001Y0080001R00H000180000F03EQ@00000_0=E^A`3Y
bKD20=Jl`@<0_jg800<000000?ooo`3oool0A`3oool2000007H0oooo001[0?ooo`030000003oool0
oooo0340oooo00<0@bB502/@N`0c5gh00P0Q27L02P0806l0001R0000J@0005P0001R0000B03/Qb/0
eHD00:i?EP3EKTL20=Jl`@<0a[;600<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1f0?oo
o`00K03oool00`000000oooo0?ooo`0a0?ooo`0<02/@N`0c5gh08@Qg0248M`0806l0001R0000J@00
05P0001R0000B03/Qb/0eHD00P2^CeH00`3Ta[T0dKW30=6i``02000004T0oooo00<000000?ooo`3o
ool0M`3oool006d0oooo0P00000a0?ooo`0>04<TQ@0[47/08@Qg0248M`0806l05P1c0000J@0005P0
001R0000;00004P0eHD00:i?EP24<5T30=6i`dT0oooo0P00001j0?ooo`00K`3oool00`000000oooo
0?ooo`0^0?ooo`0=04<TQ@0[47/05P1c0248M`0806l05P1c0000HP0005P0001R0000;00004P0k8L[
0:i?EP030?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0NP3oool00700oooo00<0
00000?ooo`3oool0;@3oool03@0R2GP0:a1k01H0L`0Q27L0201_0000E`000680001H0=R7000002`0
00180>b7:`24<5T00`3oool00`000000oooo0?ooo`140?ooo`800000O@3oool00740oooo00<00000
0?ooo`3oool0;03oool03@0R2GP0:a1k01H0L`0Q27L0201_0000E`000680001H0=R7000002`0eFm;
0>b7:`24<5T00`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo07d0oooo001b0?oo
o`030000003oool0oooo02`0oooo00P0:a1k01H0L`0Q27L0001Y0000E`00068000160000F080000/
00<0k8L[05dCEP3oool00P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo07h0oooo
001c0?ooo`800000;03oool0200R2GP05P1c0000HP0006T0001G0000HP0004H0001H0P0002`00`1M
4eH0oooo0?ooo`020?ooo`030000003oool0oooo0400oooo0P0000210?ooo`00M@3oool00`000000
oooo0?ooo`0Y0?ooo`0;0289N00F07<0001R0000J@0005L0001R0000AP0005P0f8L00000;03EKd/0
103oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0840oooo001f0?ooo`030000003o
ool0oooo02P0oooo00@08PUh00P0K`000680001Y0P0005L01@0004H0k8P_0=R7002^D5P0eFm;00@0
oooo00<000000?ooo`3oool0?@3oool2000008@0oooo001g0?ooo`030000003oool0oooo02L0oooo
00@08PUh00P0K`0F07<0001Y0P0005L01@0004H0k8P_0=R7002^D5P0QS9K00@0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`240?ooo`00N03oool2000002L0oooo00@08PUh00P0K`0F
07<0001Y0P0005L01@0002T000160=R7002^D5P0GaIH00@0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`250?ooo`00NP3oool00`000000oooo0?ooo`0U0?ooo`0300P0K`0F07<0001R
0080001G00@0000Y0000AP3/R2l0[U1H1@3oool00`000000oooo0?ooo`0i0?ooo`800000R03oool0
07/0oooo00<000000?ooo`3oool0903oool00`0806l0001G0000HP020000E`040000:@3EL4h0k8P_
08HbF`D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`280?ooo`00O03oool00`00
0000oooo0?ooo`0S0?ooo`090000J@0005L0001R0000A@0005L0000Y0=E`CP3/R2l0QS9K00D0oooo
00<000000?ooo`3oool0=P3oool2000008/0oooo001m0?ooo`030000003oool0oooo0280oooo00D0
001Y0000E`00068000150000E`020000:@030>b8;`1O5UP0oooo00@0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`2;0?ooo`00OP3oool200000280oooo00P0001Y0000E`0006800015
0000E`3KRP<0000Y0=E`CPH0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2<0?oo
o`00P03oool00`000000oooo0?ooo`0O0?ooo`080000J@0005L0001G0000A@3]RS<0fhX30000:@3E
L4h60?ooo`030000003oool0oooo0380oooo0P00002?0?ooo`00P@3oool00`000000oooo0?ooo`0N
0?ooo`080000J@0005L0001G0000A@3]RS<0fhX30:iBF`3EL4h60?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0S`3oool00880oooo00<000000?ooo`3oool07@3oool00`0006T0001G
0000E`020000A@030=^:0`2^DU/0QcAM00H0oooo00<000000?ooo`3oool0;`3oool200000980oooo
00230?ooo`030000003oool0oooo01`0oooo00P0001R0000E`0005L0000V0000A@3KRP<0[U9K064H
F@H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2B0?ooo`00Q03oool2000001`0
oooo00L0001R0000E`0005L0000V0000A@3]RS<0[U9K00L0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2C0?ooo`00QP3oool00`000000oooo0?ooo`0I0?ooo`070000HP0005L0001G
00009P3ELU40kHXc08LdG@070?ooo`030000003oool0oooo02/0oooo0P00002F0?ooo`00Q`3oool0
0`000000oooo0?ooo`0H0?ooo`070000HP0004@0001G00009P3ELU40kHXc064HF@070?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0UP3oool008P0oooo00<000000?ooo`3oool05`3o
ool00`00068000140000E`0200009P80HAQI1`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo09L0oooo00290?ooo`030000003oool0oooo01H0oooo00H0001R0000A00005L0gH`70000
9P3ELU480?ooo`030000003oool0oooo02L0oooo0P00002J0?ooo`00RP3oool2000001L0oooo00D0
00140>f;=`3MS0L0000V0=EbD@080?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
VP3oool008`0oooo00<000000?ooo`3oool0503oool01@0004@0kH/g0=f<1`2_Ded0eG9A00P0oooo
00<000000?ooo`3oool0903oool2000009d0oooo002=0?ooo`030000003oool0oooo01<0oooo0P00
04@20=f<1`030:mCG@3oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`2M0?ooo`00SP3oool00`000000oooo0?ooo`0B0?ooo`050000900004@0gH`70=f<1`2_Ded01`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo09h0oooo002?0?ooo`8000004P3oool0
100002@000140>f;=`28=Ul80?ooo`030000003oool0oooo0240oooo0P00002Q0?ooo`00T@3oool0
0`000000oooo0?ooo`0?0?ooo`040000903ELe<0kH/g08PfG`P0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`2Q0?ooo`00TP3oool00`000000oooo0?ooo`0>0?ooo`040000903ELe<0
kH/g068JF`P0oooo00<000000?ooo`3oool07P3oool200000:@0oooo002C0?ooo`030000003oool0
oooo00d0oooo0P0002@00`1R6U/0?01C0?ooo`070?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0Y03oool009@0oooo00<000000?ooo`3oool0303oool00`3OSP/0000T0=EcD`090?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0Y@3oool009D0oooo0P00000<0?ooo`03
0=n>2`2_EEh0eG=C00T0oooo00<000000?ooo`3oool06P3oool200000:P0oooo002G0?ooo`030000
003oool0oooo00T0oooo00<0ghh;0:mEGP2_EEh02@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0:P0oooo002H0?ooo`030000003oool0oooo00P0oooo0P3OSP/00`2_EEh0oooo0?oo
o`070?ooo`030000003oool0oooo01L0oooo0P00002[0?ooo`00V@3oool00`000000oooo0?ooo`08
0?ooo`030=n>2`2_EEh0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2[
0?ooo`00VP3oool00`000000oooo0?ooo`070?ooo`80RCQP2@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0:`0oooo002K0?ooo`800000203oool00`29>600oooo0?ooo`070?ooo`03
0000003oool0oooo01<0oooo0P00002_0?ooo`00W@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0[`3oool009h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0@0?ooo`800000/P3oool009l0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0;80oooo002P0?ooo`8000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0;<0oooo002R0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool200000;H0oooo002S0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2f0?ooo`00Y03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00T0oooo0P00002i0?ooo`00Y@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^@3oool00:H0oooo0P0000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0^P3oool00:P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`800000_@3oool00:T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;d0oooo002Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool200000<00oooo002[0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`300?ooo`00[03oool2000000050?ooo`000000
oooo0?ooo`000000``3oool00:h0oooo100000340?ooo`00[`3oool00`000000oooo0?ooo`340?oo
o`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?ooo`00o`3ooomg0?oo
o`00o`3ooomg0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 373.813}, {359.813, 0}} -> {-0.0304673, -0.0756256, \
0.00438619, 0.00438619}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: Partial Differential Equation \[Dash] sine-Gordon (3D)\
\>", "Subsection"],

Cell["\<\
In this case we solve the sine-Gordon equation, which is a nonlinear wave \
equation.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{\(L = 10; \), "\n", 
    RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
        RowBox[{
          RowBox[{"{", 
            
            RowBox[{\(\[PartialD]\_\(t, t\)u[t, x, 
                    y] \[Equal] \[PartialD]\_\(x, x\)u[t, x, 
                      y] + \[PartialD]\_\(y, y\)u[t, x, y] - 
                  Sin[u[t, x, y]]\), 
              ",", \(u[0, x, 
                  y] \[Equal] \[ExponentialE]\^\(-\((x\^2 + y\^2)\)\)\), ",", 
              
              RowBox[{
                RowBox[{
                  SuperscriptBox["u", 
                    TagBox[\((1, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(0, x, y\), "]"}], 
                "\[Equal]", "0"}], 
              ",", \(u[t, \(-L\), y] \[Equal] u[t, L, y]\), 
              ",", \(u[t, x, \(-L\)] \[Equal] u[t, x, L]\)}], "}"}], ",", "u",
           ",", \({t, 0, L}\), ",", \({x, \(-L\), L}\), 
          ",", \({y, \(-L\), L}\), 
          ",", \(Method \[Rule] {"\<MethodOfLines\>", \
"\<SpatialDiscretization\>" \[Rule] {"\<TensorProductGrid\>", \
"\<DifferenceOrder\>" \[Rule] "\<Pseudospectral\>"}}\)}], "]"}]}]}], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"u", "\[Rule]", 
          
          TagBox[\(InterpolatingFunction[{{0.`, 10.`}, {"...", \(-10.`\), 
                  10.`, "..."}, {"...", \(-10.`\), 10.`, "..."}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["This shows clearly that this is a nonlinear wave phenomena.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MoviePlot3D[\ 
      Evaluate[\ u[t, x, y]\  /. \ First[sol]], \ {x, \ \(-L\), 
        L}, \ {y, \(-L\), L}, \ {t, \ 0, \ 10}, \ 
      PlotRange\  \[Rule] \ {0, \ 1}, \ PlotPoints\  \[Rule] \ 50, \ 
      Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[98]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42659 Mtetra
.55607 .42659 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42659 .54978 .41947 Mtetra
.54978 .41947 .55607 .42659 .56794 .42274 .56169 .4156 Mtetra
.56169 .4156 .56794 .42274 .57987 .41888 .57366 .41171 Mtetra
.57366 .41171 .57987 .41888 .59185 .415 .58567 .4078 Mtetra
.58567 .4078 .59185 .415 .60388 .4111 .59774 .40387 Mtetra
.59774 .40387 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .4162 Mtetra
.53155 .4162 .53792 .42333 .54978 .41947 .54345 .41231 Mtetra
.664 .741 .908 r
.54345 .41231 .54978 .41947 .56169 .4156 .55539 .40841 Mtetra
.55539 .40841 .56169 .4156 .57366 .41171 .56739 .4045 Mtetra
.56739 .4045 .57366 .41171 .58567 .4078 .57944 .40056 Mtetra
.664 .742 .908 r
.57944 .40056 .58567 .4078 .59774 .40387 .59154 .39659 Mtetra
.664 .741 .908 r
.59154 .39659 .59774 .40387 .60985 .39992 .60369 .3926 Mtetra
.664 .741 .907 r
.60369 .3926 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .41291 Mtetra
.663 .741 .908 r
.51326 .41291 .51971 .42007 .53155 .4162 .52513 .40902 Mtetra
.52513 .40902 .53155 .4162 .54345 .41231 .53706 .40514 Mtetra
.662 .742 .909 r
.53706 .40514 .54345 .41231 .55539 .40841 .54904 .40126 Mtetra
.662 .743 .91 r
.54904 .40126 .55539 .40841 .56739 .4045 .56107 .39736 Mtetra
.664 .745 .911 r
.56107 .39736 .56739 .4045 .57944 .40056 .57316 .39338 Mtetra
.665 .746 .91 r
.57316 .39338 .57944 .40056 .59154 .39659 .58529 .38934 Mtetra
.666 .745 .909 r
.58529 .38934 .59154 .39659 .60369 .3926 .59748 .38527 Mtetra
.665 .743 .908 r
.59748 .38527 .60369 .3926 .6159 .3886 .60972 .3812 Mtetra
.664 .742 .908 r
.60972 .3812 .6159 .3886 .62816 .38459 .62202 .37714 Mtetra
.664 .741 .907 r
.62202 .37714 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .40961 Mtetra
.663 .741 .908 r
.4949 .40961 .50144 .41679 .51326 .41291 .50675 .40572 Mtetra
.66 .741 .91 r
.50675 .40572 .51326 .41291 .52513 .40902 .51866 .40192 Mtetra
.654 .742 .914 r
.51866 .40192 .52513 .40902 .53706 .40514 .53063 .39826 Mtetra
.648 .748 .922 r
.53063 .39826 .53706 .40514 .54904 .40126 .54264 .39475 Mtetra
.651 .761 .93 r
.54264 .39475 .54904 .40126 .56107 .39736 .55471 .39112 Mtetra
.663 .775 .933 r
.55471 .39112 .56107 .39736 .57316 .39338 .56684 .38712 Mtetra
.675 .779 .928 r
.56684 .38712 .57316 .39338 .58529 .38934 .57901 .38273 Mtetra
.678 .77 .92 r
.57901 .38273 .58529 .38934 .59748 .38527 .59123 .37824 Mtetra
.673 .756 .913 r
.59123 .37824 .59748 .38527 .60972 .3812 .6035 .37387 Mtetra
.668 .747 .909 r
.6035 .37387 .60972 .3812 .62202 .37714 .61583 .36967 Mtetra
.665 .742 .908 r
.61583 .36967 .62202 .37714 .63437 .37307 .62822 .36554 Mtetra
.664 .741 .907 r
.62822 .36554 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40629 Mtetra
.663 .741 .908 r
.47647 .40629 .48309 .4135 .4949 .40961 .48831 .40239 Mtetra
.657 .74 .911 r
.48831 .40239 .4949 .40961 .50675 .40572 .5002 .39864 Mtetra
.64 .739 .92 r
.5002 .39864 .50675 .40572 .51866 .40192 .51214 .39537 Mtetra
.6 .743 .944 r
.51214 .39537 .51866 .40192 .53063 .39826 .52413 .39301 Mtetra
.538 .766 .981 r
.52413 .39301 .53063 .39826 .54264 .39475 .5362 .39144 Mtetra
.501 .825 1 r
.5362 .39144 .54264 .39475 .55471 .39112 .54833 .38937 Mtetra
.566 .901 .98 r
.54833 .38937 .55471 .39112 .56684 .38712 .56051 .38534 Mtetra
.686 .937 .965 r
.56051 .38534 .56684 .38712 .57901 .38273 .57272 .37934 Mtetra
.735 .895 .951 r
.57272 .37934 .57901 .38273 .59123 .37824 .58495 .37283 Mtetra
.715 .822 .931 r
.58495 .37283 .59123 .37824 .6035 .37387 .59724 .3671 Mtetra
.686 .771 .916 r
.59724 .3671 .6035 .37387 .61583 .36967 .6096 .3623 Mtetra
.67 .749 .91 r
.6096 .3623 .61583 .36967 .62822 .36554 .62202 .35797 Mtetra
.665 .742 .908 r
.62202 .35797 .62822 .36554 .64066 .36141 .6345 .35378 Mtetra
.664 .741 .907 r
.6345 .35378 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40296 Mtetra
.663 .741 .908 r
.45797 .40296 .46468 .4102 .47647 .40629 .46979 .39903 Mtetra
.659 .74 .91 r
.46979 .39903 .47647 .40629 .48831 .40239 .48166 .39522 Mtetra
.638 .736 .92 r
.48166 .39522 .48831 .40239 .5002 .39864 .49358 .392 Mtetra
.554 .723 .952 r
.49358 .392 .5002 .39864 .51214 .39537 .50554 .39063 Mtetra
.212 .619 .952 r
.50554 .39063 .51214 .39537 .52413 .39301 .51757 .39281 Mtetra
.466 0 0 r
.51757 .39281 .52413 .39301 .5362 .39144 .5297 .39809 Mtetra
.53 .055 .072 r
.5297 .39809 .5362 .39144 .54833 .38937 .54195 .40154 Mtetra
.337 0 .127 r
.54195 .40154 .54833 .38937 .56051 .38534 .55424 .3975 Mtetra
0 0 0 r
.55424 .3975 .56051 .38534 .57272 .37934 .56649 .38593 Mtetra
.545 .833 .497 r
.56649 .38593 .57272 .37934 .58495 .37283 .5787 .3725 Mtetra
.816 .985 .884 r
.5787 .3725 .58495 .37283 .59724 .3671 .59097 .36215 Mtetra
.746 .846 .926 r
.59097 .36215 .59724 .3671 .6096 .3623 .60332 .35536 Mtetra
.688 .769 .913 r
.60332 .35536 .6096 .3623 .62202 .35797 .61576 .35042 Mtetra
.669 .746 .908 r
.61576 .35042 .62202 .35797 .6345 .35378 .62828 .34609 Mtetra
.665 .742 .907 r
.62828 .34609 .6345 .35378 .64703 .34961 .64085 .34187 Mtetra
.664 .741 .907 r
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39962 Mtetra
.43941 .39962 .4462 .40689 .45797 .40296 .45121 .39566 Mtetra
.662 .74 .908 r
.45121 .39566 .45797 .40296 .46979 .39903 .46306 .39174 Mtetra
.65 .738 .913 r
.46306 .39174 .46979 .39903 .48166 .39522 .47496 .38815 Mtetra
.584 .722 .938 r
.47496 .38815 .48166 .39522 .49358 .392 .4869 .38623 Mtetra
.186 .566 .936 r
.4869 .38623 .49358 .392 .50554 .39063 .49886 .38941 Mtetra
.745 .226 0 r
.49886 .38941 .50554 .39063 .51757 .39281 .51088 .40246 Mtetra
.789 .405 .328 r
.51088 .40246 .51757 .39281 .5297 .39809 .52309 .42427 Mtetra
.679 .353 .416 r
.52309 .42427 .5297 .39809 .54195 .40154 .53553 .44125 Mtetra
.491 .209 .413 r
.53553 .44125 .54195 .40154 .55424 .3975 .54803 .43721 Mtetra
.214 0 .327 r
.54803 .43721 .55424 .3975 .56649 .38593 .56037 .41211 Mtetra
0 0 .101 r
.56037 .41211 .56649 .38593 .5787 .3725 .57252 .38206 Mtetra
.694 .846 .422 r
.57252 .38206 .5787 .3725 .59097 .36215 .58469 .36074 Mtetra
.854 .958 .876 r
.58469 .36074 .59097 .36215 .60332 .35536 .59701 .3493 Mtetra
.728 .809 .915 r
.59701 .3493 .60332 .35536 .61576 .35042 .60947 .343 Mtetra
.677 .754 .909 r
.60947 .343 .61576 .35042 .62828 .34609 .62201 .33836 Mtetra
.666 .743 .908 r
.62201 .33836 .62828 .34609 .64085 .34187 .63462 .33407 Mtetra
.664 .741 .907 r
.63462 .33407 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32554 Mtetra
.66002 .32554 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39962 .43256 .39229 Mtetra
.663 .741 .908 r
.43256 .39229 .43941 .39962 .45121 .39566 .44439 .38831 Mtetra
.66 .74 .909 r
.44439 .38831 .45121 .39566 .46306 .39174 .45628 .38441 Mtetra
.637 .734 .919 r
.45628 .38441 .46306 .39174 .47496 .38815 .4682 .38118 Mtetra
.48 .684 .956 r
.4682 .38118 .47496 .38815 .4869 .38623 .48014 .38121 Mtetra
.503 0 0 r
.48014 .38121 .4869 .38623 .49886 .38941 .49206 .39125 Mtetra
.876 .478 .272 r
.49206 .39125 .49886 .38941 .51088 .40246 .50401 .42086 Mtetra
.836 .503 .425 r
.50401 .42086 .51088 .40246 .52309 .42427 .51623 .46842 Mtetra
.725 .425 .471 r
.51623 .46842 .52309 .42427 .53553 .44125 .52888 .50694 Mtetra
.513 .254 .459 r
.52888 .50694 .53553 .44125 .54803 .43721 .54171 .50295 Mtetra
.159 0 .358 r
.54171 .50295 .54803 .43721 .56037 .41211 .55422 .45632 Mtetra
0 0 .134 r
.55422 .45632 .56037 .41211 .57252 .38206 .56633 .40042 Mtetra
.717 .755 .25 r
.56633 .40042 .57252 .38206 .58469 .36074 .5784 .3624 Mtetra
.931 .969 .742 r
.5784 .3624 .58469 .36074 .59701 .3493 .59066 .344 Mtetra
.782 .844 .899 r
.59066 .344 .59701 .3493 .60947 .343 .60312 .33566 Mtetra
.689 .762 .908 r
.60312 .33566 .60947 .343 .62201 .33836 .61569 .33059 Mtetra
.667 .744 .907 r
.61569 .33059 .62201 .33836 .63462 .33407 .62834 .32621 Mtetra
.664 .741 .907 r
.62834 .32621 .63462 .33407 .64729 .32981 .64105 .32191 Mtetra
.64105 .32191 .64729 .32981 .66002 .32554 .65381 .31759 Mtetra
.65381 .31759 .66002 .32554 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39229 .42565 .3849 Mtetra
.663 .741 .908 r
.42565 .3849 .43256 .39229 .44439 .38831 .43752 .3809 Mtetra
.659 .74 .909 r
.43752 .3809 .44439 .38831 .45628 .38441 .44943 .377 Mtetra
.625 .73 .922 r
.44943 .377 .45628 .38441 .4682 .38118 .46138 .37406 Mtetra
.38 .632 .953 r
.46138 .37406 .4682 .38118 .48014 .38121 .47332 .37566 Mtetra
.724 .219 0 r
.47332 .37566 .48014 .38121 .49206 .39125 .48519 .39124 Mtetra
.915 .544 .309 r
.48519 .39124 .49206 .39125 .50401 .42086 .49701 .43441 Mtetra
.889 .56 .421 r
.49701 .43441 .50401 .42086 .51623 .46842 .50914 .50356 Mtetra
.797 .486 .462 r
.50914 .50356 .51623 .46842 .52888 .50694 .52189 .56062 Mtetra
.503 .232 .437 r
.52189 .56062 .52888 .50694 .54171 .50295 .53499 .55667 Mtetra
0 0 .157 r
.53499 .55667 .54171 .50295 .55422 .45632 .54774 .4915 Mtetra
.806 .73 .201 r
.54774 .4915 .55422 .45632 .56633 .40042 .55993 .41391 Mtetra
.968 .853 .447 r
.55993 .41391 .56633 .40042 .5784 .3624 .57199 .3622 Mtetra
.966 .901 .706 r
.57199 .3622 .5784 .3624 .59066 .344 .58424 .33816 Mtetra
.809 .831 .867 r
.58424 .33816 .59066 .344 .60312 .33566 .59671 .32816 Mtetra
.697 .762 .902 r
.59671 .32816 .60312 .33566 .61569 .33059 .60932 .32275 Mtetra
.669 .744 .907 r
.60932 .32275 .61569 .33059 .62834 .32621 .622 .31829 Mtetra
.665 .741 .907 r
.622 .31829 .62834 .32621 .64105 .32191 .63475 .31394 Mtetra
.664 .741 .907 r
.63475 .31394 .64105 .32191 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.663 .741 .908 r
.41869 .37745 .42565 .3849 .43752 .3809 .43059 .37341 Mtetra
.659 .739 .909 r
.43059 .37341 .43752 .3809 .44943 .377 .44254 .36949 Mtetra
.625 .728 .921 r
.44254 .36949 .44943 .377 .46138 .37406 .45452 .36651 Mtetra
.393 .626 .946 r
.45452 .36651 .46138 .37406 .47332 .37566 .46648 .36809 Mtetra
.642 .159 0 r
.46648 .36809 .47332 .37566 .48519 .39124 .47833 .38367 Mtetra
.933 .555 .208 r
.47833 .38367 .48519 .39124 .49701 .43441 .4901 .42689 Mtetra
.954 .611 .307 r
.4901 .42689 .49701 .43441 .50914 .50356 .5021 .49616 Mtetra
.945 .585 .261 r
.5021 .49616 .50914 .50356 .52189 .56062 .51476 .55331 Mtetra
.647 .761 .932 r
.51476 .55331 .52189 .56062 .53499 .55667 .5279 .54932 Mtetra
.954 .742 .578 r
.5279 .54932 .53499 .55667 .54774 .4915 .54082 .48399 Mtetra
.958 .734 .556 r
.54082 .48399 .54774 .4915 .55993 .41391 .5532 .40622 Mtetra
.949 .748 .598 r
.5532 .40622 .55993 .41391 .57199 .3622 .56539 .35439 Mtetra
.904 .775 .71 r
.56539 .35439 .57199 .3622 .58424 .33816 .57772 .33027 Mtetra
.791 .776 .839 r
.57772 .33027 .58424 .33816 .59671 .32816 .59024 .32024 Mtetra
.696 .752 .895 r
.59024 .32024 .59671 .32816 .60932 .32275 .60289 .31478 Mtetra
.668 .742 .906 r
.60289 .31478 .60932 .32275 .622 .31829 .61561 .31029 Mtetra
.665 .741 .907 r
.61561 .31029 .622 .31829 .63475 .31394 .6284 .3059 Mtetra
.664 .741 .907 r
.6284 .3059 .63475 .31394 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.663 .741 .907 r
.41167 .36994 .41869 .37745 .43059 .37341 .4236 .36586 Mtetra
.66 .74 .908 r
.4236 .36586 .43059 .37341 .44254 .36949 .43559 .36186 Mtetra
.637 .731 .916 r
.43559 .36186 .44254 .36949 .45452 .36651 .44761 .35854 Mtetra
.497 .665 .937 r
.44761 .35854 .45452 .36651 .46648 .36809 .45962 .35849 Mtetra
0 .215 .736 r
.45962 .35849 .46648 .36809 .47833 .38367 .47155 .3685 Mtetra
.725 .363 0 r
.47155 .3685 .47833 .38367 .4901 .42689 .48339 .39819 Mtetra
0 0 .214 r
.48339 .39819 .4901 .42689 .5021 .49616 .49538 .44594 Mtetra
.081 .062 .534 r
.49538 .44594 .5021 .49616 .51476 .55331 .50788 .48461 Mtetra
.572 .393 .601 r
.50788 .48461 .51476 .55331 .5279 .54932 .52083 .48052 Mtetra
.728 .508 .592 r
.52083 .48052 .5279 .54932 .54082 .48399 .53372 .43353 Mtetra
.789 .563 .594 r
.53372 .43353 .54082 .48399 .5532 .40622 .54627 .37723 Mtetra
.813 .608 .625 r
.54627 .37723 .5532 .40622 .56539 .35439 .55866 .33893 Mtetra
.805 .667 .711 r
.55866 .33893 .56539 .35439 .57772 .33027 .57112 .32035 Mtetra
.747 .721 .828 r
.57112 .32035 .57772 .33027 .59024 .32024 .58371 .31187 Mtetra
.686 .739 .891 r
.58371 .31187 .59024 .32024 .60289 .31478 .59641 .3067 Mtetra
.667 .741 .905 r
.59641 .3067 .60289 .31478 .61561 .31029 .60917 .30221 Mtetra
.664 .741 .907 r
.60917 .30221 .61561 .31029 .6284 .3059 .622 .29779 Mtetra
.622 .29779 .6284 .3059 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36237 Mtetra
.40459 .36237 .41167 .36994 .4236 .36586 .41656 .35825 Mtetra
.662 .74 .908 r
.41656 .35825 .4236 .36586 .43559 .36186 .42858 .35416 Mtetra
.65 .735 .911 r
.42858 .35416 .43559 .36186 .44761 .35854 .44064 .35041 Mtetra
.59 .702 .921 r
.44064 .35041 .44761 .35854 .45962 .35849 .45272 .34834 Mtetra
.371 .542 .894 r
.45272 .34834 .45962 .35849 .47155 .3685 .46478 .35141 Mtetra
.067 .219 .713 r
.46478 .35141 .47155 .3685 .48339 .39819 .47679 .36444 Mtetra
.17 .166 .61 r
.47679 .36444 .48339 .39819 .49538 .44594 .4889 .38632 Mtetra
.416 .286 .595 r
.4889 .38632 .49538 .44594 .50788 .48461 .5013 .40332 Mtetra
.567 .38 .588 r
.5013 .40332 .50788 .48461 .52083 .48052 .514 .39911 Mtetra
.648 .441 .589 r
.514 .39911 .52083 .48052 .53372 .43353 .52674 .37364 Mtetra
.695 .488 .602 r
.52674 .37364 .53372 .43353 .54627 .37723 .53935 .34318 Mtetra
.724 .54 .642 r
.53935 .34318 .54627 .37723 .55866 .33893 .55188 .32152 Mtetra
.731 .618 .731 r
.55188 .32152 .55866 .33893 .57112 .32035 .56446 .30985 Mtetra
.706 .698 .84 r
.56446 .30985 .57112 .32035 .58371 .31187 .57713 .30335 Mtetra
.675 .733 .893 r
.57713 .30335 .58371 .31187 .59641 .3067 .58987 .29853 Mtetra
.666 .74 .905 r
.58987 .29853 .59641 .3067 .60917 .30221 .60267 .29406 Mtetra
.664 .741 .907 r
.60267 .29406 .60917 .30221 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36237 .39746 .35473 Mtetra
.39746 .35473 .40459 .36237 .41656 .35825 .40946 .35057 Mtetra
.663 .74 .907 r
.40946 .35057 .41656 .35825 .42858 .35416 .42151 .34641 Mtetra
.659 .738 .908 r
.42151 .34641 .42858 .35416 .44064 .35041 .43362 .34237 Mtetra
.639 .724 .91 r
.43362 .34237 .44064 .35041 .45272 .34834 .44576 .33892 Mtetra
.575 .664 .898 r
.44576 .33892 .45272 .34834 .46478 .35141 .45793 .33735 Mtetra
.475 .521 .825 r
.45793 .33735 .46478 .35141 .47679 .36444 .4701 .33937 Mtetra
.458 .401 .707 r
.4701 .33937 .47679 .36444 .4889 .38632 .48234 .34452 Mtetra
.517 .383 .638 r
.48234 .34452 .4889 .38632 .5013 .40332 .49473 .34783 Mtetra
.577 .405 .613 r
.49473 .34783 .5013 .40332 .514 .39911 .50728 .34354 Mtetra
.621 .437 .612 r
.50728 .34354 .514 .39911 .52674 .37364 .51989 .33164 Mtetra
.655 .478 .633 r
.51989 .33164 .52674 .37364 .53935 .34318 .5325 .31785 Mtetra
.68 .541 .689 r
.5325 .31785 .53935 .34318 .55188 .32152 .54511 .30717 Mtetra
.692 .631 .784 r
.54511 .30717 .55188 .32152 .56446 .30985 .55777 .3001 Mtetra
.68 .705 .867 r
.55777 .3001 .56446 .30985 .57713 .30335 .57049 .29491 Mtetra
.668 .734 .899 r
.57049 .29491 .57713 .30335 .58987 .29853 .58327 .29032 Mtetra
.664 .74 .906 r
.58327 .29032 .58987 .29853 .60267 .29406 .59612 .28584 Mtetra
.664 .741 .907 r
.59612 .28584 .60267 .29406 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34641 .41439 .33863 Mtetra
.663 .74 .907 r
.41439 .33863 .42151 .34641 .43362 .34237 .42653 .33444 Mtetra
.657 .735 .907 r
.42653 .33444 .43362 .34237 .44576 .33892 .43872 .33039 Mtetra
.641 .714 .901 r
.43872 .33039 .44576 .33892 .45793 .33735 .45096 .32682 Mtetra
.612 .656 .869 r
.45096 .32682 .45793 .33735 .4701 .33937 .46324 .32418 Mtetra
.588 .567 .797 r
.46324 .32418 .4701 .33937 .48234 .34452 .47557 .32234 Mtetra
.589 .502 .725 r
.47557 .32234 .48234 .34452 .49473 .34783 .48799 .31999 Mtetra
.606 .484 .687 r
.48799 .31999 .49473 .34783 .50728 .34354 .50049 .31565 Mtetra
.628 .498 .684 r
.50049 .31565 .50728 .34354 .51989 .33164 .51306 .3093 Mtetra
.651 .539 .714 r
.51306 .3093 .51989 .33164 .5325 .31785 .52568 .30244 Mtetra
.669 .608 .778 r
.52568 .30244 .5325 .31785 .54511 .30717 .53833 .29637 Mtetra
.674 .682 .849 r
.53833 .29637 .54511 .30717 .55777 .3001 .55104 .29123 Mtetra
.669 .724 .891 r
.55104 .29123 .55777 .3001 .57049 .29491 .5638 .28657 Mtetra
.665 .738 .904 r
.5638 .28657 .57049 .29491 .58327 .29032 .57663 .28206 Mtetra
.664 .74 .907 r
.57663 .28206 .58327 .29032 .59612 .28584 .58951 .27756 Mtetra
.664 .741 .907 r
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33863 .4072 .33079 Mtetra
.4072 .33079 .41439 .33863 .42653 .33444 .41938 .32653 Mtetra
.663 .739 .907 r
.41938 .32653 .42653 .33444 .43872 .33039 .43161 .32228 Mtetra
.66 .734 .905 r
.43161 .32228 .43872 .33039 .45096 .32682 .44389 .3181 Mtetra
.653 .717 .895 r
.44389 .3181 .45096 .32682 .46324 .32418 .45623 .31409 Mtetra
.647 .682 .87 r
.45623 .31409 .46324 .32418 .47557 .32234 .46863 .3102 Mtetra
.643 .641 .833 r
.46863 .3102 .47557 .32234 .48799 .31999 .48108 .3062 Mtetra
.646 .617 .807 r
.48108 .3062 .48799 .31999 .50049 .31565 .4936 .30182 Mtetra
.653 .621 .804 r
.4936 .30182 .50049 .31565 .51306 .3093 .50618 .29704 Mtetra
.662 .65 .827 r
.50618 .29704 .51306 .3093 .52568 .30244 .51881 .29215 Mtetra
.667 .69 .863 r
.51881 .29215 .52568 .30244 .53833 .29637 .5315 .28739 Mtetra
.666 .721 .89 r
.5315 .28739 .53833 .29637 .55104 .29123 .54425 .28279 Mtetra
.665 .736 .903 r
.54425 .28279 .55104 .29123 .5638 .28657 .55705 .27826 Mtetra
.664 .74 .906 r
.55705 .27826 .5638 .28657 .57663 .28206 .56992 .27375 Mtetra
.664 .741 .907 r
.56992 .27375 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32653 .41217 .31859 Mtetra
.41217 .31859 .41938 .32653 .43161 .32228 .42444 .31427 Mtetra
.663 .74 .907 r
.42444 .31427 .43161 .32228 .44389 .3181 .43676 .30995 Mtetra
.662 .736 .905 r
.43676 .30995 .44389 .3181 .45623 .31409 .44914 .30562 Mtetra
.661 .729 .899 r
.44914 .30562 .45623 .31409 .46863 .3102 .46157 .3013 Mtetra
.661 .719 .891 r
.46157 .3013 .46863 .3102 .48108 .3062 .47407 .29695 Mtetra
.662 .711 .884 r
.47407 .29695 .48108 .3062 .4936 .30182 .48662 .29253 Mtetra
.663 .712 .884 r
.48662 .29253 .4936 .30182 .50618 .29704 .49923 .28803 Mtetra
.664 .72 .89 r
.49923 .28803 .50618 .29704 .51881 .29215 .51189 .2835 Mtetra
.665 .73 .898 r
.51189 .2835 .51881 .29215 .5315 .28739 .52462 .27897 Mtetra
.664 .737 .904 r
.52462 .27897 .5315 .28739 .54425 .28279 .53741 .27445 Mtetra
.664 .74 .906 r
.53741 .27445 .54425 .28279 .55705 .27826 .55025 .26991 Mtetra
.664 .741 .907 r
.55025 .26991 .55705 .27826 .56992 .27375 .56316 .26536 Mtetra
.56316 .26536 .56992 .27375 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30995 .42956 .30185 Mtetra
.664 .74 .907 r
.42956 .30185 .43676 .30995 .44914 .30562 .44197 .29746 Mtetra
.664 .739 .906 r
.44197 .29746 .44914 .30562 .46157 .3013 .45445 .29305 Mtetra
.663 .738 .905 r
.45445 .29305 .46157 .3013 .47407 .29695 .46698 .28861 Mtetra
.664 .737 .904 r
.46698 .28861 .47407 .29695 .48662 .29253 .47956 .28415 Mtetra
.47956 .28415 .48662 .29253 .49923 .28803 .49221 .27966 Mtetra
.664 .738 .905 r
.49221 .27966 .49923 .28803 .51189 .2835 .50492 .27515 Mtetra
.664 .739 .906 r
.50492 .27515 .51189 .2835 .52462 .27897 .51768 .27061 Mtetra
.664 .74 .907 r
.51768 .27061 .52462 .27897 .53741 .27445 .5305 .26606 Mtetra
.664 .741 .907 r
.5305 .26606 .53741 .27445 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29746 .43475 .28927 Mtetra
.43475 .28927 .44197 .29746 .45445 .29305 .44726 .28481 Mtetra
.664 .74 .907 r
.44726 .28481 .45445 .29305 .46698 .28861 .45982 .28034 Mtetra
.45982 .28034 .46698 .28861 .47956 .28415 .47245 .27584 Mtetra
.47245 .27584 .47956 .28415 .49221 .27966 .48513 .27131 Mtetra
.48513 .27131 .49221 .27966 .50492 .27515 .49788 .26677 Mtetra
.664 .741 .907 r
.49788 .26677 .50492 .27515 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28034 .45261 .27201 Mtetra
.45261 .27201 .45982 .28034 .47245 .27584 .46527 .26747 Mtetra
.46527 .26747 .47245 .27584 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26677 .49078 .25832 Mtetra
.49078 .25832 .49788 .26677 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .27201 .44533 .26361 Mtetra
.44533 .26361 .45261 .27201 .46527 .26747 .45803 .25903 Mtetra
.45803 .25903 .46527 .26747 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13794 Mtetra
.33645 .13794 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{1.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000/@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000]02Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool30000
0;H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0;H0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000_02Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo
00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool300000;h0ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX0;d0ZKgX0P00
000/0:Vmj0030000003oool0oooo03T0oooo000/0?ooo`040:Vmj0000000000000000;l0ZKgX0`00
00020:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0>@3oool002/0oooo0P00002o
0:Vmj0<000001@2Y_NP00`000000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03P0oooo000Y0?oo
o`800000_P2Y_NP3000000T0ZKgX00<000000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0g0?oo
o`007@3oool01@3ookl0M00000000000B9`0gooo00L0oooo0P00002l0:Vmj08000003@2Y_NP00`00
0000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?oo
o`3OW4P007Bo1`3oool00`000000oooo0000002h0:Vmj0<00000402Y_NP00`000000ZKgX0:Vmj00Y
0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`050?ooo`8000000P3oool00`000000ZKgX0:Vmj02b0:Vmj0<000004`2Y_NP00`000000ZKgX0:Vm
j00Z0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP0[P2Y_NP3000001L0ZKgX
00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@004RL0=oo
o`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`030?oooh/0ZKgX0`2Y_NL70:Vmj0<0
ZKgW5@2Y_NP3000001/0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0d0?ooo`00
703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<000000:Vm
j02Y_NP0Q@2Y_NP60:Vmi`@0ZKgX1P2Y_NL20:Vmj0<0ZKgW302Y_NP3000001l0ZKgX00<000000:Vm
j02Y_NP0:@2Y_NP00`000000oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool01@3oool00`000000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX0800ZKgX1@2Y_>L5
0:Vmi`D0ZKcW2`2Y_NL80:Vmj0<000008P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0
oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?oo
o`070?ooogl0ZKgX202Y_>L50:Zji@D0ZKcW1@2Z_>L50:Vmi`D0ZKgX0`00000V0:Vmj0030000002Y
_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@00000000004RL0=oo
o`060?ooo`030000003oool0oooo00P0ooooO02Y_NP80:Vli`<0ZKSS1@2Z^^D50:Zhh`X0Z[cW0P2Y
_NP2000002X0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0b0?ooo`009`3oool0
0`000000oooo0?ooo`0:0?ooogL0ZKgX2P2Y_>L60:Vhh`80Z[[U0`2Z/=`50:Zhh`80Z[cW0`2[^N@3
0:Zli`<00000102Y_NLX0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<@3oool0
02L0oooo00<000000?ooo`3oool02`3ooomc0:Vmj0T0ZKcW1@2Y]^850:Vhh`H0Z[3L102Z^><50:^i
i0<000000`2[^nH50:VmibP0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0`0?oo
o`009`3oool00`000000oooo0?ooo`0<0?ooog00ZKgX0`2Y_NL50:Vli`T0ZKKR1@2YY]<50:Z`g0D0
[:kI00D0ZkWT00000000000000000:^ii0060:^kiP@0ZKgW:@2Y_NP00`000000ZKgX0:Vmj00X0:Vm
j0030000003oool0oooo0300oooo000W0?ooo`8000003P3ooom]0:Vmj0H0ZKgW0P2Y_>L30:Vhi0L0
ZKKR0P2WW/d50:VVd`80Z[3L0`2[VlL20:b^f@<000001@2^]=d50:^kiPD0Z[gW:@2Y_NP00`000000
ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02l0oooo000W0?ooo`030000003oool0oooo00h0oooo
K@2Y_NP50:Vmi`H0ZKST102Y]^840:NNc@D0ZJKC102[VlL300000080[:kI0P2aXLP50:jdg@D0[;_T
1@2Z_NLX0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo00<0
00000?ooo`3oool03`3ooom]0:Vmj0D0ZK[V1@2Y^>@50:FMcP@0Yik=0P2YY]<30:J9]P<000000P2[
VlL20:b^f@@0/J780P2^]=d30;Bbe`D0[;_T1@2Z_NLX0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<0
00000?ooo`3oool0;P3oool002L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX06D0ZKgX1@2Y_>L5
0:VjiPD0Y:CE102UWLh40:NNc@80YXVf0`0000050:^Ka`H0/J781P2d/]L20:bki0<0[kgT1@2Z_NL5
0:Zmj2<0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool20000
01<0oooo00<000000:Vmj02Y_NP0I@2Y_NP50:Vli`80ZK[V0`2U[]h40:BTe@D0YIg>0P2WW/d30000
00@0YXVf0`2[VlL20:j:/0@0/J780P2kW[/50;Bbe`H0[kgT0P2Z_NL30:^mi`@0Z[gX902Y_NP00`00
0000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018
W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo
0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000:Vmj02Y_NP0I@2Y_NP40:Vli`D0YJkN
1@2TY=D40:FMcP8000000P2POjl50:J9]P80Zi_70`2^R[030;6Qb0<0^ijk102d/]L20;nhd`D0[kgT
1P2[_NL30:Zmj2@0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0:0?ooo`050=nL
B000000000000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?oo
o`030?oOW0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<0
00000?ooo`3oool0503oool00`000000ZKgX0:Vmj01T0:Vmj0D0YkOU1@2U[]h40:BTe@0509]k[`00
000000000000002KNjl0102POjl40:J9]PH0[XZ`00<0/J780;^N^`2kW[/00`2kW[/20;Bbe`@0_kSC
1@2b`>D50:^mi`@0Z[gX902Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00P0oooo
00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3oool01@3oool2
000001H0ooooH`2Y_NP50:Rki`@0YkOU102U[]h209J0^@<00000102KNjl40:1o[`@0YXVf00<0YgZR
0:j:/02^R[000`2^R[060;^N^`D0_kSC0P3:a]H50;;0i@D0ZkkX102Z_NPT0:Vmj0030000002Y_NP0
ZKgX02P0ZKgX00<000000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3ookl0M00004RLg`070?ooo`030;md001d
_ol0oooo00D0oooo00<000000?ooo`3oool05`3ooomR0:Vmj0D0Z;_W0`2W]nD309JAc0<000000`2F
P;T409]k[`D0X7n_0P2VRKH20:MjXPD0[XZ`00<0^HZT0;^N^`2kW[/00`2kW[/0103>Z[H0_kSC0;nh
d`2o^=<40<[6eP80//3U0`2b`nH50:^nj2L0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo
0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo0?ooo`3ookl0
M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0
1P3oool00`000000oooo0?ooo`0H0?ooof80ZKgX0P2X^nL30:BfiP80W:ON0`00000209JAc0@0UX2i
102KNjl50:1o[`040:J9]P2WNZ80YgZR0:MjXP@0[XZ`0P2iRZ@40;^N^`<0cZZf00<0_kSC0<[6eP3:
a]H00`3:a]H60;;3iP80ZkkX0`2Z_^PW0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3o
ool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Bo
o`3oool0oooo00@0oooo0P00000K0?ooof40ZKgX102T]^H30000000309bWgP2FTL`0UY7<0080UY7<
102FP;T509]k[`@0X7n_1@2WNZ820:j:/0@0^HZT0P2kW[/40<jZ]PD0b/KF0P3?e=d50;;3iPD0Z[kX
:02Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0K0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md001d_ol0oooO09a8B02Lgol02@3oool00`00
0000oooo0?ooo`0K0?oooe`0ZKgX1@2X_>P300000080Y;KV0`2LYmh409JAc0@0UX2i102KNjl30:1o
[`80WVnL102WNZ820:j:/0@0^HZT00<0^ijk0<jZ]P3>Z[H00`3>Z[H0103Wa[D0b/KF0<[6eP3:a]H4
0<oDg@D0/<?X102Z_^PY0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3oool0
0`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00X0
oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool00`000000oooo0?ooo`0L
0?oooe`0ZKgX00D0Z;cX00000000000000000:Rlj0040:BfiP<0W:ON102FTL`409J0^@@0Vg^_0P2P
Ojl309i_W0@0YgZR00<0[XZ`0;V:Y02iRZ@00`2iRZ@50<jZ]P<0ilJe1@3?e=d20<SHiPD0/<?X102Z
_^PX0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`2oM000M;oo0?oo
o`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P0000000000000
07Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`000000oooo0?ooo`0M0?oo
oeX0ZKgX0P0000050:>ij0@0TjWU0`1iQM<00`1eI[@0UY7<09JAc00409J0^@@0Vg^_00<0X7n_09i_
W02NKi`00P2NKi`40:MjXPH0^HZT00<0d9^O0<jZ]P3>Z[H00P3>Z[H30>O6]@040?OV]03?e=d0cmCM
0<oDg@@0b=SV1@2]`NP40:Znj2P0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`05
0?ooo`060=nLB000000000000000000007@0_ooo703oool002D0oooo0P00000O0?oooeH0ZKgX0`00
00030:Rlj0D0XkWX0`2CZND307V5d`<0MFJd102FP;T409]k[`D0WVnL102WNZ800`2aO9X0^HZT0;V:
Y0030;V:Y0040=2KW`3>Z[H0cZZf0<jZ]P<0ilJe0`3gi[@40<SHiP<0^/oZ102]`NP50:Zmj2P0ZKgX
00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0V0?ooo`009@3oool00`000000oooo0?oo
o`0O0?oooe80ZKgX0`0000030:Vmj0@0Z;cX102S^NP409>Yi@80NHGC101eI[@308ARX`D0TfNL102N
Ki`40:MjXP030;5lVP2iRZ@0^HZT00<0^HZT0P3@Vil20<jZ]P<0ilJe0`3gi[@20>kh_@H0^/oZ0P2]
`NP20:^nj0D0Z[gX9`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02D0oooo000U
0?ooo`030000003oool0oooo0200ooooCP2Y_NP3000000L0ZKgX0`2X_>P509Ncj`<0GX[T0P1iQM<4
07EV]0@0Q6:S102CIi`409i_W0@0YgZR00<0/GbJ0;V:Y02iRZ@00P2iRZ@30=2KW`040<jZ]P3Wa[D0
ilJe0>O6]@<0mnJd0P3^n;d20=[eh0D0^/oZ1@2[_^P20:Zmj2X0ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`0U0?ooo`00903oool2000002<0ooooBP2Y_NP3000000X0ZKgX1@2V_>T4
09Ncj`<0GX[T0P1iQM<307EV]0@0Q6:S102CIi`509i_W080YgZR0`2aO9X30;V:Y0<0d9^O103Wa[D2
0?OV]080k_Rm103JmN050;34j@@0ZkkX;@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0
oooo02@0oooo000T0?ooo`030000003oool0oooo02<0ooooAP2Y_NP3000000h0ZKgX1@2V_>T309Nc
j`<0GX[T00<04CRf07V5d`1eI[@00P1eI[@408ARX`@0TfNL1@2NKi`20:MjXP<0/GbJ0`2iRZ@30=2K
W`030?:oV@3Wa[D0ilJe0080mnJd0P3^n;d30=[eh0<0_]S]1@2`a>T40:Zmj2d0ZKgX00<000000:Vm
j02Y_NP09`2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T0?oood80
ZKgX0`00000B0:Vmj0D0Xk_Z0`1oZ^l01000=k`0GX[T05j:i00A>;H307EV]0@0Q6:S102CIi`509i_
W080YgZR0`2aO9X30;V:Y0<0d9^O0P3b_iT20?OV]080k_Rm0P3JmN060;kHk@D0ZkoX102Z_NP/0:Vm
j0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?oooch0
ZKgX0`00000A0:Vmj0D0Z;gX1@2S^nX307nZk`03000g_01NR^@04CRf00<0MFJd1024HZ<409=WW0D0
WVnL00<0YgZR0;5lVP2aO9X00P2aO9X20;V:Y0@0d9^O0P3b_iT20?OJLP80]l4o00<0/MQ/0=3lhP3@
o>800`2nf>d30:o5jP@0ZkoX<@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo0280
oooo000S0?ooo`800000:03ooolk0:Vmj08000005@2Y_NP50:Rmj0@0Xk_Z0`1oZ^l2000g_0804CRf
0`1eI[@308ARX`@0TfNL1@2NKi`00`2WNZ80/GbJ0;5lVP030;5lVP030;V:Y03@Vil0d9^O0080d9^O
0P3b_iT20?OJLP030;O1?`2af6`0d?cR00<0d?cR1P2_aNX40:Zmj340ZKgX00<000000:Vmj02Y_NP0
9`2Y_NP00`000000oooo0?ooo`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3o
gi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X
0?ooocH0ZKgX0`00000H0:Vmj0D0Z;gX102O^^/306BPlP8003Nl00@04CRf02/ZW01eI[@0MFJd0`24
HZ<409=WW0D0WVnL00<0YgZR0;5lVP2aO9X00`2aO9X00`2iRZ@0d9^O0=2KW`020=2KW`80l[nI0P3g
fW800`2g`Cl0d?cR0;OBkP040;OBkP<0[lGZ0`2[_nP40:Zmj340ZKgX00<000000:Vmj02Y_NP09P2Y
_NP00`000000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo
00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3ooolb0:Vm
j0<000006`2Y_NP60:Rmj0@0Wk[[0`1TX?800`00=k`04CRf02/ZW00207EV]0<0Q6:S1@2CIi`409i_
W0H0/GbJ00@0^HZT0=2KW`3@Vil0d9^O0`3b_iT00`3gfW80]l4o08_EO`020;cUl`D0]m;^1P2[_nP3
0:Zmj340ZKgX00<000000:Vmj02Y_NP09`2Y_NP200000240oooo000<0?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000/0?ooobh0ZKgX0`00
000P0:Vmj0@0Z;gX1@2O^^`3066Ql`04014h]P0[:Y`0:bZL07EV]0@0Q6:S102CIi`409i_W0030:E`
UP2aO9X0/GbJ00<0/GbJ103@Vil30?:oV@030?OJLP2g`Cl0_>Gc00<0_>Gc1@2/`NT50:^oj3D0ZKgX
00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02`0
oooo:P2Y_NP3000002@0ZKgX102X_NP509njk0<0HJ7c0P0[:Y`00`1eI[@0Q6:S08ARX`0208ARX`@0
TfNL0`2NKi`20:E`UPD0/GbJ00@0bI2H0=2KW`3@Vil0d9^O0P3b_iT20?OJLP80[nog102]aN/50:c1
jCX0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3o_g@0
04RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0
1P3oool00`000000oooo0?ooo`0]0?ooobH0ZKgX0`00000X0:Vmj0@0Z;gX1@2S^n/207Z_m003014h
]P0[:Y`0:bZL00@0Q6:S102CIi`309i_W080YG2F1@2aO9X01039T9P0d9^O0=2KW`3@Vil20?:oV@80
mmYb0`2/and40:g5j`D0Z[kX>@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01h0
oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d00000000
0080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooob80ZKgX0`00000/0:Vm
j0@0Z;gX1@2S^n/0101j[o@04CRf02/ZW00[:Y`408ARX`@0TfNL0P2NKi`30:E`UPD0/GbJ00@0bI2H
0=2KW`3@Vil0d9^O0P3b_iT00`3gfW80]l4o0:c7k@020:c7k@X0Z[kX>@2Y_NP00`000000ZKgX0:Vm
j00W0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`030?oog`2LB4P0W=oo00T0oooo0P00000a0?oooah0ZKgX0`00000`0:Vmj0@0Z;gX
1@2V_>T0102E^?00:bZL02/ZW00[:Y`308ARX`@0TfNL0P2NKi`30:E`UPD0/GbJ00<0bI2H0=2KW`3@
Vil00`3b_iT0103gfW80[<O]0:c7k@2/and70:Znj3h0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`00
0000oooo0?ooo`0M0?ooo`00303oool01P3ooml0W4P007Boo`3oool0gia8001d_`D0oooo00<0_g@0
07Boo`3oool0203oool00`000000oooo0?ooo`0a0?oooa/0ZKgX0P00000h0:Vmj0D0Y[cY0`0[:Y`0
0`1ZBIP0Q6:S08ARX`0409=WW00309i_W02UL9H0YG2F0080YG2F102aO9X30<V@V0060=2KW`3b_iT0
l[nI0?:oV@3gfW80ZLK^1`2Z_^Q10:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0
703oool000d0oooo00D0oono07@00000000004RL0=ooo`050?ooo`060=nLB0000000000000000000
07@0_ooo1@3oool00`000000oooo0?ooo`0b0?oooaL0ZKgX0`00000k0:Vmj0@0Z;gX0`0[:Y`206Y9
V00308ARX`2CIi`0TfNL0080TfNL1@2UL9H40;5lVP<0bI2H00<0d9^O0?:oV@3b_iT00P3gfW820:Vn
j@@0Z[kX@`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01/0oooo000R0?ooo`80
0000=03ooolC0:Vmj0<00000?`2Y_NP40:Rmj080:bZL0`1ZBIP209=WW0<0TF6F102UL9H40;5lVP<0
bI2H00@0d9^O0?:oV@3b_iT0mmYb102Y_^U70:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?oo
o`3oool06`3oool00280oooo00<000000?ooo`3oool0=03oool?0:Vmj0<00000@`2Y_NP20:Rmj003
0:Vmj00[:Y`0:bZL00<0JTVH1@2AHIH40:E`UP@0/GbJ0`39T9P0103@Vil0l[nI0?:oV@3gfW9<0:Vm
j0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06P3oool00280oooo00<000000?ooo`3o
ool0=@3oool00`000000ZKgX0:Vmj0080:Vmj0<00000B@2Y_NP202/ZW0@0JTVH102AHIH50:E`UP80
/GbJ1039T9P30?:oV@030<jj<`2Y_NP0ZKgX04/0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000
oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?oo
o`008P3oool00`000000oooo0?ooo`0g0?ooo`H0ZKgX0`00001=0:Vmj00302/ZW01ZBIP0JTVH0080
JTVH102AHIH50:E`UP80/GbJ1039T9P0103e^hh0l[nI0?:oV@3>^S==0:Vmj0030000002Y_NP0ZKgX
02H0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo000Q0?ooo`800000>P3oool20:Vmj0<00000D02Y_NP00`0[:Y`0JTVH06Y9V00206Y9V0@0TF6F
1@2UL9H20;5lVP@0bI2H0P3e^hh20<jj<dh0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo
0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3o
ool00240oooo00<000000?ooo`3oool0>03oool3000005<0ZKgX00<0:bZL06Y9V01ZBIP00P1ZBIP4
095QUPD0YG2F0P2aO9X40<V@V080mK^>00<0c[Xc0:Vmj02Y_NP0CP2Y_NP00`000000ZKgX0:Vmj00U
0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`8000000`3ooomC0:Vmj080
:bZL0`1ZBIP4095QUPD0YG2F00<0/GbJ0<V@V039T9P00`39T9P20?FkSP030<jj<`2Y_NP0ZKgX04h0
ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?oo
o`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo0P00000d0?ooo`<000001P3o
oomC0:Vmj00402/ZW01ZBIP0JTVH06Y9V0@0TF6F1@2UL9H00`2aO9X0bI2H0<V@V0030<V@V080mK^>
00<0c[Xc0:Vmj02Y_NP0C`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00P0oooo
00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool0
0`000000oooo0?ooo`0`0?ooo`<000002@3ooomC0:Vmj00402/ZW01ZBIP0JTVH06Y9V0@0TF6F1@2U
L9H00`2aO9X0bI2H0<V@V0020<V@V0<0mK^>00<0c[Xc0:Vmj02Y_NP0D02Y_NP00`000000ZKgX0:Vm
j00U0:Vmj0030000003oool0oooo00H0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0
M02oool0oooo0?oOW01807@0_ooo00<0oooo00040?ooo`0=0?oo_`1d000000000018W03Oool0oooo
0?oOW01807@0_ooo0?ooo`3ookl0M01809cOo`040?ooo`050=nLB000000000000000B02Lgol01`3o
ool00`000000oooo0?ooo`0]0?ooo`<000003P3ooomA0:Vmj00402/ZW01ZBIP0JTVH06Y9V0@0TF6F
1@2UL9H00`2aO9X0bI2H0<V@V0020<V@V0<0mK^>E02Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000
003oool0oooo00H0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`040?ooo`000`3oool01P3ooml0W4P004RLg`3oool0gia8001d_`D0oooo00<0oooO09a8B02Lgol0
0`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z0?oo
o`<000004P3ooom@0:Vmj00402/ZW01ZBIP0JTVH06Y9V0@0TF6F1@2UL9H50<V@V080mK^>00<0c[Xc
0:Vmj02Y_NP0DP2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003oool0203oool0
0`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool000<0oooo00L0oono
07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo
0?ooo`040?ooo`800000:@3oool3000001H0ooooD02Y_NP306Y9V0@0TF6F1@2UL9H00`2jPYL0bI2H
0<V@V0020<V@V080mK^>00<0c[Xc0:Vmj02Y_NP0D`2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0<00000
1@3oool00`000000oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02L
gol01@3oool00`3o_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3o
ool09@3oool3000001X0ooooC`2Y_NP306Y9V0D0TF6F102UL9H00`2jPYL0bI2H0<V@V0020<V@V080
mK^>00<0c[Xc0:Vmj02Y_NP0E02Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`000000
oooo0?ooo`0E0?ooo`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o
okl0M01809cOo`020?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003o
ool0oooo0280oooo0`00000N0?ooodh0ZKgX0`1ZBIP5095QUP@0YG2F00<0^X:G0<V@V039T9P00P39
T9P20?FkSUP0ZKgX00<000000:Vmj02Y_NP04`2Y_NP4000000`0oooo00<000000?ooo`3oool0503o
ool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00H0gia8001d_`3oool0
oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool30000
0280ooooC@2Y_NP406Y9V0@0TF6F0`2UL9H20;Z2U`<0bI2H0`3e^hiH0:Vmj0030000002Y_NP0ZKgX
00l0ZKgX00@0oooo0000000000000000403oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool01P3oool01`3ookl0M01809cOo`3oool0oooO09a8B02L
gol02@3oool2000001h0oooo0P00000V0?ooo`030000002Y_NP0ZKgX04T0ZKgX00@0000f06Y9V01Z
BIP0JTVH102AHIH30:E`UP80^X:G0`39T9P30?FkSUT0ZKgX00<000000:Vmj02Y_NP02P2Y_NP20?oo
o`<000004`3oool00`000000oooo0?ooo`0D0?ooo`000`3oool01P3ooml0W4P007Boo`3oool0gia8
001d_`P0oooo00H0okmd0018W03Oool0oooo0;md001d_ol80?ooo`800000703oool3000002X0oooo
B`2Y_NP306Y9V0@0TF6F0`2UL9H20;Z2U`<0bI2H0P3e^hh00`3>^S<0ZKgX0:Vmj01H0:Vmj0030000
002Y_NP0ZKgX00L0ZKgX1000000F0?ooo`030000003oool0oooo01@0oooo00040?ooo`050?oo_`1d
000000000018W03Oool0103oool00`3OW4P00000000000030000000307Boo`3oool0gia800<00000
00<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`<00000;P3ooom:0:Vmj00301@?
R01ZBIP0JTVH00@0TF6F0P2UL9H30;Z2U`<0bI2H0P3e^hiK0:Vmj0030000002Y_NP0ZKgX00D0ZKgX
0P00000J0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo01D0oooo0`00
000b0?ooodT0ZKgX00<050n806Y9V01ZBIP0102AHIH20:E`UP@0^X:G0P39T9P20?FkSU`0ZKgX00@0
00000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000003oool0oooo01@0oooo000O0?ooo`8000004`3o
ool3000003H0ooooB02Y_NP00`0D3hP0JTVH06Y9V004095QUP80YG2F102jPYL20<V@V080mK^>G02Y
_NP300000200oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool03`3oool3
000003X0ooooA`2Y_NP201@?R00306Y9V02AHIH0TF6F0080TF6F0P2UL9H40;Z2U`040<V@V03e^hh0
mK^>0?FkSUP0ZKgX0`0000030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503o
ool001l0oooo00<000000?ooo`3oool0303oool3000003h0ooooAP2Y_NP201@?R00306Y9V02AHIH0
TF6F0080TF6F00<0YG2F0;Z2U`2jPYL00`2jPYL01039T9P0mK^>0?FkSP3e^hiE0:Vmj0<000001P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0
oooo00T0oooo0`0000120?ooodD0ZKgX00<0000f01@?R01ZBIP0102AHIH00`2UL9H0^X:G0;Z2U`03
0;Z2U`040<V@V03e^hh0mK^>0<jj<e40ZKgX1000000:0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool04`3oool001h0oooo0P0000090?ooo`800000AP3ooom50:Vmj08050n8102AHIH0
0`2UL9H0^X:G0;Z2U`030;Z2U`030<V@V03e^hh0mK^>04h0ZKgX00@0oooo00000000000000003`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000003oool0
oooo00D0oooo0`0000190?oood@0ZKgX0P0D3hP4095QUPH0^X:G00<0bI2H0?FkSP3e^hh0B`2Y_NP0
103oool0000000000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3o
ool001h0oooo00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP0@02Y_NP2
01@?R0D0TVBI1@2jPYL30?FkSTL0ZKgX00<0oooo0000000000000P00000F0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`0000000P00001A0?oo
o`030000002Y_NP0ZKgX03l0ZKgX0`0D3hP4099TV@D0^X:G00<0m;fC0?FkSP3e^hh0A@2Y_NP30000
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000005D0
oooo00<000000:Vmj02Y_NP0?P2Y_NP301@?R0@0TVBI1@2jPYL20?BmT`030?FkSP2Y_NP0ZKgX0440
ZKgX0P00000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool001<0oooo
00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`1D0?ooo`030000002Y_NP0ZKgX03d0ZKgX
0`0D3hP4099TV@D0^X:G0P3d_I=10:Vmj0030000003oool0oooo0240oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000EP3o
ooln0:Vmj0<050n8102BI9T50;Z2U`80m;fC?@2Y_NP2000002L0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0
oooo05@0oooo?P2Y_NP201@?R0@0TVBI102jPYL30?BmTcX0ZKgX0P00000[0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`00
0000oooo0?ooo`1D0?ooocd0ZKgX0P0D3hP4099TV@@0^X:G0`3d_I<f0:Vmj0800000<03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0
oooo00<000000?ooo`3oool0E03oooll0:Vmj08050n8102BI9T40;Z2U`<0m;fC<P2Y_NP3000003<0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d
0;ooo`0?0?ooo`030000003oool0oooo05@0oooo>`2Y_NP201@?R0@0TVBI102jPYL20?BmTc00ZKgX
0`00000g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0
_g@00000B02L_i`0B01d0;ooo`0@0?ooo`800000E@3ooolk0:Vmj00301@?R02BI9T0TVBI0080TVBI
102jPYL20?BmTb`0ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?ooo`1C0?ooocX0ZKgX
00<050n8099TV@2BI9T00`2BI9T20;Z2U`<0m;fC:@2Y_NP300000400oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003o
ool0oooo05<0oooo>@2Y_NP201@?R0@0TVBI0P2jPYL30?BmTbD0ZKgX100000130?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool04@3oool002X0oooo00<000000?ooo`3oool0D`3ooolh
0:Vmj08050n8102BI9T20;Z2U`<0m;fC8P2Y_NP3000004P0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo>02Y_NP00`0D3hP0TVBI099TV@02099T
V@80^X:G0P3d_I<O0:Vmj0040?ooo`0000000000000004`0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`1B0?ooocL0ZKgX00<050n8099T
V@2BI9T00P2BI9T20;Z2U`80m;fC702Y_NP4000004l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?ooocH0ZKgX00<050n8099TV@2B
I9T00P2BI9T0102jPYL0m;fC0?BmT`3d_I<I0:Vmj0<00000E03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo0580oooo=@2Y_NP00`0D3hP0
TVBI099TV@02099TV@040;Z2U`3d_I<0m;fC0?BmTaD0ZKgX00@0oooo0000000000000000F03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?ooo`030000003oool0oooo
0580oooo=@2Y_NP4099TV@040;Z2U`3d_I<0m;fC0?BmTa80ZKgX1000001L0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00340oooo0P00001C0?oooc@0ZKgX102BI9T00`2j
PYL0m;fC0?BmT`0?0:Vmj0040?ooo`000000000000000600oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`1A0?oooc<0ZKgX102BI9T00`2j
PYL0m;fC0?BmT`0<0:Vmj0@00000I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo000d0?ooo`030000003oool0oooo0540oooo<P2Y_NP4099TV@<0m;fC2@2Y_NP3000006T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo
0?ooo`1A0?oooc40ZKgX1@2U`^h20?BmT`D0ZKgX00@0oooo0000000000000000K03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000f0?ooo`800000DP3ooola0:Vmj0D0YL;^
0`2Y_NP400000700oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`00>03o
ool00`000000oooo0?ooo`1@0?oooc40ZKgX0P2U`^h20:Vmj0<00000M@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0100oooo000i0?ooo`030000003oool0oooo0540oooo;`2Y_NP0
103oool0000000000000001i0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool003X0oooo00<000000?ooo`3oool0D@3oool[0:Vmj0@00000O03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo000k0?ooo`030000003oool0oooo0540oooo9`2Y_NP30000
0840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`00?03oool200000580
oooo8P2Y_NP0103oool000000000000000250?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool003h0oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo0500oooo
6P2Y_NP3000008d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00@03o
ool00`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03`3oool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3oool=0:Vm
j0<00000V@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00140?ooo`03
0000003oool0oooo0500oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`800000YP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00190?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo001;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool004l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00540oooo0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo0:`0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo
001F0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0000
000?0?ooo`00E`3oool2000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo0000000>
0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00000>0?oo
o`00FP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00
F`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00G03o
ool2000003X0oooo00<000000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0WP3oool300000200oooo001R0?ooo`800000=03oool00`000000oooo0?oo
o`2J0?ooo`@000008`3oool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F
0?ooo`@000009`3oool006D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?oo
o`@00000:`3oool006H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`@0
0000;`3oool006L0oooo0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?ooo`00J@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00JP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo100000120?ooo`00K@3oool2000002T0oooo
00<000000?ooo`3oool0M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0M@3oool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0L@3oool4000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0K@3oool400000540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`@0
0000E@3oool007@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?ooo`@00000
F@3oool007D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<00000G@3o
ool007H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000H03oool0
07L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03oool007P0
oooo0P00000M0?ooo`030000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<000000?oo
o`3oool0A`3oool4000007L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0@`3oool4000007/0oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
?`3oool4000007l0oooo00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3o
ool4000008<0oooo00220?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000Q`3oool0
08@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3oool008D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool008H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo0P00000=
0?ooo`030000003oool0oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01h0oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3oool05P3o
ool400000:T0oooo002?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool4
00000:d0oooo002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool30000
0;40oooo002A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000;@0
oooo002B0?ooo`050000003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?ooo`800000
00<0oooo0000003oool0103oool400000;`0oooo002E0?ooo`80000000<0oooo0000000000000P00
00300?ooo`00UP3oool200000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo
003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50128 .61629 .49474 Mtetra
.61629 .49474 .62206 .50128 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46699 Mtetra
.65136 .46699 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46699 .64558 .46019 Mtetra
.64558 .46019 .65136 .46699 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43042 Mtetra
.54424 .43042 .55051 .43744 .5623 .43364 .55607 .42659 Mtetra
.55607 .42659 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43042 .53792 .42333 Mtetra
.53792 .42333 .54424 .43042 .55607 .42659 .54978 .41948 Mtetra
.54978 .41948 .55607 .42659 .56794 .42274 .56169 .41561 Mtetra
.664 .741 .908 r
.56169 .41561 .56794 .42274 .57987 .41888 .57366 .41172 Mtetra
.57366 .41172 .57987 .41888 .59185 .415 .58567 .40781 Mtetra
.58567 .40781 .59185 .415 .60388 .4111 .59774 .40388 Mtetra
.664 .741 .907 r
.59774 .40388 .60388 .4111 .61597 .40719 .60985 .39993 Mtetra
.60985 .39993 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42393 Mtetra
.50792 .42393 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.664 .741 .908 r
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41621 Mtetra
.663 .741 .908 r
.53155 .41621 .53792 .42333 .54978 .41948 .54345 .41234 Mtetra
.663 .742 .908 r
.54345 .41234 .54978 .41948 .56169 .41561 .55539 .40846 Mtetra
.663 .742 .909 r
.55539 .40846 .56169 .41561 .57366 .41172 .56739 .40456 Mtetra
.664 .743 .909 r
.56739 .40456 .57366 .41172 .58567 .40781 .57944 .40062 Mtetra
.665 .743 .909 r
.57944 .40062 .58567 .40781 .59774 .40388 .59154 .39664 Mtetra
.665 .743 .908 r
.59154 .39664 .59774 .40388 .60985 .39993 .60369 .39263 Mtetra
.665 .742 .908 r
.60369 .39263 .60985 .39993 .62203 .39596 .6159 .38861 Mtetra
.664 .741 .908 r
.6159 .38861 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.664 .741 .907 r
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42393 .50144 .4168 Mtetra
.663 .741 .908 r
.50144 .4168 .50792 .42393 .51971 .42007 .51326 .41294 Mtetra
.661 .741 .909 r
.51326 .41294 .51971 .42007 .53155 .41621 .52513 .40911 Mtetra
.659 .742 .912 r
.52513 .40911 .53155 .41621 .54345 .41234 .53706 .40535 Mtetra
.657 .746 .915 r
.53706 .40535 .54345 .41234 .55539 .40846 .54904 .40162 Mtetra
.659 .752 .919 r
.54904 .40162 .55539 .40846 .56739 .40456 .56108 .39782 Mtetra
.664 .757 .92 r
.56108 .39782 .56739 .40456 .57944 .40062 .57316 .39385 Mtetra
.669 .759 .918 r
.57316 .39385 .57944 .40062 .59154 .39664 .5853 .3897 Mtetra
.67 .755 .914 r
.5853 .3897 .59154 .39664 .60369 .39263 .59749 .38548 Mtetra
.669 .75 .911 r
.59749 .38548 .60369 .39263 .6159 .38861 .60973 .3813 Mtetra
.666 .745 .909 r
.60973 .3813 .6159 .38861 .62816 .38459 .62202 .37717 Mtetra
.665 .742 .908 r
.62202 .37717 .62816 .38459 .64047 .38056 .63437 .37308 Mtetra
.664 .741 .907 r
.63437 .37308 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .41351 Mtetra
.663 .741 .908 r
.48309 .41351 .48966 .42066 .50144 .4168 .4949 .40965 Mtetra
.659 .74 .91 r
.4949 .40965 .50144 .4168 .51326 .41294 .50675 .40589 Mtetra
.649 .741 .917 r
.50675 .40589 .51326 .41294 .52513 .40911 .51866 .4024 Mtetra
.634 .747 .93 r
.51866 .4024 .52513 .40911 .53706 .40535 .53063 .39929 Mtetra
.62 .765 .949 r
.53063 .39929 .53706 .40535 .54904 .40162 .54265 .39639 Mtetra
.624 .797 .965 r
.54265 .39639 .54904 .40162 .56108 .39782 .55473 .39319 Mtetra
.651 .828 .968 r
.55473 .39319 .56108 .39782 .57316 .39385 .56687 .38919 Mtetra
.684 .837 .957 r
.56687 .38919 .57316 .39385 .5853 .3897 .57904 .38438 Mtetra
.697 .818 .94 r
.57904 .38438 .5853 .3897 .59749 .38548 .59125 .37926 Mtetra
.691 .787 .924 r
.59125 .37926 .59749 .38548 .60973 .3813 .60351 .37436 Mtetra
.678 .762 .914 r
.60351 .37436 .60973 .3813 .62202 .37717 .61584 .36984 Mtetra
.669 .748 .909 r
.61584 .36984 .62202 .37717 .63437 .37308 .62822 .36558 Mtetra
.665 .743 .908 r
.62822 .36558 .63437 .37308 .64678 .36899 .64066 .36142 Mtetra
.664 .741 .907 r
.64066 .36142 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.663 .741 .908 r
.46468 .4102 .47134 .41739 .48309 .41351 .47647 .40632 Mtetra
.658 .74 .91 r
.47647 .40632 .48309 .41351 .4949 .40965 .48831 .40256 Mtetra
.642 .739 .919 r
.48831 .40256 .4949 .40965 .50675 .40589 .50019 .39926 Mtetra
.597 .738 .943 r
.50019 .39926 .50675 .40589 .51866 .4024 .51213 .39701 Mtetra
.497 .743 .983 r
.51213 .39701 .51866 .4024 .53063 .39929 .52413 .39619 Mtetra
.315 .739 .974 r
.52413 .39619 .53063 .39929 .54265 .39639 .53622 .39611 Mtetra
.169 .706 .816 r
.53622 .39611 .54265 .39639 .55473 .39319 .54837 .39491 Mtetra
.264 .764 .72 r
.54837 .39491 .55473 .39319 .56687 .38919 .56058 .39088 Mtetra
.532 .919 .808 r
.56058 .39088 .56687 .38919 .57904 .38438 .57279 .38402 Mtetra
.732 .978 .918 r
.57279 .38402 .57904 .38438 .59125 .37926 .58501 .37603 Mtetra
.759 .904 .941 r
.58501 .37603 .59125 .37926 .60351 .37436 .59728 .36876 Mtetra
.718 .817 .927 r
.59728 .36876 .60351 .37436 .61584 .36984 .60961 .36292 Mtetra
.684 .767 .914 r
.60961 .36292 .61584 .36984 .62822 .36558 .62202 .35814 Mtetra
.669 .748 .909 r
.62202 .35814 .62822 .36558 .64066 .36142 .6345 .35381 Mtetra
.665 .742 .908 r
.6345 .35381 .64066 .36142 .65316 .35728 .64703 .34961 Mtetra
.664 .741 .907 r
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.663 .741 .908 r
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40297 Mtetra
.661 .74 .909 r
.45797 .40297 .46468 .4102 .47647 .40632 .46979 .39913 Mtetra
.646 .738 .916 r
.46979 .39913 .47647 .40632 .48831 .40256 .48166 .3957 Mtetra
.59 .729 .94 r
.48166 .3957 .48831 .40256 .50019 .39926 .49356 .39364 Mtetra
.381 .681 .977 r
.49356 .39364 .50019 .39926 .51213 .39701 .50552 .39453 Mtetra
.261 0 0 r
.50552 .39453 .51213 .39701 .52413 .39619 .51756 .39918 Mtetra
.595 .069 0 r
.51756 .39918 .52413 .39619 .53622 .39611 .52972 .40547 Mtetra
.539 .105 .164 r
.52972 .40547 .53622 .39611 .54837 .39491 .54199 .40864 Mtetra
.364 0 .174 r
.54199 .40864 .54837 .39491 .56058 .39088 .55431 .4046 Mtetra
.073 0 .039 r
.55431 .4046 .56058 .39088 .57279 .38402 .56659 .39334 Mtetra
0 0 0 r
.56659 .39334 .57279 .38402 .58501 .37603 .57881 .3789 Mtetra
.782 .989 .752 r
.57881 .3789 .58501 .37603 .59728 .36876 .59105 .36608 Mtetra
.806 .927 .915 r
.59105 .36608 .59728 .36876 .60961 .36292 .60336 .35702 Mtetra
.724 .812 .919 r
.60336 .35702 .60961 .36292 .62202 .35814 .61578 .35091 Mtetra
.681 .76 .911 r
.61578 .35091 .62202 .35814 .6345 .35381 .62828 .34619 Mtetra
.667 .744 .908 r
.62828 .34619 .6345 .35381 .64703 .34961 .64085 .34188 Mtetra
.664 .741 .907 r
.64085 .34188 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39962 Mtetra
.663 .741 .908 r
.43941 .39962 .4462 .40689 .45797 .40297 .45121 .39569 Mtetra
.656 .739 .911 r
.45121 .39569 .45797 .40297 .46979 .39913 .46306 .39195 Mtetra
.621 .731 .926 r
.46306 .39195 .46979 .39913 .48166 .3957 .47494 .38918 Mtetra
.458 .687 .965 r
.47494 .38918 .48166 .3957 .49356 .39364 .48686 .38942 Mtetra
0 .275 .685 r
.48686 .38942 .49356 .39364 .50552 .39453 .4988 .39578 Mtetra
.762 .275 .076 r
.4988 .39578 .50552 .39453 .51756 .39918 .51085 .40933 Mtetra
.742 .347 .304 r
.51085 .40933 .51756 .39918 .52972 .40547 .52309 .42532 Mtetra
.634 .285 .363 r
.52309 .42532 .52972 .40547 .54199 .40864 .53551 .43479 Mtetra
.457 .144 .345 r
.53551 .43479 .54199 .40864 .55431 .4046 .54799 .43075 Mtetra
.18 0 .245 r
.54799 .43075 .55431 .4046 .56659 .39334 .56038 .41316 Mtetra
0 0 .011 r
.56038 .41316 .56659 .39334 .57881 .3789 .57263 .38897 Mtetra
.68 .831 .401 r
.57263 .38897 .57881 .3789 .59105 .36608 .58482 .36715 Mtetra
.887 .988 .797 r
.58482 .36715 .59105 .36608 .60336 .35702 .59709 .35252 Mtetra
.789 .869 .907 r
.59709 .35252 .60336 .35702 .61578 .35091 .60949 .34403 Mtetra
.702 .778 .911 r
.60949 .34403 .61578 .35091 .62828 .34619 .62202 .33858 Mtetra
.671 .748 .908 r
.62202 .33858 .62828 .34619 .64085 .34188 .63462 .3341 Mtetra
.665 .742 .907 r
.63462 .3341 .64085 .34188 .65348 .33765 .64729 .32982 Mtetra
.664 .741 .907 r
.64729 .32982 .65348 .33765 .66617 .33341 .66002 .32554 Mtetra
.66002 .32554 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39962 .43256 .3923 Mtetra
.662 .74 .908 r
.43256 .3923 .43941 .39962 .45121 .39569 .44439 .38836 Mtetra
.65 .737 .913 r
.44439 .38836 .45121 .39569 .46306 .39195 .45627 .38477 Mtetra
.584 .72 .936 r
.45627 .38477 .46306 .39195 .47494 .38918 .46817 .38283 Mtetra
.229 .573 .941 r
.46817 .38283 .47494 .38918 .48686 .38942 .48007 .38589 Mtetra
.699 .164 0 r
.48007 .38589 .48686 .38942 .4988 .39578 .49198 .39865 Mtetra
.843 .426 .245 r
.49198 .39865 .4988 .39578 .51085 .40933 .504 .42191 Mtetra
.792 .426 .363 r
.504 .42191 .51085 .40933 .52309 .42532 .51628 .4476 Mtetra
.679 .338 .392 r
.51628 .4476 .52309 .42532 .53551 .43479 .52883 .46294 Mtetra
.461 .152 .354 r
.52883 .46294 .53551 .43479 .54799 .43075 .54149 .45891 Mtetra
.059 0 .205 r
.54149 .45891 .54799 .43075 .56038 .41316 .55403 .43543 Mtetra
0 0 0 r
.55403 .43543 .56038 .41316 .57263 .38897 .56635 .40147 Mtetra
.82 .854 .398 r
.56635 .40147 .57263 .38897 .58482 .36715 .57852 .36985 Mtetra
.945 .96 .697 r
.57852 .36985 .58482 .36715 .59709 .35252 .59076 .34873 Mtetra
.849 .891 .868 r
.59076 .34873 .59709 .35252 .60949 .34403 .60316 .33733 Mtetra
.726 .792 .904 r
.60316 .33733 .60949 .34403 .62202 .33858 .6157 .33096 Mtetra
.677 .751 .907 r
.6157 .33096 .62202 .33858 .63462 .3341 .62834 .32627 Mtetra
.666 .742 .907 r
.62834 .32627 .63462 .3341 .64729 .32982 .64105 .32192 Mtetra
.664 .741 .907 r
.64105 .32192 .64729 .32982 .66002 .32554 .65381 .3176 Mtetra
.65381 .3176 .66002 .32554 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25974 Mtetra
.82521 .25974 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.663 .741 .907 r
.41384 .38891 .42077 .39626 .43256 .3923 .42565 .38491 Mtetra
.661 .74 .908 r
.42565 .38491 .43256 .3923 .44439 .38836 .43752 .38096 Mtetra
.646 .736 .915 r
.43752 .38096 .44439 .38836 .45627 .38477 .44942 .37747 Mtetra
.556 .707 .941 r
.44942 .37747 .45627 .38477 .46817 .38283 .46134 .37614 Mtetra
.061 .456 .882 r
.46134 .37614 .46817 .38283 .48007 .38589 .47323 .38121 Mtetra
.783 .287 0 r
.47323 .38121 .48007 .38589 .49198 .39865 .4851 .39835 Mtetra
.886 .479 .235 r
.4851 .39835 .49198 .39865 .504 .42191 .49707 .42794 Mtetra
.856 .474 .323 r
.49707 .42794 .504 .42191 .51628 .4476 .50934 .45953 Mtetra
.75 .366 .325 r
.50934 .45953 .51628 .4476 .52883 .46294 .52196 .47819 Mtetra
.372 0 .186 r
.52196 .47819 .52883 .46294 .54149 .45891 .53475 .47414 Mtetra
0 0 0 r
.53475 .47414 .54149 .45891 .55403 .43543 .54743 .44732 Mtetra
.939 .881 .468 r
.54743 .44732 .55403 .43543 .56635 .40147 .55986 .40741 Mtetra
.99 .885 .567 r
.55986 .40741 .56635 .40147 .57852 .36985 .57209 .36937 Mtetra
.969 .888 .694 r
.57209 .36937 .57852 .36985 .59076 .34873 .58434 .34375 Mtetra
.866 .853 .827 r
.58434 .34375 .59076 .34873 .60316 .33733 .59676 .33027 Mtetra
.741 .787 .89 r
.59676 .33027 .60316 .33733 .6157 .33096 .60933 .32322 Mtetra
.681 .751 .904 r
.60933 .32322 .6157 .33096 .62834 .32627 .62201 .31835 Mtetra
.666 .742 .907 r
.62201 .31835 .62834 .32627 .64105 .32192 .63475 .31395 Mtetra
.664 .741 .907 r
.63475 .31395 .64105 .32192 .65381 .3176 .64756 .30959 Mtetra
.64756 .30959 .65381 .3176 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .29201 Mtetra
.69937 .29201 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23517 .44007 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.663 .741 .907 r
.40684 .38149 .41384 .38891 .42565 .38491 .41869 .37746 Mtetra
.661 .74 .908 r
.41869 .37746 .42565 .38491 .43752 .38096 .43059 .37348 Mtetra
.646 .735 .914 r
.43059 .37348 .43752 .38096 .44942 .37747 .44253 .36995 Mtetra
.558 .703 .937 r
.44253 .36995 .44942 .37747 .46134 .37614 .45447 .3686 Mtetra
.119 .467 .892 r
.45447 .3686 .46134 .37614 .47323 .38121 .46638 .37364 Mtetra
.699 .22 0 r
.46638 .37364 .47323 .38121 .4851 .39835 .47823 .3908 Mtetra
.885 .464 .062 r
.47823 .3908 .4851 .39835 .49707 .42794 .49016 .42042 Mtetra
.892 .476 .081 r
.49016 .42042 .49707 .42794 .50934 .45953 .5024 .45203 Mtetra
.715 .237 0 r
.5024 .45203 .50934 .45953 .52196 .47819 .51501 .4707 Mtetra
.655 .753 .922 r
.51501 .4707 .52196 .47819 .53475 .47414 .52783 .46662 Mtetra
.911 .775 .698 r
.52783 .46662 .53475 .47414 .54743 .44732 .5406 .43972 Mtetra
.937 .759 .635 r
.5406 .43972 .54743 .44732 .55986 .40741 .55314 .3997 Mtetra
.936 .761 .64 r
.55314 .3997 .55986 .40741 .57209 .36937 .56548 .36157 Mtetra
.909 .774 .7 r
.56548 .36157 .57209 .36937 .58434 .34375 .57781 .33588 Mtetra
.836 .781 .8 r
.57781 .33588 .58434 .34375 .59676 .33027 .59029 .32234 Mtetra
.736 .764 .875 r
.59029 .32234 .59676 .33027 .60933 .32322 .6029 .31525 Mtetra
.68 .747 .901 r
.6029 .31525 .60933 .32322 .62201 .31835 .61562 .31035 Mtetra
.666 .742 .906 r
.61562 .31035 .62201 .31835 .63475 .31395 .6284 .30591 Mtetra
.664 .741 .907 r
.6284 .30591 .63475 .31395 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .29201 .69322 .28378 Mtetra
.69322 .28378 .69937 .29201 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23517 .44007 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37746 .41167 .36995 Mtetra
.662 .74 .908 r
.41167 .36995 .41869 .37746 .43059 .37348 .4236 .36591 Mtetra
.65 .736 .912 r
.4236 .36591 .43059 .37348 .44253 .36995 .43558 .36222 Mtetra
.587 .71 .928 r
.43558 .36222 .44253 .36995 .45447 .3686 .44757 .3602 Mtetra
.322 .563 .924 r
.44757 .3602 .45447 .3686 .46638 .37364 .45952 .3632 Mtetra
0 .087 .639 r
.45952 .3632 .46638 .37364 .47823 .3908 .47143 .37594 Mtetra
0 0 .383 r
.47143 .37594 .47823 .3908 .49016 .42042 .48338 .39924 Mtetra
0 0 .493 r
.48338 .39924 .49016 .42042 .5024 .45203 .49557 .425 Mtetra
.241 .25 .668 r
.49557 .425 .5024 .45203 .51501 .4707 .50811 .44035 Mtetra
.602 .474 .679 r
.50811 .44035 .51501 .4707 .52783 .46662 .52088 .43621 Mtetra
.748 .567 .65 r
.52088 .43621 .52783 .46662 .5406 .43972 .53366 .41252 Mtetra
.807 .61 .636 r
.53366 .41252 .5406 .43972 .55314 .3997 .54628 .37829 Mtetra
.83 .642 .648 r
.54628 .37829 .55314 .3997 .56548 .36157 .55874 .34641 Mtetra
.824 .677 .7 r
.55874 .34641 .56548 .36157 .57781 .33588 .57119 .32509 Mtetra
.783 .717 .79 r
.57119 .32509 .57781 .33588 .59029 .32234 .58374 .31355 Mtetra
.716 .738 .868 r
.58374 .31355 .59029 .32234 .6029 .31525 .59642 .30706 Mtetra
.676 .741 .899 r
.59642 .30706 .6029 .31525 .61562 .31035 .60917 .30226 Mtetra
.666 .741 .906 r
.60917 .30226 .61562 .31035 .6284 .30591 .622 .2978 Mtetra
.664 .741 .907 r
.622 .2978 .6284 .30591 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26642 Mtetra
.71345 .26642 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23328 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36995 .40459 .36237 Mtetra
.663 .74 .908 r
.40459 .36237 .41167 .36995 .4236 .36591 .41656 .35828 Mtetra
.656 .738 .91 r
.41656 .35828 .4236 .36591 .43558 .36222 .42857 .35437 Mtetra
.622 .721 .917 r
.42857 .35437 .43558 .36222 .44757 .3602 .44061 .35144 Mtetra
.499 .645 .922 r
.44061 .35144 .44757 .3602 .45952 .3632 .45265 .35155 Mtetra
.228 .422 .845 r
.45265 .35155 .45952 .3632 .47143 .37594 .46466 .35784 Mtetra
.08 .215 .704 r
.46466 .35784 .47143 .37594 .48338 .39924 .47669 .37138 Mtetra
.228 .233 .657 r
.47669 .37138 .48338 .39924 .49557 .425 .48889 .38737 Mtetra
.437 .339 .646 r
.48889 .38737 .49557 .425 .50811 .44035 .50135 .3968 Mtetra
.586 .43 .636 r
.50135 .3968 .50811 .44035 .52088 .43621 .51402 .39259 Mtetra
.675 .491 .629 r
.51402 .39259 .52088 .43621 .53366 .41252 .52674 .37469 Mtetra
.725 .534 .632 r
.52674 .37469 .53366 .41252 .54628 .37829 .53938 .35015 Mtetra
.75 .573 .655 r
.53938 .35015 .54628 .37829 .55874 .34641 .55194 .32799 Mtetra
.755 .622 .712 r
.55194 .32799 .55874 .34641 .57119 .32509 .5645 .3131 Mtetra
.733 .682 .8 r
.5645 .3131 .57119 .32509 .58374 .31355 .57714 .30439 Mtetra
.694 .723 .872 r
.57714 .30439 .58374 .31355 .59642 .30706 .58987 .29875 Mtetra
.671 .738 .9 r
.58987 .29875 .59642 .30706 .60917 .30226 .60267 .29409 Mtetra
.665 .74 .906 r
.60267 .29409 .60917 .30226 .622 .2978 .61554 .28962 Mtetra
.664 .741 .907 r
.61554 .28962 .622 .2978 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26712 Mtetra
.68077 .26712 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26642 .70729 .25797 Mtetra
.70729 .25797 .71345 .26642 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36237 .39746 .35473 Mtetra
.663 .741 .907 r
.39746 .35473 .40459 .36237 .41656 .35828 .40946 .35059 Mtetra
.661 .739 .908 r
.40946 .35059 .41656 .35828 .42857 .35437 .42151 .34651 Mtetra
.646 .731 .91 r
.42151 .34651 .42857 .35437 .44061 .35144 .4336 .34286 Mtetra
.598 .694 .91 r
.4336 .34286 .44061 .35144 .45265 .35155 .44572 .34059 Mtetra
.496 .59 .878 r
.44572 .34059 .45265 .35155 .46466 .35784 .45784 .3413 Mtetra
.414 .449 .788 r
.45784 .3413 .46466 .35784 .47669 .37138 .46999 .34582 Mtetra
.439 .386 .703 r
.46999 .34582 .47669 .37138 .48889 .38737 .48224 .352 Mtetra
.515 .398 .658 r
.48224 .352 .48889 .38737 .50135 .3968 .49466 .35502 Mtetra
.587 .433 .639 r
.49466 .35502 .50135 .3968 .51402 .39259 .50724 .35073 Mtetra
.641 .47 .636 r
.50724 .35073 .51402 .39259 .52674 .37469 .51988 .33913 Mtetra
.678 .507 .647 r
.51988 .33913 .52674 .37469 .53938 .35015 .53252 .32432 Mtetra
.7 .551 .681 r
.53252 .32432 .53938 .35015 .55194 .32799 .54514 .31115 Mtetra
.709 .612 .747 r
.54514 .31115 .55194 .32799 .5645 .3131 .55779 .30178 Mtetra
.698 .681 .83 r
.55779 .30178 .5645 .3131 .57714 .30439 .5705 .2954 Mtetra
.678 .723 .884 r
.5705 .2954 .57714 .30439 .58987 .29875 .58328 .29042 Mtetra
.667 .737 .903 r
.58328 .29042 .58987 .29875 .60267 .29409 .59612 .28586 Mtetra
.664 .74 .907 r
.59612 .28586 .60267 .29409 .61554 .28962 .60903 .28137 Mtetra
.664 .741 .907 r
.60903 .28137 .61554 .28962 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26712 .67446 .25868 Mtetra
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35059 .4023 .34284 Mtetra
.663 .74 .907 r
.4023 .34284 .40946 .35059 .42151 .34651 .41439 .33866 Mtetra
.658 .737 .908 r
.41439 .33866 .42151 .34651 .4336 .34286 .42652 .33461 Mtetra
.642 .722 .906 r
.42652 .33461 .4336 .34286 .44572 .34059 .4387 .33102 Mtetra
.608 .676 .889 r
.4387 .33102 .44572 .34059 .45784 .3413 .45092 .32849 Mtetra
.567 .591 .837 r
.45092 .32849 .45784 .3413 .46999 .34582 .46317 .32741 Mtetra
.554 .512 .763 r
.46317 .32741 .46999 .34582 .48224 .352 .4755 .32708 Mtetra
.572 .476 .707 r
.4755 .32708 .48224 .352 .49466 .35502 .48792 .32561 Mtetra
.603 .476 .68 r
.48792 .32561 .49466 .35502 .50724 .35073 .50045 .32127 Mtetra
.633 .495 .676 r
.50045 .32127 .50724 .35073 .51988 .33913 .51305 .31406 Mtetra
.658 .529 .695 r
.51305 .31406 .51988 .33913 .53252 .32432 .52568 .30569 Mtetra
.676 .58 .74 r
.52568 .30569 .53252 .32432 .54514 .31115 .53834 .29805 Mtetra
.683 .646 .806 r
.53834 .29805 .54514 .31115 .55779 .30178 .55104 .29187 Mtetra
.677 .702 .866 r
.55104 .29187 .55779 .30178 .5705 .2954 .5638 .28675 Mtetra
.668 .73 .896 r
.5638 .28675 .5705 .2954 .58328 .29042 .57663 .28209 Mtetra
.665 .739 .905 r
.57663 .28209 .58328 .29042 .59612 .28586 .58951 .27757 Mtetra
.664 .741 .907 r
.58951 .27757 .59612 .28586 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33866 .4072 .3308 Mtetra
.662 .74 .907 r
.4072 .3308 .41439 .33866 .42652 .33461 .41938 .32658 Mtetra
.659 .735 .906 r
.41938 .32658 .42652 .33461 .4387 .33102 .43161 .32245 Mtetra
.649 .718 .899 r
.43161 .32245 .4387 .33102 .45092 .32849 .44388 .31859 Mtetra
.636 .682 .877 r
.44388 .31859 .45092 .32849 .46317 .32741 .45621 .31513 Mtetra
.625 .63 .836 r
.45621 .31513 .46317 .32741 .4755 .32708 .4686 .31188 Mtetra
.624 .587 .792 r
.4686 .31188 .4755 .32708 .48792 .32561 .48105 .30831 Mtetra
.633 .568 .764 r
.48105 .30831 .48792 .32561 .50045 .32127 .49358 .30393 Mtetra
.646 .576 .761 r
.49358 .30393 .50045 .32127 .51305 .31406 .50617 .29872 Mtetra
.66 .605 .782 r
.50617 .29872 .51305 .31406 .52568 .30569 .51881 .2932 Mtetra
.67 .65 .822 r
.51881 .2932 .52568 .30569 .53834 .29805 .5315 .28789 Mtetra
.671 .695 .864 r
.5315 .28789 .53834 .29805 .55104 .29187 .54425 .28296 Mtetra
.668 .725 .892 r
.54425 .28296 .55104 .29187 .5638 .28675 .55705 .27831 Mtetra
.665 .737 .903 r
.55705 .27831 .5638 .28675 .57663 .28209 .56992 .27375 Mtetra
.664 .74 .907 r
.56992 .27375 .57663 .28209 .58951 .27757 .58284 .26921 Mtetra
.664 .741 .907 r
.58284 .26921 .58951 .27757 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .3308 .39996 .3229 Mtetra
.39996 .3229 .4072 .3308 .41938 .32658 .41217 .3186 Mtetra
.663 .739 .907 r
.41217 .3186 .41938 .32658 .43161 .32245 .42443 .3143 Mtetra
.661 .735 .905 r
.42443 .3143 .43161 .32245 .44388 .31859 .43676 .31004 Mtetra
.658 .724 .898 r
.43676 .31004 .44388 .31859 .45621 .31513 .44913 .30584 Mtetra
.655 .706 .884 r
.44913 .30584 .45621 .31513 .4686 .31188 .46156 .30167 Mtetra
.655 .686 .867 r
.46156 .30167 .4686 .31188 .48105 .30831 .47406 .29742 Mtetra
.657 .673 .854 r
.47406 .29742 .48105 .30831 .49358 .30393 .48661 .293 Mtetra
.661 .674 .852 r
.48661 .293 .49358 .30393 .50617 .29872 .49922 .2884 Mtetra
.664 .689 .863 r
.49922 .2884 .50617 .29872 .51881 .2932 .51189 .28372 Mtetra
.666 .71 .881 r
.51189 .28372 .51881 .2932 .5315 .28789 .52462 .27907 Mtetra
.665 .727 .895 r
.52462 .27907 .5315 .28789 .54425 .28296 .53741 .27448 Mtetra
.665 .736 .903 r
.53741 .27448 .54425 .28296 .55705 .27831 .55025 .26992 Mtetra
.664 .74 .906 r
.55025 .26992 .55705 .27831 .56992 .27375 .56316 .26536 Mtetra
.664 .741 .907 r
.56316 .26536 .56992 .27375 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .3186 .4049 .31059 Mtetra
.4049 .31059 .41217 .3186 .42443 .3143 .4172 .30624 Mtetra
.663 .74 .907 r
.4172 .30624 .42443 .3143 .43676 .31004 .42956 .30187 Mtetra
.663 .738 .905 r
.42956 .30187 .43676 .31004 .44913 .30584 .44197 .29749 Mtetra
.663 .734 .903 r
.44197 .29749 .44913 .30584 .46156 .30167 .45444 .2931 Mtetra
.663 .729 .899 r
.45444 .2931 .46156 .30167 .47406 .29742 .46697 .28868 Mtetra
.663 .726 .896 r
.46697 .28868 .47406 .29742 .48661 .293 .47956 .28422 Mtetra
.664 .726 .896 r
.47956 .28422 .48661 .293 .49922 .2884 .49221 .27971 Mtetra
.664 .73 .898 r
.49221 .27971 .49922 .2884 .51189 .28372 .50492 .27518 Mtetra
.664 .734 .902 r
.50492 .27518 .51189 .28372 .52462 .27907 .51768 .27063 Mtetra
.664 .738 .905 r
.51768 .27063 .52462 .27907 .53741 .27448 .5305 .26607 Mtetra
.664 .74 .907 r
.5305 .26607 .53741 .27448 .55025 .26992 .54339 .2615 Mtetra
.664 .741 .907 r
.54339 .2615 .55025 .26992 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30624 .4099 .29813 Mtetra
.4099 .29813 .4172 .30624 .42956 .30187 .4223 .29371 Mtetra
.664 .74 .907 r
.4223 .29371 .42956 .30187 .44197 .29749 .43475 .28928 Mtetra
.43475 .28928 .44197 .29749 .45444 .2931 .44726 .28482 Mtetra
.664 .739 .906 r
.44726 .28482 .45444 .2931 .46697 .28868 .45982 .28035 Mtetra
.45982 .28035 .46697 .28868 .47956 .28422 .47245 .27585 Mtetra
.47245 .27585 .47956 .28422 .49221 .27971 .48513 .27132 Mtetra
.48513 .27132 .49221 .27971 .50492 .27518 .49788 .26677 Mtetra
.664 .74 .907 r
.49788 .26677 .50492 .27518 .51768 .27063 .51068 .2622 Mtetra
.51068 .2622 .51768 .27063 .5305 .26607 .52354 .25762 Mtetra
.664 .741 .907 r
.52354 .25762 .5305 .26607 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28928 .42746 .28102 Mtetra
.42746 .28102 .43475 .28928 .44726 .28482 .44001 .27653 Mtetra
.44001 .27653 .44726 .28482 .45982 .28035 .45261 .27201 Mtetra
.664 .74 .907 r
.45261 .27201 .45982 .28035 .47245 .27585 .46527 .26747 Mtetra
.46527 .26747 .47245 .27585 .48513 .27132 .478 .26291 Mtetra
.664 .741 .907 r
.478 .26291 .48513 .27132 .49788 .26677 .49078 .25832 Mtetra
.49078 .25832 .49788 .26677 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27653 .43269 .26816 Mtetra
.43269 .26816 .44001 .27653 .45261 .27201 .44533 .26361 Mtetra
.44533 .26361 .45261 .27201 .46527 .26747 .45803 .25903 Mtetra
.45803 .25903 .46527 .26747 .478 .26291 .4708 .25443 Mtetra
.4708 .25443 .478 .26291 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23798 Mtetra
.42312 .23798 .43059 .24659 .44337 .24193 .43594 .23328 Mtetra
.43594 .23328 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23798 .41559 .22928 Mtetra
.41559 .22928 .42312 .23798 .43594 .23328 .42844 .22454 Mtetra
.42844 .22454 .43594 .23328 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19787 Mtetra
.40556 .19787 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19787 .39779 .18881 Mtetra
.39779 .18881 .40556 .19787 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15179 Mtetra
.36602 .15179 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15179 .3579 .14231 Mtetra
.3579 .14231 .36602 .15179 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000/@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000]02Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool30000
0;H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0;H0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000_02Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo
00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool300000;h0ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX0;d0ZKgX0P00
000/0:Vmj0030000003oool0oooo03T0oooo000/0?ooo`040:Vmj0000000000000000;l0ZKgX0`00
00020:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0>@3oool002/0oooo0P00002o
0:Vmj0<000001@2Y_NP00`000000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03P0oooo000Y0?oo
o`800000_P2Y_NP3000000T0ZKgX00<000000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0g0?oo
o`007@3oool01@3ookl0M00000000000B9`0gooo00L0oooo0P00002l0:Vmj08000003@2Y_NP00`00
0000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?oo
o`3OW4P007Bo1`3oool00`000000oooo0000002h0:Vmj0<00000402Y_NP00`000000ZKgX0:Vmj00Y
0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`050?ooo`8000000P3oool00`000000ZKgX0:Vmj02b0:Vmj0<000004`2Y_NP00`000000ZKgX0:Vm
j00Z0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP0P`2Y_NP30:Vmi`D0ZKgX
1@2Y_>L50:Vmj0D0ZKgW502Y_NP3000001L0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo
0?ooo`0e0?ooo`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000
oooo0?ooo`030?oooh<0ZKgX1P2Y_NL20:Vmj0<0ZK_V1@2Y_>L20:Vmj0<0Z[cW1@2Y_NL@0:Vmj0<0
00006`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03@0oooo000L0?ooo`070?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vmj01k0:Vm
j0X0ZKgW1P2Y^nH40:Vli`H0Z[cW0P2Y_NL30:Zli``0ZKgX0`00000O0:Vmj0030000002Y_NP0ZKgX
02T0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00D0oooo00<000000?ooo`3oool01@3oool00`000000ZKgX0:Vmj01f0:Vmj0X0ZKgW1@2Y^^D5
0:VkiPD0Z[[U2`2Z_>L80:Vmj0<000008P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0
oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?oo
o`070?ooogH0ZKgX2@2Y_NL30:Vii@D0ZK[U1@2Z]N450:Zji@D0ZkWT1@2Z_>L50:Zmi`<000009P2Y
_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo0380oooo000M0?ooo`050?oo_`1d0000
00000018W03Oool01P3oool00`000000oooo0?ooo`080?ooog<0ZKgX2@2Y_NL60:Vii@80ZK[U0`2Y
/=`50:Zeh@80Z[[U0`2[/Md50:^ii0D0Zk[U0P2Z_NL2000000030:Zmi`2Y_NP0ZKgX02L0ZKgX00<0
00000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0b0?ooo`009`3oool00`000000oooo0?ooo`0:
0?ooog<0ZKgX102Y_NL:0:Vii@H0ZK3L102Z]N460:^ag@80ZkWT0`2]/md30:^ji@<00000102Z_>LX
0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<@3oool002L0oooo00<000000?oo
o`3oool02`3ooomc0:Vmj0@0ZK[V1@2Y^ND50:V/fPD0ZK3L1@2[Y]850:^ag@D0[K?M0`0000030:fi
hPD0Z[cW0P2Y_NP30:Zmib<0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0`0?oo
o`009`3oool00`000000oooo0?ooo`0<0?ooog00ZKgX0`2Y^nL40:VjiP<0ZKWU0P2X[=X50:V/fP80
ZK3L0`2XV/P50:^VdP80Zk7M0`2^YLh01@2]/md00000000000000000[K?M00H0[KWR102Z_>L60:Zm
ib<0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool2000000h0
ooooK@2Y_NP60:Vki`@0ZK[V1@2X[=X40:V/fPD0Z9[81@2[Y]830:jUcP<000000P2]/md30;:^e0D0
[KWR1@2[_>H50:Zmib@0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0_0?ooo`00
9`3oool00`000000oooo0?ooo`0>0?ooofP0ZKgX1@2Y_>L50:Vki`D0YjoM1@2X[=X20:V/fP80YI?2
1@2XV/P20:^VdP80[IBm0`0000030:jUcPH0/ZkD0P2]^N830;6ig`D0ZkcV1@2Z_NLS0:Vmj0030000
002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo00<000000?ooo`3oool03`3o
oomX0:Vmj0D0ZKcW1@2W]>850:N_g@@0Z:cJ102UTl850:RJb0050:fD_@00000000000000002]U;d0
102^YLh20;FL_`D0/ZkD1P2a^Ml50:fmiPD0Z[gW8`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000
003oool0oooo02h0oooo000W0?ooo`8000004@3oool00`000000ZKgX0:Vmj01U0:Vmj0D0Z;WU1@2W
]>840:N_g@D0XY73102UTl820:RJb0<000001@2]U;d20:jUcP@0]Ibo0P2b[]@30;^^c0<0/KWO0`2g
_=h50:fmiPD0Z[gW8`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02d0oooo000V
0?ooo`8000004`3oool00`000000ZKgX0:Vmj01S0:Vmj080ZKcW1@2X^ND40:NdhPD0WiK:102RTL<3
0:FC`P<000000`2XQk450:fD_@H0]Ibo1P2k[/`60;NlgP80[KgV0`2^_nH40:Zmib@0ZKgX00<00000
0:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0/0?ooo`002@3oool02P3ookl0M00000000000B9`0
gooo0?ooo`3ogi`0B01d0;ooo`3OW4P50000000307Boo`3oool0gia80080000000<0001809cOo`3o
ool01P3oool00`000000oooo0?ooo`0C0?ooo`030000002Y_NP0ZKgX0600ZKgX1@2Y_>L40:Rii@D0
Wj7F102OU/X50::A``80000000<0YI?20:R7/@2XQk400`2XQk440:fD_@80/hf^1@2eW;l00`31WkH0
^jk<0;^^c0020;^^c080b;O:1@2g_=h60:joiP<0Z[gW902Y_NP00`000000ZKgX0:Vmj00X0:Vmj003
0000003oool0oooo00X0oooo00D0gia8000000000000001809cOo`0M0?ooo`00203oool01P3ooml0
W4P004RLg`3oool0gia8001d_`@0oooo00<0omnL04P0001d_ol0103oool01`3o_g@004RL0=ooo`3o
ool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000002Y_NP0ZKgX0600ZKgX
102Y_>L50::^h0@0Wj7F1@2OU/X0102RTL<000000000000000020:FC`P80XWj]1@2XQk420:fD_@<0
/hf^102eW;l20<6O]P<0^jk<1038]lX20;NlgP<0_<?O1@2^_nH40:Zmj2@0ZKgX00<000000:Vmj02Y
_NP0:02Y_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0L
0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0103oool00`3ogi`0B00007Bo
o`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?ooof<0ZKgX102V]nH40::^h0D0Wj7F0P2O
U/X3000000<0XY73102ROZd50:R7/@030:fD_@2cSJh0/hf^00<0/hf^0P2eW;l40<6O]P030;^^c038
]lX0b;O:00<0b;O:1P2l`ml50:k0i`@0Z[gX902Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003o
ool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00D0oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000
003oool0oooo01L0ooooG@2Y_NP50:Rli`@0Y[OV102R[^0309nQeP<000000P2OU/X509Yi[P@0XWj]
102XQk460;>=[P030;FL_`31WkH0`Inf00<0`Inf1@38]lX20=K7c0@0_<?O0P2mbN<50:k0i`@0Z[gX
8`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool0
6`3oool000P0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018
W=l0oooo0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo01P0oooo
G@2Y_NP50:Rli`@0Y[OV0`2R[^030000000309nQeP2BNK@0TWVd00<0TWVd102JNJh40:9n[@@0Z8Na
00<0[H6U0;>=[P2cSJh00`2cSJh60<6O]P040=:]/`38]lX0b;O:0<RgbP@0e/O<0P2l`ml40;g9h`80
[/3W0`2]`>P40:Zmj2<0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`060?ooo`07
0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0L0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol01`3oool01@3ookl0M01809cOo`3ookl0M00000<0000000<0M;oo0?ooo`3oool0
103oool2000001/0ooooG@2Y_NP40:Rli`@0VjgS0`0000000`2AUmH0SH?308f3``0208f3``@0TWVd
102JNJh50:9n[@80Z8Na0P2]PJD50;>=[P030;nBY`31WkH0`Inf0080`Inf0`3B[K<00`38]lX0e/O<
0=K7c0030=K7c0H0_LWS1@2]`>P50:Zmj2<0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo
0?ooo`050?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool06`3oool000P0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0okmd001d_`3oool00P3oool01@2oM000
M;oo0?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool06`3ooomL0:Vmj0D0Y;SW0`000000102K
[N<0TIOF096GeP2AUmH408f3``@0TWVd102JNJh50:9n[@040:R7/@2]PJD0[H6U0:f1Y@@0/hf^0P2o
TZL30<6O]P@0dZfc1@3Fal`20=gJd`<0_LWS0`2ib^L40:g0j0H0Z[gX8`2Y_NP00`000000ZKgX0:Vm
j00W0:Vmj0030000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool000P0oooo00H0oooO
09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0B01809cOo`3oool0
_g@007Boo`T0oooo00<000000?ooo`3oool0703ooomH0:Vmj0@0Z;cX00D0Y;SW0000000000000000
0:Bhi`0409^]h`<0TIOF0`2=Pl<4099i]0D0VWV^102ROZd40:f1Y@@0/hf^0`2oTZL20<6O]P@0dZfc
00@0j<Jc0=K7c03Fal`0e/O<103Mf]<60;W:i`@0ZkoX1@2Z_NPS0:Vmj0030000002Y_NP0ZKgX02P0
ZKgX00<000000?ooo`3oool01@3oool00`2oM000M;oo0?ooo`0O0?ooo`002@3oool01@3ookl0M000
00000000B9`0gooo00D0oooo00D0omnL04P000000000000007Boo`020?ooo`060=nLB00000000000
0000000007@0_ooo1@3oool00`000000oooo0?ooo`0M0?oooeP0ZKgX0P2X_>P2000000@0Y;SW102K
[N<3096GeP@0SH?3102BNK@409Yi[P<0XWj]0P2TN:840:f1Y@80/hf^102oTZL00`31WkH0dZfc0=:]
/`020=:]/`<0j<Jc00<0e/O<0=gJd`3Mf]<00P3Mf]<20=WTgP<0^L[W0`2canT40:^oj2P0ZKgX00<0
00000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`060=nLB000000000000000000007@0
_ooo703oool002D0oooo0P00000O0?oooeH0ZKgX0`0000030:Fkj0@0VK7X101nUn0206Ubb@@0SH?3
102BNK@409Yi[P80XWj]0`2TN:840:f1Y@80/hf^102oTZL50=:]/`<0j<Jc103Mf]<40=WTgPD0/lOY
1@2Z_^PX0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09P3oool002D0oooo00<0
00000?ooo`3oool07`3ooomB0:Vmj0<000000`2Y_NP40:Fkj0@0VK7X0`1nUn0306Ubb@03071R/`2=
Pl<0SH?300@0TWVd102JNJh00`2ROZd0Y7RR0:AhXP020:AhXP@0[H6U00<0/hf^0;nBY`2oTZL00`2o
TZL0103DY:D0dZfc0=:]/`3B[K<40>S6/`80n>>a103Ii=h30<WNj0<0/lOY0P2^`^T50:Znj2L0ZKgX
00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?oo
o`0P0?ooodh0ZKgX0`0000070:Vmj0<0YK_X102I/NP407jGh080JG;90`1`H[<4099i]0@0VWV^1@2T
N:840:f1Y@H0_i:W00@0e:BU0=:]/`3B[K<0dZfc0`3Xa[<30?SS/@80lOFb1P39g^P50:k2j@80Z[kX
0`2Z_NPW0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00
000S0?ooodX0ZKgX0`00000:0:Vmj0@0WkSZ101oYN`00`0jK=P0OYOP07jGh00206Ubb@@0L6:c0`23
IJP509I^X`@0Y7RR102]PJD00`2iR:40_i:W0;nBY`030;nBY`80e:BU00<0dZfc0>S6/`3Xa[<00P3X
a[<20?SS/@<0lOFb00@0hoc<0<WNj039g^P0bMkX0`2icn/40:k2j@H0Z[gX9`2Y_NP00`000000ZKgX
0:Vmj00W0:Vmj0030000003oool0oooo02@0oooo000T0?ooo`030000003oool0oooo02<0ooooAP2Y
_NP3000000T0ZKgX1@2W_>P409nhjP<0OjG/0`0jK=P206Ubb@@0L6:c1023IJP409I^X`D0Y7RR0`2]
PJD00`2iR:40_i:W0;nBY`020;nBY`<0e:BU00@0dZfc0>S6/`3Xa[<0j<Jc0`3hhk420?7e/P<0hoc<
1P2icn/40:^oj0D0Z[gX:02Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02<0oooo
000T0?ooo`030000003oool0oooo02@0oooo@P2Y_NP3000000d0ZKgX1@2W_>P409nhjP<0OjG/0`0j
K=P206Ubb@<0L6:c1023IJP409I^X`D0Y7RR0P2]PJD30;V8X@<0_i:W0`3DY:D40>S6/`80n>>a0P3a
mK820>?lc0@0c^gZ1@2_a>T40:^oj2`0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`0S0?ooo`00903oool2000002H0oooo?P2Y_NP300000140ZKgX1@2V_>T409Jek@80DY3/0`0jK=P0
0`0D=k@0JG;9071R/`02071R/`@0PfFX102FKZ<50:AhXP80[H6U0`2iR:430;nBY`<0e:BU00<0kl:S
0>S6/`3Xa[<00`3hhk400`3amK80hoc<0<k]jP030<k]jP<0]m7]102_a>T50:Znj2`0ZKgX00<00000
0:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0R0?ooo`008`3oool2000002P0oooo>`2Y_NP20000
01D0ZKgX1@2V_>T409Jek@80DY3/00@001JS03Y/f00jK=P053Nd0`1`H[<408=UZ0@0UVjS1@2TN:80
0`2]PJD0^HRQ0;V8X@020;V8X@80_i:W103DY:D20>o2X`<0n>>a00<0lOFb0:kDIP38oL000P38oL06
0;OAk@80[lCY0P2[_nP50:Znj2`0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0Q
0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080
000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?ooocH0ZKgX0`00000H0:Vmj0@0
Y[cY1@2>/nl01@0NMn@0DY3/000FX`0jK=P053Nd00@0L6:c0`23IJP409I^X`D0Y7RR00<0[H6U0;V8
X@2iR:400`2iR:400`2oTZL0e:BU0=BTY@020=BTY@80kl:S0P3mhY420=7JI@80b?g00`32io050;OA
k@D0ZkoX0P2Z_^P_0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool08@3oool000`0
oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd
0;ooo`060?ooo`030000003oool0oooo02X0oooo<P2Y_NP3000001/0ZKgX1@2U_>T508jck`0301ig
i0005Z<001JS008053Nd0`1`H[<308=UZ0D0UVjS102TN:860;V8X@040;nBY`3DY:D0e:BU0=BTY@<0
kl:S0P3mhY400`3AfVD0b?g00<;Wl0050<;Wl0D0[L?Y102[_nPa0:Vmj0030000002Y_NP0ZKgX02L0
ZKgX0P00000Q0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool00`2o
M000M;oo0?ooo`050?ooo`800000;03oool^0:Vmj0<00000802Y_NP40:Flj@D0S[C`00D03gCQ000F
X`005Z<053Nd03XkZ002071R/`@0PfFX102FKZ<40:AhXP030:amX@2iR:40^HRQ00<0^HRQ103DY:D3
0>o2X`80oN:A00@0dMYU0;_jj`2kn^/0^o[[1@2`bN`50:g3j@@0Z[gX<@2Y_NP00`000000ZKgX0:Vm
j00W0:Vmj0030000003oool0oooo01l0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`080?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0;03ooolZ0:Vmj0<00000
902Y_NP40:FljPD0S[C`00<03gCQ000FX`0D=k@00P0j>jP00`1`H[<0PfFX08=UZ00208=UZ0@0UVjS
0`2TN:820:amX@D0^HRQ00@0cYbR0=BTY@3DY:D0e:BU0P3_`Z<20?gRT@040=7JI@2kn^/0^o[[0;_j
j`80/]7`1@2`bN`50:Znj0@0Z[gX<@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo
01l0oooo000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0
W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02d0oooo9P2Y_NP3000002P0ZKgX
102U_>X509Fhk`0303ZBl0005Z<0>S^X0080>S^X1023IJP409I^X`80Y7RR0`2/OJ450;V8X@040<jL
XP3DY:D0e:BU0=BTY@80kl:S0P3mhY400`3AfVD0^o[[0;;Al0040;;Al0D0ZkoY102Z_^Pe0:Vmj003
0000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3oool000`0oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`050?oo
o`030000003oool0oooo02h0oooo8P2Y_NP3000002`0ZKgX102V_>T509Fhk`0403ZBl00D=k@0>S^X
03XkZ0@0PfFX102FKZ<00`2TN:80[7fQ0:amX@020:amX@@0^HRQ0P3>W:820=BTY@<0kl:S0P3mhY43
0:oFm080/]7`0`2[`NT50:^ojCT0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0M
0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q809cO
o`090?ooo`800000<@3ooolN0:Vmj0<00000<02Y_NP40:Jlj@D0W[_]00D0001R03XkZ00j>jP0>S^X
06mFY@0208=UZ0@0UVjS1@2/OJ440;V8X@<0cYbR00H0e:BU0>o2X`3_`Z<0kl:S0?gRT@3AfVD30:oF
m0H0Zl7Y1@2Z_NPi0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07@3oool000`0
oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00P0oooo00<00000
0?ooo`3oool0<@3ooolK0:Vmj0800000=02Y_NP40:Nmj@D0W[_]0`0j>jP206mFY@0308=UZ02FKZ<0
UVjS00<0UVjR102/OJ440;V8X@<0cYbR00<0e:BU0>o2X`3_`Z<00P3mhY400`2VdoL0Zl;[0:_2j`02
0:_2j`<0Zl7Y0`2Z_^P50:Zmj3T0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0L
0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia800000000000000000000
M02oool50?ooo`030000003oool0oooo0380oooo5`2Y_NP3000003L0ZKgX102W_NT40:FljP<0>S^X
0`1_EZD509I^XPD0[7fQ0P2iR:440<jLXP030=BTY@3_`Z<0kl:S0080oN:A0P2Y`N/40:_2j`H0Z[kX
0P2Z_NPk0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool06`3oool00280oooo0P00
000d0?oooa<0ZKgX0`00000k0:Vmj080YkgY0P2Y_NP40:FljP80>S^X101_EZD409I^XPD0[7fQ0P2i
R:440<jLXP<0kl:S00<0oN:A0:W1j`2Y`N/00P2Y`N/90:Znj3h0ZKgX00<000000:Vmj02Y_NP09P2Y
_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`l0ZKgX0`000013
0:Vmj080YKcZ00<0Z;gX03XkZ00j>jP0101_EZD409I^XPD0[7fQ0P2iR:440<jLXP040>o2XP3_`Z<0
kl:S0?3QM`D0ZKkX102Z_^Q30:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06P3o
ool00280oooo00<000000?ooo`3oool0=@3oool00`000000ZKgX0:Vmj0080:Vmj0<00000AP2Y_NP4
0:Rmj080>S^X0`1_EZD409I^XPD0[7fQ00<0^HRQ0<jLXP3>W:800`3>W:820>o2XP80l>5g00<0ZKgX
0:Vnj02Y_^P00`2Y_^Q70:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool0303oool0
0`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool00280oooo00<00000
0?ooo`3oool0=`3oool60:Vmj0<00000BP2Y_NP30:Rmj080>S^X0`1_EZD409I^XPD0[7fQ00<0^HRQ
0<jLXP3>W:800P3>W:830>o2XP030?3QM`2Y_NP0ZKgX04`0ZKgX00<000000:Vmj02Y_NP09P2Y_NP2
000000`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00240
oooo0P00000j0?ooo`80ZKgX0`00001A0:Vmj00403XkZ01_EZD0KeJU06mFY@@0UVjR1@2/OJ450<jL
XP<0kl:R00<0l>5g0:Vmj02Y_NP0C@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo
00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`00
8@3oool00`000000oooo0?ooo`0h0?ooo`<00000E02Y_NP0100j>jP0KeJU06mFY@1_EZD509I^XP@0
[7fQ00<0_i6V0<jLXP3>W:800P3>W:820>o2XP030?3QM`2Y_NP0ZKgX04l0ZKgX00<000000:Vmj02Y
_NP09@2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0=P3oool2000000<0ooooE02Y
_NP00`0007h0KeJU06mFY@0206mFY@@0UVjR0`2/OJ420;nAYP<0cYbR0`3_`Z800`3`hGL0ZKgX0:Vm
j01?0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool02@3oool02`3ogi`0B01d0;oo
o`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`800000=03oool30000
00H0ooooE02Y_NP406mFY@@0UVjR0`2/OJ420;nAYP<0cYbR0`3_`Z800`3`hGL0ZKgX0:Vmj01@0:Vm
j0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0203oool02`3ogi`0B01d0;ooo`3oool0
omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo0300oooo
0`0000090?oooe@0ZKgX00@0001n06mFY@1_EZD0KeJU102FKZ820:amX@<0_i6V0`3>W:820>o2XP03
0?3QM`2Y_NP0ZKgX0580ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?ooo`0=
0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`00
103oool03@3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@0B02Lgol0
103oool01@3OW4P000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;@3oool3000000h0
ooooDP2Y_NP0100007h0?Cn[06mFY@1_EZD409I^XP80[7fQ102oTJH01@3>W:80kl:R0>o2XP3_`Z80
l>5g05D0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?ooo`0;0?noM0000000
001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0103oool000<0oooo00H0oooO09a80018
W=l0oooo0=nLB000M;l50?ooo`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018W03Oool0oooo0?oo
g`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool300000180ooooDP2Y_NP203doZ`0306mF
Y@2FKZ80UVjR0080UVjR00<0[7fQ0;nAYP2oTJH00`2oTJH0103>W:80kl:R0>o2XP3_`Z9F0:Vmj003
0000002Y_NP0ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080
oooo00D0oono07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool01@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y
0?ooo`<000005P3ooomA0:Vmj0<0?Cn[102FKZ860;nAYP040<jLXP3_`Z80kl:R0?3QMeL0ZKgX00<0
00000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?ooo`3oool05@3oool000<0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03Oool01`3oool00`2oM000M;oo
0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?oooe00ZKgX00<0001n03doZ`0m?j/0
1@2JNJd50;nAYP<0kl:RF@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`000000oooo
0?ooo`0E0?ooo`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3ookl0
M01809cOo`020?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003oool0
oooo0280oooo0`00000N0?oooe00ZKgX0`0m?j/409Yi[@D0_i6V00<0jLJb0>o2XP3_`Z80FP2Y_NP0
0`000000ZKgX0:Vmj00C0:Vmj0@00000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@000<0
000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000008P3ooom?0:Vmj0<0
?Cn[102JNJd40;nAYP<0jLJbF`2Y_NP00`000000ZKgX0:Vmj00?0:Vmj0040?ooo`00000000000000
0100oooo00<000000?ooo`3oool0503oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00H0oooo00L0oono07@0B02Lgol0oooo0?oog`2LB4P0W=oo00T0oooo0P00000N0?ooo`800000
9P3oool00`000000ZKgX0:Vmj01;0:Vmj0<0?Cn[102JNJd40;nAYP<0jLJbG02Y_NP00`000000ZKgX
0:Vmj00:0:Vmj080oooo0`00000C0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2L
B000M;oo0?ooo`3OW4P007Bo203oool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L
0?ooo`<00000:P3ooom<0:Vmj0<0?Cn[1@2JNJd20;nAYP<0jLJbGP2Y_NP00`000000ZKgX0:Vmj007
0:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0
gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003000000030000M02oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0ooooC02Y_NP303doZ`@0VWV]0P2oTJH3
0>W6/Uh0ZKgX00<000000:Vmj02Y_NP01@2Y_NP2000001X0oooo00<000000?ooo`3oool0503oool0
01l0oooo00<000000?ooo`3oool05@3oool300000380ooooC02Y_NP203doZ`@0VWV]00@0_i6V0>W6
/P3Ya[80jLJbH02Y_NP010000000ZKgX0:Vmj02Y_NP2000001d0oooo00<000000?ooo`3oool0503o
ool001l0oooo0P00000C0?ooo`<00000=P3ooom<0:Vmj00303doZ`2JNJd0VWV]0080VWV]00@0_i6V
0>W6/P3Ya[80jLJbH02Y_NP300000200oooo00<000000?ooo`3oool0503oool001l0oooo00<00000
0?ooo`3oool03`3oool3000003X0ooooC02Y_NP409Yi[@<0jLJbG@2Y_NP3000000<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0<0?oo
o`<00000?P3ooom;0:Vmj0D0Yl3/0P3Ya[9J0:Vmj0<000001P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo00T0oooo0`0000120?oood/0
ZKgX1@2W`>aG0:Vmj0@000002P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`8000002@3oool2000004H0ooooXP2Y_NP0103oool0000000000000000?0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool0
1@3oool3000004T0ooooWP2Y_NP0103oool0000000000000000C0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool00P3oool3000004d0oooo
00<000000:Vmj02Y_NP0UP2Y_NP00`3oool0000000000002000001H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0000000200000540oooo00<0
00000:Vmj02Y_NP0T`2Y_NP3000001/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0C0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP0T02Y_NP2000001l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?oo
o`030000003oool0oooo05@0oooo00<000000:Vmj02Y_NP0S02Y_NP00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02o
ool02P3oool2000005H0ooooR@2Y_NP2000002L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05@0oooo
Q@2Y_NP2000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`004`3o
ool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05@0ooooP02Y_NP200000300oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>
0?ooo`030000003oool0oooo05@0ooooN`2Y_NP3000003<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0?0?ooo`030000003oool0oooo
05@0ooooM`2Y_NP3000003L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?oo
o`004@3oool01@2oM000001809boW01807@0_ooo0100oooo0P00001E0?ooog80ZKgX0`00000l0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00180oooo00@0okmd00000000
07@0_ooo4P3oool00`000000oooo0?ooo`1C0?ooofh0ZKgX0`0000100?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool04`3oool00`000000
oooo0?ooo`1C0?ooofT0ZKgX100000130?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool002X0oooo00<000000?ooo`3oool0D`3ooomU0:Vmj0<00000B03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0140oooo000[0?ooo`800000E03ooomP0:Vmj0040?ooo`00
00000000000004`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;@3o
ool00`000000oooo0?ooo`1B0?oooe`0ZKgX1000001?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool002h0oooo00<000000?ooo`3oool0DP3ooomH0:Vmj0<00000E03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo
0580ooooD`2Y_NP0103oool0000000000000001H0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00300oooo00<000000?ooo`3oool0DP3ooom?0:Vmj0@00000G03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000a0?ooo`800000D`3ooom:0:Vmj004
0?ooo`000000000000000600oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`00<`3oool00`000000oooo0?ooo`1A0?ooodH0ZKgX1000001T0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool003@0oooo00<000000?ooo`3oool0D@3ooom20:Vmj0<00000
J@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000e0?ooo`030000003o
ool0oooo0540oooo?@2Y_NP0103oool0000000000000001/0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool003H0oooo0P00001B0?ooocT0ZKgX1000001`0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool003P0oooo00<000000?ooo`3oool0D03ooole
0:Vmj0<00000M@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000i0?oo
o`030000003oool0oooo0540oooo;`2Y_NP0103oool0000000000000001i0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool003X0oooo00<000000?ooo`3oool0D@3oool[0:Vm
j0@00000O03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000k0?ooo`03
0000003oool0oooo0540oooo9`2Y_NP300000840oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0?0?ooo`00?03oool200000580oooo8P2Y_NP0103oool000000000000000250?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0
D03ooolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo
000o0?ooo`030000003oool0oooo0500oooo6P2Y_NP3000008d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`00@03oool00`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00440oooo0P00001A0?oo
oa80ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004<0
oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00140?ooo`030000003oool0oooo0500oooo202Y_NP3000009d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?oo
o`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3o
ool004H0oooo0P00001A0?ooo`800000YP3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00180?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00190?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo001;0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001<
0?ooo`800000B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool004l0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00500oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00540oooo0P0000160?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00D`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo0:`0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:h0oooo00@00000
0?ooo`3oool000003`3oool005D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2^
0?ooo`040000003oool0oooo000000l0oooo001F0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0000000?0?ooo`00E`3oool2000003l0oooo00<000000?oo
o`3oool0/03oool00`000000oooo0000000>0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0oooo00<000000?ooo`3oool0[@3oool4
00000100oooo001N0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0Z@3oool40000
01@0oooo001O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0Y@3oool4000001P0
oooo001P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X@3oool4000001`0oooo
001Q0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0WP3oool300000200oooo001R
0?ooo`800000=03oool00`000000oooo0?ooo`2J0?ooo`@000008`3oool006@0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2F0?ooo`@000009`3oool006D0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3oool006H0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool006L0oooo0P00000_0?ooo`030000003o
ool0oooo08X0oooo1000000c0?ooo`00J@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
08<0oooo1000000j0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0
oooo1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo
100000120?ooo`00K@3oool2000002T0oooo00<000000?ooo`3oool0M`3oool4000004H0oooo001_
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0M@3oool3000004X0oooo001`0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0L@3oool4000004d0oooo001a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool400000540oooo001b0?ooo`800000
8`3oool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool007@0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M0?ooo`030000003oool0oooo05H0oooo
1000001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000
001/0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04h0oooo1000001`
0?ooo`00O03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo0`00001d0?oo
o`00O@3oool2000001P0oooo00<000000?ooo`3oool0A`3oool4000007L0oooo001o0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4000007/0oooo00200?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0?`3oool4000007l0oooo00210?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0>`3oool4000008<0oooo00220?ooo`8000004`3oool00`00
0000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0/0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X
0?ooo`@00000UP3oool008P0oooo0P00000=0?ooo`030000003oool0oooo02D0oooo0`00002J0?oo
o`00RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo1000002M0?ooo`00
R`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000002Q0?ooo`00S03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000002U0?ooo`00S@3oool2
000000L0oooo00<000000?ooo`3oool05P3oool400000:T0oooo002?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04P3oool400000:d0oooo002@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03`3oool300000;40oooo002A0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool400000;@0oooo002B0?ooo`050000003oool0oooo0?ooo`000000
2@3oool400000;P0oooo002C0?ooo`80000000<0oooo0000003oool0103oool400000;`0oooo002E
0?ooo`80000000<0oooo0000000000000P0000300?ooo`00UP3oool200000<@0oooo003o0?oooed0
oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0
oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .5166 .67351 .51018 Mtetra
.67351 .51018 .67902 .5166 .69055 .51313 .68508 .50668 Mtetra
.68508 .50668 .69055 .51313 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50372 Mtetra
.66797 .50372 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50372 .66238 .4972 Mtetra
.66238 .4972 .66797 .50372 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50128 .61629 .49474 Mtetra
.61629 .49474 .62206 .50128 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47065 Mtetra
.6396 .47065 .64536 .47736 .65708 .47373 .65136 .46699 Mtetra
.65136 .46699 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47065 .63379 .46388 Mtetra
.63379 .46388 .6396 .47065 .65136 .46699 .64558 .46019 Mtetra
.64558 .46019 .65136 .46699 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60444 .46445 Mtetra
.60444 .46445 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60444 .46445 .59847 .45763 Mtetra
.59847 .45763 .60444 .46445 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44065 Mtetra
.56849 .44065 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .42541 Mtetra
.61603 .42541 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44065 .5623 .43364 Mtetra
.5623 .43364 .56849 .44065 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .426 Mtetra
.58604 .426 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .42541 .60998 .41828 Mtetra
.60998 .41828 .61603 .42541 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43042 Mtetra
.54424 .43042 .55051 .43744 .5623 .43364 .55607 .42659 Mtetra
.664 .741 .908 r
.55607 .42659 .5623 .43364 .57415 .42983 .56794 .42275 Mtetra
.56794 .42275 .57415 .42983 .58604 .426 .57987 .41889 Mtetra
.57987 .41889 .58604 .426 .59799 .42215 .59185 .41501 Mtetra
.59185 .41501 .59799 .42215 .60998 .41828 .60388 .41111 Mtetra
.664 .741 .907 r
.60388 .41111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.663 .741 .908 r
.52611 .42718 .53247 .43423 .54424 .43042 .53792 .42335 Mtetra
.53792 .42335 .54424 .43042 .55607 .42659 .54978 .41952 Mtetra
.663 .742 .909 r
.54978 .41952 .55607 .42659 .56794 .42275 .56169 .41567 Mtetra
.663 .743 .909 r
.56169 .41567 .56794 .42275 .57987 .41889 .57366 .4118 Mtetra
.664 .743 .909 r
.57366 .4118 .57987 .41889 .59185 .41501 .58567 .40789 Mtetra
.665 .743 .909 r
.58567 .40789 .59185 .41501 .60388 .41111 .59774 .40394 Mtetra
.665 .743 .908 r
.59774 .40394 .60388 .41111 .61597 .40719 .60986 .39997 Mtetra
.665 .742 .908 r
.60986 .39997 .61597 .40719 .6281 .40326 .62203 .39598 Mtetra
.664 .742 .908 r
.62203 .39598 .6281 .40326 .64029 .39931 .63425 .39199 Mtetra
.664 .741 .907 r
.63425 .39199 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.663 .741 .908 r
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42394 Mtetra
.50792 .42394 .51436 .431 .52611 .42718 .51971 .42012 Mtetra
.661 .741 .91 r
.51971 .42012 .52611 .42718 .53792 .42335 .53155 .41634 Mtetra
.659 .743 .912 r
.53155 .41634 .53792 .42335 .54978 .41952 .54345 .41261 Mtetra
.658 .747 .916 r
.54345 .41261 .54978 .41952 .56169 .41567 .5554 .40888 Mtetra
.66 .752 .918 r
.5554 .40888 .56169 .41567 .57366 .4118 .5674 .40508 Mtetra
.664 .757 .919 r
.5674 .40508 .57366 .4118 .58567 .40789 .57945 .40114 Mtetra
.668 .758 .918 r
.57945 .40114 .58567 .40789 .59774 .40394 .59155 .39706 Mtetra
.67 .755 .915 r
.59155 .39706 .59774 .40394 .60986 .39997 .6037 .3929 Mtetra
.669 .75 .911 r
.6037 .3929 .60986 .39997 .62203 .39598 .6159 .38875 Mtetra
.667 .746 .909 r
.6159 .38875 .62203 .39598 .63425 .39199 .62816 .38464 Mtetra
.665 .743 .908 r
.62816 .38464 .63425 .39199 .64653 .38798 .64048 .38057 Mtetra
.664 .741 .907 r
.64048 .38057 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42836 Mtetra
.46627 .42836 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.663 .741 .908 r
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42068 Mtetra
.662 .741 .909 r
.48966 .42068 .49618 .42777 .50792 .42394 .50143 .41688 Mtetra
.657 .741 .912 r
.50143 .41688 .50792 .42394 .51971 .42012 .51326 .41322 Mtetra
.647 .743 .919 r
.51326 .41322 .51971 .42012 .53155 .41634 .52513 .40981 Mtetra
.635 .752 .933 r
.52513 .40981 .53155 .41634 .54345 .41261 .53707 .40668 Mtetra
.626 .77 .949 r
.53707 .40668 .54345 .41261 .5554 .40888 .54906 .40365 Mtetra
.632 .798 .962 r
.54906 .40365 .5554 .40888 .5674 .40508 .56111 .4003 Mtetra
.653 .822 .964 r
.56111 .4003 .5674 .40508 .57945 .40114 .5732 .39633 Mtetra
.678 .828 .956 r
.5732 .39633 .57945 .40114 .59155 .39706 .58534 .39173 Mtetra
.691 .815 .941 r
.58534 .39173 .59155 .39706 .6037 .3929 .59752 .38682 Mtetra
.689 .79 .927 r
.59752 .38682 .6037 .3929 .6159 .38875 .60974 .38199 Mtetra
.68 .766 .916 r
.60974 .38199 .6159 .38875 .62816 .38464 .62203 .37745 Mtetra
.671 .751 .911 r
.62203 .37745 .62816 .38464 .64048 .38057 .63437 .37317 Mtetra
.666 .744 .908 r
.63437 .37317 .64048 .38057 .65284 .37651 .64678 .36901 Mtetra
.664 .742 .908 r
.64678 .36901 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.664 .741 .907 r
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42836 .45963 .42126 Mtetra
.663 .741 .908 r
.45963 .42126 .46627 .42836 .47794 .42452 .47134 .4174 Mtetra
.661 .74 .909 r
.47134 .4174 .47794 .42452 .48966 .42068 .48309 .41359 Mtetra
.654 .74 .913 r
.48309 .41359 .48966 .42068 .50143 .41688 .49489 .41 Mtetra
.633 .74 .926 r
.49489 .41 .50143 .41688 .51326 .41322 .50675 .40697 Mtetra
.587 .746 .952 r
.50675 .40697 .51326 .41322 .52513 .40981 .51866 .40488 Mtetra
.508 .764 .988 r
.51866 .40488 .52513 .40981 .53707 .40668 .53064 .4037 Mtetra
.404 .789 .99 r
.53064 .4037 .53707 .40668 .54906 .40365 .54269 .40264 Mtetra
.346 .811 .923 r
.54269 .40264 .54906 .40365 .56111 .4003 .5548 .40053 Mtetra
.417 .864 .876 r
.5548 .40053 .56111 .4003 .5732 .39633 .56696 .39653 Mtetra
.58 .941 .905 r
.56696 .39653 .5732 .39633 .58534 .39173 .57914 .39064 Mtetra
.71 .96 .945 r
.57914 .39064 .58534 .39173 .59752 .38682 .59134 .3837 Mtetra
.745 .906 .949 r
.59134 .3837 .59752 .38682 .60974 .38199 .60357 .37686 Mtetra
.722 .832 .933 r
.60357 .37686 .60974 .38199 .62203 .37745 .61587 .37093 Mtetra
.692 .78 .918 r
.61587 .37093 .62203 .37745 .63437 .37317 .62823 .36594 Mtetra
.674 .753 .911 r
.62823 .36594 .63437 .37317 .64678 .36901 .64066 .36151 Mtetra
.666 .744 .908 r
.64066 .36151 .64678 .36901 .65924 .3649 .65316 .3573 Mtetra
.664 .741 .907 r
.65316 .3573 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .41411 Mtetra
.662 .741 .908 r
.45294 .41411 .45963 .42126 .47134 .4174 .46468 .41026 Mtetra
.655 .739 .912 r
.46468 .41026 .47134 .4174 .48309 .41359 .47646 .4066 Mtetra
.63 .736 .925 r
.47646 .4066 .48309 .41359 .49489 .41 .48829 .40364 Mtetra
.552 .729 .957 r
.48829 .40364 .49489 .41 .50675 .40697 .50017 .40228 Mtetra
.328 .687 .98 r
.50017 .40228 .50675 .40697 .51866 .40488 .51211 .40324 Mtetra
0 .458 .717 r
.51211 .40324 .51866 .40488 .53064 .4037 .52413 .40585 Mtetra
.367 0 0 r
.52413 .40585 .53064 .4037 .54269 .40264 .53626 .40799 Mtetra
.332 0 0 r
.53626 .40799 .54269 .40264 .5548 .40053 .54847 .40756 Mtetra
.18 0 0 r
.54847 .40756 .5548 .40053 .56696 .39653 .56072 .40354 Mtetra
0 0 0 r
.56072 .40354 .56696 .39653 .57914 .39064 .57297 .39593 Mtetra
.57297 .39593 .57914 .39064 .59134 .3837 .5852 .38573 Mtetra
.738 .989 .8 r
.5852 .38573 .59134 .3837 .60357 .37686 .59742 .37503 Mtetra
.801 .952 .917 r
.59742 .37503 .60357 .37686 .61587 .37093 .60969 .36597 Mtetra
.745 .846 .926 r
.60969 .36597 .61587 .37093 .62823 .36594 .62205 .35923 Mtetra
.695 .778 .915 r
.62205 .35923 .62823 .36594 .64066 .36151 .63451 .35409 Mtetra
.672 .75 .909 r
.63451 .35409 .64066 .36151 .65316 .3573 .64703 .34966 Mtetra
.665 .743 .908 r
.64703 .34966 .65316 .3573 .66571 .35313 .65962 .34543 Mtetra
.664 .741 .907 r
.65962 .34543 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.663 .741 .908 r
.43448 .4108 .44126 .41798 .45294 .41411 .4462 .40691 Mtetra
.66 .74 .909 r
.4462 .40691 .45294 .41411 .46468 .41026 .45797 .4031 Mtetra
.641 .737 .918 r
.45797 .4031 .46468 .41026 .47646 .4066 .46978 .39982 Mtetra
.57 .724 .946 r
.46978 .39982 .47646 .4066 .48829 .40364 .48162 .39819 Mtetra
.305 .646 .968 r
.48162 .39819 .48829 .40364 .50017 .40228 .4935 .39988 Mtetra
.353 0 0 r
.4935 .39988 .50017 .40228 .51211 .40324 .50545 .4054 Mtetra
.595 .056 0 r
.50545 .4054 .51211 .40324 .52413 .40585 .51753 .4119 Mtetra
.52 .033 .041 r
.51753 .4119 .52413 .40585 .53626 .40799 .52973 .41519 Mtetra
.351 0 0 r
.52973 .41519 .53626 .40799 .54847 .40756 .54202 .41411 Mtetra
.149 0 0 r
.54202 .41411 .54847 .40756 .56072 .40354 .55436 .41008 Mtetra
0 0 0 r
.55436 .41008 .56072 .40354 .57297 .39593 .56671 .40308 Mtetra
.56671 .40308 .57297 .39593 .5852 .38573 .57903 .39168 Mtetra
.658 .899 .563 r
.57903 .39168 .5852 .38573 .59742 .37503 .59127 .37702 Mtetra
.844 .998 .782 r
.59127 .37702 .59742 .37503 .60969 .36597 .60352 .36331 Mtetra
.825 .928 .901 r
.60352 .36331 .60969 .36597 .62205 .35923 .61585 .35343 Mtetra
.736 .819 .916 r
.61585 .35343 .62205 .35923 .63451 .35409 .6283 .34689 Mtetra
.685 .763 .911 r
.6283 .34689 .63451 .35409 .64703 .34966 .64086 .34202 Mtetra
.668 .745 .908 r
.64086 .34202 .64703 .34966 .65962 .34543 .65348 .33767 Mtetra
.664 .741 .907 r
.65348 .33767 .65962 .34543 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41918 Mtetra
.38116 .41918 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40357 Mtetra
.663 .741 .908 r
.42766 .40357 .43448 .4108 .4462 .40691 .43941 .39966 Mtetra
.655 .739 .911 r
.43941 .39966 .4462 .40691 .45797 .4031 .4512 .39596 Mtetra
.617 .73 .927 r
.4512 .39596 .45797 .4031 .46978 .39982 .46303 .39329 Mtetra
.454 .684 .964 r
.46303 .39329 .46978 .39982 .48162 .39819 .47488 .3936 Mtetra
0 .361 .771 r
.47488 .3936 .48162 .39819 .4935 .39988 .48674 .39909 Mtetra
.654 .1 0 r
.48674 .39909 .4935 .39988 .50545 .4054 .4987 .40851 Mtetra
.584 .058 0 r
.4987 .40851 .50545 .4054 .51753 .4119 .51083 .41448 Mtetra
0 0 0 r
.51083 .41448 .51753 .4119 .52973 .41519 .52309 .41103 Mtetra
.786 .871 .911 r
.52309 .41103 .52973 .41519 .54202 .41411 .5354 .40277 Mtetra
.653 .651 .836 r
.5354 .40277 .54202 .41411 .55436 .41008 .54776 .3987 Mtetra
.533 .595 .861 r
.54776 .3987 .55436 .41008 .56671 .40308 .56022 .39883 Mtetra
.667 .855 .972 r
.56022 .39883 .56671 .40308 .57903 .39168 .5727 .39414 Mtetra
.841 .997 .767 r
.5727 .39414 .57903 .39168 .59127 .37702 .58506 .37997 Mtetra
.9 .983 .718 r
.58506 .37997 .59127 .37702 .60352 .36331 .59731 .36228 Mtetra
.892 .957 .835 r
.59731 .36228 .60352 .36331 .61585 .35343 .60961 .3485 Mtetra
.789 .857 .901 r
.60961 .3485 .61585 .35343 .6283 .34689 .62206 .33993 Mtetra
.704 .778 .909 r
.62206 .33993 .6283 .34689 .64086 .34202 .63463 .33437 Mtetra
.672 .748 .908 r
.63463 .33437 .64086 .34202 .65348 .33767 .64729 .32986 Mtetra
.665 .742 .907 r
.64729 .32986 .65348 .33767 .66617 .33341 .66002 .32554 Mtetra
.664 .741 .907 r
.66002 .32554 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26817 Mtetra
.83087 .26817 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45392 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41918 .37415 .412 Mtetra
.37415 .412 .38116 .41918 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40357 .42077 .39627 Mtetra
.662 .74 .908 r
.42077 .39627 .42766 .40357 .43941 .39966 .43255 .39236 Mtetra
.65 .737 .913 r
.43255 .39236 .43941 .39966 .4512 .39596 .44438 .38878 Mtetra
.587 .72 .935 r
.44438 .38878 .4512 .39596 .46303 .39329 .45622 .3868 Mtetra
.302 .61 .954 r
.45622 .3868 .46303 .39329 .47488 .3936 .46806 .38909 Mtetra
.457 0 0 r
.46806 .38909 .47488 .3936 .48674 .39909 .47991 .3978 Mtetra
.681 .135 0 r
.47991 .3978 .48674 .39909 .4987 .40851 .49188 .40838 Mtetra
.102 .657 .774 r
.49188 .40838 .4987 .40851 .51083 .41448 .5041 .4076 Mtetra
.879 .786 .755 r
.5041 .4076 .51083 .41448 .52309 .41103 .51644 .38918 Mtetra
.775 .609 .673 r
.51644 .38918 .52309 .41103 .5354 .40277 .52872 .36782 Mtetra
.598 .455 .657 r
.52872 .36782 .5354 .40277 .54776 .3987 .54101 .36369 Mtetra
.383 .309 .649 r
.54101 .36369 .54776 .3987 .56022 .39883 .55351 .37684 Mtetra
.329 .339 .719 r
.55351 .37684 .56022 .39883 .5727 .39414 .56616 .3871 Mtetra
.75 .786 .882 r
.56616 .3871 .5727 .39414 .58506 .37997 .57869 .37965 Mtetra
.942 .934 .76 r
.57869 .37965 .58506 .37997 .59731 .36228 .59101 .36073 Mtetra
.926 .923 .788 r
.59101 .36073 .59731 .36228 .60961 .3485 .60332 .34365 Mtetra
.829 .862 .87 r
.60332 .34365 .60961 .3485 .62206 .33993 .61576 .33302 Mtetra
.724 .786 .902 r
.61576 .33302 .62206 .33993 .63463 .33437 .62835 .32669 Mtetra
.677 .751 .907 r
.62835 .32669 .63463 .33437 .64729 .32986 .64105 .32198 Mtetra
.666 .742 .907 r
.64105 .32198 .64729 .32986 .66002 .32554 .65381 .31761 Mtetra
.664 .741 .907 r
.65381 .31761 .66002 .32554 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26817 .82521 .25974 Mtetra
.82521 .25974 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45392 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43949 Mtetra
.26481 .43949 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42037 Mtetra
.32114 .42037 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .41261 Mtetra
.34401 .41261 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40478 Mtetra
.36709 .40478 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39688 Mtetra
.39036 .39688 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.663 .741 .907 r
.40207 .3929 .40904 .40022 .42077 .39627 .41383 .38892 Mtetra
.661 .74 .908 r
.41383 .38892 .42077 .39627 .43255 .39236 .42565 .38499 Mtetra
.647 .736 .914 r
.42565 .38499 .43255 .39236 .44438 .38878 .4375 .38148 Mtetra
.566 .71 .939 r
.4375 .38148 .44438 .38878 .45622 .3868 .44936 .37996 Mtetra
.21 .546 .93 r
.44936 .37996 .45622 .3868 .46806 .38909 .4612 .3835 Mtetra
.497 0 0 r
.4612 .3835 .46806 .38909 .47991 .3978 .47303 .3939 Mtetra
.565 .005 0 r
.47303 .3939 .47991 .3978 .49188 .40838 .48503 .40384 Mtetra
.777 .858 .91 r
.48503 .40384 .49188 .40838 .5041 .4076 .49734 .39587 Mtetra
.886 .716 .665 r
.49734 .39587 .5041 .4076 .51644 .38918 .5098 .36432 Mtetra
.696 .55 .685 r
.5098 .36432 .51644 .38918 .52872 .36782 .52207 .35217 Mtetra
.639 .583 .776 r
.52207 .35217 .52872 .36782 .54101 .36369 .53437 .348 Mtetra
.442 .474 .797 r
.53437 .348 .54101 .36369 .55351 .37684 .54678 .35183 Mtetra
0 .08 .601 r
.54678 .35183 .55351 .37684 .56616 .3871 .55951 .37517 Mtetra
.546 .595 .854 r
.55951 .37517 .56616 .3871 .57869 .37965 .57217 .37489 Mtetra
.907 .842 .769 r
.57217 .37489 .57869 .37965 .59101 .36073 .58458 .35655 Mtetra
.917 .855 .765 r
.58458 .35655 .59101 .36073 .60332 .34365 .59693 .3377 Mtetra
.838 .83 .839 r
.59693 .3377 .60332 .34365 .61576 .33302 .6094 .32574 Mtetra
.735 .78 .889 r
.6094 .32574 .61576 .33302 .62835 .32669 .62202 .31888 Mtetra
.68 .75 .904 r
.62202 .31888 .62835 .32669 .64105 .32198 .63475 .31403 Mtetra
.666 .742 .907 r
.63475 .31403 .64105 .32198 .65381 .31761 .64756 .3096 Mtetra
.664 .741 .907 r
.64756 .3096 .65381 .31761 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .29201 Mtetra
.69937 .29201 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .2741 Mtetra
.75214 .2741 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23516 .44007 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43949 .25742 .43247 Mtetra
.25742 .43247 .26481 .43949 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42037 .3139 .4132 Mtetra
.3139 .4132 .32114 .42037 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .41261 .33683 .40538 Mtetra
.33683 .40538 .34401 .41261 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40478 .35996 .39749 Mtetra
.35996 .39749 .36709 .40478 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39688 .3833 .38952 Mtetra
.3833 .38952 .39036 .39688 .40207 .3929 .39504 .38551 Mtetra
.663 .741 .907 r
.39504 .38551 .40207 .3929 .41383 .38892 .40684 .3815 Mtetra
.661 .74 .908 r
.40684 .3815 .41383 .38892 .42565 .38499 .41869 .37754 Mtetra
.647 .735 .914 r
.41869 .37754 .42565 .38499 .4375 .38148 .43057 .374 Mtetra
.567 .707 .936 r
.43057 .374 .4375 .38148 .44936 .37996 .44246 .37245 Mtetra
.245 .546 .927 r
.44246 .37245 .44936 .37996 .4612 .3835 .45431 .37597 Mtetra
0 .116 .629 r
.45431 .37597 .4612 .3835 .47303 .3939 .46615 .38636 Mtetra
0 .155 .665 r
.46615 .38636 .47303 .3939 .48503 .40384 .47815 .39629 Mtetra
.758 .769 .862 r
.47815 .39629 .48503 .40384 .49734 .39587 .49051 .38828 Mtetra
.918 .76 .67 r
.49051 .38828 .49734 .39587 .5098 .36432 .50305 .35665 Mtetra
.82 .775 .811 r
.50305 .35665 .5098 .36432 .52207 .35217 .51539 .34445 Mtetra
.664 .741 .907 r
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.249 .54 .923 r
.52772 .34025 .53437 .348 .54678 .35183 .54014 .34405 Mtetra
.79 .337 0 r
.54014 .34405 .54678 .35183 .55951 .37517 .55286 .36741 Mtetra
.505 .68 .945 r
.55286 .36741 .55951 .37517 .57217 .37489 .56555 .3671 Mtetra
.875 .782 .755 r
.56555 .3671 .57217 .37489 .58458 .35655 .57803 .3487 Mtetra
.879 .782 .75 r
.57803 .3487 .58458 .35655 .59693 .3377 .59044 .32979 Mtetra
.818 .781 .817 r
.59044 .32979 .59693 .3377 .6094 .32574 .60296 .31778 Mtetra
.731 .763 .878 r
.60296 .31778 .6094 .32574 .62202 .31888 .61563 .31088 Mtetra
.679 .746 .902 r
.61563 .31088 .62202 .31888 .63475 .31403 .6284 .30599 Mtetra
.666 .742 .906 r
.6284 .30599 .63475 .31403 .64756 .3096 .64125 .30153 Mtetra
.664 .741 .907 r
.64125 .30153 .64756 .3096 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .29201 .69322 .28378 Mtetra
.69322 .28378 .69937 .29201 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .2741 .74616 .26572 Mtetra
.74616 .26572 .75214 .2741 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24266 Mtetra
.81375 .24266 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23516 .44007 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .42541 Mtetra
.24997 .42541 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41769 Mtetra
.27248 .41769 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .3981 Mtetra
.32959 .3981 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39749 .35279 .39014 Mtetra
.35279 .39014 .35996 .39749 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .3815 .39979 .37402 Mtetra
.662 .74 .908 r
.39979 .37402 .40684 .3815 .41869 .37754 .41167 .37001 Mtetra
.65 .736 .912 r
.41167 .37001 .41869 .37754 .43057 .374 .42359 .36633 Mtetra
.59 .712 .928 r
.42359 .36633 .43057 .374 .44246 .37245 .43552 .36427 Mtetra
.366 .593 .933 r
.43552 .36427 .44246 .37245 .45431 .37597 .44741 .36649 Mtetra
0 .285 .786 r
.44741 .36649 .45431 .37597 .46615 .38636 .45928 .37517 Mtetra
0 .226 .747 r
.45928 .37517 .46615 .38636 .47815 .39629 .47126 .38572 Mtetra
.557 .628 .878 r
.47126 .38572 .47815 .39629 .49051 .38828 .48356 .38486 Mtetra
.915 .859 .771 r
.48356 .38486 .49051 .38828 .50305 .35665 .4961 .36626 Mtetra
.753 .888 .483 r
.4961 .36626 .50305 .35665 .51539 .34445 .5086 .3447 Mtetra
.429 .871 .879 r
.5086 .3447 .51539 .34445 .52772 .34025 .521 .34047 Mtetra
.74 .227 0 r
.521 .34047 .52772 .34025 .54014 .34405 .5335 .35361 Mtetra
.671 .245 .228 r
.5335 .35361 .54014 .34405 .55286 .36741 .54618 .36384 Mtetra
.76 .901 .939 r
.54618 .36384 .55286 .36741 .56555 .3671 .55884 .35626 Mtetra
.849 .731 .733 r
.55884 .35626 .56555 .3671 .57803 .3487 .57137 .33716 Mtetra
.83 .718 .741 r
.57137 .33716 .57803 .3487 .59044 .32979 .58386 .31991 Mtetra
.782 .734 .808 r
.58386 .31991 .59044 .32979 .60296 .31778 .59646 .30913 Mtetra
.716 .742 .872 r
.59646 .30913 .60296 .31778 .61563 .31088 .60918 .30269 Mtetra
.676 .742 .9 r
.60918 .30269 .61563 .31088 .6284 .30599 .622 .29786 Mtetra
.666 .741 .906 r
.622 .29786 .6284 .30599 .64125 .30153 .63488 .29338 Mtetra
.664 .741 .907 r
.63488 .29338 .64125 .30153 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27549 Mtetra
.68702 .27549 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26642 Mtetra
.71345 .26642 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26572 .74014 .25726 Mtetra
.74014 .25726 .74616 .26572 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24266 .80795 .234 Mtetra
.80795 .234 .81375 .24266 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23328 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .42541 .24247 .41828 Mtetra
.24247 .41828 .24997 .42541 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41769 .26503 .4105 Mtetra
.26503 .4105 .27248 .41769 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .3981 .32229 .39075 Mtetra
.32229 .39075 .32959 .3981 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37402 .39268 .36648 Mtetra
.663 .74 .908 r
.39268 .36648 .39979 .37402 .41167 .37001 .40459 .36241 Mtetra
.655 .737 .91 r
.40459 .36241 .41167 .37001 .42359 .36633 .41655 .35855 Mtetra
.619 .721 .919 r
.41655 .35855 .42359 .36633 .43552 .36427 .42853 .35572 Mtetra
.492 .647 .926 r
.42853 .35572 .43552 .36427 .44741 .36649 .4405 .3559 Mtetra
.24 .455 .867 r
.4405 .3559 .44741 .36649 .45928 .37517 .45243 .36131 Mtetra
.13 .314 .781 r
.45243 .36131 .45928 .37517 .47126 .38572 .46441 .37068 Mtetra
.343 .428 .805 r
.46441 .37068 .47126 .38572 .48356 .38486 .47661 .37657 Mtetra
.642 .722 .906 r
.47661 .37657 .48356 .38486 .4961 .36626 .48905 .37295 Mtetra
0 0 0 r
.48905 .37295 .4961 .36626 .5086 .3447 .50158 .36448 Mtetra
.403 .055 .257 r
.50158 .36448 .5086 .3447 .521 .34047 .51413 .36024 Mtetra
.491 .136 .292 r
.51413 .36024 .521 .34047 .5335 .35361 .52673 .36023 Mtetra
.072 0 0 r
.52673 .36023 .5335 .35361 .54618 .36384 .5394 .35536 Mtetra
.837 .77 .788 r
.5394 .35536 .54618 .36384 .55884 .35626 .55205 .34092 Mtetra
.802 .668 .716 r
.55205 .34092 .55884 .35626 .57137 .33716 .56463 .32294 Mtetra
.779 .67 .743 r
.56463 .32294 .57137 .33716 .58386 .31991 .57722 .3089 Mtetra
.743 .702 .813 r
.57722 .3089 .58386 .31991 .59646 .30913 .5899 .30011 Mtetra
.697 .729 .875 r
.5899 .30011 .59646 .30913 .60918 .30269 .60268 .29436 Mtetra
.671 .738 .901 r
.60268 .29436 .60918 .30269 .622 .29786 .61554 .28966 Mtetra
.665 .74 .906 r
.61554 .28966 .622 .29786 .63488 .29338 .62846 .28516 Mtetra
.664 .741 .907 r
.62846 .28516 .63488 .29338 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27549 .68077 .26712 Mtetra
.68077 .26712 .68702 .27549 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26642 .70729 .25797 Mtetra
.70729 .25797 .71345 .26642 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36648 .38551 .35888 Mtetra
.663 .741 .907 r
.38551 .35888 .39268 .36648 .40459 .36241 .39746 .35475 Mtetra
.66 .739 .908 r
.39746 .35475 .40459 .36241 .41655 .35855 .40945 .35072 Mtetra
.642 .729 .912 r
.40945 .35072 .41655 .35855 .42853 .35572 .42149 .34721 Mtetra
.581 .689 .915 r
.42149 .34721 .42853 .35572 .4405 .3559 .43353 .34537 Mtetra
.455 .579 .889 r
.43353 .34537 .4405 .3559 .45243 .36131 .44556 .3469 Mtetra
.346 .44 .815 r
.44556 .3469 .45243 .36131 .46441 .37068 .45761 .3523 Mtetra
.372 .402 .763 r
.45761 .3523 .46441 .37068 .47661 .37657 .46977 .35869 Mtetra
.468 .467 .774 r
.46977 .35869 .47661 .37657 .48905 .37295 .48211 .36184 Mtetra
.57 .627 .869 r
.48211 .36184 .48905 .37295 .50158 .36448 .49461 .36056 Mtetra
.633 .862 .985 r
.49461 .36056 .50158 .36448 .51413 .36024 .50721 .35628 Mtetra
.752 .887 .94 r
.50721 .35628 .51413 .36024 .52673 .36023 .51987 .349 Mtetra
.78 .71 .786 r
.51987 .349 .52673 .36023 .5394 .35536 .53255 .33726 Mtetra
.758 .626 .714 r
.53255 .33726 .5394 .35536 .55205 .34092 .54521 .32222 Mtetra
.746 .616 .714 r
.54521 .32222 .55205 .34092 .56463 .32294 .55785 .30814 Mtetra
.733 .645 .762 r
.55785 .30814 .56463 .32294 .57722 .3089 .57053 .29795 Mtetra
.709 .692 .833 r
.57053 .29795 .57722 .3089 .5899 .30011 .58329 .29113 Mtetra
.681 .726 .884 r
.58329 .29113 .5899 .30011 .60268 .29436 .59612 .28599 Mtetra
.668 .738 .903 r
.59612 .28599 .60268 .29436 .61554 .28966 .60903 .28139 Mtetra
.664 .74 .907 r
.60903 .28139 .61554 .28966 .62846 .28516 .62199 .27687 Mtetra
.664 .741 .907 r
.62199 .27687 .62846 .28516 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26782 Mtetra
.6481 .26782 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26712 .67446 .25868 Mtetra
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35888 .37829 .35121 Mtetra
.37829 .35121 .38551 .35888 .39746 .35475 .39027 .34704 Mtetra
.662 .74 .908 r
.39027 .34704 .39746 .35475 .40945 .35072 .4023 .34289 Mtetra
.655 .736 .909 r
.4023 .34289 .40945 .35072 .42149 .34721 .41438 .33894 Mtetra
.631 .716 .908 r
.41438 .33894 .42149 .34721 .43353 .34537 .42649 .3357 Mtetra
.577 .659 .894 r
.42649 .3357 .43353 .34537 .44556 .3469 .43862 .33408 Mtetra
.509 .561 .844 r
.43862 .33408 .44556 .3469 .45761 .3523 .45077 .33482 Mtetra
.484 .48 .778 r
.45077 .33482 .45761 .3523 .46977 .35869 .46298 .33722 Mtetra
.51 .46 .736 r
.46298 .33722 .46977 .35869 .48211 .36184 .47531 .33915 Mtetra
.561 .483 .724 r
.47531 .33915 .48211 .36184 .49461 .36056 .48777 .33846 Mtetra
.619 .522 .723 r
.48777 .33846 .49461 .36056 .50721 .35628 .50035 .33413 Mtetra
.665 .549 .713 r
.50035 .33413 .50721 .35628 .51987 .349 .513 .32616 Mtetra
.69 .56 .702 r
.513 .32616 .51987 .349 .53255 .33726 .52568 .31554 Mtetra
.701 .572 .707 r
.52568 .31554 .53255 .33726 .54521 .32222 .53836 .30442 Mtetra
.704 .602 .74 r
.53836 .30442 .54521 .32222 .55785 .30814 .55107 .29496 Mtetra
.699 .652 .8 r
.55107 .29496 .55785 .30814 .57053 .29795 .56382 .28785 Mtetra
.685 .702 .861 r
.56382 .28785 .57053 .29795 .58329 .29113 .57663 .28238 Mtetra
.671 .73 .894 r
.57663 .28238 .58329 .29113 .59612 .28599 .58951 .27762 Mtetra
.665 .739 .905 r
.58951 .27762 .59612 .28599 .60903 .28139 .60246 .27306 Mtetra
.664 .74 .907 r
.60246 .27306 .60903 .28139 .62199 .27687 .61546 .26852 Mtetra
.664 .741 .907 r
.61546 .26852 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26782 .64166 .25938 Mtetra
.64166 .25938 .6481 .26782 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34704 .38301 .33928 Mtetra
.663 .741 .907 r
.38301 .33928 .39027 .34704 .4023 .34289 .39508 .33506 Mtetra
.661 .739 .907 r
.39508 .33506 .4023 .34289 .41438 .33894 .4072 .33089 Mtetra
.654 .731 .906 r
.4072 .33089 .41438 .33894 .42649 .3357 .41937 .32693 Mtetra
.635 .707 .899 r
.41937 .32693 .42649 .3357 .43862 .33408 .43157 .32355 Mtetra
.604 .654 .872 r
.43157 .32355 .43862 .33408 .45077 .33482 .44382 .32113 Mtetra
.579 .584 .822 r
.44382 .32113 .45077 .33482 .46298 .33722 .45611 .31962 Mtetra
.575 .533 .771 r
.45611 .31962 .46298 .33722 .47531 .33915 .46848 .31824 Mtetra
.591 .514 .736 r
.46848 .31824 .47531 .33915 .48777 .33846 .48095 .31579 Mtetra
.617 .517 .718 r
.48095 .31579 .48777 .33846 .50035 .33413 .4935 .31141 Mtetra
.642 .532 .714 r
.4935 .31141 .50035 .33413 .513 .32616 .50613 .3051 Mtetra
.662 .555 .723 r
.50613 .3051 .513 .32616 .52568 .31554 .5188 .29771 Mtetra
.675 .587 .749 r
.5188 .29771 .52568 .31554 .53836 .30442 .53151 .29043 Mtetra
.681 .634 .795 r
.53151 .29043 .53836 .30442 .55107 .29496 .54426 .28407 Mtetra
.679 .684 .848 r
.54426 .28407 .55107 .29496 .56382 .28785 .55706 .27867 Mtetra
.671 .72 .886 r
.55706 .27867 .56382 .28785 .57663 .28238 .56992 .27384 Mtetra
.666 .735 .902 r
.56992 .27384 .57663 .28238 .58951 .27762 .58285 .26923 Mtetra
.664 .74 .906 r
.58285 .26923 .58951 .27762 .60246 .27306 .59583 .26466 Mtetra
.664 .741 .907 r
.59583 .26466 .60246 .27306 .61546 .26852 .60888 .26009 Mtetra
.60888 .26009 .61546 .26852 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33928 .3757 .33145 Mtetra
.3757 .33145 .38301 .33928 .39508 .33506 .3878 .32718 Mtetra
.663 .74 .907 r
.3878 .32718 .39508 .33506 .4072 .33089 .39996 .32292 Mtetra
.661 .738 .907 r
.39996 .32292 .4072 .33089 .41937 .32693 .41217 .31869 Mtetra
.656 .73 .903 r
.41217 .31869 .41937 .32693 .43157 .32355 .42443 .31459 Mtetra
.647 .709 .893 r
.42443 .31459 .43157 .32355 .44382 .32113 .43674 .31075 Mtetra
.636 .673 .868 r
.43674 .31075 .44382 .32113 .45611 .31962 .4491 .3072 Mtetra
.629 .631 .834 r
.4491 .3072 .45611 .31962 .46848 .31824 .46152 .30374 Mtetra
.63 .6 .801 r
.46152 .30374 .46848 .31824 .48095 .31579 .47402 .29996 Mtetra
.638 .588 .782 r
.47402 .29996 .48095 .31579 .4935 .31141 .48658 .29554 Mtetra
.649 .594 .779 r
.48658 .29554 .4935 .31141 .50613 .3051 .49921 .29047 Mtetra
.66 .615 .793 r
.49921 .29047 .50613 .3051 .5188 .29771 .51189 .28509 Mtetra
.668 .649 .821 r
.51189 .28509 .5188 .29771 .53151 .29043 .52462 .27978 Mtetra
.67 .687 .856 r
.52462 .27978 .53151 .29043 .54426 .28407 .53741 .27476 Mtetra
.668 .717 .885 r
.53741 .27476 .54426 .28407 .55706 .27867 .55025 .27001 Mtetra
.666 .733 .9 r
.55025 .27001 .55706 .27867 .56992 .27384 .56316 .26538 Mtetra
.664 .739 .906 r
.56316 .26538 .56992 .27384 .58285 .26923 .57612 .2608 Mtetra
.664 .74 .907 r
.57612 .2608 .58285 .26923 .59583 .26466 .58915 .2562 Mtetra
.664 .741 .907 r
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .32292 .39265 .31494 Mtetra
.663 .74 .907 r
.39265 .31494 .39996 .32292 .41217 .31869 .4049 .31061 Mtetra
.663 .738 .906 r
.4049 .31061 .41217 .31869 .42443 .31459 .4172 .30629 Mtetra
.661 .733 .903 r
.4172 .30629 .42443 .31459 .43674 .31075 .42955 .302 Mtetra
.658 .721 .895 r
.42955 .302 .43674 .31075 .4491 .3072 .44197 .29776 Mtetra
.656 .704 .883 r
.44197 .29776 .4491 .3072 .46152 .30374 .45443 .29353 Mtetra
.656 .687 .868 r
.45443 .29353 .46152 .30374 .47402 .29996 .46696 .28921 Mtetra
.657 .678 .858 r
.46696 .28921 .47402 .29996 .48658 .29554 .47956 .28475 Mtetra
.66 .679 .857 r
.47956 .28475 .48658 .29554 .49921 .29047 .49221 .28014 Mtetra
.664 .691 .865 r
.49221 .28014 .49921 .29047 .51189 .28509 .50491 .27545 Mtetra
.665 .708 .879 r
.50491 .27545 .51189 .28509 .52462 .27978 .51768 .27076 Mtetra
.665 .724 .893 r
.51768 .27076 .52462 .27978 .53741 .27476 .5305 .26612 Mtetra
.665 .734 .901 r
.5305 .26612 .53741 .27476 .55025 .27001 .54339 .26151 Mtetra
.664 .739 .906 r
.54339 .26151 .55025 .27001 .56316 .26538 .55633 .25691 Mtetra
.664 .74 .907 r
.55633 .25691 .56316 .26538 .57612 .2608 .56934 .2523 Mtetra
.664 .741 .907 r
.56934 .2523 .57612 .2608 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31494 .38528 .3069 Mtetra
.38528 .3069 .39265 .31494 .4049 .31061 .39756 .30253 Mtetra
.664 .74 .907 r
.39756 .30253 .4049 .31061 .4172 .30629 .4099 .29814 Mtetra
.663 .739 .906 r
.4099 .29814 .4172 .30629 .42955 .302 .4223 .29373 Mtetra
.663 .737 .905 r
.4223 .29373 .42955 .302 .44197 .29776 .43475 .28932 Mtetra
.663 .733 .902 r
.43475 .28932 .44197 .29776 .45443 .29353 .44725 .28489 Mtetra
.663 .729 .899 r
.44725 .28489 .45443 .29353 .46696 .28921 .45982 .28043 Mtetra
.663 .727 .897 r
.45982 .28043 .46696 .28921 .47956 .28475 .47245 .27593 Mtetra
.664 .727 .896 r
.47245 .27593 .47956 .28475 .49221 .28014 .48513 .27138 Mtetra
.664 .73 .898 r
.48513 .27138 .49221 .28014 .50491 .27545 .49788 .26681 Mtetra
.664 .734 .902 r
.49788 .26681 .50491 .27545 .51768 .27076 .51068 .26222 Mtetra
.664 .737 .905 r
.51068 .26222 .51768 .27076 .5305 .26612 .52354 .25762 Mtetra
.664 .74 .906 r
.52354 .25762 .5305 .26612 .54339 .26151 .53647 .25301 Mtetra
.664 .74 .907 r
.53647 .25301 .54339 .26151 .55633 .25691 .54945 .24838 Mtetra
.664 .741 .907 r
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30253 .39017 .29439 Mtetra
.39017 .29439 .39756 .30253 .4099 .29814 .40254 .28995 Mtetra
.40254 .28995 .4099 .29814 .4223 .29373 .41497 .2855 Mtetra
.664 .74 .907 r
.41497 .2855 .4223 .29373 .43475 .28932 .42746 .28103 Mtetra
.42746 .28103 .43475 .28932 .44725 .28489 .44001 .27653 Mtetra
.664 .739 .906 r
.44001 .27653 .44725 .28489 .45982 .28043 .45261 .27202 Mtetra
.45261 .27202 .45982 .28043 .47245 .27593 .46527 .26748 Mtetra
.46527 .26748 .47245 .27593 .48513 .27138 .478 .26292 Mtetra
.478 .26292 .48513 .27138 .49788 .26681 .49078 .25833 Mtetra
.664 .74 .906 r
.49078 .25833 .49788 .26681 .51068 .26222 .50362 .25372 Mtetra
.664 .74 .907 r
.50362 .25372 .51068 .26222 .52354 .25762 .51652 .24909 Mtetra
.664 .741 .907 r
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28103 .42011 .2727 Mtetra
.42011 .2727 .42746 .28103 .44001 .27653 .43269 .26817 Mtetra
.43269 .26817 .44001 .27653 .45261 .27202 .44533 .26361 Mtetra
.664 .74 .907 r
.44533 .26361 .45261 .27202 .46527 .26748 .45803 .25903 Mtetra
.45803 .25903 .46527 .26748 .478 .26292 .4708 .25443 Mtetra
.664 .741 .907 r
.4708 .25443 .478 .26292 .49078 .25833 .48362 .24981 Mtetra
.48362 .24981 .49078 .25833 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26817 .42532 .25974 Mtetra
.42532 .25974 .43269 .26817 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25974 .41787 .25123 Mtetra
.41787 .25123 .42532 .25974 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24266 Mtetra
.41037 .24266 .41787 .25123 .43059 .24659 .42312 .23798 Mtetra
.42312 .23798 .43059 .24659 .44337 .24193 .43594 .23328 Mtetra
.43594 .23328 .44337 .24193 .45621 .23725 .44881 .22856 Mtetra
.44881 .22856 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24266 .4028 .234 Mtetra
.4028 .234 .41037 .24266 .42312 .23798 .41559 .22928 Mtetra
.41559 .22928 .42312 .23798 .43594 .23328 .42844 .22454 Mtetra
.42844 .22454 .43594 .23328 .44881 .22856 .44136 .21978 Mtetra
.44136 .21978 .44881 .22856 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22052 Mtetra
.40799 .22052 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22052 .40032 .21166 Mtetra
.40032 .21166 .40799 .22052 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20274 Mtetra
.39259 .20274 .40032 .21166 .41325 .20683 .40556 .19787 Mtetra
.40556 .19787 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20274 .38478 .19373 Mtetra
.38478 .19373 .39259 .20274 .40556 .19787 .39779 .18881 Mtetra
.39779 .18881 .40556 .19787 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15179 Mtetra
.36602 .15179 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15179 .3579 .14231 Mtetra
.3579 .14231 .36602 .15179 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000/@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000]02Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool30000
0;H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0;H0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000_02Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo
00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool300000;h0ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX0;d0ZKgX0P00
000/0:Vmj0030000003oool0oooo03T0oooo000/0?ooo`040:Vmj0000000000000000;l0ZKgX0`00
00020:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0>@3oool002/0oooo0P00002o
0:Vmj0<000001@2Y_NP00`000000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03P0oooo000Y0?oo
o`800000RP2Y_NP30:Vmi`D0ZKgX1@2Y_NLW0:Vmj0<000002@2Y_NP00`000000ZKgX0:Vmj00Z0:Vm
j0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool20000
08P0ZKgX1P2Y_NL20:Vmj0<0ZKcW1@2Y_NL20:Vmj0<0ZKgW7`2Y_NP2000000d0ZKgX00<000000:Vm
j02Y_NP0:@2Y_NP00`000000oooo0?ooo`0g0?ooo`00703oool01P3ooml0W4P004RLg`3oool0gia8
001d_`L0oooo00<000000?ooo`000000P`2Y_NP:0:Vmi`H0ZKcW2P2Y_NL20:Vmj0<0ZKgW5P2Y_NP3
00000100ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0f0?ooo`00703oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y_NP0O02Y
_NP:0:Vmi`D0ZK_V1@2Y_>L50:ZkiP/0ZKgW4P2Y_NP3000001<0ZKgX00<000000:Vmj02Y_NP0:P2Y
_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
1@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX07T0ZKgX2P2Y_NL30:Vji@D0ZK_V
1@2Z^N@:0:ZkiPX0ZKgW2P2Y_NP3000001L0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo
0?ooo`0e0?ooo`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000
oooo0?ooo`030?ooogT0ZKgX2P2Y_NL60:Vji@80ZK_V0`2Z]N450:Zii080Z[_V0`2[]n850:ZkiPD0
Z[cV1@2Y_NL60:Vmj0<000006`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03@0
oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`8000001@3oool00`00
0000ZKgX0:Vmj01a0:Vmj0X0ZKgW2P2Y^^D60:Zeh@@0Z[WT1P2[]n820:ZkiP<0ZkSR1@2Z_>H20:Vm
i`<0Z[gW0P2Y_NP3000001l0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0c0?oo
o`00703oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000002Y_NP0ZKgX0740ZKgX1@2Y_NL:0:Vji@D0ZK3M1@2Z]N450:^_f`D0ZkOR1P2[^>84
0:ZliP@0Z[gW0`00000R0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<`3oool0
01`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l60?ooo`030000003oool0oooo00L0ooooL`2Y
_NP30:Vmi`80ZK[V1`2Y^^D30:R]f`D0ZK3M0P2Z]N430:^VdPD0ZjoK1@2][mT50:^hhPD0Zk[T0`00
00020:Zmib@0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0b0?ooo`007@3oool0
1@3ookl0M00000000000B9`0gooo00H0oooo00<000000?ooo`3oool0203ooomc0:Vmj0D0ZK[V102Y
^^D60:R]f`@0ZK3M1P2[Y]820:^_f`<0[Z;;1@2][mT20:^hhP<0[k?L0P2[^^@2000000030:^ji02[
_>L0ZkcW00<0ZkcW902Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo0380oooo000W
0?ooo`030000003oool0oooo00X0ooooKP2Y_NP50:VkiP@0ZK[V2P2X[M/50:RMb`D0ZjKB1@2^X//5
0:f_f@@0[k?L0`000000102[^^@0[[WR0:jihP2^^N850:^li`D0Z[gW7P2Y_NP00`000000ZKgX0:Vm
j00Y0:Vmj0030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0ooooJ@2Y_NP5
0:Vli`D0ZK_V102W[mh70:R]f`<0YYS7102XWL/40:^VdP80[9Jo1@2^X//20:f_f@<0/ZK<0`000002
0:ncg0H0[[WR0P2[_>L30:^liPD0Z[gW7P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0
oooo0300oooo000W0?ooo`030000003oool0oooo00`0ooooIP2Y_NP30:Vmi`D0ZKcW0P2Y^nH30:Nd
hP@0YjoN102X[M/50:JHa`D0Z9g;0P2[Y]830:bF_`D0[Z;;0P2bY/`3000000030;:Vc02_/m`0[k?L
00<0]K7E1@2^^N860:^liPD0Z[gW7P2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo
0300oooo000W0?ooo`8000003P3ooomS0:Vmj0H0ZKgW102Y_>L60:NdhP@0YjoN102SU/P50:JHa`@0
Z9g;1P2/U[l30:jRb`<00000102bY/`60;Fae@D0/[[O1@2[_>H50:Zmial0ZKgX00<000000:Vmj02Y
_NP0:02Y_NP00`000000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooof<0ZKgX
1@2Y_NL50:Rhi@D0YkCR1@2QVLd40:>Fb0@0YYS70P2XWL/30:V>^@D0[9Jo0`0000020;BJ_@@0/ZK<
0P2kYL<40;Fae@80_[?@1@2b^]l50:fmiP@0Z[gW7`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000
003oool0oooo02h0oooo000W0?ooo`030000003oool0oooo00l0ooooH`2Y_NP50:Vki`D0Z;SU0P2W
]>830:6Qe@@0XIW=102SU/P40:JHa`D0ZHji0P2/U[l3000000H0]9Zm0P2bY/`40;^U``80]K7E102n
/m020;:jg`<0]kgO1@2]_NH40:Zmial0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?oo
o`0^0?ooo`009`3oool200000140oooo00<000000:Vmj02Y_NP0GP2Y_NP20:Vli`D0ZK_W102X^>D5
0:6Qe@D0XIW=102SU/P20:JHa`80Y8Rf0`2YS[T300000080[9Jo0P2cT[@50;BJ_@H0^jG31P2n/m06
0;Nmg`80[KgV0`2]_^H40:Zmial0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0]
0?ooo`009P3oool2000001<0oooo00<000000:Vmj02Y_NP0F`2Y_NP50:Vli`@0ZK_W1@2R[=h50:6Q
e@@0XIW=102SU/P40:B8]P<000000P2YS[T20:bF_`<0/i:d102dV[d20;jM]P@0^jG30P37Zkh40;jc
d080b;_>1@2g_Ml50:fniP80Z[gW0`2Z_NPO0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?oo
o`3oool0;03oool000T0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0gia8
1@0000000`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool0
4`3oool00`000000ZKgX0:Vmj01K0:Vmj0D0ZKcW102U]N@50::/gP@0XJ7E102QVLd509f4]`030:B8
]P000000000000D0ZHji1P2cT[@20;BJ_@<0_Yff0`2kYL<40<N[_P80_[?@1038^lh20;Nmg`<0^l?P
102]_^H60:Zmj1h0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0:0?ooo`050=nL
B000000000000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?oo
o`030?oOW0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<0
00000?ooo`3oool0503oool00`000000ZKgX0:Vmj01K0:Vmj0D0Yk[W102U]N@40::/gP@0XJ7E1@2G
Pk`209f4]`<000000`2TR;H30:V>^@80/8nc1@2cT[@00`2dV[d0_Yff0;jM]P030;jM]P030;^U``37
Zkh0aj^n00<0aj^n1P38^lh60;_3h0@0[[oW1@2Z_NPO0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<0
00000?ooo`3oool0203oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0703oool000P0oooo
00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo00<0omnL04P0001d_ol0203oool00`2o
M000M;oo0?ooo`050?ooo`8000005P3ooomI0:Vmj0D0ZKcX1@2W^^L30:Fei0D0U9GB102CR<D309N3
_0<000000P2MQ;L40:B8]P80ZHji0`2`Sk<50;>B]0H0_Yff1P37Zkh00`3D]kd0b;_>0<RkcP020<Rk
cP80dLOA0`2k`n030;c7h`@0[[oW1@2Z_NPO0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?oo
o`3oool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono
07@0B02Lgol01@3oool00`3ookl0M00004RLg`070?ooo`030;md001d_ol0oooo00D0oooo00<00000
0?ooo`3oool05`3ooomH0:Vmj0D0ZKcX0P2W^^L30::diP<0VZOO102DUM8409>8a@<0000000<0Uh>l
09f4]`2MQ;L00`2MQ;L30:B8]PD0/8nc1@2cT[@00`32X;H0_Yff0;jM]P030;jM]P030<f[]`37Zkh0
aj^n0080aj^n0`3D]kd20<RkcP@0dLOA1P2lan<40:g0j0D0Z[gX7P2Y_NP00`000000ZKgX0:Vmj00X
0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0okmd0018
W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018W=l0oooo0?oOW01804P0W=oo0?oo
o`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo01P0ooooF02Y_NP40:Vlj0D0X[CV102JYml3
09BEdP0409>8a@0000000000000000D0Uh>l102MQ;L20:B8]P80ZXbf1@2`Sk<30;>B]080`Z2f102n
WKH20<f[]`<0aj^n103D]kd50=77d@80e]CF0`2lan<30;W9iP@0[L3X1@2Z_NPN0:Vmj0030000002Y
_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02L
gol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0
B02Lgol0oono07@000030000000307Boo`3oool0oooo00@0oooo0P00000K0?oooeL0ZKgX1@2W^nL5
0::diP@0VZOO0`00000409>8a@@0Uh>l102MQ;L0102TR;H0ZXbf0:Z<]P2ZS;H50;2?/`80/i:d0`32
X;H30;jM]P@0cJ^g0P37Zkh40=Bg_@040>78_`3Aam40dLOA0=77d@@0e]CF1@2ibNH20:g0j0<0[;oX
1@2Z_NPN0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0M000
000000020000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?oo
o`030000003oool0oooo01/0ooooF02Y_NP40:Nki`@0X[CV00@0VZOO00000000000000000`2DUM84
09>8a@@0Uh>l102MQ;L50:Z<]P@0/8nc00<0/i:d0<:P]P32X;H00`32X;H20;jM]P@0cJ^g00<0aj^n
0=Bg_@3D]kd00P3D]kd30>78_`030=77d@3Fe=H0e]CF0080e]CF0P3Dg=h40;W9iPH0[;oX0P2Z_NPQ
0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P
0?ooo`00203oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo
0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool00`000000oooo0?ooo`0L0?oooeP0ZKgX102Q]nP0
102CZ>@0000000000000000408:?f080Ng[7102CR<D409N3_0D0WXFi102ZS;H40;2?/`H0`Z2f00<0
_Yff0<f[]`3=ZkL00`3=ZkL40=Bg_@@0hLRo103Fe=H40=CLgP@0]<OX1@2/_nPS0:Vmj0030000002Y
_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`2oM000M;oo0?ooo`0O0?ooo`002@3oool0
1@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P000000000000007Boo`020?ooo`060=nL
B000000000000000000007@0_ooo1@3oool00`000000oooo0?ooo`0M0?oooe<0ZKgX1@2W_>P20:6g
j08000000`2CZ>@408:?f0<0Ng[71022MK`408mk^@@0WXFi1@2ZS;H20;2?/`80akG91@32X;H60<f[
]`040=Vk^`3D]kd0e;Nm0=Bg_@@0hLRo00<0j][30=KDeP3Fe=H0103Dg=h20<WKiP@0]<OX1@2[_^PS
0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3oool01P3OW4P0000000000000
0000001d0;oooa`0oooo000U0?ooo`8000007`3ooomC0:Vmj0<0YkcX0`0000020:6gj0@0TjST1022
SmP207]ja`@0PWFl102?NkT409j5^@D0ZXbf00@0/8nc0<Neb@37]LT0akG91032X;H20=K5b@@0cJ^g
0`3I^k/00`3D]kd0hLRo0>78_`020>78_`<0j][3103Dg=h40<WKiP80]<OX0P2_`nT50:^nj2<0ZKgX
00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0V0?ooo`009@3oool00`000000oooo0?oo
o`0O0?oooe80ZKgX0`0000020:Nlj0@0U;3Z0`1dU><408:?f080Ng[71022MK`408mk^@D0WXFi102Z
S;H50<Neb@80`Z2f0`3FaLT30<f[]`@0fK^k103Qb;l40>[J``80kNc91P39fnH50:o3j@D0Z[kX8P2Y
_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02D0oooo000U0?ooo`030000003oool0
oooo0200ooooCP2Y_NP3000000030:Vmj02T^^T0Y;[Y00<0Y;[Y102D/>X307BDh`<0F73@0`1kN/L4
089e_0@0Sg^i102NQKT20:Z<]P<0`>?`1037]LT00`32X;H0e/G90=K5b@030=K5b@030<f[]`3I^k/0
fK^k00<0fK^k00@0glS10>78_`3Qb;l0hLRo0`3Zf/<20>g/b@80i?CE0`39fnH30;cAjP80[l?Y0`2/
_nP50:Znj280ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0U0?ooo`00903oool2
000002<0ooooBP2Y_NP3000000D0Z;gX1@2T^^T309B`jP<0M9CS101HL=000`1OI/<0Ng[7089e_003
089e_0@0Sg^i102NQKT50<3Sl0@0akG91P3FaLT50=Vk^`<0glS100@0hLRo0>[J``3Zf/<0j][30P3]
k<T40>Cde@D0_=7Z1P2/_nP20:Znj2D0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`0T0?ooo`00903oool00`000000oooo0?ooo`0S0?ooodH0ZKgX0`0000050:Vmj0@0Z;gX1@2N^>/3
07fUk@0303edg@1dU><0M9CS00<0F73@0P1OI/<4089e_0@0Sg^i0P2NQKT30:;Lo0D0`>?`0P37]LT2
0:>EaP@0e/G90P32i_030=Vk^`@0glS10`3Zf/<20>g/b@@0i?CE0`3CkNH40;77jPD0[;oX:02Y_NP0
0`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02<0oooo000T0?ooo`030000003oool0oooo
02@0oooo@P2Y_NP3000000T0ZKgX102W_>P509jhj`<0OJG]0P0mM=d305Q`d0<0GfK30`1gMlH408mk
^@H0X]cl1030ho040:>EaP03075ic03FaLT0e/G900<0`^K`0`3I^k/40=o8`@80j=O40P3]k<T40>Cd
e@80dngV0`2nf>d40;77jPD0Z[kX9`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo
02<0oooo000T0?ooo`8000009P3oooln0:Vmj0<000003@2Y_NP40:Nlj0@0W[S[101mYNd203edg@03
025@a`1HL=00F73@0080GfK3101gMlH5096PgP<0jl:[1@2bS:l40:>EaP80LGW<1@32i_000`3I^k/0
glS10=o8`@020=o8`@<0j=O40P3akl820>Kk]`80dngV1@2nf>d50:c0j@D0Z[kX9`2Y_NP00`000000
ZKgX0:Vmj00W0:Vmj0030000003oool0oooo0280oooo000S0?ooo`800000:03ooolk0:Vmj0800000
4@2Y_NP20:Nlj080Y[cY102G]^d305fGkP80?GCM0P0QD<L00`1HL=00GfK305mV``0507MgaP80TJ3N
00<0j]_50>_2Z`3[`Z/00P3[`Z/00`3R]jX0/Xb_0;:<[`020;:<[`D0VGBX0`1aNL`30<;Vl0@0glS1
0`3Xel@20?7_`P80i_^g0P3HolP20<gcjP<0_]S]0P2aan/50:c0jB`0ZKgX00<000000:Vmj02Y_NP0
9`2Y_NP00`000000oooo0?ooo`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3o
gi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X
0?ooocH0ZKgX0`00000C0:Vmj0D0Y[cY102G]^d305fGkP040018b@0mM=d08E37025@a`<0GfK3101g
MlH00`2T^>L0j]_50>[Ka@040>_2Z`030>:gZP2bS:l0/Xb_0080/Xb_00<0aY^/09UdZ02IM:P00P2I
M:P0101RCjH0LGW<075ic00059T3086^l@80glS10`3Xel@20?7_`P80i_^g0P3HolP40<gcjPD0/LO[
0P2/`>T30:Znj2`0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0Q0?ooo`00303o
ool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo00H0oooo00<000000?ooo`3oool0:P3ooolb0:Vmj0<000005`2Y_NP40:Jlj@D0TKC_0`0nRnd0
1P00B<T08E37025@a`0QD<L0Efg>05mV``80MgO60`2T^>L20>[Ka@<0jl:[0P3R]jX30;:<[`80aY^/
102IM:P2069?YP03075ic00059T001BI00<0PJka103Xel@20?7_`P030>Kk]`3HolP0cO?Z00<0cO?Z
0`2he>h40;77j`H0Z[kX:`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj08000008@3oool000`0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0
oooo;P2Y_NP3000001/0ZKgX1@2U_>T4096dk`<0?X_]00<004S9000i_`0QD<L00P1GKLh40:Bhi`80
j]_5103[`Z/30>:gZP80/Xb_0P36Vj`409UdZ0<0HTnV0`0059T308^HfP80j=O40P3akl800`3VnkL0
Z>J@0;cmc0020;cmc0H0^=C^102[`>T50:Znj2`0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000
oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0203oool00`2o
M000M;oo0?ooo`050?ooo`030000003oool0oooo02`0oooo:P2Y_NP3000001l0ZKgX1@2U_>T3096d
k`@0?X_]0P00>Kl0100QD<L0Efg>05M]cP1GKLh20:Bhi`80j]_50`3[`Z/40>:gZP040;:<[`36Vj`0
aY^/0<JK[0@0VGBX101RCjH00`1DE[P001BI08^HfP0308^HfP80lNo20P3Gol@20;cmc0@0_^Ob1@2^
a>X40:_0jC40ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool0
1`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8
B02Lgol01P3oool00`000000oooo0?ooo`0]0?ooobH0ZKgX0`00000S0:Vmj0D0YKcY0`2@]O0303F;
kP03000MX@00>Kl003Vo00@0Efg>0`3ZflD30>_2Z`@0h[NZ00@0/Xb_0<JK[036Vj`0aY^/1@2IM:P3
069?YP80E5Jh00<001BI08^HfP2;V=X00`2obN400`3Gol@0_?g<0;kWlP030;kWlP<0/<[]102^a>X5
0:Znj300ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0N0?ooo`00303oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00`3ookl0M000000000020000000307Boo`3o
ool0oooo00D0oooo00<000000?ooo`3oool0;P3ooolR0:Vmj0<000009`2Y_NP50:Flj@<0T;G`0`0e
Rnh3000i_`D0SZ3P0`3[`Z/50>:gZPD0aY^/102IM:P3069?YP<0E5Jh102obN400`3Gol@000000;Ge
l@020;Gel@H0/<[]2@2Z_^P`0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07@3o
ool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol0
2@3oool200000340oooo7P2Y_NP3000002/0ZKgX1@2V_>T309Jhk`<0CIcd00<002NZ000i_`2>X>00
0`2>X>020<;4g080jl:[1@3R]jX00`3QbL40aY^/0<JK[0020<JK[0@0VGBX101RCjH305AF^080_lWQ
00<0eoo40;Gel@2`d?00102`d?030;3:k@<0ZkoY102Z_^Pe0:Vmj0030000002Y_NP0ZKgX02H0ZKgX
00<000000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`03
0;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3ooolK0:Vmj0800000;`2Y_NP50:Jlj@<0
U[S_0`1=W?@010009jX003Vo08jPh02>X>040<;4g0D0h[NZ0P3QbL440<JK[0@0VGBX101RCjH405AF
^0040:[Jn02Dl>L0[M?d0:gCm0D0/=3`1P2[_nTi0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<00000
0?ooo`3oool0703oool000d0oooo00D0oono07@00000000004RL0=ooo`050?ooo`060=nLB0000000
00000000000007@0_ooo1@3oool00`000000oooo0?ooo`0b0?oooaL0ZKgX0`00000b0:Vmj080Y[cY
0`2W_NT309fjk@@0M:of1@32a=`20<KKj0<0h[NZ0`3QbL440<JK[0@0VGBX101RCjH40:[Jn0D0[M?d
1@2[`NX30:^oj@<0Z[gX>02Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01/0oooo
000R0?ooo`800000=03ooolC0:Vmj0<00000=@2Y_NP60:Nmj@<0WK[]102A^O830<;4g0<0a]_X0`3R
]jX40>79`@<0aY^/0P2IM:P30:NVeP@0R9SL0P2Zf_P30:OBmP@0Zl;[1@2[`NX50:Zmj3T0ZKgX00<0
00000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0d
0?ooo`l0ZKgX0`00000i0:Vmj0D0YkgY102T_>/4096ilPH0a]_X00<0h[NZ0>79`@3QbL400`3QbL43
0<JK[0D0YjKF1@28V=`50:W1j`@0Zl;[1@2Z_^P40:Zmj3X0ZKgX00<000000:Vmj02Y_NP09P2Y_NP0
0`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX
00P0ZKgX0`00000m0:Vmj0D0Z;gX102T_>/50:6lk0@0a]_X1P3QbL420<JK[080bMkY1@2WY]H208RH
g0<0Z<3[1@2Y`N/90:Znj3h0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0<0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3oool00`00
0000oooo0?ooo`0g0?ooo`H0ZKgX0`0000110:Vmj0D0Z;gX102W_NT50:6lk0<0X[g]00<06ZS60>79
`@3QbL400`3QbL450<WNj@@0YjKF00<0Z;oZ0:S0j`2X`>/00`2X`>/50:Vnj0@0Z[kX@P2Y_NP00`00
0000ZKgX0:Vmj00V0:Vmj0800000303oool02P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo
0=nLB000M;l40?ooo`008@3oool2000003X0oooo0P2Y_NP3000004X0ZKgX2@2W_NT50::mk@@0YKk[
00D0X/3^0<WNj@39g^T0bMkY0:;0kP050:RojPT0ZKkXA`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000DP2Y_NP50:Nmj@D0Z;gY102U
_^/50:Rnj@<0Z;oZ0P2Y_NP50:Vnj4/0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?oo
o`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool0
0240oooo00<000000?ooo`3oool0=P3oool2000000<0ooooF02Y_NP50:Rmj@@0ZKgX1@2X_^T50:Vm
j080ZKkXC@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00T0oooo00/0omnL04P0
M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool2000003@0oooo
0`0000060?oookX0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`080?ooo`0;0?oO
W01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<00000
0?ooo`3oool0<03oool3000000T0oooo^`2Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0
oooo00H0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0
_ooo00<0oooo00040?ooo`0=0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3o
okl0M01809cOo`040?ooo`050=nLB000000000000000B02Lgol01`3oool00`000000oooo0?ooo`0]
0?ooo`<000003P3ooonj0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool0
2`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo00030?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?ooo`070?noM000B9`0
gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00000B0?oookT0ZKgX
00<000000:Vmj02Y_NP08@2Y_NP3000000030?ooo`000000oooo00P0oooo00<0omnL04P0M02oool0
0P3oool01@3ookl0M00000000000B9`0gooo00@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`050?ooo`030;md0018W=l0oooo00L0oooo00<0_g@007Boo`3oool0103oool20000
02T0oooo0`00000F0?oookT0ZKgX00<000000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?oo
o`3oool05@3oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd
0018W03Oool01`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J
0?oookT0ZKgX00<000000:Vmj02Y_NP0602Y_NP3000000P0oooo00<000000?ooo`3oool05@3oool0
00<0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02Lgol00P3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R0?ooo`<0
00007P3oooni0:Vmj0030000002Y_NP0ZKgX01<0ZKgX1000000<0?ooo`030000003oool0oooo01@0
oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000M;l0oooo
0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo0`00
000R0?oookP0ZKgX00<000000:Vmj02Y_NP03`2Y_NP0103oool0000000000000000@0?ooo`030000
003oool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`07
0?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2000002H0oooo00<00000
0:Vmj02Y_NP0]@2Y_NP00`000000ZKgX0:Vmj00:0:Vmj080oooo0`00000C0?ooo`030000003oool0
oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo203oool01P3o_g@004RL0=oo
o`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3ooong0:Vmj0030000002Y_NP0ZKgX00L0
ZKgX1000000F0?ooo`030000003oool0oooo01@0oooo00040?ooo`050?oo_`1d000000000018W03O
ool0103oool00`3OW4P00000000000030000000307Boo`3oool0gia800<0000000<0001d0;ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`<00000;P3ooonf0:Vmj0030000002Y_NP0ZKgX00D0
ZKgX0P00000J0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo01D0oooo
0`00000b0?oookH0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000003oool0oooo01@0
oooo000O0?ooo`8000004`3oool3000003H0oooo]@2Y_NP300000200oooo00<000000?ooo`3oool0
503oool001l0oooo00<000000?ooo`3oool03`3oool3000003X0oooo/02Y_NP3000000<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0<
0?ooo`<00000?P3ooon/0:Vmj0<000001P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01<0oooo000O0?ooo`030000003oool0oooo00T0oooo0`0000120?ooojL0ZKgX1000000:0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool001h0oooo0P0000090?ooo`80
0000AP3ooonR0:Vmj0040?ooo`0000000000000000l0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`<00000B@3ooonN0:Vmj004
0?ooo`0000000000000001<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?oo
o`007P3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000ZKgX0:Vmj02F0:Vmj003
0?ooo`0000000000008000005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`030000003oool0000000800000D@3oool00`000000ZKgX0:Vmj02C0:Vmj0<00000
6`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo000N0?ooo`800000E@3o
ool00`000000ZKgX0:Vmj02@0:Vmj08000007`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01<0oooo000C0?ooo`030?oOW01807@0_ooo00T0oooo00<000000?ooo`3oool0E03oool0
0`000000ZKgX0:Vmj02<0:Vmj0030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000EP3ooon90:Vm
j08000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0E03ooon50:Vmj0800000:`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00d0oooo
00<000000?ooo`3oool0E03ooon00:Vmj0800000<03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0oooo00<000000?ooo`3oool0E03o
oomk0:Vmj0<00000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C
0?ooo`030?oOW01807@0_ooo00l0oooo00<000000?ooo`3oool0E03ooomg0:Vmj0<00000=`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo000A0?ooo`050;md000004P0W;nL
04P0M02oool0403oool2000005D0ooooLP2Y_NP3000003`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0B0?ooo`004P3oool0103o_g@000000000M02ooolB0?ooo`030000003oool0
oooo05<0ooooKP2Y_NP300000400oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B
0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003oool0oooo05<0ooooJ@2Y_NP40000
04<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`00:P3oool00`000000
oooo0?ooo`1C0?ooofD0ZKgX0`0000180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool04@3oool002/0oooo0P00001D0?ooof00ZKgX00@0oooo0000000000000000C03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000]0?ooo`030000003oool0oooo0580oooo
G02Y_NP4000004l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;P3o
ool00`000000oooo0?ooo`1B0?oooeP0ZKgX0`00001D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04@3oool002l0oooo00<000000?ooo`3oool0DP3ooomC0:Vmj0040?ooo`000000
0000000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`00<03oool0
0`000000oooo0?ooo`1B0?ooodl0ZKgX1000001L0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00340oooo0P00001C0?ooodX0ZKgX00@0oooo0000000000000000H03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000c0?ooo`030000003oool0oooo
0540ooooAP2Y_NP4000006@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`00=03oool00`000000oooo0?ooo`1A0?oood80ZKgX0`00001Y0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool003D0oooo00<000000?ooo`3oool0D@3ooolm0:Vmj0040?oo
o`0000000000000006`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00
=P3oool200000580oooo>@2Y_NP400000700oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`00>03oool00`000000oooo0?ooo`1@0?ooocD0ZKgX0`00001e0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0403oool003T0oooo00<000000?ooo`3oool0D@3oool_
0:Vmj0040?ooo`0000000000000007T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A0?ooob/0ZKgX1000001l0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool003/0oooo00<000000?ooo`3oool0D@3ooolW0:Vm
j0<00000P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo000l0?ooo`80
0000DP3ooolR0:Vmj0040?ooo`0000000000000008D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0?0?ooo`00?P3oool00`000000oooo0?ooo`1@0?oooah0ZKgX100000290?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool003l0oooo00<000000?ooo`3oool0
D03ooolJ0:Vmj0<00000S@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo
00100?ooo`030000003oool0oooo0500oooo5P2Y_NP300000940oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`00@@3oool200000540oooo4P2Y_NP3000009D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`1?0?oo
o`d0ZKgX0`00002I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004@0
oooo00<000000?ooo`3oool0D03oool80:Vmj0<00000W@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo0500oooo102Y_NP300000:40oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00AP3oool200000540oooo0P00
002V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004P0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool004T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool004X0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03P3oool004/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004`0oooo0P00001;0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00CP3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0=0?ooo`00C`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`00D@3oool2000004H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo001C0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0[03oool01@000000oooo0?ooo`3oool0000000l0oooo001D0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00E@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool00000
3`3oool005H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2_0?ooo`030000003o
ool0000000l0oooo001G0?ooo`800000?`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
000000h0oooo001I0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0/@3oool20000
00h0oooo001J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0/@3oool2000000h0
oooo001K0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo
001L0?ooo`800000>P3oool00`000000oooo0?ooo`2]0?ooo`@00000403oool005h0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`2Y0?ooo`@00000503oool005l0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`2U0?ooo`@00000603oool00600oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`2Q0?ooo`@00000703oool00640oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`2N0?ooo`<00000803oool00680oooo0P00000d0?ooo`030000003o
ool0oooo09X0oooo1000000S0?ooo`00I03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo09H0oooo1000000W0?ooo`00I@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0980oooo1000000[0?ooo`00IP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo08h0
oooo1000000_0?ooo`00I`3oool2000002l0oooo00<000000?ooo`3oool0RP3oool4000003<0oooo
001Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0Q`3oool3000003L0oooo001Z
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0P`3oool4000003X0oooo001[0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0O`3oool4000003h0oooo001/0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0N`3oool400000480oooo001]0?ooo`800000
:@3oool00`000000oooo0?ooo`1g0?ooo`@00000AP3oool006l0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1e0?ooo`<00000BP3oool00700oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1a0?ooo`@00000C@3oool00740oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000D@3oool00780oooo0P00000S0?ooo`030000003oool0oooo06T0
oooo1000001E0?ooo`00M03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06D0oooo
1000001I0?ooo`00M@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo0`00
001M0?ooo`00MP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000001P
0?ooo`00M`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo1000001T0?oo
o`00N03oool2000001d0oooo00<000000?ooo`3oool0EP3oool4000006P0oooo001j0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool4000006`0oooo001k0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0CP3oool400000700oooo001l0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0B`3oool3000007@0oooo001m0?ooo`800000603oool00`00
0000oooo0?ooo`170?ooo`@00000M`3oool007l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`130?ooo`@00000N`3oool00800oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0o0?ooo`@00000O`3oool00840oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0k0?ooo`@00000P`3oool00880oooo0P00000C0?ooo`030000003oool0oooo03P0oooo0`000027
0?ooo`00Q03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo1000002:0?oo
o`00Q@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo1000002>0?ooo`00
QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0oooo1000002B0?ooo`00Q`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo1000002F0?ooo`00R03oool2
000000d0oooo00<000000?ooo`3oool09@3oool3000009X0oooo002:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool08P3oool4000009d0oooo002;0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool07P3oool400000:40oooo002<0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06P3oool400000:D0oooo002=0?ooo`8000001`3oool00`000000oooo0?oo
o`0F0?ooo`@00000Z@3oool008l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B
0?ooo`@00000[@3oool00900oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?oo
o`<00000/@3oool00940oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@0
0000]03oool00980oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000^03oool009<0oooo
0P0000000`3oool000000?ooo`040?ooo`@00000_03oool009D0oooo0P0000000`3oool000000000
000200000<00oooo002F0?ooo`800000a03oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0oooo
G@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51313 .68508 .50668 Mtetra
.68508 .50668 .69055 .51313 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49666 Mtetra
.6912 .49666 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49666 .68568 .49009 Mtetra
.68568 .49009 .6912 .49666 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50128 .61629 .49474 Mtetra
.61629 .49474 .62206 .50128 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47065 Mtetra
.6396 .47065 .64536 .47736 .65708 .47373 .65136 .46699 Mtetra
.65136 .46699 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47065 .63379 .46388 Mtetra
.63379 .46388 .6396 .47065 .65136 .46699 .64558 .46019 Mtetra
.64558 .46019 .65136 .46699 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46812 Mtetra
.59276 .46812 .59871 .47485 .61035 .47121 .60444 .46445 Mtetra
.60444 .46445 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46812 .58676 .46133 Mtetra
.58676 .46133 .59276 .46812 .60444 .46445 .59847 .45763 Mtetra
.59847 .45763 .60444 .46445 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67555 .4421 .66979 .43511 Mtetra
.66979 .43511 .67555 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44442 Mtetra
.55673 .44442 .5629 .45133 .57463 .44759 .56849 .44065 Mtetra
.56849 .44065 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .42541 Mtetra
.61603 .42541 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41769 Mtetra
.64011 .41769 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44442 .55051 .43745 Mtetra
.55051 .43745 .55673 .44442 .56849 .44065 .5623 .43365 Mtetra
.5623 .43365 .56849 .44065 .5803 .43686 .57415 .42984 Mtetra
.664 .741 .908 r
.57415 .42984 .5803 .43686 .59216 .43306 .58604 .42601 Mtetra
.58604 .42601 .59216 .43306 .60407 .42924 .59799 .42216 Mtetra
.59799 .42216 .60407 .42924 .61603 .42541 .60998 .41829 Mtetra
.664 .741 .907 r
.60998 .41829 .61603 .42541 .62805 .42155 .62203 .41441 Mtetra
.62203 .41441 .62805 .42155 .64011 .41769 .63413 .4105 Mtetra
.63413 .4105 .64011 .41769 .65223 .4138 .64628 .40659 Mtetra
.64628 .40659 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43424 Mtetra
.663 .741 .908 r
.53247 .43424 .53877 .44123 .55051 .43745 .54424 .43044 Mtetra
.54424 .43044 .55051 .43745 .5623 .43365 .55607 .42664 Mtetra
.663 .742 .909 r
.55607 .42664 .5623 .43365 .57415 .42984 .56795 .42282 Mtetra
.663 .743 .909 r
.56795 .42282 .57415 .42984 .58604 .42601 .57987 .41897 Mtetra
.664 .743 .909 r
.57987 .41897 .58604 .42601 .59799 .42216 .59185 .41509 Mtetra
.59185 .41509 .59799 .42216 .60998 .41829 .60389 .41118 Mtetra
.665 .743 .909 r
.60389 .41118 .60998 .41829 .62203 .41441 .61597 .40724 Mtetra
.665 .742 .908 r
.61597 .40724 .62203 .41441 .63413 .4105 .6281 .40329 Mtetra
.664 .742 .908 r
.6281 .40329 .63413 .4105 .64628 .40659 .64029 .39932 Mtetra
.664 .741 .907 r
.64029 .39932 .64628 .40659 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39137 Mtetra
.66483 .39137 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43482 Mtetra
.663 .741 .908 r
.50265 .43482 .50906 .44181 .52074 .43803 .51436 .43103 Mtetra
.662 .741 .908 r
.51436 .43103 .52074 .43803 .53247 .43424 .52611 .42725 Mtetra
.661 .742 .91 r
.52611 .42725 .53247 .43424 .54424 .43044 .53792 .42351 Mtetra
.659 .744 .913 r
.53792 .42351 .54424 .43044 .55607 .42664 .54979 .41981 Mtetra
.658 .748 .916 r
.54979 .41981 .55607 .42664 .56795 .42282 .5617 .4161 Mtetra
.66 .753 .919 r
.5617 .4161 .56795 .42282 .57987 .41897 .57366 .41232 Mtetra
.664 .757 .919 r
.57366 .41232 .57987 .41897 .59185 .41509 .58568 .40841 Mtetra
.667 .758 .918 r
.58568 .40841 .59185 .41509 .60389 .41118 .59775 .40437 Mtetra
.669 .756 .915 r
.59775 .40437 .60389 .41118 .61597 .40724 .60986 .40026 Mtetra
.669 .751 .912 r
.60986 .40026 .61597 .40724 .6281 .40329 .62203 .39614 Mtetra
.667 .747 .91 r
.62203 .39614 .6281 .40329 .64029 .39932 .63425 .39206 Mtetra
.665 .743 .908 r
.63425 .39206 .64029 .39932 .65253 .39535 .64653 .38801 Mtetra
.664 .742 .908 r
.64653 .38801 .65253 .39535 .66483 .39137 .65886 .38397 Mtetra
.664 .741 .907 r
.65886 .38397 .66483 .39137 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .4316 Mtetra
.663 .741 .908 r
.48449 .4316 .49099 .43861 .50265 .43482 .49618 .42781 Mtetra
.66 .741 .909 r
.49618 .42781 .50265 .43482 .51436 .43103 .50792 .42407 Mtetra
.655 .742 .914 r
.50792 .42407 .51436 .43103 .52611 .42725 .51971 .42049 Mtetra
.646 .746 .922 r
.51971 .42049 .52611 .42725 .53792 .42351 .53156 .41714 Mtetra
.636 .756 .935 r
.53156 .41714 .53792 .42351 .54979 .41981 .54346 .414 Mtetra
.631 .774 .949 r
.54346 .414 .54979 .41981 .5617 .4161 .55542 .41088 Mtetra
.637 .798 .96 r
.55542 .41088 .5617 .4161 .57366 .41232 .56743 .40746 Mtetra
.654 .817 .962 r
.56743 .40746 .57366 .41232 .58568 .40841 .57949 .40352 Mtetra
.675 .823 .955 r
.57949 .40352 .58568 .40841 .59775 .40437 .59159 .39906 Mtetra
.687 .812 .942 r
.59159 .39906 .59775 .40437 .60986 .40026 .60373 .3943 Mtetra
.688 .791 .929 r
.60373 .3943 .60986 .40026 .62203 .39614 .61593 .38955 Mtetra
.681 .77 .919 r
.61593 .38955 .62203 .39614 .63425 .39206 .62817 .38501 Mtetra
.673 .754 .912 r
.62817 .38501 .63425 .39206 .64653 .38801 .64048 .38071 Mtetra
.667 .746 .909 r
.64048 .38071 .64653 .38801 .65886 .38397 .65284 .37655 Mtetra
.665 .742 .908 r
.65284 .37655 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.664 .741 .907 r
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36837 Mtetra
.67775 .36837 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42836 Mtetra
.663 .741 .908 r
.46627 .42836 .47285 .4354 .48449 .4316 .47794 .42456 Mtetra
.659 .74 .91 r
.47794 .42456 .48449 .4316 .49618 .42781 .48966 .42085 Mtetra
.648 .74 .916 r
.48966 .42085 .49618 .42781 .50792 .42407 .50143 .41744 Mtetra
.624 .743 .932 r
.50143 .41744 .50792 .42407 .51971 .42049 .51325 .41463 Mtetra
.581 .755 .961 r
.51325 .41463 .51971 .42049 .53156 .41714 .52514 .4126 Mtetra
.517 .781 .992 r
.52514 .4126 .53156 .41714 .54346 .414 .53708 .41113 Mtetra
.45 .814 .995 r
.53708 .41113 .54346 .414 .55542 .41088 .5491 .40951 Mtetra
.424 .846 .957 r
.5491 .40951 .55542 .41088 .56743 .40746 .56118 .40696 Mtetra
.481 .89 .93 r
.56118 .40696 .56743 .40746 .57949 .40352 .5733 .403 Mtetra
.594 .938 .94 r
.5733 .403 .57949 .40352 .59159 .39906 .58545 .39761 Mtetra
.693 .948 .958 r
.58545 .39761 .59159 .39906 .60373 .3943 .59762 .39129 Mtetra
.732 .907 .955 r
.59762 .39129 .60373 .3943 .61593 .38955 .60982 .38481 Mtetra
.723 .845 .939 r
.60982 .38481 .61593 .38955 .62817 .38501 .62207 .37887 Mtetra
.698 .792 .923 r
.62207 .37887 .62817 .38501 .64048 .38071 .63439 .37373 Mtetra
.678 .761 .913 r
.63439 .37373 .64048 .38071 .65284 .37655 .64678 .36918 Mtetra
.668 .747 .909 r
.64678 .36918 .65284 .37655 .66527 .37245 .65924 .36494 Mtetra
.665 .742 .908 r
.65924 .36494 .66527 .37245 .67775 .36837 .67175 .36079 Mtetra
.664 .741 .907 r
.67175 .36079 .67775 .36837 .69028 .36426 .68433 .35665 Mtetra
.68433 .35665 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.663 .741 .908 r
.44798 .42511 .45464 .43218 .46627 .42836 .45963 .42128 Mtetra
.66 .74 .909 r
.45963 .42128 .46627 .42836 .47794 .42456 .47133 .41753 Mtetra
.647 .739 .916 r
.47133 .41753 .47794 .42456 .48966 .42085 .48308 .41415 Mtetra
.61 .737 .936 r
.48308 .41415 .48966 .42085 .50143 .41744 .49488 .41168 Mtetra
.516 .735 .973 r
.49488 .41168 .50143 .41744 .51325 .41463 .50673 .41078 Mtetra
.301 .702 .976 r
.50673 .41078 .51325 .41463 .52514 .4126 .51865 .41146 Mtetra
0 .556 .765 r
.51865 .41146 .52514 .4126 .53708 .41113 .53065 .41266 Mtetra
.166 0 0 r
.53065 .41266 .53708 .41113 .5491 .40951 .54274 .41284 Mtetra
.125 0 0 r
.54274 .41284 .5491 .40951 .56118 .40696 .5549 .41106 Mtetra
0 0 0 r
.5549 .41106 .56118 .40696 .5733 .403 .5671 .40707 Mtetra
.5671 .40707 .5733 .403 .58545 .39761 .57931 .40088 Mtetra
.48 .869 .678 r
.57931 .40088 .58545 .39761 .59762 .39129 .59153 .3927 Mtetra
.702 .984 .836 r
.59153 .3927 .59762 .39129 .60982 .38481 .60374 .38348 Mtetra
.784 .965 .921 r
.60374 .38348 .60982 .38481 .62207 .37887 .61598 .37476 Mtetra
.757 .876 .933 r
.61598 .37476 .62207 .37887 .63439 .37373 .62829 .36763 Mtetra
.709 .8 .921 r
.62829 .36763 .63439 .37373 .64678 .36918 .64068 .36207 Mtetra
.68 .76 .912 r
.64068 .36207 .64678 .36918 .65924 .36494 .65317 .35743 Mtetra
.668 .745 .908 r
.65317 .35743 .65924 .36494 .67175 .36079 .66571 .35316 Mtetra
.665 .742 .908 r
.66571 .35316 .67175 .36079 .68433 .35665 .67832 .34897 Mtetra
.664 .741 .907 r
.67832 .34897 .68433 .35665 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41799 Mtetra
.662 .74 .908 r
.44126 .41799 .44798 .42511 .45963 .42128 .45294 .41418 Mtetra
.652 .739 .913 r
.45294 .41418 .45963 .42128 .47133 .41753 .46467 .41062 Mtetra
.617 .734 .93 r
.46467 .41062 .47133 .41753 .48308 .41415 .47644 .40801 Mtetra
.503 .717 .968 r
.47644 .40801 .48308 .41415 .49488 .41168 .48825 .40745 Mtetra
.169 .61 .938 r
.48825 .40745 .49488 .41168 .50673 .41078 .50011 .40967 Mtetra
.3 0 0 r
.50011 .40967 .50673 .41078 .51865 .41146 .51207 .41345 Mtetra
.375 0 0 r
.51207 .41345 .51865 .41146 .53065 .41266 .52413 .41578 Mtetra
.173 0 0 r
.52413 .41578 .53065 .41266 .54274 .41284 .53628 .41476 Mtetra
0 0 0 r
.53628 .41476 .54274 .41284 .5549 .41106 .54849 .4113 Mtetra
.414 .863 .875 r
.54849 .4113 .5549 .41106 .5671 .40707 .56076 .40729 Mtetra
.464 .889 .887 r
.56076 .40729 .5671 .40707 .57931 .40088 .57307 .40272 Mtetra
.522 .913 .793 r
.57307 .40272 .57931 .40088 .59153 .3927 .58538 .39571 Mtetra
.654 .953 .735 r
.58538 .39571 .59153 .3927 .60374 .38348 .59765 .38531 Mtetra
.794 .998 .802 r
.59765 .38531 .60374 .38348 .61598 .37476 .60989 .37342 Mtetra
.829 .965 .893 r
.60989 .37342 .61598 .37476 .62829 .36763 .62217 .36308 Mtetra
.767 .864 .921 r
.62217 .36308 .62829 .36763 .64068 .36207 .63456 .35552 Mtetra
.705 .787 .915 r
.63456 .35552 .64068 .36207 .65317 .35743 .64705 .35004 Mtetra
.675 .753 .91 r
.64705 .35004 .65317 .35743 .66571 .35316 .65963 .3455 Mtetra
.666 .743 .908 r
.65963 .3455 .66571 .35316 .67832 .34897 .67227 .34123 Mtetra
.664 .741 .907 r
.67227 .34123 .67832 .34897 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.663 .741 .908 r
.42282 .4147 .42962 .42185 .44126 .41799 .43448 .41083 Mtetra
.659 .74 .91 r
.43448 .41083 .44126 .41799 .45294 .41418 .4462 .40707 Mtetra
.637 .736 .919 r
.4462 .40707 .45294 .41418 .46467 .41062 .45795 .40391 Mtetra
.553 .718 .95 r
.45795 .40391 .46467 .41062 .47644 .40801 .46973 .40262 Mtetra
.258 .622 .959 r
.46973 .40262 .47644 .40801 .48825 .40745 .48153 .40478 Mtetra
.318 0 0 r
.48153 .40478 .48825 .40745 .50011 .40967 .4934 .41009 Mtetra
.418 0 0 r
.4934 .41009 .50011 .40967 .51207 .41345 .5054 .41412 Mtetra
.266 .774 .8 r
.5054 .41412 .51207 .41345 .52413 .41578 .51753 .4112 Mtetra
.817 .853 .876 r
.51753 .4112 .52413 .41578 .53628 .41476 .52971 .40137 Mtetra
.742 .655 .764 r
.52971 .40137 .53628 .41476 .54849 .4113 .5419 .39118 Mtetra
.625 .534 .731 r
.5419 .39118 .54849 .4113 .56076 .40729 .55415 .38712 Mtetra
.519 .471 .743 r
.55415 .38712 .56076 .40729 .57307 .40272 .56653 .38922 Mtetra
.497 .535 .826 r
.56653 .38922 .57307 .40272 .58538 .39571 .57902 .39098 Mtetra
.692 .843 .955 r
.57902 .39098 .58538 .39571 .59765 .38531 .59146 .3858 Mtetra
.845 .994 .842 r
.59146 .3858 .59765 .38531 .60989 .37342 .60377 .37361 Mtetra
.879 .984 .826 r
.60377 .37361 .60989 .37342 .62217 .36308 .61604 .36008 Mtetra
.834 .919 .891 r
.61604 .36008 .62217 .36308 .63456 .35552 .6284 .34973 Mtetra
.745 .822 .912 r
.6284 .34973 .63456 .35552 .64705 .35004 .64089 .34283 Mtetra
.688 .765 .91 r
.64089 .34283 .64705 .35004 .65963 .3455 .65349 .33783 Mtetra
.669 .746 .908 r
.65349 .33783 .65963 .3455 .67227 .34123 .66617 .33344 Mtetra
.665 .742 .907 r
.66617 .33344 .67227 .34123 .68498 .337 .67892 .32916 Mtetra
.664 .741 .907 r
.67892 .32916 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31627 Mtetra
.7175 .31627 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30758 Mtetra
.74351 .30758 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .29881 Mtetra
.76977 .29881 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41918 Mtetra
.38116 .41918 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .4075 Mtetra
.662 .74 .908 r
.41596 .4075 .42282 .4147 .43448 .41083 .42765 .40361 Mtetra
.655 .739 .912 r
.42765 .40361 .43448 .41083 .4462 .40707 .4394 .39995 Mtetra
.614 .729 .928 r
.4394 .39995 .4462 .40707 .45795 .40391 .45117 .39736 Mtetra
.45 .682 .964 r
.45117 .39736 .45795 .40391 .46973 .40262 .46295 .39774 Mtetra
0 .425 .83 r
.46295 .39774 .46973 .40262 .48153 .40478 .47474 .40258 Mtetra
.449 0 0 r
.47474 .40258 .48153 .40478 .4934 .41009 .48662 .40904 Mtetra
.253 .754 .893 r
.48662 .40904 .4934 .41009 .5054 .41412 .49871 .40781 Mtetra
.869 .797 .777 r
.49871 .40781 .5054 .41412 .51753 .4112 .51093 .39167 Mtetra
.782 .623 .684 r
.51093 .39167 .51753 .4112 .52971 .40137 .52312 .37151 Mtetra
.606 .474 .675 r
.52312 .37151 .52971 .40137 .5419 .39118 .53529 .36742 Mtetra
.617 .507 .706 r
.53529 .36742 .5419 .39118 .55415 .38712 .54751 .36331 Mtetra
.54751 .36331 .55415 .38712 .56653 .38922 .55979 .35919 Mtetra
.374 .321 .67 r
.55979 .35919 .56653 .38922 .57902 .39098 .57236 .37122 Mtetra
.368 .383 .744 r
.57236 .37122 .57902 .39098 .59146 .3858 .58504 .37926 Mtetra
.742 .798 .897 r
.58504 .37926 .59146 .3858 .60377 .37361 .59754 .37231 Mtetra
.905 .944 .821 r
.59754 .37231 .60377 .37361 .61604 .36008 .60986 .35757 Mtetra
.882 .923 .847 r
.60986 .35757 .61604 .36008 .6284 .34973 .6222 .34445 Mtetra
.788 .847 .895 r
.6222 .34445 .6284 .34973 .64089 .34283 .63468 .3358 Mtetra
.706 .777 .907 r
.63468 .3358 .64089 .34283 .65349 .33783 .6473 .33015 Mtetra
.673 .749 .908 r
.6473 .33015 .65349 .33783 .66617 .33344 .66002 .32559 Mtetra
.665 .742 .907 r
.66002 .32559 .66617 .33344 .67892 .32916 .6728 .32125 Mtetra
.664 .741 .907 r
.6728 .32125 .67892 .32916 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31627 .71151 .30825 Mtetra
.71151 .30825 .7175 .31627 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30758 .7376 .29948 Mtetra
.7376 .29948 .74351 .30758 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .29881 .76394 .29064 Mtetra
.76394 .29064 .76977 .29881 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26817 Mtetra
.83087 .26817 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45392 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41918 .37415 .412 Mtetra
.37415 .412 .38116 .41918 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .4075 .40904 .40023 Mtetra
.662 .74 .908 r
.40904 .40023 .41596 .4075 .42765 .40361 .42077 .39634 Mtetra
.65 .737 .913 r
.42077 .39634 .42765 .40361 .4394 .39995 .43254 .39279 Mtetra
.589 .721 .935 r
.43254 .39279 .4394 .39995 .45117 .39736 .44433 .39078 Mtetra
.338 .626 .958 r
.44433 .39078 .45117 .39736 .46295 .39774 .4561 .39268 Mtetra
0 .282 .717 r
.4561 .39268 .46295 .39774 .47474 .40258 .46788 .39933 Mtetra
0 .309 .67 r
.46788 .39933 .47474 .40258 .48662 .40904 .47981 .40459 Mtetra
.821 .856 .874 r
.47981 .40459 .48662 .40904 .49871 .40781 .49202 .39453 Mtetra
.856 .695 .681 r
.49202 .39453 .49871 .40781 .51093 .39167 .50435 .36805 Mtetra
.617 .507 .707 r
.50435 .36805 .51093 .39167 .52312 .37151 .5165 .36395 Mtetra
.664 .741 .907 r
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57236 .37122 .56565 .34736 Mtetra
.124 .187 .658 r
.56565 .34736 .57236 .37122 .58504 .37926 .57845 .36571 Mtetra
.49 .534 .829 r
.57845 .36571 .58504 .37926 .59754 .37231 .59115 .36758 Mtetra
.869 .858 .828 r
.59115 .36758 .59754 .37231 .60986 .35757 .60357 .354 Mtetra
.896 .886 .815 r
.60357 .354 .60986 .35757 .6222 .34445 .61593 .33897 Mtetra
.817 .844 .869 r
.61593 .33897 .6222 .34445 .63468 .3358 .62842 .32872 Mtetra
.722 .782 .9 r
.62842 .32872 .63468 .3358 .6473 .33015 .64107 .32242 Mtetra
.677 .75 .906 r
.64107 .32242 .6473 .33015 .66002 .32559 .65382 .31767 Mtetra
.666 .742 .907 r
.65382 .31767 .66002 .32559 .6728 .32125 .66664 .31328 Mtetra
.664 .741 .907 r
.66664 .31328 .6728 .32125 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26817 .82521 .25974 Mtetra
.82521 .25974 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45392 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42037 Mtetra
.32114 .42037 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39688 Mtetra
.39036 .39688 .39736 .40417 .40904 .40023 .40207 .39291 Mtetra
.661 .74 .908 r
.40207 .39291 .40904 .40023 .42077 .39634 .41383 .389 Mtetra
.646 .736 .914 r
.41383 .389 .42077 .39634 .43254 .39279 .42563 .38551 Mtetra
.572 .712 .937 r
.42563 .38551 .43254 .39279 .44433 .39078 .43744 .38387 Mtetra
.278 .583 .943 r
.43744 .38387 .44433 .39078 .4561 .39268 .44921 .38665 Mtetra
0 .262 .726 r
.44921 .38665 .4561 .39268 .46788 .39933 .46099 .39408 Mtetra
.094 .531 .908 r
.46099 .39408 .46788 .39933 .47981 .40459 .47297 .39765 Mtetra
.866 .784 .768 r
.47297 .39765 .47981 .40459 .49202 .39453 .48531 .38085 Mtetra
.825 .683 .707 r
.48531 .38085 .49202 .39453 .50435 .36805 .49765 .36046 Mtetra
.664 .741 .907 r
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
0 .081 .607 r
.55913 .3396 .56565 .34736 .57845 .36571 .57183 .35174 Mtetra
.223 .368 .8 r
.57183 .35174 .57845 .36571 .59115 .36758 .58466 .36034 Mtetra
.824 .795 .825 r
.58466 .36034 .59115 .36758 .60357 .354 .59717 .34839 Mtetra
.883 .834 .793 r
.59717 .34839 .60357 .354 .61593 .33897 .60958 .33251 Mtetra
.823 .818 .844 r
.60958 .33251 .61593 .33897 .62842 .32872 .6221 .3213 Mtetra
.731 .777 .889 r
.6221 .3213 .62842 .32872 .64107 .32242 .63477 .31456 Mtetra
.68 .75 .904 r
.63477 .31456 .64107 .32242 .65382 .31767 .64756 .30968 Mtetra
.666 .742 .907 r
.64756 .30968 .65382 .31767 .66664 .31328 .66042 .30524 Mtetra
.664 .741 .907 r
.66042 .30524 .66664 .31328 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .29201 Mtetra
.69937 .29201 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23517 .44007 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42037 .3139 .4132 Mtetra
.3139 .4132 .32114 .42037 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39749 Mtetra
.35996 .39749 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39688 .3833 .38952 Mtetra
.3833 .38952 .39036 .39688 .40207 .39291 .39504 .38553 Mtetra
.661 .74 .908 r
.39504 .38553 .40207 .39291 .41383 .389 .40684 .38158 Mtetra
.646 .735 .914 r
.40684 .38158 .41383 .389 .42563 .38551 .41867 .37807 Mtetra
.573 .709 .935 r
.41867 .37807 .42563 .38551 .43744 .38387 .4305 .3764 Mtetra
.303 .58 .938 r
.4305 .3764 .43744 .38387 .44921 .38665 .44229 .37915 Mtetra
0 .313 .793 r
.44229 .37915 .44921 .38665 .46099 .39408 .45408 .38657 Mtetra
.244 .546 .928 r
.45408 .38657 .46099 .39408 .47297 .39765 .46608 .39012 Mtetra
.861 .774 .764 r
.46608 .39012 .47297 .39765 .48531 .38085 .47848 .37326 Mtetra
.882 .77 .735 r
.47848 .37326 .48531 .38085 .49765 .36046 .49089 .35281 Mtetra
.664 .741 .907 r
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
0 .081 .607 r
.55255 .33177 .55913 .3396 .57183 .35174 .56526 .34391 Mtetra
0 .295 .785 r
.56526 .34391 .57183 .35174 .58466 .36034 .57809 .35249 Mtetra
.818 .782 .819 r
.57809 .35249 .58466 .36034 .59717 .34839 .59066 .3405 Mtetra
.858 .784 .777 r
.59066 .3405 .59717 .34839 .60958 .33251 .60313 .32456 Mtetra
.808 .78 .827 r
.60313 .32456 .60958 .33251 .6221 .3213 .6157 .31331 Mtetra
.728 .762 .88 r
.6157 .31331 .6221 .3213 .63477 .31456 .62842 .30652 Mtetra
.679 .746 .902 r
.62842 .30652 .63477 .31456 .64756 .30968 .64125 .30161 Mtetra
.666 .742 .906 r
.64125 .30161 .64756 .30968 .66042 .30524 .65415 .29712 Mtetra
.664 .741 .907 r
.65415 .29712 .66042 .30524 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .29201 .69322 .28378 Mtetra
.69322 .28378 .69937 .29201 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26572 Mtetra
.74616 .26572 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23517 .44007 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .42541 Mtetra
.24997 .42541 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41769 Mtetra
.27248 .41769 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .3981 Mtetra
.32959 .3981 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39749 .35279 .39014 Mtetra
.35279 .39014 .35996 .39749 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38553 .38796 .37808 Mtetra
.662 .74 .908 r
.38796 .37808 .39504 .38553 .40684 .38158 .39979 .37409 Mtetra
.65 .736 .912 r
.39979 .37409 .40684 .38158 .41867 .37807 .41165 .37045 Mtetra
.591 .713 .928 r
.41165 .37045 .41867 .37807 .4305 .3764 .42352 .36835 Mtetra
.388 .609 .937 r
.42352 .36835 .4305 .3764 .44229 .37915 .43535 .37018 Mtetra
.069 .391 .85 r
.43535 .37018 .44229 .37915 .45408 .38657 .44716 .37679 Mtetra
.225 .467 .88 r
.44716 .37679 .45408 .38657 .46608 .39012 .45914 .38199 Mtetra
.788 .76 .827 r
.45914 .38199 .46608 .39012 .47848 .37326 .4715 .3718 Mtetra
.957 .853 .697 r
.4715 .3718 .47848 .37326 .49089 .35281 .48407 .3451 Mtetra
.664 .741 .907 r
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.665 .195 0 r
.54591 .32389 .55255 .33177 .56526 .34391 .55869 .34225 Mtetra
0 .541 .779 r
.55869 .34225 .56526 .34391 .57809 .35249 .57147 .34404 Mtetra
.831 .771 .795 r
.57147 .34404 .57809 .35249 .59066 .3405 .58406 .33031 Mtetra
.828 .739 .767 r
.58406 .33031 .59066 .3405 .60313 .32456 .5966 .31512 Mtetra
.781 .743 .818 r
.5966 .31512 .60313 .32456 .6157 .31331 .60924 .30473 Mtetra
.716 .745 .875 r
.60924 .30473 .6157 .31331 .62842 .30652 .62201 .2983 Mtetra
.677 .742 .9 r
.62201 .2983 .62842 .30652 .64125 .30161 .63488 .29345 Mtetra
.666 .741 .906 r
.63488 .29345 .64125 .30161 .65415 .29712 .64783 .28894 Mtetra
.664 .741 .907 r
.64783 .28894 .65415 .29712 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27549 Mtetra
.68702 .27549 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26642 Mtetra
.71345 .26642 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26572 .74014 .25726 Mtetra
.74014 .25726 .74616 .26572 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23328 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .42541 .24247 .41828 Mtetra
.24247 .41828 .24997 .42541 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41769 .26503 .4105 Mtetra
.26503 .4105 .27248 .41769 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .3981 .32229 .39075 Mtetra
.32229 .39075 .32959 .3981 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37808 .38082 .37057 Mtetra
.662 .74 .908 r
.38082 .37057 .38796 .37808 .39979 .37409 .39268 .36653 Mtetra
.655 .737 .91 r
.39268 .36653 .39979 .37409 .41165 .37045 .40458 .3627 Mtetra
.616 .72 .92 r
.40458 .3627 .41165 .37045 .42352 .36835 .4165 .35996 Mtetra
.486 .649 .93 r
.4165 .35996 .42352 .36835 .43535 .37018 .4284 .36022 Mtetra
.257 .482 .883 r
.4284 .36022 .43535 .37018 .44716 .37679 .44026 .36496 Mtetra
.225 .417 .841 r
.44026 .36496 .44716 .37679 .45914 .38199 .4522 .37135 Mtetra
.574 .635 .874 r
.4522 .37135 .45914 .38199 .4715 .3718 .46443 .36997 Mtetra
.914 .904 .801 r
.46443 .36997 .4715 .3718 .48407 .3451 .47696 .35356 Mtetra
.79 .922 .543 r
.47696 .35356 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.664 .741 .907 r
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
0 .079 .604 r
.52671 .32025 .53343 .32817 .54591 .32389 .5393 .33224 Mtetra
.633 .186 .17 r
.5393 .33224 .54591 .32389 .55869 .34225 .55204 .34021 Mtetra
.724 .945 .954 r
.55204 .34021 .55869 .34225 .57147 .34404 .56476 .33306 Mtetra
.818 .725 .762 r
.56476 .33306 .57147 .34404 .58406 .33031 .57737 .31805 Mtetra
.79 .699 .764 r
.57737 .31805 .58406 .33031 .5966 .31512 .59 .30466 Mtetra
.749 .716 .821 r
.59 .30466 .5966 .31512 .60924 .30473 .60272 .2958 Mtetra
.699 .733 .877 r
.60272 .2958 .60924 .30473 .62201 .2983 .61555 .28996 Mtetra
.672 .739 .901 r
.61555 .28996 .62201 .2983 .63488 .29345 .62847 .28521 Mtetra
.665 .741 .906 r
.62847 .28521 .63488 .29345 .64783 .28894 .64145 .28068 Mtetra
.664 .741 .907 r
.64145 .28068 .64783 .28894 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27549 .68077 .26712 Mtetra
.68077 .26712 .68702 .27549 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26642 .70729 .25797 Mtetra
.70729 .25797 .71345 .26642 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39137 Mtetra
.29182 .39137 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .36711 Mtetra
.36178 .36711 .36901 .37464 .38082 .37057 .37362 .363 Mtetra
.663 .74 .908 r
.37362 .363 .38082 .37057 .39268 .36653 .38551 .3589 Mtetra
.659 .739 .909 r
.38551 .3589 .39268 .36653 .40458 .3627 .39745 .35491 Mtetra
.638 .728 .914 r
.39745 .35491 .40458 .3627 .4165 .35996 .40942 .35153 Mtetra
.567 .685 .919 r
.40942 .35153 .4165 .35996 .4284 .36022 .42139 .35005 Mtetra
.425 .572 .896 r
.42139 .35005 .4284 .36022 .44026 .36496 .43334 .35204 Mtetra
.321 .452 .837 r
.43334 .35204 .44026 .36496 .4522 .37135 .4453 .35724 Mtetra
.405 .481 .824 r
.4453 .35724 .4522 .37135 .46443 .36997 .45742 .36113 Mtetra
.627 .702 .899 r
.45742 .36113 .46443 .36997 .47696 .35356 .46978 .35799 Mtetra
.566 .904 .672 r
.46978 .35799 .47696 .35356 .4895 .33308 .4823 .34784 Mtetra
.096 0 .037 r
.4823 .34784 .4895 .33308 .50184 .32882 .49483 .33733 Mtetra
.192 0 0 r
.49483 .33733 .50184 .32882 .51425 .32455 .50734 .33304 Mtetra
.477 .014 .075 r
.50734 .33304 .51425 .32455 .52671 .32025 .51989 .33496 Mtetra
.504 .112 .23 r
.51989 .33496 .52671 .32025 .5393 .33224 .53255 .33655 Mtetra
0 0 0 r
.53255 .33655 .5393 .33224 .55204 .34021 .54527 .33111 Mtetra
.811 .757 .802 r
.54527 .33111 .55204 .34021 .56476 .33306 .55796 .31857 Mtetra
.776 .667 .743 r
.55796 .31857 .56476 .33306 .57737 .31805 .57063 .30468 Mtetra
.75 .671 .773 r
.57063 .30468 .57737 .31805 .59 .30466 .58334 .294 Mtetra
.717 .702 .835 r
.58334 .294 .59 .30466 .60272 .2958 .59614 .28682 Mtetra
.684 .728 .883 r
.59614 .28682 .60272 .2958 .61555 .28996 .60903 .28155 Mtetra
.668 .738 .902 r
.60903 .28155 .61555 .28996 .62847 .28521 .62199 .2769 Mtetra
.665 .74 .907 r
.62199 .2769 .62847 .28521 .64145 .28068 .63502 .27236 Mtetra
.664 .741 .907 r
.63502 .27236 .64145 .28068 .65449 .27618 .6481 .26782 Mtetra
.6481 .26782 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26712 .67446 .25868 Mtetra
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39137 .28434 .38397 Mtetra
.28434 .38397 .29182 .39137 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .36711 .35449 .35951 Mtetra
.35449 .35951 .36178 .36711 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .3589 .37829 .35122 Mtetra
.662 .74 .908 r
.37829 .35122 .38551 .3589 .39745 .35491 .39026 .34711 Mtetra
.652 .734 .909 r
.39026 .34711 .39745 .35491 .40942 .35153 .40228 .34327 Mtetra
.62 .711 .911 r
.40228 .34327 .40942 .35153 .42139 .35005 .41433 .34038 Mtetra
.546 .645 .899 r
.41433 .34038 .42139 .35005 .43334 .35204 .42637 .33957 Mtetra
.457 .539 .853 r
.42637 .33957 .43334 .35204 .4453 .35724 .43841 .34158 Mtetra
.432 .473 .802 r
.43841 .34158 .4453 .35724 .45742 .36113 .45053 .34518 Mtetra
.483 .5 .799 r
.45053 .34518 .45742 .36113 .46978 .35799 .46278 .34731 Mtetra
.567 .636 .879 r
.46278 .34731 .46978 .35799 .4823 .34784 .4752 .34603 Mtetra
.528 .888 .977 r
.4752 .34603 .4823 .34784 .49483 .33733 .48773 .34226 Mtetra
0 0 0 r
.48773 .34226 .49483 .33733 .50734 .33304 .50032 .33794 Mtetra
.50032 .33794 .50734 .33304 .51989 .33496 .51297 .33305 Mtetra
.731 .948 .951 r
.51297 .33305 .51989 .33496 .53255 .33655 .52568 .32568 Mtetra
.773 .715 .799 r
.52568 .32568 .53255 .33655 .54527 .33111 .53841 .31485 Mtetra
.746 .637 .739 r
.53841 .31485 .54527 .33111 .55796 .31857 .55113 .30252 Mtetra
.731 .632 .749 r
.55113 .30252 .55796 .31857 .57063 .30468 .56387 .29176 Mtetra
.714 .663 .798 r
.56387 .29176 .57063 .30468 .58334 .294 .57666 .28383 Mtetra
.692 .704 .857 r
.57666 .28383 .58334 .294 .59614 .28682 .58952 .278 Mtetra
.673 .73 .893 r
.58952 .278 .59614 .28682 .60903 .28155 .60246 .27313 Mtetra
.666 .739 .904 r
.60246 .27313 .60903 .28155 .62199 .2769 .61546 .26853 Mtetra
.664 .74 .907 r
.61546 .26853 .62199 .2769 .63502 .27236 .62853 .26396 Mtetra
.664 .741 .907 r
.62853 .26396 .63502 .27236 .6481 .26782 .64166 .25938 Mtetra
.64166 .25938 .6481 .26782 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35122 .371 .34349 Mtetra
.663 .74 .907 r
.371 .34349 .37829 .35122 .39026 .34711 .38301 .3393 Mtetra
.66 .738 .908 r
.38301 .3393 .39026 .34711 .40228 .34327 .39507 .33519 Mtetra
.647 .728 .908 r
.39507 .33519 .40228 .34327 .41433 .34038 .40718 .33145 Mtetra
.616 .695 .9 r
.40718 .33145 .41433 .34038 .42637 .33957 .41931 .32865 Mtetra
.566 .628 .872 r
.41931 .32865 .42637 .33957 .43841 .34158 .43146 .32743 Mtetra
.525 .548 .822 r
.43146 .32743 .43841 .34158 .45053 .34518 .44364 .32783 Mtetra
.521 .505 .779 r
.44364 .32783 .45053 .34518 .46278 .34731 .45591 .32875 Mtetra
.548 .508 .764 r
.45591 .32875 .46278 .34731 .4752 .34603 .46829 .32864 Mtetra
.59 .545 .772 r
.46829 .32864 .4752 .34603 .48773 .34226 .4808 .32652 Mtetra
.638 .589 .783 r
.4808 .32652 .48773 .34226 .50032 .33794 .4934 .32215 Mtetra
.676 .608 .772 r
.4934 .32215 .50032 .33794 .51297 .33305 .50607 .31553 Mtetra
.695 .601 .746 r
.50607 .31553 .51297 .33305 .52568 .32568 .51878 .30688 Mtetra
.701 .593 .732 r
.51878 .30688 .52568 .32568 .53841 .31485 .53152 .29718 Mtetra
.701 .603 .743 r
.53152 .29718 .53841 .31485 .55113 .30252 .54428 .28798 Mtetra
.698 .635 .782 r
.54428 .28798 .55113 .30252 .56387 .29176 .55708 .2804 Mtetra
.689 .68 .837 r
.55708 .2804 .56387 .29176 .57666 .28383 .56993 .27441 Mtetra
.676 .717 .88 r
.56993 .27441 .57666 .28383 .58952 .278 .58285 .26937 Mtetra
.667 .734 .9 r
.58285 .26937 .58952 .278 .60246 .27313 .59583 .26469 Mtetra
.665 .74 .906 r
.59583 .26469 .60246 .27313 .61546 .26853 .60888 .26009 Mtetra
.664 .741 .907 r
.60888 .26009 .61546 .26853 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34349 .36365 .33569 Mtetra
.36365 .33569 .371 .34349 .38301 .3393 .3757 .33145 Mtetra
.663 .74 .907 r
.3757 .33145 .38301 .3393 .39507 .33519 .3878 .32722 Mtetra
.659 .736 .907 r
.3878 .32722 .39507 .33519 .40718 .33145 .39995 .32308 Mtetra
.649 .723 .903 r
.39995 .32308 .40718 .33145 .41931 .32865 .41215 .31925 Mtetra
.628 .691 .889 r
.41215 .31925 .41931 .32865 .43146 .32743 .42438 .31603 Mtetra
.603 .637 .857 r
.42438 .31603 .43146 .32743 .44364 .32783 .43666 .31361 Mtetra
.587 .581 .814 r
.43666 .31361 .44364 .32783 .45591 .32875 .44899 .31175 Mtetra
.588 .547 .777 r
.44899 .31175 .45591 .32875 .46829 .32864 .4614 .30973 Mtetra
.603 .537 .754 r
.4614 .30973 .46829 .32864 .4808 .32652 .47391 .30677 Mtetra
.625 .543 .742 r
.47391 .30677 .4808 .32652 .4934 .32215 .4865 .30235 Mtetra
.647 .555 .738 r
.4865 .30235 .4934 .32215 .50607 .31553 .49916 .29648 Mtetra
.663 .571 .741 r
.49916 .29648 .50607 .31553 .51878 .30688 .51187 .28965 Mtetra
.674 .593 .757 r
.51187 .28965 .51878 .30688 .53152 .29718 .52462 .28266 Mtetra
.679 .627 .79 r
.52462 .28266 .53152 .29718 .54428 .28798 .53741 .27622 Mtetra
.679 .669 .834 r
.53741 .27622 .54428 .28798 .55708 .2804 .55026 .27058 Mtetra
.673 .707 .873 r
.55026 .27058 .55708 .2804 .56993 .27441 .56316 .26555 Mtetra
.668 .73 .896 r
.56316 .26555 .56993 .27441 .58285 .26937 .57612 .26083 Mtetra
.665 .738 .905 r
.57612 .26083 .58285 .26937 .59583 .26469 .58915 .25621 Mtetra
.664 .74 .907 r
.58915 .25621 .59583 .26469 .60888 .26009 .60223 .25159 Mtetra
.664 .741 .907 r
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32722 .38046 .31926 Mtetra
.663 .74 .907 r
.38046 .31926 .3878 .32722 .39995 .32308 .39265 .31497 Mtetra
.66 .736 .906 r
.39265 .31497 .39995 .32308 .41215 .31925 .40489 .31074 Mtetra
.655 .724 .9 r
.40489 .31074 .41215 .31925 .42438 .31603 .41718 .30666 Mtetra
.646 .701 .886 r
.41718 .30666 .42438 .31603 .43666 .31361 .42953 .30282 Mtetra
.636 .666 .862 r
.42953 .30282 .43666 .31361 .44899 .31175 .44193 .2992 Mtetra
.632 .632 .832 r
.44193 .2992 .44899 .31175 .4614 .30973 .45439 .29557 Mtetra
.633 .608 .807 r
.45439 .29557 .4614 .30973 .47391 .30677 .46692 .29165 Mtetra
.641 .599 .792 r
.46692 .29165 .47391 .30677 .4865 .30235 .47952 .28719 Mtetra
.65 .604 .789 r
.47952 .28719 .4865 .30235 .49916 .29648 .49218 .28219 Mtetra
.66 .621 .799 r
.49218 .28219 .49916 .29648 .51187 .28965 .5049 .27689 Mtetra
.667 .647 .821 r
.5049 .27689 .51187 .28965 .52462 .28266 .51768 .27159 Mtetra
.67 .68 .851 r
.51768 .27159 .52462 .28266 .53741 .27622 .53051 .2665 Mtetra
.669 .709 .878 r
.53051 .2665 .53741 .27622 .55026 .27058 .54339 .26165 Mtetra
.666 .728 .896 r
.54339 .26165 .55026 .27058 .56316 .26555 .55633 .25695 Mtetra
.665 .737 .904 r
.55633 .25695 .56316 .26555 .57612 .26083 .56934 .25231 Mtetra
.664 .74 .907 r
.56934 .25231 .57612 .26083 .58915 .25621 .58241 .24767 Mtetra
.664 .741 .907 r
.58241 .24767 .58915 .25621 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31926 .37306 .31126 Mtetra
.37306 .31126 .38046 .31926 .39265 .31497 .38528 .30691 Mtetra
.663 .74 .907 r
.38528 .30691 .39265 .31497 .40489 .31074 .39756 .30255 Mtetra
.662 .737 .905 r
.39756 .30255 .40489 .31074 .41718 .30666 .4099 .29821 Mtetra
.66 .73 .901 r
.4099 .29821 .41718 .30666 .42953 .30282 .42229 .29389 Mtetra
.658 .718 .893 r
.42229 .29389 .42953 .30282 .44193 .2992 .43474 .28961 Mtetra
.656 .703 .881 r
.43474 .28961 .44193 .2992 .45439 .29557 .44724 .28533 Mtetra
.656 .689 .869 r
.44724 .28533 .45439 .29557 .46692 .29165 .45981 .28096 Mtetra
.658 .681 .86 r
.45981 .28096 .46692 .29165 .47952 .28719 .47244 .27646 Mtetra
.661 .682 .859 r
.47244 .27646 .47952 .28719 .49218 .28219 .48513 .27183 Mtetra
.663 .692 .866 r
.48513 .27183 .49218 .28219 .5049 .27689 .49787 .26711 Mtetra
.665 .706 .878 r
.49787 .26711 .5049 .27689 .51768 .27159 .51068 .26239 Mtetra
.665 .721 .89 r
.51068 .26239 .51768 .27159 .53051 .2665 .52354 .2577 Mtetra
.665 .732 .9 r
.52354 .2577 .53051 .2665 .54339 .26165 .53647 .25304 Mtetra
.664 .738 .905 r
.53647 .25304 .54339 .26165 .55633 .25695 .54945 .24839 Mtetra
.664 .74 .907 r
.54945 .24839 .55633 .25695 .56934 .25231 .5625 .24373 Mtetra
.664 .741 .907 r
.5625 .24373 .56934 .25231 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .30691 .37785 .29881 Mtetra
.37785 .29881 .38528 .30691 .39756 .30255 .39017 .29439 Mtetra
.664 .74 .907 r
.39017 .29439 .39756 .30255 .4099 .29821 .40254 .28997 Mtetra
.663 .739 .906 r
.40254 .28997 .4099 .29821 .42229 .29389 .41497 .28553 Mtetra
.663 .736 .904 r
.41497 .28553 .42229 .29389 .43474 .28961 .42746 .28107 Mtetra
.663 .733 .902 r
.42746 .28107 .43474 .28961 .44724 .28533 .44 .2766 Mtetra
.663 .729 .899 r
.44 .2766 .44724 .28533 .45981 .28096 .45261 .2721 Mtetra
.663 .727 .897 r
.45261 .2721 .45981 .28096 .47244 .27646 .46527 .26756 Mtetra
.664 .727 .896 r
.46527 .26756 .47244 .27646 .48513 .27183 .47799 .26298 Mtetra
.664 .729 .898 r
.47799 .26298 .48513 .27183 .49787 .26711 .49078 .25838 Mtetra
.664 .733 .901 r
.49078 .25838 .49787 .26711 .51068 .26239 .50362 .25375 Mtetra
.664 .737 .904 r
.50362 .25375 .51068 .26239 .52354 .2577 .51652 .24911 Mtetra
.664 .739 .906 r
.51652 .24911 .52354 .2577 .53647 .25304 .52949 .24445 Mtetra
.664 .74 .907 r
.52949 .24445 .53647 .25304 .54945 .24839 .54251 .23978 Mtetra
.664 .741 .907 r
.54251 .23978 .54945 .24839 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .29881 .37036 .29064 Mtetra
.37036 .29064 .37785 .29881 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28997 .39512 .28171 Mtetra
.39512 .28171 .40254 .28997 .41497 .28553 .40759 .27722 Mtetra
.664 .74 .907 r
.40759 .27722 .41497 .28553 .42746 .28107 .42011 .27271 Mtetra
.664 .74 .906 r
.42011 .27271 .42746 .28107 .44 .2766 .43269 .26818 Mtetra
.664 .739 .906 r
.43269 .26818 .44 .2766 .45261 .2721 .44533 .26362 Mtetra
.44533 .26362 .45261 .2721 .46527 .26756 .45803 .25904 Mtetra
.45803 .25904 .46527 .26756 .47799 .26298 .47079 .25444 Mtetra
.47079 .25444 .47799 .26298 .49078 .25838 .48362 .24981 Mtetra
.664 .74 .906 r
.48362 .24981 .49078 .25838 .50362 .25375 .4965 .24517 Mtetra
.664 .74 .907 r
.4965 .24517 .50362 .25375 .51652 .24911 .50944 .2405 Mtetra
.664 .741 .907 r
.50944 .2405 .51652 .24911 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26887 Mtetra
.40013 .26887 .40759 .27722 .42011 .27271 .4127 .26431 Mtetra
.4127 .26431 .42011 .27271 .43269 .26818 .42532 .25974 Mtetra
.42532 .25974 .43269 .26818 .44533 .26362 .43799 .25514 Mtetra
.43799 .25514 .44533 .26362 .45803 .25904 .45073 .25052 Mtetra
.45073 .25052 .45803 .25904 .47079 .25444 .46353 .24588 Mtetra
.46353 .24588 .47079 .25444 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24517 .48931 .23653 Mtetra
.48931 .23653 .4965 .24517 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .2271 Mtetra
.51534 .2271 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26887 .39262 .26044 Mtetra
.39262 .26044 .40013 .26887 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25974 .41787 .25123 Mtetra
.41787 .25123 .42532 .25974 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .2271 .50817 .2183 Mtetra
.50817 .2183 .51534 .2271 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24266 Mtetra
.41037 .24266 .41787 .25123 .43059 .24659 .42312 .23798 Mtetra
.42312 .23798 .43059 .24659 .44337 .24193 .43594 .23328 Mtetra
.43594 .23328 .44337 .24193 .45621 .23725 .44881 .22856 Mtetra
.44881 .22856 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24266 .4028 .234 Mtetra
.4028 .234 .41037 .24266 .42312 .23798 .41559 .22928 Mtetra
.41559 .22928 .42312 .23798 .43594 .23328 .42844 .22454 Mtetra
.42844 .22454 .43594 .23328 .44881 .22856 .44136 .21978 Mtetra
.44136 .21978 .44881 .22856 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20274 Mtetra
.39259 .20274 .40032 .21166 .41325 .20683 .40556 .19787 Mtetra
.40556 .19787 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20274 .38478 .19373 Mtetra
.38478 .19373 .39259 .20274 .40556 .19787 .39779 .18881 Mtetra
.39779 .18881 .40556 .19787 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15179 Mtetra
.36602 .15179 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15179 .3579 .14231 Mtetra
.3579 .14231 .36602 .15179 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15336 Mtetra
.2971 .15336 .30546 .16272 .31847 .15766 .31015 .14825 Mtetra
.31015 .14825 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000/@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000]02Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool30000
0;H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0;H0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000_02Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo
00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool300000;h0ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX08P0ZKgX0P2Y
_NLc0:Vmj0800000;02Y_NP00`000000oooo0?ooo`0i0?ooo`00;03oool0102Y_NP0000000000000
00210:Vmj0D0ZKgW1@2Y_NP50:Vmibl0ZKgX0`0000020:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<0
00000?ooo`3oool0>@3oool002/0oooo0P0000200:Vmj0X0ZKgW1@2Y_>L50:Vmi`D0ZKcW9P2Y_NP3
000000D0ZKgX00<000000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0h0?ooo`00:@3oool20000
0800ZKgX2P2Y_NL30:VkiPD0ZKcW1@2Z^nH50:Vli`D0Z[cW7@2Y_NP3000000T0ZKgX00<000000:Vm
j02Y_NP0:P2Y_NP00`000000oooo0?ooo`0g0?ooo`007@3oool01@3ookl0M00000000000B9`0gooo
00L0oooo0P00001n0:Vmj0X0ZKgW1P2Y^nH20:Vli`<0Z[SS1@2Z^nH20:Vli`<0Z[[U2P2Z_>LE0:Vm
j08000003@2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03L0oooo000L0?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo1`3oool00`000000oooo0000001i0:Vmj0X0ZKgW1@2Y^^D5
0:VkiPH0Z[SS102Z^nH60:Zji@80Z[cW0`2[^^D50:Zli`80ZKgX0`2Z_NL<0:Vmj0<00000402Y_NP0
0`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`050?ooo`8000000P3oool00`000000ZKgX0:Vmj01d0:Vmj0P0ZKgW2P2Y
^^D50:Zdh0D0Z[SS1@2[]N050:Zji@H0Zk[U102Z_>L60:Zmi`P0ZKgX0`00000C0:Vmj0030000002Y
_NP0ZKgX02X0ZKgX00<000000?ooo`3oool0=@3oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00D0oooo00<000000?ooo`3oool00P3oool00`000000ZKgX0:Vmj01a0:Vmj0P0ZKgW
2P2Y^^D30:Vag@D0Z[CP0P2Z^><30:^^f@D0ZkGP1@2/]=l50:^ji@D0Z[_V1@2Z_NL50:Vmj0<00000
5`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?noM000
B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo00<0ooooK`2Y_NP:0:Vmi`X0
ZK[U1P2Y/Md40:Zdh0H0ZjkI0P2[]N030:f[e@D0[;CO0P2[^^D30:fgh@D0Z[_V1@2Z_NL0102Y_NP0
000000000000000K0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0=03oool001`0
oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo0P0000050?ooo`030000002Y_NP0
ZKgX06`0ZKgX1@2Y_NL50:VjiPD0ZK[U1@2Y[]/50:Vag@D0ZZGB1@2[[]T60:f[e@@0[;CO1P2]]n42
0:ZkiP<0[;[T0P2Z_NL3000000D0Z[gX6P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0
oooo03<0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000:Vmj02Y_NP0K02Y_NP20:Vmi`<0ZK_V1@2Y^^H20:Vji@<0Z:kL1@2Y
[]/20:Vag@<0Z9k<1@2ZYM820:^^f@<0[J3:1@2]ZmD50;2^ePD0[KOQ102/^^@3000000040:Zmi`2[
_>H0ZkcV0:^liPD0Z[gX6@2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03<0oooo
000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?ooo`070?ooofd0
ZKgX1P2Y^nH40:VjiPH0Z:kL102Y[]/50:RNc0D0ZZGB1@2]X<X40:f[e@80/Z;81@2`[]H50;6df`<0
00000P2/^^@60:^liP80Z[gX0`2Z_NLI0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3o
ool0<P3oool001d0oooo00D0oono07@00000000004RL0=ooo`060?ooo`030000003oool0oooo00P0
ooooJ@2Y_NP50:Vli`@0ZK_V1@2W/=h50:R^g0D0YY[91@2XW/`20:ZUdP<0[9O11@2]X<X20:f[e@<0
/Z;8102`[]H20;JYc080/KCK0P0000000`2a]=/0[k[R0:njhP030:njhPD0ZkcV1@2Z_NLJ0:Vmj003
0000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool0
2P3ooomT0:Vmj0D0ZKgW1@2Y_>L40:Nch@D0Yk3N0P2X[]`30:BIbP@0YY[91@2XW/`50:bG`@D0[J3:
1P2bX/P20;2^eP80]ZW<0`0000020;6df`80]k?E1@2_^^850:bmiP@0Z[gW6P2Y_NP00`000000ZKgX
0:Vmj00Y0:Vmj0030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0ooooI02Y
_NP50:Vmi`D0Z;OT102W/n440:N`gPD0Y9W:1@2VV/T20:RNc0<0ZI:m1@2/Ul420:fPbP<0/iZn1@2b
X/P0102fZL`000000000000000020;JYc080/KCK102g/mD20:njhP<0/[_P1@2/_NH40:ZmiaX0ZKgX
00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool00`000000oooo0?oo
o`0<0?ooof@0ZKgX0P2Y_NL30:RjiPD0Z;OT102W/n440::KcPD0Y9W:102VV/T50:VB_@D0[9O11@2c
V[h30;:Rb0<000001@2fZL`60;Nce@H0/[_P0P2/_NH30:fmiP@0Z[gW6P2Y_NP00`000000ZKgX0:Vm
j00X0:Vmj0030000003oool0oooo0300oooo000W0?ooo`8000003P3ooomS0:Vmj0H0Z;[V102X]n@5
0:6Qe0@0XY_>102TVLX20:JJb@<0YHjl1@2YT[d30:bG`@80/iNk102cV[h3000000<0^j6o102fZL`2
0;n[a@@0]k?E0P2o]m850;:kh0D0[KgV1@2Z_NLJ0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<00000
0?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3ooomN0:Vmj0D0ZKcW1@2X^^H50::Z
g0@0XJ7D1@2RVlh30:BIbPD0YHjl1@2YT[d20:bG`@<0/iNk00D0/iZn00000000000000000;>J_P06
0;^Q_`80]ZW<102oZlD20;Nce@@0_kOB0P2b^n030;Nng`@0[KgV1P2Z_NLI0:Vmj0030000002Y_NP0
ZKgX02T0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo00<000000?ooo`3oool03`3ooomN0:Vm
j0D0ZKcW1@2U/n840::Zg0D0XJ7D102RVlh409n;_@@0YHjl1@2YT[d30;>G^`<000000`2cV[h20;jS
_@D0^j6o1P2oZlD60;ngdPH0]kkO102]_^H50:ZmiaX0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`00
0000oooo0?ooo`0^0?ooo`009`3oool200000140oooo00<000000:Vmj02Y_NP0F`2Y_NP30:Vli`80
YkWV1@2U/n840::Zg0@0XJ7D1@2JRL4309n;_@D0YHjl0`2YT[d0102aVKh000000000000000030;>G
^`80/iZn0`2nXkd40;^Q_`80aZZn102oZlD20<Zb``@0_kOB0P37_]430;Nng`<0^/?Q102]_^H50:Zm
j1X0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool2000001<0
oooo00<000000:Vmj02Y_NP0F`2Y_NP50:NiiP@0YK?R102RZ]`509J<aP@0VXW1102ORkd40:F>_005
0:VB_@00000000000000002aVKh01@2cUk/00`2cV[h0_Z>m0;jS_@030;jS_@80^j6o0`36Z[h30;n[
a@@0b[;30P2o]m840<Nnd@D0^/?Q0P2]_^H30:joi`D0Z[gX6P2Y_NP00`000000ZKgX0:Vmj00X0:Vm
j0030000003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oOW018
07@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000
003oool0oooo01<0oooo00<000000:Vmj02Y_NP0EP2Y_NP50:Rli`D0YkWV102JXm/409JDd0@0UXc6
102JRL4409n;_@<0YHjl0P0000040;6I_PD0/iNk1P2nXkd00`2kXKl0aZZn0<JZ_P030<JZ_P030;n[
a@3://<0b[;300<0b[;31@37_]420<k7d`@0^/?Q1P2^_nL50:Zmj1T0ZKgX00<000000:Vmj02Y_NP0
:02Y_NP00`000000oooo0?ooo`0:0?ooo`050=nLB000000000000000B02Lgol07@3oool000P0oooo
00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0okmd0018
W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0503oool00`000000ZKgX0:Vm
j01F0:Vmj0D0Z;cW1@2P/><309ZSf`@0UYC@102FS<H509Z9`@<0Wh^m0`0000020:fKa@D0/IVn0`2c
Uk/20<Fgc0D0_Z>m1P36Z[h60<Zb``040=>ma037_]40akkA0<Nnd@@0c/OC0P2j`n420;_6h`D0[[oW
1P2Z_NPI0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0203oool01`3o_g@004RL
0=ooo`3oool0oooO09a8M02oool0703oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00@0oooo00<0omnL04P0001d_ol0203oool00`2oM000M;oo0?ooo`050?ooo`8000005P3ooomI
0:Vmj0D0Y[WW102P/><409ZSf`@0UYC@102FS<H409Z9`@<0000000<0Wh^m0:fKa@2]VlD00P2]VlD5
0;6I_P80/iNk0`35]l`40;jS_@80cl7=1036Z[h20=6i``@0b[;30`3C_L@00`37_]40c/OC0<k7d`03
0<k7d`D0^lKS1@2]_nL50:Zmj1X0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0<
0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?oo
o`0G0?oooeD0ZKgX0`2X_>P50:Jii`@0X;3S0`2JXm/409JDd0@0UXc600@0VXW10000000000000000
1@2SU/P40:fKa@@0/IVn1P35]l`20;jS_@<0cl7=0`36Z[h30=6i``<0b[;3103C_L@50<k7d`80d]7H
0`2ka^<20;S8iPD0[KoW1@2Z_NPI0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0
303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02L
gol01P3oool02`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo
00<000000?ooo`3oool0603ooomB0:Vmj0H0Z;cX102V^NL40:2`h`<0VZ?K102FU=0209J<aP<00000
102GRlD40:>Fb0@0[I_50P2aVKh30;_bl`D0aKO<00<0_Z>m0<o1c@3?`Ld00`3?`Ld00`36Z[h0dKW3
0=6i``030=6i``030<Zb``3C_L@0dkg400<0dkg400@0flS60<k7d`3>am<0c/OC103BdMP50;S8iPD0
[;oX1@2Z_NPI0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0
B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0oooo00@0oooo
0P00000K0?oooe<0ZKgX102X_>P509faiP@0T:3O0`26S=8208F1a`<000000`2<P/<409N;a@D0XiK8
0`2]VlD60;_bl`@0aKO<1P3?`Ld60=6i``D0dkg40`3Kb<H50=;Af080dMSN0P2hb>H30;C6j0D0[;oX
1@2Z_NPI0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0M000
000000020000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?oo
o`030000003oool0oooo01/0ooooD`2Y_NP40:Fjj0D0WK7V0`2@X=l208J<dP<000000P25PLL408b2
``D0Uh_5102SU/P20:fKa@@0ZKgX0`2kl_<40:Vmj0030000003?`Ld0cl7=0080cl7=0P2ilO@40=6i
``80e<G;0`3C_L@40=_8aP040>;Eb`3BdMP0d]7H0=;Af0<0dMSN1P2da^P20:boj0<0ZkkX1@2Z_NPI
0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P
0?ooo`00203oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo
0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool00`000000oooo0?ooo`0L0?ooodh0ZKgX1@2X_>P4
0:Fjj0@0WK7V0P2@X=l300000080QXcB0`25PLL508b2``@0Uh_5102SU/P>0:Vmj0030000003?`Ld0
cl7=00<0^O7d0`3A^L<40=C5b`030=>ma03Kb<H0flS60080flS60`3ReL/40=7HgP80bMSU1@2da^P6
0:^nj0@0Z[gX6@2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00<0_g@0
07Boo`3oool07`3oool000T0oooo00D0oono07@00000000004RL0=ooo`050?ooo`050?oOW0180000
00000000001d_ol00P3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3o
ool07@3ooom>0:Vmj0D0Z;cX0`2U^^P408^UiP8000000P1dRMX308J<dP@0QH77102<P/<409N;a@03
08OSnP3:k8/0ZKgX0100ZKgX1P2ilO@00`3A^L<0e<G;0=C5b`030=C5b`@0flS6103ReL/00`3Uh]00
dMSN0=7HgP040<WHi@D0/<?X1@2[_^PN0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3o
ool01@3oool01P3OW4P00000000000000000001d0;oooa`0oooo000U0?ooo`8000007`3ooom>0:Vm
j080Z;cX0`2V^nP309jfj@<0000000<0RjGV07B9fP1dRMX00P1dRMX206iic@@0QH77102<P/<408OS
nQL0ZKgX0P00R/L50=C5b`80dLSA0P3Kb<H40>;Eb`<0iN;@1039f>D20;kBj@D0/<?X1@2Z_^PN0:Vm
j0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09P3oool002D0oooo00<000000?ooo`3o
ool07`3ooom=0:Vmj0D0Y[_X0`0000000`2N]^T0RjGV08^UiP0208^UiP<0M8WJ0`1^NLd307]oc0H0
TJ;Q00<0b^b;0?CJ/P2Y_NP05P2Y_NP00`0059/004_8002:a`030=C5b`@0dLSA103ReL/30>GRd0<0
hNcH1@2nd^T20;33j0<0[<3X1@2Z_^PM0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3o
ool09@3oool002D0oooo00<000000?ooo`3oool0803ooom=0:Vmj0050:Jkj000000000000000002V
^nP0102N]^T308^UiP@0M8WJ0`1^NLd307]oc0@0TJ;Q00@0T>N/0?CJ/P3df[80m=Zb5`2Y_NP00`00
59/004_8001;b0050=78d@80d/_C0P3ReL/30>GRd0<0hNcH0P3Ejn@40;kBj@H0[<3X1@2Z_NPM0:Vm
j0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?ooodX0
ZKgX0`0000050:>jj@@0TJo[0`1/T^D00`1BLmH0M8WJ07B9fP0306iic@@0Ngo<0P2AX^400`2@ij`0
jNO=0?CJ/P020?CJ/P030>75_02Y_NP0ZKgX01@0ZKgX00@07bnX000DV`0iG/`004_80`3Ab=440=;;
d`<0iN;@0`3Qk=P30=G[i0D0]<WZ0`2/`>P30:^nj0D0Z[gX7@2Y_NP00`000000ZKgX0:Vmj00W0:Vm
j0030000003oool0oooo02@0oooo000T0?ooo`030000003oool0oooo02<0ooooAP2Y_NP3000000D0
Z;gX102S^^T4096_j`80K9;U0`1BLmH406iic@<0Ngo<0`2P/nH30?CJ/P<0hLFl5P2Y_NP01@0O;jP0
>Ek<03UNc000BlP0dLSA00@0d/_C0`3Nfm<30>7/f0<0eN_T0P34gN/50;C9jPH0ZkkX102Z_NPN0:Vm
j0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3o
ool0903ooom20:Vmj0<00000102Y_NP50:Rmj0<0Xk[Y102A[n/306bBi@<0DW?F0`1WNm850:2ciP04
0>WWc@3df[80m=Zb0?CJ/P<0hLFl4@2Y_NP309f1]080ZKgX0P0O;jP203UNc0@0d/_C0`3Nfm<30>Oa
dP80eN_T1@34gN/50:k2j@D0ZkkX8P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo
02<0oooo000T0?ooo`8000009P3oooln0:Vmj0<00000202Y_NP20:Rmj0<0YkcX0`2M^>/407bVkP80
@G_R0`1BLmH406MkdP<0X;?V00@0jNO=0?CJ/P3df[80m=Zb103QaK`00`3C[[@0ZKgX0:Vmj00<0:Vm
j0D0WH6d00@0Ge:[0:Vmj02Y_NP07bnX0`0iG/`20=;;d`<0g]_C0`3WlM820>7kd`80e?OT0`34gN/2
0;G<j`D0[/;Y1@2Z_NPR0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08P3oool0
02<0oooo0P00000X0?oooc/0ZKgX0P00000;0:Vmj0H0YkcX0`2M^>/407bVkP80@G_R00<0>F[G059c
eP1BLmH0101WNm800`2P/nH0jNO=0>WWc@030?CJ/P<0hLFl0`3C[[@509f1]0@0ZKgX2@2MPK@205mB
Z`030:Vmj00O;jP07bnX00<0OHSD0`3Nfm<30>OadP80hO_C103Dmn@50;G<j`D0ZkoX1@2Z_NPR0:Vm
j0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@00000
000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo
00<000000?ooo`3oool0:03ooolf0:Vmj0<000003P2Y_NP50:Nlj0@0UkK]0`1SVnl2045khP<0>F[G
101WNm820>WWc@<0m=Zb0`3QaK`40=>^]0030=^a[P2MPK@0WH6d00<0WH6d102KNJ`809f1]0<0Ge:[
0P0O;jP507f8e0<0io7B0P3Qnm<30=Cgi0<0`N3^0P2ec>/30:g2j@D0ZkoX9`2Y_NP00`000000ZKgX
0:Vmj00V0:Vmj0030000003oool0oooo0240oooo000<0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P0
07Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z
0?oooc80ZKgX0`00000B0:Vmj0D0Y[cY102G]^d306>Kk`03015Tf@11Nn80>F[G0080>F[G102BX]l3
0<W2d`@0hLFl0`3C[[@20=^a[PD0WH6d00@0b9n_09]i[02KNJ`0VgV/2@2MPK@305mBZ`0405iR_P0O
;jP0OHSD07f8e0@0_LcU0P3Qnm<20=Cgi0D0`N3^1P2]`^T20:^oj0<0Z[gX9P2Y_NP00`000000ZKgX
0:Vmj00W0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00P0
oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo;P2Y_NP3000001H0ZKgX1@2V_>T309Nfk@@0
Hi__00<04FCI03UZe`0iJ]L00P0iJ]L209:Rg`@0bL;C00<0g<K30>75_03QaK`0103C[[@20=^a[P@0
WH6d0P38Wjl309]i[0T0WH6d0`1ODZ/205iR_PD0_LcU0P3Ho]L20<_oc@<0b?O[102bb^`50:g2j@H0
Z[gX9P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01l0oooo000<0?ooo`070?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo00D0oooo00<000000?oo
o`3oool0;03ooolZ0:Vmj0<000006P2Y_NP50:Flj@@0T[G_0`1=U?001000D</0>GOQ03Ugh@0iMn45
0<W2d`<0g<K3103C[[@40=^a[P80WH6d0`38Wjl409]i[0P0WH6d0`1ODZ/305iR_P<0_LcU0P3Ho]L2
0<_oc@80b?O[0`2if?040;;:k0D0Z[kX1@2Z_NPW0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<00000
0?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0
omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3ooolV0:Vmj0<0
00007P2Y_NP50:Flj@@0T[G_0`1=U?001000D</0>GOQ03Ugh@0iMn430<W2d`@0g<K300@0gLS40=>^
]03C[[@0djjd103K/Jh209f1]0<0b9n_102KNJ`809f1]0@0Ge:[0`1NH[h20=Sne`80boo=0P38mn/5
0;WHl0D0[<7Y1@2Z_^P[0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3oool0
00`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P00
00000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y_NP300000280ZKgX1@2U
_>T409:fk`80AiGa0P00D</303Ugh@030<W2d`3La/<0g<K30080g<K30P3Mb<@20=>^]0D0fk6^00<0
WH6d0<RO[`38Wjl00`38Wjl309]i[0P0WH6d101ODZ/205iR_P80/MOd00<0Yo>l0;?keP2cnmH00`2k
j?@30;WHl080[/G[1@2/`NT`0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07@3o
ool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol0
2@3oool200000340oooo7P2Y_NP3000002H0ZKgX1@2U_>T409:fk`<0AiGa00<0053;03j;k@0nRnd0
103La/<40=g8a0030=>^]03K/Jh0fk6^00<0fk6^1P38Wjl309]i[0D0WhRk1024N;h307n8d`<0/MOd
0P2cnmH60;_Xm0D0[/G[1@2Z_^P`0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0
7@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00P0
oooo00<000000?ooo`3oool0<@3ooolK0:Vmj0800000:P2Y_NP40:Flj@D0U[S_0`1FX?D00`00B;L0
?X_]03j;k@020=c6``D0gLS41P3K/Jh00`3Nc<H0b9n_0<RO[`030<RO[`80VgV/0P2mYl<409n8^`@0
Q7Rn101oR=<00`25jL/0N]j]0;7bm@030;7bm@D0/<[]0`2^aN/20:Zoj0D0Z[kX<02Y_NP00`000000
ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d000000000018W03O
ool01@3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool0<P3ooolG
0:Vmj0<00000;02Y_NP50:Jlj@D0U[S_0`1FX?D00`00B;L068OX01R7j0050=g8a080d]_O103K/Jh2
0=k<aPD0b9n_00@0VgV/0;fW``2mYl<0_JO3102OR;/508Ah_P80OhSC00<0QNW;0;7bm@2al_D01@2_
co450;3:k@D0Z[oX0P2Z_^Pb0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool06`3o
ool00280oooo0P00000d0?oooa<0ZKgX0`00000a0:Vmj0@0Y[cY1@2M^^d307>^mP03001/e00HQnP0
68OX00<0gLS40`3Bfml30=^a[P<0g/c61@38Wjl40;fW``D0WhRk1024N;h0101oR=<0QNW;09S`l02H
l?020:cBm0D0[loa1@2[`>T40:Zoj3D0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?oo
o`0K0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`l0ZKgX0`00000e0:Vmj0@0YkgY1@2M^^d3
07>^mP<006cD1P3Bfml00`3K/Jh0g/c60=k<aP030=k<aP<0b9n_0P3Af^040;fW``@0WhRk1024N;h2
09S`l0D0[=;d1@2[`NX40:_0jCX0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0J
0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX00P0ZKgX0`00000i0:Vm
j0@0YkgY1@2S_>/408fgl`<0@Yoe103Bfml60=k<aP80b9n_0`3Af^040;fW``@0WhRk0P1fhn<60:OA
mP@0Z/;[1@2[`NX40:Zmj3X0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0<0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3oool00`00
0000oooo0?ooo`0g0?ooo`H0ZKgX0`00000m0:Vmj0@0Z;gX1@2S_>/409fkkPD0P;Og0P10`N@50=k<
aPH0dM[P0`2mYl<206WLg`H0Xlce1@2Y`N/40:[2j`D0Z[kX102Z_NPi0:Vmj0030000002Y_NP0ZKgX
02H0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo000Q0?ooo`800000>P3oool20:Vmj0<00000@@2Y_NP40:Rmj0D0Y[gY102M^nh509blk`80Q;ci
1@14a/`50=7Jh0800000102Qa_830:?<m@<0Z<3[102Y`N/50:Vnj0D0Z[kX?@2Y_NP00`000000ZKgX
0:Vmj00V0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000B@2Y_NP5
0:Jmj@@0YKgZ1@2L_>l509nnkP@0U<7f1@2R`Nl40:76lPH0Z<3[2@2Y_^Q20:Vmj0030000002Y_NP0
ZKgX02D0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0oooo0P0000030?ooodX0
ZKgX1@2X_NP90:FmjPD0Wkk^102U_^`50:;1k`@0Z;oZ0`2X`>/70:Vnj4H0ZKgX00<000000:Vmj02Y
_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3o
ool0oono07@0B02Lgol00`3oool00240oooo0P00000d0?ooo`<000001P3ooom:0:Vmj0T0Z;gX1@2U
_NX50:Nmj@@0YKk/1@2X_^T40:RojPP0ZKkXB02Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003o
ool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`03
0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3ooom@0:Vmj0T0Z;gX102W_NT50:Vm
j0D0Z;kY102Y_NP50:Vnj4/0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?oo
o`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?oo
o`00103oool03@3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@0B02L
gol0103oool01@3OW4P000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;@3oool30000
00h0ooooD`2Y_NP50:Rmj680ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?oo
o`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0103oool000<0oooo
00H0oooO09a80018W=l0oooo0=nLB000M;l50?ooo`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018
W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool300000180oooo^@2Y
_NP00`000000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003oool0203oool00`3ogi`0B01d0;oo
o`020?ooo`050?oo_`1d000000000018W03Oool0103oool000<0oooo00L0oono07@0M02oool0oooo
0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`80
0000:@3oool3000001H0oooo^@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0<000001@3oool00`000000
oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o
_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool09@3oool30000
01X0oooo^@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`000000oooo0?ooo`0E0?oo
o`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3ookl0M01809cOo`02
0?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003oool0oooo0280oooo
0`00000N0?oookT0ZKgX00<000000:Vmj02Y_NP04`2Y_NP4000000`0oooo00<000000?ooo`3oool0
503oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00H0gia8001d_`3o
ool0oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool3
00000280oooo^02Y_NP00`000000ZKgX0:Vmj00?0:Vmj0040?ooo`000000000000000100oooo00<0
00000?ooo`3oool0503oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00H0oooo
00L0oono07@0B02Lgol0oooo0?oog`2LB4P0W=oo00T0oooo0P00000N0?ooo`8000009P3oool00`00
0000ZKgX0:Vmj02e0:Vmj0030000002Y_NP0ZKgX00X0ZKgX0P3oool3000001<0oooo00<000000?oo
o`3oool0503oool000<0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0
gooo0?ooo`2oM000M;oo203oool2000001`0oooo0`00000Z0?oookL0ZKgX00<000000:Vmj02Y_NP0
1`2Y_NP4000001H0oooo00<000000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL
0=ooo`040?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo
0?ooo`040?ooo`030000003oool0oooo01L0oooo0`00000^0?oookH0ZKgX00<000000:Vmj02Y_NP0
1@2Y_NP2000001X0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool05@3o
ool300000380oooo]P2Y_NP010000000ZKgX0:Vmj02Y_NP2000001d0oooo00<000000?ooo`3oool0
503oool001l0oooo0P00000C0?ooo`<00000=P3ooone0:Vmj0<00000803oool00`000000oooo0?oo
o`0D0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`<00000>P3ooon`0:Vmj0<000000`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo
00`0oooo0`00000n0?oooj`0ZKgX0`0000060?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3oool300000480ooooY`2Y_NP4000000X0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000000T0oooo
0P0000160?oooj80ZKgX00@0oooo00000000000000003`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo00D0oooo0`0000190?oooih0ZKgX
00@0oooo00000000000000004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`030000002Y_NP0ZKgX09H0ZKgX
00<0oooo0000000000000P00000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
4`3oool001h0oooo00<000000?ooo`0000000P00001A0?ooo`030000002Y_NP0ZKgX09<0ZKgX0`00
000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool001h0oooo0P00001E
0?ooo`030000002Y_NP0ZKgX0900ZKgX0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool04`3oool001<0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`1D0?oo
o`030000002Y_NP0ZKgX08`0ZKgX00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00X0oooo0P00001F0?ooohT0
ZKgX0P00000W0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool001<0oooo
00<0omnL04P0M02oool0303oool00`000000oooo0?ooo`1D0?ooohD0ZKgX0P00000[0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3o
ool00`000000oooo0?ooo`1D0?oooh00ZKgX0P00000`0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03P3oool00`000000oooo0?ooo`1D
0?ooog/0ZKgX0`00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool0
01<0oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?ooogL0ZKgX0`00000g0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000B02L
_i`0B01d0;ooo`0@0?ooo`800000E@3ooomb0:Vmj0<00000?03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oooa80oooo00<000000?oo
o`3oool0D`3ooom^0:Vmj0<00000@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0180oooo000C0?ooo`030?oOW01807@0_ooo01<0oooo00<000000?ooo`3oool0D`3ooomY0:Vmj0@0
0000@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000
003oool0oooo05<0ooooI@2Y_NP3000004P0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0A0?ooo`00:`3oool2000005@0ooooH02Y_NP0103oool0000000000000001<0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool0DP3o
oomL0:Vmj0@00000C`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000^
0?ooo`030000003oool0oooo0580ooooF02Y_NP3000005@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0A0?ooo`00;`3oool00`000000oooo0?ooo`1B0?oooe<0ZKgX00@0oooo0000
000000000000F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?oo
o`030000003oool0oooo0580ooooC`2Y_NP4000005`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`00<@3oool2000005<0ooooBP2Y_NP0103oool0000000000000001P0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool003<0oooo00<000000?ooo`3o
ool0D@3ooom60:Vmj0@00000I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo000d0?ooo`030000003oool0oooo0540oooo@P2Y_NP3000006T0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo0?ooo`1A0?ooocd0ZKgX00@0
oooo0000000000000000K03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
000f0?ooo`800000DP3oooli0:Vmj0@00000L03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo000h0?ooo`030000003oool0oooo0500oooo=@2Y_NP3000007D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?oo
obl0ZKgX00@0oooo0000000000000000N@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo000j0?ooo`030000003oool0oooo0540oooo:`2Y_NP4000007`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool00`000000oooo0?ooo`1A0?ooobL0
ZKgX0`0000210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool003`0oooo
0P00001B0?ooob80ZKgX00@0oooo0000000000000000Q@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00l0oooo000n0?ooo`030000003oool0oooo0500oooo7P2Y_NP4000008T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00?`3oool00`000000oooo0?oo
o`1@0?oooaX0ZKgX0`00002=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3o
ool00400oooo00<000000?ooo`3oool0D03ooolF0:Vmj0<00000T@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00110?ooo`800000D@3ooolB0:Vmj0<00000U@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo04l0
oooo3@2Y_NP3000009T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00
A03oool00`000000oooo0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0D03oool40:Vmj0<00000X@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00160?ooo`800000D@3oool2
00000:H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B03oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`00B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00C03oool2000004/0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001>0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo001?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001@0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo001A0?ooo`800000AP3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool005<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`2/0?ooo`050000003oool0oooo0?ooo`0000003`3oool005@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001E
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00
000?0?ooo`00EP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`0000003`3oool005L0oooo0P00000o0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`0000003P3oool005T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2a0?ooo`80
00003P3oool005X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2a0?ooo`800000
3P3oool005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2a0?ooo`8000003P3o
ool005`0oooo0P00000j0?ooo`030000003oool0oooo0:d0oooo1000000@0?ooo`00GP3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:T0oooo1000000D0?ooo`00G`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0oooo1000000H0?ooo`00H03oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0:40oooo1000000L0?ooo`00H@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo09h0oooo0`00000P0?ooo`00HP3oool2000003@0oooo00<00000
0?ooo`3oool0VP3oool4000002<0oooo001T0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0UP3oool4000002L0oooo001U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0TP3oool4000002/0oooo001V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
SP3oool4000002l0oooo001W0?ooo`800000;`3oool00`000000oooo0?ooo`2:0?ooo`@00000<`3o
ool006T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`270?ooo`<00000=`3oool0
06X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`230?ooo`@00000>P3oool006/0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1o0?ooo`@00000?P3oool006`0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1k0?ooo`@00000@P3oool006d0oooo0P00
000Y0?ooo`030000003oool0oooo07L0oooo100000160?ooo`00K`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo07D0oooo0`00001:0?ooo`00L03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0740oooo1000001=0?ooo`00L@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo06d0oooo1000001A0?ooo`00LP3oool2000002<0oooo00<000000?ooo`3oool0
J@3oool4000005D0oooo001d0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I@3o
ool4000005T0oooo001e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool3
000005d0oooo001f0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool40000
0600oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4000006@0
oooo001h0?ooo`8000007@3oool00`000000oooo0?ooo`1F0?ooo`@00000J03oool007X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`@00000K03oool007/0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000L03oool007`0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1;0?ooo`<00000M03oool007d0oooo0P00000H0?ooo`03
0000003oool0oooo04L0oooo1000001g0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04<0oooo1000001k0?ooo`00P03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo03l0oooo1000001o0?ooo`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03/0oooo100000230?ooo`00PP3oool2000001<0oooo00<000000?ooo`3oool0>03oool30000
08L0oooo00240?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool4000008X0
oooo00250?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool4000008h0oooo
00260?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;03oool400000980oooo0027
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool4000009H0oooo00280?oo
o`8000003@3oool00`000000oooo0?ooo`0U0?ooo`<00000VP3oool008X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0R0?ooo`@00000W@3oool008/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`@00000X@3oool008`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000Y@3oool008d0oooo0P0000070?ooo`030000003oool0
oooo01H0oooo1000002Y0?ooo`00S`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0180oooo1000002]0?ooo`00T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo0`00002a0?ooo`00T@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
1000002d0?ooo`00TP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002h0?ooo`00T`3o
ool2000000030?ooo`000000oooo00@0oooo1000002l0?ooo`00U@3oool2000000030?ooo`000000
000000800000`03oool009H0oooo0P0000340?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3o
oomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49666 Mtetra
.6912 .49666 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49666 .68568 .49009 Mtetra
.68568 .49009 .6912 .49666 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50128 .61629 .49474 Mtetra
.61629 .49474 .62206 .50128 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46699 Mtetra
.65136 .46699 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45592 Mtetra
.68693 .45592 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46699 .64558 .46019 Mtetra
.64558 .46019 .65136 .46699 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45592 .68126 .44903 Mtetra
.68126 .44903 .68693 .45592 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46812 Mtetra
.59276 .46812 .59871 .47485 .61035 .47121 .60444 .46444 Mtetra
.60444 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46812 .58676 .46133 Mtetra
.58676 .46133 .59276 .46812 .60444 .46444 .59847 .45763 Mtetra
.59847 .45763 .60444 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67555 .4421 .66979 .43511 Mtetra
.66979 .43511 .67555 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43189 Mtetra
.65193 .43189 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43628 Mtetra
.61011 .43628 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43189 .64605 .42481 Mtetra
.64605 .42481 .65193 .43189 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44442 Mtetra
.55673 .44442 .5629 .45133 .57463 .44759 .56849 .44065 Mtetra
.664 .741 .908 r
.56849 .44065 .57463 .44759 .5864 .44384 .5803 .43687 Mtetra
.5803 .43687 .5864 .44384 .59823 .44006 .59216 .43307 Mtetra
.59216 .43307 .59823 .44006 .61011 .43628 .60407 .42925 Mtetra
.60407 .42925 .61011 .43628 .62204 .43247 .61603 .42542 Mtetra
.61603 .42542 .62204 .43247 .63402 .42865 .62805 .42156 Mtetra
.664 .741 .907 r
.62805 .42156 .63402 .42865 .64605 .42481 .64011 .41769 Mtetra
.64011 .41769 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44875 Mtetra
.51543 .44875 .52175 .45563 .53336 .45191 .52707 .445 Mtetra
.664 .741 .908 r
.52707 .445 .53336 .45191 .54502 .44817 .53877 .44124 Mtetra
.663 .741 .908 r
.53877 .44124 .54502 .44817 .55673 .44442 .55051 .43747 Mtetra
.55051 .43747 .55673 .44442 .56849 .44065 .5623 .4337 Mtetra
.663 .742 .909 r
.5623 .4337 .56849 .44065 .5803 .43687 .57415 .42991 Mtetra
.663 .743 .909 r
.57415 .42991 .5803 .43687 .59216 .43307 .58604 .42609 Mtetra
.664 .743 .909 r
.58604 .42609 .59216 .43307 .60407 .42925 .59799 .42224 Mtetra
.664 .744 .909 r
.59799 .42224 .60407 .42925 .61603 .42542 .60998 .41836 Mtetra
.665 .743 .909 r
.60998 .41836 .61603 .42542 .62805 .42156 .62203 .41446 Mtetra
.665 .742 .908 r
.62203 .41446 .62805 .42156 .64011 .41769 .63413 .41053 Mtetra
.664 .742 .908 r
.63413 .41053 .64011 .41769 .65223 .4138 .64629 .4066 Mtetra
.664 .741 .907 r
.64629 .4066 .65223 .4138 .6644 .4099 .65849 .40266 Mtetra
.65849 .40266 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44875 .50906 .44182 Mtetra
.663 .741 .908 r
.50906 .44182 .51543 .44875 .52707 .445 .52074 .43806 Mtetra
.662 .741 .909 r
.52074 .43806 .52707 .445 .53877 .44124 .53247 .43433 Mtetra
.66 .742 .911 r
.53247 .43433 .53877 .44124 .55051 .43747 .54424 .43062 Mtetra
.659 .745 .913 r
.54424 .43062 .55051 .43747 .5623 .4337 .55607 .42695 Mtetra
.659 .748 .916 r
.55607 .42695 .5623 .4337 .57415 .42991 .56795 .42326 Mtetra
.66 .753 .919 r
.56795 .42326 .57415 .42991 .58604 .42609 .57988 .41949 Mtetra
.664 .757 .919 r
.57988 .41949 .58604 .42609 .59799 .42224 .59186 .41562 Mtetra
.667 .758 .918 r
.59186 .41562 .59799 .42224 .60998 .41836 .6039 .41162 Mtetra
.669 .756 .916 r
.6039 .41162 .60998 .41836 .62203 .41446 .61598 .40755 Mtetra
.669 .752 .913 r
.61598 .40755 .62203 .41446 .63413 .41053 .62811 .40347 Mtetra
.667 .747 .91 r
.62811 .40347 .63413 .41053 .64629 .4066 .6403 .39941 Mtetra
.666 .744 .909 r
.6403 .39941 .64629 .4066 .65849 .40266 .65254 .39538 Mtetra
.665 .742 .908 r
.65254 .39538 .65849 .40266 .67075 .3987 .66483 .39138 Mtetra
.664 .741 .907 r
.66483 .39138 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.663 .741 .908 r
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43862 Mtetra
.662 .741 .908 r
.49099 .43862 .49744 .44557 .50906 .44182 .50265 .43488 Mtetra
.659 .741 .91 r
.50265 .43488 .50906 .44182 .52074 .43806 .51436 .43122 Mtetra
.653 .743 .915 r
.51436 .43122 .52074 .43806 .53247 .43433 .52611 .42771 Mtetra
.645 .748 .924 r
.52611 .42771 .53247 .43433 .54424 .43062 .53793 .42441 Mtetra
.637 .76 .937 r
.53793 .42441 .54424 .43062 .55607 .42695 .5498 .42125 Mtetra
.634 .778 .95 r
.5498 .42125 .55607 .42695 .56795 .42326 .56172 .41805 Mtetra
.64 .798 .958 r
.56172 .41805 .56795 .42326 .57988 .41949 .5737 .41458 Mtetra
.655 .814 .96 r
.5737 .41458 .57988 .41949 .59186 .41562 .58572 .41067 Mtetra
.672 .819 .954 r
.58572 .41067 .59186 .41562 .6039 .41162 .59779 .40633 Mtetra
.684 .81 .943 r
.59779 .40633 .6039 .41162 .61598 .40755 .6099 .40171 Mtetra
.686 .793 .931 r
.6099 .40171 .61598 .40755 .62811 .40347 .62206 .39704 Mtetra
.681 .773 .921 r
.62206 .39704 .62811 .40347 .6403 .39941 .63427 .39252 Mtetra
.674 .757 .914 r
.63427 .39252 .6403 .39941 .65254 .39538 .64654 .3882 Mtetra
.668 .748 .91 r
.64654 .3882 .65254 .39538 .66483 .39138 .65886 .38404 Mtetra
.665 .743 .908 r
.65886 .38404 .66483 .39138 .67718 .38737 .67125 .37995 Mtetra
.664 .741 .907 r
.67125 .37995 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.663 .741 .908 r
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .43542 Mtetra
.662 .741 .908 r
.47285 .43542 .47938 .44239 .49099 .43862 .48449 .43167 Mtetra
.656 .74 .912 r
.48449 .43167 .49099 .43862 .50265 .43488 .49618 .42808 Mtetra
.643 .742 .921 r
.49618 .42808 .50265 .43488 .51436 .43122 .50792 .42484 Mtetra
.618 .748 .939 r
.50792 .42484 .51436 .43122 .52611 .42771 .51971 .42218 Mtetra
.579 .765 .967 r
.51971 .42218 .52611 .42771 .53793 .42441 .53156 .42012 Mtetra
.531 .795 .994 r
.53156 .42012 .53793 .42441 .5498 .42125 .54348 .41834 Mtetra
.49 .83 .998 r
.54348 .41834 .5498 .42125 .56172 .41805 .55547 .41629 Mtetra
.484 .865 .979 r
.55547 .41629 .56172 .41805 .5737 .41458 .56751 .41344 Mtetra
.529 .9 .963 r
.56751 .41344 .5737 .41458 .58572 .41067 .57959 .40951 Mtetra
.608 .93 .964 r
.57959 .40951 .58572 .41067 .59779 .40633 .5917 .40449 Mtetra
.682 .934 .967 r
.5917 .40449 .59779 .40633 .6099 .40171 .60384 .39866 Mtetra
.72 .903 .96 r
.60384 .39866 .6099 .40171 .62206 .39704 .61601 .39255 Mtetra
.72 .852 .944 r
.61601 .39255 .62206 .39704 .63427 .39252 .62823 .38672 Mtetra
.702 .803 .928 r
.62823 .38672 .63427 .39252 .64654 .3882 .64051 .38148 Mtetra
.683 .769 .916 r
.64051 .38148 .64654 .3882 .65886 .38404 .65286 .37683 Mtetra
.671 .751 .91 r
.65286 .37683 .65886 .38404 .67125 .37995 .66527 .37253 Mtetra
.666 .744 .908 r
.66527 .37253 .67125 .37995 .68369 .37589 .67775 .36838 Mtetra
.664 .741 .907 r
.67775 .36838 .68369 .37589 .69618 .37182 .69028 .36427 Mtetra
.69028 .36427 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43219 Mtetra
.662 .741 .908 r
.45464 .43219 .46126 .43919 .47285 .43542 .46627 .42842 Mtetra
.656 .74 .912 r
.46627 .42842 .47285 .43542 .48449 .43167 .47793 .42483 Mtetra
.637 .739 .923 r
.47793 .42483 .48449 .43167 .49618 .42808 .48965 .42176 Mtetra
.59 .741 .948 r
.48965 .42176 .49618 .42808 .50792 .42484 .50141 .41969 Mtetra
.493 .746 .985 r
.50141 .41969 .50792 .42484 .51971 .42218 .51324 .41892 Mtetra
.316 .731 .976 r
.51324 .41892 .51971 .42218 .53156 .42012 .52514 .41904 Mtetra
.123 .665 .84 r
.52514 .41904 .53156 .42012 .54348 .41834 .53711 .419 Mtetra
0 0 0 r
.53711 .419 .54348 .41834 .55547 .41629 .54917 .41786 Mtetra
.54917 .41786 .55547 .41629 .56751 .41344 .56127 .41527 Mtetra
.241 .746 .698 r
.56127 .41527 .56751 .41344 .57959 .40951 .57343 .41132 Mtetra
.381 .837 .754 r
.57343 .41132 .57959 .40951 .5917 .40449 .58561 .40598 Mtetra
.538 .923 .817 r
.58561 .40598 .5917 .40449 .60384 .39866 .5978 .3992 Mtetra
.683 .978 .885 r
.5978 .3992 .60384 .39866 .61601 .39255 .60999 .39129 Mtetra
.761 .965 .93 r
.60999 .39129 .61601 .39255 .62823 .38672 .6222 .38321 Mtetra
.759 .896 .939 r
.6222 .38321 .62823 .38672 .64051 .38148 .63447 .37601 Mtetra
.721 .821 .927 r
.63447 .37601 .64051 .38148 .65286 .37683 .64682 .3701 Mtetra
.688 .773 .916 r
.64682 .3701 .65286 .37683 .66527 .37253 .65925 .36521 Mtetra
.672 .75 .91 r
.65925 .36521 .66527 .37253 .67775 .36838 .67176 .36085 Mtetra
.666 .743 .908 r
.67176 .36085 .67775 .36838 .69028 .36427 .68433 .35666 Mtetra
.664 .741 .907 r
.68433 .35666 .69028 .36427 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48098 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42895 Mtetra
.663 .741 .908 r
.43637 .42895 .44307 .43598 .45464 .43219 .44798 .42515 Mtetra
.658 .74 .91 r
.44798 .42515 .45464 .43219 .46627 .42842 .45963 .42147 Mtetra
.64 .738 .92 r
.45963 .42147 .46627 .42842 .47793 .42483 .47132 .41831 Mtetra
.584 .733 .946 r
.47132 .41831 .47793 .42483 .48965 .42176 .48305 .4164 Mtetra
.439 .715 .983 r
.48305 .4164 .48965 .42176 .50141 .41969 .49483 .41648 Mtetra
.133 .62 .915 r
.49483 .41648 .50141 .41969 .51324 .41892 .50668 .41821 Mtetra
.104 0 0 r
.50668 .41821 .51324 .41892 .52514 .41904 .51863 .41975 Mtetra
0 0 0 r
.51863 .41975 .52514 .41904 .53711 .419 .53066 .41902 Mtetra
.376 .84 .88 r
.53066 .41902 .53711 .419 .54917 .41786 .54276 .41569 Mtetra
.616 .905 .985 r
.54276 .41569 .54917 .41786 .56127 .41527 .5549 .41126 Mtetra
.64 .849 .98 r
.5549 .41126 .56127 .41527 .57343 .41132 .5671 .40727 Mtetra
.617 .841 .985 r
.5671 .40727 .57343 .41132 .58561 .40598 .57936 .40374 Mtetra
.625 .908 .983 r
.57936 .40374 .58561 .40598 .5978 .3992 .59166 .39909 Mtetra
.68 .972 .916 r
.59166 .39909 .5978 .3992 .60999 .39129 .60394 .39183 Mtetra
.76 .994 .872 r
.60394 .39183 .60999 .39129 .6222 .38321 .61619 .38226 Mtetra
.81 .975 .899 r
.61619 .38226 .6222 .38321 .63447 .37601 .62844 .37248 Mtetra
.783 .9 .924 r
.62844 .37248 .63447 .37601 .64682 .3701 .64077 .36435 Mtetra
.726 .816 .921 r
.64077 .36435 .64682 .3701 .65925 .36521 .6532 .35821 Mtetra
.686 .767 .913 r
.6532 .35821 .65925 .36521 .67176 .36085 .66572 .35335 Mtetra
.669 .747 .909 r
.66572 .35335 .67176 .36085 .68433 .35666 .67833 .349 Mtetra
.665 .742 .908 r
.67833 .349 .68433 .35666 .69695 .35249 .69099 .34478 Mtetra
.664 .741 .907 r
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46699 Mtetra
.29379 .46699 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.663 .741 .908 r
.41803 .4257 .42482 .43276 .43637 .42895 .42962 .42186 Mtetra
.661 .74 .909 r
.42962 .42186 .43637 .42895 .44798 .42515 .44125 .41808 Mtetra
.649 .738 .914 r
.44125 .41808 .44798 .42515 .45963 .42147 .45293 .41463 Mtetra
.604 .731 .934 r
.45293 .41463 .45963 .42147 .47132 .41831 .46464 .41232 Mtetra
.464 .704 .972 r
.46464 .41232 .47132 .41831 .48305 .4164 .47638 .41231 Mtetra
.115 .58 .916 r
.47638 .41231 .48305 .4164 .49483 .41648 .48817 .41489 Mtetra
0 .43 .689 r
.48817 .41489 .49483 .41648 .50668 .41821 .50005 .4177 Mtetra
.22 .738 .854 r
.50005 .4177 .50668 .41821 .51863 .41975 .51205 .41631 Mtetra
.774 .889 .927 r
.51205 .41631 .51863 .41975 .53066 .41902 .52413 .40868 Mtetra
.779 .709 .786 r
.52413 .40868 .53066 .41902 .54276 .41569 .53622 .39758 Mtetra
.702 .59 .727 r
.53622 .39758 .54276 .41569 .5549 .41126 .54832 .38817 Mtetra
.619 .511 .709 r
.54832 .38817 .5549 .41126 .5671 .40727 .5605 .38414 Mtetra
.54 .462 .717 r
.5605 .38414 .5671 .40727 .57936 .40374 .57281 .38549 Mtetra
.492 .471 .762 r
.57281 .38549 .57936 .40374 .59166 .39909 .58525 .38858 Mtetra
.55 .618 .873 r
.58525 .38858 .59166 .39909 .60394 .39183 .59772 .38819 Mtetra
.739 .89 .948 r
.59772 .38819 .60394 .39183 .61619 .38226 .61011 .38151 Mtetra
.836 .977 .879 r
.61011 .38151 .61619 .38226 .62844 .37248 .6224 .3706 Mtetra
.841 .951 .888 r
.6224 .3706 .62844 .37248 .64077 .36435 .63471 .35988 Mtetra
.781 .87 .914 r
.63471 .35988 .64077 .36435 .6532 .35821 .64711 .35175 Mtetra
.713 .793 .914 r
.64711 .35175 .6532 .35821 .66572 .35335 .65965 .34597 Mtetra
.677 .755 .91 r
.65965 .34597 .66572 .35335 .67833 .349 .67228 .34132 Mtetra
.667 .744 .908 r
.67228 .34132 .67833 .349 .69099 .34478 .68498 .33701 Mtetra
.664 .741 .907 r
.68498 .33701 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46699 .28663 .46019 Mtetra
.28663 .46019 .29379 .46699 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.663 .741 .908 r
.4112 .41858 .41803 .4257 .42962 .42186 .42281 .41473 Mtetra
.658 .74 .91 r
.42281 .41473 .42962 .42186 .44125 .41808 .43448 .41101 Mtetra
.634 .735 .921 r
.43448 .41101 .44125 .41808 .45293 .41463 .44618 .40797 Mtetra
.542 .715 .952 r
.44618 .40797 .45293 .41463 .46464 .41232 .45789 .4069 Mtetra
.256 .62 .958 r
.45789 .4069 .46464 .41232 .47638 .41231 .46962 .40908 Mtetra
0 .421 .767 r
.46962 .40908 .47638 .41231 .48817 .41489 .48142 .41308 Mtetra
.204 .707 .906 r
.48142 .41308 .48817 .41489 .50005 .4177 .49338 .41296 Mtetra
.83 .843 .857 r
.49338 .41296 .50005 .4177 .51205 .41631 .50547 .40225 Mtetra
.814 .674 .709 r
.50547 .40225 .51205 .41631 .52413 .40868 .51759 .38304 Mtetra
.613 .495 .694 r
.51759 .38304 .52413 .40868 .53622 .39758 .52968 .379 Mtetra
.63 .547 .743 r
.52968 .379 .53622 .39758 .54832 .38817 .54181 .37495 Mtetra
.647 .615 .803 r
.54181 .37495 .54832 .38817 .5605 .38414 .554 .37088 Mtetra
.554 .37088 .5605 .38414 .57281 .38549 .56624 .36679 Mtetra
.63 .547 .743 r
.56624 .36679 .57281 .38549 .58525 .38858 .57854 .36268 Mtetra
.361 .332 .692 r
.57854 .36268 .58525 .38858 .59772 .38819 .59121 .37384 Mtetra
.476 .511 .814 r
.59121 .37384 .59772 .38819 .61011 .38151 .60384 .3765 Mtetra
.776 .85 .907 r
.60384 .3765 .61011 .38151 .6224 .3706 .61628 .36847 Mtetra
.869 .938 .863 r
.61628 .36847 .6224 .3706 .63471 .35988 .62861 .35626 Mtetra
.833 .9 .886 r
.62861 .35626 .63471 .35988 .64711 .35175 .641 .34586 Mtetra
.75 .822 .908 r
.641 .34586 .64711 .35175 .65965 .34597 .65353 .33874 Mtetra
.691 .766 .909 r
.65353 .33874 .65965 .34597 .67228 .34132 .66618 .33362 Mtetra
.669 .746 .908 r
.66618 .33362 .67228 .34132 .68498 .33701 .67892 .32919 Mtetra
.665 .742 .907 r
.67892 .32919 .68498 .33701 .69774 .33276 .69172 .32488 Mtetra
.664 .741 .907 r
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31627 Mtetra
.7175 .31627 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30758 Mtetra
.74351 .30758 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .29881 Mtetra
.76977 .29881 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27653 Mtetra
.83647 .27653 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41918 Mtetra
.38116 .41918 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .41141 Mtetra
.662 .74 .908 r
.40431 .41141 .4112 .41858 .42281 .41473 .41595 .40755 Mtetra
.654 .739 .912 r
.41595 .40755 .42281 .41473 .43448 .41101 .42765 .40392 Mtetra
.612 .729 .929 r
.42765 .40392 .43448 .41101 .44618 .40797 .43936 .4014 Mtetra
.455 .683 .963 r
.43936 .4014 .44618 .40797 .45789 .4069 .45107 .40172 Mtetra
.054 .503 .891 r
.45107 .40172 .45789 .4069 .46962 .40908 .46279 .40564 Mtetra
0 .492 .83 r
.46279 .40564 .46962 .40908 .48142 .41308 .47464 .40895 Mtetra
.757 .864 .927 r
.47464 .40895 .48142 .41308 .49338 .41296 .48671 .40193 Mtetra
.856 .716 .707 r
.48671 .40193 .49338 .41296 .50547 .40225 .49894 .37962 Mtetra
.619 .514 .712 r
.49894 .37962 .50547 .40225 .51759 .38304 .511 .37557 Mtetra
.664 .741 .907 r
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59121 .37384 .58451 .35089 Mtetra
.24 .272 .694 r
.58451 .35089 .59121 .37384 .60384 .3765 .59737 .36514 Mtetra
.573 .616 .857 r
.59737 .36514 .60384 .3765 .61628 .36847 .61003 .36402 Mtetra
.847 .871 .859 r
.61003 .36402 .61628 .36847 .62861 .35626 .62244 .35244 Mtetra
.862 .891 .855 r
.62244 .35244 .62861 .35626 .641 .34586 .63483 .34021 Mtetra
.785 .837 .892 r
.63483 .34021 .641 .34586 .65353 .33874 .64736 .33162 Mtetra
.707 .776 .906 r
.64736 .33162 .65353 .33874 .66618 .33362 .66003 .32591 Mtetra
.673 .749 .907 r
.66003 .32591 .66618 .33362 .67892 .32919 .6728 .3213 Mtetra
.665 .742 .907 r
.6728 .3213 .67892 .32919 .69172 .32488 .68564 .31694 Mtetra
.664 .741 .907 r
.68564 .31694 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31627 .71151 .30825 Mtetra
.71151 .30825 .7175 .31627 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30758 .7376 .29948 Mtetra
.7376 .29948 .74351 .30758 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .29881 .76394 .29064 Mtetra
.76394 .29064 .76977 .29881 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27653 .83087 .26817 Mtetra
.83087 .26817 .83647 .27653 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45392 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41918 .37415 .412 Mtetra
.37415 .412 .38116 .41918 .39271 .4153 .38573 .40809 Mtetra
.663 .741 .907 r
.38573 .40809 .39271 .4153 .40431 .41141 .39736 .40418 Mtetra
.662 .74 .908 r
.39736 .40418 .40431 .41141 .41595 .40755 .40904 .40031 Mtetra
.649 .737 .914 r
.40904 .40031 .41595 .40755 .42765 .40392 .42076 .39678 Mtetra
.59 .721 .934 r
.42076 .39678 .42765 .40392 .43936 .4014 .43249 .39476 Mtetra
.373 .642 .96 r
.43249 .39476 .43936 .4014 .45107 .40172 .44419 .39622 Mtetra
0 .441 .855 r
.44419 .39622 .45107 .40172 .46279 .40564 .45592 .40107 Mtetra
.293 .676 .974 r
.45592 .40107 .46279 .40564 .47464 .40895 .46783 .40219 Mtetra
.853 .786 .786 r
.46783 .40219 .47464 .40895 .48671 .40193 .48005 .38736 Mtetra
.782 .658 .726 r
.48005 .38736 .48671 .40193 .49894 .37962 .49225 .37213 Mtetra
.664 .741 .907 r
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.015 .384 .845 r
.57808 .34316 .58451 .35089 .59737 .36514 .59079 .35021 Mtetra
.337 .422 .802 r
.59079 .35021 .59737 .36514 .61003 .36402 .60364 .35689 Mtetra
.788 .793 .857 r
.60364 .35689 .61003 .36402 .62244 .35244 .61618 .34746 Mtetra
.864 .856 .832 r
.61618 .34746 .62244 .35244 .63483 .34021 .6286 .33424 Mtetra
.806 .83 .87 r
.6286 .33424 .63483 .34021 .64736 .33162 .64114 .32442 Mtetra
.721 .779 .899 r
.64114 .32442 .64736 .33162 .66003 .32591 .65383 .31812 Mtetra
.677 .75 .906 r
.65383 .31812 .66003 .32591 .6728 .3213 .66664 .31335 Mtetra
.666 .742 .907 r
.66664 .31335 .6728 .3213 .68564 .31694 .67952 .30893 Mtetra
.664 .741 .907 r
.67952 .30893 .68564 .31694 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26817 .82521 .25974 Mtetra
.82521 .25974 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45392 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.663 .741 .908 r
.3787 .40083 .38573 .40809 .39736 .40418 .39036 .39689 Mtetra
.661 .74 .908 r
.39036 .39689 .39736 .40418 .40904 .40031 .40207 .393 Mtetra
.646 .736 .914 r
.40207 .393 .40904 .40031 .42076 .39678 .41381 .38953 Mtetra
.576 .714 .936 r
.41381 .38953 .42076 .39678 .43249 .39476 .42556 .38779 Mtetra
.335 .613 .951 r
.42556 .38779 .43249 .39476 .44419 .39622 .43727 .38989 Mtetra
.019 .441 .869 r
.43727 .38989 .44419 .39622 .45592 .40107 .44901 .395 Mtetra
.5 .726 .974 r
.44901 .395 .45592 .40107 .46783 .40219 .46098 .39427 Mtetra
.873 .762 .736 r
.46098 .39427 .46783 .40219 .48005 .38736 .47334 .37445 Mtetra
.742 .661 .771 r
.47334 .37445 .48005 .38736 .49225 .37213 .48551 .36458 Mtetra
.664 .741 .907 r
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.407 .626 .943 r
.57159 .33537 .57808 .34316 .59079 .35021 .58422 .33694 Mtetra
.042 .262 .758 r
.58422 .33694 .59079 .35021 .60364 .35689 .59718 .34859 Mtetra
.744 .756 .862 r
.59718 .34859 .60364 .35689 .61618 .34746 .60981 .34097 Mtetra
.852 .817 .815 r
.60981 .34097 .61618 .34746 .6286 .33424 .62229 .32741 Mtetra
.809 .808 .85 r
.62229 .32741 .6286 .33424 .64114 .32442 .63485 .31688 Mtetra
.728 .774 .889 r
.63485 .31688 .64114 .32442 .65383 .31812 .64758 .31022 Mtetra
.68 .749 .904 r
.64758 .31022 .65383 .31812 .66664 .31335 .66042 .30532 Mtetra
.666 .742 .907 r
.66042 .30532 .66664 .31335 .67952 .30893 .67334 .30085 Mtetra
.664 .741 .907 r
.67334 .30085 .67952 .30893 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .29201 Mtetra
.69937 .29201 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23517 .44007 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.663 .741 .908 r
.37161 .39351 .3787 .40083 .39036 .39689 .3833 .38954 Mtetra
.661 .74 .908 r
.3833 .38954 .39036 .39689 .40207 .393 .39504 .38561 Mtetra
.646 .736 .914 r
.39504 .38561 .40207 .393 .41381 .38953 .40682 .38211 Mtetra
.577 .711 .934 r
.40682 .38211 .41381 .38953 .42556 .38779 .41859 .38035 Mtetra
.353 .608 .945 r
.41859 .38035 .42556 .38779 .43727 .38989 .43032 .38242 Mtetra
.102 .459 .887 r
.43032 .38242 .43727 .38989 .44901 .395 .44207 .38752 Mtetra
.528 .692 .944 r
.44207 .38752 .44901 .395 .46098 .39427 .45407 .38676 Mtetra
.878 .769 .739 r
.45407 .38676 .46098 .39427 .47334 .37445 .4665 .36688 Mtetra
.79 .77 .835 r
.4665 .36688 .47334 .37445 .48551 .36458 .47872 .35696 Mtetra
.664 .741 .907 r
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.407 .626 .943 r
.56505 .32751 .57159 .33537 .58422 .33694 .5777 .32905 Mtetra
0 .127 .65 r
.5777 .32905 .58422 .33694 .59718 .34859 .59067 .3407 Mtetra
.748 .769 .87 r
.59067 .3407 .59718 .34859 .60981 .34097 .60334 .33303 Mtetra
.837 .784 .801 r
.60334 .33303 .60981 .34097 .62229 .32741 .61588 .31942 Mtetra
.798 .779 .835 r
.61588 .31942 .62229 .32741 .63485 .31688 .6285 .30884 Mtetra
.725 .761 .881 r
.6285 .30884 .63485 .31688 .64758 .31022 .64127 .30215 Mtetra
.679 .746 .902 r
.64127 .30215 .64758 .31022 .66042 .30532 .65415 .29721 Mtetra
.666 .742 .906 r
.65415 .29721 .66042 .30532 .67334 .30085 .66711 .2927 Mtetra
.664 .741 .907 r
.66711 .2927 .67334 .30085 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .29201 .69322 .28378 Mtetra
.69322 .28378 .69937 .29201 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23517 .44007 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .42541 Mtetra
.24997 .42541 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.663 .741 .907 r
.36446 .38613 .37161 .39351 .3833 .38954 .37618 .38212 Mtetra
.662 .74 .908 r
.37618 .38212 .3833 .38954 .39504 .38561 .38796 .37815 Mtetra
.649 .736 .913 r
.38796 .37815 .39504 .38561 .40682 .38211 .39977 .37454 Mtetra
.592 .714 .928 r
.39977 .37454 .40682 .38211 .41859 .38035 .41158 .37242 Mtetra
.412 .624 .94 r
.41158 .37242 .41859 .38035 .43032 .38242 .42335 .37382 Mtetra
.193 .481 .895 r
.42335 .37382 .43032 .38242 .44207 .38752 .43512 .37861 Mtetra
.456 .618 .92 r
.43512 .37861 .44207 .38752 .45407 .38676 .44709 .37966 Mtetra
.851 .783 .785 r
.44709 .37966 .45407 .38676 .4665 .36688 .45949 .36467 Mtetra
.903 .898 .811 r
.45949 .36467 .4665 .36688 .47872 .35696 .47187 .34928 Mtetra
.664 .741 .907 r
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.015 .384 .845 r
.55845 .31959 .56505 .32751 .5777 .32905 .57121 .32658 Mtetra
.387 0 0 r
.57121 .32658 .5777 .32905 .59067 .3407 .58411 .33321 Mtetra
.786 .789 .854 r
.58411 .33321 .59067 .3407 .60334 .33303 .59679 .32365 Mtetra
.819 .753 .79 r
.59679 .32365 .60334 .33303 .61588 .31942 .60939 .31027 Mtetra
.778 .75 .828 r
.60939 .31027 .61588 .31942 .6285 .30884 .62208 .30031 Mtetra
.715 .747 .877 r
.62208 .30031 .6285 .30884 .64127 .30215 .6349 .2939 Mtetra
.677 .743 .9 r
.6349 .2939 .64127 .30215 .65415 .29721 .64783 .28901 Mtetra
.666 .741 .906 r
.64783 .28901 .65415 .29721 .66711 .2927 .66083 .28448 Mtetra
.664 .741 .907 r
.66083 .28448 .66711 .2927 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26642 Mtetra
.71345 .26642 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23328 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .42541 .24247 .41828 Mtetra
.24247 .41828 .24997 .42541 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38212 .36901 .37465 Mtetra
.662 .74 .908 r
.36901 .37465 .37618 .38212 .38796 .37815 .38082 .37062 Mtetra
.654 .737 .911 r
.38082 .37062 .38796 .37815 .39977 .37454 .39267 .36684 Mtetra
.614 .72 .921 r
.39267 .36684 .39977 .37454 .41158 .37242 .40453 .36417 Mtetra
.488 .653 .932 r
.40453 .36417 .41158 .37242 .42335 .37382 .41635 .36436 Mtetra
.298 .519 .9 r
.41635 .36436 .42335 .37382 .43512 .37861 .42815 .36819 Mtetra
.368 .534 .888 r
.42815 .36819 .43512 .37861 .44709 .37966 .44009 .37139 Mtetra
.737 .747 .86 r
.44009 .37139 .44709 .37966 .45949 .36467 .45236 .36417 Mtetra
.953 .888 .73 r
.45236 .36417 .45949 .36467 .47187 .34928 .46497 .34154 Mtetra
.664 .741 .907 r
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
0 0 .512 r
.5518 .31159 .55845 .31959 .57121 .32658 .56466 .32582 Mtetra
.205 .728 .854 r
.56466 .32582 .57121 .32658 .58411 .33321 .57748 .32455 Mtetra
.808 .766 .814 r
.57748 .32455 .58411 .33321 .59679 .32365 .59016 .31273 Mtetra
.794 .721 .784 r
.59016 .31273 .59679 .32365 .60939 .31027 .60283 .30025 Mtetra
.751 .726 .829 r
.60283 .30025 .60939 .31027 .62208 .30031 .61559 .29144 Mtetra
.701 .736 .878 r
.61559 .29144 .62208 .30031 .6349 .2939 .62848 .28553 Mtetra
.673 .74 .901 r
.62848 .28553 .6349 .2939 .64783 .28901 .64145 .28073 Mtetra
.665 .741 .906 r
.64145 .28073 .64783 .28901 .66083 .28448 .65449 .27619 Mtetra
.664 .741 .907 r
.65449 .27619 .66083 .28448 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26712 Mtetra
.68077 .26712 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26642 .70729 .25797 Mtetra
.70729 .25797 .71345 .26642 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39137 Mtetra
.29182 .39137 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37465 .36178 .36711 Mtetra
.663 .74 .908 r
.36178 .36711 .36901 .37465 .38082 .37062 .37362 .36303 Mtetra
.658 .738 .909 r
.37362 .36303 .38082 .37062 .39267 .36684 .3855 .35909 Mtetra
.634 .727 .915 r
.3855 .35909 .39267 .36684 .40453 .36417 .39742 .35582 Mtetra
.557 .682 .923 r
.39742 .35582 .40453 .36417 .41635 .36436 .40931 .35456 Mtetra
.415 .576 .904 r
.40931 .35456 .41635 .36436 .42815 .36819 .42118 .35658 Mtetra
.357 .501 .865 r
.42118 .35658 .42815 .36819 .44009 .37139 .4331 .36045 Mtetra
.536 .611 .875 r
.4331 .36045 .44009 .37139 .45236 .36417 .44523 .36014 Mtetra
.838 .872 .868 r
.44523 .36014 .45236 .36417 .46497 .34154 .45768 .34911 Mtetra
.816 .945 .59 r
.45768 .34911 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.664 .741 .907 r
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
0 .138 .658 r
.53248 .30791 .53922 .31593 .5518 .31159 .54519 .31901 Mtetra
.483 .002 .038 r
.54519 .31901 .5518 .31159 .56466 .32582 .558 .3215 Mtetra
.779 .883 .921 r
.558 .3215 .56466 .32582 .57748 .32455 .57076 .31317 Mtetra
.79 .713 .78 r
.57076 .31317 .57748 .32455 .59016 .31273 .58347 .30061 Mtetra
.761 .693 .787 r
.58347 .30061 .59016 .31273 .60283 .30025 .59621 .28988 Mtetra
.724 .711 .838 r
.59621 .28988 .60283 .30025 .61559 .29144 .60906 .28248 Mtetra
.687 .73 .883 r
.60906 .28248 .61559 .29144 .62848 .28553 .622 .27709 Mtetra
.669 .738 .902 r
.622 .27709 .62848 .28553 .64145 .28073 .63502 .27239 Mtetra
.665 .74 .906 r
.63502 .27239 .64145 .28073 .65449 .27619 .6481 .26782 Mtetra
.664 .741 .907 r
.6481 .26782 .65449 .27619 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26712 .67446 .25868 Mtetra
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21647 Mtetra
.79619 .21647 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39137 .28434 .38397 Mtetra
.28434 .38397 .29182 .39137 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36774 Mtetra
.3309 .36774 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .36711 .35449 .35951 Mtetra
.663 .741 .907 r
.35449 .35951 .36178 .36711 .37362 .36303 .36636 .35538 Mtetra
.661 .74 .908 r
.36636 .35538 .37362 .36303 .3855 .35909 .37828 .35131 Mtetra
.649 .733 .91 r
.37828 .35131 .3855 .35909 .39742 .35582 .39024 .34758 Mtetra
.609 .707 .914 r
.39024 .34758 .39742 .35582 .40931 .35456 .40222 .34499 Mtetra
.521 .636 .904 r
.40222 .34499 .40931 .35456 .42118 .35658 .41417 .34475 Mtetra
.432 .539 .865 r
.41417 .34475 .42118 .35658 .4331 .36045 .42613 .34713 Mtetra
.442 .516 .839 r
.42613 .34713 .4331 .36045 .44523 .36014 .43819 .34974 Mtetra
.579 .646 .88 r
.43819 .34974 .44523 .36014 .45768 .34911 .45046 .34809 Mtetra
.748 .964 .935 r
.45046 .34809 .45768 .34911 .47027 .32948 .46293 .3401 Mtetra
0 0 0 r
.46293 .3401 .47027 .32948 .4826 .32521 .47547 .32857 Mtetra
.622 .944 .745 r
.47547 .32857 .4826 .32521 .49499 .32091 .488 .31877 Mtetra
.585 .902 .984 r
.488 .31877 .49499 .32091 .50743 .3166 .5005 .31443 Mtetra
.079 .616 .856 r
.5005 .31443 .50743 .3166 .51992 .31226 .51304 .31555 Mtetra
.425 0 0 r
.51304 .31555 .51992 .31226 .53248 .30791 .52568 .31843 Mtetra
.407 0 .089 r
.52568 .31843 .53248 .30791 .54519 .31901 .53842 .31778 Mtetra
.692 .958 .947 r
.53842 .31778 .54519 .31901 .558 .3215 .5512 .31074 Mtetra
.781 .722 .797 r
.5512 .31074 .558 .3215 .57076 .31317 .56396 .2994 Mtetra
.752 .668 .768 r
.56396 .2994 .57076 .31317 .58347 .30061 .57673 .28825 Mtetra
.728 .678 .802 r
.57673 .28825 .58347 .30061 .59621 .28988 .58956 .27974 Mtetra
.699 .708 .855 r
.58956 .27974 .59621 .28988 .60906 .28248 .60247 .2736 Mtetra
.676 .73 .891 r
.60247 .2736 .60906 .28248 .622 .27709 .61546 .26862 Mtetra
.666 .739 .904 r
.61546 .26862 .622 .27709 .63502 .27239 .62853 .26397 Mtetra
.664 .74 .907 r
.62853 .26397 .63502 .27239 .6481 .26782 .64166 .25938 Mtetra
.664 .741 .907 r
.64166 .25938 .6481 .26782 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21647 .79023 .20758 Mtetra
.79023 .20758 .79619 .21647 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19787 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36774 .32348 .36014 Mtetra
.32348 .36014 .3309 .36774 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35538 .35904 .34768 Mtetra
.663 .74 .908 r
.35904 .34768 .36636 .35538 .37828 .35131 .371 .34352 Mtetra
.658 .737 .908 r
.371 .34352 .37828 .35131 .39024 .34758 .383 .33949 Mtetra
.64 .724 .909 r
.383 .33949 .39024 .34758 .40222 .34499 .39504 .33598 Mtetra
.596 .684 .903 r
.39504 .33598 .40222 .34499 .41417 .34475 .40709 .33375 Mtetra
.53 .609 .876 r
.40709 .33375 .41417 .34475 .42613 .34713 .41914 .33353 Mtetra
.485 .536 .834 r
.41914 .33353 .42613 .34713 .43819 .34974 .43123 .33501 Mtetra
.5 .527 .816 r
.43123 .33501 .43819 .34974 .45046 .34809 .44343 .33628 Mtetra
.562 .61 .858 r
.44343 .33628 .45046 .34809 .46293 .3401 .45577 .33524 Mtetra
.621 .827 .979 r
.45577 .33524 .46293 .3401 .47547 .32857 .46824 .33154 Mtetra
0 0 0 r
.46824 .33154 .47547 .32857 .488 .31877 .48079 .32672 Mtetra
.155 0 0 r
.48079 .32672 .488 .31877 .5005 .31443 .49339 .32235 Mtetra
.184 0 0 r
.49339 .32235 .5005 .31443 .51304 .31555 .50605 .31844 Mtetra
0 0 0 r
.50605 .31844 .51304 .31555 .52568 .31843 .51877 .3134 Mtetra
.762 .859 .921 r
.51877 .3134 .52568 .31843 .53842 .31778 .53154 .30568 Mtetra
.752 .691 .793 r
.53154 .30568 .53842 .31778 .5512 .31074 .54433 .29562 Mtetra
.732 .643 .761 r
.54433 .29562 .5512 .31074 .56396 .2994 .55713 .28533 Mtetra
.716 .65 .782 r
.55713 .28533 .56396 .2994 .57673 .28825 .56996 .27674 Mtetra
.699 .682 .83 r
.56996 .27674 .57673 .28825 .58956 .27974 .58286 .27016 Mtetra
.681 .716 .876 r
.58286 .27016 .58956 .27974 .60247 .2736 .59584 .26488 Mtetra
.669 .734 .899 r
.59584 .26488 .60247 .2736 .61546 .26862 .60888 .26013 Mtetra
.665 .739 .906 r
.60888 .26013 .61546 .26862 .62853 .26397 .62198 .2555 Mtetra
.664 .741 .907 r
.62198 .2555 .62853 .26397 .64166 .25938 .63515 .25088 Mtetra
.63515 .25088 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24158 Mtetra
.66168 .24158 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19787 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34352 .36365 .33571 Mtetra
.662 .74 .907 r
.36365 .33571 .371 .34352 .383 .33949 .3757 .33152 Mtetra
.656 .734 .907 r
.3757 .33152 .383 .33949 .39504 .33598 .38779 .3275 Mtetra
.638 .716 .904 r
.38779 .3275 .39504 .33598 .40709 .33375 .39991 .32402 Mtetra
.604 .672 .888 r
.39991 .32402 .40709 .33375 .41914 .33353 .41206 .32156 Mtetra
.564 .607 .854 r
.41206 .32156 .41914 .33353 .43123 .33501 .42424 .32042 Mtetra
.543 .553 .815 r
.42424 .32042 .43123 .33501 .44343 .33628 .43647 .3202 Mtetra
.55 .537 .794 r
.43647 .3202 .44343 .33628 .45577 .33524 .44879 .3198 Mtetra
.578 .561 .799 r
.44879 .3198 .45577 .33524 .46824 .33154 .46123 .31827 Mtetra
.615 .612 .825 r
.46123 .31827 .46824 .33154 .48079 .32672 .47377 .31527 Mtetra
.654 .662 .846 r
.47377 .31527 .48079 .32672 .49339 .32235 .48639 .31086 Mtetra
.685 .675 .834 r
.48639 .31086 .49339 .32235 .50605 .31844 .49909 .30504 Mtetra
.701 .651 .797 r
.49909 .30504 .50605 .31844 .51877 .3134 .51184 .29774 Mtetra
.704 .625 .766 r
.51184 .29774 .51877 .3134 .53154 .30568 .52462 .28929 Mtetra
.702 .616 .758 r
.52462 .28929 .53154 .30568 .54433 .29562 .53743 .28065 Mtetra
.697 .63 .778 r
.53743 .28065 .54433 .29562 .55713 .28533 .55028 .27291 Mtetra
.69 .664 .819 r
.55028 .27291 .55713 .28533 .56996 .27674 .56317 .2665 Mtetra
.68 .702 .863 r
.56317 .2665 .56996 .27674 .58286 .27016 .57613 .26112 Mtetra
.67 .727 .892 r
.57613 .26112 .58286 .27016 .59584 .26488 .58915 .25627 Mtetra
.665 .737 .904 r
.58915 .25627 .59584 .26488 .60888 .26013 .60223 .2516 Mtetra
.664 .74 .907 r
.60223 .2516 .60888 .26013 .62198 .2555 .61538 .24695 Mtetra
.664 .741 .907 r
.61538 .24695 .62198 .2555 .63515 .25088 .62859 .24229 Mtetra
.62859 .24229 .63515 .25088 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24158 .6552 .23291 Mtetra
.6552 .23291 .66168 .24158 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33571 .35624 .32784 Mtetra
.663 .74 .907 r
.35624 .32784 .36365 .33571 .3757 .33152 .36832 .32357 Mtetra
.662 .739 .907 r
.36832 .32357 .3757 .33152 .38779 .3275 .38046 .31934 Mtetra
.656 .732 .905 r
.38046 .31934 .38779 .3275 .39991 .32402 .39264 .31525 Mtetra
.644 .713 .898 r
.39264 .31525 .39991 .32402 .41206 .32156 .40486 .31153 Mtetra
.624 .676 .879 r
.40486 .31153 .41206 .32156 .42424 .32042 .41712 .3084 Mtetra
.604 .627 .847 r
.41712 .3084 .42424 .32042 .43647 .3202 .42944 .30588 Mtetra
.595 .585 .812 r
.42944 .30588 .43647 .3202 .44879 .3198 .44181 .30365 Mtetra
.598 .564 .787 r
.44181 .30365 .44879 .3198 .46123 .31827 .45426 .30113 Mtetra
.613 .561 .772 r
.45426 .30113 .46123 .31827 .47377 .31527 .4668 .29779 Mtetra
.632 .568 .765 r
.4668 .29779 .47377 .31527 .48639 .31086 .47943 .29334 Mtetra
.651 .578 .76 r
.47943 .29334 .48639 .31086 .49909 .30504 .49213 .28776 Mtetra
.664 .588 .76 r
.49213 .28776 .49909 .30504 .51184 .29774 .50488 .28136 Mtetra
.673 .603 .768 r
.50488 .28136 .51184 .29774 .52462 .28929 .51767 .27466 Mtetra
.678 .626 .79 r
.51767 .27466 .52462 .28929 .53743 .28065 .53051 .26825 Mtetra
.678 .66 .825 r
.53051 .26825 .53743 .28065 .55028 .27291 .54339 .26245 Mtetra
.675 .696 .862 r
.54339 .26245 .55028 .27291 .56317 .2665 .55634 .25723 Mtetra
.669 .722 .889 r
.55634 .25723 .56317 .2665 .57613 .26112 .56934 .25238 Mtetra
.666 .735 .902 r
.56934 .25238 .57613 .26112 .58915 .25627 .58241 .24768 Mtetra
.664 .74 .906 r
.58241 .24768 .58915 .25627 .60223 .2516 .59553 .24301 Mtetra
.664 .741 .907 r
.59553 .24301 .60223 .2516 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36832 .32357 .36089 .3156 Mtetra
.663 .74 .907 r
.36089 .3156 .36832 .32357 .38046 .31934 .37306 .31128 Mtetra
.662 .738 .907 r
.37306 .31128 .38046 .31934 .39264 .31525 .38528 .30697 Mtetra
.659 .732 .904 r
.38528 .30697 .39264 .31525 .40486 .31153 .39756 .30274 Mtetra
.653 .718 .896 r
.39756 .30274 .40486 .31153 .41712 .3084 .40988 .29868 Mtetra
.645 .694 .881 r
.40988 .29868 .41712 .3084 .42944 .30588 .42226 .29481 Mtetra
.637 .662 .858 r
.42226 .29481 .42944 .30588 .44181 .30365 .43469 .2911 Mtetra
.634 .634 .833 r
.43469 .2911 .44181 .30365 .45426 .30113 .44719 .28734 Mtetra
.636 .616 .813 r
.44719 .28734 .45426 .30113 .4668 .29779 .45976 .2833 Mtetra
.643 .61 .801 r
.45976 .2833 .4668 .29779 .47943 .29334 .4724 .2788 Mtetra
.652 .614 .799 r
.4724 .2788 .47943 .29334 .49213 .28776 .4851 .27384 Mtetra
.66 .627 .806 r
.4851 .27384 .49213 .28776 .50488 .28136 .49786 .2686 Mtetra
.666 .648 .823 r
.49786 .2686 .50488 .28136 .51767 .27466 .51068 .26331 Mtetra
.669 .676 .847 r
.51068 .26331 .51767 .27466 .53051 .26825 .52354 .25817 Mtetra
.669 .703 .872 r
.52354 .25817 .53051 .26825 .54339 .26245 .53647 .25323 Mtetra
.667 .723 .891 r
.53647 .25323 .54339 .26245 .55634 .25723 .54945 .24845 Mtetra
.665 .735 .902 r
.54945 .24845 .55634 .25723 .56934 .25238 .5625 .24375 Mtetra
.664 .739 .906 r
.5625 .24375 .56934 .25238 .58241 .24768 .57561 .23906 Mtetra
.664 .74 .907 r
.57561 .23906 .58241 .24768 .59553 .24301 .58877 .23436 Mtetra
.664 .741 .907 r
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31128 .36559 .3032 Mtetra
.664 .74 .907 r
.36559 .3032 .37306 .31128 .38528 .30697 .37785 .29882 Mtetra
.663 .739 .906 r
.37785 .29882 .38528 .30697 .39756 .30274 .39017 .29443 Mtetra
.662 .735 .904 r
.39017 .29443 .39756 .30274 .40988 .29868 .40254 .29006 Mtetra
.66 .728 .9 r
.40254 .29006 .40988 .29868 .42226 .29481 .41496 .28571 Mtetra
.658 .716 .891 r
.41496 .28571 .42226 .29481 .43469 .2911 .42745 .28139 Mtetra
.656 .702 .88 r
.42745 .28139 .43469 .2911 .44719 .28734 .43999 .27706 Mtetra
.656 .69 .87 r
.43999 .27706 .44719 .28734 .45976 .2833 .4526 .27264 Mtetra
.658 .683 .863 r
.4526 .27264 .45976 .2833 .4724 .2788 .46526 .2681 Mtetra
.661 .684 .862 r
.46526 .2681 .4724 .2788 .4851 .27384 .47799 .26344 Mtetra
.663 .692 .867 r
.47799 .26344 .4851 .27384 .49786 .2686 .49077 .2587 Mtetra
.665 .705 .877 r
.49077 .2587 .49786 .2686 .51068 .26331 .50362 .25394 Mtetra
.665 .719 .888 r
.50362 .25394 .51068 .26331 .52354 .25817 .51652 .2492 Mtetra
.665 .73 .898 r
.51652 .2492 .52354 .25817 .53647 .25323 .52949 .24449 Mtetra
.664 .736 .903 r
.52949 .24449 .53647 .25323 .54945 .24845 .54251 .23979 Mtetra
.664 .739 .906 r
.54251 .23979 .54945 .24845 .5625 .24375 .5556 .23509 Mtetra
.664 .74 .907 r
.5556 .23509 .5625 .24375 .57561 .23906 .56875 .23037 Mtetra
.664 .741 .907 r
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .29882 .37036 .29064 Mtetra
.664 .74 .907 r
.37036 .29064 .37785 .29882 .39017 .29443 .38271 .28619 Mtetra
.38271 .28619 .39017 .29443 .40254 .29006 .39512 .28173 Mtetra
.663 .738 .906 r
.39512 .28173 .40254 .29006 .41496 .28571 .40758 .27725 Mtetra
.663 .736 .904 r
.40758 .27725 .41496 .28571 .42745 .28139 .42011 .27276 Mtetra
.663 .732 .901 r
.42011 .27276 .42745 .28139 .43999 .27706 .43269 .26825 Mtetra
.663 .729 .899 r
.43269 .26825 .43999 .27706 .4526 .27264 .44533 .26371 Mtetra
.663 .727 .897 r
.44533 .26371 .4526 .27264 .46526 .2681 .45803 .25913 Mtetra
.663 .727 .896 r
.45803 .25913 .46526 .2681 .47799 .26344 .47079 .25451 Mtetra
.664 .729 .898 r
.47079 .25451 .47799 .26344 .49077 .2587 .48361 .24987 Mtetra
.664 .733 .901 r
.48361 .24987 .49077 .2587 .50362 .25394 .4965 .2452 Mtetra
.664 .736 .903 r
.4965 .2452 .50362 .25394 .51652 .2492 .50944 .24051 Mtetra
.664 .739 .905 r
.50944 .24051 .51652 .2492 .52949 .24449 .52244 .23581 Mtetra
.664 .74 .907 r
.52244 .23581 .52949 .24449 .54251 .23979 .53551 .2311 Mtetra
.664 .741 .907 r
.53551 .2311 .54251 .23979 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28619 .37519 .27791 Mtetra
.37519 .27791 .38271 .28619 .39512 .28173 .38763 .2734 Mtetra
.664 .74 .907 r
.38763 .2734 .39512 .28173 .40758 .27725 .40013 .26887 Mtetra
.40013 .26887 .40758 .27725 .42011 .27276 .4127 .26432 Mtetra
.664 .739 .906 r
.4127 .26432 .42011 .27276 .43269 .26825 .42532 .25975 Mtetra
.42532 .25975 .43269 .26825 .44533 .26371 .43799 .25515 Mtetra
.664 .738 .906 r
.43799 .25515 .44533 .26371 .45803 .25913 .45073 .25053 Mtetra
.664 .739 .906 r
.45073 .25053 .45803 .25913 .47079 .25451 .46353 .24589 Mtetra
.46353 .24589 .47079 .25451 .48361 .24987 .47639 .24123 Mtetra
.664 .74 .906 r
.47639 .24123 .48361 .24987 .4965 .2452 .48931 .23654 Mtetra
.664 .74 .907 r
.48931 .23654 .4965 .2452 .50944 .24051 .50229 .23183 Mtetra
.50229 .23183 .50944 .24051 .52244 .23581 .51534 .2271 Mtetra
.664 .741 .907 r
.51534 .2271 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26887 .39262 .26044 Mtetra
.39262 .26044 .40013 .26887 .4127 .26432 .40522 .25585 Mtetra
.40522 .25585 .4127 .26432 .42532 .25975 .41787 .25123 Mtetra
.664 .74 .907 r
.41787 .25123 .42532 .25975 .43799 .25515 .43059 .24659 Mtetra
.43059 .24659 .43799 .25515 .45073 .25053 .44337 .24193 Mtetra
.44337 .24193 .45073 .25053 .46353 .24589 .45621 .23725 Mtetra
.45621 .23725 .46353 .24589 .47639 .24123 .4691 .23255 Mtetra
.664 .741 .907 r
.4691 .23255 .47639 .24123 .48931 .23654 .48206 .22782 Mtetra
.48206 .22782 .48931 .23654 .50229 .23183 .49509 .22308 Mtetra
.49509 .22308 .50229 .23183 .51534 .2271 .50817 .2183 Mtetra
.50817 .2183 .51534 .2271 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25656 Mtetra
.37246 .25656 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24266 Mtetra
.41037 .24266 .41787 .25123 .43059 .24659 .42312 .23798 Mtetra
.42312 .23798 .43059 .24659 .44337 .24193 .43594 .23328 Mtetra
.43594 .23328 .44337 .24193 .45621 .23725 .44881 .22856 Mtetra
.44881 .22856 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25656 .36478 .24802 Mtetra
.36478 .24802 .37246 .25656 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24266 .4028 .234 Mtetra
.4028 .234 .41037 .24266 .42312 .23798 .41559 .22928 Mtetra
.41559 .22928 .42312 .23798 .43594 .23328 .42844 .22454 Mtetra
.42844 .22454 .43594 .23328 .44881 .22856 .44136 .21978 Mtetra
.44136 .21978 .44881 .22856 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23473 Mtetra
.36968 .23473 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23473 .3619 .226 Mtetra
.3619 .226 .36968 .23473 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19787 Mtetra
.40556 .19787 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19787 .39779 .18881 Mtetra
.39779 .18881 .40556 .19787 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15179 Mtetra
.36602 .15179 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15179 .3579 .14231 Mtetra
.3579 .14231 .36602 .15179 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15336 Mtetra
.2971 .15336 .30546 .16272 .31847 .15766 .31015 .14825 Mtetra
.31015 .14825 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000/@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000]02Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H
0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool30000
0;H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0;H0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000M`2Y_NP50:Vmi`D0ZKgX1@2Y_NL50:Vmj0H0ZKgW:`2Y_NP00`000000ZKgX
0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`00
<P3oool3000007L0ZKgX202Y_NL20:Vmj0<0ZKcW1@2Y_NL50:Vli`/0ZKgW9@2Y_NP00`000000ZKgX
0:Vmj00Y0:Vmj0030000003oool0oooo03X0oooo000`0?ooo`80000000<0ZKgX0000002Y_NP0M@2Y
_NP:0:Vmi`H0ZKcW0`2Y_NL20:Zji@D0ZKcW0`2Y_NL30:ZliPX0ZKgW7P2Y_NP2000002`0ZKgX00<0
00000?ooo`3oool0>@3oool002`0oooo00@0ZKgX0000000000000000M`2Y_NP:0:Vmi`D0ZK_V1@2Y
_>L50:Zji@D0ZKcW1P2Z_>H20:Vmi`<0Z[cV1@2Y_NLJ0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vm
j00Y0:Vmj0030000003oool0oooo03T0oooo000[0?ooo`800000N02Y_NP30:Vli`L0ZKgW0`2Y^^D5
0:VkiPD0Z[SS1@2Z^^D50:Zii0/0Z[cV102Y_NLG0:Vmj0<000001@2Y_NP00`000000ZKgX0:Vmj00Z
0:Vmj0030000003oool0oooo03P0oooo000Y0?ooo`800000N02Y_NP60:Vli`@0ZKgW1P2Y^^D20:Vk
iP<0Z[CP1@2Z^><20:Zji@<0Zk?O1@2Z^N@50:^hh`D0Z[cV1@2Z_>LC0:Vmj0<000002@2Y_NP00`00
0000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018
W03Oool01`3oool2000007@0ZKgX1@2Y_NL50:Vli`X0ZK[U1P2Z]>040:Zhh`H0Zk?O0P2Z^N@30:bb
g0D0ZkSS0P2Z_>H30:^ji0D0Z[cW1@2Z_NL;0:Vmj08000003@2Y_NP00`000000ZKgX0:Vmj00Y0:Vm
j0030000003oool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1`3oool0
0`000000oooo0000001_0:Vmj0X0ZKgW2P2Y^^D50:Vag@D0Z[CP1@2[[MP50:^cg`H0[;;L102[^><6
0:^ji080Z[cW0`2[^nH50:Zmi`L0ZKgX0`00000@0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<00000
0?ooo`3oool0=P3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo0P00
00020?ooo`030000002Y_NP0ZKgX06d0ZKgX1`2Y_NL30:VjiPL0ZK[U0`2Y[m`50:Vag@80Z[CP0`2Z
YM850:^]f080Zk?O0`2]Z=<50:bbg0D0[[?L1@2[^^@60:^kiPD0Z[gW0`2Y_NP3000001<0ZKgX00<0
00000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX06d0ZKgX
102Y_NL60:VjiP@0ZK[U1P2Y[m`40:Vag@D0ZZGB1@2[[MP60:fXd`80[;;L0`2`ZM450:jcg0D0[[OP
1@2[^nH50:Zmi`<000005`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03D0oooo
000L0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo00<0
ooooK`2Y_NP50:VkiPD0ZK[V1@2X[]`50:V_g0D0Z:3>1@2ZYM820:^]f0<0[J3:1@2]Z=<60;2Yd@80
[[?L0`2b[]@50:jgh0D0[K[T00@0Z[gW00000000000000001P2Z_NLE0:Vmj0030000002Y_NP0ZKgX
02T0ZKgX00<000000?ooo`3oool0=03oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00D0oooo0P0000050?ooo`030000002Y_NP0ZKgX06L0ZKgX1@2Y_>L50:VkiPD0Yk3N1@2X[]`2
0:V_g0<0YYg<102XX<h50:ZUdPH0[J3:0P2]Z=<30;:Qa`D0/:WA1P2b[]@20:jgh0<0/[GJ0P2]^^@3
000000D0ZkcV102Z_NLF0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<`3oool0
01`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000ZKgX0:Vmj01U0:Vmj0L0ZKcW0P2Y^nH30:Nch@D0Yk3N102X[]`50:JMc0D0Z:3>0P2Z
YM830:bJa0D0[J3:1@2bXLL40;2Yd@80]jK81@2b[]@40;:efP<0000000@0[K[T0:njhP2_^^80[k[R
1@2[_>H40:ZmiaD0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0c0?ooo`00703o
ool01P3ooml0W4P007Boo`3oool0gia8001d_`H0oooo00<000000?ooo`3oool01`3ooomT0:Vmj0T0
ZKcW1P2W/n440:N`gPD0Y9c=1@2VWL`40:RPcPD0[9[4102]X<X20;>M`PD0/Z770P2`ZM430;NVb0@0
/ZkD0P2j[Ld300000080/[GJ1P2_^^820:^liP<0[;gV102Z_NLE0:Vmj0030000002Y_NP0ZKgX02T0
ZKgX00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@00000000004RL0=ooo`060?ooo`03
0000003oool0oooo00P0ooooI02Y_NP50:Vli`@0Z;OT1@2W/n450::Md0@0Y9c=1@2VWL`20:RPcP<0
ZIK21@2/V/@20:fPbP<0/ig21@2bXLL60;NVb080/ZkD00@0^Zg=000000000000^Zg=0P2b]MX30;Vf
ePD0[k[R1@2/_NH40:ZmiaH0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0b0?oo
o`009`3oool00`000000oooo0?ooo`0:0?ooof@0ZKgX1@2X^^H40:Rgi0<0Yk?Q0P2RX]D40::Md0D0
Y9c=102VWL`50:VF`PD0[9[41P2cWL830;:Qa`80^jC21@2gY/P3000000<0^Zg=1P2i]]H20:njhP<0
/kcP102/_NH50:ZmiaD0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0a0?ooo`00
9`3oool00`000000oooo0?ooo`0;0?ooof40ZKgX0`2Y_>L50:RjiP@0Z;OT1@2RX]D40::Md0@0Y9c=
1@2VTl850:VF`P<0[9[40P2dWl@50;>M`P80/Z770`2kY<820;NVb0<0000000<0`:_40;Z]c@2j[Ld0
0P2j[Ld20<:ab@D0^KKF1P2c_>040:fniPD0Z[gW5@2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000
003oool0oooo0300oooo000W0?ooo`030000003oool0oooo00`0ooooGP2Y_NP60:Vli`@0Z;[V1@2S
ZM/40::Re@@0XYg@0P2TW<d30:6A``@0YY?21@2YU/820:bJa0<0]9o41@2cWL840;^T`P<0000000@0
]jK80<2[a030Zl@0`:_40`2j[Ld40<:ab@80^KKF0`30^M@30;>lh0<0]koP102]_^H50:ZmiaD0ZKgX
00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool2000000h0ooooF@2Y
_NP50:Vmi`D0ZKcW1@2U/N450:>Yf`@0XZ;E0`2RWM050:6A``D0YY?2102YU/860;BOa0<0/ig20P30
/</300000080^jC21P30Zl@00`2j[Ld0`[790<:ab@030<:ab@H0`;WD1@2g_n050:fniPD0Z[gW5@2Y
_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02l0oooo000W0?ooo`030000003oool0
oooo00h0ooooFP2Y_NP40:Vmi`D0YkOU1@2U/N440:>Yf`@0XZ;E102LSlD40:6A``D0YY?20P2YU/83
0;>Vc0D0]9o40P2cWL83000000@0^jC20P37^<`50<2[a0D0`[790P3;^<P40<2ie080akoC102g_n06
0:fniP@0Z[gW5@2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo02h0oooo000W0?oo
o`030000003oool0oooo00l0ooooFP2Y_NP40:Rki`D0YkOU102U/N4509REc`@0VI39102LSlD40:6A
``@0YY?21@2cY/`40;BOa0<000001030/</20;^T`P<0akS<1030Zl@20<Zfa`<0`[79103;^<P20<2i
e0@0akoC0P2g_n020;W2h@D0[KkV1@2Z_NPE0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?oo
o`3oool0;P3oool002L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX05@0ZKgX0`2Y_>P40:Rki`@0
YkOU1@2JX=P409REc`@0VI39102LSlD40:6A``80YY?20`2_[=D50;>Vc0<000000P33fn/50<2`b`03
0;^T`P37^<`0akS<00<0akS<0P30Zl@40<Zfa`030<:ab@3;^<P0bkS800<0bkS81P37_m<50;W2h@D0
[[oW1@2Z_NPE0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0;@3oool002H0oooo
0P00000C0?ooo`030000002Y_NP0ZKgX0540ZKgX1P2Y_>P40:Rki`@0WjgQ102JX=P509REc`@0VI39
102LSlD30:6A``D0[jcE0P2cY/`3000000D0`m_[1@30/</60<Nhc0H0b[K71P3;^<P00`3A`<X0akoC
0<Nod`020<Nod`80c<OE0P2i`^430;[6h`D0[[oW1@2Z_NPE0:Vmj0030000002Y_NP0ZKgX02P0ZKgX
00<000000?ooo`3oool0;03oool000T0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL04P0
M02oool0gia81@0000000`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<00000
0?ooo`3oool04`3oool00`000000ZKgX0:Vmj01A0:Vmj0D0ZKcX1@2T]^D409n]h@@0VZ3H102HULl4
09V@b@@0W8o5102WZMP40:n/e@80000000@0/jK<00000000000000001@33fn/20<2`b`<0/OGb1037
^<`20<ORj`@0b[K70P3>a=040<^hb0<0dL3:0P37_m<30<c7e@H0^/KS0P2^_nL30:foi`D0Z[gX502Y
_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00X0oooo00D0gia80000000000000018
09cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00<0omnL04P0001d
_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0D
0?ooo`030000002Y_NP0ZKgX0540ZKgX1@2W^nL50:Bfi@@0WjgQ0`2JX=P409REc`@0VI391@2MW=<4
0:NYf0<0000000<0[jcE0:Vmj02Y_NP0102Y_NP40<?Kj`H0/OGb0P37^<`30<ORj`<0b[K70`3>a=03
0<^hb0@0dL3:1@3<amD00`3?c]T0^/KS0;[6h`030;[6h`H0[KoW1@2Z_NPD0:Vmj0030000002Y_NP0
ZKgX02P0ZKgX00<000000?ooo`3oool0203oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0
703oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo00<0omnL04P0001d
_ol0203oool00`2oM000M;oo0?ooo`050?ooo`8000005P3ooomD0:Vmj0D0Yk_W102T]^D409n]h@@0
Rhg@102<RL/409>?c0D0WIcC0`0000000`2WZMP0ZKgX0:Vmj00A0:Vmj0H0an;[00<0b[K70<k4d03>
a=000`3>a=000`3;^<P0dL3:0=70bP020=70bP80e/S=0`3<amD30<o>f@80^/KS0`2hanH50:foi`H0
Z[gX502Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3o
ool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0
0018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo01L0ooooD`2Y_NP40:Nk
i`D0VZcS102@VmX308^=d0@0S8W;102CSl`209fLd`<000006@2Y_NP40<ORj`H0c/C@103A`<X40=K8
c@030<c7e@3?c]T0clkI0080clkI1P2hanH50:boj0D0Z[gX502Y_NP00`000000ZKgX0:Vmj00X0:Vm
j0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018W=l0oooo0?oOW01804P0W=oo0?ooo`3o
oml0W4Q809cOo`060?ooo`030000003oool0oooo01P0ooooDP2Y_NP50:>gi`@0VZcS102@VmX408^=
d0@0S8W;0P2CSl`30000000309fLd`2Y_NP0ZKgX01T0ZKgX1003H]P0100d^]X0c/C@0<k4d03>a=03
0<W9fP80dL3:1@3Fb<d40<o>f@80c]CN0`2hanH30;C6i`D0[;oX1@2Z_NPD0:Vmj0030000002Y_NP0
ZKgX02P0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0
703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02L
gol0oono07@000030000000307Boo`3oool0oooo00@0oooo0P00000K0?ooodh0ZKgX1@2W^nP40:>g
i`@0VZcS102@VmX308^=d0<0S8W;0`00000209>?c00309kCnP2Y_NP0ZKgX01/0ZKgX101XX?400`1S
0000bLWJ0<W9fP040<W9fPD0e/S=0P3JdM020<o>f@@0c]CN1P2da^L20:boj0<0ZkkX1@2Z_NPD0:Vm
j0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0M000000000020000
000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`03
0?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000003o
ool0oooo01/0ooooCP2Y_NP50:Nkj0<0XkOW102J[><4092KfP<0Rhg@0`0000000`2<RL/0W]?j09kC
nP0209kCnP80d?6G7@2Y_NP406RPl@0306<00039bMX0bLWJ0080bLWJ0P2oa=h30=K8c@@0f]7@103>
e=h20<SFi0D0]<KW1P2[_^P20:Zmj1L0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`050?ooo`030?oog`2LB4P0W=oo0200oooo00080?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo
103oool02P3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooo0;md001d_ol90?ooo`030000003o
ool0oooo01`0ooooCP2Y_NP50:>ij0<0V:oW1027Vn0307b9e@<0000000<0OhK@08nLf`2?W=/00P2?
W=/209kCnP@0d?6G7@2Y_NP306RPl@04000PYP1S0000bLWJ0<W9fP@0_lCN00<0e/S=0=[Ad03JdM00
0P3JdM020=gKe080c]CN1038e^@50;34j0D0ZkkX6@2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000
003oool0oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0oono07@00000000004RL
0=ooo`050?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P00000000000000000001d
0;ooo`D0oooo00<000000?ooo`3oool07@3ooom;0:Vmj0<0Z;cX1@2S^NP309R_i`<0Qi_P00@0O8WE
000000000000O8WE0`1oQ]0508nLf`030=3aU`2Y_NP0ZKgX0200ZKgX0`1XX?400`0:@l80_lCN0;o4
gP040;o4gP@0f]7@0`3Mfm@40<SFi0<0_m;X1@2`a>P50:Znj1T0ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`050?ooo`060=nLB000000000000000000007@0_ooo703oool002D0oooo
0P00000O0?ooodP0ZKgX1P2X_>P40:>ij0<0V:oW00@0Qi_P0000000000000000101lRMD307n6d080
SicK0P2om^l00`3Fgmh0ln>j0:Vmj00Q0:Vmj00400=Rf01XX?402T?200Y3`P<0_lCN0`2n`M`20=[A
d0<0gM_D0`3Li=X60;oBj0D0[L7X1@2Z_^PI0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?oo
o`3oool09P3oool002D0oooo00<000000?ooo`3oool07`3ooom90:Vmj0@0Z;cX1@2K]>T3000000<0
KXWM101lRMD307n6d0<0_oK_00@0e]oN0??S^P3chkX0ln>j8P2Y_NP01003H]P0J:3a00Y3`P0:@l86
0;k1g0<0gM_D0`3Li=X20=GVhP<0_m;X0`2fbnT50:g1j0D0Z[gX602Y_NP00`000000ZKgX0:Vmj00X
0:Vmj0030000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo0200ooooB@2Y_NP40:Jk
j00509^dj@00000000000000002K]>T00`25X^L306j9g@@0LHCF102DYN420=KOgP<0ln>j00<0inG?
0:Vmj02Y_NP07`2Y_NP200=Rf0<02T?2102n`M`30<W;f`<0g>CJ103Ei^860;K;j@80[L7X0`2[_nP4
0:Zmj1T0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0U0?ooo`00903oool20000
02<0ooooB@2Y_NP0102V^nP0000000000000000409^dj@@0QJ;W0P1^RMd40764eP<0U:GQ0P3Fgmh3
0??S^P<0inG?8@2Y_NP200=Rf00305I/c@0:@l802T?20080_/7L0`39bm/30=SNf`@0eNKR0P37g^T5
0;K;j@H0ZkoX0P2Z_NPK0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool0903oool0
02@0oooo00<000000?ooo`3oool08`3ooom60:Vmj0<00000102R^^X408j^k0<0JY?W0`1^RMd40764
eP0409BUh@3Fgmh0e]oN0=KOgP80ln>j103WiLlQ0:Vmj00303e5/@03H]P0EVc=0080EVc=1039bm/3
0=SNf`80g_3L0P3Ei^840<ONj@D0[lCY1@2[_nPN0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<00000
0?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0903ooom20:Vmj0<00000102X_>P40::j
jP@0SZk/0`1ZTnL205^0g@@0LHCF0`3Fgmh20??S^P@0inG?0P3:aMDP0:Vmj080?DFa00@00f;H05I/
c@1FK<d0EVc=0P39bm/30=SNf`<0g_3L1037g^T30;W@j`D0[lCY1@2Z_^PM0:Vmj0030000002Y_NP0
ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?oooch0ZKgX0`0000030:Vm
j0D0Z;cX102R^^X308j^k0@0JY?W0P1KP=d508VLg`80ln>j103WiLl40<[5eA/0ZKgX0P2QS;h30:Vm
j080?DFa101FK<d30=SNf`<0g_3L0`3Gln<60;W@j`D0[;oX102Z_^PN0:Vmj0030000002Y_NP0ZKgX
02L0ZKgX00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?oooc/0ZKgX0P0000070:Vmj0@0
Z;cX1@2M^>/307bWkP<0C8CV0`1KP=d208VLg`@0_;oL0P3Ib<P50<[5e@80_JW5602Y_NP40:6<_P03
05aD/@2Y_NP0ZKgX00<0?DFa1@2BWM/30=k`g0<0eo?S0P38i^`30;W@j`<0/<GZ1@2/_nPR0:Vmj003
0000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@000000000
04RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool0:03ooolf0:Vmj0<000002@2Y_NP50:Nlj@D0WKS[0`1lYnh304b4iP80GXSS1@2l
_m`30=W8b0040>34_@3:aMD0b/GE0<[5e@@0_JW54`2Y_NP50:FMc@<0XHbn0P1LE;40102Y_NP0?DFa
03e5/@0mAK4409:Mf`<0a]WX0P3Gln<50<SVk0H0/<GZ1@2Z_^PR0:Vmj0030000002Y_NP0ZKgX02H0
ZKgX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo<P2Y
_NP3000000d0ZKgX1@2W_>T509Nfk@80JIo`101<Q>H205j8h`<0_;oL0`3Ib<P30>34_@H0_JW500<0
b:Ri0:Vmj02Y_NP0302Y_NP90:FMc@<0XHbn0`1LE;4403e5/@80TYgK0`36fNP20=Kjh@80coWV1@2h
d^d30;35jP<0Zl3X102Z_^PR0:Vmj0030000002Y_NP0ZKgX02L0ZKgX0P00000Q0?ooo`00303oool0
1`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool00`2oM000M;oo0?ooo`050?ooo`800000
;03oool^0:Vmj0<000004@2Y_NP50:Jlj@D0UkK]0P1YWo03035ki@<0GXSS00<0_;oL0=W8b03Ib<P0
0P3Ib<P30>34_@030=o3_02mZLD0_JW50080_JW50`38Z;T20:Vmj0<0WX>f1@2Y_NP40:6<_PT0YIg=
0`2QS;h305aD/@<0NH;@1036fNP20=Kjh@80coWV0P32iO050;SBk@H0Zl3X0P2Z_^PT0:Vmj0030000
002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0/0?ooobX0
ZKgX0`00000F0:Vmj0@0Y[cY102G]^d306VOl0<0<G_U0P1dW^/40=W8b0<0h<Bm0P3O`k`30;fYa@@0
b:Ri1P2NPkH20:Vmj0<0W7ja0`2QS;h90:FMc@<0XHbn0`1LE;4507V2d080e_[Q0`3?nNH40<;Ul0D0
[/CZ1@2[`>PW0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07`3oool000`0oooo
00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2L
B4P0W=oo00H0oooo00<000000?ooo`3oool0;@3ooolV0:Vmj0<000006P2Y_NP40:Flj@@0TkK_0`1J
Vo400`0JMN<0<G_U035ki@0307BNj`80fLS80`3Pa;d30=o3_0030;fYa@38Z;T0b:Ri00<0b:Ri00<0
fkNd09j3]P2NPkH00`2NPkH509an/@@0XHbn202UWLd30:6<_P@0G5Ba0P1iP]030;gSlP<0`_kO0`32
iO030;?=k@D0[/CZ1@2Z_^PV0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3o
ool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y_NP3000001h0ZKgX
102U_>T409>fk`<0FY_a0P0JMN<407BNj`<0h<Bm103O`k`50<RX^@80fkNd1@2NPkH00`3@[;D0W7ja
09an/@0209an/@@0XHbn1@2NP[D408Yf]`80OGS3101LE;440;gSlP80`_kO0`32mnh60;?=k@D0ZkoX
102Z_^PW0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol02@3oool200000340
oooo7P2Y_NP300000280ZKgX0`2U_>T509>fk`80EIcc0`0JMN<408Nal@80h<Bm103O`k`0103JbLT0
b:Ri0<RX^@38Z;T30=^g]0@0WX>f0P3@[;D509an/@80XHbn0P2cUkX409j2]@@0RWJg0`1mN<<508bN
g`80`_kO0P32mnh50;SJl@D0[<7Y1@2[_nP[0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?oo
o`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0
oooo00P0oooo00<000000?ooo`3oool0<@3ooolK0:Vmj08000009@2Y_NP40:Flj@D0TkK_0`1EW?<2
00A`gP@0Qk7a103O`k`20=[9b@<0b:Ri103K]k@209j3]P<0d:be1@2LO[40102QS;h0/iNj0;>G^P2c
UkX409j2]@@0RWJg101mN<<208bNg`80[_SZ0P2^n^830;SWm@<0^=[a0P2^aN/50:c1j@D0Z[gX:`2Y
_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d0000
00000018W03Oool01@3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3o
ool0<P3ooolG0:Vmj0<00000:02Y_NP40:Flj@D0UkS_0`1OY?D200A`gP@0OkWi0P3O`k`40=[9b@03
0<RX^@3K]k@0fkNd00<0fkNd00<0WX>f0=2/]@3@[;D00`3@[;D409an/@@0/iNj1@2NP[D408Yf]`<0
OGS30P2^n>X20:kjhPH0^>Oe1@2^aN/20:c1j@<0Z[kX102Z_NP[0:Vmj0030000002Y_NP0ZKgX02L0
ZKgX00<000000?ooo`3oool06`3oool00280oooo0P00000d0?oooa<0ZKgX0`00000/0:Vmj0D0Y[cY
102G^>l405nTm@03001`fP1o^OT0OkWi0080OkWi1@3JbLT60=^g]0H0d:be0`2LO[420<Neb@@0/iNj
102NP[D408Yf]`80OGS30P2Oj?/00`29k=40[^og0:k_m`020:k_m`D0[l_^102^aN/60:Znj080Z[gX
;@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01/0oooo000R0?ooo`030000003o
ool0oooo03@0oooo3`2Y_NP300000300ZKgX1@2V_>T409bjk@@0M:kf0P0=P>@304^]n@<0f/W90P31
gNd50=^g]0030=CGf`3@[;D0d:be00<0d:be0P2LO[430<Neb@@0/iNj102NP[D408Yf]`<0WnSk102^
koL30:o?l@@0[l_^1@2Z_nP50:Znj300ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?oo
o`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX00P0ZKgX0`00000d
0:Vmj0D0YkgY102L^^d407B^mP<03H3T0P00OM@50<7Mk@<0fkNd0P3Dem/50=2/]@H0akG90`2cUkX4
09j2]@H0WMOl0`2Kk_H60:o?l@@0Zl3Y1@2Z_nPe0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<00000
0?ooo`3oool0303oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103o
ool00280oooo00<000000?ooo`3oool0=`3oool60:Vmj0<00000>02Y_NP50:Nmj@@0X[c[1@2:]o<3
046Nm@03001me031gNd0`Mg]00<0`Mg]00<0fkNd0=CGf`3Dem/00P3Dem/30=2/]@80a^?]1@37]LT3
0;>G^PH0XmWj0P1Qe/4209_^mPD0[=7d1@2[`NX40:_0jCT0ZKgX00<000000:Vmj02Y_NP09P2Y_NP2
000000`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00240
oooo0P00000j0?ooo`80ZKgX0`00000l0:Vmj0D0Z;gX102R_>/509Zkk`<0M[Ch00<07ICZ0<7Mk@31
gNd00P31gNd50=CGf`80d:be1036hnd40<Neb@D0WNOl0P0m_[8208OVmPD0Ym3e1@2Z`^/50:_1jP@0
Z[gX>@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02o
ool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?oo
o`0h0?ooo`<00000@02Y_NP50:Rmj0@0Y[cY1@2J^nl307Jdn0@07ICZ0P00K[030=CGf`H0a^?]1@1P
en430000000307_MnP2Sc?D0Xlce00<0Xlce0`2Wd?D20:W1j`D0Z/;[1@2Z_^P40:Zmj3T0ZKgX00<0
00000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0=P3oool20000
00<0ooooAP2Y_NP40:Jlj@D0Xkc[102E^o84072gn`H0O[kl0`1@^oT608O;oP@0X/Oc1@2Sc?D50:W1
j`D0ZKkX102Z_^Pm0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool02@3oool02`3o
gi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`800000
=03oool3000000H0ooooAP2Y_NP40:Rmj0D0Xkc[102S_N`509NmlPD0W[o`102D`oL50:?2k`@0X/Oc
1@2X`>/30:W1j`L0ZKkX@@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00P0oooo
00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool0
0`000000oooo0?ooo`0`0?ooo`<000002@3ooom70:Vmj0@0Z;gX1@2W_NT40:>mk0D0Y;g[102N_o05
0:Fok0D0Xl;_102X_nX50:S0j`L0ZKkXA02Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0
oooo00H0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0
_ooo00<0oooo00040?ooo`0=0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3o
okl0M01809cOo`040?ooo`050=nLB000000000000000B02Lgol01`3oool00`000000oooo0?ooo`0]
0?ooo`<000003P3ooom:0:Vmj0T0YkgY1@2T_N/40:NnjPD0YKo/1@2X_^T40:RojPT0ZKkXA`2Y_NP0
0`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000000007@0_ooo0?oo
o`3ooml0W4P007Boo`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P004RLg`3oool0gia8
001d_`D0oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0
1P3oool00`000000oooo0?ooo`0Z0?ooo`<000004P3ooom?0:Vmj0@0YkgY1@2X_NP40:NnjPD0Z;gY
102X_^T50:Vmj0D0ZKkXBP2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003oool0
203oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool000<0oooo
00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2o
M000M;oo0?ooo`040?ooo`800000:@3oool3000001H0ooooD`2Y_NP50:Rmj0@0ZKgX1@2X_NUH0:Vm
j0030000002Y_NP0ZKgX01`0ZKgX0`0000050?ooo`030000003oool0oooo01D0oooo00030?ooo`07
0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@0
07Boo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`<000006P3oooni0:Vmj0030000002Y_NP0
ZKgX01P0ZKgX0`0000080?ooo`030000003oool0oooo01D0oooo00030?ooo`070?noM000B9`0gooo
0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo0080oooo00L0omnL04P0B02Lgol0oooo
0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool08P3oool3000001h0oooo^@2Y_NP00`000000
ZKgX0:Vmj00C0:Vmj0@00000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ogi`0B4RL
0=ooo`3oool0oono07@0B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@000<0000000<0
M;oo0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000008P3ooonh0:Vmj0030000002Y
_NP0ZKgX00l0ZKgX00@0oooo0000000000000000403oool00`000000oooo0?ooo`0D0?ooo`000`3o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01P3oool01`3ookl0M01809cOo`3oool0oooO
09a8B02Lgol02@3oool2000001h0oooo0P00000V0?ooo`030000002Y_NP0ZKgX0;D0ZKgX00<00000
0:Vmj02Y_NP02P2Y_NP20?ooo`<000004`3oool00`000000oooo0?ooo`0D0?ooo`000`3oool01P3o
oml0W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd0018W03Oool0oooo0;md001d_ol80?ooo`80
0000703oool3000002X0oooo]`2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000
oooo0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia800000000
00000`0000000`1d_ol0oooo0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3o
ool05`3oool3000002h0oooo]P2Y_NP00`000000ZKgX0:Vmj0050:Vmj08000006P3oool00`000000
oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3ooonf0:Vmj0040000
002Y_NP0ZKgX0:Vmj08000007@3oool00`000000oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo
0`00000f0?oookD0ZKgX0`00000P0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003o
ool0oooo00l0oooo0`00000j0?oook00ZKgX0`0000030?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3000003h0oooo[02Y_NP3
000000H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0C0?ooo`007`3oool00`00
0000oooo0?ooo`090?ooo`<00000@P3ooonW0:Vmj0@000002P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01<0oooo000N0?ooo`8000002@3oool2000004H0ooooXP2Y_NP0103oool0
000000000000000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool001h0
oooo00<000000?ooo`3oool01@3oool3000004T0ooooWP2Y_NP0103oool0000000000000000C0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3o
ool00P3oool3000004d0oooo00<000000:Vmj02Y_NP0UP2Y_NP00`3oool0000000000002000001H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo
0000000200000540oooo00<000000:Vmj02Y_NP0T`2Y_NP3000001/0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP0T02Y
_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool0
0`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vmj02Y_NP0S02Y_NP0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool0
01<0oooo00<0omnL04P0M02oool02P3oool2000005H0ooooR@2Y_NP2000002L0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`03
0000003oool0oooo05@0ooooQ@2Y_NP2000002/0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05@0oooo
P02Y_NP200000300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3o
ool00`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0ooooN`2Y_NP3000003<0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0?
0?ooo`030000003oool0oooo05@0ooooM`2Y_NP3000003L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0B0?ooo`004@3oool01@2oM000001809boW01807@0_ooo0100oooo0P00001E
0?ooog80ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool0
0180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?ooo`1C0?ooofh0ZKgX0`000010
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0
M02oool04`3oool00`000000oooo0?ooo`1C0?ooofT0ZKgX100000130?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04@3oool002X0oooo00<000000?ooo`3oool0D`3ooomU0:Vmj0<0
0000B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo000[0?ooo`800000
E03ooomP0:Vmj0040?ooo`0000000000000004`0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`1B0?oooe`0ZKgX1000001?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002h0oooo00<000000?ooo`3oool0DP3o
oomH0:Vmj0<00000E03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000_
0?ooo`030000003oool0oooo0580ooooD`2Y_NP0103oool0000000000000001H0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool04@3oool00300oooo00<000000?ooo`3oool0DP3ooom?
0:Vmj0@00000G03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000a0?oo
o`800000D`3ooom:0:Vmj0040?ooo`000000000000000600oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`1A0?ooodH0ZKgX1000001T0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool003@0oooo00<000000?ooo`3o
ool0D@3ooom20:Vmj0<00000J@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo000e0?ooo`030000003oool0oooo0540oooo?@2Y_NP0103oool0000000000000001/0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003H0oooo0P00001B0?ooocT0ZKgX
1000001`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool003P0oooo00<0
00000?ooo`3oool0D03ooole0:Vmj0<00000M@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0100oooo000i0?ooo`030000003oool0oooo0540oooo;`2Y_NP0103oool0000000000000
001i0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool003X0oooo00<00000
0?ooo`3oool0D@3oool[0:Vmj0@00000O03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo000k0?ooo`030000003oool0oooo0540oooo9`2Y_NP300000840oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`00?03oool200000580oooo8P2Y_NP0103oool0
00000000000000250?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool003h0
oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo0500oooo6P2Y_NP3000008d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00@03oool00`000000oooo0?oo
o`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00140?ooo`030000003oool0oooo0500
oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00
A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`800000YP3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00190?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001;0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool0
04l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00540oooo
0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0:`0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001F0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0000000?0?ooo`00E`3oool2
000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo0000000>0?ooo`00F@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0oooo00<0
00000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
WP3oool300000200oooo001R0?ooo`800000=03oool00`000000oooo0?ooo`2J0?ooo`@000008`3o
ool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F0?ooo`@000009`3oool0
06D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3oool006H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool006L0oooo
0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?ooo`00J@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo07/0oooo100000120?ooo`00K@3oool2000002T0oooo00<000000?ooo`3oool0
M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0M@3o
ool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0L@3oool4
000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool40000
0540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool007@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M0?ooo`03
0000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<000000?ooo`3oool0A`3oool40000
07L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4000007/0
oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3oool4000007l0oooo
00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool4000008<0oooo0022
0?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo0P00000=0?ooo`030000003oool0
oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3oool05P3oool400000:T0oooo002?
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool400000:d0oooo002@0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool300000;40oooo002A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000;@0oooo002B0?ooo`050000
003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?ooo`80000000<0oooo0000003oool0
103oool400000;`0oooo002E0?ooo`80000000<0oooo0000000000000P0000300?ooo`00UP3oool2
00000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o
0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50128 .61629 .49474 Mtetra
.61629 .49474 .62206 .50128 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45592 Mtetra
.68693 .45592 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45592 .68126 .44903 Mtetra
.68126 .44903 .68693 .45592 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67555 .4421 .66979 .43511 Mtetra
.66979 .43511 .67555 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .4619 Mtetra
.55738 .4619 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43189 Mtetra
.65193 .43189 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .4619 .55122 .45506 Mtetra
.55122 .45506 .55738 .4619 .56902 .4582 .5629 .45134 Mtetra
.5629 .45134 .56902 .4582 .58072 .45449 .57463 .4476 Mtetra
.57463 .4476 .58072 .45449 .59246 .45076 .5864 .44385 Mtetra
.664 .741 .908 r
.5864 .44385 .59246 .45076 .60425 .44702 .59823 .44008 Mtetra
.59823 .44008 .60425 .44702 .6161 .44326 .61011 .43629 Mtetra
.61011 .43629 .6161 .44326 .62799 .43948 .62204 .43248 Mtetra
.664 .741 .907 r
.62204 .43248 .62799 .43948 .63994 .43569 .63402 .42866 Mtetra
.63402 .42866 .63994 .43569 .65193 .43189 .64605 .42482 Mtetra
.64605 .42482 .65193 .43189 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45192 Mtetra
.664 .741 .908 r
.53336 .45192 .53959 .45877 .55122 .45506 .54502 .44819 Mtetra
.663 .741 .908 r
.54502 .44819 .55122 .45506 .5629 .45134 .55673 .44445 Mtetra
.663 .742 .908 r
.55673 .44445 .5629 .45134 .57463 .4476 .56849 .44071 Mtetra
.663 .742 .909 r
.56849 .44071 .57463 .4476 .5864 .44385 .5803 .43695 Mtetra
.663 .743 .909 r
.5803 .43695 .5864 .44385 .59823 .44008 .59216 .43316 Mtetra
.664 .744 .909 r
.59216 .43316 .59823 .44008 .61011 .43629 .60407 .42934 Mtetra
.60407 .42934 .61011 .43629 .62204 .43248 .61604 .42549 Mtetra
.665 .743 .909 r
.61604 .42549 .62204 .43248 .63402 .42866 .62805 .42162 Mtetra
.665 .743 .908 r
.62805 .42162 .63402 .42866 .64605 .42482 .64011 .41772 Mtetra
.664 .742 .908 r
.64011 .41772 .64605 .42482 .65813 .42096 .65223 .41382 Mtetra
.65223 .41382 .65813 .42096 .67026 .41709 .6644 .40991 Mtetra
.664 .741 .907 r
.6644 .40991 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40205 Mtetra
.6889 .40205 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45249 Mtetra
.663 .741 .908 r
.50384 .45249 .51018 .45934 .52175 .45563 .51543 .44876 Mtetra
.51543 .44876 .52175 .45563 .53336 .45192 .52707 .44505 Mtetra
.662 .741 .909 r
.52707 .44505 .53336 .45192 .54502 .44819 .53877 .44135 Mtetra
.66 .743 .911 r
.53877 .44135 .54502 .44819 .55673 .44445 .55051 .43768 Mtetra
.659 .745 .914 r
.55051 .43768 .55673 .44445 .56849 .44071 .56231 .43403 Mtetra
.659 .749 .917 r
.56231 .43403 .56849 .44071 .5803 .43695 .57415 .43036 Mtetra
.661 .754 .919 r
.57415 .43036 .5803 .43695 .59216 .43316 .58605 .42662 Mtetra
.663 .757 .92 r
.58605 .42662 .59216 .43316 .60407 .42934 .598 .42277 Mtetra
.667 .758 .919 r
.598 .42277 .60407 .42934 .61604 .42549 .61 .41882 Mtetra
.668 .756 .916 r
.61 .41882 .61604 .42549 .62805 .42162 .62204 .41479 Mtetra
.669 .752 .913 r
.62204 .41479 .62805 .42162 .64011 .41772 .63414 .41074 Mtetra
.668 .748 .911 r
.63414 .41074 .64011 .41772 .65223 .41382 .64629 .40671 Mtetra
.666 .745 .909 r
.64629 .40671 .65223 .41382 .6644 .40991 .65849 .4027 Mtetra
.665 .743 .908 r
.65849 .4027 .6644 .40991 .67662 .40598 .67075 .39872 Mtetra
.664 .741 .908 r
.67075 .39872 .67662 .40598 .6889 .40205 .68306 .39474 Mtetra
.664 .741 .907 r
.68306 .39474 .6889 .40205 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44933 Mtetra
.663 .741 .908 r
.48586 .44933 .49229 .4562 .50384 .45249 .49744 .4456 Mtetra
.661 .741 .909 r
.49744 .4456 .50384 .45249 .51543 .44876 .50906 .44191 Mtetra
.658 .742 .912 r
.50906 .44191 .51543 .44876 .52707 .44505 .52074 .43831 Mtetra
.652 .744 .917 r
.52074 .43831 .52707 .44505 .53877 .44135 .53247 .43487 Mtetra
.644 .751 .926 r
.53247 .43487 .53877 .44135 .55051 .43768 .54425 .43159 Mtetra
.638 .763 .938 r
.54425 .43159 .55051 .43768 .56231 .43403 .55608 .42841 Mtetra
.637 .78 .949 r
.55608 .42841 .56231 .43403 .57415 .43036 .56798 .42516 Mtetra
.643 .798 .957 r
.56798 .42516 .57415 .43036 .58605 .42662 .57992 .42166 Mtetra
.656 .811 .958 r
.57992 .42166 .58605 .42662 .598 .42277 .59191 .41778 Mtetra
.67 .815 .953 r
.59191 .41778 .598 .42277 .61 .41882 .60394 .41353 Mtetra
.681 .808 .943 r
.60394 .41353 .61 .41882 .62204 .41479 .61602 .40903 Mtetra
.684 .793 .933 r
.61602 .40903 .62204 .41479 .63414 .41074 .62814 .40444 Mtetra
.681 .776 .923 r
.62814 .40444 .63414 .41074 .64629 .40671 .64031 .39996 Mtetra
.675 .76 .915 r
.64031 .39996 .64629 .40671 .65849 .4027 .65255 .39564 Mtetra
.67 .75 .911 r
.65255 .39564 .65849 .4027 .67075 .39872 .66483 .39147 Mtetra
.666 .744 .908 r
.66483 .39147 .67075 .39872 .68306 .39474 .67718 .3874 Mtetra
.665 .742 .908 r
.67718 .3874 .68306 .39474 .69543 .39075 .68958 .38336 Mtetra
.664 .741 .907 r
.68958 .38336 .69543 .39075 .70785 .38675 .70204 .37932 Mtetra
.70204 .37932 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44616 Mtetra
.663 .741 .908 r
.46782 .44616 .47433 .45305 .48586 .44933 .47938 .44242 Mtetra
.66 .741 .909 r
.47938 .44242 .48586 .44933 .49744 .4456 .49099 .43876 Mtetra
.653 .741 .914 r
.49099 .43876 .49744 .4456 .50906 .44191 .50264 .43529 Mtetra
.638 .744 .925 r
.50264 .43529 .50906 .44191 .52074 .43831 .51435 .4322 Mtetra
.614 .754 .945 r
.51435 .4322 .52074 .43831 .53247 .43487 .52611 .42962 Mtetra
.581 .774 .971 r
.52611 .42962 .53247 .43487 .54425 .43159 .53794 .42746 Mtetra
.547 .805 .993 r
.53794 .42746 .54425 .43159 .55608 .42841 .54983 .4254 Mtetra
.524 .84 .999 r
.54983 .4254 .55608 .42841 .56798 .42516 .56178 .42301 Mtetra
.528 .872 .99 r
.56178 .42301 .56798 .42516 .57992 .42166 .57378 .41994 Mtetra
.564 .9 .981 r
.57378 .41994 .57992 .42166 .59191 .41778 .58582 .41604 Mtetra
.621 .919 .977 r
.58582 .41604 .59191 .41778 .60394 .41353 .5979 .4113 Mtetra
.675 .92 .974 r
.5979 .4113 .60394 .41353 .61602 .40903 .61001 .40588 Mtetra
.709 .896 .964 r
.61001 .40588 .61602 .40903 .62814 .40444 .62215 .40012 Mtetra
.715 .855 .949 r
.62215 .40012 .62814 .40444 .64031 .39996 .63433 .39444 Mtetra
.703 .811 .932 r
.63433 .39444 .64031 .39996 .65255 .39564 .64657 .38919 Mtetra
.687 .777 .92 r
.64657 .38919 .65255 .39564 .66483 .39147 .65888 .38445 Mtetra
.674 .756 .912 r
.65888 .38445 .66483 .39147 .67718 .3874 .67125 .38009 Mtetra
.667 .746 .909 r
.67125 .38009 .67718 .3874 .68958 .38336 .68369 .37592 Mtetra
.665 .742 .908 r
.68369 .37592 .68958 .38336 .70204 .37932 .69618 .37183 Mtetra
.664 .741 .907 r
.69618 .37183 .70204 .37932 .71455 .37526 .70873 .36774 Mtetra
.70873 .36774 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.663 .741 .908 r
.44972 .44297 .45631 .4499 .46782 .44616 .46126 .43922 Mtetra
.66 .74 .909 r
.46126 .43922 .46782 .44616 .47938 .44242 .47285 .43555 Mtetra
.65 .74 .915 r
.47285 .43555 .47938 .44242 .49099 .43876 .48448 .43215 Mtetra
.625 .741 .93 r
.48448 .43215 .49099 .43876 .50264 .43529 .49617 .42937 Mtetra
.575 .748 .959 r
.49617 .42937 .50264 .43529 .51435 .4322 .5079 .42756 Mtetra
.485 .761 .992 r
.5079 .42756 .51435 .4322 .52611 .42962 .5197 .42667 Mtetra
.363 .766 .984 r
.5197 .42667 .52611 .42962 .53794 .42746 .53157 .42611 Mtetra
.274 .761 .917 r
.53157 .42611 .53794 .42746 .54983 .4254 .54352 .42504 Mtetra
.284 .782 .87 r
.54352 .42504 .54983 .4254 .56178 .42301 .55553 .42296 Mtetra
.359 .83 .877 r
.55553 .42296 .56178 .42301 .57378 .41994 .56759 .41986 Mtetra
.442 .876 .901 r
.56759 .41986 .57378 .41994 .58582 .41604 .5797 .41593 Mtetra
.516 .911 .914 r
.5797 .41593 .58582 .41604 .5979 .4113 .59184 .41117 Mtetra
.593 .944 .921 r
.59184 .41117 .5979 .4113 .61001 .40588 .60401 .40539 Mtetra
.678 .966 .931 r
.60401 .40539 .61001 .40588 .62215 .40012 .61618 .39858 Mtetra
.739 .955 .944 r
.61618 .39858 .62215 .40012 .63433 .39444 .62837 .39125 Mtetra
.752 .905 .945 r
.62837 .39125 .63433 .39444 .64657 .38919 .64061 .38423 Mtetra
.728 .839 .933 r
.64061 .38423 .64657 .38919 .65888 .38445 .65291 .37814 Mtetra
.697 .787 .92 r
.65291 .37814 .65888 .38445 .67125 .38009 .66529 .37301 Mtetra
.677 .758 .912 r
.66529 .37301 .67125 .38009 .68369 .37592 .67775 .36851 Mtetra
.668 .745 .909 r
.67775 .36851 .68369 .37592 .69618 .37183 .69028 .36429 Mtetra
.665 .742 .908 r
.69028 .36429 .69618 .37183 .70873 .36774 .70287 .36015 Mtetra
.664 .741 .907 r
.70287 .36015 .70873 .36774 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43978 Mtetra
.663 .741 .908 r
.43155 .43978 .43822 .44673 .44972 .44297 .44307 .436 Mtetra
.661 .74 .909 r
.44307 .436 .44972 .44297 .46126 .43922 .45464 .43228 Mtetra
.652 .739 .914 r
.45464 .43228 .46126 .43922 .47285 .43555 .46626 .42883 Mtetra
.622 .738 .929 r
.46626 .42883 .47285 .43555 .48448 .43215 .47792 .42613 Mtetra
.551 .736 .962 r
.47792 .42613 .48448 .43215 .49617 .42937 .48962 .42479 Mtetra
.401 .725 .989 r
.48962 .42479 .49617 .42937 .5079 .42756 .50138 .42493 Mtetra
.202 .684 .932 r
.50138 .42493 .5079 .42756 .5197 .42667 .51321 .42559 Mtetra
.189 .711 .871 r
.51321 .42559 .5197 .42667 .53157 .42611 .52514 .42501 Mtetra
.438 .858 .951 r
.52514 .42501 .53157 .42611 .54352 .42504 .53713 .42214 Mtetra
.655 .889 .982 r
.53713 .42214 .54352 .42504 .55553 .42296 .54916 .41751 Mtetra
.693 .808 .936 r
.54916 .41751 .55553 .42296 .56759 .41986 .56124 .41262 Mtetra
.663 .743 .91 r
.56124 .41262 .56759 .41986 .5797 .41593 .57339 .40866 Mtetra
.631 .732 .92 r
.57339 .40866 .5797 .41593 .59184 .41117 .5856 .40563 Mtetra
.629 .789 .959 r
.5856 .40563 .59184 .41117 .60401 .40539 .59787 .40235 Mtetra
.671 .894 .978 r
.59787 .40235 .60401 .40539 .61618 .39858 .61015 .3973 Mtetra
.731 .961 .942 r
.61015 .3973 .61618 .39858 .62837 .39125 .62241 .38993 Mtetra
.78 .966 .922 r
.62241 .38993 .62837 .39125 .64061 .38423 .63465 .3813 Mtetra
.783 .919 .929 r
.63465 .3813 .64061 .38423 .65291 .37814 .64694 .37317 Mtetra
.742 .845 .927 r
.64694 .37317 .65291 .37814 .66529 .37301 .65931 .36653 Mtetra
.7 .785 .917 r
.65931 .36653 .66529 .37301 .67775 .36851 .67178 .36126 Mtetra
.675 .755 .911 r
.67178 .36126 .67775 .36851 .69028 .36429 .68433 .35675 Mtetra
.667 .744 .908 r
.68433 .35675 .69028 .36429 .70287 .36015 .69695 .35251 Mtetra
.664 .741 .907 r
.69695 .35251 .70287 .36015 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48098 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44036 Mtetra
.40185 .44036 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43978 .42482 .43277 Mtetra
.662 .741 .908 r
.42482 .43277 .43155 .43978 .44307 .436 .43637 .429 Mtetra
.656 .74 .911 r
.43637 .429 .44307 .436 .45464 .43228 .44797 .4254 Mtetra
.632 .736 .923 r
.44797 .4254 .45464 .43228 .46626 .42883 .45961 .42245 Mtetra
.56 .728 .953 r
.45961 .42245 .46626 .42883 .47792 .42613 .47128 .42103 Mtetra
.384 .698 .983 r
.47128 .42103 .47792 .42613 .48962 .42479 .48299 .42165 Mtetra
.145 .631 .918 r
.48299 .42165 .48962 .42479 .50138 .42493 .49477 .4232 Mtetra
.252 .739 .923 r
.49477 .4232 .50138 .42493 .51321 .42559 .50666 .42264 Mtetra
.695 .895 .969 r
.50666 .42264 .51321 .42559 .52514 .42501 .51863 .41723 Mtetra
.787 .758 .827 r
.51863 .41723 .52514 .42501 .53713 .42214 .53064 .40742 Mtetra
.741 .637 .745 r
.53064 .40742 .53713 .42214 .54916 .41751 .54265 .39648 Mtetra
.658 .545 .715 r
.54265 .39648 .54916 .41751 .56124 .41262 .5547 .38983 Mtetra
.62 .513 .71 r
.5547 .38983 .56124 .41262 .57339 .40866 .56682 .38582 Mtetra
.583 .49 .715 r
.56682 .38582 .57339 .40866 .5856 .40563 .57904 .38447 Mtetra
.508 .455 .733 r
.57904 .38447 .5856 .40563 .59787 .40235 .59142 .38744 Mtetra
.508 .517 .801 r
.59142 .38744 .59787 .40235 .61015 .3973 .60388 .38929 Mtetra
.614 .708 .912 r
.60388 .38929 .61015 .3973 .62241 .38993 .61632 .38673 Mtetra
.763 .908 .939 r
.61632 .38673 .62241 .38993 .63465 .3813 .62866 .37927 Mtetra
.816 .949 .908 r
.62866 .37927 .63465 .3813 .64694 .37317 .64096 .36966 Mtetra
.798 .903 .916 r
.64096 .36966 .64694 .37317 .65931 .36653 .65331 .36097 Mtetra
.739 .827 .919 r
.65331 .36097 .65931 .36653 .67178 .36126 .66577 .35435 Mtetra
.692 .772 .913 r
.66577 .35435 .67178 .36126 .68433 .35675 .67834 .34926 Mtetra
.671 .749 .909 r
.67834 .34926 .68433 .35675 .69695 .35251 .69099 .34483 Mtetra
.665 .742 .908 r
.69099 .34483 .69695 .35251 .70964 .34832 .70371 .34058 Mtetra
.664 .741 .907 r
.70371 .34058 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46699 Mtetra
.29379 .46699 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44036 .39501 .43335 Mtetra
.39501 .43335 .40185 .44036 .41331 .43657 .4065 .42953 Mtetra
.663 .741 .908 r
.4065 .42953 .41331 .43657 .42482 .43277 .41803 .42572 Mtetra
.661 .74 .909 r
.41803 .42572 .42482 .43277 .43637 .429 .42962 .42197 Mtetra
.646 .738 .916 r
.42962 .42197 .43637 .429 .44797 .4254 .44124 .41862 Mtetra
.594 .729 .938 r
.44124 .41862 .44797 .4254 .45961 .42245 .45289 .41655 Mtetra
.443 .697 .974 r
.45289 .41655 .45961 .42245 .47128 .42103 .46456 .41682 Mtetra
.168 .611 .938 r
.46456 .41682 .47128 .42103 .48299 .42165 .47628 .41899 Mtetra
.236 .705 .943 r
.47628 .41899 .48299 .42165 .49477 .4232 .48812 .41933 Mtetra
.753 .87 .933 r
.48812 .41933 .49477 .4232 .50666 .42264 .50009 .41252 Mtetra
.822 .72 .752 r
.50009 .41252 .50666 .42264 .51863 .41723 .51213 .39708 Mtetra
.661 .552 .721 r
.51213 .39708 .51863 .41723 .53064 .40742 .52414 .39044 Mtetra
.634 .563 .756 r
.52414 .39044 .53064 .40742 .54265 .39648 .53618 .38644 Mtetra
.658 .673 .853 r
.53618 .38644 .54265 .39648 .5547 .38983 .54828 .38242 Mtetra
.664 .741 .907 r
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57904 .38447 .57264 .37432 Mtetra
.658 .673 .853 r
.57264 .37432 .57904 .38447 .59142 .38744 .5849 .37025 Mtetra
.587 .536 .765 r
.5849 .37025 .59142 .38744 .60388 .38929 .59728 .36883 Mtetra
.4 .395 .738 r
.59728 .36883 .60388 .38929 .61632 .38673 .60997 .37629 Mtetra
.576 .633 .871 r
.60997 .37629 .61632 .38673 .62866 .37927 .62254 .37507 Mtetra
.789 .879 .912 r
.62254 .37507 .62866 .37927 .64096 .36966 .63494 .36664 Mtetra
.834 .919 .892 r
.63494 .36664 .64096 .36966 .65331 .36097 .64729 .35632 Mtetra
.787 .866 .908 r
.64729 .35632 .65331 .36097 .66577 .35435 .65973 .34791 Mtetra
.719 .797 .912 r
.65973 .34791 .66577 .35435 .67834 .34926 .6723 .34187 Mtetra
.68 .757 .909 r
.6723 .34187 .67834 .34926 .69099 .34483 .68498 .33712 Mtetra
.667 .744 .908 r
.68498 .33712 .69099 .34483 .70371 .34058 .69774 .33278 Mtetra
.665 .741 .907 r
.69774 .33278 .70371 .34058 .7165 .33635 .71056 .3285 Mtetra
.664 .741 .907 r
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46699 .28663 .46019 Mtetra
.28663 .46019 .29379 .46699 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42245 Mtetra
.663 .741 .908 r
.39963 .42245 .4065 .42953 .41803 .42572 .4112 .41862 Mtetra
.657 .739 .91 r
.4112 .41862 .41803 .42572 .42962 .42197 .42281 .41494 Mtetra
.631 .734 .922 r
.42281 .41494 .42962 .42197 .44124 .41862 .43445 .41199 Mtetra
.536 .713 .954 r
.43445 .41199 .44124 .41862 .45289 .41655 .4461 .41103 Mtetra
.29 .635 .965 r
.4461 .41103 .45289 .41655 .46456 .41682 .45777 .41291 Mtetra
.141 .605 .925 r
.45777 .41291 .46456 .41682 .47628 .41899 .46952 .41505 Mtetra
.668 .854 .971 r
.46952 .41505 .47628 .41899 .48812 .41933 .48146 .41055 Mtetra
.846 .744 .751 r
.48146 .41055 .48812 .41933 .50009 .41252 .49356 .39371 Mtetra
.666 .565 .731 r
.49356 .39371 .50009 .41252 .51213 .39708 .50556 .38706 Mtetra
.658 .673 .853 r
.50556 .38706 .51213 .39708 .52414 .39044 .51759 .38304 Mtetra
.664 .741 .907 r
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59728 .36883 .59089 .35856 Mtetra
.583 .64 .873 r
.59089 .35856 .59728 .36883 .60997 .37629 .60336 .35709 Mtetra
.345 .372 .746 r
.60336 .35709 .60997 .37629 .62254 .37507 .61621 .36592 Mtetra
.645 .696 .882 r
.61621 .36592 .62254 .37507 .63494 .36664 .62881 .36231 Mtetra
.828 .878 .88 r
.62881 .36231 .63494 .36664 .64729 .35632 .64122 .35196 Mtetra
.823 .879 .885 r
.64122 .35196 .64729 .35632 .65973 .34791 .65365 .34186 Mtetra
.752 .819 .905 r
.65365 .34186 .65973 .34791 .6723 .34187 .66622 .33462 Mtetra
.693 .767 .909 r
.66622 .33462 .6723 .34187 .68498 .33712 .67893 .3294 Mtetra
.67 .747 .908 r
.67893 .3294 .68498 .33712 .69774 .33278 .69172 .32492 Mtetra
.665 .742 .907 r
.69172 .32492 .69774 .33278 .71056 .3285 .70458 .32058 Mtetra
.664 .741 .907 r
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31627 Mtetra
.7175 .31627 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30758 Mtetra
.74351 .30758 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .29881 Mtetra
.76977 .29881 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41918 Mtetra
.38116 .41918 .38811 .42629 .39963 .42245 .39271 .4153 Mtetra
.662 .74 .908 r
.39271 .4153 .39963 .42245 .4112 .41862 .4043 .41147 Mtetra
.653 .738 .912 r
.4043 .41147 .4112 .41862 .42281 .41494 .41594 .40788 Mtetra
.611 .728 .929 r
.41594 .40788 .42281 .41494 .43445 .41199 .4276 .4054 Mtetra
.465 .686 .962 r
.4276 .4054 .43445 .41199 .4461 .41103 .43925 .40558 Mtetra
.185 .578 .939 r
.43925 .40558 .4461 .41103 .45777 .41291 .45092 .40844 Mtetra
.362 .716 .987 r
.45092 .40844 .45777 .41291 .46952 .41505 .46273 .40879 Mtetra
.824 .798 .827 r
.46273 .40879 .46952 .41505 .48146 .41055 .47482 .39733 Mtetra
.779 .669 .742 r
.47482 .39733 .48146 .41055 .49356 .39371 .48693 .38366 Mtetra
.658 .673 .853 r
.48693 .38366 .49356 .39371 .50556 .38706 .49894 .37962 Mtetra
.664 .741 .907 r
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .60336 .35709 .59695 .34671 Mtetra
.271 .47 .871 r
.59695 .34671 .60336 .35709 .61621 .36592 .60971 .35227 Mtetra
.444 .505 .827 r
.60971 .35227 .61621 .36592 .62881 .36231 .62254 .35563 Mtetra
.777 .803 .874 r
.62254 .35563 .62881 .36231 .64122 .35196 .63507 .34704 Mtetra
.837 .862 .862 r
.63507 .34704 .64122 .35196 .65365 .34186 .64753 .33586 Mtetra
.779 .827 .889 r
.64753 .33586 .65365 .34186 .66622 .33462 .6601 .32741 Mtetra
.707 .775 .905 r
.6601 .32741 .66622 .33462 .67893 .3294 .67282 .32164 Mtetra
.674 .749 .907 r
.67282 .32164 .67893 .3294 .69172 .32492 .68565 .317 Mtetra
.666 .742 .907 r
.68565 .317 .69172 .32492 .70458 .32058 .69855 .31261 Mtetra
.664 .741 .907 r
.69855 .31261 .70458 .32058 .7175 .31627 .71151 .30825 Mtetra
.71151 .30825 .7175 .31627 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30758 .7376 .29948 Mtetra
.7376 .29948 .74351 .30758 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .29881 .76394 .29064 Mtetra
.76394 .29064 .76977 .29881 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26817 Mtetra
.83087 .26817 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41918 .37415 .412 Mtetra
.37415 .412 .38116 .41918 .39271 .4153 .38573 .4081 Mtetra
.661 .74 .908 r
.38573 .4081 .39271 .4153 .4043 .41147 .39736 .40426 Mtetra
.649 .737 .914 r
.39736 .40426 .4043 .41147 .41594 .40788 .40902 .40076 Mtetra
.592 .722 .934 r
.40902 .40076 .41594 .40788 .4276 .4054 .42069 .3987 Mtetra
.407 .657 .961 r
.42069 .3987 .4276 .4054 .43925 .40558 .43234 .39974 Mtetra
.177 .561 .933 r
.43234 .39974 .43925 .40558 .45092 .40844 .44402 .40293 Mtetra
.577 .773 .972 r
.44402 .40293 .45092 .40844 .46273 .40879 .45593 .40072 Mtetra
.859 .757 .749 r
.45593 .40072 .46273 .40879 .47482 .39733 .46817 .38291 Mtetra
.688 .618 .772 r
.46817 .38291 .47482 .39733 .48693 .38366 .48021 .3762 Mtetra
.664 .741 .907 r
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.566 .702 .933 r
.59056 .33895 .59695 .34671 .60971 .35227 .60316 .33741 Mtetra
.212 .345 .781 r
.60316 .33741 .60971 .35227 .62254 .35563 .61617 .34711 Mtetra
.709 .739 .875 r
.61617 .34711 .62254 .35563 .63507 .34704 .62883 .34104 Mtetra
.833 .831 .846 r
.62883 .34104 .63507 .34704 .64753 .33586 .64133 .32948 Mtetra
.794 .819 .871 r
.64133 .32948 .64753 .33586 .6601 .32741 .65391 .32008 Mtetra
.719 .777 .898 r
.65391 .32008 .6601 .32741 .67282 .32164 .66666 .31381 Mtetra
.678 .75 .906 r
.66666 .31381 .67282 .32164 .68565 .317 .67952 .30901 Mtetra
.666 .742 .907 r
.67952 .30901 .68565 .317 .69855 .31261 .69246 .30456 Mtetra
.664 .741 .907 r
.69246 .30456 .69855 .31261 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26817 .82521 .25973 Mtetra
.82521 .25973 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.663 .741 .907 r
.36709 .40477 .37415 .412 .38573 .4081 .3787 .40084 Mtetra
.661 .74 .909 r
.3787 .40084 .38573 .4081 .39736 .40426 .39035 .39698 Mtetra
.646 .736 .915 r
.39035 .39698 .39736 .40426 .40902 .40076 .40205 .39353 Mtetra
.581 .716 .935 r
.40205 .39353 .40902 .40076 .42069 .3987 .41374 .39171 Mtetra
.382 .636 .955 r
.41374 .39171 .42069 .3987 .43234 .39974 .42539 .39319 Mtetra
.223 .564 .937 r
.42539 .39319 .43234 .39974 .44402 .40293 .4371 .39635 Mtetra
.662 .766 .927 r
.4371 .39635 .44402 .40293 .45593 .40072 .44907 .39234 Mtetra
.866 .752 .735 r
.44907 .39234 .45593 .40072 .46817 .38291 .46141 .37276 Mtetra
.658 .673 .853 r
.46141 .37276 .46817 .38291 .48021 .3762 .47344 .36868 Mtetra
.664 .741 .907 r
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60316 .33741 .59668 .32685 Mtetra
0 .227 .748 r
.59668 .32685 .60316 .33741 .61617 .34711 .60973 .33827 Mtetra
.662 .716 .889 r
.60973 .33827 .61617 .34711 .62883 .34104 .62249 .33396 Mtetra
.822 .803 .833 r
.62249 .33396 .62883 .34104 .64133 .32948 .63505 .32236 Mtetra
.797 .801 .855 r
.63505 .32236 .64133 .32948 .65391 .32008 .64767 .31244 Mtetra
.725 .771 .89 r
.64767 .31244 .65391 .32008 .66666 .31381 .66045 .30586 Mtetra
.68 .749 .904 r
.66045 .30586 .66666 .31381 .67952 .30901 .67335 .30094 Mtetra
.667 .742 .907 r
.67335 .30094 .67952 .30901 .69246 .30456 .68633 .29644 Mtetra
.664 .741 .907 r
.68633 .29644 .69246 .30456 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.663 .741 .907 r
.35996 .39748 .36709 .40477 .3787 .40084 .37161 .39352 Mtetra
.661 .74 .909 r
.37161 .39352 .3787 .40084 .39035 .39698 .3833 .38963 Mtetra
.646 .736 .914 r
.3833 .38963 .39035 .39698 .40205 .39353 .39502 .38615 Mtetra
.582 .713 .933 r
.39502 .38615 .40205 .39353 .41374 .39171 .40674 .3843 Mtetra
.395 .63 .949 r
.40674 .3843 .41374 .39171 .42539 .39319 .41841 .38576 Mtetra
.269 .563 .934 r
.41841 .38576 .42539 .39319 .4371 .39635 .43013 .38889 Mtetra
.662 .742 .909 r
.43013 .38889 .4371 .39635 .44907 .39234 .44214 .38485 Mtetra
.876 .768 .74 r
.44214 .38485 .44907 .39234 .46141 .37276 .45455 .36521 Mtetra
.664 .741 .907 r
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
0 .148 .669 r
.59022 .31892 .59668 .32685 .60973 .33827 .60328 .33033 Mtetra
.664 .743 .909 r
.60328 .33033 .60973 .33827 .62249 .33396 .61607 .32598 Mtetra
.813 .782 .823 r
.61607 .32598 .62249 .33396 .63505 .32236 .62868 .31434 Mtetra
.789 .778 .843 r
.62868 .31434 .63505 .32236 .64767 .31244 .64135 .30437 Mtetra
.723 .761 .883 r
.64135 .30437 .64767 .31244 .66045 .30586 .65418 .29775 Mtetra
.68 .747 .902 r
.65418 .29775 .66045 .30586 .67335 .30094 .66712 .29279 Mtetra
.667 .742 .906 r
.66712 .29279 .67335 .30094 .68633 .29644 .68014 .28826 Mtetra
.664 .741 .907 r
.68014 .28826 .68633 .29644 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39352 .36446 .38614 Mtetra
.661 .74 .908 r
.36446 .38614 .37161 .39352 .3833 .38963 .37618 .3822 Mtetra
.649 .736 .913 r
.37618 .3822 .3833 .38963 .39502 .38615 .38794 .37861 Mtetra
.594 .715 .928 r
.38794 .37861 .39502 .38615 .40674 .3843 .39969 .37646 Mtetra
.437 .639 .942 r
.39969 .37646 .40674 .3843 .41841 .38576 .4114 .37743 Mtetra
.307 .556 .923 r
.4114 .37743 .41841 .38576 .43013 .38889 .42314 .38056 Mtetra
.602 .698 .911 r
.42314 .38056 .43013 .38889 .44214 .38485 .43513 .37826 Mtetra
.876 .787 .759 r
.43513 .37826 .44214 .38485 .45455 .36521 .44757 .36028 Mtetra
.748 .841 .921 r
.44757 .36028 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.664 .741 .907 r
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.566 .702 .933 r
.57104 .31527 .5776 .32323 .59022 .31892 .58375 .31363 Mtetra
0 .143 .606 r
.58375 .31363 .59022 .31892 .60328 .33033 .59679 .32329 Mtetra
.717 .787 .907 r
.59679 .32329 .60328 .33033 .61607 .32598 .60957 .3171 Mtetra
.805 .762 .813 r
.60957 .3171 .61607 .32598 .62868 .31434 .62223 .3054 Mtetra
.773 .755 .836 r
.62223 .3054 .62868 .31434 .64135 .30437 .63497 .29586 Mtetra
.714 .749 .879 r
.63497 .29586 .64135 .30437 .65418 .29775 .64785 .28948 Mtetra
.677 .743 .901 r
.64785 .28948 .65418 .29775 .66712 .29279 .66083 .28456 Mtetra
.666 .741 .906 r
.66083 .28456 .66712 .29279 .68014 .28826 .67389 .28 Mtetra
.664 .741 .907 r
.67389 .28 .68014 .28826 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38614 .35725 .3787 Mtetra
.662 .74 .908 r
.35725 .3787 .36446 .38614 .37618 .3822 .36901 .3747 Mtetra
.653 .737 .911 r
.36901 .3747 .37618 .3822 .38794 .37861 .3808 .37096 Mtetra
.612 .72 .922 r
.3808 .37096 .38794 .37861 .39969 .37646 .3926 .36833 Mtetra
.493 .658 .934 r
.3926 .36833 .39969 .37646 .4114 .37743 .40437 .36838 Mtetra
.354 .562 .915 r
.40437 .36838 .4114 .37743 .42314 .38056 .41612 .37114 Mtetra
.503 .629 .907 r
.41612 .37114 .42314 .38056 .43513 .37826 .42806 .37136 Mtetra
.82 .789 .823 r
.42806 .37136 .43513 .37826 .44757 .36028 .4404 .35967 Mtetra
.894 .946 .835 r
.4404 .35967 .44757 .36028 .45972 .35345 .45278 .34574 Mtetra
.664 .741 .907 r
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.139 .467 .891 r
.56443 .30724 .57104 .31527 .58375 .31363 .57728 .3127 Mtetra
.228 0 0 r
.57728 .3127 .58375 .31363 .59679 .32329 .59023 .31594 Mtetra
.774 .793 .869 r
.59023 .31594 .59679 .32329 .60957 .3171 .603 .30713 Mtetra
.79 .738 .805 r
.603 .30713 .60957 .3171 .62223 .3054 .61572 .29572 Mtetra
.752 .734 .836 r
.61572 .29572 .62223 .3054 .63497 .29586 .62853 .28704 Mtetra
.702 .739 .88 r
.62853 .28704 .63497 .29586 .64785 .28948 .64146 .28108 Mtetra
.673 .74 .901 r
.64146 .28108 .64785 .28948 .66083 .28456 .6545 .27624 Mtetra
.666 .741 .906 r
.6545 .27624 .66083 .28456 .67389 .28 .6676 .27166 Mtetra
.664 .741 .907 r
.6676 .27166 .67389 .28 .68702 .27548 .68077 .26712 Mtetra
.68077 .26712 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39137 Mtetra
.29182 .39137 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .3787 .34999 .3712 Mtetra
.663 .74 .908 r
.34999 .3712 .35725 .3787 .36901 .3747 .36178 .36714 Mtetra
.657 .738 .909 r
.36178 .36714 .36901 .3747 .3808 .37096 .37361 .36324 Mtetra
.631 .726 .916 r
.37361 .36324 .3808 .37096 .3926 .36833 .38546 .36007 Mtetra
.552 .682 .925 r
.38546 .36007 .3926 .36833 .40437 .36838 .39729 .35893 Mtetra
.424 .59 .911 r
.39729 .35893 .40437 .36838 .41612 .37114 .40909 .36064 Mtetra
.431 .567 .89 r
.40909 .36064 .41612 .37114 .42806 .37136 .42098 .36263 Mtetra
.677 .719 .881 r
.42098 .36263 .42806 .37136 .4404 .35967 .43317 .35789 Mtetra
.919 .895 .79 r
.43317 .35789 .4404 .35967 .45278 .34574 .44572 .34066 Mtetra
.748 .84 .921 r
.44572 .34066 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.664 .741 .907 r
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.566 .703 .933 r
.54509 .30354 .5518 .31159 .56443 .30724 .55779 .30185 Mtetra
0 .195 .653 r
.55779 .30185 .56443 .30724 .57728 .3127 .57072 .31059 Mtetra
.535 .888 .981 r
.57072 .31059 .57728 .3127 .59023 .31594 .58358 .30673 Mtetra
.787 .753 .822 r
.58358 .30673 .59023 .31594 .603 .30713 .59635 .29605 Mtetra
.767 .713 .802 r
.59635 .29605 .603 .30713 .61572 .29572 .60914 .28563 Mtetra
.728 .719 .842 r
.60914 .28563 .61572 .29572 .62853 .28704 .62203 .27809 Mtetra
.689 .733 .884 r
.62203 .27809 .62853 .28704 .64146 .28108 .63502 .2726 Mtetra
.67 .739 .902 r
.63502 .2726 .64146 .28108 .6545 .27624 .6481 .26786 Mtetra
.665 .741 .906 r
.6481 .26786 .6545 .27624 .6676 .27166 .66125 .26326 Mtetra
.664 .741 .907 r
.66125 .26326 .6676 .27166 .68077 .26712 .67446 .25868 Mtetra
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21647 Mtetra
.79619 .21647 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40387 Mtetra
.22728 .40387 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39137 .28434 .38397 Mtetra
.28434 .38397 .29182 .39137 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36774 Mtetra
.3309 .36774 .33825 .37526 .34999 .3712 .34266 .36363 Mtetra
.663 .741 .908 r
.34266 .36363 .34999 .3712 .36178 .36714 .35448 .35953 Mtetra
.661 .739 .908 r
.35448 .35953 .36178 .36714 .37361 .36324 .36635 .35549 Mtetra
.647 .732 .911 r
.36635 .35549 .37361 .36324 .38546 .36007 .37826 .35186 Mtetra
.6 .704 .917 r
.37826 .35186 .38546 .36007 .39729 .35893 .39016 .34952 Mtetra
.507 .633 .909 r
.39016 .34952 .39729 .35893 .40909 .36064 .40204 .34956 Mtetra
.439 .559 .879 r
.40204 .34956 .40909 .36064 .42098 .36263 .41394 .35153 Mtetra
.52 .6 .874 r
.41394 .35153 .42098 .36263 .43317 .35789 .42599 .35163 Mtetra
.748 .805 .898 r
.42599 .35163 .43317 .35789 .44572 .34066 .43834 .34448 Mtetra
.867 .992 .744 r
.43834 .34448 .44572 .34066 .458 .33374 .45092 .32856 Mtetra
.748 .84 .921 r
.45092 .32856 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.664 .741 .907 r
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.566 .703 .934 r
.52568 .29982 .53248 .30791 .54509 .30354 .53834 .29812 Mtetra
0 .285 .729 r
.53834 .29812 .54509 .30354 .55779 .30185 .55115 .30544 Mtetra
.142 0 0 r
.55115 .30544 .55779 .30185 .57072 .31059 .56402 .30395 Mtetra
.779 .815 .881 r
.56402 .30395 .57072 .31059 .58358 .30673 .57684 .29512 Mtetra
.766 .704 .794 r
.57684 .29512 .58358 .30673 .59635 .29605 .58965 .28438 Mtetra
.737 .694 .809 r
.58965 .28438 .59635 .29605 .60914 .28563 .60252 .27558 Mtetra
.705 .713 .856 r
.60252 .27558 .60914 .28563 .62203 .27809 .61548 .26918 Mtetra
.678 .731 .891 r
.61548 .26918 .62203 .27809 .63502 .2726 .62853 .26409 Mtetra
.667 .739 .904 r
.62853 .26409 .63502 .2726 .6481 .26786 .64166 .2594 Mtetra
.664 .741 .907 r
.64166 .2594 .6481 .26786 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25017 Mtetra
.6681 .25017 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21647 .79023 .20758 Mtetra
.79023 .20758 .79619 .21647 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19787 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40387 .21959 .39657 Mtetra
.21959 .39657 .22728 .40387 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36837 Mtetra
.30004 .36837 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36774 .32348 .36015 Mtetra
.32348 .36015 .3309 .36774 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35448 .35953 .34713 .35186 Mtetra
.662 .74 .908 r
.34713 .35186 .35448 .35953 .36635 .35549 .35904 .34773 Mtetra
.656 .737 .909 r
.35904 .34773 .36635 .35549 .37826 .35186 .37099 .34378 Mtetra
.633 .721 .911 r
.37099 .34378 .37826 .35186 .39016 .34952 .38296 .34049 Mtetra
.578 .676 .907 r
.38296 .34049 .39016 .34952 .40204 .34956 .39493 .33875 Mtetra
.506 .601 .882 r
.39493 .33875 .40204 .34956 .41394 .35153 .40689 .3391 Mtetra
.482 .555 .854 r
.40689 .3391 .41394 .35153 .42599 .35163 .41892 .34039 Mtetra
.554 .616 .869 r
.41892 .34039 .42599 .35163 .43834 .34448 .4311 .33952 Mtetra
.711 .843 .945 r
.4311 .33952 .43834 .34448 .45092 .32856 .44349 .33371 Mtetra
.53 .876 .629 r
.44349 .33371 .45092 .32856 .46329 .32157 .45603 .32342 Mtetra
.793 .999 .832 r
.45603 .32342 .46329 .32157 .47565 .31726 .46859 .31196 Mtetra
.748 .841 .921 r
.46859 .31196 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.664 .741 .907 r
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.564 .703 .934 r
.49361 .3005 .50055 .30858 .51308 .30421 .50617 .29881 Mtetra
.177 .588 .939 r
.50617 .29881 .51308 .30421 .52568 .29982 .5188 .30152 Mtetra
.27 0 0 r
.5188 .30152 .52568 .29982 .53834 .29812 .53154 .3031 Mtetra
.111 0 0 r
.53154 .3031 .53834 .29812 .55115 .30544 .54436 .30018 Mtetra
.766 .855 .917 r
.54436 .30018 .55115 .30544 .56402 .30395 .5572 .29226 Mtetra
.757 .7 .799 r
.5572 .29226 .56402 .30395 .57684 .29512 .57004 .28215 Mtetra
.733 .673 .791 r
.57004 .28215 .57684 .29512 .58965 .28438 .58292 .27297 Mtetra
.709 .689 .829 r
.58292 .27297 .58965 .28438 .60252 .27558 .59586 .2659 Mtetra
.686 .717 .873 r
.59586 .2659 .60252 .27558 .61548 .26918 .60888 .26039 Mtetra
.67 .734 .897 r
.60888 .26039 .61548 .26918 .62853 .26409 .62199 .25555 Mtetra
.665 .739 .905 r
.62199 .25555 .62853 .26409 .64166 .2594 .63515 .25088 Mtetra
.664 .741 .907 r
.63515 .25088 .64166 .2594 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25017 .66168 .24158 Mtetra
.66168 .24158 .6681 .25017 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19787 .81217 .18882 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36837 .2925 .36078 Mtetra
.2925 .36078 .30004 .36837 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36015 .316 .35249 Mtetra
.316 .35249 .32348 .36015 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35186 .33972 .34413 Mtetra
.663 .741 .907 r
.33972 .34413 .34713 .35186 .35904 .34773 .35166 .33994 Mtetra
.661 .739 .908 r
.35166 .33994 .35904 .34773 .37099 .34378 .36365 .3358 Mtetra
.652 .732 .908 r
.36365 .3358 .37099 .34378 .38296 .34049 .37568 .33193 Mtetra
.625 .708 .905 r
.37568 .33193 .38296 .34049 .39493 .33875 .38773 .32883 Mtetra
.579 .657 .89 r
.38773 .32883 .39493 .33875 .40689 .3391 .39979 .32711 Mtetra
.533 .591 .859 r
.39979 .32711 .40689 .3391 .41892 .34039 .41187 .32692 Mtetra
.522 .559 .835 r
.41187 .32692 .41892 .34039 .4311 .33952 .42402 .32724 Mtetra
.559 .6 .851 r
.42402 .32724 .4311 .33952 .44349 .33371 .4363 .32629 Mtetra
.625 .746 .934 r
.4363 .32629 .44349 .33371 .45603 .32342 .44872 .32301 Mtetra
.549 .922 .935 r
.44872 .32301 .45603 .32342 .46859 .31196 .46124 .31792 Mtetra
0 0 0 r
.46124 .31792 .46859 .31196 .4811 .30488 .47381 .31256 Mtetra
.135 0 0 r
.47381 .31256 .4811 .30488 .49361 .3005 .48642 .30815 Mtetra
.196 0 0 r
.48642 .30815 .49361 .3005 .50617 .29881 .49909 .30469 Mtetra
.095 0 0 r
.49909 .30469 .50617 .29881 .5188 .30152 .51182 .30096 Mtetra
.572 .931 .935 r
.51182 .30096 .5188 .30152 .53154 .3031 .52462 .29542 Mtetra
.752 .783 .878 r
.52462 .29542 .53154 .3031 .54436 .30018 .53746 .28752 Mtetra
.736 .678 .795 r
.53746 .28752 .54436 .30018 .5572 .29226 .55032 .27832 Mtetra
.719 .654 .784 r
.55032 .27832 .5572 .29226 .57004 .28215 .56321 .26963 Mtetra
.704 .669 .813 r
.56321 .26963 .57004 .28215 .58292 .27297 .57615 .26246 Mtetra
.687 .7 .856 r
.57615 .26246 .58292 .27297 .59586 .2659 .58916 .25669 Mtetra
.673 .725 .888 r
.58916 .25669 .59586 .2659 .60888 .26039 .60224 .2517 Mtetra
.666 .737 .903 r
.60224 .2517 .60888 .26039 .62199 .25555 .61538 .24697 Mtetra
.664 .74 .906 r
.61538 .24697 .62199 .25555 .63515 .25088 .62859 .2423 Mtetra
.664 .741 .907 r
.62859 .2423 .63515 .25088 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24158 .6552 .23291 Mtetra
.6552 .23291 .66168 .24158 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18882 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33994 .34422 .33211 Mtetra
.663 .74 .907 r
.34422 .33211 .35166 .33994 .36365 .3358 .35624 .32787 Mtetra
.66 .738 .907 r
.35624 .32787 .36365 .3358 .37568 .33193 .36832 .32371 Mtetra
.65 .728 .906 r
.36832 .32371 .37568 .33193 .38773 .32883 .38043 .31983 Mtetra
.629 .701 .897 r
.38043 .31983 .38773 .32883 .39979 .32711 .39258 .31658 Mtetra
.597 .653 .876 r
.39258 .31658 .39979 .32711 .41187 .32692 .40475 .31432 Mtetra
.57 .6 .844 r
.40475 .31432 .41187 .32692 .42402 .32724 .41697 .31301 Mtetra
.562 .57 .819 r
.41697 .31301 .42402 .32724 .4363 .32629 .42925 .31203 Mtetra
.576 .577 .817 r
.42925 .31203 .4363 .32629 .44872 .32301 .44163 .31052 Mtetra
.604 .621 .841 r
.44163 .31052 .44872 .32301 .46124 .31792 .45411 .30797 Mtetra
.636 .687 .881 r
.45411 .30797 .46124 .31792 .47381 .31256 .46668 .30438 Mtetra
.663 .742 .909 r
.46668 .30438 .47381 .31256 .48642 .30815 .47933 .29993 Mtetra
.687 .749 .899 r
.47933 .29993 .48642 .30815 .49909 .30469 .49205 .29462 Mtetra
.704 .712 .855 r
.49205 .29462 .49909 .30469 .51182 .30096 .50483 .28827 Mtetra
.707 .666 .807 r
.50483 .28827 .51182 .30096 .52462 .29542 .51766 .28085 Mtetra
.703 .639 .782 r
.51766 .28085 .52462 .29542 .53746 .28752 .53052 .2729 Mtetra
.698 .636 .784 r
.53052 .2729 .53746 .28752 .55032 .27832 .54341 .26526 Mtetra
.691 .656 .81 r
.54341 .26526 .55032 .27832 .56321 .26963 .55635 .25858 Mtetra
.683 .688 .848 r
.55635 .25858 .56321 .26963 .57615 .26246 .56935 .25288 Mtetra
.673 .717 .882 r
.56935 .25288 .57615 .26246 .58916 .25669 .58241 .24782 Mtetra
.667 .733 .899 r
.58241 .24782 .58916 .25669 .60224 .2517 .59553 .24304 Mtetra
.665 .739 .905 r
.59553 .24304 .60224 .2517 .61538 .24697 .60872 .23834 Mtetra
.664 .74 .907 r
.60872 .23834 .61538 .24697 .62859 .2423 .62198 .23364 Mtetra
.664 .741 .907 r
.62198 .23364 .62859 .2423 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .33211 .33671 .32422 Mtetra
.33671 .32422 .34422 .33211 .35624 .32787 .34877 .31992 Mtetra
.663 .74 .907 r
.34877 .31992 .35624 .32787 .36832 .32371 .36089 .31564 Mtetra
.66 .737 .906 r
.36089 .31564 .36832 .32371 .38043 .31983 .37305 .31141 Mtetra
.653 .726 .903 r
.37305 .31141 .38043 .31983 .39258 .31658 .38526 .30739 Mtetra
.639 .703 .892 r
.38526 .30739 .39258 .31658 .40475 .31432 .39751 .30375 Mtetra
.622 .665 .871 r
.39751 .30375 .40475 .31432 .41697 .31301 .40981 .30064 Mtetra
.607 .624 .842 r
.40981 .30064 .41697 .31301 .42925 .31203 .42216 .29796 Mtetra
.602 .594 .816 r
.42216 .29796 .42925 .31203 .44163 .31052 .43457 .29538 Mtetra
.608 .583 .8 r
.43457 .29538 .44163 .31052 .45411 .30797 .44707 .29244 Mtetra
.622 .586 .792 r
.44707 .29244 .45411 .30797 .46668 .30438 .45965 .28882 Mtetra
.639 .594 .788 r
.45965 .28882 .46668 .30438 .47933 .29993 .47231 .28432 Mtetra
.655 .602 .784 r
.47231 .28432 .47933 .29993 .49205 .29462 .48504 .27896 Mtetra
.666 .608 .78 r
.48504 .27896 .49205 .29462 .50483 .28827 .49782 .2729 Mtetra
.674 .615 .782 r
.49782 .2729 .50483 .28827 .51766 .28085 .51066 .26648 Mtetra
.677 .63 .795 r
.51066 .26648 .51766 .28085 .53052 .2729 .52354 .26015 Mtetra
.678 .655 .821 r
.52354 .26015 .53052 .2729 .54341 .26526 .53647 .25425 Mtetra
.675 .686 .853 r
.53647 .25425 .54341 .26526 .55635 .25858 .54946 .24887 Mtetra
.671 .714 .881 r
.54946 .24887 .55635 .25858 .56935 .25288 .5625 .24388 Mtetra
.667 .731 .898 r
.5625 .24388 .56935 .25288 .58241 .24782 .57561 .23909 Mtetra
.665 .738 .905 r
.57561 .23909 .58241 .24782 .59553 .24304 .58878 .23437 Mtetra
.664 .74 .907 r
.58878 .23437 .59553 .24304 .60872 .23834 .60201 .22965 Mtetra
.664 .741 .907 r
.60201 .22965 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .31564 .35339 .30758 Mtetra
.663 .74 .907 r
.35339 .30758 .36089 .31564 .37305 .31141 .36559 .30323 Mtetra
.661 .737 .906 r
.36559 .30323 .37305 .31141 .38526 .30739 .37785 .29891 Mtetra
.658 .729 .902 r
.37785 .29891 .38526 .30739 .39751 .30375 .39016 .29469 Mtetra
.651 .713 .893 r
.39016 .29469 .39751 .30375 .40981 .30064 .40252 .29061 Mtetra
.644 .688 .877 r
.40252 .29061 .40981 .30064 .42216 .29796 .41493 .28672 Mtetra
.638 .661 .856 r
.41493 .28672 .42216 .29796 .43457 .29538 .4274 .28291 Mtetra
.636 .638 .835 r
.4274 .28291 .43457 .29538 .44707 .29244 .43994 .27903 Mtetra
.639 .625 .819 r
.43994 .27903 .44707 .29244 .45965 .28882 .45254 .27488 Mtetra
.645 .62 .81 r
.45254 .27488 .45965 .28882 .47231 .28432 .46522 .27034 Mtetra
.653 .624 .808 r
.46522 .27034 .47231 .28432 .48504 .27896 .47796 .26541 Mtetra
.66 .634 .813 r
.47796 .26541 .48504 .27896 .49782 .2729 .49076 .26022 Mtetra
.665 .651 .826 r
.49076 .26022 .49782 .2729 .51066 .26648 .50361 .25494 Mtetra
.668 .673 .846 r
.50361 .25494 .51066 .26648 .52354 .26015 .51652 .24976 Mtetra
.669 .698 .868 r
.51652 .24976 .52354 .26015 .53647 .25425 .52949 .24474 Mtetra
.667 .718 .887 r
.52949 .24474 .53647 .25425 .54946 .24887 .54251 .23989 Mtetra
.666 .731 .899 r
.54251 .23989 .54946 .24887 .5625 .24388 .5556 .23512 Mtetra
.664 .738 .905 r
.5556 .23512 .5625 .24388 .57561 .23909 .56875 .23038 Mtetra
.664 .74 .907 r
.56875 .23038 .57561 .23909 .58878 .23437 .58196 .22564 Mtetra
.664 .741 .907 r
.58196 .22564 .58878 .23437 .60201 .22965 .59523 .22088 Mtetra
.59523 .22088 .60201 .22965 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30758 .34583 .29948 Mtetra
.34583 .29948 .35339 .30758 .36559 .30323 .35806 .29507 Mtetra
.663 .74 .907 r
.35806 .29507 .36559 .30323 .37785 .29891 .37036 .29066 Mtetra
.663 .738 .906 r
.37036 .29066 .37785 .29891 .39016 .29469 .38271 .28624 Mtetra
.661 .734 .903 r
.38271 .28624 .39016 .29469 .40252 .29061 .39511 .28184 Mtetra
.659 .725 .898 r
.39511 .28184 .40252 .29061 .41493 .28672 .40758 .27746 Mtetra
.657 .714 .89 r
.40758 .27746 .41493 .28672 .4274 .28291 .4201 .2731 Mtetra
.656 .701 .88 r
.4201 .2731 .4274 .28291 .43994 .27903 .43268 .26872 Mtetra
.657 .691 .871 r
.43268 .26872 .43994 .27903 .45254 .27488 .44532 .26426 Mtetra
.658 .686 .865 r
.44532 .26426 .45254 .27488 .46522 .27034 .45802 .25968 Mtetra
.661 .687 .864 r
.45802 .25968 .46522 .27034 .47796 .26541 .47079 .25498 Mtetra
.663 .694 .868 r
.47079 .25498 .47796 .26541 .49076 .26022 .48361 .25021 Mtetra
.665 .704 .877 r
.48361 .25021 .49076 .26022 .50361 .25494 .49649 .24541 Mtetra
.665 .717 .887 r
.49649 .24541 .50361 .25494 .51652 .24976 .50944 .24062 Mtetra
.665 .727 .896 r
.50944 .24062 .51652 .24976 .52949 .24474 .52244 .23586 Mtetra
.665 .735 .902 r
.52244 .23586 .52949 .24474 .54251 .23989 .53551 .23112 Mtetra
.664 .739 .905 r
.53551 .23112 .54251 .23989 .5556 .23512 .54863 .22637 Mtetra
.664 .74 .907 r
.54863 .22637 .5556 .23512 .56875 .23038 .56182 .22161 Mtetra
.664 .741 .907 r
.56182 .22161 .56875 .23038 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29066 .3628 .2824 Mtetra
.664 .74 .907 r
.3628 .2824 .37036 .29066 .38271 .28624 .37519 .27792 Mtetra
.663 .739 .907 r
.37519 .27792 .38271 .28624 .39511 .28184 .38763 .27342 Mtetra
.663 .738 .905 r
.38763 .27342 .39511 .28184 .40758 .27746 .40013 .2689 Mtetra
.663 .735 .903 r
.40013 .2689 .40758 .27746 .4201 .2731 .41269 .26438 Mtetra
.663 .732 .901 r
.41269 .26438 .4201 .2731 .43268 .26872 .42531 .25983 Mtetra
.663 .728 .898 r
.42531 .25983 .43268 .26872 .44532 .26426 .43799 .25525 Mtetra
.663 .727 .897 r
.43799 .25525 .44532 .26426 .45802 .25968 .45073 .25063 Mtetra
.663 .727 .896 r
.45073 .25063 .45802 .25968 .47079 .25498 .46353 .24597 Mtetra
.664 .729 .898 r
.46353 .24597 .47079 .25498 .48361 .25021 .47639 .24128 Mtetra
.664 .732 .9 r
.47639 .24128 .48361 .25021 .49649 .24541 .48931 .23657 Mtetra
.664 .735 .903 r
.48931 .23657 .49649 .24541 .50944 .24062 .50229 .23185 Mtetra
.664 .738 .905 r
.50229 .23185 .50944 .24062 .52244 .23586 .51534 .2271 Mtetra
.664 .74 .906 r
.51534 .2271 .52244 .23586 .53551 .23112 .52844 .22235 Mtetra
.664 .74 .907 r
.52844 .22235 .53551 .23112 .54863 .22637 .54161 .21757 Mtetra
.664 .741 .907 r
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27792 .3676 .26956 Mtetra
.3676 .26956 .37519 .27792 .38763 .27342 .38008 .26501 Mtetra
.664 .74 .907 r
.38008 .26501 .38763 .27342 .40013 .2689 .39262 .26044 Mtetra
.39262 .26044 .40013 .2689 .41269 .26438 .40522 .25585 Mtetra
.664 .739 .906 r
.40522 .25585 .41269 .26438 .42531 .25983 .41787 .25124 Mtetra
.41787 .25124 .42531 .25983 .43799 .25525 .43059 .24661 Mtetra
.664 .738 .905 r
.43059 .24661 .43799 .25525 .45073 .25063 .44337 .24195 Mtetra
.44337 .24195 .45073 .25063 .46353 .24597 .45621 .23727 Mtetra
.664 .739 .906 r
.45621 .23727 .46353 .24597 .47639 .24128 .4691 .23256 Mtetra
.4691 .23256 .47639 .24128 .48931 .23657 .48206 .22783 Mtetra
.664 .74 .907 r
.48206 .22783 .48931 .23657 .50229 .23185 .49509 .22308 Mtetra
.49509 .22308 .50229 .23185 .51534 .2271 .50817 .2183 Mtetra
.664 .741 .907 r
.50817 .2183 .51534 .2271 .52844 .22235 .52132 .21351 Mtetra
.52132 .21351 .52844 .22235 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26115 Mtetra
.35995 .26115 .3676 .26956 .38008 .26501 .37246 .25656 Mtetra
.37246 .25656 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25124 .41037 .24265 Mtetra
.41037 .24265 .41787 .25124 .43059 .24661 .42312 .23798 Mtetra
.664 .74 .907 r
.42312 .23798 .43059 .24661 .44337 .24195 .43594 .23328 Mtetra
.43594 .23328 .44337 .24195 .45621 .23727 .44881 .22855 Mtetra
.664 .741 .907 r
.44881 .22855 .45621 .23727 .4691 .23256 .46175 .22381 Mtetra
.46175 .22381 .4691 .23256 .48206 .22783 .47475 .21904 Mtetra
.47475 .21904 .48206 .22783 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26115 .35223 .25265 Mtetra
.35223 .25265 .35995 .26115 .37246 .25656 .36478 .24802 Mtetra
.36478 .24802 .37246 .25656 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23798 .41559 .22928 Mtetra
.41559 .22928 .42312 .23798 .43594 .23328 .42844 .22454 Mtetra
.42844 .22454 .43594 .23328 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23473 Mtetra
.36968 .23473 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23473 .3619 .226 Mtetra
.3619 .226 .36968 .23473 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12594 Mtetra
.43285 .12594 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12594 .42493 .11623 Mtetra
.42493 .11623 .43285 .12594 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15336 Mtetra
.2971 .15336 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13794 Mtetra
.33645 .13794 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000:X0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool300000:`0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00002^0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<0
0000N02Y_NP50:Vmic@0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`060?ooo`07
0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool03@2oM000001809boW01807@0
_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool2000006l0ZKgX0`2Y_NL70:Vm
j0<0ZKcW2P2Y_NL^0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool01P3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool001P0oooo00/0okmd0000000007@0_ooo0?oo
o`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<00000K`2Y_NP60:Vmi`@0ZKgX1P2Y_>L20:Vm
i`<0Z[cV1@2Y_NL20:Vmj0<0ZKcW:02Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo
00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D0?ooo`<0000000<0ZKgX0000002Y_NP0J`2Y
_NP:0:Vmi`X0ZKcW1P2Z_>H40:Vmi`H0ZKcW0P2Y_NP30:Zlib80ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000K`2Y_NP30:Vli`D0ZKgW1@2Y^nH50:Vli`D0Z[[U1@2Z_>H60:ZkiP@0ZKcW
1P2Z_>LQ0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool01@3ookl0M000
00000000B9`0gooo0340oooo000b0?ooo`<00000K`2Y_NP60:Vli`80ZKgW0`2Y^^D50:VkiP80ZKcW
0`2Z]n<50:Zji@80Z[cV0`2Z]n<60:ZkiPD0Z[_U1@2Z_>L50:Zmia/0ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX06/0ZKgX2P2Y
_>L60:Vji@@0ZK_V1P2Z]n<40:Zji@H0Z[OS0`2Z^nH30:^fh@D0Z[_U1@2Z^nH50:Zmi`D0ZKgW502Y
_NP2000002`0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo00@0ZKgX0000000000000000K`2Y
_NP20:Vmi`H0ZKcW2P2Y^^D40:Zdh0H0Z[OS1@2[/]h50:Zgh`H0ZkKQ0P2Z^nD30:bgh@D0Z[_V0P2Z
_NL30:Zli`D0ZKgW402Y_NP300000080ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?oo
o`0i0?ooo`00:`3oool200000700ZKgX1@2Y_NL30:Vli`X0ZK[U0`2Y/Mh40:Zdh0<0Z[OS0`2[[=P5
0:^bgPD0[:oJ1@2[]^460:bgh@@0Z[_V1P2Z_>L20:Vmi`<0Z[gW302Y_NP3000000D0ZKgX00<00000
0:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0h0?ooo`00:@3oool2000006h0ZKgX2P2Y_NL:0:Vj
i@H0ZK7N102Z]>060:^/f080Zk;N0`2]Ym850:b_fP80ZkKQ0`2^/=T50:bgh@D0[;WS1@2Z_>L60:Zm
i`P0ZKgX0`0000090:Vmj0030000002Y_NP0ZKgX02X0ZKgX00<000000?ooo`3oool0=`3oool001d0
oooo00D0oono07@00000000004RL0=ooo`070?ooo`800000K`2Y_NP50:Vmi`X0ZK[U1@2Y[md50:Va
gPD0ZZKC1@2[[=P50:fWdPD0[:oJ1P2^/=T20:bgh@<0[k?K1@2/^N<50:^ki@D0Z[gW1P2Y_NP20000
00d0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0g0?ooo`00703oool01P3ooml0
W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000K`2Y_NP20:Vmi`<0ZK_V1@2Y^^D5
0:R_g@D0ZJoM0P2Y/Mh30:RRd0D0ZZKC0P2[[=P30:fQb`D0[JOB0P2/[mX30;2Wc`D0[[3I1P2_/m/2
0:bih`<0[kOO1@2[^nD50:Zmi`80ZKgX0`00000@0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<00000
0?ooo`3oool0=P3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo0P00
00020?ooo`030000002Y_NP0ZKgX06`0ZKgX1P2Y^nH20:Vji@<0Z;3N1@2X[md40:V_g@D0Z:;@1@2Z
Y]<50:fQb`D0[JOB1P2`Yll20:j`f@<0]:_@1@2_/m/60:ngg`80Zk_U0`2]^n@30:Zmi`<0000000@0
ZKgX0:Zmi`2Z_NL0Z[gW3`2Y_NP00`000000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03D0oooo
000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo0080
oooo00<000000:Vmj02Y_NP0I`2Y_NP50:Vli`D0ZK_V1@2X/=h50:R_g@D0Yio>1@2XX]020:ZVd`<0
[9g81@2]XL/20:fWdP<0/Z;81@2`Yll60;B[d080[k?K0`2e/=@50:ngg`D0[K_T0`0000070:Zmia00
ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@004RL
0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`030?ooofD0ZKgX2P2Y_>L50:Nc
h@D0Z;3N0P2X[md30:FNc`@0Yio>1@2XX]050:bMb0D0[J7;1@2bX/P40;2Wc`80^:O81@2dZm060;F`
e080[kOO0`2d]]/01@2]^n@00000000000000000[K_T00D0ZkgV102Z_NLA0:Vmj0030000002Y_NP0
ZKgX02T0ZKgX00<000000?ooo`3oool0=03oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo00D0oooo0P0000050?ooo`030000002Y_NP0ZKgX0680ZKgX1@2Y_>L50:Rfh`D0Yk?Q102X
/=h50:FNc`D0Yio>0P2XX]030:ZKa`D0[9g80`2]XL/20;>Sb0D0/Z;80P2`Yll30;RWb0@0]:_@0P2k
[<X50;F`e0<0];KK0`0000020:fki0<0/;_R102[_NH50:Zmia40ZKgX00<000000:Vmj02Y_NP0:@2Y
_NP00`000000oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX0680ZKgX0`2Y_>L20:Rii@D0Z;KS
102W/n450:>Od@D0YIk?102WWlh50:ZKa`D0[9g80P2]XL/30;>Sb0D0/Z;81P2hYlP20;B[d0<0^jc:
102e/=@0102l/Ll000000000000000030;Bff`H0/;_R0P2[_NH20:bmiPD0Z[gW402Y_NP00`000000
ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3O
W4P007Bo1P3oool00`000000oooo0?ooo`070?ooof@0ZKgX1@2X^ND40:Rfh`D0XZ?E102SWm450:FN
c`80Yio>0`2WV/P50:ZKa`@0[9g81P2cXlP30;:Rb080_:g;1@2hYlP60;^/bP040;F`e00000000000
00000080_;7?0P2d]]/30;Zhe`D0/;_R1@2/_NH50:Zmia00ZKgX00<000000:Vmj02Y_NP0:@2Y_NP0
0`000000oooo0?ooo`0b0?ooo`007@3oool01@3ookl0M00000000000B9`0gooo00H0oooo00<00000
0?ooo`3oool0203ooomO0:Vmj0D0ZK_W1@2X^ND40:>Yf`@0XZ?E1@2SWm440:FNc`D0Yi[81@2ZVlL2
0:bMb0<0]:[>1@2cXlP20;:Rb0<0_:g;102hYlP20<6cc0@0^jc:0P0000050;bac`H0^[SG1@2c_N44
0:bmiPH0Z[gW402Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo0380oooo000W0?oo
o`030000003oool0oooo00X0ooooFP2Y_NP50:Vli`D0ZK_W1@2T/>040:>Yf`@0XZ?E102SWm450:>H
b@D0Yi[8102ZVlL50;BZcPD0/j?81P2l[L/20;RWb0<0`K?<00@0^jc:00000000000000000P34]</4
0;bac`80a;K=102j^=L20<2keP@0/kgQ1@2]_^H50:Zmia00ZKgX00<000000:Vmj02Y_NP0:@2Y_NP0
0`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`0;0?oooeX0ZKgX1@2Y_>L20:Vk
i`<0Y[KT102T/>050:>Yf`<0XZ?E1@2OU/X40:>Hb@D0Yi[80P2ZVlL30;BffPD0]:[>0P2cXlP30<38
h0D0_:g;0`31/l`300000080^jc:1034]</20;bac`@0a;K=0P2j^=L40<2keP80/kgQ0P2f_n450:fn
iPD0Z[gW402Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo0300oooo000W0?ooo`03
0000003oool0oooo00`0ooooFP2Y_NP40:Vli`D0Y[KT1@2T/>040:>Yf`@0ViG<102OU/X50:>Hb@@0
Yi[81@2d]]X50;BZcPH0`<SP0P2l[L/20<CJjP<000000`31/l`60<Bdb`H0a;K=1P30^mH50;Joh@80
[KkV0`2^_nH50:Zmia00ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0`0?ooo`00
9`3oool2000000h0ooooF@2Y_NP50:RjiPD0Y[KT102T/>0509ZHd0@0ViG<102OU/X40:>Hb@D0[koV
1@2d]]X20;BZcP<0T^k_1@30b>001@34f^X00000000000000000a=[Z00@0`K?<0P37d>440<Bdb`80
bL3B1034]/d20<ZlcP@0`;_F0P35`MH40;Joh@H0[[oV0P2Z_NL30:Zmj100ZKgX00<000000:Vmj02Y
_NP0:02Y_NP00`000000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?oooeD0ZKgX
102Y_>L50:RjiP@0Y[KT1@2KWmL409ZHd0@0ViG<102OU/X20:>Hb@<0ZKgX1@2__nH40;BffPH0T^k_
0P2@/nl3000000D0a=[Z0P31/l`40<O@h@80a;C;1039`=820<Bfc@@0b[c>0P30^mH30<G1eP80][oQ
0`2i`^850:joiPH0Z[gX3`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo02h0oooo
000W0?ooo`030000003oool0oooo00l0ooooE@2Y_NP40:Vli`<0Z;[V0P2S/n@409nZgP@0VioG1@2J
V=0409^Ec0<0WiK:1P2Y_NP40:noiP030:Vmj02@/nl0T;?_0080T;?_102Y_NP3000000<0ZKgX00<0
T;?^0<CJjP34f^X00P34f^X60<O@h@H0bL3B1P3:_<h50<G1ePH0^L;R1@2^_nL50:Zmj100ZKgX00<0
00000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool200000140oooo00<00000
0:Vmj02Y_NP0DP2Y_NP40:Vli`D0Xk?T102OZ]h409^Oe`@0VYS@102KUL`50::_h@h0ZKgX0`000007
0:Vmj0@0T;?^00@0036W0<O@h@37d>40am3Q0`28ho/40<W0dP80a/_N103:_<h20<k3d0<0aL7F0P39
amL30;W2hP<0^LGS1@2^_nL50:Zmj100ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?oo
o`0]0?ooo`009P3oool2000001<0oooo00<000000:Vmj02Y_NP0D@2Y_NP50:Nii`D0Xk?T0`2OZ]h4
09^Oe`@0VYS@1@2JW]L50::_h@@0_mO[1P2Y_NP3000000l0ZKgX00<08gOT08SSn`28ho/01028ho/2
0<W0dP<0a/_N0`3:_<h40<k3d0030<G1eP39amL0bLOG0080bLOG1P2iaN<20:joi`<0[KoW1@2Z_NP@
0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0;03oool000T0oooo00X0oono07@0
0000000004RL0=ooo`3oool0omnL04P0M02oool0gia81@0000000`1d_ol0oooo0=nLB00200000003
0000B02Lgol0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000ZKgX0:Vmj01<0:Vmj0D0
Z;cW1@2W^NL40:>ci0@0TIWH102?TM4409>Cd@D0VYkG0P2R[n40103;om@0_mO[0;oGj`2oen/60:Vm
j08000004`2Y_NP5092ckP03000TV`36bmh0a/_N00@0a/_N00<0b[c>0<k3d03>`m000`3>`m040<W7
e`80c<gJ1@2iaN<60:foi`D0Z[gX3`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo
00X0oooo00D0gia8000000000000001809cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0
gia8001d_`@0oooo00<0omnL04P0001d_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02o
ool01P3oool00`000000oooo0?ooo`0D0?ooo`030000002Y_NP0ZKgX04`0ZKgX1@2X_>L50:6ci@@0
V:OP0`2AVMP408nAd@D0Ti?A102JW]L40<_oe0D0ZKgX0`00000F0:Vmj0D0T;?^00<002BK0<K;gP36
bmh00`36bmh50<k3d080d<SB0P39amL40<c=fPD0^<KU0`2]_nL30:boj0D0Z[gX3`2Y_NP00`000000
ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00P0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW018
0000M;oo00P0oooo00<0_g@007Boo`3oool01@3oool2000001H0ooooC`2Y_NP30:Rli`80Y[[W102Q
/nD409RWh0@0TIWH102?TM4409>Cd@80S>c_0P3;om@60:Vmj0<000007`2Y_NP00`0099/0]lWX0;O9
j0030;O9j0<0c/?@103@b=840<c=fP80bm7N1@2ha^D60:boj0@0Z[gX402Y_NP00`000000ZKgX0:Vm
j00X0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo
0?ooo`050?ooo`030000003oool0oooo01L0ooooCP2Y_NP50:Jji`@0XK?U102HYn03096If0@0Si7A
1@2O_^l208OPX@80_mO[0P2Y_NP3000002<0ZKgX00<002BK0;O9j02gbNP00`2gbNP50=38dP80d/gE
0P3<cMX40<_AgP80^<KU0`2da^L50:boj0D0Z[gX3`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000
003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0okmd0018W03Oool0oooo
0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018W=l0oooo0?oOW01804P0W=oo0?ooo`3ooml0W4Q8
09cOo`060?ooo`030000003oool0oooo01P0ooooB@2Y_NP50:Rlj0@0Y[[W102Q/nD409RWh0<0TIWH
1@2?VMT309nnk`0408OPX@2oen/0_mO[0;oGj`<000009`2Y_NP00`0099/0]lWX0;O9j0030:Vnj0<0
d<SB0`3BcMD60<_AgPH0]<KW1@2[_nP40:Zmj100ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000
oooo0?ooo`060?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0L0?ooo`00203oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool01@3ookl0M01809cOo`3ookl0M00000<00000
00<0M;oo0?ooo`3oool0103oool2000001/0ooooB@2Y_NP50:Rlj0@0WkGW102DZ><408RGf`<0QHoE
1@2?VMT00`2O_^l0Qn2Q0;KGl@03000000030;oGj`2Y_NP0ZKgX02L0ZKgX00<003Zo0:Vnj02Y_^P0
102Y_^P00`3@b=80d/gE0=;=e@020=;=e@040=GDf03;dMh0bm7N0<_AgP<0am?S0`2da^L30;74j0D0
ZkoX102Z_NP@0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0
M000000000020000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`09
0?ooo`030000003oool0oooo01/0ooooB@2Y_NP50:Jkj0@0WkGW102DZ><308RGf`@0QHoE102?VMT3
00000080gOfn;02Y_NP00`00>[l0ZKkX0:Vnj0030:Vnj0@0d/gE0`3Ee=P60<OCh`H0/LCX0P2[_nP3
0:Znj0@0Z[gX402Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo00D0oooo00<0oooO
09a8B02Lgol0803oool000P0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d
04P0W=oo0?ooo`3ogi`0B01809cOo`3oool0_g@007Boo`T0oooo00<000000?ooo`3oool0703ooom9
0:Vmj0D0Y[_X102O]NL309BXh`@0R9OK1025SmD3000000030;KGl@3MoKh0gOfn00<0_mO[:`2Y_NP2
000j_`D0ZKOS0P3BcMD40=GDf0040=KLg037dn<0am?S0<OCh`<0`=7W1@2aa>P50:Znj080Z[gX4P2Y
_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00<0_g@007Boo`3oool07`3o
ool000T0oooo00D0oono07@00000000004RL0=ooo`050?ooo`050?oOW018000000000000001d_ol0
0P3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool07@3ooom90:Vm
j0@0Y[_X1@2C[NP3086Ih@<0NhkJ0P2=WMh20000000408fMgP2feo40]]Oa0=gm_PH0_mO[9`2Y_NP4
092ckP0303IHa`00>[l0ZKOS00@0ZKOS103Ee=P30=KLg0H0`=7W1@2^`NP40:Znj1D0ZKgX00<00000
0:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`060=nLB000000000000000000007@0_ooo
703oool002D0oooo0P00000O0?ooodP0ZKgX1@2R^>T509>]j080PIWQ0P1kS]X3000000@0SIgN0P2o
c^D20>_UbR`0ZKgX0`2@/nh203IHa`03000j_`2Y]n<0ZKOS00<0]KgO0P3Ee=P30=KLg080d^7R0`30
dNL30;S<j@D0[/7X102Z_NPE0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09P3o
ool002D0oooo00<000000?ooo`3oool07`3ooom40:Vmj0D0YkcX102R^>T409>]j004086Ih@000000
0000000000<0NhkJ0P2=WMh30;o>i@80jnG:0P3Tl]D[0:Vmj0@0T;?^0P0fF<L60;Fmg`<0e]cL103B
hN860;S<j@D0ZkoX102Z_NPD0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool09@3o
ool002D0oooo00<000000?ooo`3oool0803ooom40:Vmj0D0YkcX102I]>X01021X^P0000000000000
0002072?h@@0NhkJ102oc^D20>_UbP@0i?;E:`2Y_NP304EhgP<0=US70`2e_Ml30<K=g`@0d^7R0`39
gNP30;S<j@<0/LGY102[_nPI0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09@3o
ool002@0oooo0P00000S0?oood@0ZKgX1@2U^nT0102I]>X00000000000000003086Rj0<0L8oQ1025
VMl20;o>i@80jnG:1@3Tl]D/0:Vmj0<0AGSN0`1aPM<40<K=g`<0dn3Q1P39gNP60;75j@80ZkoX0P2Z
_^PI0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool0903oool002@0oooo00<00000
0?ooo`3oool08`3ooom40:Vmj080YK_Y0`00000309VdjP@0PJ;X0`1`Sn4408FIg`80jnG:1@3Tl]D2
0;oGjb/0ZKgX0`15N=h40761d`80a/gO103Ch>40103Ejn@0bMgX0<WMj039gNP30;gCj`D0/LGY1@2Z
_^PI0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo00<00000
0?ooo`3oool0903ooom20:Vmj0<000000`2U^nT408f^k0<0K9OY101`Sn450:fhh@<0dLWB1@2oen/W
0:Vmj0@0UJ?O00<0F5nn04EhgP15N=h0101aPM<40=?Ph@<0eN_T1P2mdn/50:c1j@@0Z[kX6@2Y_NP0
0`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02<0oooo000T0?ooo`8000009P3oooln0:Vm
j0<000000P2Y_NP50:6ijP@0SJk/0`1/UnT406jAh`<0[KSQ103AbM820>39`R/0ZKgX0`2EXml305QO
_PD0YK;Q0P3Ch>420=G[i0<0c>OZ0`2mdn/30;?8jP@0[<7Y1@2Z_NPI0:Vmj0030000002Y_NP0ZKgX
02L0ZKgX00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?oooc/0ZKgX0P0000020:Vmj0@0
Z;cX1@2Q^NX308f^k0@0K9OY101^TN<00`2]^>40dLWB0=79dP020=79dP<0h<W200<0h<Bm0:Vmj02Y
_NP0:02Y_NP309FSg`@0F5nn1@2U/^400`3Ejn@0c>OZ0<cWjP040<cWjPH0/lSZ102[_^P50:Zmj1T0
ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0Q0?ooo`003@3oool02`3ookl0M000
00000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3o
ool00`000000oooo0?ooo`0X0?ooocH0ZKgX0`0000050:Vmj0@0Z;cX1@2L^>`307jXk`<0FXoZ101^
TN<40=79dP<0h<W20`3Pa;d50:R/fR00ZKgX1@2FRL<00`1VIK`0UJ?O09FSg`0405QO_P80YK;Q0P39
hNT20=3bj0<0c>OZ0`2mf>d30;?8jP<0[L;Y102[_^PN0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<0
00000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`070?no
M000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo<P2Y_NP30000
00T0ZKgX102W_>T509bhk0<0OZS_0`1JSnX4082Qj080dLWB0`3PbL840>34_@030=g0_02X[=X0Z:cJ
00<0Z:cJ702Y_NP40:R/fP@0UXW30P1VIK`00`2EXml0F5nn05QO_P0205QO_P<0bN7Y103@l^P60;gH
k@D0[L;Y1@2Z_NPM0:Vmj0030000002Y_NP0ZKgX02L0ZKgX0P00000Q0?ooo`00303oool01`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool0203oool00`2oM000M;oo0?ooo`050?ooo`800000;03oool^
0:Vmj0<000003@2Y_NP40:Nlj@@0W;S/101nZ>l305Z?jP@0P:7X103PbL830>34_@80gL2l102X[=X2
0;2NaA`0ZKgX0`2X[=X409J9``<0IVFl1P2CX]h30=3bj0@0b>_]1@2bbN/30:g2j@80Z[kX1@2Z_NPM
0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?oo
o`0/0?ooobX0ZKgX0`00000A0:Vmj0@0Y[cY102H]nd406nSl@80CXk/1@2J/^T20>39`P<0h<Bm103M
`;`20:R/fP@0/9k5702Y_NP30:R/fP@0UXW30`1VIK`409>RgP80`nS`1038jnd30;[FkPD0//W[1@2Z
_^P20:Zmj200ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool0
1`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8
B02Lgol01P3oool00`000000oooo0?ooo`0]0?ooobH0ZKgX0`00000E0:Vmj0@0Y[cY102H]nd406nS
l@80CXk/1@2J/^T40>34_@@0gL2l1P2`W/D40:R/fPd0ZKgX0P2X[=X90:Vmj0<0Z:cJ102FRL<406IU
_080Tj;N0P33j?030<Ogk0H0^]K^1@2/`NT40:Znj280ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`00
0000oooo0?ooo`0N0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo00D0oooo00<000000?ooo`3oool0;P3ooolR
0:Vmj0<000006@2Y_NP40:Jlj@@0U;K^101UXO8204B@k`D0ZKgX0P3Pa;d50=g0_0030=_1_`2`W/D0
/9k50080/9k50P37Zkd90:R/fPD0ZKgX1@2X[=X20:Vmj0<0WX>e102EOKL2089d^`@0UXW3101VIK`3
0<?Xl0<0aoO/0`30io450:o6j`@0[<7Y1@2Z_NPR0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<00000
0?ooo`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0
oooO09a8B02Lgol02@3oool200000340oooo7P2Y_NP3000001`0ZKgX1@2U_>T409BfkP@0IJ7b0P14
T>l50:Vmj0D0gL2l0P3K`Kl30;2Na@@0aj^m0P2X[=X20:Z@^`D0Z:cJ1@2RT<440:R/fPD0WX>e102E
OKL3089d^`@0PXC=1@2M]NT20<Ogk0<0`>Oa0`2ccnh50:o6j`@0Z[kX1@2Z_NPR0:Vmj0030000002Y
_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nL
B000M;l50?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3ooolK0:Vmj0800000
802Y_NP50:Flj@@0U;O_0`1QX_@304B@k`80ZKgX0`2Ya>d30=g0_0@0fl6o00<0/9k50<N[_@37Zkd0
0`37Zkd50:Z@^`80Z:cJ0`2YSKP40::@`@80Z:cJ0`2XRkL409j3]@@0UGfg0`22M;/508:4c@80WKGY
0P2km_430;gdl@H0/lo^1@2[_nT40:Znj2L0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo
0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia8000000000000
00000000M02oool50?ooo`030000003oool0oooo0380oooo5`2Y_NP3000002<0ZKgX1@2U_>X409Bg
k`<0HJ;d0P0iT>l60:W4k@030=g0_03K`Kl0fl6o00<0fl6o1P37Zkd00`3H_/00ZY2k0:Z@^`020:Z@
^`D0ZHfh102RT<450:R;]`D0WX>e102EOKL3089d^`@0PXC=0P2km_440;gdl@80]m[b0`2ccnh30:c2
jP@0ZkoY:`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01/0oooo000R0?ooo`80
0000=03ooolC0:Vmj0<000009`2Y_NP50:FljPD0UkS_0P1XZ?H303V@k`@0ZLC]1@3K`Kl20=;<d`@0
aj^m0P3H_/040:Z@^`030=:h`02YSKP0ZHfh00<0ZHfh0P2RT<420;fS_P@0Z8^g1@2NPkD409Em]`<0
PWBk102[i?X40:ggkPD0]m[b1P2/`^X20:^oj@80Z[kX:`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo01/0oooo000R0?ooo`030000003oool0oooo03@0oooo3`2Y_NP3000002/0ZKgX
1@2V_>T509Nhk`<0J:Sf0P0]Snh409?5n0<0fl6o0`3Bc=<30<N[_@<0f;k00`2ZT;/20=:h`0D0ZHfh
00@0XY310;fS_P2mXkh0_J>n1@2XRkL409j3]@@0UGfg1@2QbOD20:ggkPD0]NGf1@2^a^`50:c2jPD0
Z[kX:`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01X0oooo000R0?ooo`030000
003oool0oooo03D0oooo00<000000:Vmj02Y_NP0202Y_NP3000002l0ZKgX1@2V_>T509bjk@<0Mjof
0`0_To0309?5n0H0d/cC00<0aj^m0=Rn`03H_/000`3H_/020:Z@^`80d[S01@2YSKP40;fS_PD0Z8^g
102NPkD50:6kj`80XLWe0P2GlN/40:c[n@@0[l_^1@2^a^`90:Znj2`0ZKgX00<000000:Vmj02Y_NP0
9@2Y_NP00`000000oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@000000000
04RL0=ooo`040?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`H0ZKgX0`00000c0:Vmj0D0YkcY
1@2L^^d307N_mP<0;i?`0`1L]o`50=;<d`H0f;k000<0ZY2k0=:h`03B^<000P3B^<030:V=^080bL;C
102mXkh40:R;]`80WX>e0`2Y_^P40:6kj`80Uo7[102/joT30:k>l@@0[l_^1@2[_nT40:Znj300ZKgX
00<000000:Vmj02Y_NP09P2Y_NP2000000`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007Bo103oool00240oooo0P00000j0?ooo`80ZKgX0`00000h0:Vmj0@0YkcY1@2Q^n`3
08Vfm0<0BZ;g0`1L]o`50:_Jn0D0f;k01@3B^<020:V=^0<0bL;C102mXkh40:R;]`H0ZKkX0P2Q^n/2
08CYj@<0W^_j1P2^c_440:_0j@D0ZkoY=02Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0
oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?oo
o`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000?02Y_NP40:Rmj0D0XK_/0`29]_@404ZRm`<0
99[/102[f_P20=Rn`0<0`=k^103B^<060<W2d`<0_J>n1@2ac^l50:Vnj080Q>WY00<0W^_j0:_@l`2[
d?<0102[d?<50:_1jP@0Zl3Y>@2Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00X0
oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3o
ool00`000000oooo0?ooo`0f0?ooo`8000000`3ooolm0:Vmj0@0Z;gX1@2U_>X309Rjl0D0LK;i0`0[
W?0203bdl@H0`=k^0P3B^<020;7Un0D0bL;C102Who/50;7>k`80LN3V0P2@i_/40:O?m@<0Zm3c0`2Z
`^/40:_1jPD0Z[kX>02Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00T0oooo00/0
omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool20000
03@0oooo0`0000060?ooocd0ZKgX0P2X_NP20:Vmj0D0YKcZ0`2H^_0508njl`@0H[;k0P0UXN/40<3N
kPD0/NGh1P1`fo<30:OSn`80FmCP00<0B<SN08OOo@2Tc?@0102Tc?@40:O?m@H0Z/;[2@2Z_^Ph0:Vm
j0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0203oool02`3ogi`0B01d0;ooo`3oool0
omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo0300oooo
0`0000090?oood80ZKgX0P2U_>X30:Nmj@@0XKc/102?^_<408flmPD0I[Wm100c[nh3032fgP80A/;Z
1P2<c_h40:?7lPD0Y<cd102Y`N/30:[2j`<0ZKkX102Z_^Pm0:Vmj0030000002Y_NP0ZKgX02D0ZKgX
00<000000?ooo`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0
M02oool0oooo0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?ooo`030000
003oool0oooo02d0oooo0`00000>0?oood00ZKgX1P2W_NT20:6lk080Y[gY1@2O_>d308flmPH0Tkoe
0`1l`_d609C6n0D0Xl?`102Sao890:W1j`H0ZKkX0P2Z_^Po0:Vmj0030000002Y_NP0ZKgX02D0ZKgX
00<000000?ooo`3oool01P3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3O
W4P007Bo00@0oooo00030?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q8
09cOo`030?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo
02X0oooo0`00000B0?oood00ZKgX1@2W_NT50:Jmj@80Wkc]0`2V_NX409nmkPD0Xkk/102M`O450:C0
k@@0Xl?`1@2X_nX50:W1j`T0ZKkX@@2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000
003oool0203oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool0
00<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3o
ool00`2oM000M;oo0?ooo`040?ooo`800000:@3oool3000001H0ooooA@2Y_NP40:Jmj@H0Y[gZ102W
_NT50:>nk0@0Y[kZ1@2T`>d40:Rnj@D0Z;oZ2@2Y_^Q60:Vmj0030000002Y_NP0ZKgX01`0ZKgX0`00
00050?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103oool00`000000oooo
0?ooo`0U0?ooo`<000006P3ooom50:Vmj0@0Z;gX0`2V_NX30:Rmj0@0YkgY1@2X_NT40:JnjPT0Z;kY
1@2Y_NP40:Vnj4/0ZKgX00<000000:Vmj02Y_NP0602Y_NP3000000P0oooo00<000000?ooo`3oool0
5@3oool000<0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02L
gol00P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R
0?ooo`<000007P3ooom50:Vmj0X0Z;gX0P2W_NT20:Vmj0D0Z;gY102Y_NP50:RnjEP0ZKgX00<00000
0:Vmj02Y_NP04`2Y_NP4000000`0oooo00<000000?ooo`3oool0503oool000<0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00H0gia8001d_`3oool0oooo0?oo_`1d000300000003
07Boo`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool300000280ooooB@2Y_NP50:Rmj0D0
ZKgX0P2X_NUS0:Vmj0030000002Y_NP0ZKgX00l0ZKgX00@0oooo0000000000000000403oool00`00
0000oooo0?ooo`0D0?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01P3oool0
1`3ookl0M01809cOo`3oool0oooO09a8B02Lgol02@3oool2000001h0oooo0P00000V0?ooo`030000
002Y_NP0ZKgX0;D0ZKgX00<000000:Vmj02Y_NP02P2Y_NP20?ooo`<000004`3oool00`000000oooo
0?ooo`0D0?ooo`000`3oool01P3ooml0W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd0018W03O
ool0oooo0;md001d_ol80?ooo`800000703oool3000002X0oooo]`2Y_NP00`000000ZKgX0:Vmj007
0:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0
gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003000000030000M02oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo]P2Y_NP00`000000ZKgX0:Vmj005
0:Vmj08000006P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?oo
o`<00000<P3ooonf0:Vmj0040000002Y_NP0ZKgX0:Vmj08000007@3oool00`000000oooo0?ooo`0D
0?ooo`007`3oool2000001<0oooo0`00000f0?oookD0ZKgX0`00000P0?ooo`030000003oool0oooo
01@0oooo000O0?ooo`030000003oool0oooo00l0oooo0`00000j0?oook00ZKgX0`0000030?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0
303oool3000003h0oooo[02Y_NP3000000H0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`<00000@P3ooonW0:Vmj0@000002P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo000N0?ooo`8000002@3oool2
000004H0ooooXP2Y_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0ooooWP2Y_NP0
103oool0000000000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3o
ool001h0oooo00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP0UP2Y_NP0
0`3oool0000000000002000001H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C
0?ooo`007P3oool00`000000oooo0000000200000540oooo00<000000:Vmj02Y_NP0T`2Y_NP30000
01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000005D0
oooo00<000000:Vmj02Y_NP0T02Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo
00<000000:Vmj02Y_NP0S02Y_NP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool02P3oool2000005H0ooooR@2Y
_NP2000002L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`004`3oool0
0`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05@0ooooQ@2Y_NP2000002/0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?oo
o`030000003oool0oooo05@0ooooP02Y_NP200000300oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0
ooooN`2Y_NP3000003<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`00
4`3oool00`3ogi`0B01d0;ooo`0?0?ooo`030000003oool0oooo05@0ooooM`2Y_NP3000003L0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`004@3oool01@2oM000001809bo
W01807@0_ooo0100oooo0P00001E0?ooog80ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo
0?ooo`1C0?ooofh0ZKgX0`0000100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4P3oool001<0oooo00<0omnL04P0M02oool04`3oool00`000000oooo0?ooo`1C0?ooofT0ZKgX1000
00130?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool002X0oooo00<00000
0?ooo`3oool0D`3ooomU0:Vmj0<00000B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0140oooo000[0?ooo`800000E03ooomP0:Vmj0040?ooo`0000000000000004`0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`1B0?oo
oe`0ZKgX1000001?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002h0
oooo00<000000?ooo`3oool0DP3ooomH0:Vmj0<00000E03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo0580ooooD`2Y_NP0103oool00000
00000000001H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00300oooo
00<000000?ooo`3oool0DP3ooom?0:Vmj0@00000G03oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo000a0?ooo`800000D`3ooom:0:Vmj0040?ooo`000000000000000600oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?oo
o`1A0?ooodH0ZKgX1000001T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool003@0oooo00<000000?ooo`3oool0D@3ooom20:Vmj0<00000J@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0100oooo000e0?ooo`030000003oool0oooo0540oooo?@2Y_NP0103o
ool0000000000000001/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
03H0oooo0P00001B0?ooocT0ZKgX1000001`0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool003P0oooo00<000000?ooo`3oool0D03ooole0:Vmj0<00000M@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000i0?ooo`030000003oool0oooo0540oooo
;`2Y_NP0103oool0000000000000001i0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0403oool003X0oooo00<000000?ooo`3oool0D@3oool[0:Vmj0@00000O03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0100oooo000k0?ooo`030000003oool0oooo0540oooo9`2Y
_NP300000840oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`00?03oool2
00000580oooo8P2Y_NP0103oool000000000000000250?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo
0500oooo6P2Y_NP3000008d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?oo
o`00@03oool00`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03`3oool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3o
ool=0:Vmj0<00000V@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo0014
0?ooo`030000003oool0oooo0500oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`80
0000YP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00190?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00h0oooo001;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool004l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool00540oooo0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo0:`0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo0000
00l0oooo001F0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0000000?0?ooo`00E`3oool2000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo
0000000>0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00
000>0?ooo`00FP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>
0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?oo
o`00G03oool2000003X0oooo00<000000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0WP3oool300000200oooo001R0?ooo`800000=03oool00`000000
oooo0?ooo`2J0?ooo`@000008`3oool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2F0?ooo`@000009`3oool006D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`2B0?ooo`@00000:`3oool006H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>
0?ooo`@00000;`3oool006L0oooo0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?oo
o`00J@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00
JP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo100000120?ooo`00K@3oool20000
02T0oooo00<000000?ooo`3oool0M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0M@3oool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0L@3oool4000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0K@3oool400000540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y
0?ooo`@00000E@3oool007@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?oo
o`@00000F@3oool007D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<0
0000G@3oool007H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000
H03oool007L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03o
ool007P0oooo0P00000M0?ooo`030000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<0
00000?ooo`3oool0A`3oool4000007L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0@`3oool4000007/0oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0?`3oool4000007l0oooo00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0>`3oool4000008<0oooo00220?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000
Q`3oool008@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3o
ool008D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool0
08H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo
0P00000=0?ooo`030000003oool0oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01h0oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01X0oooo1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3o
ool05P3oool400000:T0oooo002?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4P3oool400000:d0oooo002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3o
ool300000;40oooo002A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4
00000;@0oooo002B0?ooo`050000003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?oo
o`80000000<0oooo0000003oool0103oool400000;`0oooo002E0?ooo`80000000<0oooo00000000
00000P0000300?ooo`00UP3oool200000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oo
oed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54049 .59388 .53425 Mtetra
.59388 .53425 .59961 .54049 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .49911 .7318 .49256 Mtetra
.7318 .49256 .73714 .49911 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48098 Mtetra
.63368 .48098 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48098 .62789 .47429 Mtetra
.62789 .47429 .63368 .48098 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45592 Mtetra
.68693 .45592 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45592 .68126 .44903 Mtetra
.68126 .44903 .68693 .45592 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45019 Mtetra
.62204 .45019 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67555 .4421 .66979 .43511 Mtetra
.66979 .43511 .67555 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46558 Mtetra
.54578 .46558 .55192 .47233 .56349 .46868 .55738 .4619 Mtetra
.55738 .4619 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.664 .741 .908 r
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45077 Mtetra
.59246 .45077 .59847 .45763 .61023 .45391 .60426 .44703 Mtetra
.60426 .44703 .61023 .45391 .62204 .45019 .6161 .44327 Mtetra
.6161 .44327 .62204 .45019 .6339 .44644 .62799 .43949 Mtetra
.62799 .43949 .6339 .44644 .64581 .44268 .63994 .4357 Mtetra
.664 .741 .907 r
.63994 .4357 .64581 .44268 .65777 .4389 .65193 .43189 Mtetra
.65193 .43189 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42037 Mtetra
.68823 .42037 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46558 .53959 .45877 Mtetra
.663 .741 .908 r
.53959 .45877 .54578 .46558 .55738 .4619 .55122 .45508 Mtetra
.55122 .45508 .55738 .4619 .56902 .4582 .5629 .45138 Mtetra
.663 .742 .909 r
.5629 .45138 .56902 .4582 .58072 .45449 .57463 .44766 Mtetra
.57463 .44766 .58072 .45449 .59246 .45077 .58641 .44393 Mtetra
.663 .743 .909 r
.58641 .44393 .59246 .45077 .60426 .44703 .59823 .44017 Mtetra
.664 .744 .91 r
.59823 .44017 .60426 .44703 .6161 .44327 .61011 .43639 Mtetra
.664 .744 .909 r
.61011 .43639 .6161 .44327 .62799 .43949 .62204 .43256 Mtetra
.665 .744 .909 r
.62204 .43256 .62799 .43949 .63994 .4357 .63402 .42872 Mtetra
.665 .743 .908 r
.63402 .42872 .63994 .4357 .65193 .43189 .64605 .42486 Mtetra
.665 .742 .908 r
.64605 .42486 .65193 .43189 .66398 .42806 .65813 .42098 Mtetra
.664 .741 .908 r
.65813 .42098 .66398 .42806 .67608 .42422 .67026 .4171 Mtetra
.664 .741 .907 r
.67026 .4171 .67608 .42422 .68823 .42037 .68245 .4132 Mtetra
.68245 .4132 .68823 .42037 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.663 .741 .908 r
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45566 Mtetra
.52175 .45566 .52801 .46246 .53959 .45877 .53336 .45198 Mtetra
.661 .742 .91 r
.53336 .45198 .53959 .45877 .55122 .45508 .54502 .44832 Mtetra
.66 .743 .912 r
.54502 .44832 .55122 .45508 .5629 .45138 .55673 .44468 Mtetra
.659 .746 .915 r
.55673 .44468 .5629 .45138 .57463 .44766 .56849 .44106 Mtetra
.659 .75 .917 r
.56849 .44106 .57463 .44766 .58641 .44393 .58031 .43741 Mtetra
.661 .754 .919 r
.58031 .43741 .58641 .44393 .59823 .44017 .59217 .43369 Mtetra
.663 .757 .92 r
.59217 .43369 .59823 .44017 .61011 .43639 .60409 .42988 Mtetra
.666 .758 .919 r
.60409 .42988 .61011 .43639 .62204 .43256 .61605 .42596 Mtetra
.668 .756 .917 r
.61605 .42596 .62204 .43256 .63402 .42872 .62806 .42197 Mtetra
.668 .753 .914 r
.62806 .42197 .63402 .42872 .64605 .42486 .64012 .41796 Mtetra
.668 .749 .911 r
.64012 .41796 .64605 .42486 .65813 .42098 .65224 .41395 Mtetra
.666 .746 .909 r
.65224 .41395 .65813 .42098 .67026 .4171 .6644 .40997 Mtetra
.665 .743 .908 r
.6644 .40997 .67026 .4171 .68245 .4132 .67662 .40601 Mtetra
.664 .742 .908 r
.67662 .40601 .68245 .4132 .69469 .4093 .6889 .40205 Mtetra
.664 .741 .907 r
.6889 .40205 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .45991 Mtetra
.48079 .45991 .4872 .4667 .49867 .46303 .49229 .45621 Mtetra
.663 .741 .908 r
.49229 .45621 .49867 .46303 .51018 .45934 .50384 .45253 Mtetra
.661 .741 .91 r
.50384 .45253 .51018 .45934 .52175 .45566 .51543 .44889 Mtetra
.657 .742 .913 r
.51543 .44889 .52175 .45566 .53336 .45198 .52707 .44536 Mtetra
.651 .746 .919 r
.52707 .44536 .53336 .45198 .54502 .44832 .53877 .44197 Mtetra
.644 .753 .928 r
.53877 .44197 .54502 .44832 .55673 .44468 .55052 .43871 Mtetra
.64 .765 .939 r
.55052 .43871 .55673 .44468 .56849 .44106 .56232 .43551 Mtetra
.64 .781 .949 r
.56232 .43551 .56849 .44106 .58031 .43741 .57418 .43221 Mtetra
.646 .797 .955 r
.57418 .43221 .58031 .43741 .59217 .43369 .58609 .42868 Mtetra
.656 .808 .956 r
.58609 .42868 .59217 .43369 .60409 .42988 .59805 .42484 Mtetra
.669 .811 .952 r
.59805 .42484 .60409 .42988 .61605 .42596 .61005 .42067 Mtetra
.678 .806 .944 r
.61005 .42067 .61605 .42596 .62806 .42197 .62209 .41627 Mtetra
.682 .794 .934 r
.62209 .41627 .62806 .42197 .64012 .41796 .63417 .41178 Mtetra
.68 .778 .924 r
.63417 .41178 .64012 .41796 .65224 .41395 .64631 .40733 Mtetra
.676 .763 .917 r
.64631 .40733 .65224 .41395 .6644 .40997 .65851 .40302 Mtetra
.671 .752 .912 r
.65851 .40302 .6644 .40997 .67662 .40601 .67076 .39885 Mtetra
.667 .746 .909 r
.67076 .39885 .67662 .40601 .6889 .40205 .68306 .39478 Mtetra
.665 .742 .908 r
.68306 .39478 .6889 .40205 .70123 .39809 .69543 .39076 Mtetra
.664 .741 .907 r
.69543 .39076 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.663 .741 .908 r
.46285 .45677 .46934 .46359 .48079 .45991 .47433 .45307 Mtetra
.662 .741 .908 r
.47433 .45307 .48079 .45991 .49229 .45621 .48586 .44939 Mtetra
.658 .741 .911 r
.48586 .44939 .49229 .45621 .50384 .45253 .49744 .44581 Mtetra
.65 .742 .917 r
.49744 .44581 .50384 .45253 .51543 .44889 .50906 .44246 Mtetra
.634 .747 .93 r
.50906 .44246 .51543 .44889 .52707 .44536 .52074 .43948 Mtetra
.612 .76 .95 r
.52074 .43948 .52707 .44536 .53877 .44197 .53247 .43693 Mtetra
.586 .782 .973 r
.53247 .43693 .53877 .44197 .55052 .43871 .54427 .43464 Mtetra
.564 .813 .992 r
.54427 .43464 .55052 .43871 .56232 .43551 .55612 .43232 Mtetra
.553 .844 .998 r
.55612 .43232 .56232 .43551 .57418 .43221 .56804 .42966 Mtetra
.563 .871 .995 r
.56804 .42966 .57418 .43221 .58609 .42868 .58 .42644 Mtetra
.591 .892 .989 r
.58 .42644 .58609 .42868 .59805 .42484 .59201 .42257 Mtetra
.631 .905 .984 r
.59201 .42257 .59805 .42484 .61005 .42067 .60405 .41804 Mtetra
.671 .904 .977 r
.60405 .41804 .61005 .42067 .62209 .41627 .61613 .41295 Mtetra
.699 .887 .967 r
.61613 .41295 .62209 .41627 .63417 .41178 .62824 .40751 Mtetra
.709 .855 .952 r
.62824 .40751 .63417 .41178 .64631 .40733 .64039 .40203 Mtetra
.703 .817 .936 r
.64039 .40203 .64631 .40733 .65851 .40302 .65259 .39682 Mtetra
.689 .784 .923 r
.65259 .39682 .65851 .40302 .67076 .39885 .66486 .39202 Mtetra
.677 .761 .914 r
.66486 .39202 .67076 .39885 .68306 .39478 .67719 .3876 Mtetra
.669 .748 .91 r
.67719 .3876 .68306 .39478 .69543 .39076 .68959 .38342 Mtetra
.666 .743 .908 r
.68959 .38342 .69543 .39076 .70785 .38675 .70204 .37933 Mtetra
.664 .741 .907 r
.70204 .37933 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .44991 Mtetra
.662 .741 .908 r
.45631 .44991 .46285 .45677 .47433 .45307 .46782 .44622 Mtetra
.657 .74 .911 r
.46782 .44622 .47433 .45307 .48586 .44939 .47938 .44266 Mtetra
.643 .741 .92 r
.47938 .44266 .48586 .44939 .49744 .44581 .49098 .43947 Mtetra
.615 .745 .938 r
.49098 .43947 .49744 .44581 .50906 .44246 .50263 .43695 Mtetra
.565 .757 .968 r
.50263 .43695 .50906 .44246 .52074 .43948 .51434 .43522 Mtetra
.494 .778 .995 r
.51434 .43522 .52074 .43948 .53247 .43693 .52612 .43405 Mtetra
.425 .8 .993 r
.52612 .43405 .53247 .43693 .54427 .43464 .53796 .43281 Mtetra
.409 .825 .971 r
.53796 .43281 .54427 .43464 .55612 .43232 .54987 .43091 Mtetra
.455 .859 .966 r
.54987 .43091 .55612 .43232 .56804 .42966 .56184 .42815 Mtetra
.518 .886 .975 r
.56184 .42815 .56804 .42966 .58 .42644 .57385 .42471 Mtetra
.564 .899 .981 r
.57385 .42471 .58 .42644 .59201 .42257 .58591 .42082 Mtetra
.595 .911 .98 r
.58591 .42082 .59201 .42257 .60405 .41804 .59802 .41646 Mtetra
.63 .927 .972 r
.59802 .41646 .60405 .41804 .61613 .41295 .61016 .41141 Mtetra
.676 .942 .963 r
.61016 .41141 .61613 .41295 .62824 .40751 .62231 .4055 Mtetra
.721 .938 .957 r
.62231 .4055 .62824 .40751 .64039 .40203 .63449 .39891 Mtetra
.74 .905 .951 r
.63449 .39891 .64039 .40203 .65259 .39682 .64669 .39225 Mtetra
.729 .852 .939 r
.64669 .39225 .65259 .39682 .66486 .39202 .65895 .38613 Mtetra
.704 .801 .925 r
.65895 .38613 .66486 .39202 .67719 .3876 .67129 .38081 Mtetra
.682 .767 .915 r
.67129 .38081 .67719 .3876 .68959 .38342 .6837 .37617 Mtetra
.67 .749 .91 r
.6837 .37617 .68959 .38342 .70204 .37933 .69619 .37189 Mtetra
.666 .743 .908 r
.69619 .37189 .70204 .37933 .71455 .37526 .70873 .36775 Mtetra
.664 .741 .907 r
.70873 .36775 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44674 Mtetra
.663 .741 .908 r
.43822 .44674 .44485 .45363 .45631 .44991 .44972 .44302 Mtetra
.658 .74 .911 r
.44972 .44302 .45631 .44991 .46782 .44622 .46125 .43943 Mtetra
.642 .739 .919 r
.46125 .43943 .46782 .44622 .47938 .44266 .47284 .43626 Mtetra
.603 .74 .941 r
.47284 .43626 .47938 .44266 .49098 .43947 .48446 .434 Mtetra
.525 .744 .975 r
.48446 .434 .49098 .43947 .50263 .43695 .49613 .43294 Mtetra
.406 .748 .994 r
.49613 .43294 .50263 .43695 .51434 .43522 .50788 .43268 Mtetra
.342 .768 .973 r
.50788 .43268 .51434 .43522 .52612 .43405 .51969 .43202 Mtetra
.464 .847 .984 r
.51969 .43202 .52612 .43405 .53796 .43281 .53158 .42968 Mtetra
.646 .877 .984 r
.53158 .42968 .53796 .43281 .54987 .43091 .54352 .4254 Mtetra
.709 .807 .926 r
.54352 .4254 .54987 .43091 .56184 .42815 .5555 .42006 Mtetra
.694 .727 .875 r
.5555 .42006 .56184 .42815 .57385 .42471 .56753 .41498 Mtetra
.659 .676 .856 r
.56753 .41498 .57385 .42471 .58591 .42082 .57962 .41105 Mtetra
.627 .663 .865 r
.57962 .41105 .58591 .42082 .59802 .41646 .59178 .40827 Mtetra
.617 .699 .903 r
.59178 .40827 .59802 .41646 .61016 .41141 .60401 .40575 Mtetra
.643 .789 .952 r
.60401 .40575 .61016 .41141 .62231 .4055 .61628 .40218 Mtetra
.698 .89 .968 r
.61628 .40218 .62231 .4055 .63449 .39891 .62855 .39665 Mtetra
.748 .936 .948 r
.62855 .39665 .63449 .39891 .64669 .39225 .64079 .38941 Mtetra
.769 .921 .938 r
.64079 .38941 .64669 .39225 .65895 .38613 .65305 .38175 Mtetra
.75 .865 .933 r
.65305 .38175 .65895 .38613 .67129 .38081 .66537 .37489 Mtetra
.712 .805 .923 r
.66537 .37489 .67129 .38081 .6837 .37617 .67779 .36924 Mtetra
.684 .766 .914 r
.67779 .36924 .6837 .37617 .69619 .37189 .69029 .3645 Mtetra
.67 .748 .909 r
.69029 .3645 .69619 .37189 .70873 .36775 .70287 .36019 Mtetra
.665 .742 .908 r
.70287 .36019 .70873 .36775 .72134 .36363 .71551 .35602 Mtetra
.664 .741 .907 r
.71551 .35602 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .44731 Mtetra
.40865 .44731 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.663 .741 .908 r
.42007 .44355 .42678 .45047 .43822 .44674 .43155 .4398 Mtetra
.66 .74 .909 r
.43155 .4398 .43822 .44674 .44972 .44302 .44307 .43613 Mtetra
.647 .739 .916 r
.44307 .43613 .44972 .44302 .46125 .43943 .45463 .43283 Mtetra
.607 .736 .936 r
.45463 .43283 .46125 .43943 .47284 .43626 .46623 .43049 Mtetra
.515 .73 .971 r
.46623 .43049 .47284 .43626 .48446 .434 .47786 .42969 Mtetra
.364 .717 .987 r
.47786 .42969 .48446 .434 .49613 .43294 .48956 .43008 Mtetra
.335 .755 .976 r
.48956 .43008 .49613 .43294 .50788 .43268 .50134 .42971 Mtetra
.609 .871 .991 r
.50134 .42971 .50788 .43268 .51969 .43202 .51321 .42604 Mtetra
.772 .801 .876 r
.51321 .42604 .51969 .43202 .53158 .42968 .52514 .41812 Mtetra
.76 .681 .774 r
.52514 .41812 .53158 .42968 .54352 .4254 .53707 .40761 Mtetra
.669 .573 .738 r
.53707 .40761 .54352 .4254 .5555 .42006 .54904 .40113 Mtetra
.629 .542 .737 r
.54904 .40113 .5555 .42006 .56753 .41498 .56107 .39718 Mtetra
.632 .553 .747 r
.56107 .39718 .56753 .41498 .57962 .41105 .57315 .3932 Mtetra
.57315 .3932 .57962 .41105 .59178 .40827 .58529 .38921 Mtetra
.589 .519 .744 r
.58529 .38921 .59178 .40827 .60401 .40575 .59754 .38775 Mtetra
.506 .48 .762 r
.59754 .38775 .60401 .40575 .61628 .40218 .60997 .39036 Mtetra
.547 .586 .846 r
.60997 .39036 .61628 .40218 .62855 .39665 .62242 .39039 Mtetra
.668 .78 .933 r
.62242 .39039 .62855 .39665 .64079 .38941 .63482 .38613 Mtetra
.768 .907 .936 r
.63482 .38613 .64079 .38941 .65305 .38175 .64714 .37853 Mtetra
.79 .912 .923 r
.64714 .37853 .65305 .38175 .66537 .37489 .65946 .37014 Mtetra
.758 .857 .924 r
.65946 .37014 .66537 .37489 .67779 .36924 .67185 .36295 Mtetra
.71 .795 .918 r
.67185 .36295 .67779 .36924 .69029 .3645 .68436 .35731 Mtetra
.68 .759 .911 r
.68436 .35731 .69029 .3645 .70287 .36019 .69696 .35264 Mtetra
.668 .745 .908 r
.69696 .35264 .70287 .36019 .71551 .35602 .70964 .34835 Mtetra
.665 .742 .907 r
.70964 .34835 .71551 .35602 .72822 .35185 .72238 .34413 Mtetra
.664 .741 .907 r
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29235 Mtetra
.27897 .48098 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .44731 .40185 .44036 Mtetra
.40185 .44036 .40865 .44731 .42007 .44355 .41331 .43658 Mtetra
.662 .74 .908 r
.41331 .43658 .42007 .44355 .43155 .4398 .42482 .43283 Mtetra
.654 .739 .912 r
.42482 .43283 .43155 .4398 .44307 .43613 .43636 .42931 Mtetra
.624 .735 .926 r
.43636 .42931 .44307 .43613 .45463 .43283 .44794 .42657 Mtetra
.54 .724 .959 r
.44794 .42657 .45463 .43283 .46623 .43049 .45955 .42549 Mtetra
.375 .697 .983 r
.45955 .42549 .46623 .43049 .47786 .42969 .47119 .42616 Mtetra
.318 .723 .979 r
.47119 .42616 .47786 .42969 .48956 .43008 .48292 .42644 Mtetra
.655 .859 .978 r
.48292 .42644 .48956 .43008 .50134 .42971 .49478 .4222 Mtetra
.809 .764 .811 r
.49478 .4222 .50134 .42971 .51321 .42604 .50673 .41085 Mtetra
.716 .62 .749 r
.50673 .41085 .51321 .42604 .52514 .41812 .51866 .40174 Mtetra
.636 .568 .761 r
.51866 .40174 .52514 .41812 .53707 .40761 .53062 .39779 Mtetra
.659 .675 .855 r
.53062 .39779 .53707 .40761 .54904 .40113 .54264 .39382 Mtetra
.664 .741 .907 r
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59754 .38775 .59122 .37776 Mtetra
.659 .675 .855 r
.59122 .37776 .59754 .38775 .60997 .39036 .6035 .3737 Mtetra
.534 .511 .777 r
.6035 .3737 .60997 .39036 .62242 .39039 .61598 .37483 Mtetra
.468 .487 .794 r
.61598 .37483 .62242 .39039 .63482 .38613 .62863 .37826 Mtetra
.652 .728 .905 r
.62863 .37826 .63482 .38613 .64714 .37853 .64114 .37451 Mtetra
.788 .885 .916 r
.64114 .37451 .64714 .37853 .65946 .37014 .65352 .36618 Mtetra
.798 .889 .91 r
.65352 .36618 .65946 .37014 .67185 .36295 .6659 .35743 Mtetra
.748 .832 .916 r
.6659 .35743 .67185 .36295 .68436 .35731 .6784 .35045 Mtetra
.698 .777 .913 r
.6784 .35045 .68436 .35731 .69696 .35264 .69101 .34515 Mtetra
.673 .751 .909 r
.69101 .34515 .69696 .35264 .70964 .34835 .70372 .34064 Mtetra
.666 .743 .908 r
.70372 .34064 .70964 .34835 .72238 .34413 .7165 .33635 Mtetra
.664 .741 .907 r
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29235 .87448 .28412 Mtetra
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46699 Mtetra
.29379 .46699 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44036 .39501 .43335 Mtetra
.663 .741 .908 r
.39501 .43335 .40185 .44036 .41331 .43658 .4065 .42955 Mtetra
.66 .74 .909 r
.4065 .42955 .41331 .43658 .42482 .43283 .41803 .42585 Mtetra
.644 .737 .917 r
.41803 .42585 .42482 .43283 .43636 .42931 .4296 .42259 Mtetra
.586 .727 .941 r
.4296 .42259 .43636 .42931 .44794 .42657 .44119 .42069 Mtetra
.44 .696 .974 r
.44119 .42069 .44794 .42657 .45955 .42549 .45279 .421 Mtetra
.292 .674 .973 r
.45279 .421 .45955 .42549 .47119 .42616 .46446 .42219 Mtetra
.58 .826 .991 r
.46446 .42219 .47119 .42616 .48292 .42644 .47627 .41944 Mtetra
.821 .777 .811 r
.47627 .41944 .48292 .42644 .49478 .4222 .48825 .40752 Mtetra
.72 .627 .754 r
.48825 .40752 .49478 .4222 .50673 .41085 .5002 .3984 Mtetra
.649 .624 .811 r
.5002 .3984 .50673 .41085 .51866 .40174 .51214 .39443 Mtetra
.664 .741 .907 r
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61598 .37483 .60959 .36205 Mtetra
.515 .555 .835 r
.60959 .36205 .61598 .37483 .62863 .37826 .62217 .36315 Mtetra
.446 .481 .802 r
.62217 .36315 .62863 .37826 .64114 .37451 .63495 .36709 Mtetra
.698 .759 .9 r
.63495 .36709 .64114 .37451 .65352 .36618 .6475 .36176 Mtetra
.808 .876 .896 r
.6475 .36176 .65352 .36618 .6659 .35743 .65992 .35243 Mtetra
.786 .856 .903 r
.65992 .35243 .6659 .35743 .6784 .35045 .6724 .34398 Mtetra
.724 .798 .91 r
.6724 .34398 .6784 .35045 .69101 .34515 .68502 .33775 Mtetra
.682 .759 .909 r
.68502 .33775 .69101 .34515 .70372 .34064 .69775 .33291 Mtetra
.668 .745 .908 r
.69775 .33291 .70372 .34064 .7165 .33635 .71056 .32852 Mtetra
.664 .741 .907 r
.71056 .32852 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46699 .28663 .46019 Mtetra
.28663 .46019 .29379 .46699 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .4263 Mtetra
.663 .741 .908 r
.38811 .4263 .39501 .43335 .4065 .42955 .39963 .42249 Mtetra
.656 .739 .911 r
.39963 .42249 .4065 .42955 .41803 .42585 .41119 .41885 Mtetra
.628 .734 .923 r
.41119 .41885 .41803 .42585 .4296 .42259 .42278 .41597 Mtetra
.534 .712 .954 r
.42278 .41597 .4296 .42259 .44119 .42069 .43437 .41505 Mtetra
.343 .659 .972 r
.43437 .41505 .44119 .42069 .45279 .421 .44597 .4164 Mtetra
.396 .726 .99 r
.44597 .4164 .45279 .421 .46446 .42219 .45769 .41649 Mtetra
.781 .81 .875 r
.45769 .41649 .46446 .42219 .47627 .41944 .46964 .40815 Mtetra
.79 .695 .759 r
.46964 .40815 .47627 .41944 .48825 .40752 .48166 .39504 Mtetra
.649 .624 .811 r
.48166 .39504 .48825 .40752 .5002 .3984 .49359 .39106 Mtetra
.664 .741 .907 r
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62217 .36315 .61576 .35025 Mtetra
.37 .473 .834 r
.61576 .35025 .62217 .36315 .63495 .36709 .62858 .35532 Mtetra
.533 .586 .854 r
.62858 .35532 .63495 .36709 .6475 .36176 .64135 .35559 Mtetra
.774 .818 .887 r
.64135 .35559 .6475 .36176 .65992 .35243 .65388 .34731 Mtetra
.809 .856 .885 r
.65388 .34731 .65992 .35243 .6724 .34398 .66636 .33773 Mtetra
.751 .814 .902 r
.66636 .33773 .6724 .34398 .68502 .33775 .67898 .33045 Mtetra
.695 .767 .908 r
.67898 .33045 .68502 .33775 .69775 .33291 .69173 .32515 Mtetra
.671 .747 .908 r
.69173 .32515 .69775 .33291 .71056 .32852 .70458 .32062 Mtetra
.665 .742 .907 r
.70458 .32062 .71056 .32852 .72344 .32422 .7175 .31627 Mtetra
.664 .741 .907 r
.7175 .31627 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .4263 .38116 .41918 Mtetra
.662 .74 .908 r
.38116 .41918 .38811 .4263 .39963 .42249 .39271 .41537 Mtetra
.652 .738 .913 r
.39271 .41537 .39963 .42249 .41119 .41885 .40429 .41182 Mtetra
.61 .728 .929 r
.40429 .41182 .41119 .41885 .42278 .41597 .41589 .40937 Mtetra
.479 .691 .961 r
.41589 .40937 .42278 .41597 .43437 .41505 .42748 .40933 Mtetra
.306 .639 .966 r
.42748 .40933 .43437 .41505 .44597 .4164 .4391 .4111 Mtetra
.581 .78 .974 r
.4391 .4111 .44597 .4164 .45769 .41649 .45091 .4088 Mtetra
.839 .763 .778 r
.45091 .4088 .45769 .41649 .46964 .40815 .46301 .39421 Mtetra
.688 .622 .777 r
.46301 .39421 .46964 .40815 .48166 .39504 .47497 .38767 Mtetra
.664 .741 .907 r
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.572 .705 .932 r
.60945 .34251 .61576 .35025 .62858 .35532 .62209 .34087 Mtetra
.341 .431 .808 r
.62209 .34087 .62858 .35532 .64135 .35559 .63508 .3474 Mtetra
.708 .746 .882 r
.63508 .3474 .64135 .35559 .65388 .34731 .64774 .34148 Mtetra
.811 .836 .869 r
.64774 .34148 .65388 .34731 .66636 .33773 .66027 .33141 Mtetra
.772 .817 .888 r
.66027 .33141 .66636 .33773 .67898 .33045 .67289 .32315 Mtetra
.707 .773 .904 r
.67289 .32315 .67898 .33045 .69173 .32515 .68567 .31736 Mtetra
.675 .749 .907 r
.68567 .31736 .69173 .32515 .70458 .32062 .69855 .31267 Mtetra
.666 .742 .907 r
.69855 .31267 .70458 .32062 .7175 .31627 .71151 .30825 Mtetra
.664 .741 .907 r
.71151 .30825 .7175 .31627 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41918 .37415 .41201 Mtetra
.661 .74 .908 r
.37415 .41201 .38116 .41918 .39271 .41537 .38573 .40819 Mtetra
.648 .737 .914 r
.38573 .40819 .39271 .41537 .40429 .41182 .39734 .40472 Mtetra
.594 .722 .933 r
.39734 .40472 .40429 .41182 .41589 .40937 .40896 .40262 Mtetra
.439 .67 .96 r
.40896 .40262 .41589 .40937 .42748 .40933 .42055 .40323 Mtetra
.331 .639 .965 r
.42055 .40323 .42748 .40933 .4391 .4111 .43219 .40491 Mtetra
.693 .783 .92 r
.43219 .40491 .4391 .4111 .45091 .4088 .4441 .40002 Mtetra
.837 .743 .76 r
.4441 .40002 .45091 .4088 .46301 .39421 .45628 .38428 Mtetra
.658 .676 .855 r
.45628 .38428 .46301 .39421 .47497 .38767 .46822 .38025 Mtetra
.664 .741 .907 r
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62209 .34087 .61569 .33046 Mtetra
.151 .396 .844 r
.61569 .33046 .62209 .34087 .63508 .3474 .62873 .33808 Mtetra
.635 .692 .886 r
.62873 .33808 .63508 .3474 .64774 .34148 .64152 .33473 Mtetra
.802 .81 .857 r
.64152 .33473 .64774 .34148 .66027 .33141 .6541 .32468 Mtetra
.783 .809 .873 r
.6541 .32468 .66027 .33141 .67289 .32315 .66675 .31571 Mtetra
.717 .774 .897 r
.66675 .31571 .67289 .32315 .68567 .31736 .67955 .30949 Mtetra
.678 .75 .905 r
.67955 .30949 .68567 .31736 .69855 .31267 .69247 .30465 Mtetra
.666 .743 .907 r
.69247 .30465 .69855 .31267 .71151 .30825 .70546 .30017 Mtetra
.664 .741 .907 r
.70546 .30017 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .4087 Mtetra
.35552 .4087 .36262 .41589 .37415 .41201 .36709 .40478 Mtetra
.661 .74 .909 r
.36709 .40478 .37415 .41201 .38573 .40819 .37869 .40094 Mtetra
.646 .736 .915 r
.37869 .40094 .38573 .40819 .39734 .40472 .39033 .39751 Mtetra
.585 .717 .934 r
.39033 .39751 .39734 .40472 .40896 .40262 .40197 .39561 Mtetra
.423 .655 .956 r
.40197 .39561 .40896 .40262 .42055 .40323 .41357 .39652 Mtetra
.371 .641 .96 r
.41357 .39652 .42055 .40323 .43219 .40491 .42525 .39799 Mtetra
.734 .772 .884 r
.42525 .39799 .43219 .40491 .4441 .40002 .43723 .39144 Mtetra
.831 .748 .772 r
.43723 .39144 .4441 .40002 .45628 .38428 .44944 .37682 Mtetra
.664 .741 .907 r
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.084 .427 .871 r
.60931 .32256 .61569 .33046 .62873 .33808 .62233 .32898 Mtetra
.581 .676 .905 r
.62233 .32898 .62873 .33808 .64152 .33473 .63522 .32724 Mtetra
.793 .79 .85 r
.63522 .32724 .64152 .33473 .6541 .32468 .64786 .31734 Mtetra
.785 .794 .86 r
.64786 .31734 .6541 .32468 .66675 .31571 .66054 .30799 Mtetra
.722 .769 .89 r
.66054 .30799 .66675 .31571 .67955 .30949 .67337 .30149 Mtetra
.68 .749 .903 r
.67337 .30149 .67955 .30949 .69247 .30465 .68633 .29654 Mtetra
.667 .742 .907 r
.68633 .29654 .69247 .30465 .70546 .30017 .69937 .29202 Mtetra
.664 .741 .907 r
.69937 .29202 .70546 .30017 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .4087 .34837 .40144 Mtetra
.34837 .40144 .35552 .4087 .36709 .40478 .35996 .3975 Mtetra
.661 .74 .909 r
.35996 .3975 .36709 .40478 .37869 .40094 .3716 .39362 Mtetra
.646 .736 .914 r
.3716 .39362 .37869 .40094 .39033 .39751 .38327 .39016 Mtetra
.586 .715 .932 r
.38327 .39016 .39033 .39751 .40197 .39561 .39493 .38823 Mtetra
.432 .649 .95 r
.39493 .38823 .40197 .39561 .41357 .39652 .40656 .38912 Mtetra
.395 .631 .949 r
.40656 .38912 .41357 .39652 .42525 .39799 .41825 .39057 Mtetra
.731 .76 .875 r
.41825 .39057 .42525 .39799 .43723 .39144 .43028 .38398 Mtetra
.843 .771 .782 r
.43028 .38398 .43723 .39144 .44944 .37682 .44254 .36931 Mtetra
.664 .741 .907 r
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.084 .427 .871 r
.60289 .3146 .60931 .32256 .62233 .32898 .61592 .321 Mtetra
.572 .705 .932 r
.61592 .321 .62233 .32898 .63522 .32724 .62884 .31922 Mtetra
.788 .778 .844 r
.62884 .31922 .63522 .32724 .64786 .31734 .64153 .30928 Mtetra
.779 .776 .85 r
.64153 .30928 .64786 .31734 .66054 .30799 .65426 .29988 Mtetra
.72 .76 .884 r
.65426 .29988 .66054 .30799 .67337 .30149 .66714 .29334 Mtetra
.68 .747 .902 r
.66714 .29334 .67337 .30149 .68633 .29654 .68014 .28836 Mtetra
.667 .742 .906 r
.68014 .28836 .68633 .29654 .69937 .29202 .69322 .28379 Mtetra
.664 .741 .907 r
.69322 .28379 .69937 .29202 .71247 .28756 .70636 .2793 Mtetra
.70636 .2793 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23798 Mtetra
.82746 .23798 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40205 Mtetra
.31807 .40205 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .3975 .35278 .39015 Mtetra
.661 .74 .908 r
.35278 .39015 .35996 .3975 .3716 .39362 .36445 .38623 Mtetra
.648 .736 .913 r
.36445 .38623 .3716 .39362 .38327 .39016 .37616 .38267 Mtetra
.596 .716 .928 r
.37616 .38267 .38327 .39016 .39493 .38823 .38786 .38048 Mtetra
.461 .653 .943 r
.38786 .38048 .39493 .38823 .40656 .38912 .39952 .38101 Mtetra
.403 .614 .936 r
.39952 .38101 .40656 .38912 .41825 .39057 .41122 .38263 Mtetra
.689 .737 .888 r
.41122 .38263 .41825 .39057 .43028 .38398 .42323 .37763 Mtetra
.864 .793 .779 r
.42323 .37763 .43028 .38398 .44254 .36931 .43559 .36173 Mtetra
.664 .741 .907 r
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
0 .365 .834 r
.5964 .30657 .60289 .3146 .61592 .321 .60949 .31414 Mtetra
.628 .765 .945 r
.60949 .31414 .61592 .321 .62884 .31922 .6224 .31068 Mtetra
.787 .767 .835 r
.6224 .31068 .62884 .31922 .64153 .30928 .63513 .30049 Mtetra
.767 .758 .844 r
.63513 .30049 .64153 .30928 .65426 .29988 .64792 .29139 Mtetra
.713 .75 .881 r
.64792 .29139 .65426 .29988 .66714 .29334 .66085 .28504 Mtetra
.678 .744 .901 r
.66085 .28504 .66714 .29334 .68014 .28836 .6739 .28008 Mtetra
.666 .741 .906 r
.6739 .28008 .68014 .28836 .69322 .28379 .68702 .27549 Mtetra
.664 .741 .907 r
.68702 .27549 .69322 .28379 .70636 .2793 .70021 .27096 Mtetra
.70021 .27096 .70636 .2793 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40205 .31074 .39473 Mtetra
.31074 .39473 .31807 .40205 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35278 .39015 .34555 .38274 Mtetra
.662 .74 .908 r
.34555 .38274 .35278 .39015 .36445 .38623 .35725 .37876 Mtetra
.652 .737 .911 r
.35725 .37876 .36445 .38623 .37616 .38267 .36899 .37506 Mtetra
.612 .72 .922 r
.36899 .37506 .37616 .38267 .38786 .38048 .38073 .37246 Mtetra
.503 .665 .935 r
.38073 .37246 .38786 .38048 .39952 .38101 .39244 .3723 Mtetra
.413 .603 .925 r
.39244 .3723 .39952 .38101 .41122 .38263 .40416 .37396 Mtetra
.608 .692 .903 r
.40416 .37396 .41122 .38263 .42323 .37763 .41611 .3715 Mtetra
.859 .801 .793 r
.41611 .3715 .42323 .37763 .43559 .36173 .4285 .35666 Mtetra
.745 .836 .921 r
.4285 .35666 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.664 .741 .907 r
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.572 .705 .932 r
.57712 .30286 .58369 .31093 .5964 .30657 .58992 .30106 Mtetra
0 .367 .802 r
.58992 .30106 .5964 .30657 .60949 .31414 .60301 .3075 Mtetra
.715 .801 .918 r
.60301 .3075 .60949 .31414 .6224 .31068 .61588 .30138 Mtetra
.782 .751 .825 r
.61588 .30138 .6224 .31068 .63513 .30049 .62866 .29108 Mtetra
.751 .741 .843 r
.62866 .29108 .63513 .30049 .64792 .29139 .64152 .2826 Mtetra
.703 .741 .881 r
.64152 .2826 .64792 .29139 .66085 .28504 .65451 .27661 Mtetra
.674 .741 .901 r
.65451 .27661 .66085 .28504 .6739 .28008 .6676 .27173 Mtetra
.666 .741 .906 r
.6676 .27173 .6739 .28008 .68702 .27549 .68077 .26712 Mtetra
.664 .741 .907 r
.68077 .26712 .68702 .27549 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38274 .33825 .37527 Mtetra
.663 .74 .908 r
.33825 .37527 .34555 .38274 .35725 .37876 .34999 .37124 Mtetra
.656 .738 .91 r
.34999 .37124 .35725 .37876 .36899 .37506 .36176 .36738 Mtetra
.629 .726 .917 r
.36176 .36738 .36899 .37506 .38073 .37246 .37356 .36429 Mtetra
.55 .683 .927 r
.37356 .36429 .38073 .37246 .39244 .3723 .38532 .36317 Mtetra
.447 .61 .917 r
.38532 .36317 .39244 .3723 .40416 .37396 .39707 .36436 Mtetra
.517 .632 .903 r
.39707 .36436 .40416 .37396 .41611 .3715 .40896 .36427 Mtetra
.772 .777 .857 r
.40896 .36427 .41611 .3715 .4285 .35666 .42121 .35564 Mtetra
.887 .938 .843 r
.42121 .35564 .4285 .35666 .44066 .34993 .43362 .34219 Mtetra
.664 .741 .907 r
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.182 .493 .904 r
.57049 .29473 .57712 .30286 .58992 .30106 .58345 .29966 Mtetra
.124 .663 .848 r
.58345 .29966 .58992 .30106 .60301 .3075 .59644 .29973 Mtetra
.766 .783 .868 r
.59644 .29973 .60301 .3075 .61588 .30138 .60929 .29115 Mtetra
.767 .729 .818 r
.60929 .29115 .61588 .30138 .62866 .29108 .62213 .28124 Mtetra
.73 .727 .847 r
.62213 .28124 .62866 .29108 .64152 .2826 .63506 .27367 Mtetra
.691 .735 .884 r
.63506 .27367 .64152 .2826 .65451 .27661 .64811 .2681 Mtetra
.671 .739 .902 r
.64811 .2681 .65451 .27661 .6676 .27173 .66125 .2633 Mtetra
.665 .74 .906 r
.66125 .2633 .6676 .27173 .68077 .26712 .67446 .25868 Mtetra
.664 .741 .907 r
.67446 .25868 .68077 .26712 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37527 .3309 .36774 Mtetra
.663 .741 .908 r
.3309 .36774 .33825 .37527 .34999 .37124 .34266 .36365 Mtetra
.66 .739 .909 r
.34266 .36365 .34999 .37124 .36176 .36738 .35448 .35966 Mtetra
.644 .731 .912 r
.35448 .35966 .36176 .36738 .37356 .36429 .36632 .35612 Mtetra
.593 .702 .919 r
.36632 .35612 .37356 .36429 .38532 .36317 .37816 .35396 Mtetra
.503 .636 .913 r
.37816 .35396 .38532 .36317 .39707 .36436 .38997 .35404 Mtetra
.475 .595 .893 r
.38997 .35404 .39707 .36436 .40896 .36427 .40183 .35501 Mtetra
.625 .689 .889 r
.40183 .35501 .40896 .36427 .42121 .35564 .41392 .35199 Mtetra
.859 .875 .849 r
.41392 .35199 .42121 .35564 .43362 .34219 .42637 .33964 Mtetra
.815 .92 .907 r
.42637 .33964 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.664 .741 .907 r
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.441 .643 .943 r
.55103 .29098 .55776 .29914 .57049 .29473 .56387 .29183 Mtetra
0 .45 .772 r
.56387 .29183 .57049 .29473 .58345 .29966 .57685 .29558 Mtetra
.689 .881 .97 r
.57685 .29558 .58345 .29966 .59644 .29973 .58977 .28991 Mtetra
.768 .738 .826 r
.58977 .28991 .59644 .29973 .60929 .29115 .60263 .28016 Mtetra
.744 .709 .819 r
.60263 .28016 .60929 .29115 .62213 .28124 .61554 .27131 Mtetra
.709 .719 .857 r
.61554 .27131 .62213 .28124 .63506 .27367 .62855 .26473 Mtetra
.68 .733 .89 r
.62855 .26473 .63506 .27367 .64811 .2681 .64166 .25954 Mtetra
.668 .739 .903 r
.64166 .25954 .64811 .2681 .66125 .2633 .65485 .25481 Mtetra
.664 .74 .907 r
.65485 .25481 .66125 .2633 .67446 .25868 .6681 .25017 Mtetra
.664 .741 .907 r
.6681 .25017 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19787 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36837 Mtetra
.30004 .36837 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36774 .32348 .36015 Mtetra
.32348 .36015 .3309 .36774 .34266 .36365 .33528 .35602 Mtetra
.662 .74 .908 r
.33528 .35602 .34266 .36365 .35448 .35966 .34713 .35192 Mtetra
.654 .736 .909 r
.34713 .35192 .35448 .35966 .36632 .35612 .35902 .34805 Mtetra
.626 .718 .913 r
.35902 .34805 .36632 .35612 .37816 .35396 .37093 .34497 Mtetra
.564 .671 .91 r
.37093 .34497 .37816 .35396 .38997 .35404 .38282 .34358 Mtetra
.5 .605 .89 r
.38282 .34358 .38997 .35404 .40183 .35501 .39471 .34399 Mtetra
.522 .604 .876 r
.39471 .34399 .40183 .35501 .41392 .35199 .40671 .34398 Mtetra
.673 .74 .9 r
.40671 .34398 .41392 .35199 .42637 .33964 .41895 .33937 Mtetra
.856 .969 .869 r
.41895 .33937 .42637 .33964 .43873 .33014 .43146 .3275 Mtetra
.815 .92 .907 r
.43146 .3275 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.664 .741 .907 r
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.44 .643 .944 r
.5315 .28721 .53833 .29541 .55103 .29098 .54428 .28805 Mtetra
0 .492 .803 r
.54428 .28805 .55103 .29098 .56387 .29183 .55719 .29123 Mtetra
.457 .881 .92 r
.55719 .29123 .56387 .29183 .57685 .29558 .57011 .28708 Mtetra
.764 .767 .855 r
.57011 .28708 .57685 .29558 .58977 .28991 .58301 .27828 Mtetra
.745 .699 .808 r
.58301 .27828 .58977 .28991 .60263 .28016 .59593 .26904 Mtetra
.718 .699 .831 r
.59593 .26904 .60263 .28016 .61554 .27131 .60892 .2616 Mtetra
.69 .719 .871 r
.60892 .2616 .61554 .27131 .62855 .26473 .622 .25587 Mtetra
.672 .734 .896 r
.622 .25587 .62855 .26473 .64166 .25954 .63516 .25095 Mtetra
.666 .739 .905 r
.63516 .25095 .64166 .25954 .65485 .25481 .64839 .24624 Mtetra
.664 .74 .907 r
.64839 .24624 .65485 .25481 .6681 .25017 .66168 .24158 Mtetra
.664 .741 .907 r
.66168 .24158 .6681 .25017 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19787 .81217 .18882 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36837 .2925 .36078 Mtetra
.2925 .36078 .30004 .36837 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36015 .316 .35249 Mtetra
.316 .35249 .32348 .36015 .33528 .35602 .32784 .34832 Mtetra
.663 .74 .908 r
.32784 .34832 .33528 .35602 .34713 .35192 .33972 .34416 Mtetra
.66 .738 .908 r
.33972 .34416 .34713 .35192 .35902 .34805 .35165 .34007 Mtetra
.647 .73 .909 r
.35165 .34007 .35902 .34805 .37093 .34497 .36362 .33636 Mtetra
.613 .702 .907 r
.36362 .33636 .37093 .34497 .38282 .34358 .3756 .33363 Mtetra
.558 .646 .893 r
.3756 .33363 .38282 .34358 .39471 .34399 .38757 .33247 Mtetra
.521 .594 .869 r
.38757 .33247 .39471 .34399 .40671 .34398 .39957 .33253 Mtetra
.549 .61 .867 r
.39957 .33253 .40671 .34398 .41895 .33937 .41169 .33181 Mtetra
.656 .75 .919 r
.41169 .33181 .41895 .33937 .43146 .3275 .42401 .3277 Mtetra
.734 .982 .909 r
.42401 .3277 .43146 .3275 .4439 .31793 .4365 .31925 Mtetra
.801 .998 .854 r
.4365 .31925 .4439 .31793 .45624 .3136 .44908 .30815 Mtetra
.745 .836 .921 r
.44908 .30815 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.664 .741 .907 r
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.57 .705 .933 r
.49923 .2879 .50619 .29609 .51881 .29166 .51188 .28604 Mtetra
.226 .613 .953 r
.51188 .28604 .51881 .29166 .5315 .28721 .52462 .28833 Mtetra
.06 0 0 r
.52462 .28833 .5315 .28721 .54428 .28805 .53746 .28799 Mtetra
.468 .89 .897 r
.53746 .28799 .54428 .28805 .55719 .29123 .55036 .28326 Mtetra
.755 .778 .872 r
.55036 .28326 .55719 .29123 .57011 .28708 .56328 .27511 Mtetra
.737 .691 .807 r
.56328 .27511 .57011 .28708 .58301 .27828 .57621 .26616 Mtetra
.716 .681 .815 r
.57621 .26616 .58301 .27828 .59593 .26904 .58919 .25842 Mtetra
.695 .701 .852 r
.58919 .25842 .59593 .26904 .60892 .2616 .60225 .25227 Mtetra
.677 .724 .885 r
.60225 .25227 .60892 .2616 .622 .25587 .61539 .24711 Mtetra
.667 .736 .901 r
.61539 .24711 .622 .25587 .63516 .25095 .6286 .24232 Mtetra
.665 .74 .906 r
.6286 .24232 .63516 .25095 .64839 .24624 .64187 .23762 Mtetra
.664 .741 .907 r
.64187 .23762 .64839 .24624 .66168 .24158 .65521 .23291 Mtetra
.65521 .23291 .66168 .24158 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18882 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34416 .33225 .33635 Mtetra
.663 .74 .907 r
.33225 .33635 .33972 .34416 .35165 .34007 .34422 .33215 Mtetra
.658 .736 .908 r
.34422 .33215 .35165 .34007 .36362 .33636 .35623 .32808 Mtetra
.643 .723 .906 r
.35623 .32808 .36362 .33636 .3756 .33363 .36828 .32444 Mtetra
.612 .689 .898 r
.36828 .32444 .3756 .33363 .38757 .33247 .38035 .32172 Mtetra
.572 .636 .877 r
.38035 .32172 .38757 .33247 .39957 .33253 .39243 .32024 Mtetra
.548 .595 .853 r
.39243 .32024 .39957 .33253 .41169 .33181 .40455 .31958 Mtetra
.561 .603 .852 r
.40455 .31958 .41169 .33181 .42401 .3277 .41678 .3185 Mtetra
.612 .693 .901 r
.41678 .3185 .42401 .3277 .4365 .31925 .42914 .31569 Mtetra
.652 .88 .982 r
.42914 .31569 .4365 .31925 .44908 .30815 .44162 .31089 Mtetra
.37 .824 .718 r
.44162 .31089 .44908 .30815 .46157 .30117 .45418 .305 Mtetra
0 0 0 r
.45418 .305 .46157 .30117 .47407 .29677 .46678 .29937 Mtetra
.46678 .29937 .47407 .29677 .48662 .29234 .47941 .29492 Mtetra
.47941 .29492 .48662 .29234 .49923 .2879 .49208 .29164 Mtetra
.01 0 0 r
.49208 .29164 .49923 .2879 .51188 .28604 .50483 .28863 Mtetra
0 0 0 r
.50483 .28863 .51188 .28604 .52462 .28833 .51765 .28454 Mtetra
.702 .893 .967 r
.51765 .28454 .52462 .28833 .53746 .28799 .53053 .27843 Mtetra
.737 .737 .851 r
.53053 .27843 .53746 .28799 .55036 .28326 .54344 .27057 Mtetra
.721 .674 .803 r
.54344 .27057 .55036 .28326 .56328 .27511 .55639 .26228 Mtetra
.707 .666 .808 r
.55639 .26228 .56328 .27511 .57621 .26616 .56937 .2548 Mtetra
.692 .687 .84 r
.56937 .2548 .57621 .26616 .58919 .25842 .58242 .24857 Mtetra
.678 .714 .875 r
.58242 .24857 .58919 .25842 .60225 .25227 .59554 .24326 Mtetra
.669 .731 .897 r
.59554 .24326 .60225 .25227 .61539 .24711 .60873 .23839 Mtetra
.665 .738 .905 r
.60873 .23839 .61539 .24711 .6286 .24232 .62198 .23365 Mtetra
.664 .74 .907 r
.62198 .23365 .6286 .24232 .64187 .23762 .63529 .22892 Mtetra
.664 .741 .907 r
.63529 .22892 .64187 .23762 .65521 .23291 .64867 .22417 Mtetra
.64867 .22417 .65521 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .33215 .33671 .32423 Mtetra
.662 .739 .907 r
.33671 .32423 .34422 .33215 .35623 .32808 .34877 .31999 Mtetra
.657 .734 .906 r
.34877 .31999 .35623 .32808 .36828 .32444 .36087 .31588 Mtetra
.644 .718 .902 r
.36087 .31588 .36828 .32444 .38035 .32172 .37301 .31215 Mtetra
.621 .686 .889 r
.37301 .31215 .38035 .32172 .39243 .32024 .38519 .3091 Mtetra
.595 .641 .866 r
.38519 .3091 .39243 .32024 .40455 .31958 .39739 .30687 Mtetra
.579 .604 .842 r
.39739 .30687 .40455 .31958 .41678 .3185 .40964 .30521 Mtetra
.581 .596 .832 r
.40964 .30521 .41678 .3185 .42914 .31569 .42197 .30346 Mtetra
.6 .624 .847 r
.42197 .30346 .42914 .31569 .44162 .31089 .43441 .30104 Mtetra
.626 .686 .886 r
.43441 .30104 .44162 .31089 .45418 .305 .44693 .29774 Mtetra
.647 .763 .934 r
.44693 .29774 .45418 .305 .46678 .29937 .45954 .29373 Mtetra
.657 .818 .961 r
.45954 .29373 .46678 .29937 .47941 .29492 .47222 .28924 Mtetra
.675 .823 .954 r
.47222 .28924 .47941 .29492 .49208 .29164 .48497 .28427 Mtetra
.699 .779 .913 r
.48497 .28427 .49208 .29164 .50483 .28863 .49777 .27859 Mtetra
.708 .716 .856 r
.49777 .27859 .50483 .28863 .51765 .28454 .51064 .27202 Mtetra
.705 .67 .813 r
.51064 .27202 .51765 .28454 .53053 .27843 .52354 .26475 Mtetra
.699 .651 .798 r
.52354 .26475 .53053 .27843 .54344 .27057 .53648 .2574 Mtetra
.692 .656 .809 r
.53648 .2574 .54344 .27057 .55639 .26228 .54947 .2506 Mtetra
.685 .678 .838 r
.54947 .2506 .55639 .26228 .56937 .2548 .56251 .24463 Mtetra
.676 .706 .87 r
.56251 .24463 .56937 .2548 .58242 .24857 .57561 .23934 Mtetra
.669 .727 .893 r
.57561 .23934 .58242 .24857 .59554 .24326 .58878 .23443 Mtetra
.665 .737 .903 r
.58878 .23443 .59554 .24326 .60873 .23839 .60201 .22966 Mtetra
.664 .74 .906 r
.60201 .22966 .60873 .23839 .62198 .23365 .6153 .22491 Mtetra
.664 .741 .907 r
.6153 .22491 .62198 .23365 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32423 .32915 .31627 Mtetra
.663 .74 .907 r
.32915 .31627 .33671 .32423 .34877 .31999 .34124 .31195 Mtetra
.662 .739 .907 r
.34124 .31195 .34877 .31999 .36087 .31588 .35339 .30764 Mtetra
.658 .733 .905 r
.35339 .30764 .36087 .31588 .37301 .31215 .36558 .30344 Mtetra
.65 .719 .899 r
.36558 .30344 .37301 .31215 .38519 .3091 .37782 .29948 Mtetra
.636 .693 .886 r
.37782 .29948 .38519 .3091 .39739 .30687 .3901 .29589 Mtetra
.621 .658 .865 r
.3901 .29589 .39739 .30687 .40964 .30521 .40243 .29274 Mtetra
.611 .626 .841 r
.40243 .29274 .40964 .30521 .42197 .30346 .41482 .28986 Mtetra
.61 .607 .823 r
.41482 .28986 .42197 .30346 .43441 .30104 .42727 .28695 Mtetra
.617 .604 .814 r
.42727 .28695 .43441 .30104 .44693 .29774 .43981 .28367 Mtetra
.63 .611 .812 r
.43981 .28367 .44693 .29774 .45954 .29373 .45243 .27981 Mtetra
.645 .621 .811 r
.45243 .27981 .45954 .29373 .47222 .28924 .46512 .27528 Mtetra
.659 .627 .807 r
.46512 .27528 .47222 .28924 .48497 .28427 .47789 .27007 Mtetra
.669 .629 .801 r
.47789 .27007 .48497 .28427 .49777 .27859 .49071 .26428 Mtetra
.675 .631 .798 r
.49071 .26428 .49777 .27859 .51064 .27202 .50359 .25811 Mtetra
.677 .638 .803 r
.50359 .25811 .51064 .27202 .52354 .26475 .51651 .2519 Mtetra
.678 .655 .821 r
.51651 .2519 .52354 .26475 .53648 .2574 .52949 .24597 Mtetra
.676 .68 .847 r
.52949 .24597 .53648 .2574 .54947 .2506 .54251 .24046 Mtetra
.672 .706 .873 r
.54251 .24046 .54947 .2506 .56251 .24463 .5556 .23533 Mtetra
.668 .725 .893 r
.5556 .23533 .56251 .24463 .57561 .23934 .56875 .23044 Mtetra
.665 .736 .902 r
.56875 .23044 .57561 .23934 .58878 .23443 .58196 .22565 Mtetra
.664 .739 .906 r
.58196 .22565 .58878 .23443 .60201 .22966 .59523 .22088 Mtetra
.664 .741 .907 r
.59523 .22088 .60201 .22966 .6153 .22491 .60857 .2161 Mtetra
.60857 .2161 .6153 .22491 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31627 .32152 .30825 Mtetra
.32152 .30825 .32915 .31627 .34124 .31195 .33364 .30388 Mtetra
.664 .74 .907 r
.33364 .30388 .34124 .31195 .35339 .30764 .34583 .2995 Mtetra
.663 .739 .907 r
.34583 .2995 .35339 .30764 .36558 .30344 .35806 .29512 Mtetra
.66 .735 .905 r
.35806 .29512 .36558 .30344 .37782 .29948 .37035 .29079 Mtetra
.656 .725 .9 r
.37035 .29079 .37782 .29948 .3901 .29589 .38269 .28656 Mtetra
.65 .708 .889 r
.38269 .28656 .3901 .29589 .40243 .29274 .39509 .28248 Mtetra
.644 .685 .874 r
.39509 .28248 .40243 .29274 .41482 .28986 .40754 .27853 Mtetra
.639 .661 .855 r
.40754 .27853 .41482 .28986 .42727 .28695 .42004 .27463 Mtetra
.639 .643 .839 r
.42004 .27463 .42727 .28695 .43981 .28367 .43262 .27064 Mtetra
.642 .633 .826 r
.43262 .27064 .43981 .28367 .45243 .27981 .44526 .26639 Mtetra
.647 .63 .819 r
.44526 .26639 .45243 .27981 .46512 .27528 .45797 .26182 Mtetra
.654 .634 .817 r
.45797 .26182 .46512 .27528 .47789 .27007 .47075 .25691 Mtetra
.66 .642 .821 r
.47075 .25691 .47789 .27007 .49071 .26428 .48359 .25175 Mtetra
.665 .655 .83 r
.48359 .25175 .49071 .26428 .50359 .25811 .49648 .24648 Mtetra
.668 .673 .846 r
.49648 .24648 .50359 .25811 .51651 .2519 .50943 .24127 Mtetra
.669 .694 .865 r
.50943 .24127 .51651 .2519 .52949 .24597 .52244 .23619 Mtetra
.668 .714 .883 r
.52244 .23619 .52949 .24597 .54251 .24046 .53551 .23125 Mtetra
.666 .728 .896 r
.53551 .23125 .54251 .24046 .5556 .23533 .54863 .22642 Mtetra
.665 .736 .903 r
.54863 .22642 .5556 .23533 .56875 .23044 .56182 .22162 Mtetra
.664 .739 .906 r
.56182 .22162 .56875 .23044 .58196 .22565 .57508 .21684 Mtetra
.664 .74 .907 r
.57508 .21684 .58196 .22565 .59523 .22088 .58839 .21203 Mtetra
.664 .741 .907 r
.58839 .21203 .59523 .22088 .60857 .2161 .60178 .20721 Mtetra
.60178 .20721 .60857 .2161 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30388 .32598 .29575 Mtetra
.32598 .29575 .33364 .30388 .34583 .2995 .3382 .29132 Mtetra
.664 .74 .907 r
.3382 .29132 .34583 .2995 .35806 .29512 .35047 .28688 Mtetra
.663 .739 .907 r
.35047 .28688 .35806 .29512 .37035 .29079 .3628 .28243 Mtetra
.662 .737 .905 r
.3628 .28243 .37035 .29079 .38269 .28656 .37518 .27798 Mtetra
.661 .732 .902 r
.37518 .27798 .38269 .28656 .39509 .28248 .38763 .27355 Mtetra
.659 .723 .897 r
.38763 .27355 .39509 .28248 .40754 .27853 .40012 .26914 Mtetra
.657 .713 .889 r
.40012 .26914 .40754 .27853 .42004 .27463 .41268 .26474 Mtetra
.656 .701 .88 r
.41268 .26474 .42004 .27463 .43262 .27064 .4253 .26031 Mtetra
.657 .693 .872 r
.4253 .26031 .43262 .27064 .44526 .26639 .43798 .2558 Mtetra
.658 .688 .867 r
.43798 .2558 .44526 .26639 .45797 .26182 .45072 .25118 Mtetra
.661 .689 .866 r
.45072 .25118 .45797 .26182 .47075 .25691 .46352 .24645 Mtetra
.663 .695 .87 r
.46352 .24645 .47075 .25691 .48359 .25175 .47638 .24165 Mtetra
.664 .704 .877 r
.47638 .24165 .48359 .25175 .49648 .24648 .48931 .23681 Mtetra
.665 .715 .886 r
.48931 .23681 .49648 .24648 .50943 .24127 .50229 .23198 Mtetra
.665 .726 .894 r
.50229 .23198 .50943 .24127 .52244 .23619 .51534 .22717 Mtetra
.665 .733 .901 r
.51534 .22717 .52244 .23619 .53551 .23125 .52844 .22237 Mtetra
.664 .738 .905 r
.52844 .22237 .53551 .23125 .54863 .22642 .54161 .21758 Mtetra
.664 .74 .906 r
.54161 .21758 .54863 .22642 .56182 .22162 .55484 .21277 Mtetra
.664 .741 .907 r
.55484 .21277 .56182 .22162 .57508 .21684 .56814 .20795 Mtetra
.56814 .20795 .57508 .21684 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28688 .34281 .2786 Mtetra
.34281 .2786 .35047 .28688 .3628 .28243 .35518 .2741 Mtetra
.664 .74 .907 r
.35518 .2741 .3628 .28243 .37518 .27798 .3676 .26957 Mtetra
.663 .739 .906 r
.3676 .26957 .37518 .27798 .38763 .27355 .38008 .26503 Mtetra
.663 .737 .905 r
.38008 .26503 .38763 .27355 .40012 .26914 .39262 .26048 Mtetra
.663 .734 .903 r
.39262 .26048 .40012 .26914 .41268 .26474 .40521 .25592 Mtetra
.662 .731 .9 r
.40521 .25592 .41268 .26474 .4253 .26031 .41787 .25133 Mtetra
.663 .728 .898 r
.41787 .25133 .4253 .26031 .43798 .2558 .43059 .24671 Mtetra
.663 .726 .897 r
.43059 .24671 .43798 .2558 .45072 .25118 .44337 .24205 Mtetra
.663 .727 .896 r
.44337 .24205 .45072 .25118 .46352 .24645 .4562 .23735 Mtetra
.664 .729 .898 r
.4562 .23735 .46352 .24645 .47638 .24165 .4691 .23262 Mtetra
.664 .732 .9 r
.4691 .23262 .47638 .24165 .48931 .23681 .48206 .22787 Mtetra
.664 .735 .902 r
.48206 .22787 .48931 .23681 .50229 .23198 .49508 .2231 Mtetra
.664 .737 .905 r
.49508 .2231 .50229 .23198 .51534 .22717 .50817 .21831 Mtetra
.664 .739 .906 r
.50817 .21831 .51534 .22717 .52844 .22237 .52132 .21351 Mtetra
.664 .74 .907 r
.52132 .21351 .52844 .22237 .54161 .21758 .53453 .20869 Mtetra
.664 .741 .907 r
.53453 .20869 .54161 .21758 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .2741 .34749 .26572 Mtetra
.34749 .26572 .35518 .2741 .3676 .26957 .35995 .26115 Mtetra
.35995 .26115 .3676 .26957 .38008 .26503 .37246 .25656 Mtetra
.664 .74 .907 r
.37246 .25656 .38008 .26503 .39262 .26048 .38504 .25195 Mtetra
.38504 .25195 .39262 .26048 .40521 .25592 .39767 .24732 Mtetra
.664 .739 .906 r
.39767 .24732 .40521 .25592 .41787 .25133 .41037 .24266 Mtetra
.664 .738 .906 r
.41037 .24266 .41787 .25133 .43059 .24671 .42312 .23799 Mtetra
.664 .738 .905 r
.42312 .23799 .43059 .24671 .44337 .24205 .43594 .23329 Mtetra
.43594 .23329 .44337 .24205 .4562 .23735 .44881 .22856 Mtetra
.664 .739 .906 r
.44881 .22856 .4562 .23735 .4691 .23262 .46175 .22382 Mtetra
.46175 .22382 .4691 .23262 .48206 .22787 .47475 .21905 Mtetra
.664 .74 .907 r
.47475 .21905 .48206 .22787 .49508 .2231 .48781 .21425 Mtetra
.48781 .21425 .49508 .2231 .50817 .21831 .50094 .20944 Mtetra
.664 .741 .907 r
.50094 .20944 .50817 .21831 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26572 .33974 .25726 Mtetra
.33974 .25726 .34749 .26572 .35995 .26115 .35223 .25265 Mtetra
.35223 .25265 .35995 .26115 .37246 .25656 .36478 .24802 Mtetra
.36478 .24802 .37246 .25656 .38504 .25195 .37739 .24337 Mtetra
.37739 .24337 .38504 .25195 .39767 .24732 .39007 .2387 Mtetra
.39007 .2387 .39767 .24732 .41037 .24266 .4028 .234 Mtetra
.4028 .234 .41037 .24266 .42312 .23799 .41559 .22928 Mtetra
.664 .74 .907 r
.41559 .22928 .42312 .23799 .43594 .23329 .42844 .22454 Mtetra
.42844 .22454 .43594 .23329 .44881 .22856 .44136 .21978 Mtetra
.664 .741 .907 r
.44136 .21978 .44881 .22856 .46175 .22382 .45434 .21499 Mtetra
.45434 .21499 .46175 .22382 .47475 .21905 .46737 .21018 Mtetra
.46737 .21018 .47475 .21905 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20684 Mtetra
.41325 .20684 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20684 .40556 .19786 Mtetra
.40556 .19786 .41325 .20684 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20012 Mtetra
.30447 .20012 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20012 .29626 .19108 Mtetra
.29626 .19108 .30447 .20012 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12594 Mtetra
.43285 .12594 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12594 .42493 .11623 Mtetra
.42493 .11623 .43285 .12594 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25832 .16854 Mtetra
.25832 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000X@2Y
_NP00`000000ZKgX0:Vmj00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000Y02Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0:40ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj000000000000740ZKgX0`2Y_NL50:Vmj0D0ZKgW;02Y_NP00`000000ZKgX0:Vmj00T0:Vmj003
0000003oool0oooo00P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;la0?ooo`003@3oool00`3o
gi`0B00000000003000000030000M02oool0oooo00<0oooo00/0omnL04P0M02oool0oooo0?oOW00D
55l0a?oo0?ooo`3oohl0=@0D05o4o`0P0?ooo`<00000L@2Y_NP60:Vmi`80ZKgX0`2Y_>L50:Vmi`80
ZKgX0`2Y_NLV0:Vmj0030000002Y_NP0ZKgX02@0ZKgX00<000000?ooo`3oool0203oool01`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?noM000
55l0a?oo0?ooo`3oohl0=@0D05o4o`0N0?ooo`<00000I@2Y_NP50:Vmi`D0ZKgX1@2Y_>L50:Vmi`H0
ZKcW2P2Y_NL20:Vmj0<0ZKgW802Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00L0
oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000I0?ooo`0;0?oOW01807@0_ooo
0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l06`3oool3000006H0ZKgX202Y_NL50:VliPD0
ZKcW1@2Z^nH50:Vli`D0Z[cW2`2Y_NLO0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3o
ool01P3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0<03oool001L0oooo00d0_g@00000
B02L_i`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0P00001W0:Vm
j0P0ZKgW0`2Y^nH50:VliP80ZKcW0`2Z^N@50:ZkiPD0Z[[U1@2Z_>L50:ZliP/0ZKgW6@2Y_NP00`00
0000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo0300oooo000H0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO
5000=Hl05`3oool3000006D0ZKgX1@2Y_>L50:Vmi`H0ZK_V102Y_>H60:Zii080Z[_V0`2[]^850:Zj
i@80Z[cW0`2[^N@50:ZliPH0Z[cW1@2Y_NLH0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?oo
o`3oool01@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00<0omnL
04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo01@0oooo0`0000000`2Y_NP000000:Vm
j01Q0:Vmj0X0ZKcW1@2Y^^D50:VkiPD0Z[OR1@2Z^N@60:^fhP@0Z[[U1P2[^N@20:ZliP<0Zk[T1P2Z
_>L20:Vmi`<0Z[cW5`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00@0oooo00H0
oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y_NP000000000001U0:Vmj0X0ZKcW
202Y^^D20:VkiP<0ZKCP1@2Z]n850:^ag@D0ZkKR1@2/]=l50:^ii0H0Zk[T2`2Z_>L20:Vmj0<0Z[gW
4@2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00D0oono07@000000000
04RL0=ooo`0a0?ooo`00<P3oool3000006D0ZKgX2P2Y_>L:0:Vji@H0ZKCP0P2Z]n830:^/f0D0Zk7M
0P2[]^830:f^f0D0[;CO0`2[^N@20:fdgPH0Zk[T1@2[^nD50:Zli`H0Z[gW402Y_NP00`000000ZKgX
0:Vmj00Y0:Vmj0030000003oool0oooo03X0oooo000`0?ooo`80000000<0ZKgX0000002Y_NP0H@2Y
_NP50:Vmi`D0ZKcW1P2Y^ND40:Vji@D0ZK7N1@2Y]>060:^/f0@0Zk7M1P2][]P50:bdg`D0[KCN0`2[
^^@30:ffg`D0Zk_U1@2Z_>H50:Zmi`l0ZKgX0P00000/0:Vmj0030000003oool0oooo03T0oooo000/
0?ooo`040:Vmj00000000000000006L0ZKgX1@2Y_NL30:Vli`80ZK[U1P2Y^ND40:V`g@D0ZK7N0`2Y
]>020:ZWe0H0ZjcH0P2[/Md20:fWdPH0[JkH1@2_[MH50:fdgPH0[KKO0P2[^nD30:fihPD0Z[cV1@2Z
_NL;0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03T0oooo000[
0?ooo`800000J`2Y_NP50:Vmi`D0ZK[U0`2Y^ND30:R`g@@0ZK3M1@2Y/Mh50:ZWe0D0ZjcH1@2]Ym83
0:f^f0<0/JO?1@2_[MH20:fdgP<0/JoG1@2]]]l60:fihP80Z[cV0`2/^nD50:Zmi`L0ZKgX0`000005
0:Vmj0030000002Y_NP0ZKgX02X0ZKgX00<000000?ooo`3oool0>03oool002T0oooo0P00001^0:Vm
j0D0ZK_V1@2Y^^D50:R`g@D0ZK3M1@2XY=850:ZWe080ZjcH0`2]Xld50:fWdPD0/JO?1@2_[MH60;6_
e`80[KKO0`2a/mX50:fihPH0[;_U102Z_NL40:Vmj0<000002@2Y_NP00`000000ZKgX0:Vmj00Z0:Vm
j0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool20000
06X0ZKgX1@2Y^nL50:VkiPD0Z;7O1@2X/=d20:V`g@<0Yj;A1@2XY=840:ZWe0D0[J?=102]Ym820;:V
c0D0/JO?0P2_[MH30;BZcPD0/JoG1P2a/mX20:fihP<0/;SN1@2/^nD50:^mi`030:Vmj00000000000
00d0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0g0?ooo`00703oool01P3ooml0
W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000I`2Y_NP30:Vli`D0ZK_W0P2Y^nH3
0:Nch@D0Z;7O102X/=d50:NRd@D0Z:CB1@2/XL`50:fSc@80[JOB0`2bY/`50;6Wc`H0]:[>0P2a[mL3
0;N^d0D0/K?J1P2`^=h20:bki@<0[[_S0P2[_NL3000000D0Z[gW2`2Y_NP00`000000ZKgX0:Vmj00Y
0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`050?ooo`8000000P3oool00`000000ZKgX0:Vmj01R0:Vmj0H0ZKcW102Y^nL60:Nch@@0Z;7O1@2U
XM450:NRd@80Z:CB0`2[XLd40:bQc0D0[J?=1P2bY/`20;6Wc`<0^:c=1@2dZ/h60;N^d080/K?J0`2g
/]@50;2hgP@0[[_S0`000000102[_NL0ZkgV0:^miP2[_NH40:Zmi`/0ZKgX00<000000:Vmj02Y_NP0
:P2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02L
gol01@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX05d0ZKgX1@2Y_NL50:Vli`D0
Z;KS1@2W/n450:BRd`@0YJ7A1@2WX]450:^Qc@D0[:7<0P2]Xld30;B[d0D0/ZK<1@2h[<d40;BZcP80
_;3>1@2g[]060;Nbe080/;SN0`2e^=/300000080[[_S1@2[_NH50:Zmi`/0ZKgX00<000000:Vmj02Y
_NP0:@2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0
B02Lgol01@3oool00`000000oooo0?ooo`030?ooof00ZKgX1@2Y_NL50:Rii@D0Z;KS0P2W/n430:>T
eP@0Y:;C1@2UXM420:NRd@<0Z:3>1@2[XLd40:bQc0D0]:_@102bY/`20;blf@D0^:c=0P2dZ/h30;b`
cP@0]jk@0P2n//h50;Nbe080]KSK0`0000000`2e^=/0/;cR0;2lhP030;2lhP@0ZkgV1P2Z_NL;0:Vm
j0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0=03oool001`0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00D0oooo0P0000050?ooo`030000002Y_NP0ZKgX05d0ZKgX0`2Y_NL2
0:VkiPD0Z;WU102X]^<50:>TePD0Y:;C102UXM450:RPcPD0Zj7=0P2/XL`30;Fgf`D0]:_@0P2bY/`3
0;blf@D0^:c=1P2l/<h20;N^d0@0_[;>0P2g/]@0102n]M4000000000000000030;Fhf`80^[[H102`
_>850:bmiPD0Z[gW302Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03<0oooo000L
0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000:Vmj02Y_NP0G@2Y_NP50:VkiP@0Z;WU1@2SZMX50:>TeP@0Y:;C1@2UW/l50:RPcP@0Zj7=
1@2e]m/50;B[d0H0_;cI0P2h[<d30<77g`D0_;3>1P2n//h3000000<0_[GA0P2e^=/40;Zjf080/;cR
0P2c_N450:bmiPD0Z[gW2`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03<0oooo
000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?ooo`070?oooeX0
ZKgX1@2Y_>L50:VkiP@0Y:oO1@2SZMX40:>TePD0XIc?102UW/l50:RPcP80Zj7=0`2banT50;Fgf`80
]:_@0`2ci?L50;blf@H0`LOO0P2l/<h30<?4fP80_[;>0`0000000`34_=<0_[GA0;jed@030;jed@H0
^[[H1@2c_N420:bmiP<0[KkV1@2Z_NL;0:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3o
ool0<P3oool001d0oooo00D0oono07@00000000004RL0=ooo`060?ooo`030000003oool0oooo00P0
ooooFP2Y_NP50:Vli`D0Y[GS102T[ml40:>YfPD0WI[@102QW<l50:FNc`@0Z:3>1P2banT40;Fgf`H0
/nCg0P2l_=T307OSi@D0`LOO1@33a=X2000000040;jbcP34_=<0a;cC0<Bld`@0_[GA0P34^]440;Zj
f080`;gG102c_N460:fniPD0Z[gW2`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo
0380oooo000W0?ooo`030000003oool0oooo00X0ooooFP2Y_NP20:Vli`<0YkWV1@2V]N<40:B_g`@0
W9_B102MV]050:6Lc`@0YIk?1@2/d_@50;;7j@<0TKC^0`0iW?<40;?Tm`H0Mn?U0P31aml307CQj`05
0<?4fP000000000000000033a=X01P34_=<20;jed@@0a;[A0P2j^]P30<2me`80/kgQ0`2f_n450:fn
iPH0Z[gW2P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo0340oooo000W0?ooo`03
0000003oool0oooo00/0ooooF@2Y_NP60:NiiP@0Y[GS1@2LX=L409bKdP@0WI[@102QW<l50:SAmPD0
[=;d0`2Y_NP5096dkPH0ZKgX101`Y?42001mc@<0M>7[0`0000020<?4fP<0/>7h1@34_=<60<Bjd@D0
`;gG1P2f_n450:joiPD0Z[gW2`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo0300
oooo000W0?ooo`030000003oool0oooo00`0ooooE02Y_NP50:Rli`D0YkWV1@2NZ=d409bPe`@0W9_B
102MV]020:6Lc`<0YL?_1@2XdOHG0:Vmj005072Tl@00000000000000001`Y?400P00LlD60;3Qn080
a;cC0`34b=h40<Bjd@80b<3C0`30_ML20<C2f0<0][oQ0`2h`^850:joiPD0Z[gX2`2Y_NP00`000000
ZKgX0:Vmj00X0:Vmj0030000003oool0oooo0300oooo000W0?ooo`8000003P3ooomE0:Vmj0@0Z;cW
1@2R/N8409jXg@D0W:3G102LVm8309fJd0H0YL?_00<000000:Vmj02Y_NP05P2Y_NP3000000D0ZKgX
0`0^O^L40;3Qn0H0a<SN0P34^]440<S0d`D0a<;H1P2h`^820:joiP<0[[oW1@2Z_NP;0:Vmj0030000
002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3o
oomE0:Vmj0@0Y[SV1@2R/N8409jXg@@0W:3G102LVm850:2_hP<0YL?_5`2Y_NP3000000T0ZKgX100^
O^L301nYf@D0a<SN1@38`=<20<W4e@<0a<;H0P37a]T50;S2hPH0[[oW0P2Z_NP30:Znj0X0ZKgX00<0
00000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0?
0?oooe80ZKgX0`2X^nL40:JhiP@0X[7R102NZ=d509BHe0@0VIoH1@2P[n830;kFja<0ZKgX0`00000=
0:Vmj0D0T[C^0P0OZMT20<C8gP<0]lg[0`38`=<40<W4e@030<C2f037a]T0alKI0080alKI0P2h`^83
0;S4h`D0[[oW1P2Z_^P:0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0;P3oool0
02L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX04`0ZKgX1P2X^nL40:JhiP@0V:CM102DV]L409BH
e0D0VIoH0P2P[n860;kFj`l0ZKgX0`00000A0:Vmj080T[C^0`2Y_NP00`00GMD0]lg[0;O=j`040;O=
j`030<S0d`39a=D0bLCE00<0bLCE1@37a]T60;S4h`D0[KoW1@2Z_^P;0:Vmj0030000002Y_NP0ZKgX
02P0ZKgX00<000000?ooo`3oool0;@3oool002H0oooo0P00000C0?ooo`030000002Y_NP0ZKgX04`0
ZKgX1@2X^nL509j_h`@0V:CM0`2DV]L509BHe0@0VIoH00@0Y^7k0<gofP3=omX0cOoJ402Y_NP30000
01X0ZKgX00<005gE0;O=j`2gcN/00`2gcN/50<W4e@80bLOH0`37a]T20<S;g0<0^<CS0`2ga^D50:fo
i`D0Z[gX2`2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo02`0oooo00090?ooo`0:
0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P0
0P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000:Vmj02Y_NP0
C02Y_NP50:BgiPD0WZoS102HY=d309BJe`@0U9SD102VhO/20<gofQ00ZKgX0P00000M0:Vmj08005gE
1@2P`o430<W4e@<0bLOH0P37a]T40<S;g0H0]lKU0P2]_nL30:boj0D0Z[gX2P2Y_NP00`000000ZKgX
0:Vmj00X0:Vmj0030000003oool0oooo00X0oooo00D0gia8000000000000001809cOo`0M0?ooo`00
203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00<0omnL04P0001d_ol0103oool01`3o
_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000002Y
_NP0ZKgX04P0ZKgX102X^nL50:BgiP@0WZoS102HY=d309BJe`H0W;7V0P3=omX?0:Vmj0<00000802Y
_NP00`0EKMh005gE0:33l@040:33l@D0bLOH1@38bm`20<S?g`D0]lKU1P2/_nP50:Zmj0X0ZKgX00<0
00000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0gooo0?ooo`3ooml0
W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0103oool00`3o
gi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?oood/0ZKgX102X^nL40:Bg
iPD0TZ;P102<V=X308nJfP@0W;7V0P2knnP30=3[j0X0ZKgX0`00000T0:Vmj0805FgN1@2B]>h30<W7
f080bl[I0`38bm`40<S?g`D0]<GW1@2/_nP50:Zmj0/0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`00
0000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3oool0
0`000000oooo0?ooo`0G0?ooodX0ZKgX102X^nL409b`i@@0TZ;P102<V=X408nJfP80W;7V0P2knnP5
0=3[j0H0ZKgX0`00000X0:Vmj0805FgN1@2B]>h00`39amP0bl[I0<_:f@020<_:f@D0b<oO0P35dN<5
0;C5i`D0ZkoX102Z_NP;0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0303oool0
0`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01P3o
ool02`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<00000
0?ooo`3oool0603ooom90:Vmj0D0Y;WW102L/>D409:Rh0@0S9SJ0`2?V]X30;_kj080d>_X1`2Y_NP3
000002`0ZKgX0P0EKMh409:dkP@0bl[I0P3=cm/30<S?g`@0aM7S0P2daNL30;74j0@0ZkoX402Y_NP0
0`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00H0oooo00L0omnL04P0B02Lgol0oooo0?oo
g`2LB4P0W=oo01`0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`070?ooo`05
0?oo_`1d04P0W=oo0?oo_`1d00000`0000000`1d_ol0oooo0?ooo`040?ooo`8000006`3ooom40:Vm
j0D0Z;cX1@2T^NL309b`i@@0TZ;P102<V=X50:Noj`80foSN0P3@jnP30:Vmj0<00000;`2Y_NP301E]
gP@0U:gW0P3;b]T40<g?f`H0aM7S1P2aa>P40:^nj100ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`00
0000oooo0?ooo`050?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool06`3oool000P0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0okmd001d_`3oool00P3oool0
1@2oM000M;oo0?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool06`3ooom40:Vmj0D0Z;cX102T
^NL408jUi0@0QISN102<W=d30:Noj`80foSN0`3@jnP3000003<0ZKgX00<09VGH01E]gP0EKMh0102D
[NL40<g?f`80cmKN0`35dN<30<3@iP<0/LCX0`2^`^P40:^nj100ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`050?ooo`030?oog`2LB4P0W=oo0200oooo00080?ooo`060?oog`2LB000
M;oo0?ooo`3OW4P007Bo103oool02P3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooo0;md001d
_ol90?ooo`030000003oool0oooo01`0ooooA02Y_NP20:Rlj0<0YK[X102L/nP408jUi0<0QISN1@2<
W=d20=_hgP80d>_X0`0000000`3@jnP0ZKgX0:Vmj00d0:Vmj0809VGH1@2R/N820<g?f`@0cmKN1P30
d>H50:k2j080ZkkX0`2Z_^P?0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3o
ool00`2oM000M;oo0?ooo`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0
omnL04P000000000000007Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`00
0000oooo0?ooo`0M0?oood<0ZKgX1P2U^^P409bcj0@0SZGT0`25V=h208bLg@<0[;gV00<0fmoI0000
00000000>P2Y_NP302IUf0@0X[7R1@3?e]h20<oKhP<0`=3V0`2ic>P40:k2j0H0Z[kX3`2Y_NP00`00
0000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo00D0oooo00H0gia800000000000000000000M02o
oolL0?ooo`009@3oool2000001l0oooo?`2Y_NP50:Rlj0@0YK[X102L/nP408jUi0<0QISN0`2/_NH3
00000080fmoI00<0ho3G0:Vmj02Y_NP0=02Y_NP409:dkP0305M^cP0VIMP09VGH0080X[7R0P2e_^43
0<oFgP@0cm_R1P2ic>P40:c0j0D0Z[kX402Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0
oooo02H0oooo000U0?ooo`030000003oool0oooo01l0oooo?`2Y_NP50:Rlj0@0X;OY102@ZnP407nJ
h`80QI[P0`0000040=_Of@<0ho3G=P2Y_NP309:dkP<0Efk>1@2e_^440<oKhP<0bM_W0`2ic>P30;;6
j@@0[<3X1@2Z_NP?0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0803ooolo0:Vmj0D0YkcX102P]nT4092[j080Oi[S0`00000208FJh0@0
fmoI0`3Sl=L20;kFjcD0ZKgX102B]>h305M^cP80]KkQ1036dN<60<WKi`D0//KY1@2[_^P50:Zmj0l0
ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0U0?ooo`00903oool2000002<0oooo
?`2Y_NP50:Nlj0@0X;OY0P2@ZnP300000080Oi[S1P2O/><30>?`e`@0_]K[=@2Y_NP305iie@<0Efk>
1@36dN<20<kPi@<0bM_W0`2oe>X30;;6j@80[/;Y1@2[_^PD0:Vmj0030000002Y_NP0ZKgX02L0ZKgX
00<000000?ooo`3oool0903oool002@0oooo00<000000?ooo`3oool08`3ooolo0:Vmj0D0Y;_Y0P2G
/n/300000080P:;Y101iV>@409n`h`<0aLKK1P2ne^/d0:Vmj0@0GWWE0`28U]X30<KAh`@0c^3U1P2o
e>X50:k2j@80ZkkX0`2Z_NPD0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3o
ool002@0oooo00<000000?ooo`3oool0903ooolm0:Vmj080Z;gX0`2T^nT3000000<0Uk?[0`20X^T4
07VHi080Wk3S0`35a]/30=_=bcT0ZKgX0`1NNMD408RFfP@0c^3U103<hnP50;G;j`@0[/;Y1P2Z_NPC
0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?oo
ocX0ZKgX102X_NP300000080Y;_Y102G/n/3082Rj@@0NIST1035a]/40=_=b`030=g;a`2Y_NP0ZKgX
03<0ZKgX0`23S]D405iie@80R9KJ0`2b`^H50<cSj080`]_/102ebn/50:^oj0D0Z[gX502Y_NP00`00
0000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo0280oooo000S0?ooo`800000:03ooolj0:Vmj003
0:Rmj000000000000080Z;gX102Q^NX408b^k@<0LYcZ1024XNL20<G6f`@0flg;0`3MblLd0:Vmj0@0
PhkE0`1bNld40;;2iP80bN;Z0`3<hnP40<;Kk0@0[lCY1@2[_nPI0:Vmj0030000002Y_NP0ZKgX02L0
ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@00000000004RL0=ooo`3oool0omnL
04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo00<000000?ooo`3oool0:03o
oolf0:Vmj0<000001@2W_>P40:6ijP@0S:k]0`1bW>X408BQi`@0flg;103MblL00`3GaLP0ZKgX0:Vm
j00b0:Vmj0<0PhkE101bNld20;;2iP@0bN;Z1032fn`30;K>k0@0[lCY1@2Z_^PI0:Vmj0030000002Y
_NP0ZKgX02H0ZKgX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nL
B000M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo
02X0oooo<P2Y_NP3000000@0ZKgX1@2W_>P409bhk0@0P:[_0P1YV^`509^ai`80flg;103MblL30=O5
b3<0ZKgX1023S]D3079kc@@0bN;Z103:jN`50;K>k0D0ZkoX1@2Z_^PH0:Vmj0030000002Y_NP0ZKgX
02L0ZKgX0P00000Q0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool0
0`2oM000M;oo0?ooo`050?ooo`800000;03oool^0:Vmj0<00000202Y_NP50:Jlj@@0W;S/1020Z^l3
06VJk0@0Vk7W103MblL40=O5b2/0ZKgX1@2X[=X408R2aP<0Mgc;1@2V^^L40<[Yk0<0_mg^0`2fc^`2
0:k4jPD0ZkoX7@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01l0oooo000<0?oo
o`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo00D0oooo00<0
00000?ooo`3oool0;03ooolZ0:Vmj0<00000302Y_NP50:Jlj@<0W;S/1020Z^l406VJk0@0/;cS0P3M
blL40=O5b080e;o5:`2Y_NP40:R/fP@0R8;6101gO</20:Jji`@0a>S_1P2ogNh50:k4jP80ZkoX0`2Z
_^PM0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0okmd
0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo
00H0oooo00<000000?ooo`3oool0;@3ooolV0:Vmj0<00000402Y_NP20:Jlj@<0YKcY102H]nd307JW
l@@0Iig_102`_><40=O5b0@0e;o51@2X[MXV0:Vmj0@0Z:cJ1028P/H307Mlb`@0a>S_1034jo050;C=
k0@0[/CZ1P2Z_^PL0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3oool000`0
oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P000000
0`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y_NP3000001<0ZKgX1P2U_>T4
09Rgk@<0MZOa101WWNl20;2lh`80^l;O0P3GaLP50=Boa@030=Jn`P2X[MX0Z:gJ00<0Z:gJ9@2Y_NP4
0:R/fP@0R8;60P1gO</30:_7kP@0a>_`0`2jf_040;C=k0D0ZkoX1@2Z_^PM0:Vmj0030000002Y_NP0
ZKgX02L0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00<0oooo00<0oooO09a8B02Lgol02@3oool200000340oooo7P2Y_NP3000001P0ZKgX102U
_>T509JgkP<0KZKc0`1UXO850;_2g`D0e;o50`3F_/820:R]fP<0/9o67`2Y_NP20:6=_`@0UXBn0`21
N/<408R2aP@0ZlO^0`2oko860;[Jl0@0[L;Y1@2[_nPR0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<0
00000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md
001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3ooolK0:Vmj0800000702Y_NP40:Flj@D0U[O^
0`1^Y_<306FQlP<0^l;O0P2kaN840=Boa@<0e[k21P2`WlH50:JOcaL0ZKgX102QSKl409J4_P@0PG[3
102<U]P20:_7kP80_nob0`2mio<30;[Jl0<0/<S/102]`^T50:Zmj280ZKgX00<000000:Vmj02Y_NP0
9P2Y_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo
00H0gia800000000000000000000M02oool50?ooo`030000003oool0oooo0380oooo5`2Y_NP30000
01l0ZKgX102U_>T509Fgk`80K:Od101UXO850;_5hP80e;o5103F_/800`3F`lL0/9o60;2OaP020;2O
aP80b[722@2VWll50:Vmj0@0Z:cJ1@2Y_NP80:6=_`D0UXBn1021N/<408bFf0030;o_lP2mio<0_NOc
00@0_NOc1@2`b>`50:Znj0D0Z[gX8@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo
01/0oooo000R0?ooo`800000=03ooolC0:Vmj0<000008`2Y_NP40:FljPD0UKO_0P1/Yo@405jTm@D0
^lGR103F_/820=K3a`<0/9o60`3:/L840:JOc`80^:31102VWll50::A`P@0Z:cJ1@2QR[`80:6=_`@0
UXBn1021N/<40;;Sm`<0^?3d1@2cdNl30;38k080Zl3Y1@2Z_^PV0:Vmj0030000002Y_NP0ZKgX02H0
ZKgX00<000000?ooo`3oool06`3oool00280oooo00<000000?ooo`3oool0=03oool?0:Vmj0<00000
9`2Y_NP40:FljP@0UKO_0`1/Yo@405jTm@D0/LS[0P3F_/840=K3a`030;2OaP3:/L80b[7200<0b[72
0P2VWll30;RP`@<0YYo?0P2gW[l50::A`P80Z:cJ0P2[T[`40:6:_0P0XHfo102FQ;h60:C9l`<0^?3d
0`2ef_<50;?Ak`D0Zl3Y0P2Z_^PY0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0
6P3oool00280oooo00<000000?ooo`3oool0=@3oool00`000000ZKgX0:Vmj0080:Vmj0<00000:`2Y
_NP40:Flj@@0V;S^0`1`ZoD405BSm`D0/LS[1@3F`lL60<Za`PH0^:3100@0YYo?0;NN_`2gW[l0]ijo
1@2RTL840:^B_0D0XHZl1`2QSKl509fbi`<0Y<Wc0`2]lOH60;GJl`D0[L?Z102[`>T/0:Vmj0030000
002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool0303oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0103oool00280oooo00<000000?ooo`3oool0=`3oool60:Vmj0<00000
;`2Y_NP40:Flj@@0V;S^0`1`ZoD405BSm`D0U<Oi0`3F`lL20<O?g`@0b[720P3Ba/l50;RP`@D0]ijo
0`2RTL820<:^aP<0Zi:l1@2QR[`40:6=_`@0X:WM1@2M/^L40:gamP<0/^?g1@2^an`40:g3jPD0Z[kX
:`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0800000303oool02P3ogi`0B01d0;ooo`3oool0oooO09a8
0018W=l0oooo0=nLB000M;l40?ooo`008@3oool2000003X0oooo0P2Y_NP3000003<0ZKgX1@2V_>T3
09bjk@D0N[3f0P1>XoL509C7n@040=K3a`37cml0aloO0<O?g`<0b[720`3Ba/l40;RP`@80cl??102g
W[l20::A`P<0`Zk6102[T[`40:6:_0D0Z:gK102PZMd209fbi`@0XNgh102bhoL20:k;k`D0[/O/2@2Z
_^P[0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;oo
o`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo000Q0?ooo`030000003oool0oooo
03P0oooo0`00000g0:Vmj0D0Y[cY0`2L^^d508Rfm080EjSh102DaoT50<O?g`030<Za`P3Ba/l0d/K?
00<0d/K?0P2hX<430<o3c`@0]ijo1P32[/H30:^B_080XHZl0`2a^]l50:R]f`<0X:WM0P2QkOP60:_W
nPD0[/__1@2[_nT40:Znj300ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0:0?oo
o`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo
00<000000?ooo`3oool0=P3oool2000000<0oooo>02Y_NP20:Jlj@<0YkgY0`2P^n`508Rfm0<0EjSh
101U^Od30<O?g`H0d/K?1P3?`ll20;NN_`80aLgP1@32[/H30:^B_0H0/K[O102X[M/309SYnP@0XNOk
1@2]c_450:_0j@D0ZkoY<`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00T0oooo
00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool2
000003@0oooo0`0000060?ooocL0ZKgX1P2W_NT30:2kk0D0U[[`101`/_T304Z/n@<0U=?m0`3Ba/l3
0:OKnPD0cl??00@0]ijo0<G=h035cN00aLgP1@32[/H40;G>k@D0/K[O1@2@i_/20:7Wn`D0Zloc0`2]
c_420:_1jPD0Zl3Y1@2Z_NPc0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0203o
ool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?oo
o`030000003oool0oooo0300oooo0`0000090?ooocP0ZKgX1@2W_NT40:BljPD0U[[`102:^OD305nb
n`<0U=?m1P2WfoX40<o3c`D0aLgP0P32[/H30:GPn`@0]Lk]1P24h_T209OTo@@0Ylkd1@2[co<50:_1
jPD0Z[kX102Z_NPd0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool03@2o
M000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool000@0
oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0
oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo02d0oooo0`00000>0?oo
ocL0ZKgX1@2X_NP40:BljPD0Wkc]102:^OD405nbn`<0DKWj102WfoX609_No@<0aLgP1P2Uh?/507CK
m`80T=kn1@2Uc?@40:O>m0D0Z/;[0`2[`NX70:Znj3P0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`00
0000oooo0?ooo`060?ooo`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000
M;l0103oool000<0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l50?ooo`030?oog`2LB4P0W=oo
00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3o
ool300000180oooo=`2Y_NP50:Rmj0@0YkgY1@2O_>d409^lk`D0Pk[h0`1M]o`405G1n@D0ElCi101f
f?/606SCn00308gHo`2Sao80XlOb00<0XlOb1@2Uc?@40:W1j`D0Z/;[1`2Z_^Pj0:Vmj0030000002Y
_NP0ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo00D0
oono07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool01@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<0
00005P3oooll0:Vmj0@0YkgY1@2U_NX409^lk`D0V[g`1026__T50931m`@0O/On1P2Fb?T40:?3l0D0
XlOb2@2Y`N/50:Vnj0@0Z[kX?@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0<000001@3oool00`000000
oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o
_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool09@3oool30000
01X0oooo?02Y_NP40:Rmj0D0YKgZ102T_N/509Zml0@0WKk`1@2@`OL509c2l`D0Y<3]102S`o050:Ro
jP@0ZL7[2@2Y_^Q20:Vmj0030000002Y_NP0ZKgX01P0ZKgX0`0000080?ooo`030000003oool0oooo
01D0oooo00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0
W=oo0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool0
8P3oool3000001h0oooo?02Y_NP40:Rmj0D0Z;gY2@2T_N/409fnl0H0X[o^102V_^/50:C0k@@0Z;kZ
1@2X_nX90:Vnj4H0ZKgX00<000000:Vmj02Y_NP04`2Y_NP4000000`0oooo00<000000?ooo`3oool0
503oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00H0gia8001d_`3o
ool0oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool3
00000280oooo@02Y_NP90:Rmj@D0Y;g[102V_NX30::okP<0Z;gY102V_^/50:Rnj@@0Z;kZ1@2Y_NP4
0:Vnj4X0ZKgX00<000000:Vmj02Y_NP03`2Y_NP0103oool0000000000000000@0?ooo`030000003o
ool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`070?oo
_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2000002H0oooo00<000000:Vm
j02Y_NP0@P2Y_NP90:Rmj@@0Y[gZ1P2X_NT20:Jnj`80ZKgX1@2X_^UG0:Vmj0030000002Y_NP0ZKgX
00X0ZKgX0P3oool3000001<0oooo00<000000?ooo`3oool0503oool000<0oooo00H0oooO09a8001d
_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0gooo0?ooo`2oM000M;oo203oool2000001`0oooo
0`00000Z0?ooodP0ZKgX1@2X_NT40:Vmj0D0Z;gYH@2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@00000
5P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0gooo00@0oooo
00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003000000030000M02oool0oooo00@0oooo
00<000000?ooo`3oool05`3oool3000002h0oooo]P2Y_NP00`000000ZKgX0:Vmj0050:Vmj0800000
6P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3o
oonf0:Vmj0040000002Y_NP0ZKgX0:Vmj08000007@3oool00`000000oooo0?ooo`0D0?ooo`007`3o
ool2000001<0oooo0`00000f0?oookD0ZKgX0`00000P0?ooo`030000003oool0oooo01@0oooo000O
0?ooo`030000003oool0oooo00l0oooo0`00000j0?oook00ZKgX0`0000030?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool30000
03h0oooo[02Y_NP3000000H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0C0?oo
o`007`3oool00`000000oooo0?ooo`090?ooo`<00000@P3ooonW0:Vmj0@000002P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo000N0?ooo`8000002@3oool2000004H0oooo
XP2Y_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool04`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0ooooWP2Y_NP0103oool00000
00000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo
00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP0UP2Y_NP00`3oool00000
00000002000001H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3o
ool00`000000oooo0000000200000540oooo00<000000:Vmj02Y_NP0T`2Y_NP3000001/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000005D0oooo00<00000
0:Vmj02Y_NP0T02Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vm
j02Y_NP0S02Y_NP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04P3oool001<0oooo00<0omnL04P0M02oool02P3oool2000005H0ooooR@2Y_NP2000002L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d
0;ooo`0<0?ooo`030000003oool0oooo05@0ooooQ@2Y_NP2000002/0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003o
ool0oooo05@0ooooP02Y_NP200000300oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0ooooN`2Y_NP3
000003<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3o
gi`0B01d0;ooo`0?0?ooo`030000003oool0oooo05@0ooooM`2Y_NP3000003L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`004@3oool01@2oM000001809boW01807@0_ooo
0100oooo0P00001E0?ooog80ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?ooo`1C0?oo
ofh0ZKgX0`0000100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool001<0
oooo00<0omnL04P0M02oool04`3oool00`000000oooo0?ooo`1C0?ooofT0ZKgX100000130?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool002X0oooo00<000000?ooo`3oool0
D`3ooomU0:Vmj0<00000B03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo
000[0?ooo`800000E03ooomP0:Vmj0040?ooo`0000000000000004`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`1B0?oooe`0ZKgX1000
001?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002h0oooo00<00000
0?ooo`3oool0DP3ooomH0:Vmj0<00000E03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0140oooo000_0?ooo`030000003oool0oooo0580ooooD`2Y_NP0103oool0000000000000001H
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00300oooo00<000000?oo
o`3oool0DP3ooom?0:Vmj0@00000G03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo000a0?ooo`800000D`3ooom:0:Vmj0040?ooo`000000000000000600oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`1A0?ooodH0
ZKgX1000001T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool003@0oooo
00<000000?ooo`3oool0D@3ooom20:Vmj0<00000J@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo000e0?ooo`030000003oool0oooo0540oooo?@2Y_NP0103oool000000000
0000001/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003H0oooo0P00
001B0?ooocT0ZKgX1000001`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool003P0oooo00<000000?ooo`3oool0D03ooole0:Vmj0<00000M@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0100oooo000i0?ooo`030000003oool0oooo0540oooo;`2Y_NP0103o
ool0000000000000001i0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
03X0oooo00<000000?ooo`3oool0D@3oool[0:Vmj0@00000O03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0100oooo000k0?ooo`030000003oool0oooo0540oooo9`2Y_NP300000840
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`00?03oool200000580oooo
8P2Y_NP0103oool000000000000000250?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool003h0oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo0500oooo6P2Y
_NP3000008d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00@03oool0
0`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<0
0000V@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00140?ooo`030000
003oool0oooo0500oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`800000YP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00190?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
001;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03@3oool004l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00540oooo0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo0:`0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001F
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0000000?
0?ooo`00E`3oool2000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo0000000>0?oo
o`00F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00
FP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00F`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00G03oool2
000003X0oooo00<000000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0WP3oool300000200oooo001R0?ooo`800000=03oool00`000000oooo0?ooo`2J
0?ooo`@000008`3oool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F0?oo
o`@000009`3oool006D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?ooo`@0
0000:`3oool006H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`@00000
;`3oool006L0oooo0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?ooo`00J@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00JP3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo100000120?ooo`00K@3oool2000002T0oooo00<0
00000?ooo`3oool0M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0M@3oool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0L@3oool4000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool400000540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`@00000
E@3oool007@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?ooo`@00000F@3o
ool007D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<00000G@3oool0
07H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000H03oool007L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo
0P00000M0?ooo`030000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<000000?ooo`3o
ool0A`3oool4000007L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
@`3oool4000007/0oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3o
ool4000007l0oooo00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool4
000008<0oooo00220?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo0P00000=0?oo
o`030000003oool0oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01h0oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01X0oooo1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3oool05P3oool4
00000:T0oooo002?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool40000
0:d0oooo002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool300000;40
oooo002A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000;@0oooo
002B0?ooo`050000003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?ooo`80000000<0
oooo0000003oool0103oool400000;`0oooo002E0?ooo`80000000<0oooo0000000000000P000030
0?ooo`00UP3oool200000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o
0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54049 .59388 .53425 Mtetra
.59388 .53425 .59961 .54049 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53138 Mtetra
.5769 .53138 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52402 .62206 .51766 Mtetra
.62206 .51766 .62773 .52402 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53138 .57106 .52507 Mtetra
.57106 .52507 .5769 .53138 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52217 Mtetra
.55394 .52217 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52217 .54798 .51579 Mtetra
.54798 .51579 .55394 .52217 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48098 Mtetra
.63368 .48098 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48098 .62789 .47429 Mtetra
.62789 .47429 .63368 .48098 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.664 .741 .908 r
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46134 Mtetra
.58676 .46134 .59276 .46811 .60443 .46444 .59847 .45764 Mtetra
.59847 .45764 .60443 .46444 .61616 .46076 .61023 .45393 Mtetra
.61023 .45393 .61616 .46076 .62794 .45706 .62204 .4502 Mtetra
.62204 .4502 .62794 .45706 .63976 .45334 .6339 .44645 Mtetra
.6339 .44645 .63976 .45334 .65164 .44961 .64581 .44269 Mtetra
.64581 .44269 .65164 .44961 .66357 .44586 .65777 .43891 Mtetra
.664 .741 .907 r
.65777 .43891 .66357 .44586 .67555 .4421 .66979 .43511 Mtetra
.66979 .43511 .67555 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46925 Mtetra
.664 .741 .908 r
.53423 .46925 .54041 .47596 .55192 .47233 .54578 .46559 Mtetra
.663 .741 .908 r
.54578 .46559 .55192 .47233 .56349 .46868 .55738 .46192 Mtetra
.55738 .46192 .56349 .46868 .5751 .46501 .56902 .45824 Mtetra
.663 .742 .909 r
.56902 .45824 .5751 .46501 .58676 .46134 .58072 .45456 Mtetra
.663 .743 .909 r
.58072 .45456 .58676 .46134 .59847 .45764 .59246 .45086 Mtetra
.663 .743 .91 r
.59246 .45086 .59847 .45764 .61023 .45393 .60426 .44713 Mtetra
.664 .744 .91 r
.60426 .44713 .61023 .45393 .62204 .4502 .6161 .44337 Mtetra
.664 .744 .909 r
.6161 .44337 .62204 .4502 .6339 .44645 .628 .43958 Mtetra
.665 .744 .909 r
.628 .43958 .6339 .44645 .64581 .44269 .63994 .43576 Mtetra
.665 .743 .909 r
.63994 .43576 .64581 .44269 .65777 .43891 .65193 .43193 Mtetra
.665 .742 .908 r
.65193 .43193 .65777 .43891 .66979 .43511 .66398 .42809 Mtetra
.664 .742 .908 r
.66398 .42809 .66979 .43511 .68185 .4313 .67608 .42423 Mtetra
.664 .741 .908 r
.67608 .42423 .68185 .4313 .69396 .42747 .68823 .42037 Mtetra
.664 .741 .907 r
.68823 .42037 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46615 Mtetra
.663 .741 .908 r
.51648 .46615 .52273 .47289 .53423 .46925 .52801 .46249 Mtetra
.662 .741 .909 r
.52801 .46249 .53423 .46925 .54578 .46559 .53959 .45885 Mtetra
.661 .742 .91 r
.53959 .45885 .54578 .46559 .55738 .46192 .55122 .45523 Mtetra
.66 .744 .912 r
.55122 .45523 .55738 .46192 .56902 .45824 .5629 .45163 Mtetra
.659 .747 .915 r
.5629 .45163 .56902 .45824 .58072 .45456 .57463 .44804 Mtetra
.659 .751 .918 r
.57463 .44804 .58072 .45456 .59246 .45086 .58641 .44441 Mtetra
.661 .755 .92 r
.58641 .44441 .59246 .45086 .60426 .44713 .59825 .44071 Mtetra
.663 .757 .92 r
.59825 .44071 .60426 .44713 .6161 .44337 .61013 .43693 Mtetra
.666 .758 .919 r
.61013 .43693 .6161 .44337 .628 .43958 .62205 .43304 Mtetra
.668 .757 .917 r
.62205 .43304 .628 .43958 .63994 .43576 .63403 .42909 Mtetra
.668 .754 .914 r
.63403 .42909 .63994 .43576 .65193 .43193 .64606 .42511 Mtetra
.668 .75 .912 r
.64606 .42511 .65193 .43193 .66398 .42809 .65814 .42113 Mtetra
.667 .746 .91 r
.65814 .42113 .66398 .42809 .67608 .42423 .67027 .41717 Mtetra
.665 .744 .908 r
.67027 .41717 .67608 .42423 .68823 .42037 .68245 .41324 Mtetra
.665 .742 .908 r
.68245 .41324 .68823 .42037 .70043 .41649 .69469 .40931 Mtetra
.664 .741 .907 r
.69469 .40931 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .46671 Mtetra
.663 .741 .908 r
.4872 .46671 .49357 .47345 .505 .4698 .49867 .46305 Mtetra
.662 .741 .908 r
.49867 .46305 .505 .4698 .51648 .46615 .51018 .45941 Mtetra
.66 .741 .91 r
.51018 .45941 .51648 .46615 .52801 .46249 .52175 .45583 Mtetra
.656 .743 .914 r
.52175 .45583 .52801 .46249 .53959 .45885 .53336 .45235 Mtetra
.65 .748 .921 r
.53336 .45235 .53959 .45885 .55122 .45523 .54502 .449 Mtetra
.645 .756 .93 r
.54502 .449 .55122 .45523 .5629 .45163 .55674 .44576 Mtetra
.642 .768 .94 r
.55674 .44576 .5629 .45163 .57463 .44804 .56851 .44253 Mtetra
.642 .782 .948 r
.56851 .44253 .57463 .44804 .58641 .44441 .58034 .4392 Mtetra
.648 .795 .953 r
.58034 .4392 .58641 .44441 .59825 .44071 .59221 .43566 Mtetra
.657 .805 .954 r
.59221 .43566 .59825 .44071 .61013 .43693 .60413 .43184 Mtetra
.667 .808 .95 r
.60413 .43184 .61013 .43693 .62205 .43304 .6161 .42775 Mtetra
.676 .803 .943 r
.6161 .42775 .62205 .43304 .63403 .42909 .62811 .42344 Mtetra
.68 .793 .935 r
.62811 .42344 .63403 .42909 .64606 .42511 .64016 .41903 Mtetra
.68 .779 .926 r
.64016 .41903 .64606 .42511 .65814 .42113 .65226 .41464 Mtetra
.676 .766 .918 r
.65226 .41464 .65814 .42113 .67027 .41717 .66442 .41035 Mtetra
.672 .755 .913 r
.66442 .41035 .67027 .41717 .68245 .41324 .67663 .40618 Mtetra
.668 .747 .91 r
.67663 .40618 .68245 .41324 .69469 .40931 .6889 .40212 Mtetra
.666 .743 .908 r
.6889 .40212 .69469 .40931 .70698 .40538 .70123 .39812 Mtetra
.664 .742 .908 r
.70123 .39812 .70698 .40538 .71933 .40144 .71361 .39413 Mtetra
.664 .741 .907 r
.71361 .39413 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .4636 Mtetra
.663 .741 .908 r
.46934 .4636 .47579 .47036 .4872 .46671 .48079 .45994 Mtetra
.661 .741 .909 r
.48079 .45994 .4872 .46671 .49867 .46305 .49229 .45631 Mtetra
.656 .741 .912 r
.49229 .45631 .49867 .46305 .51018 .45941 .50383 .45282 Mtetra
.647 .744 .92 r
.50383 .45282 .51018 .45941 .52175 .45583 .51543 .44958 Mtetra
.632 .751 .934 r
.51543 .44958 .52175 .45583 .53336 .45235 .52707 .44669 Mtetra
.612 .766 .953 r
.52707 .44669 .53336 .45235 .54502 .449 .53878 .44411 Mtetra
.593 .789 .974 r
.53878 .44411 .54502 .449 .55674 .44576 .55054 .44168 Mtetra
.58 .817 .989 r
.55054 .44168 .55674 .44576 .56851 .44253 .56237 .43913 Mtetra
.578 .843 .995 r
.56237 .43913 .56851 .44253 .58034 .4392 .57424 .43625 Mtetra
.589 .865 .994 r
.57424 .43625 .58034 .4392 .59221 .43566 .58617 .43291 Mtetra
.611 .881 .991 r
.58617 .43291 .59221 .43566 .60413 .43184 .59814 .42907 Mtetra
.64 .889 .985 r
.59814 .42907 .60413 .43184 .6161 .42775 .61015 .42472 Mtetra
.668 .888 .978 r
.61015 .42472 .6161 .42775 .62811 .42344 .6222 .41991 Mtetra
.691 .876 .967 r
.6222 .41991 .62811 .42344 .64016 .41903 .63428 .41476 Mtetra
.703 .852 .954 r
.63428 .41476 .64016 .41903 .65226 .41464 .64639 .40949 Mtetra
.701 .82 .939 r
.64639 .40949 .65226 .41464 .66442 .41035 .65856 .40436 Mtetra
.691 .79 .926 r
.65856 .40436 .66442 .41035 .67663 .40618 .67079 .39955 Mtetra
.679 .766 .916 r
.67079 .39955 .67663 .40618 .6889 .40212 .68308 .39508 Mtetra
.671 .752 .911 r
.68308 .39508 .6889 .40212 .70123 .39812 .69543 .39087 Mtetra
.667 .745 .909 r
.69543 .39087 .70123 .39812 .71361 .39413 .70785 .38678 Mtetra
.665 .742 .908 r
.70785 .38678 .71361 .39413 .72605 .39014 .72032 .38274 Mtetra
.664 .741 .907 r
.72032 .38274 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46048 Mtetra
.663 .741 .908 r
.45142 .46048 .45794 .46727 .46934 .4636 .46285 .4568 Mtetra
.661 .741 .909 r
.46285 .4568 .46934 .4636 .48079 .45994 .47433 .45319 Mtetra
.653 .741 .914 r
.47433 .45319 .48079 .45994 .49229 .45631 .48586 .44977 Mtetra
.637 .743 .925 r
.48586 .44977 .49229 .45631 .50383 .45282 .49743 .44678 Mtetra
.607 .75 .946 r
.49743 .44678 .50383 .45282 .51543 .44958 .50905 .44442 Mtetra
.563 .768 .974 r
.50905 .44442 .51543 .44958 .52707 .44669 .52073 .44264 Mtetra
.515 .793 .996 r
.52073 .44264 .52707 .44669 .53878 .44411 .53248 .44109 Mtetra
.491 .823 .999 r
.53248 .44109 .53878 .44411 .55054 .44168 .54429 .43921 Mtetra
.512 .853 .995 r
.54429 .43921 .55054 .44168 .56237 .43913 .55616 .43666 Mtetra
.562 .873 .994 r
.55616 .43666 .56237 .43913 .57424 .43625 .56809 .43342 Mtetra
.603 .875 .992 r
.56809 .43342 .57424 .43625 .58617 .43291 .58006 .42976 Mtetra
.623 .871 .989 r
.58006 .42976 .58617 .43291 .59814 .42907 .59208 .42589 Mtetra
.634 .874 .986 r
.59208 .42589 .59814 .42907 .61015 .42472 .60415 .42182 Mtetra
.648 .889 .984 r
.60415 .42182 .61015 .42472 .6222 .41991 .61625 .41731 Mtetra
.673 .907 .976 r
.61625 .41731 .6222 .41991 .63428 .41476 .62839 .41212 Mtetra
.705 .914 .967 r
.62839 .41212 .63428 .41476 .64639 .40949 .64054 .40623 Mtetra
.727 .897 .956 r
.64054 .40623 .64639 .40949 .65856 .40436 .65272 .40001 Mtetra
.726 .858 .944 r
.65272 .40001 .65856 .40436 .67079 .39955 .66494 .39401 Mtetra
.708 .812 .93 r
.66494 .39401 .67079 .39955 .68308 .39508 .67724 .38859 Mtetra
.688 .776 .918 r
.67724 .38859 .68308 .39508 .69543 .39087 .68961 .38381 Mtetra
.674 .755 .912 r
.68961 .38381 .69543 .39087 .70785 .38678 .70205 .37945 Mtetra
.667 .745 .909 r
.70205 .37945 .70785 .38678 .72032 .38274 .71455 .37529 Mtetra
.665 .742 .908 r
.71455 .37529 .72032 .38274 .73285 .37869 .72712 .3712 Mtetra
.664 .741 .907 r
.72712 .3712 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.663 .741 .908 r
.43343 .45734 .44004 .46416 .45142 .46048 .44485 .45365 Mtetra
.661 .74 .909 r
.44485 .45365 .45142 .46048 .46285 .4568 .45631 .45001 Mtetra
.653 .74 .914 r
.45631 .45001 .46285 .4568 .47433 .45319 .46781 .4466 Mtetra
.631 .74 .927 r
.46781 .4466 .47433 .45319 .48586 .44977 .47936 .44375 Mtetra
.586 .745 .952 r
.47936 .44375 .48586 .44977 .49743 .44678 .49096 .4418 Mtetra
.515 .757 .984 r
.49096 .4418 .49743 .44678 .50905 .44442 .50261 .44071 Mtetra
.452 .781 .998 r
.50261 .44071 .50905 .44442 .52073 .44264 .51433 .43975 Mtetra
.489 .828 .998 r
.51433 .43975 .52073 .44264 .53248 .44109 .52612 .4378 Mtetra
.622 .862 .988 r
.52612 .4378 .53248 .44109 .54429 .43921 .53797 .4341 Mtetra
.706 .817 .934 r
.53797 .4341 .54429 .43921 .55616 .43666 .54986 .42893 Mtetra
.711 .739 .873 r
.54986 .42893 .55616 .43666 .56809 .43342 .56178 .42324 Mtetra
.685 .675 .834 r
.56178 .42324 .56809 .43342 .58006 .42976 .57375 .41812 Mtetra
.652 .635 .82 r
.57375 .41812 .58006 .42976 .59208 .42589 .58579 .41421 Mtetra
.624 .622 .829 r
.58579 .41421 .59208 .42589 .60415 .42182 .59791 .41153 Mtetra
.609 .643 .859 r
.59791 .41153 .60415 .42182 .61625 .41731 .6101 .40942 Mtetra
.62 .707 .908 r
.6101 .40942 .61625 .41731 .62839 .41212 .62235 .4068 Mtetra
.662 .806 .952 r
.62235 .4068 .62839 .41212 .64054 .40623 .63461 .40269 Mtetra
.714 .886 .96 r
.63461 .40269 .64054 .40623 .65272 .40001 .64686 .39683 Mtetra
.747 .905 .947 r
.64686 .39683 .65272 .40001 .66494 .39401 .65911 .38994 Mtetra
.747 .875 .938 r
.65911 .38994 .66494 .39401 .67724 .38859 .67139 .38317 Mtetra
.721 .823 .928 r
.67139 .38317 .67724 .38859 .68961 .38381 .68376 .37727 Mtetra
.693 .779 .917 r
.68376 .37727 .68961 .38381 .70205 .37945 .69621 .37228 Mtetra
.674 .754 .911 r
.69621 .37228 .70205 .37945 .71455 .37529 .70874 .36785 Mtetra
.667 .744 .908 r
.70874 .36785 .71455 .37529 .72712 .3712 .72134 .36365 Mtetra
.665 .742 .907 r
.72134 .36365 .72712 .3712 .73974 .3671 .734 .35951 Mtetra
.664 .741 .907 r
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45048 Mtetra
.662 .74 .908 r
.42678 .45048 .43343 .45734 .44485 .45365 .43822 .4468 Mtetra
.655 .74 .912 r
.43822 .4468 .44485 .45365 .45631 .45001 .44971 .44331 Mtetra
.633 .738 .924 r
.44971 .44331 .45631 .45001 .46781 .4466 .46123 .4404 Mtetra
.581 .738 .95 r
.46123 .4404 .46781 .4466 .47936 .44375 .4728 .43859 Mtetra
.49 .741 .983 r
.4728 .43859 .47936 .44375 .49096 .4418 .48441 .43794 Mtetra
.426 .763 .996 r
.48441 .43794 .49096 .4418 .50261 .44071 .4961 .43737 Mtetra
.553 .837 .998 r
.4961 .43737 .50261 .44071 .51433 .43975 .50786 .43483 Mtetra
.733 .827 .923 r
.50786 .43483 .51433 .43975 .52612 .4378 .5197 .42877 Mtetra
.766 .723 .813 r
.5197 .42877 .52612 .4378 .53797 .4341 .53156 .41956 Mtetra
.696 .616 .763 r
.53156 .41956 .53797 .4341 .54986 .42893 .54345 .4123 Mtetra
.636 .564 .757 r
.54345 .4123 .54986 .42893 .56178 .42324 .55539 .40839 Mtetra
.641 .586 .777 r
.55539 .40839 .56178 .42324 .57375 .41812 .56739 .40447 Mtetra
.646 .603 .792 r
.56739 .40447 .57375 .41812 .58579 .41421 .57944 .40053 Mtetra
.57944 .40053 .58579 .41421 .59791 .41153 .59154 .39657 Mtetra
.641 .586 .777 r
.59154 .39657 .59791 .41153 .6101 .40942 .60369 .39259 Mtetra
.574 .53 .768 r
.60369 .39259 .6101 .40942 .62235 .4068 .616 .39199 Mtetra
.524 .526 .799 r
.616 .39199 .62235 .4068 .63461 .40269 .62844 .39337 Mtetra
.595 .662 .885 r
.62844 .39337 .63461 .40269 .64686 .39683 .64087 .39158 Mtetra
.703 .824 .94 r
.64087 .39158 .64686 .39683 .65911 .38994 .65323 .38624 Mtetra
.763 .892 .935 r
.65323 .38624 .65911 .38994 .67139 .38317 .66555 .37889 Mtetra
.761 .872 .929 r
.66555 .37889 .67139 .38317 .68376 .37727 .6779 .37161 Mtetra
.726 .819 .923 r
.6779 .37161 .68376 .37727 .69621 .37228 .69034 .3655 Mtetra
.691 .774 .915 r
.69034 .3655 .69621 .37228 .70874 .36785 .70289 .3605 Mtetra
.672 .751 .91 r
.70289 .3605 .70874 .36785 .72134 .36365 .71552 .35608 Mtetra
.666 .743 .908 r
.71552 .35608 .72134 .36365 .734 .35951 .72822 .35186 Mtetra
.664 .741 .907 r
.72822 .35186 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40864 .44731 Mtetra
.663 .741 .908 r
.40864 .44731 .41538 .4542 .42678 .45048 .42007 .44358 Mtetra
.658 .74 .91 r
.42007 .44358 .42678 .45048 .43822 .4468 .43154 .43997 Mtetra
.642 .738 .919 r
.43154 .43997 .43822 .4468 .44971 .44331 .44305 .43682 Mtetra
.593 .734 .942 r
.44305 .43682 .44971 .44331 .46123 .4404 .45459 .43479 Mtetra
.494 .727 .976 r
.45459 .43479 .46123 .4404 .4728 .43859 .46616 .43426 Mtetra
.411 .739 .992 r
.46616 .43426 .4728 .43859 .48441 .43794 .4778 .43413 Mtetra
.576 .828 .993 r
.4778 .43413 .48441 .43794 .4961 .43737 .48954 .43146 Mtetra
.776 .8 .872 r
.48954 .43146 .4961 .43737 .50786 .43483 .50139 .42335 Mtetra
.76 .68 .774 r
.50139 .42335 .50786 .43483 .5197 .42877 .51326 .4129 Mtetra
.638 .573 .765 r
.51326 .4129 .5197 .42877 .53156 .41956 .52513 .409 Mtetra
.656 .657 .839 r
.52513 .409 .53156 .41956 .54345 .4123 .53706 .40507 Mtetra
.664 .741 .907 r
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .616 .39199 .60972 .38118 Mtetra
.656 .657 .839 r
.60972 .38118 .616 .39199 .62844 .39337 .62202 .37713 Mtetra
.499 .495 .783 r
.62202 .37713 .62844 .39337 .64087 .39158 .6346 .3797 Mtetra
.541 .583 .846 r
.6346 .3797 .64087 .39158 .65323 .38624 .64719 .37992 Mtetra
.7 .79 .92 r
.64719 .37992 .65323 .38624 .66555 .37889 .65965 .37465 Mtetra
.776 .877 .921 r
.65965 .37465 .66555 .37889 .6779 .37161 .67203 .36678 Mtetra
.764 .857 .919 r
.67203 .36678 .6779 .37161 .69034 .3655 .68446 .35931 Mtetra
.719 .803 .917 r
.68446 .35931 .69034 .3655 .70289 .3605 .697 .35335 Mtetra
.684 .763 .911 r
.697 .35335 .70289 .3605 .71552 .35608 .70965 .34853 Mtetra
.669 .746 .908 r
.70965 .34853 .71552 .35608 .72822 .35186 .72238 .34417 Mtetra
.665 .742 .908 r
.72238 .34417 .72822 .35186 .74097 .34768 .73518 .33993 Mtetra
.664 .741 .907 r
.73518 .33993 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29235 Mtetra
.27897 .48098 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.663 .741 .907 r
.39045 .44413 .39727 .45105 .40864 .44731 .40185 .44037 Mtetra
.662 .74 .908 r
.40185 .44037 .40864 .44731 .42007 .44358 .41331 .43665 Mtetra
.652 .739 .913 r
.41331 .43665 .42007 .44358 .43154 .43997 .4248 .43321 Mtetra
.618 .734 .929 r
.4248 .43321 .43154 .43997 .44305 .43682 .43633 .43064 Mtetra
.529 .722 .961 r
.43633 .43064 .44305 .43682 .45459 .43479 .44787 .42974 Mtetra
.41 .712 .985 r
.44787 .42974 .45459 .43479 .46616 .43426 .45946 .43003 Mtetra
.526 .794 .994 r
.45946 .43003 .46616 .43426 .4778 .43413 .47116 .42831 Mtetra
.779 .803 .872 r
.47116 .42831 .4778 .43413 .48954 .43146 .48301 .42006 Mtetra
.761 .682 .775 r
.48301 .42006 .48954 .43146 .50139 .42335 .4949 .4096 Mtetra
.645 .601 .791 r
.4949 .4096 .50139 .42335 .51326 .4129 .50676 .40568 Mtetra
.664 .741 .907 r
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .6346 .3797 .62822 .36553 Mtetra
.484 .515 .814 r
.62822 .36553 .6346 .3797 .64719 .37992 .6409 .36806 Mtetra
.536 .583 .849 r
.6409 .36806 .64719 .37992 .65965 .37465 .65361 .36836 Mtetra
.728 .801 .91 r
.65361 .36836 .65965 .37465 .67203 .36678 .66611 .36205 Mtetra
.786 .864 .907 r
.66611 .36205 .67203 .36678 .68446 .35931 .67855 .35368 Mtetra
.753 .831 .912 r
.67855 .35368 .68446 .35931 .697 .35335 .69108 .34651 Mtetra
.703 .78 .912 r
.69108 .34651 .697 .35335 .70965 .34853 .70374 .34103 Mtetra
.675 .752 .909 r
.70374 .34103 .70965 .34853 .72238 .34417 .7165 .33643 Mtetra
.666 .743 .908 r
.7165 .33643 .72238 .34417 .73518 .33993 .72933 .33212 Mtetra
.664 .741 .907 r
.72933 .33212 .73518 .33993 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29235 .87448 .28412 Mtetra
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.663 .741 .908 r
.38357 .43715 .39045 .44413 .40185 .44037 .39501 .43338 Mtetra
.659 .74 .91 r
.39501 .43338 .40185 .44037 .41331 .43665 .40649 .42971 Mtetra
.641 .737 .918 r
.40649 .42971 .41331 .43665 .4248 .43321 .41801 .42654 Mtetra
.581 .726 .942 r
.41801 .42654 .4248 .43321 .43633 .43064 .42954 .42475 Mtetra
.454 .702 .973 r
.42954 .42475 .43633 .43064 .44787 .42974 .44108 .42487 Mtetra
.431 .73 .989 r
.44108 .42487 .44787 .42974 .45946 .43003 .45271 .42475 Mtetra
.725 .814 .92 r
.45271 .42475 .45946 .43003 .47116 .42831 .46452 .41893 Mtetra
.803 .725 .778 r
.46452 .41893 .47116 .42831 .48301 .42006 .47647 .40628 Mtetra
.644 .601 .791 r
.47647 .40628 .48301 .42006 .4949 .4096 .48831 .40235 Mtetra
.664 .741 .907 r
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .6409 .36806 .63449 .35377 Mtetra
.413 .474 .813 r
.63449 .35377 .6409 .36806 .65361 .36836 .64737 .35846 Mtetra
.605 .66 .877 r
.64737 .35846 .65361 .36836 .66611 .36205 .66008 .35625 Mtetra
.772 .829 .897 r
.66008 .35625 .66611 .36205 .67855 .35368 .6726 .34823 Mtetra
.78 .843 .9 r
.6726 .34823 .67855 .35368 .69108 .34651 .68513 .33995 Mtetra
.726 .798 .908 r
.68513 .33995 .69108 .34651 .70374 .34103 .69779 .33361 Mtetra
.684 .76 .909 r
.69779 .33361 .70374 .34103 .7165 .33643 .71057 .32867 Mtetra
.668 .745 .908 r
.71057 .32867 .7165 .33643 .72933 .33212 .72344 .32424 Mtetra
.665 .741 .907 r
.72344 .32424 .72933 .33212 .74223 .32784 .73638 .31992 Mtetra
.664 .741 .907 r
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43013 Mtetra
.663 .741 .908 r
.37664 .43013 .38357 .43715 .39501 .43338 .38811 .42634 Mtetra
.655 .739 .911 r
.38811 .42634 .39501 .43338 .40649 .42971 .39962 .42274 Mtetra
.626 .733 .924 r
.39962 .42274 .40649 .42971 .41801 .42654 .41115 .41993 Mtetra
.537 .713 .953 r
.41115 .41993 .41801 .42654 .42954 .42475 .42268 .41896 Mtetra
.405 .684 .975 r
.42268 .41896 .42954 .42475 .44108 .42487 .43424 .41964 Mtetra
.563 .773 .977 r
.43424 .41964 .44108 .42487 .45271 .42475 .44594 .4177 Mtetra
.814 .773 .815 r
.44594 .4177 .45271 .42475 .46452 .41893 .4579 .40634 Mtetra
.709 .647 .786 r
.4579 .40634 .46452 .41893 .47647 .40628 .46979 .39901 Mtetra
.664 .741 .907 r
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.535 .688 .937 r
.62828 .34607 .63449 .35377 .64737 .35846 .64098 .3453 Mtetra
.442 .511 .834 r
.64098 .3453 .64737 .35846 .66008 .35625 .65393 .34864 Mtetra
.718 .764 .889 r
.65393 .34864 .66008 .35625 .6726 .34823 .66657 .34241 Mtetra
.79 .834 .886 r
.66657 .34241 .6726 .34823 .68513 .33995 .67913 .3335 Mtetra
.749 .808 .9 r
.67913 .3335 .68513 .33995 .69779 .33361 .69179 .32626 Mtetra
.696 .767 .907 r
.69179 .32626 .69779 .33361 .71057 .32867 .7046 .32089 Mtetra
.672 .747 .907 r
.7046 .32089 .71057 .32867 .72344 .32424 .7175 .31631 Mtetra
.665 .742 .907 r
.7175 .31631 .72344 .32424 .73638 .31992 .73048 .31194 Mtetra
.664 .741 .907 r
.73048 .31194 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43013 .36966 .42305 Mtetra
.662 .74 .908 r
.36966 .42305 .37664 .43013 .38811 .42634 .38116 .41925 Mtetra
.651 .738 .913 r
.38116 .41925 .38811 .42634 .39962 .42274 .39269 .41574 Mtetra
.61 .728 .929 r
.39269 .41574 .39962 .42274 .41115 .41993 .40424 .4133 Mtetra
.496 .697 .959 r
.40424 .4133 .41115 .41993 .42268 .41896 .41577 .41301 Mtetra
.408 .682 .974 r
.41577 .41301 .42268 .41896 .43424 .41964 .42735 .41369 Mtetra
.684 .786 .928 r
.42735 .41369 .43424 .41964 .44594 .4177 .43915 .40912 Mtetra
.819 .743 .779 r
.43915 .40912 .44594 .4177 .4579 .40634 .45121 .39565 Mtetra
.655 .657 .84 r
.45121 .39565 .4579 .40634 .46979 .39901 .46306 .39167 Mtetra
.664 .741 .907 r
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64098 .3453 .63462 .33406 Mtetra
.314 .476 .861 r
.63462 .33406 .64098 .3453 .65393 .34864 .64767 .33946 Mtetra
.643 .698 .886 r
.64767 .33946 .65393 .34864 .66657 .34241 .66046 .33585 Mtetra
.785 .813 .874 r
.66046 .33585 .66657 .34241 .67913 .3335 .67307 .32687 Mtetra
.765 .809 .888 r
.67307 .32687 .67913 .3335 .69179 .32626 .68574 .31887 Mtetra
.707 .772 .903 r
.68574 .31887 .69179 .32626 .7046 .32089 .69857 .31305 Mtetra
.675 .749 .907 r
.69857 .31305 .7046 .32089 .7175 .31631 .71151 .30832 Mtetra
.666 .742 .907 r
.71151 .30832 .7175 .31631 .73048 .31194 .72453 .30388 Mtetra
.664 .741 .907 r
.72453 .30388 .73048 .31194 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .27201 .84444 .26361 Mtetra
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45019 Mtetra
.26104 .45019 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.663 .741 .908 r
.35114 .41977 .35821 .42688 .36966 .42305 .36262 .41591 Mtetra
.661 .74 .909 r
.36262 .41591 .36966 .42305 .38116 .41925 .37415 .4121 Mtetra
.648 .737 .914 r
.37415 .4121 .38116 .41925 .39269 .41574 .38571 .40867 Mtetra
.597 .723 .933 r
.38571 .40867 .39269 .41574 .40424 .4133 .39727 .40652 Mtetra
.469 .682 .959 r
.39727 .40652 .40424 .4133 .41577 .41301 .40881 .40669 Mtetra
.444 .688 .969 r
.40881 .40669 .41577 .41301 .42735 .41369 .42043 .40702 Mtetra
.747 .778 .878 r
.42043 .40702 .42735 .41369 .43915 .40912 .43234 .39997 Mtetra
.796 .73 .791 r
.43234 .39997 .43915 .40912 .45121 .39565 .44439 .38829 Mtetra
.664 .741 .907 r
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.295 .56 .928 r
.62834 .32619 .63462 .33406 .64767 .33946 .64133 .32971 Mtetra
.565 .651 .893 r
.64133 .32971 .64767 .33946 .66046 .33585 .65426 .32854 Mtetra
.773 .791 .868 r
.65426 .32854 .66046 .33585 .67307 .32687 .66693 .31986 Mtetra
.773 .801 .876 r
.66693 .31986 .67307 .32687 .68574 .31887 .67964 .31132 Mtetra
.716 .772 .897 r
.67964 .31132 .68574 .31887 .69857 .31305 .69249 .30514 Mtetra
.678 .75 .905 r
.69249 .30514 .69857 .31305 .71151 .30832 .70547 .30026 Mtetra
.666 .743 .907 r
.70547 .30026 .71151 .30832 .72453 .30388 .71852 .29576 Mtetra
.664 .741 .907 r
.71852 .29576 .72453 .30388 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45019 .25368 .44326 Mtetra
.25368 .44326 .26104 .45019 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.663 .741 .908 r
.34401 .4126 .35114 .41977 .36262 .41591 .35552 .40871 Mtetra
.661 .74 .909 r
.35552 .40871 .36262 .41591 .37415 .4121 .36708 .40489 Mtetra
.646 .736 .915 r
.36708 .40489 .37415 .4121 .38571 .40867 .37867 .40149 Mtetra
.589 .719 .933 r
.37867 .40149 .38571 .40867 .39727 .40652 .39025 .3995 Mtetra
.459 .671 .955 r
.39025 .3995 .39727 .40652 .40881 .40669 .40181 .39987 Mtetra
.477 .687 .959 r
.40181 .39987 .40881 .40669 .42043 .40702 .41346 .39987 Mtetra
.772 .771 .852 r
.41346 .39987 .42043 .40702 .43234 .39997 .42545 .39135 Mtetra
.787 .74 .81 r
.42545 .39135 .43234 .39997 .44439 .38829 .43752 .38087 Mtetra
.664 .741 .907 r
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.374 .605 .938 r
.622 .31826 .62834 .32619 .64133 .32971 .63498 .32049 Mtetra
.503 .636 .913 r
.63498 .32049 .64133 .32971 .65426 .32854 .64799 .32075 Mtetra
.764 .778 .865 r
.64799 .32075 .65426 .32854 .66693 .31986 .66073 .31233 Mtetra
.773 .788 .865 r
.66073 .31233 .66693 .31986 .67964 .31132 .67347 .30351 Mtetra
.719 .768 .891 r
.67347 .30351 .67964 .31132 .69249 .30514 .68636 .2971 Mtetra
.68 .749 .903 r
.68636 .2971 .69249 .30514 .70547 .30026 .69937 .29212 Mtetra
.667 .742 .907 r
.69937 .29212 .70547 .30026 .71852 .29576 .71247 .28757 Mtetra
.664 .741 .907 r
.71247 .28757 .71852 .29576 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .2466 Mtetra
.83317 .2466 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.663 .741 .908 r
.33683 .40538 .34401 .4126 .35552 .40871 .34837 .40145 Mtetra
.661 .74 .909 r
.34837 .40145 .35552 .40871 .36708 .40489 .35996 .3976 Mtetra
.646 .735 .914 r
.35996 .3976 .36708 .40489 .37867 .40149 .37158 .39417 Mtetra
.59 .717 .932 r
.37158 .39417 .37867 .40149 .39025 .3995 .38318 .39215 Mtetra
.466 .666 .949 r
.38318 .39215 .39025 .3995 .40181 .39987 .39476 .3925 Mtetra
.488 .676 .948 r
.39476 .3925 .40181 .39987 .41346 .39987 .40644 .39247 Mtetra
.77 .766 .849 r
.40644 .39247 .41346 .39987 .42545 .39135 .41847 .38391 Mtetra
.799 .769 .825 r
.41847 .38391 .42545 .39135 .43752 .38087 .43059 .37339 Mtetra
.664 .741 .907 r
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.374 .605 .938 r
.61561 .31026 .622 .31826 .63498 .32049 .62862 .31246 Mtetra
.482 .662 .941 r
.62862 .31246 .63498 .32049 .64799 .32075 .64166 .31269 Mtetra
.762 .773 .862 r
.64166 .31269 .64799 .32075 .66073 .31233 .65444 .30423 Mtetra
.769 .774 .857 r
.65444 .30423 .66073 .31233 .67347 .30351 .66724 .29537 Mtetra
.718 .76 .886 r
.66724 .29537 .67347 .30351 .68636 .2971 .68017 .28891 Mtetra
.68 .747 .902 r
.68017 .28891 .68636 .2971 .69937 .29212 .69323 .2839 Mtetra
.667 .742 .906 r
.69323 .2839 .69937 .29212 .71247 .28757 .70636 .27931 Mtetra
.664 .741 .907 r
.70636 .27931 .71247 .28757 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .2466 .82746 .23798 Mtetra
.82746 .23798 .83317 .2466 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40205 Mtetra
.31807 .40205 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.663 .741 .908 r
.32959 .39809 .33683 .40538 .34837 .40145 .34116 .39414 Mtetra
.661 .74 .908 r
.34116 .39414 .34837 .40145 .35996 .3976 .35278 .39024 Mtetra
.648 .736 .913 r
.35278 .39024 .35996 .3976 .37158 .39417 .36443 .38671 Mtetra
.598 .717 .928 r
.36443 .38671 .37158 .39417 .38318 .39215 .37607 .38448 Mtetra
.485 .666 .943 r
.37607 .38448 .38318 .39215 .39476 .3925 .38768 .38457 Mtetra
.481 .657 .938 r
.38768 .38457 .39476 .3925 .40644 .39247 .39937 .38482 Mtetra
.742 .756 .864 r
.39937 .38482 .40644 .39247 .41847 .38391 .4114 .37766 Mtetra
.828 .799 .825 r
.4114 .37766 .41847 .38391 .43059 .37339 .4236 .36584 Mtetra
.664 .741 .907 r
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.295 .56 .928 r
.60917 .30219 .61561 .31026 .62862 .31246 .62224 .30564 Mtetra
.531 .727 .964 r
.62224 .30564 .62862 .31246 .64166 .31269 .63527 .30437 Mtetra
.766 .769 .855 r
.63527 .30437 .64166 .31269 .65444 .30423 .64809 .29556 Mtetra
.761 .76 .852 r
.64809 .29556 .65444 .30423 .66724 .29537 .66094 .28689 Mtetra
.712 .751 .883 r
.66094 .28689 .66724 .29537 .68017 .28891 .67392 .28058 Mtetra
.678 .744 .901 r
.67392 .28058 .68017 .28891 .69323 .2839 .68702 .27558 Mtetra
.666 .741 .906 r
.68702 .27558 .69323 .2839 .70636 .27931 .70021 .27097 Mtetra
.664 .741 .907 r
.70021 .27097 .70636 .27931 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40205 .31074 .39474 Mtetra
.31074 .39474 .31807 .40205 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39414 .33389 .38676 Mtetra
.662 .74 .908 r
.33389 .38676 .34116 .39414 .35278 .39024 .34554 .3828 Mtetra
.651 .737 .912 r
.34554 .3828 .35278 .39024 .36443 .38671 .35723 .37914 Mtetra
.612 .721 .923 r
.35723 .37914 .36443 .38671 .37607 .38448 .36892 .37655 Mtetra
.515 .673 .935 r
.36892 .37655 .37607 .38448 .38768 .38457 .38057 .37614 Mtetra
.471 .639 .929 r
.38057 .37614 .38768 .38457 .39937 .38482 .39226 .37669 Mtetra
.681 .731 .888 r
.39226 .37669 .39937 .38482 .4114 .37766 .40423 .37195 Mtetra
.853 .811 .808 r
.40423 .37195 .4114 .37766 .4236 .36584 .41656 .35824 Mtetra
.664 .741 .907 r
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.168 .481 .898 r
.60267 .29405 .60917 .30219 .62224 .30564 .61582 .29935 Mtetra
.635 .789 .956 r
.61582 .29935 .62224 .30564 .63527 .30437 .62881 .29555 Mtetra
.768 .759 .845 r
.62881 .29555 .63527 .30437 .64809 .29556 .64166 .28635 Mtetra
.748 .746 .85 r
.64166 .28635 .64809 .29556 .66094 .28689 .65458 .27813 Mtetra
.703 .743 .882 r
.65458 .27813 .66094 .28689 .67392 .28058 .66762 .27212 Mtetra
.675 .741 .901 r
.66762 .27212 .67392 .28058 .68702 .27558 .68077 .26719 Mtetra
.666 .741 .906 r
.68077 .26719 .68702 .27558 .70021 .27097 .694 .26256 Mtetra
.664 .741 .907 r
.694 .26256 .70021 .27097 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39474 .30335 .38737 Mtetra
.30335 .38737 .31074 .39474 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38676 .32657 .37932 Mtetra
.663 .74 .908 r
.32657 .37932 .33389 .38676 .34554 .3828 .33825 .37531 Mtetra
.655 .738 .91 r
.33825 .37531 .34554 .3828 .35723 .37914 .34997 .3715 Mtetra
.627 .725 .918 r
.34997 .3715 .35723 .37914 .36892 .37655 .36171 .36847 Mtetra
.552 .686 .928 r
.36171 .36847 .36892 .37655 .38057 .37614 .37341 .36731 Mtetra
.478 .632 .922 r
.37341 .36731 .38057 .37614 .39226 .37669 .38512 .36782 Mtetra
.596 .684 .903 r
.38512 .36782 .39226 .37669 .40423 .37195 .39702 .36568 Mtetra
.826 .802 .829 r
.39702 .36568 .40423 .37195 .41656 .35824 .40934 .35399 Mtetra
.769 .864 .919 r
.40934 .35399 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.664 .741 .907 r
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.535 .688 .937 r
.58327 .2903 .58987 .29847 .60267 .29405 .5962 .28931 Mtetra
.109 .562 .915 r
.5962 .28931 .60267 .29405 .61582 .29935 .60933 .29248 Mtetra
.724 .8 .912 r
.60933 .29248 .61582 .29935 .62881 .29555 .62228 .28598 Mtetra
.762 .742 .835 r
.62228 .28598 .62881 .29555 .64166 .28635 .63517 .27675 Mtetra
.731 .733 .852 r
.63517 .27675 .64166 .28635 .65458 .27813 .64816 .26921 Mtetra
.692 .737 .885 r
.64816 .26921 .65458 .27813 .66762 .27212 .66126 .26357 Mtetra
.671 .74 .902 r
.66126 .26357 .66762 .27212 .68077 .26719 .67446 .25873 Mtetra
.665 .741 .906 r
.67446 .25873 .68077 .26719 .694 .26256 .68773 .25408 Mtetra
.664 .741 .907 r
.68773 .25408 .694 .26256 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37932 .31918 .37182 Mtetra
.663 .74 .908 r
.31918 .37182 .32657 .37932 .33825 .37531 .33089 .36776 Mtetra
.659 .739 .909 r
.33089 .36776 .33825 .37531 .34997 .3715 .34265 .36381 Mtetra
.641 .73 .913 r
.34265 .36381 .34997 .3715 .36171 .36847 .35444 .36036 Mtetra
.589 .701 .921 r
.35444 .36036 .36171 .36847 .37341 .36731 .36621 .35831 Mtetra
.509 .644 .917 r
.36621 .35831 .37341 .36731 .38512 .36782 .37796 .35821 Mtetra
.527 .637 .902 r
.37796 .35821 .38512 .36782 .39702 .36568 .38981 .35786 Mtetra
.717 .752 .88 r
.38981 .35786 .39702 .36568 .40934 .35399 .40196 .3517 Mtetra
.877 .905 .846 r
.40196 .3517 .40934 .35399 .42151 .34639 .41439 .33862 Mtetra
.664 .741 .907 r
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.216 .513 .912 r
.57663 .28206 .58327 .2903 .5962 .28931 .5897 .28655 Mtetra
.463 .839 .988 r
.5897 .28655 .5962 .28931 .60933 .29248 .60273 .28404 Mtetra
.757 .767 .862 r
.60273 .28404 .60933 .29248 .62228 .28598 .61567 .27563 Mtetra
.746 .723 .831 r
.61567 .27563 .62228 .28598 .63517 .27675 .62863 .26696 Mtetra
.712 .724 .859 r
.62863 .26696 .63517 .27675 .64816 .26921 .64169 .26025 Mtetra
.682 .734 .89 r
.64169 .26025 .64816 .26921 .66126 .26357 .65485 .25496 Mtetra
.668 .739 .903 r
.65485 .25496 .66126 .26357 .67446 .25873 .6681 .25019 Mtetra
.665 .74 .907 r
.6681 .25019 .67446 .25873 .68773 .25408 .68141 .24552 Mtetra
.664 .741 .907 r
.68141 .24552 .68773 .25408 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36837 Mtetra
.30004 .36837 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.663 .741 .907 r
.31173 .36426 .31918 .37182 .33089 .36776 .32348 .36016 Mtetra
.662 .74 .908 r
.32348 .36016 .33089 .36776 .34265 .36381 .33528 .35609 Mtetra
.652 .735 .91 r
.33528 .35609 .34265 .36381 .35444 .36036 .34711 .35231 Mtetra
.62 .716 .914 r
.34711 .35231 .35444 .36036 .36621 .35831 .35895 .34941 Mtetra
.556 .669 .913 r
.35895 .34941 .36621 .35831 .37796 .35821 .37077 .34821 Mtetra
.513 .622 .897 r
.37077 .34821 .37796 .35821 .38981 .35786 .38261 .34822 Mtetra
.591 .667 .891 r
.38261 .34822 .38981 .35786 .40196 .3517 .39462 .34617 Mtetra
.786 .828 .885 r
.39462 .34617 .40196 .3517 .41439 .33862 .40695 .33748 Mtetra
.844 .952 .886 r
.40695 .33748 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.664 .741 .907 r
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.359 .599 .938 r
.55705 .27826 .5638 .28653 .57663 .28206 .57002 .28051 Mtetra
.141 .674 .861 r
.57002 .28051 .57663 .28206 .5897 .28655 .58306 .2805 Mtetra
.731 .829 .925 r
.58306 .2805 .5897 .28655 .60273 .28404 .59604 .27374 Mtetra
.749 .726 .83 r
.59604 .27374 .60273 .28404 .61567 .27563 .60901 .26489 Mtetra
.724 .709 .836 r
.60901 .26489 .61567 .27563 .62863 .26696 .62204 .25726 Mtetra
.694 .721 .87 r
.62204 .25726 .62863 .26696 .64169 .26025 .63517 .25134 Mtetra
.674 .734 .895 r
.63517 .25134 .64169 .26025 .65485 .25496 .64839 .24633 Mtetra
.666 .739 .905 r
.64839 .24633 .65485 .25496 .6681 .25019 .66168 .24159 Mtetra
.664 .741 .907 r
.66168 .24159 .6681 .25019 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18882 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36837 .2925 .36078 Mtetra
.2925 .36078 .30004 .36837 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36016 .316 .3525 Mtetra
.663 .74 .908 r
.316 .3525 .32348 .36016 .33528 .35609 .32783 .34836 Mtetra
.658 .738 .908 r
.32783 .34836 .33528 .35609 .34711 .35231 .33971 .34434 Mtetra
.642 .727 .91 r
.33971 .34434 .34711 .35231 .35895 .34941 .35161 .34078 Mtetra
.602 .696 .91 r
.35161 .34078 .35895 .34941 .37077 .34821 .36352 .33837 Mtetra
.547 .644 .897 r
.36352 .33837 .37077 .34821 .38261 .34822 .37541 .33749 Mtetra
.536 .619 .881 r
.37541 .33749 .38261 .34822 .39462 .34617 .38737 .33702 Mtetra
.624 .694 .894 r
.38737 .33702 .39462 .34617 .40695 .33748 .39952 .33394 Mtetra
.793 .892 .915 r
.39952 .33394 .40695 .33748 .41938 .32652 .41193 .3253 Mtetra
.844 .952 .886 r
.41193 .3253 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.664 .741 .907 r
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.357 .598 .938 r
.53741 .27444 .54425 .28274 .55705 .27826 .55031 .27668 Mtetra
.156 .684 .868 r
.55031 .27668 .55705 .27826 .57002 .28051 .56329 .27653 Mtetra
.688 .887 .971 r
.56329 .27653 .57002 .28051 .58306 .2805 .57629 .27076 Mtetra
.746 .737 .843 r
.57629 .27076 .58306 .2805 .59604 .27374 .58928 .26233 Mtetra
.726 .698 .824 r
.58928 .26233 .59604 .27374 .60901 .26489 .6023 .25431 Mtetra
.702 .706 .851 r
.6023 .25431 .60901 .26489 .62204 .25726 .61541 .24783 Mtetra
.68 .724 .883 r
.61541 .24783 .62204 .25726 .63517 .25134 .6286 .2425 Mtetra
.669 .736 .9 r
.6286 .2425 .63517 .25134 .64839 .24633 .64187 .23765 Mtetra
.665 .74 .906 r
.64187 .23765 .64839 .24633 .66168 .24159 .65521 .23292 Mtetra
.664 .741 .907 r
.65521 .23292 .66168 .24159 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18882 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .3525 .30846 .34478 Mtetra
.30846 .34478 .316 .3525 .32783 .34836 .32033 .34058 Mtetra
.662 .74 .908 r
.32033 .34058 .32783 .34836 .33971 .34434 .33224 .33642 Mtetra
.655 .735 .908 r
.33224 .33642 .33971 .34434 .35161 .34078 .3442 .33246 Mtetra
.634 .718 .908 r
.3442 .33246 .35161 .34078 .36352 .33837 .35618 .32908 Mtetra
.596 .679 .9 r
.35618 .32908 .36352 .33837 .37541 .33749 .36816 .32683 Mtetra
.556 .631 .881 r
.36816 .32683 .37541 .33749 .38737 .33702 .38016 .32577 Mtetra
.556 .619 .87 r
.38016 .32577 .38737 .33702 .39952 .33394 .39224 .32479 Mtetra
.62 .696 .898 r
.39224 .32479 .39952 .33394 .41193 .3253 .40447 .32178 Mtetra
.731 .893 .953 r
.40447 .32178 .41193 .3253 .42444 .31427 .41689 .31517 Mtetra
.77 .993 .879 r
.41689 .31517 .42444 .31427 .43676 .30992 .42945 .30531 Mtetra
.769 .864 .919 r
.42945 .30531 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.664 .741 .907 r
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.532 .688 .939 r
.50492 .27513 .5119 .28343 .52462 .27895 .51767 .27409 Mtetra
.29 .68 .974 r
.51767 .27409 .52462 .27895 .53741 .27444 .53052 .27507 Mtetra
.175 .711 .759 r
.53052 .27507 .53741 .27444 .55031 .27668 .54346 .2728 Mtetra
.692 .89 .97 r
.54346 .2728 .55031 .27668 .56329 .27653 .55644 .26688 Mtetra
.738 .737 .85 r
.55644 .26688 .56329 .27653 .57629 .27076 .56943 .2589 Mtetra
.721 .689 .819 r
.56943 .2589 .57629 .27076 .58928 .26233 .58247 .25099 Mtetra
.702 .692 .837 r
.58247 .25099 .58928 .26233 .6023 .25431 .59556 .24428 Mtetra
.684 .713 .87 r
.59556 .24428 .6023 .25431 .61541 .24783 .60873 .2387 Mtetra
.671 .73 .894 r
.60873 .2387 .61541 .24783 .6286 .2425 .62198 .23372 Mtetra
.666 .738 .904 r
.62198 .23372 .6286 .2425 .64187 .23765 .63529 .22893 Mtetra
.664 .74 .907 r
.63529 .22893 .64187 .23765 .65521 .23292 .64867 .22418 Mtetra
.664 .741 .907 r
.64867 .22418 .65521 .23292 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34058 .31276 .33276 Mtetra
.663 .74 .907 r
.31276 .33276 .32033 .34058 .33224 .33642 .32471 .32852 Mtetra
.661 .738 .907 r
.32471 .32852 .33224 .33642 .3442 .33246 .33671 .32433 Mtetra
.653 .731 .907 r
.33671 .32433 .3442 .33246 .35618 .32908 .34875 .32038 Mtetra
.633 .71 .902 r
.34875 .32038 .35618 .32908 .36816 .32683 .36082 .317 Mtetra
.602 .671 .889 r
.36082 .317 .36816 .32683 .38016 .32577 .3729 .31455 Mtetra
.574 .629 .868 r
.3729 .31455 .38016 .32577 .39224 .32479 .38501 .31298 Mtetra
.571 .616 .859 r
.38501 .31298 .39224 .32479 .40447 .32178 .3972 .31154 Mtetra
.602 .664 .883 r
.3972 .31154 .40447 .32178 .41689 .31517 .4095 .30906 Mtetra
.655 .798 .951 r
.4095 .30906 .41689 .31517 .42945 .30531 .42193 .3048 Mtetra
.606 .942 .942 r
.42193 .3048 .42945 .30531 .44197 .29745 .43447 .299 Mtetra
.509 .912 .834 r
.43447 .299 .44197 .29745 .45445 .29303 .44706 .29268 Mtetra
.587 .938 .933 r
.44706 .29268 .45445 .29303 .46698 .28858 .45969 .28693 Mtetra
.563 .908 .972 r
.45969 .28693 .46698 .28858 .47956 .28412 .47234 .28244 Mtetra
.465 .865 .965 r
.47234 .28244 .47956 .28412 .49221 .27964 .48503 .2792 Mtetra
.316 .802 .879 r
.48503 .2792 .49221 .27964 .50492 .27513 .49779 .27654 Mtetra
.202 .726 .725 r
.49779 .27654 .50492 .27513 .51767 .27409 .51063 .27336 Mtetra
.514 .906 .935 r
.51063 .27336 .51767 .27409 .53052 .27507 .52354 .26864 Mtetra
.723 .816 .923 r
.52354 .26864 .53052 .27507 .54346 .2728 .5365 .26211 Mtetra
.723 .711 .839 r
.5365 .26211 .54346 .2728 .55644 .26688 .5495 .25452 Mtetra
.709 .677 .816 r
.5495 .25452 .55644 .26688 .56943 .2589 .56254 .24706 Mtetra
.696 .681 .831 r
.56254 .24706 .56943 .2589 .58247 .25099 .57563 .24048 Mtetra
.683 .702 .862 r
.57563 .24048 .58247 .25099 .59556 .24428 .58878 .23483 Mtetra
.672 .724 .888 r
.58878 .23483 .59556 .24428 .60873 .2387 .60201 .22976 Mtetra
.666 .735 .902 r
.60201 .22976 .60873 .2387 .62198 .23372 .6153 .22493 Mtetra
.664 .74 .906 r
.6153 .22493 .62198 .23372 .63529 .22893 .62866 .22015 Mtetra
.664 .741 .907 r
.62866 .22015 .63529 .22893 .64867 .22418 .64209 .21536 Mtetra
.64209 .21536 .64867 .22418 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .32852 .31711 .32059 Mtetra
.663 .74 .907 r
.31711 .32059 .32471 .32852 .33671 .32433 .32915 .3163 Mtetra
.66 .737 .907 r
.32915 .3163 .33671 .32433 .34875 .32038 .34123 .31207 Mtetra
.653 .729 .905 r
.34123 .31207 .34875 .32038 .36082 .317 .35336 .30804 Mtetra
.638 .708 .897 r
.35336 .30804 .36082 .317 .3729 .31455 .36553 .30445 Mtetra
.617 .674 .882 r
.36553 .30445 .3729 .31455 .38501 .31298 .37773 .3015 Mtetra
.597 .637 .861 r
.37773 .3015 .38501 .31298 .3972 .31154 .38996 .29916 Mtetra
.59 .617 .847 r
.38996 .29916 .3972 .31154 .4095 .30906 .40226 .29704 Mtetra
.6 .629 .852 r
.40226 .29704 .4095 .30906 .42193 .3048 .41465 .29459 Mtetra
.621 .677 .881 r
.41465 .29459 .42193 .3048 .43447 .299 .42713 .29143 Mtetra
.642 .753 .929 r
.42713 .29143 .43447 .299 .44706 .29268 .4397 .28756 Mtetra
.645 .832 .972 r
.4397 .28756 .44706 .29268 .45969 .28693 .45235 .28325 Mtetra
.631 .876 .987 r
.45235 .28325 .45969 .28693 .47234 .28244 .46506 .27872 Mtetra
.641 .879 .985 r
.46506 .27872 .47234 .28244 .48503 .2792 .47783 .27397 Mtetra
.679 .841 .961 r
.47783 .27397 .48503 .2792 .49779 .27654 .49066 .26877 Mtetra
.703 .772 .906 r
.49066 .26877 .49779 .27654 .51063 .27336 .50356 .26287 Mtetra
.706 .709 .85 r
.50356 .26287 .51063 .27336 .52354 .26864 .5165 .25624 Mtetra
.7 .672 .819 r
.5165 .25624 .52354 .26864 .5365 .26211 .52949 .24926 Mtetra
.693 .663 .816 r
.52949 .24926 .5365 .26211 .5495 .25452 .54253 .2425 Mtetra
.686 .674 .833 r
.54253 .2425 .5495 .25452 .56254 .24706 .55561 .23635 Mtetra
.678 .697 .861 r
.55561 .23635 .56254 .24706 .57563 .24048 .56875 .23084 Mtetra
.671 .72 .885 r
.56875 .23084 .57563 .24048 .58878 .23483 .58196 .22577 Mtetra
.666 .733 .9 r
.58196 .22577 .58878 .23483 .60201 .22976 .59523 .22091 Mtetra
.665 .739 .905 r
.59523 .22091 .60201 .22976 .6153 .22493 .60857 .2161 Mtetra
.664 .74 .907 r
.60857 .2161 .6153 .22493 .62866 .22015 .62197 .21129 Mtetra
.664 .741 .907 r
.62197 .21129 .62866 .22015 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32059 .30945 .3126 Mtetra
.30945 .3126 .31711 .32059 .32915 .3163 .32152 .30825 Mtetra
.663 .74 .907 r
.32152 .30825 .32915 .3163 .34123 .31207 .33364 .30391 Mtetra
.661 .737 .906 r
.33364 .30391 .34123 .31207 .35336 .30804 .34582 .2996 Mtetra
.656 .729 .903 r
.34582 .2996 .35336 .30804 .36553 .30445 .35805 .29543 Mtetra
.647 .712 .895 r
.35805 .29543 .36553 .30445 .37773 .3015 .37032 .29151 Mtetra
.634 .685 .881 r
.37032 .29151 .37773 .3015 .38996 .29916 .38263 .28794 Mtetra
.622 .655 .861 r
.38263 .28794 .38996 .29916 .40226 .29704 .39499 .2847 Mtetra
.616 .632 .843 r
.39499 .2847 .40226 .29704 .41465 .29459 .40742 .28161 Mtetra
.618 .622 .833 r
.40742 .28161 .41465 .29459 .42713 .29143 .41992 .27839 Mtetra
.626 .626 .83 r
.41992 .27839 .42713 .29143 .4397 .28756 .43249 .27482 Mtetra
.638 .637 .833 r
.43249 .27482 .4397 .28756 .45235 .28325 .44515 .27077 Mtetra
.651 .648 .834 r
.44515 .27077 .45235 .28325 .46506 .27872 .45788 .2662 Mtetra
.662 .653 .83 r
.45788 .2662 .46506 .27872 .47783 .27397 .47068 .2611 Mtetra
.671 .651 .822 r
.47068 .2611 .47783 .27397 .49066 .26877 .48354 .25552 Mtetra
.675 .648 .815 r
.48354 .25552 .49066 .26877 .50356 .26287 .49646 .24958 Mtetra
.678 .649 .814 r
.49646 .24958 .50356 .26287 .5165 .25624 .50942 .24351 Mtetra
.678 .659 .824 r
.50942 .24351 .5165 .25624 .52949 .24926 .52244 .23758 Mtetra
.676 .677 .844 r
.52244 .23758 .52949 .24926 .54253 .2425 .53551 .23198 Mtetra
.673 .7 .867 r
.53551 .23198 .54253 .2425 .55561 .23635 .54864 .22673 Mtetra
.669 .72 .887 r
.54864 .22673 .55561 .23635 .56875 .23084 .56183 .22173 Mtetra
.666 .732 .899 r
.56183 .22173 .56875 .23084 .58196 .22577 .57508 .21686 Mtetra
.664 .738 .905 r
.57508 .21686 .58196 .22577 .59523 .22091 .58839 .21204 Mtetra
.664 .74 .907 r
.58839 .21204 .59523 .22091 .60857 .2161 .60178 .20721 Mtetra
.664 .741 .907 r
.60178 .20721 .60857 .2161 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30391 .32598 .29576 Mtetra
.663 .74 .907 r
.32598 .29576 .33364 .30391 .34582 .2996 .3382 .29134 Mtetra
.662 .738 .906 r
.3382 .29134 .34582 .2996 .35805 .29543 .35047 .28695 Mtetra
.659 .732 .903 r
.35047 .28695 .35805 .29543 .37032 .29151 .36279 .28261 Mtetra
.655 .721 .897 r
.36279 .28261 .37032 .29151 .38263 .28794 .37517 .27837 Mtetra
.649 .704 .886 r
.37517 .27837 .38263 .28794 .39499 .2847 .38759 .27426 Mtetra
.644 .683 .872 r
.38759 .27426 .39499 .2847 .40742 .28161 .40008 .27026 Mtetra
.641 .663 .856 r
.40008 .27026 .40742 .28161 .41992 .27839 .41262 .26627 Mtetra
.641 .65 .843 r
.41262 .26627 .41992 .27839 .43249 .27482 .42524 .26217 Mtetra
.644 .642 .834 r
.42524 .26217 .43249 .27482 .44515 .27077 .43792 .25784 Mtetra
.65 .641 .828 r
.43792 .25784 .44515 .27077 .45788 .2662 .45067 .25322 Mtetra
.655 .643 .826 r
.45067 .25322 .45788 .2662 .47068 .2611 .46348 .24832 Mtetra
.661 .65 .828 r
.46348 .24832 .47068 .2611 .48354 .25552 .47636 .24318 Mtetra
.665 .66 .835 r
.47636 .24318 .48354 .25552 .49646 .24958 .4893 .23793 Mtetra
.668 .674 .847 r
.4893 .23793 .49646 .24958 .50942 .24351 .50229 .2327 Mtetra
.669 .692 .863 r
.50229 .2327 .50942 .24351 .52244 .23758 .51534 .22756 Mtetra
.668 .71 .88 r
.51534 .22756 .52244 .23758 .53551 .23198 .52844 .22255 Mtetra
.666 .725 .893 r
.52844 .22255 .53551 .23198 .54864 .22673 .54161 .21765 Mtetra
.665 .734 .901 r
.54161 .21765 .54864 .22673 .56183 .22173 .55484 .2128 Mtetra
.664 .738 .905 r
.55484 .2128 .56183 .22173 .57508 .21686 .56814 .20796 Mtetra
.664 .74 .907 r
.56814 .20796 .57508 .21686 .58839 .21204 .5815 .20311 Mtetra
.664 .741 .907 r
.5815 .20311 .58839 .21204 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29576 .31826 .28756 Mtetra
.31826 .28756 .32598 .29576 .3382 .29134 .33051 .28309 Mtetra
.664 .74 .907 r
.33051 .28309 .3382 .29134 .35047 .28695 .34281 .27861 Mtetra
.663 .739 .906 r
.34281 .27861 .35047 .28695 .36279 .28261 .35518 .27413 Mtetra
.662 .736 .905 r
.35518 .27413 .36279 .28261 .37517 .27837 .3676 .26965 Mtetra
.66 .73 .901 r
.3676 .26965 .37517 .27837 .38759 .27426 .38007 .26519 Mtetra
.659 .722 .895 r
.38007 .26519 .38759 .27426 .40008 .27026 .39261 .26075 Mtetra
.657 .711 .888 r
.39261 .26075 .40008 .27026 .41262 .26627 .4052 .25631 Mtetra
.657 .702 .88 r
.4052 .25631 .41262 .26627 .42524 .26217 .41785 .25183 Mtetra
.657 .694 .873 r
.41785 .25183 .42524 .26217 .43792 .25784 .43057 .24727 Mtetra
.659 .691 .869 r
.43057 .24727 .43792 .25784 .45067 .25322 .44335 .24261 Mtetra
.661 .692 .868 r
.44335 .24261 .45067 .25322 .46348 .24832 .45619 .23785 Mtetra
.663 .696 .871 r
.45619 .23785 .46348 .24832 .47636 .24318 .4691 .23301 Mtetra
.664 .705 .877 r
.4691 .23301 .47636 .24318 .4893 .23793 .48206 .22814 Mtetra
.665 .714 .885 r
.48206 .22814 .4893 .23793 .50229 .2327 .49508 .22326 Mtetra
.665 .724 .893 r
.49508 .22326 .50229 .2327 .51534 .22756 .50817 .21839 Mtetra
.665 .731 .899 r
.50817 .21839 .51534 .22756 .52844 .22255 .52132 .21355 Mtetra
.664 .736 .904 r
.52132 .21355 .52844 .22255 .54161 .21765 .53453 .20871 Mtetra
.664 .739 .906 r
.53453 .20871 .54161 .21765 .55484 .2128 .5478 .20386 Mtetra
.664 .74 .907 r
.5478 .20386 .55484 .2128 .56814 .20796 .56114 .19899 Mtetra
.664 .741 .907 r
.56114 .19899 .56814 .20796 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .27861 .33509 .27026 Mtetra
.33509 .27026 .34281 .27861 .35518 .27413 .34749 .26572 Mtetra
.664 .74 .907 r
.34749 .26572 .35518 .27413 .3676 .26965 .35995 .26116 Mtetra
.663 .739 .906 r
.35995 .26116 .3676 .26965 .38007 .26519 .37246 .25658 Mtetra
.663 .737 .905 r
.37246 .25658 .38007 .26519 .39261 .26075 .38504 .25199 Mtetra
.663 .734 .902 r
.38504 .25199 .39261 .26075 .4052 .25631 .39767 .24739 Mtetra
.662 .73 .9 r
.39767 .24739 .4052 .25631 .41785 .25183 .41037 .24276 Mtetra
.662 .728 .898 r
.41037 .24276 .41785 .25183 .43057 .24727 .42312 .23809 Mtetra
.663 .726 .896 r
.42312 .23809 .43057 .24727 .44335 .24261 .43594 .23339 Mtetra
.43594 .23339 .44335 .24261 .45619 .23785 .44881 .22866 Mtetra
.664 .728 .897 r
.44881 .22866 .45619 .23785 .4691 .23301 .46175 .22389 Mtetra
.664 .731 .899 r
.46175 .22389 .4691 .23301 .48206 .22814 .47475 .21909 Mtetra
.664 .734 .902 r
.47475 .21909 .48206 .22814 .49508 .22326 .48781 .21428 Mtetra
.664 .737 .904 r
.48781 .21428 .49508 .22326 .50817 .21839 .50094 .20945 Mtetra
.664 .739 .906 r
.50094 .20945 .50817 .21839 .52132 .21355 .51413 .20461 Mtetra
.664 .74 .907 r
.51413 .20461 .52132 .21355 .53453 .20871 .52738 .19974 Mtetra
.664 .741 .907 r
.52738 .19974 .53453 .20871 .5478 .20386 .54069 .19486 Mtetra
.54069 .19486 .5478 .20386 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26572 .33974 .25726 Mtetra
.33974 .25726 .34749 .26572 .35995 .26116 .35223 .25265 Mtetra
.664 .74 .907 r
.35223 .25265 .35995 .26116 .37246 .25658 .36478 .24803 Mtetra
.36478 .24803 .37246 .25658 .38504 .25199 .37739 .24338 Mtetra
.37739 .24338 .38504 .25199 .39767 .24739 .39007 .23871 Mtetra
.664 .739 .906 r
.39007 .23871 .39767 .24739 .41037 .24276 .4028 .23401 Mtetra
.664 .738 .906 r
.4028 .23401 .41037 .24276 .42312 .23809 .41559 .2293 Mtetra
.664 .738 .905 r
.41559 .2293 .42312 .23809 .43594 .23339 .42844 .22456 Mtetra
.42844 .22456 .43594 .23339 .44881 .22866 .44136 .21979 Mtetra
.664 .739 .906 r
.44136 .21979 .44881 .22866 .46175 .22389 .45434 .215 Mtetra
.45434 .215 .46175 .22389 .47475 .21909 .46737 .21019 Mtetra
.664 .74 .906 r
.46737 .21019 .47475 .21909 .48781 .21428 .48048 .20535 Mtetra
.664 .74 .907 r
.48048 .20535 .48781 .21428 .50094 .20945 .49364 .20049 Mtetra
.49364 .20049 .50094 .20945 .51413 .20461 .50687 .19561 Mtetra
.664 .741 .907 r
.50687 .19561 .51413 .20461 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24803 .35703 .23942 Mtetra
.35703 .23942 .36478 .24803 .37739 .24338 .36968 .23472 Mtetra
.36968 .23472 .37739 .24338 .39007 .23871 .38239 .23001 Mtetra
.38239 .23001 .39007 .23871 .4028 .23401 .39516 .22527 Mtetra
.664 .74 .907 r
.39516 .22527 .4028 .23401 .41559 .2293 .40799 .22051 Mtetra
.40799 .22051 .41559 .2293 .42844 .22456 .42088 .21573 Mtetra
.42088 .21573 .42844 .22456 .44136 .21979 .43384 .21092 Mtetra
.43384 .21092 .44136 .21979 .45434 .215 .44685 .20609 Mtetra
.664 .741 .907 r
.44685 .20609 .45434 .215 .46737 .21019 .45993 .20124 Mtetra
.45993 .20124 .46737 .21019 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21647 Mtetra
.38745 .21647 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20684 Mtetra
.41325 .20684 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21647 .37968 .20758 Mtetra
.37968 .20758 .38745 .21647 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20684 .40556 .19786 Mtetra
.40556 .19786 .41325 .20684 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12594 Mtetra
.43285 .12594 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14232 Mtetra
.3579 .14232 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12594 .42493 .11623 Mtetra
.42493 .11623 .43285 .12594 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25832 .16854 Mtetra
.25832 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00002G0:Vmj0030000002Y_NP0
ZKgX0200ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000VP2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0V@2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000
W`2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000I`2Y
_NP30:Vmi`L0ZKgX0`2Y_NL]0:Vmj0030000002Y_NP0ZKgX02<0ZKgX00<000000?ooo`3oool0@@3o
ool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo02T0oooo0P00
001N0:Vmj0D0ZKgW1@2Y_NP60:Vmi`@0ZKgX1P2Y_NL20:Vmj0<0ZKcW9`2Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX05T0ZKgX202Y_NL50:Vl
i`D0ZKgW1@2Y_>L50:Vmi`H0ZKcW9P2Y_NP00`000000ZKgX0:Vmj00T0:Vmj0030000003oool0oooo
00X0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo0280oooo00<0ZKgX000000000000G`2Y_NP80:Vmi`<0
ZK_V1@2Y_>L20:Vmi`<0Z[_V1@2Y_>L50:ZkiPX0ZKcW8P2Y_NP00`000000ZKgX0:Vmj00T0:Vmj003
0000003oool0oooo00P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;la0?ooo`003@3oool00`3o
gi`0B00000000003000000030000M02oool0oooo00<0oooo00/0omnL04P0M02oool0oooo0?oOW00D
55l0a?oo0?ooo`3oohl0=@0D05o4o`0P0?ooo`<00000G@2Y_NP:0:Vmi`H0ZK_V102Y_>L60:ZkiP80
ZKcW0`2Z^N@50:ZkiP80ZKcW0`2Z^nH50:Vli`H0Z[gW6`2Y_NP00`000000ZKgX0:Vmj00T0:Vmj003
0000003oool0oooo00P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?oo
o`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Coo`3oool0oon?03D0501Oa?l07P3oool3000005/0
ZKgX1@2Y_>L50:Vmi`X0ZK_V1@2Z^N@50:ZkiPH0Z[WT2P2Z^nH20:Vli`<0Z[_V1P2Z_NL20:Vmj0<0
ZKgW5@2Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00L0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Co
o`3oool0oon?03D0501Oa?l06`3oool3000005`0ZKgX202Y_>L20:Vmi`<0ZK[U1@2Y^nH50:ZfhPD0
Z[WT1@2[]N450:Zii0D0ZkSS2`2Z^nH50:Zmi`H0ZKgW502Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo00H0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000G0?oo
o`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?oo
o`800000G@2Y_NP:0:Vli`H0ZK[U0P2Y^nH30:Vdh0D0Z[KR0P2Z^N@30:^ag0D0ZkGQ0P2Z^N@30:bc
g@D0ZkSS1@2[^>860:ZkiPD0Z[cV1@2Y_NLD0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?oo
o`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool001P0oooo00/0okmd
0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<00000F`2Y_NP:0:Vl
i`D0ZKWU1@2Y^^D60:Vdh0@0Z[KR1P2[/M`40:^eh@H0[;?M0P2[^><30:fbg0D0ZkSR0`2Z^nH30:bi
h`D0Z[cV1@2Z_>LC0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00<0omnL04P0M02oool00P3oool0
1@3oohl0=@000000000055l0a?oo01@0oooo0`0000000`2Y_NP000000:Vmj01I0:Vmj0<0ZKgW1`2Y
_>L80:Vii@D0ZK;N1@2Y]>050:^/f0D0Zk7L1@2][MP50:bcg@H0[K;L102[^>870:bih`80Z[cV0`2[
^^@50:Zli`D0Z[gW3@2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00@0oooo00H0
oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y_NP000000000001M0:Vmj0H0ZKgW
102Y_>L80:Vii@<0ZK7N1@2Y/]h20:Vdh0<0ZZSE1@2[[=P20:^ag0<0[JSB1@2][MP20:bcg@<0[jcE
1P2]/]`50:jcg0D0[;WS1P2[^^@20:Zli`<0ZkcV1@2Z_NL<0:Vmj0030000002Y_NP0ZKgX02P0ZKgX
00<000000?ooo`3oool01@3oool01@3ookl0M00000000000B9`0gooo0340oooo000b0?ooo`<00000
H02Y_NP50:Vmi`D0ZK[U1@2Y^ND50:VagPD0ZK;N1@2ZZ=D50:^/f0D0[JSB1@2][MP60:n/e@<0[K;L
0`2b[]@50:jcg0D0[kKN1@2[^^@60:^liP@0Z[gW302Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000
003oool0oooo03X0oooo000`0?ooo`80000000<0ZKgX0000002Y_NP0H@2Y_NP50:VjiPD0ZK[U1@2X
/=h50:VagP80ZK;N0`2YY]<50:ZXe@80ZjcH0`2]Y]050:fXdP80[JgH0`2aZM060:n/e@H0/ZkD0P2^
/m`30;>aePD0[kKN1@2^^N850:^liPD0Z[gW2P2Y_NP2000002`0ZKgX00<000000?ooo`3oool0>@3o
ool002`0oooo00@0ZKgX0000000000000000I@2Y_NP20:VkiPD0ZK[V0`2Y^^D20:Rag`D0Z;3N102Y
/Mh60:VVd`@0ZZSE1P2]Y]040:fXdPH0/JW@102_[=D20;F]d0D0/ZkD1P2c/MH20:nfgP<0/kCI1@2^
^N820:^liP<0[;_U1@2Z_NL50:Zmj0040:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0
:@2Y_NP00`000000oooo0?ooo`0i0?ooo`00:`3oool2000006H0ZKgX1@2Y^nH50:VjiPD0Z;7O1@2X
/=h40:NTd`H0ZJKC0P2ZZ=D20:bUd0H0[JK@0P2]Z=820;>/d@H0/JW@0P2_[=D30;F]d0@0/ZkD0P2h
/=450;>aePH0/kCI102^^N860:bki@80Z[gW0`2[_NL20:Zmj0<000001@2Y_NP00`000000ZKgX0:Vm
j00Z0:Vmj0030000003oool0oooo03P0oooo000Y0?ooo`800000I02Y_NP50:Vli`D0ZK_V1@2X/n45
0:Rag`80Z;3N0`2VY=<40:NTd`D0ZJKC1@2/YM050:fVd0D0/jcA1@2aZM060;F]d080/ZkD0`2h/=44
0;>aeP80^K;B1@2c]=T50;6hgPD0[;_U102[_NL3000000040:Zmj02Z_NL0Z[gW0:Zmi`D0ZKgX00<0
00000:Vmj02Y_NP0:P2Y_NP00`000000oooo0?ooo`0g0?ooo`007@3oool01@3ookl0M00000000000
B9`0gooo00L0oooo0P00001R0:Vmj0<0ZKgW1@2Y_>L50:Rfh`D0Z;?Q102X/Ml50:JTd`D0YjCC0P2Y
Y]<30:^VdPD0[:G@0P2]Y]030;Bef@D0/jcA0P2aZM030;VfePD0]Jg@1P2h/=420;>aeP<0^K;B102c
]=T20;VeePD0/KSN1@2^^n<00`2[_NL00000000000020:^mi`D0Z[gW1P2Y_NP00`000000ZKgX0:Vm
j00Y0:Vmj0030000003oool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo
1`3oool00`000000oooo0000001O0:Vmj0H0ZKgW0P2Y_>L30:Rhi@D0Z;KS102X/n450:BTe@D0YZCC
102WY=<50:^VdPD0[:G@1@2d]MT50;>/d@H0^KKF0P2e[M030;blf@D0^;3A1P2i/]820;>df@@0^KGF
0P2a^=h30;Jif`80[[_S0`0000050:^miP@0Z[gW1`2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0030000
003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`80
00000P3oool00`000000ZKgX0:Vmj01M0:Vmj0D0ZKgW1P2X^>D40:Rfh`D0Y:KG1@2TY=D40:JTd`D0
ZJOD1@2[Y]820:bUd0<0/lGW1@2d]MT20;>/d@<0^M3/1@2i]]H60;blf@80^;3A0`2n_=L50;VbdPH0
^KGF102f^M/3000000040:jkh`2a_>80/KcR0;6lhP@0ZkgV1@2Z_NL60:Vmj0030000002Y_NP0ZKgX
02X0ZKgX00<000000?ooo`3oool0=@3oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00D0oooo00<000000?ooo`3oool00P3oool00`000000ZKgX0:Vmj01M0:Vmj0D0Z;[V1@2X^>D5
0:BYf`@0Y:KG1@2TY=D50:JUe@D0ZJOD102[Y]860;?5i`@0];GI1P2id>`20;VfeP<0/N?h1@2l_=T6
0;jle`80^K;B0`2o^M@40;VeeP80_[WD0`0000020;Jif`D0/KcR0P2[_NH30:bmiPD0Z[gW1P2Y_NP0
0`000000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?noM000B9`0gooo
0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo00<0ooooG02Y_NP40:Vli`D0Z;[V0P2X
^>D30:B^g`@0Y:WK1@2TY]L20:BTe@<0Xj?E102VYMD50:VWe0D0[MOf1@2caNL508?Wk`D0^M3/1P2a
hoP20;blf@<0/>?h1@2n_=L60;nie080^KGF0`0000000`2n^M@0][WK0;Jif`030;^kfP@0/KcR1P2/
_NH40:Zmi`L0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0d0?ooo`00703oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<000000:Vmj02Y_NP0
EP2Y_NP30:Vmi`@0ZKcW102X^^H50:B^g`D0Y:WK102TY]L50:>Se@D0YZGE0P2YYm@30:CQo0D0[MOf
0P0c^KT508R`l0<0BZki1P0/]/840;7Sn0H0/>?h0P2n_=L30;_Dk0@0_kWD0`0000040;jie0D0^k_J
0P2a_>830;>nh@D0[;gV1@2Z_NL70:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0
<`3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000ZKgX0:Vmj01C0:Vmj0H0ZKgW102Y_>L40:JdhPD0Y:kO102TZM/50:2Pe0D0
Xj?E102VYMD60:CQo080D<gQ1@2Y_NP508R`l0D0ZKgX1@1KVO0402N_gP@0/>?h1P2ke>`300000080
`LCL102n^M@20<>me@@0^k_J1P2c_^450:fniPD0Z[gW1P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj003
0000003oool0oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`00
0000oooo0?ooo`070?oooeD0ZKgX1@2Y_NL50:Nhi@@0Y[CR102T[]l509jOe@@0X:3D1@2SXmD60:7P
o0@0Mmgg5`2Y_NP505^Il0<09:cL0P2ke>`3000000H0`LCL0P2n^M@40<>me@80^k_J0P2o_]T30;>n
h@<0]/3R1@2]_^H50:Zmi`H0ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0b0?oo
o`007@3oool01@3ookl0M00000000000B9`0gooo00H0oooo00<000000?ooo`3oool0203ooomE0:Vm
j0D0Z;_W1@2W^>D40:JdhP@0WJ7G102NWmD50:2Pe080Xj?E102Ue?P6093Xn1l0ZKgX0P0gPnT20000
00@0M]Kl1@31a=`60<>me@D0_kkI1P2f`>820:fniP<0[[oV1@2Z_NL60:Vmj0030000002Y_NP0ZKgX
02P0ZKgX00<000000?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool02P3ooomB0:Vmj0<0
ZKcW1@2X^nL40:Nhi@D0WjOL102MXML409jOe@@0X:3D102Ue?P409K`kR80ZKgX0`00000303N3j@@0
M]Kl0P31a=`30;W<j@@0`kgE0P34`]P30;nnf@80`/;J1@2f`>860:joiP@0Z[gW1P2Y_NP00`000000
ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0oooo
C`2Y_NP60:Vli`@0Z;_W1@2R[n4509nWg0@0WJ7G0`2NWmD60:C0k@<0U_3^8P2Y_NP3000000<0ZKgX
1028/>l301^?jPH0^LcY0P33_MD40<C2f0030;nnf@32`]X0`/;J0080`/;J0P2f`>830;O2hPD0[[oV
1@2Z_NP60:Vmj0030000002Y_NP0ZKgX02T0ZKgX00<000000?ooo`3oool0<03oool002L0oooo00<0
00000?ooo`3oool0303ooom@0:Vmj0@0ZKcW1@2U]^D50::_h@@0WjOL102MXML509j]h@<0Y<3]0P22
jMDQ0:Vmj0<000001`2Y_NP408R`k`<06hoZ1@2ic>T60<C2f0D0`/;J1P2g`^850:joi`D0Z[gX1P2Y
_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo0300oooo000W0?ooo`8000003P3ooom@
0:Vmj0@0Yk[W1@2U]^D40::_h@D0UigH102IXMX509j]h@80P^WE802Y_NP3000000l0ZKgX0`0[NnD5
0:;9m0@0a<;H0P34a=X30<;2fP80a<KK0`2g`^830;S4i0D0[[oW1@2Z_^P60:Vmj0030000002Y_NP0
ZKgX02P0ZKgX00<000000?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3ooom=0:Vm
j0<0ZKcW102W^^L40:Ffi@D0V:?L102GWMP509VQfP80WZgQ0P2KlO430<CMja`0ZKgX0`00000C0:Vm
j0<0:g_U1@2RbO@20<C2f0<0a<CJ0P32`]X40<C6f`H0^<CT0P2^_nL30:foi`D0Z[kX1@2Y_NP00`00
0000ZKgX0:Vmj00Y0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`030000003oool0oooo00l0
ooooBP2Y_NP60:Vli`@0Yk[W102M[>4409RSg0D0UigH102IXMX209_al@H0a=g[602Y_NP3000001L0
ZKgX0`1;Snd40:;9m0D0a<CJ1@34a]/20<G9g@D0^<CT1P2]_nL40:Znj0H0ZKgX00<000000:Vmj02Y
_NP0:02Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool200000140oooo00<000000:Vmj02Y_NP0
A`2Y_NP50:Vli`D0XkGU102M[>4409RSg0@0UigH1@2Wc?<30<GnhAT0ZKgX0`00000K0:Vmj0<0Bho]
1027^_H30<C4fP80`lGL0`34a]/40<G9g@80^<CT0`2gaND50:foi`D0Z[gX1P2Y_NP00`000000ZKgX
0:Vmj00X0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000ZKgX0:Vm
j0170:Vmj0D0Yk[W1@2S]ND409f/h@<0V:?L1@2JZN830:O<l`<0aOkQ5`2Y_NP3000001l0ZKgX0`1O
V_0408NjmPD0`lGL1P35bMd60;O5i@D0[;oX1@2Z_NP60:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<0
00000?ooo`3oool0;03oool000T0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL04P0M02o
ool0gia81@0000000`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<000000?oo
o`3oool04`3oool00`000000ZKgX0:Vmj0130:Vmj0@0Z;cX1@2W^^L40:>ei@D0TZ7N0`2BWM/509ZY
hP<0aOkQ5`2Y_NP2000002<0ZKgX0`1OV_0407^Yl0<0`lGL0P33amd30<G9g@<0aLgP0`2gaND30;C5
i`D0[;oX1@2Z_NP50:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool02P3oool01@3O
W4P000000000000004P0W=oo01d0oooo00080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103o
ool00`3ogi`0B00007Boo`040?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`03
0000003oool0oooo01@0oooo00<000000:Vmj02Y_NP0@`2Y_NP40:Rlj0<0Yk[W0P2R]NH409Z[h`@0
TZ7N102BWM/309ZYhP<0^nCc0P3Hln8C0:Vmj0<000009@2Y_NP405nJl0<0NjW`0P33aM`40<?7g@H0
aLgP1P2daNL50:boj0@0Z[gX1P2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00P0
oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3oool01@3o
ool2000001H0ooooAP2Y_NP40:Rlj0D0X[GV102JZn<409:QgP@0TYgK102ki?<40=SchPl0ZKgX0`00
000Y0:Vmj0<0Gi[`0`1kZO050<?7g@80aL[N0`35cN030<??h`D0]<GW1@2/_nP50:Zmj0H0ZKgX00<0
00000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo0008
0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0oooo
00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G0?oood@0ZKgX1@2W^nP40::eiP@0VZ_S
102BXMh609jbi@80f??R402Y_NP3000002d0ZKgX0`1OV_03082Rj@<0`lOM1035b]h60<??h`D0//CX
102/_nP60:Zmj0D0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0<0?ooo`030;md
001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`0;
0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01P3oool00`000000oooo
0?ooo`0H0?ooocl0ZKgX1@2Y_>P50:Nkj0@0V:gV102>XN4408jNgP@0W[;U0P3;i>X20=SchP`0ZKgX
0`00000a0:Vmj080Bho]1020X^T50<G:gP80b=3O1033cn<20;o>iPD0//CX102[_^P50:Zmj0H0ZKgX
00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`060?ooo`070?oOW01804P0W=oo0?ooo`3o
oml0W4Q809cOo`0L0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool0
1@3ookl0M01809cOo`3ookl0M00000<0000000<0M;oo0?ooo`3oool0103oool2000001/0oooo@02Y
_NP40:Vlj0D0X[OX102H[NH308jQh@D0SYkN0P2N/^D20<_TjP@0f??R202Y_NP3000003@0ZKgX0`1;
Snd4092Vi0<0aL[N1038d=l20<??h`@0_lkV0P2ba>P30:o2j0@0ZkkX2`2Y_NP00`000000ZKgX0:Vm
j00X0:Vmj0030000003oool0oooo00D0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?oo
o`0K0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo
0?ooo`020?ooo`050;md001d_ol0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?oood00
ZKgX102W_>P50::gj0@0V:gV0`2>XN4408jNgP<0bnCZ1@3Hln850:Vmj0<00000=`2Y_NP404^?k@@0
T:KT1P38d=l60;o>iPD0[l;X1@2Z_^P;0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3o
ool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Boo`3oool0gia8001d
_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool00`000000
oooo0?ooo`0L0?oood00ZKgX102W_>P40::gj0@0V:gV0`2>XN4609nai0<0f??R1@2Y_NP3000003/0
ZKgX0`1@NM`50:BbhP<0b=3O103:eN850;W<j080[l;X0`2/`>P50:Znj0X0ZKgX00<000000:Vmj02Y
_NP0:02Y_NP00`000000oooo0?ooo`050?ooo`030;md001d_ol0oooo01l0oooo00090?ooo`050?oo
_`1d000000000018W03Oool01@3oool01@3ogi`0B000000000000000M;oo0080oooo00H0gia80000
0000000000000000M02oool50?ooo`030000003oool0oooo01d0oooo@02Y_NP30:Nlj0D0V[;X102<
Y>D408VNh@<0Wk7T0`39dn820>3Wf080ZKgX0P00000o0:Vmj0<0D7WL1@2T/^850<[EhP80amOV102i
c>P60:c0j080Z[kX0`2Z_NP:0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool01@3o
ool01P3OW4P00000000000000000001d0;oooa`0oooo000U0?ooo`8000007`3ooolo0:Vmj0D0Y;[X
102J/^P408bTi@@0RIkQ1039dn820>3Wf0<00000@@2Y_NP4051ig080Y;;R0`2g`n<30<[EhP@0amOV
102canT50:c0j0H0Z[gX2P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02H0oooo
000U0?ooo`030000003oool0oooo01l0oooo>P2Y_NP50:Rlj0D0Y;[X0`2J/^P408bTi@D0Uj[T0P39
dn83000000030>3Wf034gN/0a=g[03h0ZKgX1028/>l30762e@H0]l?S1@37enH20<3Dj@@0/lOY1@2[
_^P50:Zmj0X0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?ooo`0U0?ooo`009@3oool0
0`000000oooo0?ooo`0P0?ooocX0ZKgX1@2X_>P509jgj@<0SZ_Y1023WnD309NZi0<000000`3PimP4
0<CMjch0ZKgX0`28/>l40762e@<0]l?S0`35e>D30<OGiP<0`=CY0P2canT30:o3j@D0ZkkX3`2Y_NP0
0`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02D0oooo000T0?ooo`8000008`3ooolj0:Vm
j0D0Y[cX1@2N]nT308j[j@<0PioU0`0000040;O0h@H0a=g[?P2Y_NP408R`k`@0LH;E1P35e>D50<3D
j@H0[l?Y1@2Z_^P?0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool0903oool002@0
oooo00<000000?ooo`3oool08`3ooolj0:Vmj0D0Y[cX102N]nT308j[j@<0000000<0PioU0;O0h@2g
`>400`2g`>430=?=e4<0ZKgX0`1YNM0509ZXh0<0aMCU1039gNP40;S=jP<0[l?Y0`2/`>P50:Znj0l0
ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo
0?ooo`0T0?ooocX0ZKgX102V_>P409Jcj`<0000000<0PZCZ08JSiP26XnH00P26XnH30;O0h@<0dlgD
0P3Jcli20:Vmj0@0JGW@1@2JZ>050<WMj080`m_[102hcNX60:c0j080Z[kX0`2Z_NP>0:Vmj0030000
002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?ooocX0ZKgX102T
^^T300000080U[?[0`22Y>X408JSiP@0dlgD103Jcli20:Vmj0@0JGW@0P2JZ>030;[=j0<0bMgX0`33
fn/50;36jPD0[<3X1@2Z_NP?0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08P3o
ool002<0oooo0P00000X0?ooocD0ZKgX1@2X_NP00`2T^^T00000000000020:Bjj@<0U[?[1022Y>X4
09R_i`80dlgD1@3Jclh00`3Cc=<0ZKgX0:Vmj00l0:Vmj0<0Nh?@101YNM060;[=j0@0`m_[0P2idN`5
0;36jPD0Z[kX102Z_NP@0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08@3oool0
00d0oooo00/0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB00200000003
0000B02Lgol0oooo00L0oooo00<000000?ooo`3oool0:03ooold0:Vmj080Z;gX0`0000050:2ij`<0
SJo]101jXN`409R_i`D0f/o>0`3Cc=<m0:Vmj0@0Nh?@1029UMT30;[=j0@0a^3[1@2idN`50:c1j@D0
Z[kX502Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo0240oooo000<0?ooo`060?oo
g`2LB000B9cO0?ooo`3OW4P007Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3o
ool00`000000oooo0?ooo`0Z0?oooc80ZKgX0`0000040:Nlj0D0X;W[0`2=[nd407ZQk080V:oW0`2^
^n<20=[?cP@0dlcC?P2Y_NP307^3d0D0RIGI1036h>/30<;Ok@80^M7/0`2aanX50:c1j@D0Z[gX4`2Y
_NP00`000000ZKgX0:Vmj00W0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oO
W01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo;P2Y_NP3000000@0ZKgX
102W_>P40:2ij`@0Pjc_0`1hXnd60:jkh`@0dlcC0`3<a=<l0:Vmj0@0Nh?@0P29UMT40;?:j`D0`]o]
1P2aanX50:Znj0@0Z[gX502Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01l0oooo
000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo00D0
oooo00<000000?ooo`3oool0;03ooolZ0:Vmj0<00000202Y_NP40:Jlj@@0W;S/1023[>l307RSk@<0
[[_S0`2m`Md20=?<d`D0c<CC=02Y_NP50:NXeP80Ogk8101kPm050;?:j`80`nC_0`32gnd20;SBk@<0
/LOZ0`2/`NT40:Znj1T0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0O0?ooo`00
303oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0
oooO09a8B02Lgol01P3oool00`000000oooo0?ooo`0]0?ooobH0ZKgX0`00000<0:Vmj0@0Y[cY102L
^>`308>/k`@0N:?]1P2m`Md50<c4d`80bKg?=02Y_NP40:NXeP<0Ogk8102:UMP30;?:j`@0`nC_1@2h
d^d60:c1j@80Z[kX0P2Z_NPH0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3o
ool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y_NP300000100ZKgX
0`2V_>T509Vgk@@0O:[a0`1kZ?030;g1g@<0aLCI0`3<a=<40<Vmcc@0ZKgX102WZ=H307mnb0@0RYGH
1033i>l30;oOl0D0/<K[1@2/`NT50:Zmj1P0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo
0?ooo`0M0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0
W4Q809cOo`090?ooo`800000<@3ooolN0:Vmj0<000004`2Y_NP50:Flj@@0VKO]101lZ_4307^Xl0H0
aLCI1@39_Ll20<^jbS<0ZKgX102WZ=H307mnb0H0/m;`102ogo020;G?kPD0/<K[1@2Z_^P40:Zmj1T0
ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0M0?ooo`00303oool01P3ooml0W4P0
07Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3oool0203oool00`000000oooo0?ooo`0a0?oo
oa/0ZKgX0P00000G0:Vmj0D0YKcY102G]nh407NZlP<0O:gb1035a=T20<G5fP<0bKg?103;^/X40:NX
ebP0ZKgX0`2TU/H409:7a0<0QXK<102HZN830;?Bl0@0_nOb1@2ecnh50:_0j@@0Z[kX7P2Y_NP00`00
0000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d000000000018
W03Oool01@3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool0<P3o
oolG0:Vmj0<000006P2Y_NP50:Flj@@0UkO^101gZ_8307b]lP80aLCI1035aMX00`39_Ll0bk[:0<^j
bP020<^jbP80dKk7102WZ=LU0:Vmj0D0Y9K6102BQl@408J6c0@0V:WR102oio830;WKl@80]Lo^0`2]
a>X50:_0jB40ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool2
000003@0oooo4`2Y_NP3000001h0ZKgX1@2U_>T309NgkP@0Mj[b0`1l[O860<G5fP@0bk[:0`3A_/L3
0:NXe`80]JG98@2Y_NP40:FJbP@0Y9K61@2BQl@308J6c080V:WR102fh_D50;WKl@H0[LCZ1@2Z_^PQ
0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06`3oool00280oooo00<000000?oo
o`3oool0=03oool?0:Vmj0<000008P2Y_NP50:FljP<0U[S^101eZo@307Z_m@<0aLGJ0`2oan020<^j
bPD0dKk700<0YjSG0;FUb@2eYLT00P2eYLT20:Vmj0<0Y9W:5`2Y_NP80:FJbPD0Y9K6102BQl@308J6
c0@0]^;e102jiO@40;3:k@<0[LCZ0`2[_nP40:Znj280ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`00
0000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX00P0
ZKgX0`00000V0:Vmj0D0YKcZ0`2F^>h407F[m0<0NZoe1P2oan060=6na`D0]JG91P2TVLX20:Vmj0<0
YIW:102Y_NP50:NXeP@0ZKgX1@2TU/H80:FJbP@0Y9K6102BQl@50:W>l`@0^^Gd0`2cdO040;3:k@H0
ZkoX0P2Z_^PT0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool0303oool00`3ogi`0
B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool00280oooo00<000000?ooo`3o
ool0=`3oool60:Vmj0<00000:P2Y_NP50:Flj@<0V;W^101h[_D3076`n0<0_lOP0`2_bNd40=6na`80
d<G@0`2eYLT20<fia`D0Y9W:1P2UVLX20:Vmj080Xi;31@2WZ=H40::@`@@0Y9K6202UV/X40:BFaPH0
W[CX1@2djOL50;?Al0D0[<7Y1@2[_nPV0:Vmj0030000002Y_NP0ZKgX02H0ZKgX0P00000<0?ooo`0:
0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0oooo000Q0?ooo`800000>P3o
ool20:Vmj0<00000;P2Y_NP50:Flj@<0V;W^101h[_D3076`n0H0[lW]0P3A_/L40=35d0040;FUb@3=
^LL0cKW70<fia`@0Y9W:0P32[/H50:FIbP@0Xi;3102WZ=H20;:M``<0XY311@2TU/H40:FJbP@0WioD
102KY=/309jdj0<0[>Si1P2cf_@40:g4j`D0[<7Y1@2Z_NPV0:Vmj0030000002Y_NP0ZKgX02H0ZKgX
00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW018
07@0_ooo00<0oooo000Q0?ooo`030000003oool0oooo03P0oooo0`00000b0:Vmj080YKcY0`2V_>T4
09bjk@@0O[;e0`1X[_T40:o9k@H0d<G@1@3=^LL20:BIbP<0`Zk6102UVLX20<:^aP@0Xi;30P2WZ=H3
0;:M``@0XY31102TU/H50:JRd@@0WioD102KY=/40:cXn@<0/>3g1@2^and40:g4j`D0Z[kX102Z_NPW
0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3o
ool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0
oooo0P0000030?oooc80ZKgX1P2V_>T409bjk@@0RKKc0`1W[oT40935nP<0d<G@0`2id>/40<fia`H0
`Zk60P2UVLX30<:^aP@0Xi;31P2bWL<30::@`@80Y9K60`2_[=D40:JRd@@0WioD1P2Uho/30;3Pm`<0
[/__1@2^and90:Znj2X0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;
0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo0P00
000d0?ooo`<000001P3ooolc0:Vmj0@0Y[cY1@2P^n`408Vfl`@0Ijoi0`2@aOX60;W@j`80cKW70P37
cMl;0<:^aP80Xi;30P34^M050;:M``<0XY311@2_[=D50:JRd@80WioD0`2Rgo`50:_SnPH0[/__1@2[
_nT40:Znj2l0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`080?ooo`0;0?oOW018
07@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?oo
o`3oool0<03oool3000000T0oooo=02Y_NP40:Nmj@D0X;_/102D^O4407Bcn@<0K[[m1@2id>/50<O=
g`80`Zk60`36c=l50<:^aP@0a;W@1@2bWL<40;Jmg`D0[jcE102VX]430:;Oo0@0Xn?l102]cO430:k;
k`<0Zl7Y102[_nTd0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool03@2o
M000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool000@0
oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0
oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo02d0oooo0`00000>0?oo
oc<0ZKgX102W_NT50:Blj`@0U;Wa101d/oT306jjo@D0Q/_n1037cMl60<K<g`80`Zk60`2kdn`40<Bi
d080/Yg30`2ddNl40;Jmg`@0[jcE1@2Og_d20:?So0D0Z/kc102]cO460:_1j@@0Z[gX=02Y_NP00`00
0000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000000007@0_ooo0?ooo`3o
oml0W4P007Boo`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P004RLg`3oool0gia8001d
_`D0oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3o
ool00`000000oooo0?ooo`0Z0?ooo`<000004P3ooolc0:Vmj0@0Z;gX1@2T_>/409jkk@D0QkSf0`1X
]_`408K;oP@0Tm?n1@36c=l50;_Ck0@0a;W@1P2ddNl30;Jmg`H0V]om102LhOd20:S>m0D0Z/kc102[
`NX30:_1j@<0Z[kX102Z_NPc0:Vmj0030000002Y_NP0ZKgX0240ZKgX0`0000000`3oool000000?oo
o`080?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`000`3o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`2oM000B9cO0?ooo`070?ooo`03
0;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<000005P3ooolc0:Vmj0@0Z;gX1@2V_NT409jkk@D0
Uk_a101n^_T406Vmo@<0Tm?n1@2=e_l40;_Ck0D0Wmcl1@2ddNl508oOoPH0U]gn1@2Xc_@50:[2j`@0
Zl7Z1@2Z_^P20:Zmj3H0ZKgX00<000000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?ooo`3o
ool05@3oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018
W03Oool01`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?oo
ocL0ZKgX1@2V_NT40:Blj`D0Uk_a102D_?<507fmn`<0KL?n102=e_l507gCo`@0Wmcl1@23f_h609?G
oPD0YL_c1@2Y`N/40:[2j`T0Z[kX>@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`00
0000oooo0?ooo`0E0?ooo`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool0
0`3ookl0M01809cOo`020?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000
003oool0oooo0280oooo0`00000N0?ooocL0ZKgX1@2X_NP40:Blj`D0X[c/102D_?<509Jnl`@0Pl7k
101caol508?;oPD0UlWi102DdOd60:C8lPT0ZL7[102Y_^P50:Znj3d0ZKgX00<000000:Vmj02Y_NP0
4`2Y_NP4000000`0oooo00<000000?ooo`3oool0503oool000<0oooo00L0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo00H0oooo00H0gia8001d_`3oool0oooo0?oo_`1d00030000000307Boo`3oool0
oooo00@0oooo00<000000?ooo`3oool07`3oool300000280oooo=`2Y_NP50:Rmj0@0YkgY1@2R_>`4
0:6mk@D0U[kc102K_o850934n@@0W<Cc1@2GbOT50:C4l0D0Z<3[102Y`N/90:Vnj440ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP0103oool0000000000000000@0?ooo`030000003oool0oooo01@0oooo0003
0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo0?ooo`3o
oml0W4Q809cOo`090?ooo`8000007P3oool2000002H0oooo00<000000:Vmj02Y_NP0>@2Y_NP90:Nm
j@@0XKg]1@2S_^`409^olPD0XL3_102La?<60:G1kP@0Z;oZ1@2X`>/90:Vnj4D0ZKgX00<000000:Vm
j02Y_NP02P2Y_NP20?ooo`<000004`3oool00`000000oooo0?ooo`0D0?ooo`000`3oool01P3ooml0
W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd0018W03Oool0oooo0;md001d_ol80?ooo`800000
703oool3000002X0oooo?`2Y_NP90:Nmj@D0Xkk/102U_^/50:70k`D0Y[o[1@2X_^T40:RojPT0ZKkX
BP2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103o
ool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo
0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo
A02Y_NP90:Nmj@@0YKk[1@2W_^T30:Joj`80ZKgX102X_^T50:Vmj0@0ZKkXCP2Y_NP00`000000ZKgX
0:Vmj0050:Vmj08000006P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?oo
o`0E0?ooo`<00000<P3ooom80:Vmj0D0YkgY102X_NP50:Nnj@D0ZKgX0P2X_^UI0:Vmj0040000002Y
_NP0ZKgX0:Vmj08000007@3oool00`000000oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo0`00
000f0?ooodd0ZKgX102X_NQT0:Vmj0<00000803oool00`000000oooo0?ooo`0D0?ooo`007`3oool0
0`000000oooo0?ooo`0?0?ooo`<00000>P3ooon`0:Vmj0<000000`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo00`0oooo0`00000n0?oo
oj`0ZKgX0`0000060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0
oooo00<000000?ooo`3oool02@3oool300000480ooooY`2Y_NP4000000X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000000T0oooo0P0000160?oooj80ZKgX
00@0oooo00000000000000003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`030000003oool0oooo00D0oooo0`0000190?oooih0ZKgX00@0oooo000000000000
00004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000
003oool0oooo0080oooo0`00001=0?ooo`030000002Y_NP0ZKgX09H0ZKgX00<0oooo000000000000
0P00000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<0
00000?ooo`0000000P00001A0?ooo`030000002Y_NP0ZKgX09<0ZKgX0`00000K0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool04`3oool001h0oooo0P00001E0?ooo`030000002Y_NP0
ZKgX0900ZKgX0P00000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool0
01<0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`1D0?ooo`030000002Y_NP0ZKgX
08`0ZKgX00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0180oooo000C0?ooo`030?oOW01807@0_ooo00X0oooo0P00001F0?ooohT0ZKgX0P00000W0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool0
303oool00`000000oooo0?ooo`1D0?ooohD0ZKgX0P00000[0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`000000oooo0?oo
o`1D0?oooh00ZKgX0P00000`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3o
ool001<0oooo00<0omnL04P0M02oool03P3oool00`000000oooo0?ooo`1D0?ooog/0ZKgX0`00000c
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0
M02oool03`3oool00`000000oooo0?ooo`1D0?ooogL0ZKgX0`00000g0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@0?oo
o`800000E@3ooomb0:Vmj0<00000?03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0180oooo000B0?ooo`040?noM0000000001d0;oooa80oooo00<000000?ooo`3oool0D`3ooom^0:Vm
j0<00000@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0?oOW01807@0_ooo01<0oooo00<000000?ooo`3oool0D`3ooomY0:Vmj0@00000@`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000003oool0oooo05<0oooo
I@2Y_NP3000004P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00:`3o
ool2000005@0ooooH02Y_NP0103oool0000000000000001<0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool0DP3ooomL0:Vmj0@00000C`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000^0?ooo`030000003oool0
oooo0580ooooF02Y_NP3000005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A
0?ooo`00;`3oool00`000000oooo0?ooo`1B0?oooe<0ZKgX00@0oooo0000000000000000F03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?ooo`030000003oool0oooo
0580ooooC`2Y_NP4000005`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`00<@3oool2000005<0ooooBP2Y_NP0103oool0000000000000001P0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool003<0oooo00<000000?ooo`3oool0D@3ooom60:Vmj0@0
0000I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo000d0?ooo`030000
003oool0oooo0540oooo@P2Y_NP3000006T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`00=@3oool00`000000oooo0?ooo`1A0?ooocd0ZKgX00@0oooo0000000000000000
K03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000f0?ooo`800000DP3o
ooli0:Vmj0@00000L03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000h
0?ooo`030000003oool0oooo0500oooo=@2Y_NP3000007D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo0000
000000000000N@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000j0?oo
o`030000003oool0oooo0540oooo:`2Y_NP4000007`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0@0?ooo`00>`3oool00`000000oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool003`0oooo0P00001B0?ooob80ZKgX
00@0oooo0000000000000000Q@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0
oooo000n0?ooo`030000003oool0oooo0500oooo7P2Y_NP4000008T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0?0?ooo`00?`3oool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00
002=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00400oooo00<00000
0?ooo`3oool0D03ooolF0:Vmj0<00000T@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00l0oooo00110?ooo`800000D@3ooolB0:Vmj0<00000U@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo04l0oooo3@2Y_NP3000009T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00A03oool00`000000oooo
0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3`3oool004D0oooo00<000000?ooo`3oool0D03oool40:Vmj0<00000X@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo00160?ooo`800000D@3oool200000:H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B03oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`00B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00B`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0>0?ooo`00C03oool2000004/0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001>0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00d0oooo001?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001@0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
001A0?ooo`800000AP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool005<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2/
0?ooo`050000003oool0oooo0?ooo`0000003`3oool005@0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001E0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00EP3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`0000003`3oool0
05L0oooo0P00000o0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`0000003P3oool005T0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005/0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005`0oooo0P00000j
0?ooo`030000003oool0oooo0:d0oooo1000000@0?ooo`00GP3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0:T0oooo1000000D0?ooo`00G`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0:D0oooo1000000H0?ooo`00H03oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo0:40oooo1000000L0?ooo`00H@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo09h0oooo0`00000P0?ooo`00HP3oool2000003@0oooo00<000000?ooo`3oool0VP3oool4
000002<0oooo001T0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0UP3oool40000
02L0oooo001U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0TP3oool4000002/0
oooo001V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0SP3oool4000002l0oooo
001W0?ooo`800000;`3oool00`000000oooo0?ooo`2:0?ooo`@00000<`3oool006T0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`270?ooo`<00000=`3oool006X0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`230?ooo`@00000>P3oool006/0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`1o0?ooo`@00000?P3oool006`0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1k0?ooo`@00000@P3oool006d0oooo0P00000Y0?ooo`030000003o
ool0oooo07L0oooo100000160?ooo`00K`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo07D0oooo0`00001:0?ooo`00L03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0740oooo1000001=0?ooo`00L@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0
oooo1000001A0?ooo`00LP3oool2000002<0oooo00<000000?ooo`3oool0J@3oool4000005D0oooo
001d0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I@3oool4000005T0oooo001e
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool3000005d0oooo001f0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool400000600oooo001g0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4000006@0oooo001h0?ooo`800000
7@3oool00`000000oooo0?ooo`1F0?ooo`@00000J03oool007X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1B0?ooo`@00000K03oool007/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1>0?ooo`@00000L03oool007`0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1;0?ooo`<00000M03oool007d0oooo0P00000H0?ooo`030000003oool0oooo04L0
oooo1000001g0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo
1000001k0?ooo`00P03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000
001o0?ooo`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo10000023
0?ooo`00PP3oool2000001<0oooo00<000000?ooo`3oool0>03oool3000008L0oooo00240?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool4000008X0oooo00250?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool4000008h0oooo00260?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0;03oool400000980oooo00270?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0:03oool4000009H0oooo00280?ooo`8000003@3oool00`00
0000oooo0?ooo`0U0?ooo`<00000VP3oool008X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0R0?ooo`@00000W@3oool008/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0N0?ooo`@00000X@3oool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`@00000Y@3oool008d0oooo0P0000070?ooo`030000003oool0oooo01H0oooo1000002Y
0?ooo`00S`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo1000002]0?oo
o`00T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0`00002a0?ooo`00
T@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000002d0?ooo`00TP3o
ool01@000000oooo0?ooo`3oool0000000T0oooo1000002h0?ooo`00T`3oool2000000030?ooo`00
0000oooo00@0oooo1000002l0?ooo`00U@3oool2000000030?ooo`000000000000800000`03oool0
09H0oooo0P0000340?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .61641 .52744 Mtetra
.61641 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51713 Mtetra
.65053 .51713 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53138 Mtetra
.5769 .53138 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .61641 .52744 .6107 .52111 Mtetra
.6107 .52111 .61641 .52744 .62773 .52402 .62206 .51766 Mtetra
.62206 .51766 .62773 .52402 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51713 .64492 .51071 Mtetra
.64492 .51071 .65053 .51713 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53138 .57106 .52507 Mtetra
.57106 .52507 .5769 .53138 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51473 Mtetra
.60495 .51473 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52217 Mtetra
.55394 .52217 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51473 .59916 .5083 Mtetra
.59916 .5083 .60495 .51473 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52217 .54798 .51579 Mtetra
.54798 .51579 .55394 .52217 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48098 Mtetra
.63368 .48098 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48098 .62789 .47429 Mtetra
.62789 .47429 .63368 .48098 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48209 Mtetra
.57556 .48209 .58153 .48871 .59305 .48513 .58711 .47848 Mtetra
.58711 .47848 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65743 .45649 Mtetra
.65743 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48209 .56955 .47541 Mtetra
.56955 .47541 .57556 .48209 .58711 .47848 .58113 .47177 Mtetra
.58113 .47177 .58711 .47848 .59871 .47485 .59276 .46812 Mtetra
.59276 .46812 .59871 .47485 .61035 .47121 .60444 .46445 Mtetra
.664 .741 .908 r
.60444 .46445 .61035 .47121 .62205 .46755 .61616 .46077 Mtetra
.61616 .46077 .62205 .46755 .63379 .46388 .62794 .45707 Mtetra
.62794 .45707 .63379 .46388 .64558 .46019 .63977 .45335 Mtetra
.664 .741 .907 r
.63977 .45335 .64558 .46019 .65743 .45649 .65164 .44962 Mtetra
.65164 .44962 .65743 .45649 .66932 .45277 .66357 .44587 Mtetra
.66357 .44587 .66932 .45277 .68126 .44903 .67555 .4421 Mtetra
.67555 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47597 Mtetra
.664 .741 .908 r
.54041 .47597 .54653 .48264 .55801 .47903 .55192 .47234 Mtetra
.663 .741 .908 r
.55192 .47234 .55801 .47903 .56955 .47541 .56349 .46871 Mtetra
.663 .742 .908 r
.56349 .46871 .56955 .47541 .58113 .47177 .5751 .46506 Mtetra
.663 .742 .909 r
.5751 .46506 .58113 .47177 .59276 .46812 .58676 .46141 Mtetra
.663 .743 .909 r
.58676 .46141 .59276 .46812 .60444 .46445 .59847 .45774 Mtetra
.663 .744 .91 r
.59847 .45774 .60444 .46445 .61616 .46077 .61023 .45404 Mtetra
.664 .744 .91 r
.61023 .45404 .61616 .46077 .62794 .45707 .62205 .45031 Mtetra
.62205 .45031 .62794 .45707 .63977 .45335 .63391 .44655 Mtetra
.665 .744 .909 r
.63391 .44655 .63977 .45335 .65164 .44962 .64582 .44276 Mtetra
.665 .743 .909 r
.64582 .44276 .65164 .44962 .66357 .44587 .65778 .43896 Mtetra
.665 .743 .908 r
.65778 .43896 .66357 .44587 .67555 .4421 .66979 .43514 Mtetra
.664 .742 .908 r
.66979 .43514 .67555 .4421 .68757 .43832 .68185 .43131 Mtetra
.664 .741 .908 r
.68185 .43131 .68757 .43832 .69965 .43452 .69396 .42748 Mtetra
.664 .741 .907 r
.69396 .42748 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47653 Mtetra
.663 .741 .908 r
.51128 .47653 .51752 .48319 .52894 .47959 .52273 .47291 Mtetra
.52273 .47291 .52894 .47959 .54041 .47597 .53423 .46929 Mtetra
.662 .742 .909 r
.53423 .46929 .54041 .47597 .55192 .47234 .54578 .46568 Mtetra
.661 .743 .911 r
.54578 .46568 .55192 .47234 .56349 .46871 .55738 .46209 Mtetra
.66 .745 .913 r
.55738 .46209 .56349 .46871 .5751 .46506 .56903 .45852 Mtetra
.659 .748 .916 r
.56903 .45852 .5751 .46506 .58676 .46141 .58073 .45495 Mtetra
.659 .751 .918 r
.58073 .45495 .58676 .46141 .59847 .45774 .59247 .45134 Mtetra
.661 .755 .92 r
.59247 .45134 .59847 .45774 .61023 .45404 .60427 .44767 Mtetra
.663 .758 .92 r
.60427 .44767 .61023 .45404 .62205 .45031 .61612 .44391 Mtetra
.666 .758 .919 r
.61612 .44391 .62205 .45031 .63391 .44655 .62801 .44007 Mtetra
.667 .757 .917 r
.62801 .44007 .63391 .44655 .64582 .44276 .63995 .43616 Mtetra
.668 .754 .915 r
.63995 .43616 .64582 .44276 .65778 .43896 .65195 .43221 Mtetra
.668 .751 .912 r
.65195 .43221 .65778 .43896 .66979 .43514 .66399 .42826 Mtetra
.667 .747 .91 r
.66399 .42826 .66979 .43514 .68185 .43131 .67608 .42433 Mtetra
.666 .744 .909 r
.67608 .42433 .68185 .43131 .69396 .42748 .68823 .42041 Mtetra
.665 .742 .908 r
.68823 .42041 .69396 .42748 .70613 .42363 .70043 .41651 Mtetra
.664 .742 .908 r
.70043 .41651 .70613 .42363 .71835 .41977 .71269 .41261 Mtetra
.664 .741 .907 r
.71269 .41261 .71835 .41977 .73062 .41589 .725 .4087 Mtetra
.725 .4087 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47346 Mtetra
.663 .741 .908 r
.49357 .47346 .49988 .48014 .51128 .47653 .505 .46984 Mtetra
.662 .741 .909 r
.505 .46984 .51128 .47653 .52273 .47291 .51648 .46624 Mtetra
.659 .742 .911 r
.51648 .46624 .52273 .47291 .53423 .46929 .52801 .46271 Mtetra
.655 .744 .916 r
.52801 .46271 .53423 .46929 .54578 .46568 .5396 .45929 Mtetra
.65 .75 .923 r
.5396 .45929 .54578 .46568 .55738 .46209 .55123 .45598 Mtetra
.645 .758 .931 r
.55123 .45598 .55738 .46209 .56903 .45852 .56292 .45273 Mtetra
.643 .77 .94 r
.56292 .45273 .56903 .45852 .58073 .45495 .57466 .44948 Mtetra
.645 .782 .947 r
.57466 .44948 .58073 .45495 .59247 .45134 .58645 .44612 Mtetra
.65 .794 .951 r
.58645 .44612 .59247 .45134 .60427 .44767 .59829 .44257 Mtetra
.657 .802 .952 r
.59829 .44257 .60427 .44767 .61612 .44391 .61017 .43879 Mtetra
.666 .804 .949 r
.61017 .43879 .61612 .44391 .62801 .44007 .6221 .43476 Mtetra
.674 .801 .943 r
.6221 .43476 .62801 .44007 .63995 .43616 .63408 .43055 Mtetra
.678 .792 .935 r
.63408 .43055 .63995 .43616 .65195 .43221 .6461 .42622 Mtetra
.679 .78 .927 r
.6461 .42622 .65195 .43221 .66399 .42826 .65817 .42188 Mtetra
.676 .768 .92 r
.65817 .42188 .66399 .42826 .67608 .42433 .67029 .41762 Mtetra
.672 .757 .914 r
.67029 .41762 .67608 .42433 .68823 .42041 .68246 .41346 Mtetra
.669 .749 .911 r
.68246 .41346 .68823 .42041 .70043 .41651 .69469 .4094 Mtetra
.666 .744 .909 r
.69469 .4094 .70043 .41651 .71269 .41261 .70698 .40541 Mtetra
.665 .742 .908 r
.70698 .40541 .71269 .41261 .725 .4087 .71933 .40145 Mtetra
.664 .741 .907 r
.71933 .40145 .725 .4087 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.664 .741 .908 r
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47038 Mtetra
.663 .741 .908 r
.47579 .47038 .48218 .47708 .49357 .47346 .4872 .46676 Mtetra
.66 .741 .91 r
.4872 .46676 .49357 .47346 .505 .46984 .49867 .4632 Mtetra
.654 .742 .915 r
.49867 .4632 .505 .46984 .51648 .46624 .51018 .4598 Mtetra
.644 .746 .923 r
.51018 .4598 .51648 .46624 .52801 .46271 .52175 .45665 Mtetra
.63 .755 .937 r
.52175 .45665 .52801 .46271 .5396 .45929 .53336 .4538 Mtetra
.615 .771 .955 r
.53336 .4538 .5396 .45929 .55123 .45598 .54504 .45117 Mtetra
.602 .793 .973 r
.54504 .45117 .55123 .45598 .56292 .45273 .55677 .44858 Mtetra
.595 .817 .985 r
.55677 .44858 .56292 .45273 .57466 .44948 .56856 .44583 Mtetra
.599 .839 .99 r
.56856 .44583 .57466 .44948 .58645 .44612 .5804 .44277 Mtetra
.61 .856 .99 r
.5804 .44277 .58645 .44612 .59829 .44257 .59229 .43935 Mtetra
.627 .866 .987 r
.59229 .43935 .59829 .44257 .61017 .43879 .60422 .43553 Mtetra
.646 .872 .983 r
.60422 .43553 .61017 .43879 .6221 .43476 .6162 .43134 Mtetra
.667 .872 .976 r
.6162 .43134 .6221 .43476 .63408 .43055 .62821 .42676 Mtetra
.685 .864 .967 r
.62821 .42676 .63408 .43055 .6461 .42622 .64026 .42188 Mtetra
.696 .846 .955 r
.64026 .42188 .6461 .42622 .65817 .42188 .65235 .41682 Mtetra
.698 .821 .941 r
.65235 .41682 .65817 .42188 .67029 .41762 .66448 .41181 Mtetra
.691 .794 .929 r
.66448 .41181 .67029 .41762 .68246 .41346 .67667 .40702 Mtetra
.681 .771 .919 r
.67667 .40702 .68246 .41346 .69469 .4094 .68892 .40252 Mtetra
.673 .755 .913 r
.68892 .40252 .69469 .4094 .70698 .40541 .70124 .39827 Mtetra
.668 .747 .909 r
.70124 .39827 .70698 .40541 .71933 .40145 .71361 .39418 Mtetra
.665 .743 .908 r
.71361 .39418 .71933 .40145 .73173 .39748 .72605 .39015 Mtetra
.664 .741 .907 r
.72605 .39015 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47093 Mtetra
.44659 .47093 .45309 .47764 .46442 .47401 .45794 .46728 Mtetra
.662 .741 .908 r
.45794 .46728 .46442 .47401 .47579 .47038 .46934 .46365 Mtetra
.658 .741 .911 r
.46934 .46365 .47579 .47038 .4872 .46676 .48079 .46013 Mtetra
.649 .742 .917 r
.48079 .46013 .4872 .46676 .49867 .4632 .49228 .45686 Mtetra
.63 .746 .931 r
.49228 .45686 .49867 .4632 .51018 .4598 .50383 .45404 Mtetra
.602 .757 .953 r
.50383 .45404 .51018 .4598 .52175 .45665 .51542 .45175 Mtetra
.568 .778 .977 r
.51542 .45175 .52175 .45665 .53336 .4538 .52708 .44982 Mtetra
.544 .806 .994 r
.52708 .44982 .53336 .4538 .54504 .45117 .5388 .44784 Mtetra
.549 .834 .998 r
.5388 .44784 .54504 .45117 .55677 .44858 .55057 .44541 Mtetra
.583 .853 .995 r
.55057 .44541 .55677 .44858 .56856 .44583 .5624 .44235 Mtetra
.621 .854 .987 r
.5624 .44235 .56856 .44583 .5804 .44277 .57428 .43877 Mtetra
.643 .841 .977 r
.57428 .43877 .5804 .44277 .59229 .43935 .58621 .43496 Mtetra
.649 .83 .97 r
.58621 .43496 .59229 .43935 .60422 .43553 .59819 .43112 Mtetra
.649 .83 .969 r
.59819 .43112 .60422 .43553 .6162 .43134 .61022 .42725 Mtetra
.654 .845 .973 r
.61022 .42725 .6162 .43134 .62821 .42676 .62229 .42314 Mtetra
.669 .868 .974 r
.62229 .42314 .62821 .42676 .64026 .42188 .6344 .41852 Mtetra
.692 .884 .969 r
.6344 .41852 .64026 .42188 .65235 .41682 .64654 .41326 Mtetra
.713 .882 .959 r
.64654 .41326 .65235 .41682 .66448 .41181 .65869 .40752 Mtetra
.719 .858 .947 r
.65869 .40752 .66448 .41181 .67667 .40702 .67089 .40174 Mtetra
.709 .82 .934 r
.67089 .40174 .67667 .40702 .68892 .40252 .68314 .39632 Mtetra
.692 .785 .922 r
.68314 .39632 .68892 .40252 .70124 .39827 .69546 .39142 Mtetra
.678 .761 .914 r
.69546 .39142 .70124 .39827 .71361 .39418 .70786 .38698 Mtetra
.669 .748 .91 r
.70786 .38698 .71361 .39418 .72605 .39015 .72033 .38279 Mtetra
.665 .743 .908 r
.72033 .38279 .72605 .39015 .73854 .38613 .73285 .37871 Mtetra
.664 .741 .907 r
.73285 .37871 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47093 .44004 .46417 Mtetra
.662 .741 .908 r
.44004 .46417 .44659 .47093 .45794 .46728 .45142 .46053 Mtetra
.658 .74 .911 r
.45142 .46053 .45794 .46728 .46934 .46365 .46285 .457 Mtetra
.646 .741 .918 r
.46285 .457 .46934 .46365 .48079 .46013 .47432 .4538 Mtetra
.62 .743 .935 r
.47432 .4538 .48079 .46013 .49228 .45686 .48584 .45122 Mtetra
.575 .753 .962 r
.48584 .45122 .49228 .45686 .50383 .45404 .49741 .44942 Mtetra
.526 .774 .988 r
.49741 .44942 .50383 .45404 .51542 .45175 .50903 .44804 Mtetra
.52 .808 .998 r
.50903 .44804 .51542 .45175 .52708 .44982 .52073 .44623 Mtetra
.599 .842 .99 r
.52073 .44623 .52708 .44982 .5388 .44784 .53249 .44314 Mtetra
.688 .824 .948 r
.53249 .44314 .5388 .44784 .55057 .44541 .54429 .43848 Mtetra
.717 .759 .886 r
.54429 .43848 .55057 .44541 .5624 .44235 .55613 .43277 Mtetra
.704 .692 .836 r
.55613 .43277 .5624 .44235 .57428 .43877 .568 .42695 Mtetra
.676 .641 .807 r
.568 .42695 .57428 .43877 .58621 .43496 .57992 .42187 Mtetra
.647 .61 .798 r
.57992 .42187 .58621 .43496 .59819 .43112 .59191 .41799 Mtetra
.622 .597 .804 r
.59191 .41799 .59819 .43112 .61022 .42725 .60399 .41533 Mtetra
.606 .609 .828 r
.60399 .41533 .61022 .42725 .62229 .42314 .61614 .41341 Mtetra
.607 .653 .869 r
.61614 .41341 .62229 .42314 .6344 .41852 .62836 .41137 Mtetra
.635 .734 .92 r
.62836 .41137 .6344 .41852 .64654 .41326 .64061 .40829 Mtetra
.681 .824 .952 r
.64061 .40829 .64654 .41326 .65869 .40752 .65286 .40364 Mtetra
.722 .875 .953 r
.65286 .40364 .65869 .40752 .67089 .40174 .6651 .39767 Mtetra
.737 .872 .943 r
.6651 .39767 .67089 .40174 .68314 .39632 .67736 .39127 Mtetra
.725 .835 .933 r
.67736 .39127 .68314 .39632 .69546 .39142 .68968 .38528 Mtetra
.7 .793 .922 r
.68968 .38528 .69546 .39142 .70786 .38698 .70208 .38007 Mtetra
.68 .763 .913 r
.70208 .38007 .70786 .38698 .72033 .38279 .71457 .37549 Mtetra
.669 .748 .909 r
.71457 .37549 .72033 .38279 .73285 .37871 .72712 .37125 Mtetra
.665 .743 .908 r
.72712 .37125 .73285 .37871 .74544 .37464 .73975 .36711 Mtetra
.664 .741 .907 r
.73975 .36711 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .4684 Mtetra
.39948 .4684 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46105 Mtetra
.663 .741 .908 r
.42207 .46105 .4287 .46783 .44004 .46417 .43343 .45738 Mtetra
.659 .74 .91 r
.43343 .45738 .44004 .46417 .45142 .46053 .44484 .4538 Mtetra
.647 .74 .917 r
.44484 .4538 .45142 .46053 .46285 .457 .4563 .45056 Mtetra
.617 .74 .934 r
.4563 .45056 .46285 .457 .47432 .4538 .46779 .44805 Mtetra
.56 .745 .963 r
.46779 .44805 .47432 .4538 .48584 .45122 .47932 .44654 Mtetra
.501 .762 .989 r
.47932 .44654 .48584 .45122 .49741 .44942 .49092 .44554 Mtetra
.536 .808 .996 r
.49092 .44554 .49741 .44942 .50903 .44804 .50259 .44359 Mtetra
.682 .832 .955 r
.50259 .44359 .50903 .44804 .52073 .44623 .51433 .43907 Mtetra
.757 .761 .856 r
.51433 .43907 .52073 .44623 .53249 .44314 .52612 .43145 Mtetra
.728 .664 .787 r
.52612 .43145 .53249 .44314 .54429 .43848 .53792 .42333 Mtetra
.64 .58 .772 r
.53792 .42333 .54429 .43848 .55613 .43277 .54978 .41947 Mtetra
.647 .606 .795 r
.54978 .41947 .55613 .43277 .568 .42695 .56169 .41559 Mtetra
.653 .64 .824 r
.56169 .41559 .568 .42695 .57992 .42187 .57366 .4117 Mtetra
.658 .665 .845 r
.57366 .4117 .57992 .42187 .59191 .41799 .58567 .40779 Mtetra
.58567 .40779 .59191 .41799 .60399 .41533 .59774 .40386 Mtetra
.653 .64 .824 r
.59774 .40386 .60399 .41533 .61614 .41341 .60985 .39992 Mtetra
.647 .606 .795 r
.60985 .39992 .61614 .41341 .62836 .41137 .62203 .39596 Mtetra
.554 .533 .787 r
.62203 .39596 .62836 .41137 .64061 .40829 .6344 .39629 Mtetra
.556 .585 .838 r
.6344 .39629 .64061 .40829 .65286 .40364 .64684 .39613 Mtetra
.64 .728 .912 r
.64684 .39613 .65286 .40364 .6651 .39767 .65923 .39286 Mtetra
.721 .843 .939 r
.65923 .39286 .6651 .39767 .67736 .39127 .67157 .38697 Mtetra
.75 .868 .934 r
.67157 .38697 .67736 .39127 .68968 .38528 .6839 .38011 Mtetra
.734 .836 .927 r
.6839 .38011 .68968 .38528 .70208 .38007 .69629 .37376 Mtetra
.703 .791 .919 r
.69629 .37376 .70208 .38007 .71457 .37549 .70877 .36841 Mtetra
.679 .76 .912 r
.70877 .36841 .71457 .37549 .72712 .37125 .72135 .36381 Mtetra
.668 .746 .909 r
.72135 .36381 .72712 .37125 .73975 .36711 .73401 .35954 Mtetra
.665 .742 .908 r
.73401 .35954 .73975 .36711 .75242 .363 .74672 .35538 Mtetra
.664 .741 .907 r
.74672 .35538 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .4684 .39273 .46161 Mtetra
.39273 .46161 .39948 .4684 .41075 .46473 .40403 .45791 Mtetra
.663 .741 .908 r
.40403 .45791 .41075 .46473 .42207 .46105 .41538 .45422 Mtetra
.661 .74 .909 r
.41538 .45422 .42207 .46105 .43343 .45738 .42678 .45058 Mtetra
.652 .739 .914 r
.42678 .45058 .43343 .45738 .44484 .4538 .43821 .4472 Mtetra
.624 .738 .929 r
.43821 .4472 .44484 .4538 .4563 .45056 .44968 .44453 Mtetra
.563 .737 .957 r
.44968 .44453 .4563 .45056 .46779 .44805 .46118 .44304 Mtetra
.49 .746 .985 r
.46118 .44304 .46779 .44805 .47932 .44654 .47274 .44233 Mtetra
.541 .798 .993 r
.47274 .44233 .47932 .44654 .49092 .44554 .48438 .44045 Mtetra
.723 .817 .923 r
.48438 .44045 .49092 .44554 .50259 .44359 .49612 .43477 Mtetra
.786 .729 .8 r
.49612 .43477 .50259 .44359 .51433 .43907 .50792 .42415 Mtetra
.645 .585 .773 r
.50792 .42415 .51433 .43907 .52612 .43145 .51971 .42007 Mtetra
.653 .639 .823 r
.51971 .42007 .52612 .43145 .53792 .42333 .53155 .41619 Mtetra
.664 .741 .907 r
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .6344 .39629 .62816 .38459 Mtetra
.648 .636 .825 r
.62816 .38459 .6344 .39629 .64684 .39613 .64048 .38079 Mtetra
.489 .499 .794 r
.64048 .38079 .64684 .39613 .65923 .39286 .65313 .3836 Mtetra
.606 .67 .885 r
.65313 .3836 .65923 .39286 .67157 .38697 .66566 .38144 Mtetra
.724 .822 .926 r
.66566 .38144 .67157 .38697 .6839 .38011 .67808 .37541 Mtetra
.759 .859 .924 r
.67808 .37541 .6839 .38011 .69629 .37376 .69048 .36819 Mtetra
.735 .825 .921 r
.69048 .36819 .69629 .37376 .70877 .36841 .70296 .36174 Mtetra
.698 .78 .915 r
.70296 .36174 .70877 .36841 .72135 .36381 .71554 .35649 Mtetra
.675 .754 .91 r
.71554 .35649 .72135 .36381 .73401 .35954 .72822 .35196 Mtetra
.667 .744 .908 r
.72822 .35196 .73401 .35954 .74672 .35538 .74098 .3477 Mtetra
.664 .741 .907 r
.74098 .3477 .74672 .35538 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.662 .741 .908 r
.39727 .45105 .40403 .45791 .41538 .45422 .40864 .44735 Mtetra
.657 .74 .911 r
.40864 .44735 .41538 .45422 .42678 .45058 .42006 .4438 Mtetra
.637 .737 .921 r
.42006 .4438 .42678 .45058 .43821 .4472 .43152 .4408 Mtetra
.583 .732 .946 r
.43152 .4408 .43821 .4472 .44968 .44453 .443 .43899 Mtetra
.495 .73 .977 r
.443 .43899 .44968 .44453 .46118 .44304 .45451 .43842 Mtetra
.512 .772 .99 r
.45451 .43842 .46118 .44304 .47274 .44233 .46611 .43715 Mtetra
.721 .814 .922 r
.46611 .43715 .47274 .44233 .48438 .44045 .47784 .43153 Mtetra
.788 .728 .796 r
.47784 .43153 .48438 .44045 .49612 .43477 .48966 .42066 Mtetra
.643 .595 .785 r
.48966 .42066 .49612 .43477 .50792 .42415 .50144 .41679 Mtetra
.664 .734 .902 r
.50144 .41679 .50792 .42415 .51971 .42007 .51326 .4129 Mtetra
.664 .741 .907 r
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64048 .38079 .63437 .37307 Mtetra
.664 .734 .902 r
.63437 .37307 .64048 .38079 .65313 .3836 .64678 .36899 Mtetra
.476 .503 .807 r
.64678 .36899 .65313 .3836 .66566 .38144 .65954 .372 Mtetra
.609 .669 .883 r
.65954 .372 .66566 .38144 .67808 .37541 .67217 .36972 Mtetra
.741 .823 .915 r
.67217 .36972 .67808 .37541 .69048 .36819 .68464 .363 Mtetra
.762 .846 .914 r
.68464 .363 .69048 .36819 .70296 .36174 .69712 .35556 Mtetra
.725 .806 .915 r
.69712 .35556 .70296 .36174 .71554 .35649 .7097 .34937 Mtetra
.688 .766 .911 r
.7097 .34937 .71554 .35649 .72822 .35196 .7224 .34439 Mtetra
.67 .748 .909 r
.7224 .34439 .72822 .35196 .74098 .3477 .73518 .33997 Mtetra
.665 .742 .908 r
.73518 .33997 .74098 .3477 .75379 .34348 .74804 .3357 Mtetra
.664 .741 .907 r
.74804 .3357 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29235 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.663 .741 .908 r
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44414 Mtetra
.661 .74 .909 r
.39045 .44414 .39727 .45105 .40864 .44735 .40185 .44046 Mtetra
.65 .738 .914 r
.40185 .44046 .40864 .44735 .42006 .4438 .41329 .43709 Mtetra
.612 .733 .932 r
.41329 .43709 .42006 .4438 .43152 .4408 .42476 .43466 Mtetra
.528 .722 .962 r
.42476 .43466 .43152 .4408 .443 .43899 .43624 .43379 Mtetra
.473 .734 .984 r
.43624 .43379 .443 .43899 .45451 .43842 .44778 .43334 Mtetra
.664 .806 .951 r
.44778 .43334 .45451 .43842 .46611 .43715 .45947 .42934 Mtetra
.809 .754 .801 r
.45947 .42934 .46611 .43715 .47784 .43153 .47133 .41762 Mtetra
.648 .6 .787 r
.47133 .41762 .47784 .43153 .48966 .42066 .48309 .4135 Mtetra
.664 .741 .907 r
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.657 .738 .91 r
.64066 .36141 .64678 .36899 .65954 .372 .65317 .35752 Mtetra
.447 .49 .81 r
.65317 .35752 .65954 .372 .67217 .36972 .66608 .36135 Mtetra
.658 .719 .894 r
.66608 .36135 .67217 .36972 .68464 .363 .67873 .35735 Mtetra
.764 .832 .905 r
.67873 .35735 .68464 .363 .69712 .35556 .69125 .34972 Mtetra
.752 .825 .909 r
.69125 .34972 .69712 .35556 .7097 .34937 .70382 .34251 Mtetra
.706 .782 .911 r
.70382 .34251 .7097 .34937 .7224 .34439 .71653 .33688 Mtetra
.677 .754 .909 r
.71653 .33688 .7224 .34439 .73518 .33997 .72934 .33221 Mtetra
.667 .744 .908 r
.72934 .33221 .73518 .33997 .74804 .3357 .74223 .32786 Mtetra
.664 .741 .907 r
.74223 .32786 .74804 .3357 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29235 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47065 Mtetra
.28278 .47065 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .44471 Mtetra
.36084 .44471 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.663 .741 .908 r
.37218 .44094 .37909 .44788 .39045 .44414 .38357 .43718 Mtetra
.658 .74 .91 r
.38357 .43718 .39045 .44414 .40185 .44046 .395 .43355 Mtetra
.639 .736 .919 r
.395 .43355 .40185 .44046 .41329 .43709 .40646 .43046 Mtetra
.579 .726 .943 r
.40646 .43046 .41329 .43709 .42476 .43466 .41794 .42871 Mtetra
.479 .71 .971 r
.41794 .42871 .42476 .43466 .43624 .43379 .42943 .4285 Mtetra
.546 .763 .977 r
.42943 .4285 .43624 .43379 .44778 .43334 .44103 .42693 Mtetra
.779 .785 .857 r
.44103 .42693 .44778 .43334 .45947 .42934 .45285 .41839 Mtetra
.734 .679 .797 r
.45285 .41839 .45947 .42934 .47133 .41762 .46468 .4102 Mtetra
.664 .734 .902 r
.46468 .4102 .47133 .41762 .48309 .4135 .47647 .40628 Mtetra
.664 .741 .907 r
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65317 .35752 .64703 .34961 Mtetra
.496 .662 .935 r
.64703 .34961 .65317 .35752 .66608 .36135 .65981 .34978 Mtetra
.525 .585 .858 r
.65981 .34978 .66608 .36135 .67873 .35735 .6727 .35032 Mtetra
.73 .784 .896 r
.6727 .35032 .67873 .35735 .69125 .34972 .68532 .34378 Mtetra
.769 .827 .898 r
.68532 .34378 .69125 .34972 .70382 .34251 .69791 .33584 Mtetra
.727 .795 .906 r
.69791 .33584 .70382 .34251 .71653 .33688 .71062 .32944 Mtetra
.686 .761 .908 r
.71062 .32944 .71653 .33688 .72934 .33221 .72345 .32442 Mtetra
.669 .746 .908 r
.72345 .32442 .72934 .33221 .74223 .32786 .73638 .31995 Mtetra
.665 .742 .907 r
.73638 .31995 .74223 .32786 .75519 .32356 .74937 .3156 Mtetra
.664 .741 .907 r
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47065 .27559 .46388 Mtetra
.27559 .46388 .28278 .47065 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .44471 .35385 .43774 Mtetra
.35385 .43774 .36084 .44471 .37218 .44094 .36522 .43394 Mtetra
.662 .74 .908 r
.36522 .43394 .37218 .44094 .38357 .43718 .37664 .43018 Mtetra
.655 .739 .912 r
.37664 .43018 .38357 .43718 .395 .43355 .3881 .42662 Mtetra
.625 .733 .925 r
.3881 .42662 .395 .43355 .40646 .43046 .39958 .42385 Mtetra
.544 .715 .952 r
.39958 .42385 .40646 .43046 .41794 .42871 .41105 .42277 Mtetra
.465 .706 .973 r
.41105 .42277 .41794 .42871 .42943 .4285 .42256 .42271 Mtetra
.658 .783 .94 r
.42256 .42271 .42943 .4285 .44103 .42693 .43426 .4189 Mtetra
.81 .75 .797 r
.43426 .4189 .44103 .42693 .45285 .41839 .4462 .40689 Mtetra
.652 .639 .824 r
.4462 .40689 .45285 .41839 .46468 .4102 .45797 .40295 Mtetra
.664 .741 .907 r
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65981 .34978 .65348 .33765 Mtetra
.402 .507 .851 r
.65348 .33765 .65981 .34978 .6727 .35032 .66654 .34165 Mtetra
.665 .718 .889 r
.66654 .34165 .6727 .35032 .68532 .34378 .67931 .33733 Mtetra
.77 .813 .887 r
.67931 .33733 .68532 .34378 .69791 .33584 .69194 .32916 Mtetra
.745 .802 .898 r
.69194 .32916 .69791 .33584 .71062 .32944 .70466 .32202 Mtetra
.697 .767 .906 r
.70466 .32202 .71062 .32944 .72345 .32442 .71752 .3166 Mtetra
.672 .748 .907 r
.71752 .3166 .72345 .32442 .73638 .31995 .73048 .31199 Mtetra
.666 .742 .907 r
.73048 .31199 .73638 .31995 .74937 .3156 .74351 .30758 Mtetra
.664 .741 .907 r
.74351 .30758 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43774 .34681 .43071 Mtetra
.34681 .43071 .35385 .43774 .36522 .43394 .35821 .42689 Mtetra
.661 .74 .908 r
.35821 .42689 .36522 .43394 .37664 .43018 .36966 .42312 Mtetra
.651 .738 .913 r
.36966 .42312 .37664 .43018 .3881 .42662 .38114 .41964 Mtetra
.611 .729 .929 r
.38114 .41964 .3881 .42662 .39958 .42385 .39263 .4172 Mtetra
.514 .704 .956 r
.39263 .4172 .39958 .42385 .41105 .42277 .40411 .41662 Mtetra
.489 .712 .969 r
.40411 .41662 .41105 .42277 .42256 .42271 .41566 .41625 Mtetra
.736 .78 .888 r
.41566 .41625 .42256 .42271 .43426 .4189 .42747 .40978 Mtetra
.778 .725 .804 r
.42747 .40978 .43426 .4189 .4462 .40689 .43941 .39961 Mtetra
.664 .741 .907 r
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.409 .632 .946 r
.511 .37557 .51759 .38304 .52968 .379 .52311 .37704 Mtetra
.362 .8 .961 r
.52311 .37704 .52968 .379 .54181 .37495 .53531 .37552 Mtetra
.391 .851 .848 r
.53531 .37552 .54181 .37495 .554 .37088 .54757 .37142 Mtetra
.609 .954 .89 r
.54757 .37142 .554 .37088 .56624 .36679 .55985 .36474 Mtetra
.82 .942 .906 r
.55985 .36474 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.664 .741 .907 r
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.389 .612 .939 r
.64729 .32981 .65348 .33765 .66654 .34165 .66029 .33187 Mtetra
.585 .658 .888 r
.66029 .33187 .66654 .34165 .67931 .33733 .67322 .33018 Mtetra
.759 .792 .88 r
.67322 .33018 .67931 .33733 .69194 .32916 .68592 .32227 Mtetra
.756 .8 .888 r
.68592 .32227 .69194 .32916 .70466 .32202 .69865 .31455 Mtetra
.707 .77 .902 r
.69865 .31455 .70466 .32202 .71752 .3166 .71153 .30873 Mtetra
.676 .749 .906 r
.71153 .30873 .71752 .3166 .73048 .31199 .72453 .30396 Mtetra
.666 .743 .907 r
.72453 .30396 .73048 .31199 .74351 .30758 .7376 .29949 Mtetra
.664 .741 .907 r
.7376 .29949 .74351 .30758 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .27201 .84444 .26361 Mtetra
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45019 Mtetra
.26104 .45019 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42689 .35114 .41978 Mtetra
.661 .74 .909 r
.35114 .41978 .35821 .42689 .36966 .42312 .36261 .416 Mtetra
.648 .737 .914 r
.36261 .416 .36966 .42312 .38114 .41964 .37412 .41259 Mtetra
.599 .724 .932 r
.37412 .41259 .38114 .41964 .39263 .4172 .38563 .4104 Mtetra
.497 .693 .956 r
.38563 .4104 .39263 .4172 .40411 .41662 .39713 .41013 Mtetra
.526 .717 .96 r
.39713 .41013 .40411 .41662 .41566 .41625 .40872 .40923 Mtetra
.777 .772 .848 r
.40872 .40923 .41566 .41625 .42747 .40978 .42064 .4005 Mtetra
.748 .716 .822 r
.42064 .4005 .42747 .40978 .43941 .39961 .43256 .39228 Mtetra
.664 .741 .907 r
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.407 .631 .946 r
.49225 .37213 .49894 .37962 .511 .37557 .50431 .37359 Mtetra
.115 .644 .872 r
.50431 .37359 .511 .37557 .52311 .37704 .51647 .37434 Mtetra
.465 .832 .993 r
.51647 .37434 .52311 .37704 .53531 .37552 .52872 .37221 Mtetra
.625 .874 .989 r
.52872 .37221 .53531 .37552 .54757 .37142 .54103 .36809 Mtetra
.717 .896 .961 r
.54103 .36809 .54757 .37142 .55985 .36474 .55337 .36195 Mtetra
.805 .922 .915 r
.55337 .36195 .55985 .36474 .57212 .35505 .56572 .35292 Mtetra
.82 .942 .906 r
.56572 .35292 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.664 .741 .907 r
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.496 .668 .94 r
.64105 .3219 .64729 .32981 .66029 .33187 .65399 .32191 Mtetra
.503 .615 .896 r
.65399 .32191 .66029 .33187 .67322 .33018 .66705 .32245 Mtetra
.744 .775 .877 r
.66705 .32245 .67322 .33018 .68592 .32227 .67982 .31501 Mtetra
.762 .793 .878 r
.67982 .31501 .68592 .32227 .69865 .31455 .69259 .30691 Mtetra
.714 .77 .897 r
.69259 .30691 .69865 .31455 .71153 .30873 .7055 .30077 Mtetra
.678 .75 .905 r
.7055 .30077 .71153 .30873 .72453 .30396 .71853 .29586 Mtetra
.667 .743 .907 r
.71853 .29586 .72453 .30396 .7376 .29949 .73164 .29133 Mtetra
.664 .741 .907 r
.73164 .29133 .7376 .29949 .75074 .29507 .74483 .28687 Mtetra
.74483 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45019 .25368 .44326 Mtetra
.25368 .44326 .26104 .45019 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41978 .34401 .41261 Mtetra
.66 .74 .909 r
.34401 .41261 .35114 .41978 .36261 .416 .35552 .40882 Mtetra
.646 .736 .915 r
.35552 .40882 .36261 .416 .37412 .41259 .36705 .40544 Mtetra
.593 .72 .933 r
.36705 .40544 .37412 .41259 .38563 .4104 .37858 .40337 Mtetra
.492 .685 .953 r
.37858 .40337 .38563 .4104 .39713 .41013 .39009 .40322 Mtetra
.551 .715 .948 r
.39009 .40322 .39713 .41013 .40872 .40923 .40173 .40194 Mtetra
.793 .768 .83 r
.40173 .40194 .40872 .40923 .42064 .4005 .41373 .39192 Mtetra
.733 .728 .847 r
.41373 .39192 .42064 .4005 .43256 .39228 .42565 .3849 Mtetra
.664 .741 .907 r
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.22 .527 .919 r
.48551 .36458 .49225 .37213 .50431 .37359 .49758 .36857 Mtetra
.399 .719 .988 r
.49758 .36857 .50431 .37359 .51647 .37434 .50977 .36872 Mtetra
.582 .778 .973 r
.50977 .36872 .51647 .37434 .52872 .37221 .52206 .36629 Mtetra
.66 .794 .946 r
.52206 .36629 .52872 .37221 .54103 .36809 .53441 .36213 Mtetra
.717 .809 .922 r
.53441 .36213 .54103 .36809 .55337 .36195 .54681 .35624 Mtetra
.782 .828 .888 r
.54681 .35624 .55337 .36195 .56572 .35292 .55921 .34775 Mtetra
.85 .845 .838 r
.55921 .34775 .56572 .35292 .57808 .34316 .57159 .33537 Mtetra
.664 .741 .907 r
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.553 .695 .934 r
.63475 .31393 .64105 .3219 .65399 .32191 .64768 .31265 Mtetra
.434 .599 .914 r
.64768 .31265 .65399 .32191 .66705 .32245 .66082 .31444 Mtetra
.735 .766 .878 r
.66082 .31444 .66705 .32245 .67982 .31501 .67365 .30732 Mtetra
.762 .783 .87 r
.67365 .30732 .67982 .31501 .69259 .30691 .68646 .29902 Mtetra
.717 .766 .891 r
.68646 .29902 .69259 .30691 .7055 .30077 .6994 .29268 Mtetra
.68 .749 .903 r
.6994 .29268 .7055 .30077 .71853 .29586 .71248 .28768 Mtetra
.667 .743 .907 r
.71248 .28768 .71853 .29586 .73164 .29133 .72563 .2831 Mtetra
.664 .741 .907 r
.72563 .2831 .73164 .29133 .74483 .28687 .73886 .27861 Mtetra
.73886 .27861 .74483 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .2466 Mtetra
.83317 .2466 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .41261 .33683 .40539 Mtetra
.66 .74 .909 r
.33683 .40539 .34401 .41261 .35552 .40882 .34837 .40156 Mtetra
.646 .736 .915 r
.34837 .40156 .35552 .40882 .36705 .40544 .35993 .39815 Mtetra
.594 .718 .931 r
.35993 .39815 .36705 .40544 .37858 .40337 .37149 .39605 Mtetra
.497 .68 .948 r
.37149 .39605 .37858 .40337 .39009 .40322 .38302 .39588 Mtetra
.556 .705 .939 r
.38302 .39588 .39009 .40322 .40173 .40194 .39468 .39457 Mtetra
.793 .767 .83 r
.39468 .39457 .40173 .40194 .41373 .39192 .40673 .38451 Mtetra
.742 .76 .868 r
.40673 .38451 .41373 .39192 .42565 .3849 .41869 .37745 Mtetra
.664 .741 .907 r
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.22 .527 .919 r
.47872 .35696 .48551 .36458 .49758 .36857 .4908 .36094 Mtetra
.483 .669 .946 r
.4908 .36094 .49758 .36857 .50977 .36872 .50302 .36106 Mtetra
.603 .721 .928 r
.50302 .36106 .50977 .36872 .52206 .36629 .51534 .3586 Mtetra
.663 .742 .909 r
.51534 .3586 .52206 .36629 .53441 .36213 .52773 .3544 Mtetra
.711 .757 .888 r
.52773 .3544 .53441 .36213 .54681 .35624 .54016 .34847 Mtetra
.766 .77 .856 r
.54016 .34847 .54681 .35624 .55921 .34775 .55262 .33994 Mtetra
.823 .778 .811 r
.55262 .33994 .55921 .34775 .57159 .33537 .56505 .32751 Mtetra
.664 .741 .907 r
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.553 .695 .934 r
.6284 .30589 .63475 .31393 .64768 .31265 .64136 .30458 Mtetra
.403 .619 .94 r
.64136 .30458 .64768 .31265 .66082 .31444 .65453 .30634 Mtetra
.735 .765 .878 r
.65453 .30634 .66082 .31444 .67365 .30732 .66741 .29918 Mtetra
.759 .772 .864 r
.66741 .29918 .67365 .30732 .68646 .29902 .68027 .29084 Mtetra
.716 .759 .887 r
.68027 .29084 .68646 .29902 .6994 .29268 .69326 .28446 Mtetra
.68 .747 .902 r
.69326 .28446 .6994 .29268 .71248 .28768 .70637 .27942 Mtetra
.667 .742 .906 r
.70637 .27942 .71248 .28768 .72563 .2831 .71957 .2748 Mtetra
.664 .741 .907 r
.71957 .2748 .72563 .2831 .73886 .27861 .73284 .27026 Mtetra
.73284 .27026 .73886 .27861 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26115 Mtetra
.75956 .26115 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .2466 .82746 .23798 Mtetra
.82746 .23798 .83317 .2466 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40205 Mtetra
.31807 .40205 .32534 .4093 .33683 .40539 .32959 .3981 Mtetra
.661 .74 .909 r
.32959 .3981 .33683 .40539 .34837 .40156 .34116 .39423 Mtetra
.648 .736 .913 r
.34116 .39423 .34837 .40156 .35993 .39815 .35275 .39073 Mtetra
.6 .719 .927 r
.35275 .39073 .35993 .39815 .37149 .39605 .36434 .38845 Mtetra
.509 .678 .941 r
.36434 .38845 .37149 .39605 .38302 .39588 .37591 .3881 Mtetra
.543 .688 .933 r
.37591 .3881 .38302 .39588 .39468 .39457 .38757 .38713 Mtetra
.774 .765 .845 r
.38757 .38713 .39468 .39457 .40673 .38451 .39962 .37828 Mtetra
.776 .798 .871 r
.39962 .37828 .40673 .38451 .41869 .37745 .41167 .36994 Mtetra
.664 .741 .907 r
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.407 .631 .946 r
.47187 .34928 .47872 .35696 .4908 .36094 .484 .35066 Mtetra
.495 .603 .89 r
.484 .35066 .4908 .36094 .50302 .36106 .49624 .35134 Mtetra
.6 .666 .886 r
.49624 .35134 .50302 .36106 .51534 .3586 .50858 .34912 Mtetra
.66 .697 .874 r
.50858 .34912 .51534 .3586 .52773 .3544 .521 .34489 Mtetra
.708 .714 .854 r
.521 .34489 .52773 .3544 .54016 .34847 .53346 .33864 Mtetra
.759 .724 .82 r
.53346 .33864 .54016 .34847 .55262 .33994 .54595 .32948 Mtetra
.764 .715 .806 r
.54595 .32948 .55262 .33994 .56505 .32751 .55845 .31959 Mtetra
.664 .741 .907 r
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.496 .668 .94 r
.622 .29779 .6284 .30589 .64136 .30458 .63503 .29771 Mtetra
.439 .68 .966 r
.63503 .29771 .64136 .30458 .65453 .30634 .64819 .29816 Mtetra
.743 .767 .873 r
.64819 .29816 .65453 .30634 .66741 .29918 .6611 .29059 Mtetra
.753 .761 .859 r
.6611 .29059 .66741 .29918 .68027 .29084 .67401 .28236 Mtetra
.711 .752 .884 r
.67401 .28236 .68027 .29084 .69326 .28446 .68705 .27609 Mtetra
.678 .744 .901 r
.68705 .27609 .69326 .28446 .70637 .27942 .70021 .27107 Mtetra
.667 .742 .906 r
.70021 .27107 .70637 .27942 .71957 .2748 .71345 .26643 Mtetra
.664 .741 .907 r
.71345 .26643 .71957 .2748 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26115 .75357 .25265 Mtetra
.75357 .25265 .75956 .26115 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40205 .31074 .39474 Mtetra
.31074 .39474 .31807 .40205 .32959 .3981 .32229 .39076 Mtetra
.661 .74 .908 r
.32229 .39076 .32959 .3981 .34116 .39423 .33389 .38683 Mtetra
.651 .736 .912 r
.33389 .38683 .34116 .39423 .35275 .39073 .34552 .3832 Mtetra
.612 .721 .923 r
.34552 .3832 .35275 .39073 .36434 .38845 .35715 .38061 Mtetra
.529 .681 .935 r
.35715 .38061 .36434 .38845 .37591 .3881 .36875 .37991 Mtetra
.523 .669 .929 r
.36875 .37991 .37591 .3881 .38757 .38713 .38042 .3794 Mtetra
.73 .752 .87 r
.38042 .3794 .38757 .38713 .39962 .37828 .39242 .37275 Mtetra
.816 .82 .853 r
.39242 .37275 .39962 .37828 .41167 .36994 .40459 .36236 Mtetra
.664 .741 .907 r
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .484 .35066 .4772 .33732 Mtetra
.496 .542 .834 r
.4772 .33732 .484 .35066 .49624 .35134 .48943 .33866 Mtetra
.586 .601 .834 r
.48943 .33866 .49624 .35134 .50858 .34912 .50178 .33699 Mtetra
.651 .642 .828 r
.50178 .33699 .50858 .34912 .521 .34489 .51422 .33272 Mtetra
.703 .664 .809 r
.51422 .33272 .521 .34489 .53346 .33864 .52671 .32584 Mtetra
.744 .671 .78 r
.52671 .32584 .53346 .33864 .54595 .32948 .53922 .31593 Mtetra
.647 .619 .808 r
.53922 .31593 .54595 .32948 .55845 .31959 .5518 .31159 Mtetra
.664 .741 .907 r
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.389 .612 .939 r
.61554 .28961 .622 .29779 .63503 .29771 .62868 .29154 Mtetra
.545 .758 .976 r
.62868 .29154 .63503 .29771 .64819 .29816 .64179 .28968 Mtetra
.751 .764 .863 r
.64179 .28968 .64819 .29816 .6611 .29059 .65472 .28156 Mtetra
.743 .749 .857 r
.65472 .28156 .6611 .29059 .67401 .28236 .66769 .27362 Mtetra
.703 .744 .884 r
.66769 .27362 .67401 .28236 .68705 .27609 .68079 .2676 Mtetra
.675 .742 .901 r
.68079 .2676 .68705 .27609 .70021 .27107 .694 .26264 Mtetra
.666 .741 .906 r
.694 .26264 .70021 .27107 .71345 .26643 .70729 .25798 Mtetra
.664 .741 .907 r
.70729 .25798 .71345 .26643 .72676 .26185 .72064 .25337 Mtetra
.72064 .25337 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39474 .30335 .38737 Mtetra
.30335 .38737 .31074 .39474 .32229 .39076 .31493 .38335 Mtetra
.662 .74 .908 r
.31493 .38335 .32229 .39076 .33389 .38683 .32656 .37937 Mtetra
.655 .737 .91 r
.32656 .37937 .33389 .38683 .34552 .3832 .33823 .37559 Mtetra
.626 .725 .918 r
.33823 .37559 .34552 .3832 .35715 .38061 .34991 .37262 Mtetra
.556 .69 .928 r
.34991 .37262 .35715 .38061 .36875 .37991 .36156 .37135 Mtetra
.512 .655 .924 r
.36156 .37135 .36875 .37991 .38042 .3794 .37323 .37111 Mtetra
.66 .721 .894 r
.37323 .37111 .38042 .3794 .39242 .37275 .38515 .36707 Mtetra
.839 .814 .826 r
.38515 .36707 .39242 .37275 .40459 .36236 .39746 .35473 Mtetra
.664 .741 .907 r
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .48943 .33866 .4826 .32521 Mtetra
.647 .619 .808 r
.4826 .32521 .48943 .33866 .50178 .33699 .49499 .32091 Mtetra
.637 .581 .775 r
.49499 .32091 .50178 .33699 .51422 .33272 .50743 .3166 Mtetra
.50743 .3166 .51422 .33272 .52671 .32584 .51992 .31226 Mtetra
.647 .619 .808 r
.51992 .31226 .52671 .32584 .53922 .31593 .53248 .30791 Mtetra
.664 .741 .907 r
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.269 .543 .922 r
.60903 .28137 .61554 .28961 .62868 .29154 .62225 .28521 Mtetra
.663 .8 .948 r
.62225 .28521 .62868 .29154 .64179 .28968 .63531 .28062 Mtetra
.753 .752 .852 r
.63531 .28062 .64179 .28968 .65472 .28156 .64828 .27215 Mtetra
.73 .738 .858 r
.64828 .27215 .65472 .28156 .66769 .27362 .66131 .26472 Mtetra
.693 .739 .886 r
.66131 .26472 .66769 .27362 .68079 .2676 .67448 .25902 Mtetra
.672 .74 .902 r
.67448 .25902 .68079 .2676 .694 .26264 .68773 .25413 Mtetra
.665 .741 .906 r
.68773 .25413 .694 .26264 .70729 .25798 .70106 .24945 Mtetra
.664 .741 .907 r
.70106 .24945 .70729 .25798 .72064 .25337 .71446 .24481 Mtetra
.71446 .24481 .72064 .25337 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.663 .74 .908 r
.30751 .37589 .31493 .38335 .32656 .37937 .31918 .37185 Mtetra
.658 .739 .909 r
.31918 .37185 .32656 .37937 .33823 .37559 .33088 .36794 Mtetra
.639 .73 .914 r
.33088 .36794 .33823 .37559 .34991 .37262 .34261 .36457 Mtetra
.587 .701 .922 r
.34261 .36457 .34991 .37262 .36156 .37135 .35432 .36257 Mtetra
.523 .656 .919 r
.35432 .36257 .36156 .37135 .37323 .37111 .36602 .36212 Mtetra
.584 .677 .904 r
.36602 .36212 .37323 .37111 .38515 .36707 .37787 .3603 Mtetra
.781 .788 .859 r
.37787 .3603 .38515 .36707 .39746 .35473 .39008 .35139 Mtetra
.795 .892 .914 r
.39008 .35139 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.664 .741 .907 r
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.492 .667 .941 r
.58951 .27756 .59612 .28584 .60903 .28137 .60257 .27747 Mtetra
.302 .717 .975 r
.60257 .27747 .60903 .28137 .62225 .28521 .61573 .27776 Mtetra
.73 .788 .898 r
.61573 .27776 .62225 .28521 .63531 .28062 .62876 .27084 Mtetra
.745 .736 .843 r
.62876 .27084 .63531 .28062 .64828 .27215 .64177 .26251 Mtetra
.714 .729 .862 r
.64177 .26251 .64828 .27215 .66131 .26472 .65489 .25574 Mtetra
.684 .735 .89 r
.65489 .25574 .66131 .26472 .67448 .25902 .66811 .25037 Mtetra
.669 .739 .903 r
.66811 .25037 .67448 .25902 .68773 .25413 .68141 .24555 Mtetra
.665 .741 .906 r
.68141 .24555 .68773 .25413 .70106 .24945 .69479 .24086 Mtetra
.664 .741 .907 r
.69479 .24086 .70106 .24945 .71446 .24481 .70823 .23617 Mtetra
.70823 .23617 .71446 .24481 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.663 .741 .907 r
.30004 .36836 .30751 .37589 .31918 .37185 .31173 .36428 Mtetra
.661 .739 .908 r
.31173 .36428 .31918 .37185 .33088 .36794 .32347 .36025 Mtetra
.65 .734 .911 r
.32347 .36025 .33088 .36794 .34261 .36457 .33525 .35654 Mtetra
.615 .714 .916 r
.33525 .35654 .34261 .36457 .35432 .36257 .34703 .35379 Mtetra
.555 .671 .915 r
.34703 .35379 .35432 .36257 .36602 .36212 .35878 .35261 Mtetra
.541 .647 .903 r
.35878 .35261 .36602 .36212 .37787 .3603 .37059 .35188 Mtetra
.667 .724 .892 r
.37059 .35188 .37787 .3603 .39008 .35139 .38264 .34752 Mtetra
.855 .866 .848 r
.38264 .34752 .39008 .35139 .4023 .34284 .39507 .33528 Mtetra
.672 .75 .909 r
.39507 .33528 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.664 .741 .907 r
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.657 .738 .91 r
.56992 .27374 .57663 .28206 .58951 .27756 .58285 .26945 Mtetra
.27 .552 .928 r
.58285 .26945 .58951 .27756 .60257 .27747 .59602 .27303 Mtetra
.633 .857 .984 r
.59602 .27303 .60257 .27747 .61573 .27776 .60911 .26862 Mtetra
.745 .751 .857 r
.60911 .26862 .61573 .27776 .62876 .27084 .62214 .26052 Mtetra
.728 .72 .843 r
.62214 .26052 .62876 .27084 .64177 .26251 .63522 .25285 Mtetra
.698 .725 .871 r
.63522 .25285 .64177 .26251 .65489 .25574 .64841 .24678 Mtetra
.676 .734 .895 r
.64841 .24678 .65489 .25574 .66811 .25037 .66168 .24169 Mtetra
.666 .739 .904 r
.66168 .24169 .66811 .25037 .68141 .24555 .67504 .23691 Mtetra
.664 .741 .907 r
.67504 .23691 .68141 .24555 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36428 .30422 .35665 Mtetra
.662 .74 .908 r
.30422 .35665 .31173 .36428 .32347 .36025 .316 .35254 Mtetra
.657 .737 .909 r
.316 .35254 .32347 .36025 .33525 .35654 .32782 .34858 Mtetra
.637 .725 .912 r
.32782 .34858 .33525 .35654 .34703 .35379 .33966 .34518 Mtetra
.593 .693 .912 r
.33966 .34518 .34703 .35379 .35878 .35261 .35149 .343 Mtetra
.547 .649 .901 r
.35149 .343 .35878 .35261 .37059 .35188 .36333 .34208 Mtetra
.576 .658 .892 r
.36333 .34208 .37059 .35188 .38264 .34752 .37527 .34044 Mtetra
.718 .776 .898 r
.37527 .34044 .38264 .34752 .39507 .33528 .38749 .33435 Mtetra
.853 .953 .878 r
.38749 .33435 .39507 .33528 .4072 .33079 .39996 .3229 Mtetra
.664 .741 .907 r
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.332 .583 .934 r
.56316 .26536 .56992 .27374 .58285 .26945 .57624 .26806 Mtetra
.385 .832 .936 r
.57624 .26806 .58285 .26945 .59602 .27303 .58934 .26533 Mtetra
.736 .785 .892 r
.58934 .26533 .59602 .27303 .60911 .26862 .6024 .25808 Mtetra
.732 .718 .838 r
.6024 .25808 .60911 .26862 .62214 .26052 .61548 .25009 Mtetra
.708 .712 .852 r
.61548 .25009 .62214 .26052 .63522 .25285 .62863 .24337 Mtetra
.684 .725 .882 r
.62863 .24337 .63522 .25285 .64841 .24678 .64188 .23788 Mtetra
.67 .736 .899 r
.64188 .23788 .64841 .24678 .66168 .24169 .65521 .23296 Mtetra
.665 .74 .906 r
.65521 .23296 .66168 .24169 .67504 .23691 .66861 .22819 Mtetra
.664 .741 .907 r
.66861 .22819 .67504 .23691 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35665 .29665 .34896 Mtetra
.663 .74 .907 r
.29665 .34896 .30422 .35665 .316 .35254 .30846 .3448 Mtetra
.661 .739 .908 r
.30846 .3448 .316 .35254 .32782 .34858 .32032 .34068 Mtetra
.652 .733 .909 r
.32032 .34068 .32782 .34858 .33966 .34518 .33222 .33683 Mtetra
.626 .713 .909 r
.33222 .33683 .33966 .34518 .35149 .343 .34413 .33371 Mtetra
.584 .674 .902 r
.34413 .33371 .35149 .343 .36333 .34208 .35603 .33179 Mtetra
.557 .639 .888 r
.35603 .33179 .36333 .34208 .37527 .34044 .36797 .33067 Mtetra
.599 .67 .89 r
.36797 .33067 .37527 .34044 .38749 .33435 .38004 .32835 Mtetra
.724 .811 .919 r
.38004 .32835 .38749 .33435 .39996 .3229 .39235 .32212 Mtetra
.847 .96 .881 r
.39235 .32212 .39996 .3229 .41217 .31859 .40489 .31083 Mtetra
.672 .75 .909 r
.40489 .31083 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.664 .741 .907 r
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.657 .738 .91 r
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .26174 Mtetra
.336 .593 .94 r
.54339 .26174 .55025 .26991 .56316 .26536 .55641 .26418 Mtetra
.364 .823 .923 r
.55641 .26418 .56316 .26536 .57624 .26806 .56947 .26152 Mtetra
.725 .816 .921 r
.56947 .26152 .57624 .26806 .58934 .26533 .58254 .25489 Mtetra
.73 .72 .841 r
.58254 .25489 .58934 .26533 .6024 .25808 .59563 .24703 Mtetra
.71 .702 .84 r
.59563 .24703 .6024 .25808 .61548 .25009 .60877 .23997 Mtetra
.689 .714 .867 r
.60877 .23997 .61548 .25009 .62863 .24337 .62199 .23413 Mtetra
.674 .729 .892 r
.62199 .23413 .62863 .24337 .64188 .23788 .6353 .22903 Mtetra
.666 .738 .903 r
.6353 .22903 .64188 .23788 .65521 .23296 .64867 .22419 Mtetra
.664 .74 .906 r
.64867 .22419 .65521 .23296 .66861 .22819 .66212 .21941 Mtetra
.664 .741 .907 r
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37433 Mtetra
.19615 .37433 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .3448 .30086 .337 Mtetra
.663 .74 .907 r
.30086 .337 .30846 .3448 .32032 .34068 .31276 .33279 Mtetra
.659 .738 .908 r
.31276 .33279 .32032 .34068 .33222 .33683 .3247 .32868 Mtetra
.647 .728 .907 r
.3247 .32868 .33222 .33683 .34413 .33371 .33667 .3249 Mtetra
.621 .703 .903 r
.33667 .3249 .34413 .33371 .35603 .33179 .34866 .32188 Mtetra
.587 .662 .89 r
.34866 .32188 .35603 .33179 .36797 .33067 .36066 .31988 Mtetra
.57 .636 .877 r
.36066 .31988 .36797 .33067 .38004 .32835 .37271 .3184 Mtetra
.601 .669 .887 r
.37271 .3184 .38004 .32835 .39235 .32212 .38488 .31594 Mtetra
.688 .802 .935 r
.38488 .31594 .39235 .32212 .40489 .31083 .39723 .31083 Mtetra
.734 .979 .917 r
.39723 .31083 .40489 .31083 .4172 .30623 .40974 .30253 Mtetra
.795 .892 .914 r
.40974 .30253 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.664 .741 .907 r
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.487 .667 .942 r
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .26205 Mtetra
.376 .759 .989 r
.52354 .26205 .5305 .26606 .54339 .26174 .5365 .2614 Mtetra
.408 .857 .896 r
.5365 .2614 .54339 .26174 .55641 .26418 .54952 .25753 Mtetra
.723 .812 .921 r
.54952 .25753 .55641 .26418 .56947 .26152 .56259 .25096 Mtetra
.723 .716 .843 r
.56259 .25096 .56947 .26152 .58254 .25489 .57568 .2434 Mtetra
.707 .693 .834 r
.57568 .2434 .58254 .25489 .59563 .24703 .58882 .23636 Mtetra
.69 .703 .857 r
.58882 .23636 .59563 .24703 .60877 .23997 .60203 .23034 Mtetra
.676 .722 .884 r
.60203 .23034 .60877 .23997 .62199 .23413 .61531 .22509 Mtetra
.668 .734 .9 r
.61531 .22509 .62199 .23413 .6353 .22903 .62866 .22018 Mtetra
.665 .739 .906 r
.62866 .22018 .6353 .22903 .64867 .22419 .64209 .21536 Mtetra
.664 .741 .907 r
.64209 .21536 .64867 .22419 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37433 .18821 .36679 Mtetra
.18821 .36679 .19615 .37433 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33279 .30513 .32489 Mtetra
.662 .74 .907 r
.30513 .32489 .31276 .33279 .3247 .32868 .31711 .32064 Mtetra
.658 .736 .907 r
.31711 .32064 .3247 .32868 .33667 .3249 .32913 .3165 Mtetra
.646 .723 .905 r
.32913 .3165 .33667 .3249 .34866 .32188 .3412 .3127 Mtetra
.624 .697 .897 r
.3412 .3127 .34866 .32188 .36066 .31988 .35328 .30954 Mtetra
.598 .66 .881 r
.35328 .30954 .36066 .31988 .37271 .3184 .36539 .30717 Mtetra
.585 .636 .868 r
.36539 .30717 .37271 .3184 .38488 .31594 .37755 .30524 Mtetra
.598 .653 .876 r
.37755 .30524 .38488 .31594 .39723 .31083 .3898 .30287 Mtetra
.64 .738 .92 r
.3898 .30287 .39723 .31083 .40974 .30253 .40218 .29916 Mtetra
.672 .891 .977 r
.40218 .29916 .40974 .30253 .4223 .29371 .41468 .29382 Mtetra
.614 .951 .92 r
.41468 .29382 .4223 .29371 .43475 .28927 .42726 .28741 Mtetra
.694 .94 .962 r
.42726 .28741 .43475 .28927 .44726 .28481 .43989 .28088 Mtetra
.695 .882 .967 r
.43989 .28088 .44726 .28481 .45982 .28033 .45254 .27509 Mtetra
.655 .832 .968 r
.45254 .27509 .45982 .28033 .47245 .27583 .46521 .27055 Mtetra
.596 .813 .983 r
.46521 .27055 .47245 .27583 .48513 .27131 .47793 .26727 Mtetra
.518 .826 1 r
.47793 .26727 .48513 .27131 .49788 .26676 .49071 .26474 Mtetra
.427 .841 .967 r
.49071 .26474 .49788 .26676 .51068 .2622 .50356 .2621 Mtetra
.383 .844 .88 r
.50356 .2621 .51068 .2622 .52354 .26205 .5165 .25837 Mtetra
.663 .89 .98 r
.5165 .25837 .52354 .26205 .5365 .2614 .5295 .25301 Mtetra
.719 .764 .888 r
.5295 .25301 .5365 .2614 .54952 .25753 .54255 .24629 Mtetra
.711 .699 .837 r
.54255 .24629 .54952 .25753 .56259 .25096 .55564 .23911 Mtetra
.699 .684 .832 r
.55564 .23911 .56259 .25096 .57568 .2434 .56877 .23237 Mtetra
.687 .695 .852 r
.56877 .23237 .57568 .2434 .58882 .23636 .58197 .22642 Mtetra
.676 .715 .878 r
.58197 .22642 .58882 .23636 .60203 .23034 .59524 .22111 Mtetra
.668 .731 .896 r
.59524 .22111 .60203 .23034 .61531 .22509 .60857 .21615 Mtetra
.665 .738 .904 r
.60857 .21615 .61531 .22509 .62866 .22018 .62197 .2113 Mtetra
.664 .74 .907 r
.62197 .2113 .62866 .22018 .64209 .21536 .63544 .20646 Mtetra
.664 .741 .907 r
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32489 .29743 .31693 Mtetra
.664 .74 .907 r
.29743 .31693 .30513 .32489 .31711 .32064 .30945 .31261 Mtetra
.662 .739 .907 r
.30945 .31261 .31711 .32064 .32913 .3165 .32151 .30831 Mtetra
.658 .735 .906 r
.32151 .30831 .32913 .3165 .3412 .3127 .33363 .30411 Mtetra
.649 .722 .902 r
.33363 .30411 .3412 .3127 .35328 .30954 .34579 .30017 Mtetra
.633 .698 .892 r
.34579 .30017 .35328 .30954 .36539 .30717 .35798 .29669 Mtetra
.615 .666 .876 r
.35798 .29669 .36539 .30717 .37755 .30524 .3702 .29375 Mtetra
.603 .641 .861 r
.3702 .29375 .37755 .30524 .3898 .30287 .38248 .29118 Mtetra
.604 .638 .858 r
.38248 .29118 .3898 .30287 .40218 .29916 .39483 .28857 Mtetra
.618 .668 .876 r
.39483 .28857 .40218 .29916 .41468 .29382 .40727 .28548 Mtetra
.639 .731 .915 r
.40727 .28548 .41468 .29382 .42726 .28741 .4198 .28172 Mtetra
.648 .815 .963 r
.4198 .28172 .42726 .28741 .43989 .28088 .43242 .27744 Mtetra
.626 .882 .988 r
.43242 .27744 .43989 .28088 .45254 .27509 .44509 .2729 Mtetra
.586 .905 .982 r
.44509 .2729 .45254 .27509 .46521 .27055 .45783 .26833 Mtetra
.587 .905 .982 r
.45783 .26833 .46521 .27055 .47793 .26727 .47063 .26372 Mtetra
.639 .886 .986 r
.47063 .26372 .47793 .26727 .49071 .26474 .48349 .25887 Mtetra
.686 .825 .95 r
.48349 .25887 .49071 .26474 .50356 .2621 .49642 .25347 Mtetra
.702 .752 .891 r
.49642 .25347 .50356 .2621 .5165 .25837 .5094 .24741 Mtetra
.701 .7 .846 r
.5094 .24741 .5165 .25837 .5295 .25301 .52244 .24085 Mtetra
.694 .676 .828 r
.52244 .24085 .5295 .25301 .54255 .24629 .53552 .23424 Mtetra
.687 .676 .834 r
.53552 .23424 .54255 .24629 .55564 .23911 .54865 .228 Mtetra
.68 .692 .854 r
.54865 .228 .55564 .23911 .56877 .23237 .56183 .22231 Mtetra
.673 .712 .878 r
.56183 .22231 .56877 .23237 .58197 .22642 .57508 .21707 Mtetra
.668 .728 .895 r
.57508 .21707 .58197 .22642 .59524 .22111 .5884 .2121 Mtetra
.665 .737 .903 r
.5884 .2121 .59524 .22111 .60857 .21615 .60178 .20722 Mtetra
.664 .74 .906 r
.60178 .20722 .60857 .21615 .62197 .2113 .61522 .20236 Mtetra
.664 .741 .907 r
.61522 .20236 .62197 .2113 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .31261 .30172 .30455 Mtetra
.664 .74 .907 r
.30172 .30455 .30945 .31261 .32151 .30831 .31382 .30017 Mtetra
.662 .739 .907 r
.31382 .30017 .32151 .30831 .33363 .30411 .32598 .29581 Mtetra
.66 .735 .905 r
.32598 .29581 .33363 .30411 .34579 .30017 .33819 .2915 Mtetra
.654 .724 .901 r
.33819 .2915 .34579 .30017 .35798 .29669 .35044 .28736 Mtetra
.644 .706 .891 r
.35044 .28736 .35798 .29669 .3702 .29375 .36275 .28347 Mtetra
.633 .68 .877 r
.36275 .28347 .3702 .29375 .38248 .29118 .37509 .27988 Mtetra
.625 .656 .861 r
.37509 .27988 .38248 .29118 .39483 .28857 .38749 .27652 Mtetra
.622 .641 .848 r
.38749 .27652 .39483 .28857 .40727 .28548 .39996 .27319 Mtetra
.625 .639 .844 r
.39996 .27319 .40727 .28548 .4198 .28172 .4125 .2697 Mtetra
.634 .649 .847 r
.4125 .2697 .4198 .28172 .43242 .27744 .42512 .26589 Mtetra
.645 .663 .853 r
.42512 .26589 .43242 .27744 .44509 .2729 .43781 .26168 Mtetra
.656 .675 .856 r
.43781 .26168 .44509 .2729 .45783 .26833 .45058 .25706 Mtetra
.665 .679 .853 r
.45058 .25706 .45783 .26833 .47063 .26372 .46341 .25204 Mtetra
.672 .674 .844 r
.46341 .25204 .47063 .26372 .48349 .25887 .47631 .24663 Mtetra
.676 .667 .833 r
.47631 .24663 .48349 .25887 .49642 .25347 .48926 .24089 Mtetra
.678 .662 .827 r
.48926 .24089 .49642 .25347 .5094 .24741 .50227 .23497 Mtetra
.678 .665 .83 r
.50227 .23497 .5094 .24741 .52244 .24085 .51533 .22908 Mtetra
.676 .677 .844 r
.51533 .22908 .52244 .24085 .53552 .23424 .52844 .22342 Mtetra
.673 .696 .863 r
.52844 .22342 .53552 .23424 .54865 .228 .54161 .21806 Mtetra
.67 .715 .882 r
.54161 .21806 .54865 .228 .56183 .22231 .55484 .21296 Mtetra
.667 .729 .896 r
.55484 .21296 .56183 .22231 .57508 .21707 .56814 .20801 Mtetra
.665 .736 .903 r
.56814 .20801 .57508 .21707 .5884 .2121 .5815 .20312 Mtetra
.664 .74 .906 r
.5815 .20312 .5884 .2121 .60178 .20722 .59492 .19824 Mtetra
.664 .741 .907 r
.59492 .19824 .60178 .20722 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30017 .30606 .29201 Mtetra
.664 .74 .907 r
.30606 .29201 .31382 .30017 .32598 .29581 .31825 .28757 Mtetra
.663 .739 .907 r
.31825 .28757 .32598 .29581 .33819 .2915 .3305 .28313 Mtetra
.661 .736 .905 r
.3305 .28313 .33819 .2915 .35044 .28736 .34281 .27871 Mtetra
.658 .729 .902 r
.34281 .27871 .35044 .28736 .36275 .28347 .35516 .27436 Mtetra
.654 .717 .895 r
.35516 .27436 .36275 .28347 .37509 .27988 .36757 .27011 Mtetra
.649 .701 .884 r
.36757 .27011 .37509 .27988 .38749 .27652 .38004 .26597 Mtetra
.645 .682 .871 r
.38004 .26597 .38749 .27652 .39996 .27319 .39256 .2619 Mtetra
.642 .667 .858 r
.39256 .2619 .39996 .27319 .4125 .2697 .40514 .25782 Mtetra
.643 .657 .848 r
.40514 .25782 .4125 .2697 .42512 .26589 .41779 .25362 Mtetra
.647 .652 .841 r
.41779 .25362 .42512 .26589 .43781 .26168 .43051 .24921 Mtetra
.651 .651 .837 r
.43051 .24921 .43781 .26168 .45058 .25706 .4433 .24456 Mtetra
.657 .653 .835 r
.4433 .24456 .45058 .25706 .46341 .25204 .45615 .23965 Mtetra
.662 .658 .836 r
.45615 .23965 .46341 .25204 .47631 .24663 .46907 .23453 Mtetra
.665 .666 .841 r
.46907 .23453 .47631 .24663 .48926 .24089 .48204 .22929 Mtetra
.668 .677 .85 r
.48204 .22929 .48926 .24089 .50227 .23497 .49508 .22404 Mtetra
.669 .692 .863 r
.49508 .22404 .50227 .23497 .51533 .22908 .50817 .21886 Mtetra
.668 .708 .877 r
.50817 .21886 .51533 .22908 .52844 .22342 .52132 .21378 Mtetra
.667 .722 .89 r
.52132 .21378 .52844 .22342 .54161 .21806 .53453 .2088 Mtetra
.665 .732 .899 r
.53453 .2088 .54161 .21806 .55484 .21296 .5478 .20389 Mtetra
.664 .737 .904 r
.5478 .20389 .55484 .21296 .56814 .20801 .56114 .199 Mtetra
.664 .74 .906 r
.56114 .199 .56814 .20801 .5815 .20312 .57454 .19411 Mtetra
.664 .741 .907 r
.57454 .19411 .5815 .20312 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .29201 .29823 .28378 Mtetra
.29823 .28378 .30606 .29201 .31825 .28757 .31046 .2793 Mtetra
.31046 .2793 .31825 .28757 .3305 .28313 .32275 .27479 Mtetra
.663 .74 .907 r
.32275 .27479 .3305 .28313 .34281 .27871 .33509 .27028 Mtetra
.663 .738 .906 r
.33509 .27028 .34281 .27871 .35516 .27436 .34749 .26576 Mtetra
.662 .735 .904 r
.34749 .26576 .35516 .27436 .36757 .27011 .35994 .26125 Mtetra
.66 .728 .9 r
.35994 .26125 .36757 .27011 .38004 .26597 .37245 .25676 Mtetra
.658 .72 .894 r
.37245 .25676 .38004 .26597 .39256 .2619 .38502 .25228 Mtetra
.657 .711 .887 r
.38502 .25228 .39256 .2619 .40514 .25782 .39765 .24779 Mtetra
.657 .702 .88 r
.39765 .24779 .40514 .25782 .41779 .25362 .41035 .24327 Mtetra
.657 .696 .874 r
.41035 .24327 .41779 .25362 .43051 .24921 .4231 .23866 Mtetra
.659 .693 .871 r
.4231 .23866 .43051 .24921 .4433 .24456 .43592 .23396 Mtetra
.661 .694 .87 r
.43592 .23396 .4433 .24456 .45615 .23965 .4488 .22917 Mtetra
.663 .698 .872 r
.4488 .22917 .45615 .23965 .46907 .23453 .46174 .2243 Mtetra
.664 .705 .877 r
.46174 .2243 .46907 .23453 .48204 .22929 .47475 .21938 Mtetra
.665 .714 .884 r
.47475 .21938 .48204 .22929 .49508 .22404 .48781 .21446 Mtetra
.665 .722 .892 r
.48781 .21446 .49508 .22404 .50817 .21886 .50094 .20955 Mtetra
.665 .73 .898 r
.50094 .20955 .50817 .21886 .52132 .21378 .51412 .20465 Mtetra
.664 .735 .903 r
.51412 .20465 .52132 .21378 .53453 .2088 .52738 .19976 Mtetra
.664 .739 .905 r
.52738 .19976 .53453 .2088 .5478 .20389 .54069 .19486 Mtetra
.664 .74 .907 r
.54069 .19486 .5478 .20389 .56114 .199 .55407 .18995 Mtetra
.664 .741 .907 r
.55407 .18995 .56114 .199 .57454 .19411 .56752 .18502 Mtetra
.56752 .18502 .57454 .19411 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .2793 .3026 .27096 Mtetra
.3026 .27096 .31046 .2793 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27028 .3273 .26185 Mtetra
.664 .74 .907 r
.3273 .26185 .33509 .27028 .34749 .26576 .33973 .25727 Mtetra
.663 .74 .907 r
.33973 .25727 .34749 .26576 .35994 .26125 .35223 .25267 Mtetra
.663 .738 .906 r
.35223 .25267 .35994 .26125 .37245 .25676 .36478 .24806 Mtetra
.663 .736 .904 r
.36478 .24806 .37245 .25676 .38502 .25228 .37739 .24343 Mtetra
.663 .733 .902 r
.37739 .24343 .38502 .25228 .39765 .24779 .39006 .23878 Mtetra
.662 .73 .9 r
.39006 .23878 .39765 .24779 .41035 .24327 .40279 .23411 Mtetra
.662 .728 .898 r
.40279 .23411 .41035 .24327 .4231 .23866 .41559 .22941 Mtetra
.663 .726 .896 r
.41559 .22941 .4231 .23866 .43592 .23396 .42844 .22467 Mtetra
.42844 .22467 .43592 .23396 .4488 .22917 .44136 .21989 Mtetra
.664 .728 .897 r
.44136 .21989 .4488 .22917 .46174 .2243 .45433 .21508 Mtetra
.664 .731 .899 r
.45433 .21508 .46174 .2243 .47475 .21938 .46737 .21024 Mtetra
.664 .734 .902 r
.46737 .21024 .47475 .21938 .48781 .21446 .48048 .20538 Mtetra
.664 .736 .904 r
.48048 .20538 .48781 .21446 .50094 .20955 .49364 .20051 Mtetra
.664 .738 .905 r
.49364 .20051 .50094 .20955 .51412 .20465 .50687 .19562 Mtetra
.664 .74 .906 r
.50687 .19562 .51412 .20465 .52738 .19976 .52016 .19071 Mtetra
.664 .74 .907 r
.52016 .19071 .52738 .19976 .54069 .19486 .53352 .18578 Mtetra
.664 .741 .907 r
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25337 Mtetra
.31944 .25337 .3273 .26185 .33973 .25727 .33191 .24874 Mtetra
.33191 .24874 .33973 .25727 .35223 .25267 .34444 .24409 Mtetra
.664 .74 .907 r
.34444 .24409 .35223 .25267 .36478 .24806 .35703 .23942 Mtetra
.35703 .23942 .36478 .24806 .37739 .24343 .36968 .23473 Mtetra
.664 .739 .906 r
.36968 .23473 .37739 .24343 .39006 .23878 .38239 .23002 Mtetra
.38239 .23002 .39006 .23878 .40279 .23411 .39516 .22528 Mtetra
.664 .738 .905 r
.39516 .22528 .40279 .23411 .41559 .22941 .40799 .22052 Mtetra
.40799 .22052 .41559 .22941 .42844 .22467 .42088 .21574 Mtetra
.42088 .21574 .42844 .22467 .44136 .21989 .43384 .21093 Mtetra
.43384 .21093 .44136 .21989 .45433 .21508 .44685 .2061 Mtetra
.664 .739 .906 r
.44685 .2061 .45433 .21508 .46737 .21024 .45993 .20124 Mtetra
.45993 .20124 .46737 .21024 .48048 .20538 .47307 .19636 Mtetra
.664 .74 .907 r
.47307 .19636 .48048 .20538 .49364 .20051 .48628 .19146 Mtetra
.48628 .19146 .49364 .20051 .50687 .19562 .49955 .18654 Mtetra
.664 .741 .907 r
.49955 .18654 .50687 .19562 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25337 .31152 .2448 Mtetra
.31152 .2448 .31944 .25337 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23074 Mtetra
.34921 .23074 .35703 .23942 .36968 .23473 .3619 .226 Mtetra
.3619 .226 .36968 .23473 .38239 .23002 .37465 .22125 Mtetra
.37465 .22125 .38239 .23002 .39516 .22528 .38745 .21647 Mtetra
.38745 .21647 .39516 .22528 .40799 .22052 .40032 .21166 Mtetra
.40032 .21166 .40799 .22052 .42088 .21574 .41325 .20684 Mtetra
.41325 .20684 .42088 .21574 .43384 .21093 .42625 .20199 Mtetra
.42625 .20199 .43384 .21093 .44685 .2061 .4393 .19712 Mtetra
.4393 .19712 .44685 .2061 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23074 .34133 .22198 Mtetra
.34133 .22198 .34921 .23074 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22125 .36683 .2124 Mtetra
.36683 .2124 .37465 .22125 .38745 .21647 .37968 .20758 Mtetra
.37968 .20758 .38745 .21647 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20684 .40556 .19786 Mtetra
.40556 .19786 .41325 .20684 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19712 .43169 .18806 Mtetra
.43169 .18806 .4393 .19712 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10479 Mtetra
.48753 .10479 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14232 Mtetra
.3579 .14232 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10479 .47978 .09488 Mtetra
.47978 .09488 .48753 .10479 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17854 Mtetra
.23279 .17854 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000008l0ZKgX00<000000:Vmj02Y_NP0
7P2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000002A0:Vmj0030000
002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00002D0:Vmj0030000002Y
_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00001O0:Vmj0<0ZKgW=@2Y_NP0
0`000000ZKgX0:Vmj00P0:Vmj0030000003oool0oooo04@0oooo001E0?ooo`030:Vmj00000000000
0600ZKgX1P2Y_NL20:Vmj0<0ZKgW1`2Y_NP30:VmibD0ZKgX00<000000:Vmj02Y_NP08@2Y_NP00`00
0000oooo0?ooo`130?ooo`00D`3oool3000000030:Vmj0000000ZKgX0500ZKgX1@2Y_NL60:Vmj0D0
ZKcW2`2Y_NL40:Vmj0H0ZKgW0P2Y_NP30:Vmial0ZKgX00<000000:Vmj02Y_NP08P2Y_NP00`000000
oooo0?ooo`120?ooo`00D@3oool2000005@0ZKgX202Y_NL30:Vmj0d0ZKcW1@2Y_NL50:Vli`/0ZKgW
7P2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001>0?ooo`<00000E02Y
_NP;0:Vmi`P0ZKcW0`2Z^^D50:Vli`80ZKgW0`2Z^nH50:Vli`D0Z[cW2`2Y_NLH0:Vmj0030000002Y
_NP0ZKgX02<0ZKgX00<000000?ooo`3oool0@@3oool001T0oooo00<0omnL04P0M02oool00P3oool0
1@3oohl0=@000000000055l0a?oo02T0oooo0P00001C0:Vmj0D0ZKcW1P2Y_NL50:VkiPD0ZKcW1P2Z
^^D40:Vli`H0Z[_V0P2Y_>L30:Zji@D0Z[cW0P2Y_NL30:Zli`H0ZKgW5`2Y_NP00`000000ZKgX0:Vm
j00T0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX04h0ZKgX202Y_>L30:Vm
i`P0ZK_V1@2Z^>@50:Zji@D0Z[SS1@2Z^nH60:Zji@X0Z[cW0`2Y_NL30:ZliaH0ZKgX00<000000:Vm
j02Y_NP0902Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Vmj0000000000005@0ZKgX2`2Y_>L80:VkiP<0Z[KR1@2Z^>@20:Zji@<0ZkGP1@2Z^><50:^gh@D0
Z[[U1@2[^^D<0:ZliaH0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`080?ooo`06
0?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`00
07@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501O
a?l0803oool3000005<0ZKgX2P2Y_>L50:Vji@D0ZK_V1P2Z]^840:Zhi0H0ZkGP0P2Z^><30:bbg0D0
ZkOQ0P2Z^^D30:bfh0D0Zk[U1P2[^nD50:Zli`D0Z[gW4@2Y_NP00`000000ZKgX0:Vmj00T0:Vmj003
0000003oool0oooo00P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?oo
o`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Coo`3oool0oon?03D0501Oa?l07P3oool3000005<0
ZKgX202Y_>L50:Vii@D0ZK[U1@2Y]>050:ZfhPD0Zk7L1@2[]N060:bbg0@0ZkOQ1P2/]^020:^ji@<0
[KOP1P2[^nD20:Zli`<0Zk_V1@2Z_NL50:Vmi`/0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000
oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`006@3oool02`3o
gi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0oooo0`00001D0:Vmj0P0
ZKcW202Y^ND20:Vji@<0ZK;O1@2Y]>020:ZfhP<0ZjgI1@2[/M`20:^eh0<0[JgH1@2//]`50:jafPD0
[;KP1P2]]n050:^ki@H0Zk_V0P2Z_NL30:Zli`D0ZKgW2P2Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo00H0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000G0?oo
o`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?oo
o`800000D`2Y_NP50:Vmi`D0ZKcW2P2Y^ND60:Vbg`@0ZKCP1@2[[MT50:^ag0H0[JgH0P2//]`30:n]
e@D0[[7J0P2/]^030:nafPH0[KOP1@2]^>850:^kiPH0Z[cW102Y_NL:0:Vmj0030000002Y_NP0ZKgX
02H0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03o
ool001P0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?oo
o`<00000D@2Y_NP:0:Vmi`D0ZK[U1@2Y^ND50:VagPD0ZK;O1@2ZZ]L50:^]f@80Zk7L0`2]Z]@50:f]
f0D0[jgE1@2^/MX60:nafP<0[KOP0`2`/m/50:fhhPD0[;[T1@2Z_>L50:Zmi`T0ZKgX00<000000:Vm
j02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e00000000000DG`34ool0503o
ool3000000030:Vmj0000000ZKgX0580ZKgX1`2Y_NL30:VjiPD0ZK[U0P2Y^ND30:RagPD0ZK7N0P2Y
/]l30:VXePD0ZZ[G102[[MT60:fZe080[JgH0`2a[M<50:n]e@80[[7J0`2b[m@60:nafPH0/;?K0P2]
^>830;2fg@D0[;[T1@2[_>H50:Zmi`P0ZKgX00<000000:Vmj02Y_NP0:02Y_NP00`000000oooo0?oo
o`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo00<0ZKgX000000000000
F@2Y_NP40:Vmi`H0ZK[V102Y^^D60:RagP@0ZK7N1@2YZ=H50:ZZe`D0[JWC1@2]Z]@50;6]d`D0[jgE
1P2b[m@30:nafP<0];7E1@2`/m/60;2fg@80[;[T0`2_^N450:^liPD0Z[gW1`2Y_NP00`000000ZKgX
0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`00
<P3oool3000005/0ZKgX1@2Y^nH50:VjiPD0Z;;O1@2X/Mh50:RWe@D0ZJSF0P2ZZ]L30:fZe@D0[JWC
0P2]Z]@30;>cf0D0/JgC0P2_[MD30;JbePH0/ZoD1P2d/MD20;2cf`<0]K?G1@2`]]d60:nih@@0ZkcV
1P2Z_NL20:Vmj0<0Z[gW00<0ZKgX0000002Y_NP0:P2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03o
ool2000000030:Vmj0000000ZKgX05T0ZKgX0`2Y_>L50:VkiPD0Z;?Q1@2X/]l20:RagP<0YZKF102X
YmD50:VXePD0[J[E1@2]ZM<50;>cf0D0/JgC1P2f/]H30;:_e0<0^KOG1@2d/MD60;Fce`80/;KM0`2e
]]X50:nih@D0[K_U2P2Z_NL2000002`0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo00@0ZKgX
0000000000000000G02Y_NP60:Vli`<0ZK_V0P2X]^<50:Rch@@0Z;;O1P2VY]H40:RWe@80ZJSF0`2/
[=P50:fZe@80[JWC0`2c`>@50;>cf080/JgC0`2h`n<60;JbePD0^KOG102d/MD20;Zhe`D0]K?G1P2e
]]X20:nih@<0/[WN1@2]^nD50:^mi`070:Zmi`00000000000000002Z_NL0ZKgX0000000[0:Vmj003
0000003oool0oooo03T0oooo000[0?ooo`800000G02Y_NP:0:Vli`D0Z;KS1@2X/n440:FVe`H0YZKF
0`2XYmD60:b/f0@0[J[E1P2c`>@40;>cf0H0^<?S0`2f/]H30;W?j`D0^KOG0P2d/MD30;Zhe`@0]K?G
0P2k]mH50;FffPH0/[WN0P2]^nD30:nlh`80ZkgW0`0000050:Zmi`030000002Y_NP0ZKgX02X0ZKgX
00<000000?ooo`3oool0>03oool002T0oooo0P00001O0:Vmj0D0ZKcW1@2X^>@50:Rfh`80Z;?Q0`2T
Z=T40:FVe`D0YZKF102Z[MX60:b/f080[J[E0P2_do<60;?0i080/k?H0P2YhoX60;S3h`D0^Lo[1@2i
]mL60;Zhe`80]K?G102k]mH20;FffP<0^[SG1@2b^Mh40:nlh`<0000000@0ZkgW0:bmiP2/_NH0[;gV
1@2Z_NL00`000000ZKgX0:Vmj00Z0:Vmj0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d
000000000018W03Oool01`3oool200000600ZKgX0P2Y_>L30:RjiPD0Z;ST102X]^<50:BXf@D0YJKG
0P2VY]H30:N/f`@0ZZgJ1@2/[=P50:oCl`D0/l3T1@2YhoX30;S3h`<0J=_U1@2icn/20;Vge`<0^M3[
1@2j^=L60;^gePH0^[SG0P2b^Mh30;Jjg0030:nlh`00000000000080[kcS1@2/_NH50:Zmi`030:Vm
j0000000ZKgX02X0ZKgX00<000000?ooo`3oool0=`3oool001`0oooo00H0oooO09a80018W=l0oooo
0=nLB000M;l70?ooo`030000003oool0000005l0ZKgX1P2X^^H40:Rhi0D0Y:[K1@2TZ=T40:FVe`D0
YjcK1@2Z[MX50:?Ro0D0[m?c1P1Rf>440:WSnPH0J=_U102icn/60;W@j`80^[SG0`2lb>@40;^geP80
_/3K1@2j^=L30;Jjg0<000000P2__><30;6mhP@0[;gV1P2Z_NL00`2Y_NP000000:Vmj00Z0:Vmj003
0000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?oo
o`8000000P3oool00`000000ZKgX0:Vmj01H0:Vmj0D0ZKcW1@2X^^H50:F^gPD0Y:[K102TZ=T50:FY
fPD0YjcK0P2Z[MX409KWn`@0Xn;l0P1]eoL50:Vmj0D0O:[a1@2X_>P505JGl0<0GM;/1@2id>/60;c8
i080^kOF102n`=/20;Zhe`80_[cG0`0000030;Jjg0D0/KgR1@2/_NH50:Zmi`030:Vmj0000000ZKgX
02/0ZKgX00<000000?ooo`3oool0=@3oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00D0oooo00<000000?ooo`3oool00P3oool00`000000ZKgX0:Vmj01C0:Vmj0X0ZKcW1@2V/n85
0:F^gP@0Y:[K1@2RY]P50:FYfP@0YjcK0P2Fio/509S@n`<0Q=?o3@2Y_NP50:Rlj0D0ZKgX0`1DUNl5
06;Dk`D0_<ST1P2n`=/0102n_=L000000000000000020;jle`80][[L0`2j_=/20;6mhP<0/kkR1@2/
_NH50:Zmi`030:Vmj0000000ZKgX02X0ZKgX00<000000?ooo`3oool0=@3oool001`0oooo00L0okmd
0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool00`3ooomF0:Vmj0P0ZKcW
0P2W]nD50:JchP@0YJkN1@2OXmP50::Vf0@0YJWJ102Fio/30:ODm`D0V=3k402Y_NP20:Rlj0P0ZKgX
1@2X_>P304F=k@D0X]_k0`2n`=/3000000D0_[cG1@2j_=/60;>nhP@0[;gV1P2Z_NL00`2Y_NP00000
0:Vmj00Z0:Vmj0030000003oool0oooo03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vmj01C0:Vmj0D0ZKcW1@2W]nD40:JchPD0
WjCI102OXmP50::Vf0H0X>7l1P2We?LO0:Vmj0D0Z;cX1015SNd30:;Kn`<00000102jbND20;jle`<0
`<3J0`2j_=/20;jof`D0/kkR1@2]_^H50:Zmi`80ZKgX00<000000:Vmj02Y_NP0:@2Y_NP00`000000
oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX05<0ZKgX1@2X^^H50:Ngi@@0WjOL102OY=T509nS
f080XZKH0`2Ud?H30:3Qo0@0/N7g902Y_NP40:Rlj0@0OJ[`0`0000000`1=]oT0^/WU0;[9i@040;[9
i@H0`<3J00<0^[cK0;jof`2n_m/00P2n_m/20;>nhP<0]/3R1@2]_^H50:Zmi`030:Vmj0000000ZKgX
02X0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l6
0?ooo`030000003oool0oooo00L0ooooD02Y_NP50:Vli`D0Z;[V1@2R[^0409nWg0@0WjCI102OXmP6
0:G@mPD0/N7g:P2Y_NP300000080OJ[`0`1=]oT30;[9i@<0ZLcb1@30`=X50;jof`H0]/3R0P2]_^H3
0:joiPD0Z[gW00<0ZKgX0000002Y_NP0:P2Y_NP00`000000oooo0?ooo`0b0?ooo`007@3oool01@3o
okl0M00000000000B9`0gooo00H0oooo00<000000?ooo`3oool0203ooom@0:Vmj0D0ZKcW1@2T]>@4
0::^h0D0WjOL0`2OY=T50:>kjP<0YM3f1@2al?HZ0:Vmj08000001P2Y_NP304B;k0H0ZLcb0P30`=X3
0<33g080_[oK0`30`]/50;K0hPH0[[oV0P2Z_NL30:Znj0030:Vmj0000000ZKgX02T0ZKgX00<00000
0?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool02P3ooom@0:Vmj080ZKcW0`2W^NH50:Bd
i0@0XZkP102OYm`509j[h0@0Xk_Z0`2al?H[0:Vmj0<000002@2Y_NP304B;k0D0ZLcb1@30`m`60<32
f`80]/3R0`2g`^<50:joiPH0Z[kX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0a0?oo
o`009`3oool00`000000oooo0?ooo`0;0?ooodl0ZKgX1P2W^NH40:Bdi0@0XZkP1@2JXm/509j[h080
WO?[;02Y_NP3000000d0ZKgX0`1SW?0508_2n@<0`<?L0P2na=l50<32f`H0]l;S1@2^_nL50:Znj003
0:Vmj0000000ZKgX02X0ZKgX00<000000?ooo`3oool0<03oool002L0oooo00<000000?ooo`3oool0
303ooom;0:Vmj0D0Z;cW102W^NH509fZh0@0VZCL1@2JXm/209j[h0<0[>Cj0P3;i>TX0:Vmj0<00000
4@2Y_NP306>Ll0D0Rl;i00<0`<?L0;k4g`2na=l00P2na=l20<32f`<0`/GM0`2g`^<30;O4i0D0[[oW
1@2Z_^P00`2Y_NP000000:Vmj00Y0:Vmj0030000003oool0oooo0300oooo000W0?ooo`8000003P3o
oom;0:Vmj0D0Z;cW102R/^@409fZh0D0VZCL102JXm/40:cTnP@0bnCY902Y_NP3000001@0ZKgX101S
W?0408_2n@D0_/CO1P32aMd60;O4i080[[oW0`2]_nL50:Znj0030:Vmj0000000ZKgX02T0ZKgX00<0
00000?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3ooom;0:Vmj080Z;cW0`2V^>H4
0::bi0@0WJ[P102JY=`60:>lj`H0bnCY8@2Y_NP3000001P0ZKgX101nZo04072^m`80_/CO0`2l`n04
0<;5g@80`lSN1@2ga>@60:foi`D0Z[kX00<000000:Vmj02Y_NP0:@2Y_NP00`000000oooo0?ooo`0^
0?ooo`009`3oool00`000000oooo0?ooo`0?0?ooodX0ZKgX1P2V^>H40::bi0<0WJ[P1@2IYn040:>l
j`<0^o[Z8P2Y_NP3000001`0ZKgX0`1nZo04072^m`H0_<?P0P32aMd40<?8gPD0]/GU1@2]_nL60:Zn
j0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo0P00000A0?ooo`03
0000002Y_NP0ZKgX0480ZKgX1@2X_>L50:JhiP@0X[;T102EX]h509VWh080Xkc[0`2kn^X20:boj1h0
ZKgX0`00000P0:Vmj0<0SK7_101WW_050;c3h0D0`lSN0P33bn050;K5i@D0[KoW1@2Z_^P00`2Y_NP0
00000:Vmj00Y0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000ZKgX
0:Vmj0130:Vmj0@0Z;cW1@2O/^D409VXh@@0UJ;N102IYn030;_jjPD0[;oX6P2Y_NP3000000030:Vm
j02UW/h0YIk>0080YIk>7P2Y_NP408fak`@0Iik`0P2l`n030;c4h0<0`lSN1033bn020;K5i@<0]<GV
1@2]_nL50:Zmj0030:Vmj0000000ZKgX02T0ZKgX00<000000?ooo`3oool0;03oool000T0oooo00X0
oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0gia81@0000000`1d_ol0oooo0=nLB002
000000030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000ZKgX0:Vmj013
0:Vmj0@0YKWW1@2O/^D409VXh@@0UJ;N1@2`cNl20=Seh@D0[;oX5`2Y_NP2000000D0XiC62@2UW/hH
0:Vmj0D0SK7_0`1_VNT60;c4h0H0`l_P1P2daNH50:boj0@0Z[gX00<0ZKgX0000002Y_NP0:@2Y_NP0
0`000000oooo0?ooo`0:0?ooo`050=nLB000000000000000B02Lgol07@3oool000P0oooo00H0oooO
09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0okmd0018W03Oool0
oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0503oool00`000000ZKgX0:Vmj0100:Vm
j0<0Z;cX102U^NL409nbi@@0VJSQ1@2IZn<30;3=k`@0f?GQ602Y_NP3000000L0XiC60`2UW/h20;j[
a`D0YIk>602Y_NP508fak`<0KiWY0`2la>030;k6h0<0`l_P0`31c><30;C5iP<0//CW102/_nP50:Zm
j0030:Vmj0000000ZKgX02T0ZKgX00<000000?ooo`3oool0203oool01`3o_g@004RL0=ooo`3oool0
oooO09a8M02oool0703oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo
00<0omnL04P0001d_ol0203oool00`2oM000M;oo0?ooo`050?ooo`8000005P3ooom00:Vmj0H0Z;cX
102U^NL409JYh`@0TJ;P1@2IZn<20=SehAT0ZKgX0`0000000`2Y_NP0XiC60:>DaP080:>DaP040:FN
cP2nZlL0_Z_70;j[a`@0YIk>0P33]lhH0:Vmj0@0SK7_101_VNT60;k6h0H0`LcS1@2ba>L20:boj0<0
ZkkX1@2Z_NP00`2Y_NP000000:Vmj00Y0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3o
ool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0
0018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo01L0oooo?`2Y_NP50:Rl
j0D0W[?W0`2FZN<5096Rh080VJ_S0`2icn/20=[ch1D0ZKgX0`0000050:FNcPT0XiC61@2nZlL20:FN
cP@0`kO>602Y_NP407j[l0@0P9gU0`2na^030<;:h@<0`LcS0`2ncND40;;4i`H0ZkkX0P2Z_NP30:Vm
j0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?oo
o`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01P3oool02`3ooml0W4P004RLg`3o
ool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0603ooolo0:Vm
j0D0YK[X1@2N/nL309JYh`@0TJ;P102icn/40=[ch140ZKgX0`0000040:Vmj0@0YIk>1`2SU<H30;>Y
c`@0_Z_71P33]lhI0:Vmj0@0OZ_`1020WND60<;:h@H0_/gU102_`^P50:^nj0H0ZKgX00<000000:Vm
j02Y_NP0:02Y_NP00`000000oooo0?ooo`060?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cO
o`0L0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool01@3ookl0M018
09cOo`3ookl0M00000<0000000<0M;oo0?ooo`3oool0103oool2000001/0oooo>`2Y_NP40:Rlj0D0
YK[X102N/nL309JYh`D0VJ_S0P2icn/50=[ch0h0ZKgX0`0000070:Vmj0D0YIk>102SU<H50;>Yc`<0
_Z_70P32^M440<>gcP80d/O?6@2Y_NP306>Ll0D0UJSS1032b^420<G@h`<0_/gU0`2jbnL40:o2j0D0
Z[kX1P2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00<0oono07@00000
00000P0000000`1d_ol0oooo0?ooo`0K0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md001d_ol0oooO09a8B02Lgol02@3oool0
0`000000oooo0?ooo`0K0?oooc/0ZKgX102X_>P40:Fjj0D0UJcV0`2>Xn<509V[h`<0f_?P1@2/_nP9
0:Vmj0<000002`2Y_NP40:FNcP80XiC60`2VY=<50;>Yc`030;j[a`32^M40`[WA0080`[WA0P33]lh4
0=;7caT0ZKgX0`1SW?0509FXh`80`/[Q1035d><50;[;i`80[l;X0`2]`NP50:Znj0H0ZKgX00<00000
0:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`030?oog`2LB4P0W=oo0200oooo00080?oo
o`060?oog`2LB000M;oo0?ooo`3OW4P007Bo103oool02P3ookl0M01809cOo`3oool0omnL04P0B02L
gol0oooo0;md001d_ol90?ooo`030000003oool0oooo01`0oooo>`2Y_NP40:Rlj0@0X;KX1@2E[>H3
08jSh`<0VJ_S0`2ga^D20=[Mf@D0[;oX1@2Y_NP3000000h0ZKgX102UW/h50:JTd`D0/jW?1P32^M45
0=;7c`030=WHeP2Y_NP0ZKgX01H0ZKgX101SW?0409FXh`D0aM3S0P34dnD40;[;i`H0[L7X1@2Z_NP5
0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?ooo`3oool01@3oool00`2oM000M;oo0?ooo`0O
0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P000000000000007Bo
o`020?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`000000oooo0?ooo`0M0?ooocX0
ZKgX1@2V^nP40:2fj0@0UJcV102>Xn<40;O6i@@0f]gI1`2Y_NP2000000l0ZKgX0`1nR]D409JIe@D0
YZCC0P2cZLl30;FffP@0`[WA0P34aM/30=;7c`<0fMSF602Y_NP306J1f@D0Z[OS0`35d><30<CCi@D0
]<SY0`2]`NP30:^oj0D0Z[gX1@2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo00D0
oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo>P2Y_NP50:Jk
j0@0Uk7Y102<Y^H409>Xi080]lKU103JgMT20<_Tj@<0ZKgX0`00000A0:Vmj0<0OX[E1@2FVMD40:JT
d`H0]KKJ0P32^M440<C5f`040=;7c`3If=H0fMSF0=WHeP80dO7W602Y_NP306J1f@D0Z[OS1034dnD2
0<3Cj0D0]<SY1P2[_nP40:Zmj0H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0V
0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooocX0ZKgX1@2S^NT409Naj@@0S:KV102CZ>@40=[M
f@<0bnCY0`00000E0:Vmj0<0OX[E102FVMD50:Rbg`D0]KKJ1P34aM/30=WHeP@0dO7W5`2Y_NP406J1
f@80Z[OS102jb>D50<3Cj0D0/<CY1@2[_nP:0:Vmj0030000002Y_NP0ZKgX02P0ZKgX00<000000?oo
o`3oool09@3oool002D0oooo00<000000?ooo`3oool0803ooolf0:Vmj0@0Z;cX1@2S^NT409Naj@<0
S:KV1P2Z^N@20<_Tj@<0000000<0bnCY0:Vmj02Y_NP04P2Y_NP306RQlP<0OX[E1@2IZ^850:Rbg`80
]KKJ0`2f`N<30<C5f`<0b=?S1P3AlNLD0:Vmj0@0OZW_0`26UM/50;[8i@80`mCW0P30dnP30;W>jPD0
/<CY1@2Z_^P:0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool09@3oool002@0oooo
0P00000S0?ooocH0ZKgX102X_>P40:>ij@D0SZ_Z0`2:YNL40:Zii0<000006@2Y_NP306RQlP<0OY[S
1@2IZ^840:Rbg`H0]/7S1038dn<30<k/jQT0ZKgX0`1nZNl408JEf`<0^/SU0`33e>L60;W>jPD0[<7X
102Z_^P;0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool0903oool002@0oooo00<0
00000?ooo`3oool08`3ooolf0:Vmj0<0Z;cX1@2M]^X508j[jP<0RZGW0`0000030<O9f`80e]3C5`2Y
_NP406RQlP<0OY[S102IZ^850:Vmj0<0]/7S0`2gcn`20<SCh`<0c^cZ0P3AlNLH0:Vmj0@0OZW_1026
UM/40<?Di`80`mSY0`2ic^X30;;7jPD0[<7X102Z_NP;0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<0
00000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0903ooole0:Vmj0D0Y[_Y102M]^X4
08j[jP<000001@37bM/40=K@daL0ZKgX0`0hQ^/307jJh`D0V[S]1@2Y_NP60;O?k0<0c^cZ103AlNLC
0:Vmj0D0Z;cX0`1bOLl60:Rhi0D0`mSY1P2banX20:c1j0<0ZkkX102Z_NP:0:Vmj0030000002Y_NP0
ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?ooocD0ZKgX1@2V^nT409Jc
k0<0000000<0QJO[09F]i`2E[NL00P2E[NL20<O9f`@0e]3C0P3@dMXG0:Vmj0<0>8K[0`1kZo8509Zh
k@D0Z<_b0`2gcn`40;OUmP@0dO7W5@2Y_NP40:Rlj0@0LWg?102X^>@20;gBjP80`mSY0`2ldn/50;;7
jPD0ZkkX0P2Z_NP=0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08P3oool002<0
oooo0P00000X0?ooocD0ZKgX1@2S^^T0102F/n`000000000002F/n`408FWj`@0UJgW103Fd=<40=3A
fQL0ZKgX0`0hQ^/307^[lPD0U<Oi1@2Xbo840;OUmP@0VoCS602Y_NP40:Rlj0@0LWg?0P2X^>@30;gB
jPH0_=?[1@2]`^T40:^nj100ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0Q0?oo
o`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia800800000
00<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?oooc00ZKgX102X_NP20:>jj@<00000
0`2F/n`408FWj`H0Z;ST1P3@dMXH0:Vmj0<0>8K[101V^?`409C7n@H0Wmom0P2Km><J0:Vmj0<0ZK_V
0`1iP<h4079mc`@0_M;Z0P32fn`30;cCj`<0/l[[1@2]`^T40:Znj100ZKgX00<000000:Vmj02Y_NP0
9P2Y_NP00`000000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool`
0:Vmj080Z;gX0`0000040:2ij`<0S[3]1023Yn`30:Rhi0<0^/3N0`3@dMX30<K<gQP0ZKgX0`1XXO84
06Jho0D0MmCn0P1TfMTL0:Vmj0D0ZK_V101iP<h509^[hPD0`]_/1P2cb^/50:^oj0@0Z[kX3`2Y_NP0
0`000000ZKgX0:Vmj00W0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo;P2Y_NP3000000<0YkcX1@2P
^N/308j`k@@0PjO/1P2j`=h60<K<gQP0ZKgX0P1XXO830:Vmj0<0J:7b0P1Lc?HP0:Vmj0D0ZK_V101i
P<h209^[hP<0^M;]0P32fn`30;_Fk@<0/l[[0`2^`nT40:^oj1@0ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02`0oooo:P2Y_NP3000000<0ZKgX
102W_>P40:2ij`@0S[3]1025Znd40;[0gP80a/?H0`36c=h30;g2gQd0ZKgX0P1XXO8S0:Vmj0@0ZK_V
101iP<h50;WBk@H0^mK]1@2^`nT50:Znj1@0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo
0?ooo`0O0?ooo`00303oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0
B01809cOo`3oool0oooO09a8B02Lgol01P3oool00`000000oooo0?ooo`0]0?ooobH0ZKgX0`000007
0:Vmj0@0YkcX102L^>`408N^k`@0QJ_]0P2j`=h40<K3f0H0_L;N?@2Y_NP50:FRd`<0OGo;1@2KZn83
0;WBk@<0_mk_1@2cbn`30:k3j@80ZkoX1@2Z_^PC0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<00000
0?ooo`3oool07P3oool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0
oono07@0000000000P0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y
_NP3000000X0ZKgX1@2V_>T409bhk0@0Qjk_0`25Znd50<K3f080blCD0`2m`]h30;^jf3d0ZKgX102U
X]<407eob`D0Vj_R0`2og^l30;WEkPD0/l_/1@2[_nP20:Znj1H0ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`0M0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
0`3oool00`3ooml0W4Q809cOo`090?ooo`800000<@3ooolN0:Vmj0<000003P2Y_NP50:Jlj@@0VKS]
1022[O0408^`kP80a/?H103;a=@60;^jf3`0ZKgX1@2UX]<407eob`80Vj_R0`2heo060;WEkPD0[L;Y
102[_nPI0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00H0
oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3o
ool0<@3ooolK0:Vmj08000004P2Y_NP50:Flj@@0VKS]1022[O0408^`kPH0blCD102k^]P20;ngdS`0
ZKgX102UX]<407eob`@0^=O`0P2lgo430;WEkP<0/LS/102]`^T50:Znj1T0ZKgX00<000000:Vmj02Y
_NP09P2Y_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0
oooo00H0gia800000000000000000000M02oool50?ooo`030000003oool0oooo0380oooo5`2Y_NP3
000001D0ZKgX1@2U_>T309Vhk@D0Ojkb102>]?060<_4e080^k[H102o]m8f0:Vmj0<0YI_;0P2=R<T4
0:FRd`H0Xk[Y1@2lgo460;78k0@0ZkoX1@2Z_^PH0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<00000
0?ooo`3oool06`3oool00280oooo0P00000d0?oooa<0ZKgX0`00000I0:Vmj0D0YKcZ102H]nh407n^
lP@0S[C`1@3;a=@60;ngdS@0ZKgX1@2UVl/308f8b@@0SYGF0`2S^^T30;SOl`H0]M7_1@2/`NT40:^o
j1d0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000
oooo0?ooo`0d0?ooo`l0ZKgX0`00000I0:Vmj0D0Z;gX102U_>X409RgkP<0Ojkb1@2=]o830<_4e080
a/GI102o]m820<NicBl0ZKgX1@2WXm850:FKb`<0SHS9102>UMH40;SOl`80^=_b0`2edNl30:k5j`@0
[<7Y1@2Z_NPM0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06P3oool00280oooo
00<000000?ooo`3oool0=@3oool00`000000ZKgX0:Vmj0080:Vmj0<000007@2Y_NP50:Rmj0@0YKcZ
102G^>h307f_l`D0SKOb00<0blCD0<K5f@36aMT00P36aMT20;ngdP@0akW=1@2VXm8V0:Vmj0@0Z:[H
102WXm850:FKb`<0SHS91P2^d_<50;SKlPH0[/G[0P2/`NT20:Znj0D0Z[gX7@2Y_NP00`000000ZKgX
0:Vmj00U0:Vmj0030000003oool0oooo00`0oooo00<0omnL04P0M02oool00P3oool01@3ookl0M000
00000000B9`0gooo00@0oooo000R0?ooo`030000003oool0oooo03L0oooo1P2Y_NP300000240ZKgX
1@2X_NP40:FljP@0UkS^0`1m[o<408fglPD0a/GI1@37^Ld20<noc0D0YZ?B102Y^nHM0:Vmj0T0Z:[H
102WXm840:FKb`@0X[_[0`2^d_<30;KQm@D0/<_]1@2^aN/50:Znj080Z[gX7`2Y_NP00`000000ZKgX
0:Vmj00V0:Vmj0800000303oool02P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000
M;l40?ooo`008@3oool2000003X0oooo0P2Y_NP3000002@0ZKgX1P2X_NP30:FljPD0VKW^0`1o/O@4
08Jgm@<0a/GI0`2lan<20<Nic@@0cko<0P2VXm830;^]c0@0ZK_V602Y_NP50:NSdPP0Z:[H102WXm85
09^WgP@0X[_[102fhOD20;;Bl0D0/<_]1@2[_nT40:Znj280ZKgX00<000000:Vmj02Y_NP09P2Y_NP0
0`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool00240oooo00<000000?ooo`3oool0>03oool3000002P0ZKgX1@2X_NP40:Flj@D0
VKW^0`1o/O@408Jgm@H0_<OS1@3?_l`60;^]c0@0YIW91@2Y_NP50:VkiP`0ZKgX0P2UVl/50:NSdP<0
Z:[H1@2OV<d409^Kd`@0VjON1P2ah_P50;;Bl0D0[<7Y102[_nTW0:Vmj0030000002Y_NP0ZKgX02D0
ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0oooo0P0000030?ooobh0ZKgX102U
_>T509bjk@@0PkCd0`1m]_P30;c7h`<0Z<S`0`3?_l`20<O8f`@0^jg<0P3?`Ld40:FIb@D0Y9S81@2Y
^nH40:NSdPD0ZKgX102UVl/50:NSdP@0YIc<102OV<d509^Kd`80VjON0`2[g_T60;;Hm0@0[LC[1@2/
`NT40:Zmj2H0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;0?oOW018
07@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo0P00000d0?oo
o`<000001P3oool^0:Vmj0D0Y[cY102L^^d408>dm0<0OKKh1P2Xb?00103?_l`0alSK0<O8f`37b=/3
0;^]c0<0cl7=0`2UVLT20<Vjb`D0Y9S81@2UULD40:NSdPD0XiC5102UVl/20:NSdP<0[JC>0`2UW<`5
09nHc@@0Vi_C0`2[g_T30:oMm`<0/]Sd0`2]and40:g4j`D0Z[kX102Z_NPV0:Vmj0030000002Y_NP0
ZKgX02H0ZKgX00<000000?ooo`3oool0203oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo0300oooo0`0000090?ooobl0
ZKgX1@2V_>T409nkk0D0RkOc0`1g]?T40:S8l0D0alSK00<0^jg<0<o1c@3?`Ld00`3?`Ld0102UVLT0
bK[;0<Vjb`39^//40:BHb080bK[<102UULD20:NSdP<0^ZW9102SU<D40:FKb`D0[JC>102UW<`409nH
c@D0YmSi1P2_gOL50:g7k@D0Z[oX102Z_^P[0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?oo
o`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo
0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo
02d0oooo0`00000>0?ooobh0ZKgX1@2W_NT409nkk0D0U;Wa0`1j]OP408_3nP@0alSK1P3?`Ld50<Vj
b`80Y9S80`39^/`40:FEa@D0^ZW91@2SU<D20:FKb`80];7F1@2]Y<h30:FLc0H0Y]Ch1@2ZgoT60:g:
k`@0Zl3Y1@2Z_nP_0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool02`3o
_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo00030?ooo`060?oo
g`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?ooo`070?noM000B9`0gooo
0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00000B0?ooobh0ZKgX1@2W
_NT40:>lj`D0U;Wa0`1j]OP408_3nP@0ZLkc0`3?`Ld30;S@k0@0bK[;1P39^/`20:FEa@80`L;K1@2j
ZLT40:>Da@D0];7F102]Y<h70:KDn0@0YMok102/cO430:g:k`<0Zl7Z102[`>Tc0:Vmj0030000002Y
_NP0ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo00D0
oono07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool01@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<0
00005P3oool^0:Vmj0D0Z;gX102S_>/509bkkP<0QkSf1@1i^o/30:W>l`H0^=3/0P39^//20;WAk0D0
bK[<00@0YIG50<72f`31`]/0`L;K1@2jZLT50;O2hP@0];7F1@2TeoX40:KDn080YMok1@2ZcO840:c=
l@D0Zl7Z0P2[`>T30:Znj3<0ZKgX00<000000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?oo
o`3oool05@3oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd
0018W03Oool01`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J
0?ooobh0ZKgX1@2X_NP40:Jlj@D0W;_^0`27^?H507jjnP<0PlGm1@2hd>`50;WAk0@0bK[<1@31`]/2
0;ZYb@<0/=;b102g`^820;BaeP<0W][l1@2TeoX30:3Mo0<0Z<gc102ZcO850:[1jP@0Zl7Z1P2Z_^Pc
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX0`0000080?ooo`030000003oool0oooo01D0oooo00030?oo
o`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo0080oooo00L0
omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool08P3oool3000001h0
oooo<`2Y_NP40:Jlj@D0Xkc[102E^o8407jjnP<0PlGm1@2:c?h40;WAk0D0[]Cd1031`]/60;3BlP<0
]l;R1P2Nf_`509cKo@H0Z<gc102Z`^/50:[1jPL0Z[kX=P2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0@0
0000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@000<0000000<0M;oo0?ooo`3oool0103o
ool00`000000oooo0?ooo`0O0?ooo`<000008P3ooolc0:Vmj0@0Z;gY1@2S_>/409nlk@D0T;cd0`1m
__`408[<oPD0RLkn102^e?@509WGo@@0/=;b1@2Ef_h609WFo@D0Y/_c1@2Y`^/40:[2j`T0Z[kX>02Y
_NP00`000000ZKgX0:Vmj00?0:Vmj0040?ooo`000000000000000100oooo00<000000?ooo`3oool0
503oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00H0oooo00L0oono07@0B02L
gol0oooo0?oog`2LB4P0W=oo00T0oooo0P00000N0?ooo`8000009P3oool00`000000ZKgX0:Vmj00`
0:Vmj0@0Z;gY1@2V_NT409nlk@D0WKg_102?__H40833o@D0Q/Kl1025c_l508_>oPD0V/_i102HdO`6
0:G8lP@0ZL7[1@2Y`^/40:Vnj0D0Z[kX?02Y_NP00`000000ZKgX0:Vmj00:0:Vmj080oooo0`00000C
0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo203o
ool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3ooolf0:Vmj0D0
Y[gY102U_NX509fmk`@0W[k_1@2C`?H409[1l`D0TLOj102MaO@509[;n@D0Y<G`1@2X`>/40:W1j`T0
ZKkX@@2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00
103oool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0
oooo0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0
oooo=P2Y_NP50:Rmj0@0YKgZ1@2U_N/409jnk`D0XKk^102J`O<50:71k`@0WLGd1@2U`^h50:RojP@0
Z<3[2@2Y_^Q50:Vmj0030000002Y_NP0ZKgX00D0ZKgX0P00000J0?ooo`030000003oool0oooo01@0
oooo000O0?ooo`030000003oool0oooo01D0oooo0`00000b0?ooocH0ZKgX1@2X_NP40:Rmj@D0YKg[
102V_NX50:6nkP@0Y;k/1@2Q`Nl40:Jok0<0YL;^0P2X_^T50:RojPT0ZKkXB@2Y_NP010000000ZKgX
0:Vmj02Y_NP2000001d0oooo00<000000?ooo`3oool0503oool001l0oooo0P00000C0?ooo`<00000
=P3ooolk0:Vmj0T0Z;gY102V_NX50:NmjP@0Y;k/1@2W_^X40:Jok0D0Z;kY1@2Y_NP40:Vnj4d0ZKgX
0`00000P0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo00l0oooo0`00
000j0?ooocl0ZKgX1@2X_NT40:Rmj0D0YkgZ102X_NT40:NnjPD0ZKkY0`2X_^UC0:Vmj0<000000`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0
oooo00`0oooo0`00000n0?oood@0ZKgX102X_NP50:Vmj0@0Z;gY102Y_NP50:VnjE80ZKgX0`000006
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?oo
o`3oool02@3oool300000480ooooY`2Y_NP4000000X0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0C0?ooo`007P3oool2000000T0oooo0P0000160?oooj80ZKgX00@0oooo00000000
000000003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo000N0?ooo`03
0000003oool0oooo00D0oooo0`0000190?oooih0ZKgX00@0oooo00000000000000004`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo0080
oooo0`00001=0?ooo`030000002Y_NP0ZKgX09H0ZKgX00<0oooo0000000000000P00000F0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`000000
0P00001A0?ooo`030000002Y_NP0ZKgX09<0ZKgX0`00000K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool04`3oool001h0oooo0P00001E0?ooo`030000002Y_NP0ZKgX0900ZKgX0P00
000O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool001<0oooo00<0omnL
04P0M02oool02@3oool00`000000oooo0?ooo`1D0?ooo`030000002Y_NP0ZKgX08`0ZKgX00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo000C0?oo
o`030?oOW01807@0_ooo00X0oooo0P00001F0?ooohT0ZKgX0P00000W0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool0303oool00`000000
oooo0?ooo`1D0?ooohD0ZKgX0P00000[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`000000oooo0?ooo`1D0?oooh00ZKgX
0P00000`0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0
omnL04P0M02oool03P3oool00`000000oooo0?ooo`1D0?ooog/0ZKgX0`00000c0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03`3oool0
0`000000oooo0?ooo`1D0?ooogL0ZKgX0`00000g0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool04P3oool00140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@0?ooo`800000E@3ooomb
0:Vmj0<00000?03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo000B0?oo
o`040?noM0000000001d0;oooa80oooo00<000000?ooo`3oool0D`3ooom^0:Vmj0<00000@03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo
01<0oooo00<000000?ooo`3oool0D`3ooomY0:Vmj0@00000@`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0140oooo000Z0?ooo`030000003oool0oooo05<0ooooI@2Y_NP3000004P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo
H02Y_NP0103oool0000000000000001<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04@3oool002d0oooo00<000000?ooo`3oool0DP3ooomL0:Vmj0@00000C`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0140oooo000^0?ooo`030000003oool0oooo0580ooooF02Y
_NP3000005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00;`3oool0
0`000000oooo0?ooo`1B0?oooe<0ZKgX00@0oooo0000000000000000F03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo000`0?ooo`030000003oool0oooo0580ooooC`2Y_NP4
000005`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool20000
05<0ooooBP2Y_NP0103oool0000000000000001P0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool003<0oooo00<000000?ooo`3oool0D@3ooom60:Vmj0@00000I03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo000d0?ooo`030000003oool0oooo0540
oooo@P2Y_NP3000006T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00
=@3oool00`000000oooo0?ooo`1A0?ooocd0ZKgX00@0oooo0000000000000000K03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000f0?ooo`800000DP3oooli0:Vmj0@00000
L03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000h0?ooo`030000003o
ool0oooo0500oooo=@2Y_NP3000007D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo0000000000000000N@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000j0?ooo`030000003oool0
oooo0540oooo:`2Y_NP4000007`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@
0?ooo`00>`3oool00`000000oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03`3oool003`0oooo0P00001B0?ooob80ZKgX00@0oooo00000000
00000000Q@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo000n0?ooo`03
0000003oool0oooo0500oooo7P2Y_NP4000008T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0?0?ooo`00?`3oool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00002=0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00400oooo00<000000?ooo`3oool0D03o
oolF0:Vmj0<00000T@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo0011
0?ooo`800000D@3ooolB0:Vmj0<00000U@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00l0oooo00130?ooo`030000003oool0oooo04l0oooo3@2Y_NP3000009T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00A03oool00`000000oooo0?ooo`1@0?ooo`P0
ZKgX0`00002M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool004D0oooo
00<000000?ooo`3oool0D03oool40:Vmj0<00000X@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00h0oooo00160?ooo`800000D@3oool200000:H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`00B03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B@3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00B`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0>0?ooo`00C03oool2000004/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00h0oooo001>0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo001?0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo001@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001A0?ooo`800000
AP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool005<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2/0?ooo`050000003o
ool0oooo0?ooo`0000003`3oool005@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`2^0?ooo`040000003oool0oooo000000l0oooo001E0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00EP3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`0000003`3oool005L0oooo0P00000o
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`0000003P3oool005T0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005/0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005`0oooo0P00000j0?ooo`030000003o
ool0oooo0:d0oooo1000000@0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:T0oooo1000000D0?ooo`00G`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
0:D0oooo1000000H0?ooo`00H03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:40
oooo1000000L0?ooo`00H@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo09h0oooo
0`00000P0?ooo`00HP3oool2000003@0oooo00<000000?ooo`3oool0VP3oool4000002<0oooo001T
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0UP3oool4000002L0oooo001U0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0TP3oool4000002/0oooo001V0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0SP3oool4000002l0oooo001W0?ooo`800000
;`3oool00`000000oooo0?ooo`2:0?ooo`@00000<`3oool006T0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`270?ooo`<00000=`3oool006X0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`230?ooo`@00000>P3oool006/0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`1o0?ooo`@00000?P3oool006`0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1k0?ooo`@00000@P3oool006d0oooo0P00000Y0?ooo`030000003oool0oooo07L0oooo
100000160?ooo`00K`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo0`00
001:0?ooo`00L03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0740oooo1000001=
0?ooo`00L@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001A0?oo
o`00LP3oool2000002<0oooo00<000000?ooo`3oool0J@3oool4000005D0oooo001d0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0I@3oool4000005T0oooo001e0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0HP3oool3000005d0oooo001f0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0GP3oool400000600oooo001g0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0FP3oool4000006@0oooo001h0?ooo`8000007@3oool00`000000
oooo0?ooo`1F0?ooo`@00000J03oool007X0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1B0?ooo`@00000K03oool007/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1>0?ooo`@00000L03oool007`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;
0?ooo`<00000M03oool007d0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000001g0?oo
o`00O`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000001k0?ooo`00
P03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000001o0?ooo`00P@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo100000230?ooo`00PP3oool2
000001<0oooo00<000000?ooo`3oool0>03oool3000008L0oooo00240?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0=03oool4000008X0oooo00250?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0<03oool4000008h0oooo00260?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0;03oool400000980oooo00270?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0:03oool4000009H0oooo00280?ooo`8000003@3oool00`000000oooo0?ooo`0U
0?ooo`<00000VP3oool008X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?oo
o`@00000W@3oool008/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@0
0000X@3oool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000
Y@3oool008d0oooo0P0000070?ooo`030000003oool0oooo01H0oooo1000002Y0?ooo`00S`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo1000002]0?ooo`00T03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0`00002a0?ooo`00T@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000002d0?ooo`00TP3oool01@000000oooo
0?ooo`3oool0000000T0oooo1000002h0?ooo`00T`3oool2000000030?ooo`000000oooo00@0oooo
1000002l0?ooo`00U@3oool2000000030?ooo`000000000000800000`03oool009H0oooo0P000034
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .61641 .52744 Mtetra
.61641 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51713 Mtetra
.65053 .51713 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .61641 .52744 .6107 .52111 Mtetra
.6107 .52111 .61641 .52744 .62773 .52402 .62206 .51766 Mtetra
.62206 .51766 .62773 .52402 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51713 .64492 .51071 Mtetra
.64492 .51071 .65053 .51713 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51473 Mtetra
.60495 .51473 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52217 Mtetra
.55394 .52217 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51473 .59916 .5083 Mtetra
.59916 .5083 .60495 .51473 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47569 .72744 .46896 Mtetra
.72744 .46896 .73287 .47569 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52217 .54798 .51579 Mtetra
.54798 .51579 .55394 .52217 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48098 Mtetra
.63368 .48098 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48098 .62789 .47429 Mtetra
.62789 .47429 .63368 .48098 .64536 .47736 .6396 .47065 Mtetra
.6396 .47065 .64536 .47736 .65708 .47373 .65136 .46699 Mtetra
.65136 .46699 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48209 Mtetra
.57556 .48209 .58153 .48871 .59305 .48513 .58711 .47848 Mtetra
.664 .741 .908 r
.58711 .47848 .59305 .48513 .60461 .48153 .59871 .47486 Mtetra
.59871 .47486 .60461 .48153 .61622 .47792 .61035 .47122 Mtetra
.61035 .47122 .61622 .47792 .62789 .47429 .62205 .46757 Mtetra
.62205 .46757 .62789 .47429 .6396 .47065 .63379 .46389 Mtetra
.63379 .46389 .6396 .47065 .65136 .46699 .64558 .4602 Mtetra
.64558 .4602 .65136 .46699 .66316 .46331 .65743 .4565 Mtetra
.65743 .4565 .66316 .46331 .67502 .45962 .66932 .45278 Mtetra
.664 .741 .907 r
.66932 .45278 .67502 .45962 .68693 .45591 .68126 .44904 Mtetra
.68126 .44904 .68693 .45591 .69889 .45219 .69325 .44529 Mtetra
.69325 .44529 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48624 Mtetra
.53509 .48624 .5412 .49283 .55261 .48926 .54653 .48265 Mtetra
.664 .741 .908 r
.54653 .48265 .55261 .48926 .56406 .48568 .55801 .47905 Mtetra
.663 .741 .908 r
.55801 .47905 .56406 .48568 .57556 .48209 .56955 .47544 Mtetra
.56955 .47544 .57556 .48209 .58711 .47848 .58113 .47182 Mtetra
.663 .742 .909 r
.58113 .47182 .58711 .47848 .59871 .47486 .59276 .4682 Mtetra
.663 .743 .909 r
.59276 .4682 .59871 .47486 .61035 .47122 .60444 .46455 Mtetra
.663 .743 .91 r
.60444 .46455 .61035 .47122 .62205 .46757 .61617 .46088 Mtetra
.664 .744 .91 r
.61617 .46088 .62205 .46757 .63379 .46389 .62794 .45718 Mtetra
.62794 .45718 .63379 .46389 .64558 .4602 .63977 .45345 Mtetra
.665 .744 .909 r
.63977 .45345 .64558 .4602 .65743 .4565 .65164 .44969 Mtetra
.665 .743 .909 r
.65164 .44969 .65743 .4565 .66932 .45278 .66357 .44592 Mtetra
.665 .743 .908 r
.66357 .44592 .66932 .45278 .68126 .44904 .67555 .44213 Mtetra
.664 .742 .908 r
.67555 .44213 .68126 .44904 .69325 .44529 .68757 .43833 Mtetra
.664 .741 .908 r
.68757 .43833 .69325 .44529 .7053 .44152 .69965 .43453 Mtetra
.664 .741 .907 r
.69965 .43453 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48679 Mtetra
.50614 .48679 .51236 .49338 .5237 .48981 .51752 .4832 Mtetra
.663 .741 .908 r
.51752 .4832 .5237 .48981 .53509 .48624 .52894 .47961 Mtetra
.52894 .47961 .53509 .48624 .54653 .48265 .54041 .47603 Mtetra
.662 .742 .909 r
.54041 .47603 .54653 .48265 .55801 .47905 .55192 .47246 Mtetra
.661 .743 .911 r
.55192 .47246 .55801 .47905 .56955 .47544 .56349 .4689 Mtetra
.66 .746 .914 r
.56349 .4689 .56955 .47544 .58113 .47182 .5751 .46536 Mtetra
.659 .749 .916 r
.5751 .46536 .58113 .47182 .59276 .4682 .58677 .46182 Mtetra
.66 .752 .919 r
.58677 .46182 .59276 .4682 .60444 .46455 .59849 .45823 Mtetra
.661 .756 .92 r
.59849 .45823 .60444 .46455 .61617 .46088 .61025 .45459 Mtetra
.663 .758 .921 r
.61025 .45459 .61617 .46088 .62794 .45718 .62206 .45086 Mtetra
.665 .759 .92 r
.62206 .45086 .62794 .45718 .63977 .45345 .63392 .44705 Mtetra
.667 .758 .918 r
.63392 .44705 .63977 .45345 .65164 .44969 .64583 .44317 Mtetra
.668 .755 .916 r
.64583 .44317 .65164 .44969 .66357 .44592 .65779 .43926 Mtetra
.668 .752 .913 r
.65779 .43926 .66357 .44592 .67555 .44213 .6698 .43534 Mtetra
.667 .748 .911 r
.6698 .43534 .67555 .44213 .68757 .43833 .68185 .43143 Mtetra
.666 .745 .909 r
.68185 .43143 .68757 .43833 .69965 .43453 .69397 .42753 Mtetra
.665 .743 .908 r
.69397 .42753 .69965 .43453 .71178 .43071 .70613 .42365 Mtetra
.664 .742 .908 r
.70613 .42365 .71178 .43071 .72397 .42688 .71835 .41978 Mtetra
.664 .741 .907 r
.71835 .41978 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.663 .741 .908 r
.48852 .48375 .49482 .49036 .50614 .48679 .49988 .48016 Mtetra
.49988 .48016 .50614 .48679 .51752 .4832 .51128 .47658 Mtetra
.661 .741 .91 r
.51128 .47658 .51752 .4832 .52894 .47961 .52273 .47303 Mtetra
.658 .743 .912 r
.52273 .47303 .52894 .47961 .54041 .47603 .53423 .46955 Mtetra
.654 .746 .917 r
.53423 .46955 .54041 .47603 .55192 .47246 .54579 .46617 Mtetra
.65 .751 .924 r
.54579 .46617 .55192 .47246 .56349 .4689 .55739 .46288 Mtetra
.646 .76 .932 r
.55739 .46288 .56349 .4689 .5751 .46536 .56904 .45964 Mtetra
.645 .771 .94 r
.56904 .45964 .5751 .46536 .58677 .46182 .58075 .45636 Mtetra
.647 .782 .946 r
.58075 .45636 .58677 .46182 .59849 .45823 .59251 .45298 Mtetra
.651 .792 .949 r
.59251 .45298 .59849 .45823 .61025 .45459 .60431 .44943 Mtetra
.658 .798 .95 r
.60431 .44943 .61025 .45459 .62206 .45086 .61617 .44567 Mtetra
.665 .8 .947 r
.61617 .44567 .62206 .45086 .63392 .44705 .62806 .44171 Mtetra
.672 .798 .942 r
.62806 .44171 .63392 .44705 .64583 .44317 .64 .43758 Mtetra
.676 .791 .935 r
.64 .43758 .64583 .44317 .65779 .43926 .65199 .43333 Mtetra
.678 .781 .928 r
.65199 .43333 .65779 .43926 .6698 .43534 .66402 .42906 Mtetra
.676 .769 .921 r
.66402 .42906 .6698 .43534 .68185 .43143 .67611 .42482 Mtetra
.673 .759 .915 r
.67611 .42482 .68185 .43143 .69397 .42753 .68825 .42068 Mtetra
.669 .751 .911 r
.68825 .42068 .69397 .42753 .70613 .42365 .70044 .41663 Mtetra
.667 .745 .909 r
.70044 .41663 .70613 .42365 .71835 .41978 .71269 .41266 Mtetra
.665 .743 .908 r
.71269 .41266 .71835 .41978 .73062 .41589 .725 .40871 Mtetra
.664 .741 .908 r
.725 .40871 .73062 .41589 .74295 .412 .73736 .40478 Mtetra
.664 .741 .907 r
.73736 .40478 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.663 .741 .908 r
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .4771 Mtetra
.662 .741 .909 r
.48218 .4771 .48852 .48375 .49988 .48016 .49356 .47353 Mtetra
.658 .741 .911 r
.49356 .47353 .49988 .48016 .51128 .47658 .505 .47005 Mtetra
.652 .743 .917 r
.505 .47005 .51128 .47658 .52273 .47303 .51648 .46674 Mtetra
.642 .749 .926 r
.51648 .46674 .52273 .47303 .53423 .46955 .52802 .46366 Mtetra
.63 .759 .94 r
.52802 .46366 .53423 .46955 .54579 .46617 .5396 .46082 Mtetra
.618 .775 .956 r
.5396 .46082 .54579 .46617 .55739 .46288 .55125 .45811 Mtetra
.61 .796 .97 r
.55125 .45811 .55739 .46288 .56904 .45964 .56295 .45537 Mtetra
.609 .816 .979 r
.56295 .45537 .56904 .45964 .58075 .45636 .5747 .45244 Mtetra
.615 .833 .983 r
.5747 .45244 .58075 .45636 .59251 .45298 .58651 .44925 Mtetra
.626 .844 .983 r
.58651 .44925 .59251 .45298 .60431 .44943 .59836 .44575 Mtetra
.638 .851 .981 r
.59836 .44575 .60431 .44943 .61617 .44567 .61026 .44197 Mtetra
.651 .855 .978 r
.61026 .44197 .61617 .44567 .62806 .44171 .6222 .4379 Mtetra
.666 .855 .972 r
.6222 .4379 .62806 .44171 .64 .43758 .63418 .43352 Mtetra
.68 .851 .964 r
.63418 .43352 .64 .43758 .65199 .43333 .6462 .42887 Mtetra
.69 .839 .954 r
.6462 .42887 .65199 .43333 .66402 .42906 .65825 .42403 Mtetra
.694 .82 .943 r
.65825 .42403 .66402 .42906 .67611 .42482 .67036 .41916 Mtetra
.69 .797 .931 r
.67036 .41916 .67611 .42482 .68825 .42068 .68251 .41442 Mtetra
.683 .776 .921 r
.68251 .41442 .68825 .42068 .70044 .41663 .69472 .4099 Mtetra
.675 .759 .914 r
.69472 .4099 .70044 .41663 .71269 .41266 .707 .40563 Mtetra
.669 .749 .91 r
.707 .40563 .71269 .41266 .725 .40871 .71933 .40153 Mtetra
.666 .744 .908 r
.71933 .40153 .725 .40871 .73736 .40478 .73173 .39751 Mtetra
.664 .742 .908 r
.73173 .39751 .73736 .40478 .74978 .40083 .74418 .39352 Mtetra
.664 .741 .907 r
.74418 .39352 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.663 .741 .908 r
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47404 Mtetra
.661 .741 .909 r
.46442 .47404 .47084 .4807 .48218 .4771 .47578 .47047 Mtetra
.656 .741 .913 r
.47578 .47047 .48218 .4771 .49356 .47353 .4872 .46705 Mtetra
.644 .743 .921 r
.4872 .46705 .49356 .47353 .505 .47005 .49866 .46393 Mtetra
.626 .75 .936 r
.49866 .46393 .505 .47005 .51648 .46674 .51018 .46122 Mtetra
.602 .764 .957 r
.51018 .46122 .51648 .46674 .52802 .46366 .52174 .45891 Mtetra
.58 .786 .977 r
.52174 .45891 .52802 .46366 .5396 .46082 .53337 .45675 Mtetra
.575 .812 .989 r
.53337 .45675 .5396 .46082 .55125 .45811 .54506 .45436 Mtetra
.595 .833 .989 r
.54506 .45436 .55125 .45811 .56295 .45537 .5568 .45145 Mtetra
.628 .837 .981 r
.5568 .45145 .56295 .45537 .5747 .45244 .56859 .448 Mtetra
.652 .825 .966 r
.56859 .448 .5747 .45244 .58651 .44925 .58042 .44418 Mtetra
.661 .805 .952 r
.58042 .44418 .58651 .44925 .59836 .44575 .59231 .44028 Mtetra
.659 .79 .944 r
.59231 .44028 .59836 .44575 .61026 .44197 .60425 .43647 Mtetra
.655 .789 .946 r
.60425 .43647 .61026 .44197 .6222 .4379 .61624 .43275 Mtetra
.655 .803 .954 r
.61624 .43275 .6222 .4379 .63418 .43352 .62828 .42894 Mtetra
.664 .828 .962 r
.62828 .42894 .63418 .43352 .6462 .42887 .64036 .42477 Mtetra
.681 .852 .964 r
.64036 .42477 .6462 .42887 .65825 .42403 .65248 .42004 Mtetra
.7 .862 .959 r
.65248 .42004 .65825 .42403 .67036 .41916 .66461 .41479 Mtetra
.71 .851 .949 r
.66461 .41479 .67036 .41916 .68251 .41442 .67678 .4093 Mtetra
.707 .824 .937 r
.67678 .4093 .68251 .41442 .69472 .4099 .689 .40396 Mtetra
.695 .793 .925 r
.689 .40396 .69472 .4099 .707 .40563 .70128 .39901 Mtetra
.681 .767 .916 r
.70128 .39901 .707 .40563 .71933 .40153 .71363 .39448 Mtetra
.671 .752 .911 r
.71363 .39448 .71933 .40153 .73173 .39751 .72606 .39025 Mtetra
.666 .744 .908 r
.72606 .39025 .73173 .39751 .74418 .39352 .73854 .38616 Mtetra
.665 .742 .908 r
.73854 .38616 .74418 .39352 .75669 .38952 .75109 .38211 Mtetra
.664 .741 .907 r
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.663 .741 .908 r
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47095 Mtetra
.661 .741 .909 r
.44659 .47095 .45309 .47764 .46442 .47404 .45794 .46738 Mtetra
.654 .741 .913 r
.45794 .46738 .46442 .47404 .47578 .47047 .46934 .46399 Mtetra
.639 .742 .923 r
.46934 .46399 .47578 .47047 .4872 .46705 .48078 .461 Mtetra
.61 .748 .943 r
.48078 .461 .4872 .46705 .49866 .46393 .49227 .45862 Mtetra
.574 .763 .968 r
.49227 .45862 .49866 .46393 .51018 .46122 .50381 .45677 Mtetra
.553 .789 .987 r
.50381 .45677 .51018 .46122 .52174 .45891 .51541 .45491 Mtetra
.588 .82 .988 r
.51541 .45491 .52174 .45891 .53337 .45675 .52708 .45225 Mtetra
.664 .824 .96 r
.52708 .45225 .53337 .45675 .54506 .45436 .5388 .44822 Mtetra
.711 .779 .905 r
.5388 .44822 .54506 .45436 .5568 .45145 .55055 .44291 Mtetra
.714 .715 .85 r
.55055 .44291 .5568 .45145 .56859 .448 .56234 .43694 Mtetra
.695 .66 .811 r
.56234 .43694 .56859 .448 .58042 .44418 .57417 .43113 Mtetra
.669 .619 .79 r
.57417 .43113 .58042 .44418 .59231 .44028 .58604 .42612 Mtetra
.644 .593 .782 r
.58604 .42612 .59231 .44028 .60425 .43647 .59799 .42227 Mtetra
.621 .581 .788 r
.59799 .42227 .60425 .43647 .61624 .43275 .61002 .41958 Mtetra
.605 .587 .807 r
.61002 .41958 .61624 .43275 .62828 .42894 .62213 .41771 Mtetra
.601 .618 .84 r
.62213 .41771 .62828 .42894 .64036 .42477 .63432 .41601 Mtetra
.616 .679 .887 r
.63432 .41601 .64036 .42477 .65248 .42004 .64655 .41364 Mtetra
.653 .763 .93 r
.64655 .41364 .65248 .42004 .66461 .41479 .65879 .40998 Mtetra
.695 .833 .949 r
.65879 .40998 .66461 .41479 .67678 .4093 .67103 .40495 Mtetra
.721 .857 .946 r
.67103 .40495 .67678 .4093 .689 .40396 .68328 .39909 Mtetra
.722 .84 .937 r
.68328 .39909 .689 .40396 .70128 .39901 .69556 .39321 Mtetra
.706 .804 .926 r
.69556 .39321 .70128 .39901 .71363 .39448 .70791 .38786 Mtetra
.686 .772 .917 r
.70791 .38786 .71363 .39448 .72606 .39025 .72035 .38313 Mtetra
.673 .753 .911 r
.72035 .38313 .72606 .39025 .73854 .38616 .73286 .37881 Mtetra
.667 .744 .908 r
.73286 .37881 .73854 .38616 .75109 .38211 .74544 .37466 Mtetra
.664 .742 .908 r
.74544 .37466 .75109 .38211 .76369 .37807 .75808 .37057 Mtetra
.664 .741 .907 r
.75808 .37057 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.663 .741 .908 r
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46785 Mtetra
.662 .741 .909 r
.4287 .46785 .43528 .47457 .44659 .47095 .44004 .46425 Mtetra
.655 .74 .912 r
.44004 .46425 .44659 .47095 .45794 .46738 .45141 .46083 Mtetra
.637 .74 .923 r
.45141 .46083 .45794 .46738 .46934 .46399 .46283 .45787 Mtetra
.602 .744 .944 r
.46283 .45787 .46934 .46399 .48078 .461 .47429 .45568 Mtetra
.555 .757 .972 r
.47429 .45568 .48078 .461 .49227 .45862 .4858 .45415 Mtetra
.547 .787 .988 r
.4858 .45415 .49227 .45862 .50381 .45677 .49738 .45238 Mtetra
.635 .82 .971 r
.49738 .45238 .50381 .45677 .51541 .45491 .50903 .44896 Mtetra
.732 .789 .897 r
.50903 .44896 .51541 .45491 .52708 .45225 .52073 .44289 Mtetra
.752 .709 .811 r
.52073 .44289 .52708 .45225 .5388 .44822 .53247 .43442 Mtetra
.648 .599 .785 r
.53247 .43442 .5388 .44822 .55055 .44291 .54424 .43041 Mtetra
.649 .617 .804 r
.54424 .43041 .55055 .44291 .56234 .43694 .55607 .42658 Mtetra
.657 .658 .839 r
.55607 .42658 .56234 .43694 .57417 .43113 .56794 .42274 Mtetra
.662 .704 .878 r
.56794 .42274 .57417 .43113 .58604 .42612 .57987 .41888 Mtetra
.664 .737 .904 r
.57987 .41888 .58604 .42612 .59799 .42227 .59185 .415 Mtetra
.59185 .415 .59799 .42227 .61002 .41958 .60388 .4111 Mtetra
.662 .704 .878 r
.60388 .4111 .61002 .41958 .62213 .41771 .61597 .40719 Mtetra
.657 .658 .839 r
.61597 .40719 .62213 .41771 .63432 .41601 .6281 .40326 Mtetra
.645 .616 .805 r
.6281 .40326 .63432 .41601 .64655 .41364 .6403 .3995 Mtetra
.541 .542 .805 r
.6403 .3995 .64655 .41364 .65879 .40998 .65273 .40026 Mtetra
.594 .649 .874 r
.65273 .40026 .65879 .40998 .67103 .40495 .66514 .39861 Mtetra
.674 .776 .927 r
.66514 .39861 .67103 .40495 .68328 .39909 .67751 .39428 Mtetra
.726 .844 .937 r
.67751 .39428 .68328 .39909 .69556 .39321 .68983 .38826 Mtetra
.733 .842 .932 r
.68983 .38826 .69556 .39321 .70791 .38786 .70219 .38199 Mtetra
.712 .806 .923 r
.70219 .38199 .70791 .38786 .72035 .38313 .71462 .37638 Mtetra
.687 .771 .915 r
.71462 .37638 .72035 .38313 .73286 .37881 .72714 .37155 Mtetra
.672 .751 .91 r
.72714 .37155 .73286 .37881 .74544 .37466 .73975 .36719 Mtetra
.666 .743 .908 r
.73975 .36719 .74544 .37466 .75808 .37057 .75243 .36302 Mtetra
.664 .741 .907 r
.75243 .36302 .75808 .37057 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .4684 Mtetra
.39948 .4684 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.662 .741 .908 r
.41075 .46473 .41741 .47149 .4287 .46785 .42207 .4611 Mtetra
.657 .74 .911 r
.42207 .4611 .4287 .46785 .44004 .46425 .43343 .45759 Mtetra
.641 .739 .92 r
.43343 .45759 .44004 .46425 .45141 .46083 .44483 .45453 Mtetra
.603 .739 .94 r
.44483 .45453 .45141 .46083 .46283 .45787 .45626 .45232 Mtetra
.548 .747 .969 r
.45626 .45232 .46283 .45787 .47429 .45568 .46774 .45098 Mtetra
.542 .777 .985 r
.46774 .45098 .47429 .45568 .4858 .45415 .47928 .44937 Mtetra
.666 .814 .954 r
.47928 .44937 .4858 .45415 .49738 .45238 .49092 .44534 Mtetra
.767 .763 .85 r
.49092 .44534 .49738 .45238 .50903 .44896 .50263 .43725 Mtetra
.698 .65 .798 r
.50263 .43725 .50903 .44896 .52073 .44289 .51436 .431 Mtetra
.651 .628 .814 r
.51436 .431 .52073 .44289 .53247 .43442 .52611 .42718 Mtetra
.664 .735 .903 r
.52611 .42718 .53247 .43442 .54424 .43041 .53792 .42333 Mtetra
.664 .741 .907 r
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .6403 .3995 .63425 .39198 Mtetra
.664 .735 .903 r
.63425 .39198 .6403 .3995 .65273 .40026 .64653 .38798 Mtetra
.594 .6 .827 r
.64653 .38798 .65273 .40026 .66514 .39861 .65896 .38643 Mtetra
.542 .576 .838 r
.65896 .38643 .66514 .39861 .67751 .39428 .67156 .38677 Mtetra
.655 .736 .909 r
.67156 .38677 .67751 .39428 .68983 .38826 .68404 .38298 Mtetra
.731 .832 .927 r
.68404 .38298 .68983 .38826 .70219 .38199 .69645 .37674 Mtetra
.739 .836 .924 r
.69645 .37674 .70219 .38199 .71462 .37638 .70888 .37021 Mtetra
.711 .799 .919 r
.70888 .37021 .71462 .37638 .72714 .37155 .7214 .36455 Mtetra
.684 .765 .913 r
.7214 .36455 .72714 .37155 .73975 .36719 .73402 .35977 Mtetra
.67 .748 .909 r
.73402 .35977 .73975 .36719 .75243 .36302 .74673 .35543 Mtetra
.665 .742 .908 r
.74673 .35543 .75243 .36302 .76516 .35887 .7595 .35122 Mtetra
.664 .741 .907 r
.7595 .35122 .76516 .35887 .77795 .35473 .77233 .34704 Mtetra
.77233 .34704 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .4684 .39273 .46161 Mtetra
.663 .741 .908 r
.39273 .46161 .39948 .4684 .41075 .46473 .40403 .45794 Mtetra
.66 .74 .909 r
.40403 .45794 .41075 .46473 .42207 .4611 .41538 .45434 Mtetra
.648 .739 .916 r
.41538 .45434 .42207 .4611 .43343 .45759 .42676 .45107 Mtetra
.615 .737 .933 r
.42676 .45107 .43343 .45759 .44483 .45453 .43817 .44862 Mtetra
.554 .737 .961 r
.43817 .44862 .44483 .45453 .45626 .45232 .44962 .44727 Mtetra
.528 .759 .981 r
.44962 .44727 .45626 .45232 .46774 .45098 .46113 .44601 Mtetra
.661 .806 .953 r
.46113 .44601 .46774 .45098 .47928 .44937 .47274 .44214 Mtetra
.782 .761 .834 r
.47274 .44214 .47928 .44937 .49092 .44534 .48447 .433 Mtetra
.677 .632 .798 r
.48447 .433 .49092 .44534 .50263 .43725 .49618 .42777 Mtetra
.659 .677 .856 r
.49618 .42777 .50263 .43725 .51436 .431 .50792 .42392 Mtetra
.664 .741 .907 r
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65896 .38643 .65284 .37651 Mtetra
.621 .66 .867 r
.65284 .37651 .65896 .38643 .67156 .38677 .66533 .37388 Mtetra
.515 .551 .83 r
.66533 .37388 .67156 .38677 .68404 .38298 .67807 .37521 Mtetra
.661 .733 .903 r
.67807 .37521 .68404 .38298 .69645 .37674 .69064 .37121 Mtetra
.741 .828 .918 r
.69064 .37121 .69645 .37674 .70888 .37021 .70311 .36453 Mtetra
.738 .824 .918 r
.70311 .36453 .70888 .37021 .7214 .36455 .71563 .35794 Mtetra
.704 .785 .915 r
.71563 .35794 .7214 .36455 .73402 .35977 .72826 .35247 Mtetra
.678 .757 .91 r
.72826 .35247 .73402 .35977 .74673 .35543 .74098 .34782 Mtetra
.668 .745 .908 r
.74098 .34782 .74673 .35543 .7595 .35122 .75379 .34351 Mtetra
.665 .742 .907 r
.75379 .34351 .7595 .35122 .77233 .34704 .76666 .33928 Mtetra
.664 .741 .907 r
.76666 .33928 .77233 .34704 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45478 Mtetra
.662 .74 .908 r
.38594 .45478 .39273 .46161 .40403 .45794 .39726 .45111 Mtetra
.655 .74 .912 r
.39726 .45111 .40403 .45794 .41538 .45434 .40863 .44762 Mtetra
.632 .737 .923 r
.40863 .44762 .41538 .45434 .42676 .45107 .42003 .44475 Mtetra
.577 .732 .948 r
.42003 .44475 .42676 .45107 .43817 .44862 .43145 .44307 Mtetra
.517 .737 .974 r
.43145 .44307 .43817 .44862 .44962 .44727 .44292 .44217 Mtetra
.614 .789 .965 r
.44292 .44217 .44962 .44727 .46113 .44601 .45449 .43935 Mtetra
.778 .775 .85 r
.45449 .43935 .46113 .44601 .47274 .44214 .46622 .4308 Mtetra
.701 .658 .804 r
.46622 .4308 .47274 .44214 .48447 .433 .47794 .42452 Mtetra
.662 .702 .876 r
.47794 .42452 .48447 .433 .49618 .42777 .48966 .42066 Mtetra
.664 .741 .907 r
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66533 .37388 .65924 .3649 Mtetra
.586 .67 .897 r
.65924 .3649 .66533 .37388 .67807 .37521 .67187 .36326 Mtetra
.526 .575 .847 r
.67187 .36326 .67807 .37521 .69064 .37121 .68469 .36395 Mtetra
.693 .762 .905 r
.68469 .36395 .69064 .37121 .70311 .36453 .6973 .3588 Mtetra
.751 .827 .911 r
.6973 .3588 .70311 .36453 .71563 .35794 .70983 .35169 Mtetra
.728 .806 .913 r
.70983 .35169 .71563 .35794 .72826 .35247 .72246 .34536 Mtetra
.691 .769 .911 r
.72246 .34536 .72826 .35247 .74098 .34782 .7352 .34025 Mtetra
.672 .749 .909 r
.7352 .34025 .74098 .34782 .75379 .34351 .74804 .33576 Mtetra
.666 .743 .908 r
.74804 .33576 .75379 .34351 .76666 .33928 .76095 .33145 Mtetra
.664 .741 .907 r
.76095 .33145 .76666 .33928 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.663 .741 .908 r
.36777 .45162 .37465 .45848 .38594 .45478 .37909 .4479 Mtetra
.66 .74 .909 r
.37909 .4479 .38594 .45478 .39726 .45111 .39044 .44425 Mtetra
.648 .738 .915 r
.39044 .44425 .39726 .45111 .40863 .44762 .40183 .44096 Mtetra
.608 .733 .933 r
.40183 .44096 .40863 .44762 .42003 .44475 .41324 .43863 Mtetra
.535 .725 .961 r
.41324 .43863 .42003 .44475 .43145 .44307 .42467 .43763 Mtetra
.543 .753 .974 r
.42467 .43763 .43145 .44307 .44292 .44217 .43617 .43623 Mtetra
.736 .791 .897 r
.43617 .43623 .44292 .44217 .45449 .43935 .44786 .42999 Mtetra
.756 .711 .811 r
.44786 .42999 .45449 .43935 .46622 .4308 .45963 .42126 Mtetra
.659 .677 .856 r
.45963 .42126 .46622 .4308 .47794 .42452 .47134 .41739 Mtetra
.664 .741 .907 r
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67187 .36326 .66571 .35313 Mtetra
.504 .604 .886 r
.66571 .35313 .67187 .36326 .68469 .36395 .67856 .35393 Mtetra
.591 .65 .877 r
.67856 .35393 .68469 .36395 .6973 .3588 .69138 .35221 Mtetra
.735 .797 .902 r
.69138 .35221 .6973 .3588 .70983 .35169 .704 .34554 Mtetra
.747 .816 .906 r
.704 .34554 .70983 .35169 .72246 .34536 .71662 .33846 Mtetra
.708 .782 .91 r
.71662 .33846 .72246 .34536 .7352 .34025 .72937 .33272 Mtetra
.678 .755 .909 r
.72937 .33272 .7352 .34025 .74804 .33576 .74224 .32797 Mtetra
.667 .744 .908 r
.74224 .32797 .74804 .33576 .76095 .33145 .75519 .32357 Mtetra
.664 .741 .907 r
.75519 .32357 .76095 .33145 .77392 .32718 .7682 .31926 Mtetra
.7682 .31926 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47065 Mtetra
.28278 .47065 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .44471 Mtetra
.663 .741 .908 r
.36084 .44471 .36777 .45162 .37909 .4479 .37218 .44097 Mtetra
.657 .739 .91 r
.37218 .44097 .37909 .4479 .39044 .44425 .38356 .43738 Mtetra
.637 .736 .92 r
.38356 .43738 .39044 .44425 .40183 .44096 .39497 .43435 Mtetra
.58 .726 .943 r
.39497 .43435 .40183 .44096 .41324 .43863 .40639 .4326 Mtetra
.511 .721 .967 r
.40639 .4326 .41324 .43863 .42467 .43763 .41783 .43192 Mtetra
.629 .774 .951 r
.41783 .43192 .42467 .43763 .43617 .43623 .42941 .42888 Mtetra
.802 .762 .816 r
.42941 .42888 .43617 .43623 .44786 .42999 .44125 .41817 Mtetra
.655 .633 .816 r
.44125 .41817 .44786 .42999 .45963 .42126 .45294 .4141 Mtetra
.664 .741 .907 r
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.609 .722 .925 r
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39201 Mtetra
.367 .666 .972 r
.52414 .39201 .53062 .39779 .54264 .39382 .53621 .39323 Mtetra
.252 .76 .869 r
.53621 .39323 .54264 .39382 .5547 .38983 .54835 .39158 Mtetra
.26 .761 .715 r
.54835 .39158 .5547 .38983 .56682 .38582 .56054 .38755 Mtetra
.491 .899 .796 r
.56054 .38755 .56682 .38582 .57899 .3818 .57275 .38114 Mtetra
.794 .978 .905 r
.57275 .38114 .57899 .3818 .59122 .37776 .58493 .37182 Mtetra
.713 .804 .921 r
.58493 .37182 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.664 .741 .907 r
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.658 .739 .909 r
.65962 .34542 .66571 .35313 .67856 .35393 .67228 .34141 Mtetra
.459 .531 .844 r
.67228 .34141 .67856 .35393 .69138 .35221 .68534 .34417 Mtetra
.686 .742 .894 r
.68534 .34417 .69138 .35221 .704 .34554 .69809 .33912 Mtetra
.755 .81 .897 r
.69809 .33912 .704 .34554 .71662 .33846 .71075 .33164 Mtetra
.726 .792 .905 r
.71075 .33164 .71662 .33846 .72937 .33272 .72351 .32524 Mtetra
.687 .761 .908 r
.72351 .32524 .72937 .33272 .74224 .32797 .73639 .32015 Mtetra
.67 .746 .908 r
.73639 .32015 .74224 .32797 .75519 .32357 .74938 .31563 Mtetra
.665 .742 .907 r
.74938 .31563 .75519 .32357 .7682 .31926 .76243 .31127 Mtetra
.664 .741 .907 r
.76243 .31127 .7682 .31926 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30253 Mtetra
.78872 .30253 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47065 .27559 .46388 Mtetra
.27559 .46388 .28278 .47065 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .44471 .35385 .43774 Mtetra
.662 .74 .908 r
.35385 .43774 .36084 .44471 .37218 .44097 .36522 .43399 Mtetra
.654 .739 .912 r
.36522 .43399 .37218 .44097 .38356 .43738 .37663 .43048 Mtetra
.624 .733 .925 r
.37663 .43048 .38356 .43738 .39497 .43435 .38805 .42774 Mtetra
.553 .718 .95 r
.38805 .42774 .39497 .43435 .40639 .4326 .39947 .42651 Mtetra
.52 .724 .966 r
.39947 .42651 .40639 .4326 .41783 .43192 .41095 .42566 Mtetra
.713 .779 .904 r
.41095 .42566 .41783 .43192 .42941 .42888 .42264 .4202 Mtetra
.771 .73 .814 r
.42264 .4202 .42941 .42888 .44125 .41817 .43448 .4108 Mtetra
.664 .735 .903 r
.43448 .4108 .44125 .41817 .45294 .4141 .4462 .40689 Mtetra
.664 .741 .907 r
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.481 .668 .946 r
.49359 .39106 .5002 .3984 .51214 .39443 .50554 .39132 Mtetra
0 .505 .829 r
.50554 .39132 .51214 .39443 .52414 .39201 .51757 .3944 Mtetra
.186 0 0 r
.51757 .3944 .52414 .39201 .53621 .39323 .5297 .39414 Mtetra
.183 .715 .744 r
.5297 .39414 .53621 .39323 .54835 .39158 .5419 .39168 Mtetra
.431 .871 .887 r
.5419 .39168 .54835 .39158 .56054 .38755 .55415 .38762 Mtetra
.567 .935 .911 r
.55415 .38762 .56054 .38755 .57275 .38114 .56644 .38197 Mtetra
.664 .973 .874 r
.56644 .38197 .57275 .38114 .58493 .37182 .57873 .37409 Mtetra
.75 .99 .788 r
.57873 .37409 .58493 .37182 .59722 .36616 .59098 .36284 Mtetra
.791 .906 .921 r
.59098 .36284 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.664 .741 .907 r
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67228 .34141 .66617 .33341 Mtetra
.436 .631 .936 r
.66617 .33341 .67228 .34141 .68534 .34417 .67919 .33476 Mtetra
.615 .68 .888 r
.67919 .33476 .68534 .34417 .69809 .33912 .6921 .33211 Mtetra
.748 .793 .889 r
.6921 .33211 .69809 .33912 .71075 .33164 .70482 .32474 Mtetra
.739 .795 .897 r
.70482 .32474 .71075 .33164 .72351 .32524 .71759 .31775 Mtetra
.697 .766 .905 r
.71759 .31775 .72351 .32524 .73639 .32015 .7305 .3123 Mtetra
.673 .748 .907 r
.7305 .3123 .73639 .32015 .74938 .31563 .74352 .30763 Mtetra
.665 .742 .907 r
.74352 .30763 .74938 .31563 .76243 .31127 .75661 .30321 Mtetra
.664 .741 .907 r
.75661 .30321 .76243 .31127 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30253 .78299 .29439 Mtetra
.78299 .29439 .78872 .30253 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.663 .741 .907 r
.33546 .43452 .34253 .44152 .35385 .43774 .34681 .43072 Mtetra
.662 .74 .908 r
.34681 .43072 .35385 .43774 .36522 .43399 .3582 .42696 Mtetra
.65 .738 .914 r
.3582 .42696 .36522 .43399 .37663 .43048 .36964 .42353 Mtetra
.612 .729 .929 r
.36964 .42353 .37663 .43048 .38805 .42774 .38107 .42107 Mtetra
.533 .71 .953 r
.38107 .42107 .38805 .42774 .39947 .42651 .39251 .42019 Mtetra
.553 .73 .958 r
.39251 .42019 .39947 .42651 .41095 .42566 .40403 .41881 Mtetra
.766 .772 .858 r
.40403 .41881 .41095 .42566 .42264 .4202 .41584 .41081 Mtetra
.731 .707 .828 r
.41584 .41081 .42264 .4202 .43448 .4108 .42766 .40356 Mtetra
.664 .741 .907 r
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.608 .722 .926 r
.47497 .38767 .48166 .39504 .49359 .39106 .48691 .38523 Mtetra
0 .393 .83 r
.48691 .38523 .49359 .39106 .50554 .39132 .49884 .39099 Mtetra
.116 0 0 r
.49884 .39099 .50554 .39132 .51757 .3944 .51093 .39231 Mtetra
.367 .8 .965 r
.51093 .39231 .51757 .3944 .5297 .39414 .5231 .39085 Mtetra
.562 .852 .997 r
.5231 .39085 .5297 .39414 .5419 .39168 .53535 .38781 Mtetra
.637 .857 .983 r
.53535 .38781 .5419 .39168 .55415 .38762 .54765 .38372 Mtetra
.684 .869 .969 r
.54765 .38372 .55415 .38762 .56644 .38197 .56 .37859 Mtetra
.739 .898 .95 r
.56 .37859 .56644 .38197 .57873 .37409 .57237 .37186 Mtetra
.815 .939 .909 r
.57237 .37186 .57873 .37409 .59098 .36284 .58472 .36233 Mtetra
.895 .964 .827 r
.58472 .36233 .59098 .36284 .6033 .35441 .59699 .34829 Mtetra
.713 .804 .921 r
.59699 .34829 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.664 .741 .907 r
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.54 .689 .936 r
.66002 .32553 .66617 .33341 .67919 .33476 .67296 .32463 Mtetra
.532 .625 .889 r
.67296 .32463 .67919 .33476 .6921 .33211 .68603 .3245 Mtetra
.733 .774 .885 r
.68603 .3245 .6921 .33211 .70482 .32474 .69882 .3176 Mtetra
.748 .792 .889 r
.69882 .3176 .70482 .32474 .71759 .31775 .71162 .31019 Mtetra
.705 .769 .901 r
.71162 .31019 .71759 .31775 .7305 .3123 .72456 .30438 Mtetra
.676 .75 .906 r
.72456 .30438 .7305 .3123 .74352 .30763 .73761 .29957 Mtetra
.666 .742 .907 r
.73761 .29957 .74352 .30763 .75661 .30321 .75074 .29508 Mtetra
.664 .741 .907 r
.75074 .29508 .75661 .30321 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28619 Mtetra
.7772 .28619 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .27201 .84444 .26361 Mtetra
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45019 Mtetra
.26104 .45019 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.663 .741 .908 r
.32833 .42747 .33546 .43452 .34681 .43072 .33971 .42364 Mtetra
.661 .74 .909 r
.33971 .42364 .34681 .43072 .3582 .42696 .35113 .41988 Mtetra
.647 .737 .915 r
.35113 .41988 .3582 .42696 .36964 .42353 .36259 .41651 Mtetra
.602 .725 .931 r
.36259 .41651 .36964 .42353 .38107 .42107 .37405 .41425 Mtetra
.522 .703 .952 r
.37405 .41425 .38107 .42107 .39251 .42019 .3855 .41355 Mtetra
.586 .734 .945 r
.3855 .41355 .39251 .42019 .40403 .41881 .39707 .41155 Mtetra
.794 .766 .828 r
.39707 .41155 .40403 .41881 .41584 .41081 .40899 .40153 Mtetra
.692 .699 .852 r
.40899 .40153 .41584 .41081 .42766 .40356 .42077 .39626 Mtetra
.664 .741 .907 r
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.312 .582 .938 r
.46822 .38025 .47497 .38767 .48691 .38523 .48011 .38301 Mtetra
.257 0 0 r
.48011 .38301 .48691 .38523 .49884 .39099 .4921 .38729 Mtetra
.33 .73 .981 r
.4921 .38729 .49884 .39099 .51093 .39231 .50423 .38741 Mtetra
.557 .792 .987 r
.50423 .38741 .51093 .39231 .5231 .39085 .51645 .38523 Mtetra
.628 .792 .961 r
.51645 .38523 .5231 .39085 .53535 .38781 .52873 .38185 Mtetra
.659 .792 .945 r
.52873 .38185 .53535 .38781 .54765 .38372 .54108 .37774 Mtetra
.685 .799 .935 r
.54108 .37774 .54765 .38372 .56 .37859 .55347 .37287 Mtetra
.722 .818 .924 r
.55347 .37287 .56 .37859 .57237 .37186 .5659 .3668 Mtetra
.784 .849 .9 r
.5659 .3668 .57237 .37186 .58472 .36233 .57833 .35842 Mtetra
.865 .881 .847 r
.57833 .35842 .58472 .36233 .59699 .34829 .5907 .34581 Mtetra
.849 .932 .882 r
.5907 .34581 .59699 .34829 .60945 .34251 .60309 .33472 Mtetra
.664 .741 .907 r
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.62 .724 .92 r
.65381 .31759 .66002 .32553 .67296 .32463 .6667 .3146 Mtetra
.449 .585 .897 r
.6667 .3146 .67296 .32463 .68603 .3245 .67989 .31646 Mtetra
.716 .759 .886 r
.67989 .31646 .68603 .3245 .69882 .3176 .69276 .31013 Mtetra
.751 .786 .881 r
.69276 .31013 .69882 .3176 .71162 .31019 .70559 .30246 Mtetra
.711 .768 .897 r
.70559 .30246 .71162 .31019 .72456 .30438 .71856 .29638 Mtetra
.679 .75 .905 r
.71856 .29638 .72456 .30438 .73761 .29957 .73165 .29143 Mtetra
.667 .743 .907 r
.73165 .29143 .73761 .29957 .75074 .29508 .74483 .28689 Mtetra
.664 .741 .907 r
.74483 .28689 .75074 .29508 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28619 .77137 .27791 Mtetra
.77137 .27791 .7772 .28619 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45019 .25368 .44326 Mtetra
.25368 .44326 .26104 .45019 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42037 Mtetra
.663 .741 .908 r
.32114 .42037 .32833 .42747 .33971 .42364 .33255 .41651 Mtetra
.66 .74 .909 r
.33255 .41651 .33971 .42364 .35113 .41988 .34401 .41272 Mtetra
.645 .736 .915 r
.34401 .41272 .35113 .41988 .36259 .41651 .35549 .40937 Mtetra
.597 .722 .931 r
.35549 .40937 .36259 .41651 .37405 .41425 .36697 .40721 Mtetra
.521 .697 .949 r
.36697 .40721 .37405 .41425 .3855 .41355 .37844 .40658 Mtetra
.606 .732 .934 r
.37844 .40658 .3855 .41355 .39707 .41155 .39005 .40416 Mtetra
.807 .765 .814 r
.39005 .40416 .39707 .41155 .40899 .40153 .40207 .39302 Mtetra
.666 .71 .881 r
.40207 .39302 .40899 .40153 .42077 .39626 .41384 .38891 Mtetra
.664 .741 .907 r
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.116 .464 .89 r
.46141 .37276 .46822 .38025 .48011 .38301 .47329 .37787 Mtetra
.097 .536 .91 r
.47329 .37787 .48011 .38301 .4921 .38729 .48531 .38135 Mtetra
.479 .723 .978 r
.48531 .38135 .4921 .38729 .50423 .38741 .49747 .38088 Mtetra
.598 .752 .952 r
.49747 .38088 .50423 .38741 .51645 .38523 .50973 .37837 Mtetra
.641 .757 .933 r
.50973 .37837 .51645 .38523 .52873 .38185 .52205 .37484 Mtetra
.662 .761 .923 r
.52205 .37484 .52873 .38185 .54108 .37774 .53444 .37069 Mtetra
.681 .767 .916 r
.53444 .37069 .54108 .37774 .55347 .37287 .54687 .36591 Mtetra
.711 .778 .905 r
.54687 .36591 .55347 .37287 .5659 .3668 .55935 .36011 Mtetra
.761 .798 .883 r
.55935 .36011 .5659 .3668 .57833 .35842 .57184 .35225 Mtetra
.834 .82 .836 r
.57184 .35225 .57833 .35842 .5907 .34581 .58428 .34039 Mtetra
.862 .84 .822 r
.58428 .34039 .5907 .34581 .60309 .33472 .59668 .32685 Mtetra
.664 .741 .907 r
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.66 .739 .909 r
.64756 .30959 .65381 .31759 .6667 .3146 .66042 .30535 Mtetra
.378 .568 .912 r
.66042 .30535 .6667 .3146 .67989 .31646 .6737 .30828 Mtetra
.706 .754 .889 r
.6737 .30828 .67989 .31646 .69276 .31013 .68663 .30231 Mtetra
.751 .778 .875 r
.68663 .30231 .69276 .31013 .70559 .30246 .69951 .29451 Mtetra
.714 .764 .892 r
.69951 .29451 .70559 .30246 .71856 .29638 .71251 .28825 Mtetra
.681 .749 .903 r
.71251 .28825 .71856 .29638 .73165 .29143 .72564 .28321 Mtetra
.667 .742 .907 r
.72564 .28321 .73165 .29143 .74483 .28689 .73886 .27862 Mtetra
.664 .741 .907 r
.73886 .27862 .74483 .28689 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .2466 Mtetra
.83317 .2466 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42037 .3139 .4132 Mtetra
.663 .741 .908 r
.3139 .4132 .32114 .42037 .33255 .41651 .32534 .40931 Mtetra
.66 .74 .909 r
.32534 .40931 .33255 .41651 .34401 .41272 .33682 .4055 Mtetra
.645 .735 .915 r
.33682 .4055 .34401 .41272 .35549 .40937 .34834 .40212 Mtetra
.598 .72 .93 r
.34834 .40212 .35549 .40937 .36697 .40721 .35984 .39993 Mtetra
.524 .692 .945 r
.35984 .39993 .36697 .40721 .37844 .40658 .37133 .39927 Mtetra
.607 .724 .927 r
.37133 .39927 .37844 .40658 .39005 .40416 .38298 .39682 Mtetra
.808 .768 .816 r
.38298 .39682 .39005 .40416 .40207 .39302 .39504 .38564 Mtetra
.668 .742 .906 r
.39504 .38564 .40207 .39302 .41384 .38891 .40684 .38149 Mtetra
.664 .741 .907 r
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.116 .464 .89 r
.45455 .36521 .46141 .37276 .47329 .37787 .46644 .3703 Mtetra
.256 .551 .929 r
.46644 .3703 .47329 .37787 .48531 .38135 .47848 .37376 Mtetra
.515 .685 .944 r
.47848 .37376 .48531 .38135 .49747 .38088 .49067 .37327 Mtetra
.606 .723 .928 r
.49067 .37327 .49747 .38088 .50973 .37837 .50296 .37072 Mtetra
.643 .736 .917 r
.50296 .37072 .50973 .37837 .52205 .37484 .51532 .36716 Mtetra
.662 .743 .91 r
.51532 .36716 .52205 .37484 .53444 .37069 .52774 .36298 Mtetra
.681 .749 .903 r
.52774 .36298 .53444 .37069 .54687 .36591 .54021 .35816 Mtetra
.708 .757 .891 r
.54021 .35816 .54687 .36591 .55935 .36011 .55273 .35232 Mtetra
.754 .769 .865 r
.55273 .35232 .55935 .36011 .57184 .35225 .56526 .34442 Mtetra
.817 .779 .818 r
.56526 .34442 .57184 .35225 .58428 .34039 .57776 .33251 Mtetra
.836 .781 .799 r
.57776 .33251 .58428 .34039 .59668 .32685 .59022 .31892 Mtetra
.664 .741 .907 r
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.66 .739 .909 r
.64125 .30151 .64756 .30959 .66042 .30535 .65415 .29724 Mtetra
.339 .582 .933 r
.65415 .29724 .66042 .30535 .6737 .30828 .66745 .30014 Mtetra
.707 .757 .891 r
.66745 .30014 .6737 .30828 .68663 .30231 .68043 .29413 Mtetra
.748 .77 .87 r
.68043 .29413 .68663 .30231 .69951 .29451 .69336 .28628 Mtetra
.713 .759 .888 r
.69336 .28628 .69951 .29451 .71251 .28825 .7064 .27999 Mtetra
.68 .747 .902 r
.7064 .27999 .71251 .28825 .72564 .28321 .71958 .27491 Mtetra
.667 .742 .906 r
.71958 .27491 .72564 .28321 .73886 .27862 .73284 .27028 Mtetra
.664 .741 .907 r
.73284 .27028 .73886 .27862 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26115 Mtetra
.75956 .26115 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .2466 .82746 .23798 Mtetra
.82746 .23798 .83317 .2466 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.663 .741 .908 r
.3066 .40598 .3139 .4132 .32534 .40931 .31807 .40206 Mtetra
.661 .74 .909 r
.31807 .40206 .32534 .40931 .33682 .4055 .32958 .3982 Mtetra
.647 .736 .914 r
.32958 .3982 .33682 .4055 .34834 .40212 .34113 .39474 Mtetra
.604 .72 .927 r
.34113 .39474 .34834 .40212 .35984 .39993 .35266 .39239 Mtetra
.531 .689 .94 r
.35266 .39239 .35984 .39993 .37133 .39927 .36418 .39162 Mtetra
.593 .71 .925 r
.36418 .39162 .37133 .39927 .38298 .39682 .37584 .38953 Mtetra
.795 .769 .83 r
.37584 .38953 .38298 .39682 .39504 .38564 .3879 .37938 Mtetra
.706 .786 .914 r
.3879 .37938 .39504 .38564 .40684 .38149 .39979 .37401 Mtetra
.664 .741 .907 r
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.312 .582 .938 r
.44763 .3576 .45455 .36521 .46644 .3703 .45958 .3603 Mtetra
.301 .505 .888 r
.45958 .3603 .46644 .3703 .47848 .37376 .47162 .36452 Mtetra
.511 .637 .91 r
.47162 .36452 .47848 .37376 .49067 .37327 .48382 .36456 Mtetra
.599 .691 .907 r
.48382 .36456 .49067 .37327 .50296 .37072 .49614 .36228 Mtetra
.639 .715 .902 r
.49614 .36228 .50296 .37072 .51532 .36716 .50853 .35881 Mtetra
.662 .726 .897 r
.50853 .35881 .51532 .36716 .52774 .36298 .52098 .35459 Mtetra
.682 .733 .889 r
.52098 .35459 .52774 .36298 .54021 .35816 .53349 .34962 Mtetra
.712 .739 .873 r
.53349 .34962 .54021 .35816 .55273 .35232 .54604 .34343 Mtetra
.756 .745 .842 r
.54604 .34343 .55273 .35232 .56526 .34442 .55861 .33492 Mtetra
.809 .745 .792 r
.55861 .33492 .56526 .34442 .57776 .33251 .57115 .32217 Mtetra
.783 .724 .797 r
.57115 .32217 .57776 .33251 .59022 .31892 .58369 .31093 Mtetra
.664 .741 .907 r
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.62 .724 .92 r
.63488 .29337 .64125 .30151 .65415 .29724 .64788 .29027 Mtetra
.361 .635 .959 r
.64788 .29027 .65415 .29724 .66745 .30014 .66116 .29205 Mtetra
.717 .763 .889 r
.66116 .29205 .66745 .30014 .68043 .29413 .67416 .2856 Mtetra
.745 .761 .866 r
.67416 .2856 .68043 .29413 .69336 .28628 .68714 .2778 Mtetra
.709 .752 .886 r
.68714 .2778 .69336 .28628 .7064 .27999 .70024 .27159 Mtetra
.679 .745 .901 r
.70024 .27159 .7064 .27999 .71958 .27491 .71346 .26653 Mtetra
.667 .742 .906 r
.71346 .26653 .71958 .27491 .73284 .27028 .72676 .26187 Mtetra
.664 .741 .907 r
.72676 .26187 .73284 .27028 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26115 .75357 .25265 Mtetra
.75357 .25265 .75956 .26115 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.663 .741 .907 r
.29924 .3987 .3066 .40598 .31807 .40206 .31074 .39475 Mtetra
.662 .74 .908 r
.31074 .39475 .31807 .40206 .32958 .3982 .32229 .39083 Mtetra
.65 .736 .912 r
.32229 .39083 .32958 .3982 .34113 .39474 .33386 .38725 Mtetra
.613 .722 .923 r
.33386 .38725 .34113 .39474 .35266 .39239 .34544 .38464 Mtetra
.544 .689 .934 r
.34544 .38464 .35266 .39239 .36418 .39162 .357 .38362 Mtetra
.569 .693 .925 r
.357 .38362 .36418 .39162 .37584 .38953 .36865 .38211 Mtetra
.763 .764 .854 r
.36865 .38211 .37584 .38953 .3879 .37938 .38067 .37391 Mtetra
.762 .82 .897 r
.38067 .37391 .3879 .37938 .39979 .37401 .39268 .36647 Mtetra
.664 .741 .907 r
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.608 .722 .926 r
.44066 .34993 .44763 .3576 .45958 .3603 .45275 .34733 Mtetra
.304 .439 .832 r
.45275 .34733 .45958 .3603 .47162 .36452 .46475 .35301 Mtetra
.485 .572 .868 r
.46475 .35301 .47162 .36452 .48382 .36456 .47695 .3542 Mtetra
.58 .645 .879 r
.47695 .3542 .48382 .36456 .49614 .36228 .48928 .35259 Mtetra
.63 .682 .88 r
.48928 .35259 .49614 .36228 .50853 .35881 .50169 .34939 Mtetra
.66 .7 .877 r
.50169 .34939 .50853 .35881 .52098 .35459 .51418 .34513 Mtetra
.686 .71 .866 r
.51418 .34513 .52098 .35459 .53349 .34962 .52672 .33981 Mtetra
.719 .715 .845 r
.52672 .33981 .53349 .34962 .54604 .34343 .5393 .33289 Mtetra
.761 .714 .808 r
.5393 .33289 .54604 .34343 .55861 .33492 .5519 .32313 Mtetra
.803 .707 .76 r
.5519 .32313 .55861 .33492 .57115 .32217 .56445 .30883 Mtetra
.679 .638 .802 r
.56445 .30883 .57115 .32217 .58369 .31093 .57712 .30286 Mtetra
.664 .741 .907 r
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.54 .689 .936 r
.62846 .28515 .63488 .29337 .64788 .29027 .64158 .28409 Mtetra
.457 .717 .98 r
.64158 .28409 .64788 .29027 .66116 .29205 .65481 .28381 Mtetra
.731 .766 .88 r
.65481 .28381 .66116 .29205 .67416 .2856 .66783 .2767 Mtetra
.738 .752 .864 r
.66783 .2767 .67416 .2856 .68714 .2778 .68087 .26907 Mtetra
.702 .746 .885 r
.68087 .26907 .68714 .2778 .70024 .27159 .69402 .26307 Mtetra
.676 .742 .901 r
.69402 .26307 .70024 .27159 .71346 .26653 .70729 .25806 Mtetra
.666 .741 .906 r
.70729 .25806 .71346 .26653 .72676 .26187 .72064 .25338 Mtetra
.664 .741 .907 r
.72064 .25338 .72676 .26187 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39475 .30335 .38737 Mtetra
.662 .74 .908 r
.30335 .38737 .31074 .39475 .32229 .39083 .31493 .38341 Mtetra
.654 .737 .911 r
.31493 .38341 .32229 .39083 .33386 .38725 .32654 .37968 Mtetra
.625 .725 .919 r
.32654 .37968 .33386 .38725 .34544 .38464 .33817 .37673 Mtetra
.563 .694 .928 r
.33817 .37673 .34544 .38464 .357 .38362 .34976 .37531 Mtetra
.548 .677 .923 r
.34976 .37531 .357 .38362 .36865 .38211 .36141 .37428 Mtetra
.708 .745 .881 r
.36141 .37428 .36865 .38211 .38067 .37391 .37335 .36857 Mtetra
.806 .825 .865 r
.37335 .36857 .38067 .37391 .39268 .36647 .38551 .35887 Mtetra
.664 .741 .907 r
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45275 .34733 .44578 .33797 Mtetra
.506 .634 .91 r
.44578 .33797 .45275 .34733 .46475 .35301 .45791 .33805 Mtetra
.452 .493 .811 r
.45791 .33805 .46475 .35301 .47695 .3542 .47008 .34097 Mtetra
.551 .576 .832 r
.47008 .34097 .47695 .3542 .48928 .35259 .4824 .34052 Mtetra
.612 .627 .841 r
.4824 .34052 .48928 .35259 .50169 .34939 .49483 .33784 Mtetra
.653 .655 .839 r
.49483 .33784 .50169 .34939 .51418 .34513 .50733 .33355 Mtetra
.688 .67 .827 r
.50733 .33355 .51418 .34513 .52672 .33981 .5199 .32762 Mtetra
.724 .674 .802 r
.5199 .32762 .52672 .33981 .5393 .33289 .53251 .31946 Mtetra
.76 .671 .765 r
.53251 .31946 .5393 .33289 .5519 .32313 .54512 .30787 Mtetra
.71 .629 .765 r
.54512 .30787 .5519 .32313 .56445 .30883 .55776 .29914 Mtetra
.661 .699 .875 r
.55776 .29914 .56445 .30883 .57712 .30286 .57049 .29473 Mtetra
.664 .741 .907 r
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.431 .634 .941 r
.62199 .27687 .62846 .28515 .64158 .28409 .63522 .27803 Mtetra
.59 .783 .972 r
.63522 .27803 .64158 .28409 .65481 .28381 .64839 .27514 Mtetra
.74 .759 .868 r
.64839 .27514 .65481 .28381 .66783 .2767 .66144 .26746 Mtetra
.728 .743 .863 r
.66144 .26746 .66783 .2767 .68087 .26907 .67453 .26018 Mtetra
.694 .74 .887 r
.67453 .26018 .68087 .26907 .69402 .26307 .68775 .25445 Mtetra
.673 .74 .901 r
.68775 .25445 .69402 .26307 .70729 .25806 .70107 .24951 Mtetra
.665 .741 .906 r
.70107 .24951 .70729 .25806 .72064 .25338 .71446 .24481 Mtetra
.664 .741 .907 r
.71446 .24481 .72064 .25338 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.663 .74 .908 r
.2959 .37994 .30335 .38737 .31493 .38341 .30751 .37592 Mtetra
.657 .738 .91 r
.30751 .37592 .31493 .38341 .32654 .37968 .31916 .37205 Mtetra
.637 .729 .915 r
.31916 .37205 .32654 .37968 .33817 .37673 .33083 .36875 Mtetra
.587 .703 .923 r
.33083 .36875 .33817 .37673 .34976 .37531 .34249 .36675 Mtetra
.543 .67 .92 r
.34249 .36675 .34976 .37531 .36141 .37428 .35415 .36583 Mtetra
.637 .71 .9 r
.35415 .36583 .36141 .37428 .37335 .36857 .366 .36251 Mtetra
.82 .806 .838 r
.366 .36251 .37335 .36857 .38551 .35887 .37828 .3514 Mtetra
.67 .748 .909 r
.37828 .3514 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.664 .741 .907 r
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .45791 .33805 .45098 .32586 Mtetra
.612 .624 .838 r
.45098 .32586 .45791 .33805 .47008 .34097 .46326 .32316 Mtetra
.522 .499 .772 r
.46326 .32316 .47008 .34097 .4824 .34052 .47554 .32416 Mtetra
.589 .553 .783 r
.47554 .32416 .4824 .34052 .49483 .33784 .48796 .32223 Mtetra
.639 .589 .782 r
.48796 .32223 .49483 .33784 .50733 .33355 .50048 .31789 Mtetra
.68 .61 .771 r
.50048 .31789 .50733 .33355 .5199 .32762 .51306 .31113 Mtetra
.715 .618 .748 r
.51306 .31113 .5199 .32762 .53251 .31946 .52568 .30142 Mtetra
.656 .574 .751 r
.52568 .30142 .53251 .31946 .54512 .30787 .53833 .29541 Mtetra
.651 .641 .827 r
.53833 .29541 .54512 .30787 .55776 .29914 .55103 .29098 Mtetra
.664 .741 .907 r
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.658 .739 .909 r
.60246 .27305 .60903 .28137 .62199 .27687 .61547 .26871 Mtetra
.346 .593 .938 r
.61547 .26871 .62199 .27687 .63522 .27803 .62877 .27124 Mtetra
.69 .797 .931 r
.62877 .27124 .63522 .27803 .64839 .27514 .6419 .26584 Mtetra
.739 .746 .857 r
.6419 .26584 .64839 .27514 .66144 .26746 .65498 .25797 Mtetra
.715 .734 .866 r
.65498 .25797 .66144 .26746 .67453 .26018 .66814 .2512 Mtetra
.685 .737 .89 r
.66814 .2512 .67453 .26018 .68775 .25445 .68142 .24576 Mtetra
.67 .739 .903 r
.68142 .24576 .68775 .25445 .70107 .24951 .69479 .24089 Mtetra
.665 .74 .907 r
.69479 .24089 .70107 .24951 .71446 .24481 .70823 .23618 Mtetra
.664 .741 .907 r
.70823 .23618 .71446 .24481 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20274 Mtetra
.80412 .20274 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.663 .741 .907 r
.28839 .37245 .2959 .37994 .30751 .37592 .30003 .36838 Mtetra
.66 .739 .908 r
.30003 .36838 .30751 .37592 .31916 .37205 .31172 .36439 Mtetra
.648 .733 .911 r
.31172 .36439 .31916 .37205 .33083 .36875 .32344 .36076 Mtetra
.612 .713 .917 r
.32344 .36076 .33083 .36875 .34249 .36675 .33516 .35811 Mtetra
.559 .676 .917 r
.33516 .35811 .34249 .36675 .35415 .36583 .34686 .35681 Mtetra
.578 .674 .905 r
.34686 .35681 .35415 .36583 .366 .36251 .35865 .3551 Mtetra
.731 .765 .88 r
.35865 .3551 .366 .36251 .37828 .3514 .37076 .34846 Mtetra
.809 .902 .907 r
.37076 .34846 .37828 .3514 .39027 .34703 .38301 .33927 Mtetra
.664 .741 .907 r
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46326 .32316 .45624 .3136 Mtetra
.661 .7 .875 r
.45624 .3136 .46326 .32316 .47554 .32416 .46864 .30925 Mtetra
.641 .599 .791 r
.46864 .30925 .47554 .32416 .48796 .32223 .4811 .30488 Mtetra
.633 .568 .764 r
.4811 .30488 .48796 .32223 .50048 .31789 .49361 .3005 Mtetra
.49361 .3005 .50048 .31789 .51306 .31113 .50619 .29609 Mtetra
.641 .599 .791 r
.50619 .29609 .51306 .31113 .52568 .30142 .51881 .29166 Mtetra
.661 .7 .875 r
.51881 .29166 .52568 .30142 .53833 .29541 .5315 .28721 Mtetra
.664 .741 .907 r
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.462 .651 .941 r
.59583 .26466 .60246 .27305 .61547 .26871 .60901 .26515 Mtetra
.466 .819 .997 r
.60901 .26515 .61547 .26871 .62877 .27124 .62222 .26306 Mtetra
.731 .771 .885 r
.62222 .26306 .62877 .27124 .6419 .26584 .63534 .25593 Mtetra
.728 .73 .852 r
.63534 .25593 .6419 .26584 .65498 .25797 .64847 .24838 Mtetra
.7 .728 .872 r
.64847 .24838 .65498 .25797 .66814 .2512 .66171 .2422 Mtetra
.677 .735 .894 r
.66171 .2422 .66814 .2512 .68142 .24576 .67504 .23703 Mtetra
.667 .739 .904 r
.67504 .23703 .68142 .24576 .69479 .24089 .68846 .2322 Mtetra
.664 .74 .907 r
.68846 .2322 .69479 .24089 .70823 .23618 .70194 .22746 Mtetra
.664 .741 .907 r
.70194 .22746 .70823 .23618 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20274 .79816 .19373 Mtetra
.79816 .19373 .80412 .20274 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.20052 .39321 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .38521 Mtetra
.22321 .38521 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30003 .36838 .2925 .36079 Mtetra
.662 .74 .908 r
.2925 .36079 .30003 .36838 .31172 .36439 .30422 .35671 Mtetra
.655 .737 .909 r
.30422 .35671 .31172 .36439 .32344 .36076 .31598 .35282 Mtetra
.633 .723 .913 r
.31598 .35282 .32344 .36076 .33516 .35811 .32776 .34955 Mtetra
.589 .692 .913 r
.32776 .34955 .33516 .35811 .34686 .35681 .33952 .3475 Mtetra
.559 .661 .905 r
.33952 .3475 .34686 .35681 .35865 .3551 .35131 .34625 Mtetra
.63 .701 .897 r
.35131 .34625 .35865 .3551 .37076 .34846 .36328 .34303 Mtetra
.794 .829 .879 r
.36328 .34303 .37076 .34846 .38301 .33927 .37558 .33394 Mtetra
.743 .831 .919 r
.37558 .33394 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.664 .741 .907 r
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.576 .706 .931 r
.57612 .26079 .58284 .26921 .59583 .26466 .5892 .25873 Mtetra
.397 .702 .983 r
.5892 .25873 .59583 .26466 .60901 .26515 .60242 .25905 Mtetra
.695 .823 .944 r
.60242 .25905 .60901 .26515 .62222 .26306 .61557 .2534 Mtetra
.732 .738 .856 r
.61557 .2534 .62222 .26306 .63534 .25593 .62871 .24573 Mtetra
.712 .72 .856 r
.62871 .24573 .63534 .25593 .64847 .24838 .64192 .23887 Mtetra
.687 .727 .881 r
.64192 .23887 .64847 .24838 .66171 .2422 .65522 .23324 Mtetra
.671 .736 .899 r
.65522 .23324 .66171 .2422 .67504 .23703 .66861 .22825 Mtetra
.665 .74 .905 r
.66861 .22825 .67504 .23703 .68846 .2322 .68207 .22345 Mtetra
.664 .741 .907 r
.68207 .22345 .68846 .2322 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.19268 .38582 .20052 .39321 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .38521 .21543 .37776 Mtetra
.21543 .37776 .22321 .38521 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36079 .28489 .35314 Mtetra
.663 .741 .908 r
.28489 .35314 .2925 .36079 .30422 .35671 .29665 .34899 Mtetra
.66 .739 .908 r
.29665 .34899 .30422 .35671 .31598 .35282 .30845 .34492 Mtetra
.648 .731 .91 r
.30845 .34492 .31598 .35282 .32776 .34955 .32029 .34119 Mtetra
.619 .71 .91 r
.32029 .34119 .32776 .34955 .33952 .3475 .33213 .33829 Mtetra
.578 .673 .904 r
.33213 .33829 .33952 .3475 .35131 .34625 .34397 .33652 Mtetra
.576 .66 .895 r
.34397 .33652 .35131 .34625 .36328 .34303 .35587 .33484 Mtetra
.666 .733 .9 r
.35587 .33484 .36328 .34303 .37558 .33394 .36798 .33047 Mtetra
.818 .889 .894 r
.36798 .33047 .37558 .33394 .3878 .32718 .38039 .3207 Mtetra
.71 .794 .916 r
.38039 .3207 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.664 .741 .907 r
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.616 .723 .922 r
.55633 .25691 .56316 .26536 .57612 .26079 .56936 .25377 Mtetra
.394 .664 .967 r
.56936 .25377 .57612 .26079 .5892 .25873 .58254 .25469 Mtetra
.628 .871 .987 r
.58254 .25469 .5892 .25873 .60242 .25905 .5957 .25013 Mtetra
.729 .755 .873 r
.5957 .25013 .60242 .25905 .61557 .2534 .60885 .24283 Mtetra
.716 .714 .847 r
.60885 .24283 .61557 .2534 .62871 .24573 .62204 .23562 Mtetra
.694 .717 .866 r
.62204 .23562 .62871 .24573 .64192 .23887 .63532 .22955 Mtetra
.676 .729 .89 r
.63532 .22955 .64192 .23887 .65522 .23324 .64868 .22432 Mtetra
.667 .737 .902 r
.64868 .22432 .65522 .23324 .66861 .22825 .66212 .21943 Mtetra
.664 .74 .906 r
.66212 .21943 .66861 .22825 .68207 .22345 .67563 .21462 Mtetra
.664 .741 .907 r
.67563 .21462 .68207 .22345 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37433 Mtetra
.19615 .37433 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35314 .27723 .34542 Mtetra
.27723 .34542 .28489 .35314 .29665 .34899 .28902 .34123 Mtetra
.662 .74 .908 r
.28902 .34123 .29665 .34899 .30845 .34492 .30086 .33705 Mtetra
.657 .736 .908 r
.30086 .33705 .30845 .34492 .32029 .34119 .31274 .33301 Mtetra
.642 .724 .908 r
.31274 .33301 .32029 .34119 .33213 .33829 .32465 .32943 Mtetra
.611 .697 .905 r
.32465 .32943 .33213 .33829 .34397 .33652 .33657 .32672 Mtetra
.58 .662 .894 r
.33657 .32672 .34397 .33652 .35587 .33484 .3485 .32489 Mtetra
.59 .663 .889 r
.3485 .32489 .35587 .33484 .36798 .33047 .36051 .32279 Mtetra
.672 .751 .91 r
.36051 .32279 .36798 .33047 .38039 .3207 .37272 .31819 Mtetra
.795 .923 .922 r
.37272 .31819 .38039 .3207 .39265 .31493 .38517 .30941 Mtetra
.743 .831 .919 r
.38517 .30941 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.664 .741 .907 r
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.575 .706 .931 r
.53647 .25301 .54339 .2615 .55633 .25691 .54947 .25092 Mtetra
.426 .717 .985 r
.54947 .25092 .55633 .25691 .56936 .25377 .56258 .25075 Mtetra
.591 .89 .99 r
.56258 .25075 .56936 .25377 .58254 .25469 .57573 .24636 Mtetra
.724 .768 .888 r
.57573 .24636 .58254 .25469 .5957 .25013 .58888 .23942 Mtetra
.716 .712 .845 r
.58888 .23942 .5957 .25013 .60885 .24283 .60207 .23219 Mtetra
.697 .707 .856 r
.60207 .23219 .60885 .24283 .62204 .23562 .61533 .22585 Mtetra
.68 .721 .881 r
.61533 .22585 .62204 .23562 .63532 .22955 .62867 .22041 Mtetra
.669 .733 .898 r
.62867 .22041 .63532 .22955 .64868 .22432 .64209 .21542 Mtetra
.665 .739 .905 r
.64209 .21542 .64868 .22432 .66212 .21943 .65557 .21056 Mtetra
.664 .74 .907 r
.65557 .21056 .66212 .21943 .67563 .21462 .66913 .20572 Mtetra
.664 .741 .907 r
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37433 .18821 .36679 Mtetra
.18821 .36679 .19615 .37433 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34123 .28132 .33341 Mtetra
.663 .74 .907 r
.28132 .33341 .28902 .34123 .30086 .33705 .2932 .32917 Mtetra
.662 .739 .907 r
.2932 .32917 .30086 .33705 .31274 .33301 .30512 .32496 Mtetra
.655 .734 .907 r
.30512 .32496 .31274 .33301 .32465 .32943 .31709 .32094 Mtetra
.638 .718 .905 r
.31709 .32094 .32465 .32943 .33657 .32672 .32908 .3174 Mtetra
.611 .688 .897 r
.32908 .3174 .33657 .32672 .3485 .32489 .34108 .31464 Mtetra
.589 .657 .885 r
.34108 .31464 .3485 .32489 .36051 .32279 .35312 .31256 Mtetra
.597 .662 .884 r
.35312 .31256 .36051 .32279 .37272 .31819 .36523 .31024 Mtetra
.652 .741 .914 r
.36523 .31024 .37272 .31819 .38517 .30941 .3775 .3062 Mtetra
.734 .904 .954 r
.3775 .3062 .38517 .30941 .39756 .30252 .38995 .29942 Mtetra
.805 .909 .912 r
.38995 .29942 .39756 .30252 .4099 .29813 .40253 .29015 Mtetra
.67 .748 .909 r
.40253 .29015 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.664 .741 .907 r
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.658 .739 .909 r
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24929 Mtetra
.463 .66 .947 r
.51652 .24929 .52354 .25762 .53647 .25301 .52949 .24952 Mtetra
.47 .825 .996 r
.52949 .24952 .53647 .25301 .54947 .25092 .54255 .24726 Mtetra
.643 .888 .985 r
.54255 .24726 .54947 .25092 .56258 .25075 .55567 .24222 Mtetra
.719 .762 .887 r
.55567 .24222 .56258 .25075 .57573 .24636 .56882 .23544 Mtetra
.71 .707 .845 r
.56882 .23544 .57573 .24636 .58888 .23942 .58201 .22839 Mtetra
.695 .7 .85 r
.58201 .22839 .58888 .23942 .60207 .23219 .59526 .22203 Mtetra
.681 .713 .873 r
.59526 .22203 .60207 .23219 .61533 .22585 .60858 .21647 Mtetra
.671 .729 .893 r
.60858 .21647 .61533 .22585 .62867 .22041 .62197 .21138 Mtetra
.666 .737 .903 r
.62197 .21138 .62867 .22041 .64209 .21542 .63544 .20648 Mtetra
.664 .74 .906 r
.63544 .20648 .64209 .21542 .65557 .21056 .64897 .20161 Mtetra
.664 .741 .907 r
.64897 .20161 .65557 .21056 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15179 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32917 .28547 .32125 Mtetra
.663 .74 .907 r
.28547 .32125 .2932 .32917 .30512 .32496 .29743 .31695 Mtetra
.661 .738 .907 r
.29743 .31695 .30512 .32496 .31709 .32094 .30944 .31271 Mtetra
.654 .731 .906 r
.30944 .31271 .31709 .32094 .32908 .3174 .32149 .30865 Mtetra
.64 .714 .901 r
.32149 .30865 .32908 .3174 .34108 .31464 .33357 .30501 Mtetra
.619 .685 .891 r
.33357 .30501 .34108 .31464 .35312 .31256 .34568 .30199 Mtetra
.601 .658 .878 r
.34568 .30199 .35312 .31256 .36523 .31024 .35783 .29952 Mtetra
.601 .655 .875 r
.35783 .29952 .36523 .31024 .3775 .3062 .37004 .29703 Mtetra
.627 .703 .9 r
.37004 .29703 .3775 .3062 .38995 .29942 .38237 .29371 Mtetra
.67 .816 .954 r
.38237 .29371 .38995 .29942 .40253 .29015 .39482 .28897 Mtetra
.653 .944 .959 r
.39482 .28897 .40253 .29015 .41497 .2855 .40737 .28289 Mtetra
.72 .924 .961 r
.40737 .28289 .41497 .2855 .42746 .28102 .41999 .27612 Mtetra
.73 .858 .941 r
.41999 .27612 .42746 .28102 .44001 .27652 .43265 .26951 Mtetra
.703 .789 .918 r
.43265 .26951 .44001 .27652 .45261 .272 .44533 .26374 Mtetra
.664 .744 .91 r
.44533 .26374 .45261 .272 .46527 .26746 .45803 .25916 Mtetra
.623 .73 .923 r
.45803 .25916 .46527 .26746 .478 .2629 .47077 .25578 Mtetra
.581 .75 .958 r
.47077 .25578 .478 .2629 .49078 .25832 .48357 .25324 Mtetra
.536 .801 .994 r
.48357 .25324 .49078 .25832 .50362 .25372 .49644 .25087 Mtetra
.5 .856 .991 r
.49644 .25087 .50362 .25372 .51652 .24929 .5094 .24781 Mtetra
.527 .9 .961 r
.5094 .24781 .51652 .24929 .52949 .24952 .52244 .2434 Mtetra
.699 .825 .942 r
.52244 .2434 .52949 .24952 .54255 .24726 .53553 .23757 Mtetra
.711 .732 .868 r
.53553 .23757 .54255 .24726 .55567 .24222 .54867 .23087 Mtetra
.701 .695 .842 r
.54867 .23087 .55567 .24222 .56882 .23544 .56186 .22416 Mtetra
.689 .693 .848 r
.56186 .22416 .56882 .23544 .58201 .22839 .5751 .21799 Mtetra
.679 .708 .87 r
.5751 .21799 .58201 .22839 .59526 .22203 .5884 .21245 Mtetra
.671 .725 .89 r
.5884 .21245 .59526 .22203 .60858 .21647 .60178 .20732 Mtetra
.666 .735 .901 r
.60178 .20732 .60858 .21647 .62197 .21138 .61522 .20239 Mtetra
.664 .739 .906 r
.61522 .20239 .62197 .21138 .63544 .20648 .62873 .19749 Mtetra
.664 .74 .907 r
.62873 .19749 .63544 .20648 .64897 .20161 .64231 .19259 Mtetra
.664 .741 .907 r
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15179 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32125 .27767 .31327 Mtetra
.27767 .31327 .28547 .32125 .29743 .31695 .28967 .30892 Mtetra
.663 .74 .907 r
.28967 .30892 .29743 .31695 .30944 .31271 .30172 .30458 Mtetra
.661 .738 .907 r
.30172 .30458 .30944 .31271 .32149 .30865 .31381 .30027 Mtetra
.656 .731 .905 r
.31381 .30027 .32149 .30865 .33357 .30501 .32596 .29612 Mtetra
.645 .715 .899 r
.32596 .29612 .33357 .30501 .34568 .30199 .33814 .29226 Mtetra
.63 .69 .887 r
.33814 .29226 .34568 .30199 .35783 .29952 .35036 .28883 Mtetra
.616 .664 .873 r
.35036 .28883 .35783 .29952 .37004 .29703 .36262 .28581 Mtetra
.611 .651 .865 r
.36262 .28581 .37004 .29703 .38237 .29371 .37494 .28294 Mtetra
.618 .665 .873 r
.37494 .28294 .38237 .29371 .39482 .28897 .38735 .27983 Mtetra
.635 .71 .901 r
.38735 .27983 .39482 .28897 .40737 .28289 .39984 .27619 Mtetra
.651 .785 .945 r
.39984 .27619 .40737 .28289 .41999 .27612 .41242 .27196 Mtetra
.643 .864 .983 r
.41242 .27196 .41999 .27612 .43265 .26951 .42507 .26735 Mtetra
.594 .908 .981 r
.42507 .26735 .43265 .26951 .44533 .26374 .43778 .26265 Mtetra
.535 .908 .954 r
.43778 .26265 .44533 .26374 .45803 .25916 .45055 .25803 Mtetra
.527 .904 .953 r
.45055 .25803 .45803 .25916 .47077 .25578 .46338 .25352 Mtetra
.584 .905 .982 r
.46338 .25352 .47077 .25578 .48357 .25324 .47627 .2489 Mtetra
.656 .868 .979 r
.47627 .2489 .48357 .25324 .49644 .25087 .48923 .2439 Mtetra
.692 .796 .93 r
.48923 .2439 .49644 .25087 .5094 .24781 .50225 .23831 Mtetra
.699 .733 .877 r
.50225 .23831 .5094 .24781 .52244 .2434 .51532 .23218 Mtetra
.695 .695 .846 r
.51532 .23218 .52244 .2434 .53553 .23757 .52845 .22579 Mtetra
.688 .683 .84 r
.52845 .22579 .53553 .23757 .54867 .23087 .54162 .21956 Mtetra
.681 .69 .851 r
.54162 .21956 .54867 .23087 .56186 .22416 .55485 .21372 Mtetra
.675 .707 .871 r
.55485 .21372 .56186 .22416 .5751 .21799 .56814 .20832 Mtetra
.669 .723 .89 r
.56814 .20832 .5751 .21799 .5884 .21245 .5815 .20322 Mtetra
.666 .734 .901 r
.5815 .20322 .5884 .21245 .60178 .20732 .59492 .19827 Mtetra
.664 .739 .905 r
.59492 .19827 .60178 .20732 .61522 .20239 .60841 .19336 Mtetra
.664 .74 .907 r
.60841 .19336 .61522 .20239 .62873 .19749 .62196 .18844 Mtetra
.664 .741 .907 r
.62196 .18844 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30458 .29392 .29644 Mtetra
.663 .74 .907 r
.29392 .29644 .30172 .30458 .31381 .30027 .30606 .29203 Mtetra
.662 .738 .906 r
.30606 .29203 .31381 .30027 .32596 .29612 .31825 .28765 Mtetra
.658 .732 .904 r
.31825 .28765 .32596 .29612 .33814 .29226 .33049 .28335 Mtetra
.652 .719 .898 r
.33049 .28335 .33814 .29226 .35036 .28883 .34278 .27923 Mtetra
.643 .7 .888 r
.34278 .27923 .35036 .28883 .36262 .28581 .35511 .27534 Mtetra
.633 .678 .875 r
.35511 .27534 .36262 .28581 .37494 .28294 .36749 .2717 Mtetra
.628 .66 .862 r
.36749 .2717 .37494 .28294 .38735 .27983 .37993 .26819 Mtetra
.628 .653 .856 r
.37993 .26819 .38735 .27983 .39984 .27619 .39244 .26465 Mtetra
.633 .658 .857 r
.39244 .26465 .39984 .27619 .41242 .27196 .40502 .26091 Mtetra
.641 .672 .864 r
.40502 .26091 .41242 .27196 .42507 .26735 .41768 .25687 Mtetra
.651 .689 .873 r
.41768 .25687 .42507 .26735 .43778 .26265 .43041 .25253 Mtetra
.66 .702 .878 r
.43041 .25253 .43778 .26265 .45055 .25803 .44321 .24788 Mtetra
.667 .704 .875 r
.44321 .24788 .45055 .25803 .46338 .25352 .45608 .24291 Mtetra
.673 .698 .865 r
.45608 .24291 .46338 .25352 .47627 .2489 .46901 .23763 Mtetra
.677 .687 .852 r
.46901 .23763 .47627 .2489 .48923 .2439 .482 .23206 Mtetra
.678 .677 .842 r
.482 .23206 .48923 .2439 .50225 .23831 .49505 .22628 Mtetra
.678 .674 .839 r
.49505 .22628 .50225 .23831 .51532 .23218 .50816 .22046 Mtetra
.676 .68 .846 r
.50816 .22046 .51532 .23218 .52845 .22579 .52131 .21478 Mtetra
.674 .694 .861 r
.52131 .21478 .52845 .22579 .54162 .21956 .53453 .20933 Mtetra
.671 .71 .878 r
.53453 .20933 .54162 .21956 .55485 .21372 .5478 .20412 Mtetra
.667 .725 .892 r
.5478 .20412 .55485 .21372 .56814 .20832 .56114 .19908 Mtetra
.665 .734 .901 r
.56114 .19908 .56814 .20832 .5815 .20322 .57454 .19413 Mtetra
.664 .739 .905 r
.57454 .19413 .5815 .20322 .59492 .19827 .58801 .1892 Mtetra
.664 .74 .907 r
.58801 .1892 .59492 .19827 .60841 .19336 .60154 .18426 Mtetra
.664 .741 .907 r
.60154 .18426 .60841 .19336 .62196 .18844 .61514 .1793 Mtetra
.61514 .1793 .62196 .18844 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29644 .28606 .28824 Mtetra
.28606 .28824 .29392 .29644 .30606 .29203 .29823 .28378 Mtetra
.663 .74 .907 r
.29823 .28378 .30606 .29203 .31825 .28765 .31046 .27931 Mtetra
.663 .739 .906 r
.31046 .27931 .31825 .28765 .33049 .28335 .32274 .27484 Mtetra
.661 .735 .904 r
.32274 .27484 .33049 .28335 .34278 .27923 .33508 .27041 Mtetra
.658 .727 .9 r
.33508 .27041 .34278 .27923 .35511 .27534 .34747 .26604 Mtetra
.653 .714 .893 r
.34747 .26604 .35511 .27534 .36749 .2717 .35991 .26177 Mtetra
.649 .699 .882 r
.35991 .26177 .36749 .2717 .37993 .26819 .37241 .25759 Mtetra
.645 .683 .871 r
.37241 .25759 .37993 .26819 .39244 .26465 .38497 .25345 Mtetra
.644 .671 .861 r
.38497 .25345 .39244 .26465 .40502 .26091 .39759 .24927 Mtetra
.646 .664 .854 r
.39759 .24927 .40502 .26091 .41768 .25687 .41028 .24498 Mtetra
.649 .661 .848 r
.41028 .24498 .41768 .25687 .43041 .25253 .42304 .2405 Mtetra
.653 .662 .845 r
.42304 .2405 .43041 .25253 .44321 .24788 .43586 .2358 Mtetra
.658 .663 .844 r
.43586 .2358 .44321 .24788 .45608 .24291 .44876 .23089 Mtetra
.662 .667 .844 r
.44876 .23089 .45608 .24291 .46901 .23763 .46171 .22578 Mtetra
.665 .672 .847 r
.46171 .22578 .46901 .23763 .482 .23206 .47473 .22056 Mtetra
.668 .681 .853 r
.47473 .22056 .482 .23206 .49505 .22628 .4878 .21529 Mtetra
.668 .692 .863 r
.4878 .21529 .49505 .22628 .50816 .22046 .50093 .21007 Mtetra
.668 .706 .875 r
.50093 .21007 .50816 .22046 .52131 .21478 .51412 .20493 Mtetra
.667 .719 .888 r
.51412 .20493 .52131 .21478 .53453 .20933 .52738 .19989 Mtetra
.666 .729 .897 r
.52738 .19989 .53453 .20933 .5478 .20412 .54069 .19491 Mtetra
.665 .736 .903 r
.54069 .19491 .5478 .20412 .56114 .19908 .55407 .18997 Mtetra
.664 .739 .906 r
.55407 .18997 .56114 .19908 .57454 .19413 .56752 .18502 Mtetra
.664 .74 .907 r
.56752 .18502 .57454 .19413 .58801 .1892 .58103 .18006 Mtetra
.664 .741 .907 r
.58103 .18006 .58801 .1892 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27931 .3026 .27096 Mtetra
.664 .74 .907 r
.3026 .27096 .31046 .27931 .32274 .27484 .31492 .26642 Mtetra
.663 .739 .907 r
.31492 .26642 .32274 .27484 .33508 .27041 .3273 .26187 Mtetra
.662 .737 .905 r
.3273 .26187 .33508 .27041 .34747 .26604 .33973 .25733 Mtetra
.661 .733 .903 r
.33973 .25733 .34747 .26604 .35991 .26177 .35222 .25279 Mtetra
.66 .727 .899 r
.35222 .25279 .35991 .26177 .37241 .25759 .36477 .24826 Mtetra
.658 .719 .893 r
.36477 .24826 .37241 .25759 .38497 .25345 .37738 .24374 Mtetra
.657 .711 .887 r
.37738 .24374 .38497 .25345 .39759 .24927 .39004 .23921 Mtetra
.657 .703 .881 r
.39004 .23921 .39759 .24927 .41028 .24498 .40277 .23464 Mtetra
.658 .698 .876 r
.40277 .23464 .41028 .24498 .42304 .2405 .41556 .22999 Mtetra
.659 .696 .873 r
.41556 .22999 .42304 .2405 .43586 .2358 .42842 .22525 Mtetra
.661 .696 .872 r
.42842 .22525 .43586 .2358 .44876 .23089 .44134 .22041 Mtetra
.663 .7 .874 r
.44134 .22041 .44876 .23089 .46171 .22578 .45432 .21551 Mtetra
.664 .706 .878 r
.45432 .21551 .46171 .22578 .47473 .22056 .46737 .21056 Mtetra
.665 .713 .884 r
.46737 .21056 .47473 .22056 .4878 .21529 .48047 .20559 Mtetra
.665 .721 .891 r
.48047 .20559 .4878 .21529 .50093 .21007 .49364 .20063 Mtetra
.665 .729 .897 r
.49364 .20063 .50093 .21007 .51412 .20493 .50687 .19568 Mtetra
.665 .734 .902 r
.50687 .19568 .51412 .20493 .52738 .19989 .52016 .19073 Mtetra
.664 .738 .905 r
.52016 .19073 .52738 .19989 .54069 .19491 .53352 .18579 Mtetra
.664 .74 .906 r
.53352 .18579 .54069 .19491 .55407 .18997 .54694 .18083 Mtetra
.664 .74 .907 r
.54694 .18083 .55407 .18997 .56752 .18502 .56043 .17585 Mtetra
.664 .741 .907 r
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26712 Mtetra
.28238 .26712 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26642 .30703 .25797 Mtetra
.30703 .25797 .31492 .26642 .3273 .26187 .31944 .25337 Mtetra
.664 .74 .907 r
.31944 .25337 .3273 .26187 .33973 .25733 .33191 .24874 Mtetra
.663 .739 .906 r
.33191 .24874 .33973 .25733 .35222 .25279 .34444 .2441 Mtetra
.663 .738 .905 r
.34444 .2441 .35222 .25279 .36477 .24826 .35703 .23945 Mtetra
.663 .735 .904 r
.35703 .23945 .36477 .24826 .37738 .24374 .36968 .23478 Mtetra
.662 .732 .902 r
.36968 .23478 .37738 .24374 .39004 .23921 .38239 .2301 Mtetra
.662 .729 .899 r
.38239 .2301 .39004 .23921 .40277 .23464 .39515 .22538 Mtetra
.662 .727 .897 r
.39515 .22538 .40277 .23464 .41556 .22999 .40799 .22064 Mtetra
.663 .726 .896 r
.40799 .22064 .41556 .22999 .42842 .22525 .42088 .21585 Mtetra
.42088 .21585 .42842 .22525 .44134 .22041 .43383 .21103 Mtetra
.664 .727 .897 r
.43383 .21103 .44134 .22041 .45432 .21551 .44685 .20618 Mtetra
.664 .73 .899 r
.44685 .20618 .45432 .21551 .46737 .21056 .45993 .2013 Mtetra
.664 .733 .901 r
.45993 .2013 .46737 .21056 .48047 .20559 .47307 .1964 Mtetra
.664 .736 .903 r
.47307 .1964 .48047 .20559 .49364 .20063 .48628 .19148 Mtetra
.664 .738 .905 r
.48628 .19148 .49364 .20063 .50687 .19568 .49955 .18655 Mtetra
.664 .739 .906 r
.49955 .18655 .50687 .19568 .52016 .19073 .51289 .18159 Mtetra
.664 .74 .907 r
.51289 .18159 .52016 .19073 .53352 .18579 .52629 .17662 Mtetra
.664 .741 .907 r
.52629 .17662 .53352 .18579 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26712 .27435 .25868 Mtetra
.27435 .25868 .28238 .26712 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25337 .31152 .2448 Mtetra
.31152 .2448 .31944 .25337 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .2441 .33659 .23545 Mtetra
.664 .74 .907 r
.33659 .23545 .34444 .2441 .35703 .23945 .34921 .23074 Mtetra
.34921 .23074 .35703 .23945 .36968 .23478 .3619 .22601 Mtetra
.664 .739 .906 r
.3619 .22601 .36968 .23478 .38239 .2301 .37465 .22126 Mtetra
.37465 .22126 .38239 .2301 .39515 .22538 .38745 .21648 Mtetra
.664 .738 .905 r
.38745 .21648 .39515 .22538 .40799 .22064 .40032 .21168 Mtetra
.40032 .21168 .40799 .22064 .42088 .21585 .41325 .20685 Mtetra
.41325 .20685 .42088 .21585 .43383 .21103 .42625 .202 Mtetra
.42625 .202 .43383 .21103 .44685 .20618 .4393 .19713 Mtetra
.664 .739 .906 r
.4393 .19713 .44685 .20618 .45993 .2013 .45242 .19223 Mtetra
.664 .74 .906 r
.45242 .19223 .45993 .2013 .47307 .1964 .46561 .1873 Mtetra
.664 .74 .907 r
.46561 .1873 .47307 .1964 .48628 .19148 .47885 .18236 Mtetra
.47885 .18236 .48628 .19148 .49955 .18655 .49216 .17739 Mtetra
.664 .741 .907 r
.49216 .17739 .49955 .18655 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23074 .34133 .22198 Mtetra
.34133 .22198 .34921 .23074 .3619 .22601 .35405 .2172 Mtetra
.35405 .2172 .3619 .22601 .37465 .22126 .36683 .2124 Mtetra
.664 .74 .907 r
.36683 .2124 .37465 .22126 .38745 .21648 .37968 .20758 Mtetra
.37968 .20758 .38745 .21648 .40032 .21168 .39259 .20273 Mtetra
.39259 .20273 .40032 .21168 .41325 .20685 .40556 .19787 Mtetra
.40556 .19787 .41325 .20685 .42625 .202 .41859 .19297 Mtetra
.41859 .19297 .42625 .202 .4393 .19713 .43169 .18806 Mtetra
.43169 .18806 .4393 .19713 .45242 .19223 .44485 .18312 Mtetra
.664 .741 .907 r
.44485 .18312 .45242 .19223 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18236 .47136 .17316 Mtetra
.47136 .17316 .47885 .18236 .49216 .17739 .48471 .16815 Mtetra
.48471 .16815 .49216 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19787 .39779 .18881 Mtetra
.39779 .18881 .40556 .19787 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13036 Mtetra
.45422 .13036 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13036 .44641 .12069 Mtetra
.44641 .12069 .45422 .13036 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10479 Mtetra
.48753 .10479 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16273 Mtetra
.30546 .16273 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14232 Mtetra
.3579 .14232 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10479 .47978 .09488 Mtetra
.47978 .09488 .48753 .10479 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18844 Mtetra
.20751 .18844 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17854 Mtetra
.23279 .17854 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16273 .2971 .15335 Mtetra
.2971 .15335 .30546 .16273 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000280:Vmj0030000002Y_NP0ZKgX01`0ZKgX
00<000000?ooo`3oool0B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`04
0:Vmj0000000000000000080ZKgX00<000000:Vmj02Y_NP0Q@2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj0000000000008d0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000005@0ZKgX0`2Y_NL80:Vmj0<0ZKgW
;@2Y_NP00`000000ZKgX0:Vmj00N0:Vmj0030000003oool0oooo04H0oooo001M0?ooo`040:Vmj000
00000000000005@0ZKgX1P2Y_NL50:Vmj0H0ZKgW0P2Y_NP30:VmibL0ZKgX00<000000:Vmj02Y_NP0
7`2Y_NP00`000000oooo0?ooo`150?ooo`00F`3oool3000004/0ZKgX0`2Y_NL50:Vmj0D0ZKcW1P2Y
_NL50:Vli`/0ZKgW9P2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030?ooo`000000oooo04D0oooo001H
0?ooo`<00000C02Y_NP60:Vmi`80ZKgX202Y_>L30:Vmi`<0Z[_V1@2Y_>L50:Zli`X0ZKgW8@2Y_NP0
0`000000ZKgX0:Vmj00P0:Vmj0030000003oool0oooo04@0oooo001E0?ooo`030:Vmj00000000000
04/0ZKgX2P2Y_NL;0:Vli`H0Z[_V0P2Y_>L30:Zji@D0Z[cW0P2Y_NL30:ZkiPX0ZKgW6`2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0B02Y_NP30:Vli`D0ZKgW1@2Y^nH60:Vli`D0Z[[U1@2Z^nH60:Zji@@0Z[cW1P2Z^nH20:Vmi`<0
Z[_V1@2Y_NL30:Vmj0<0ZKgW502Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480
oooo001A0?ooo`800000C02Y_NP60:Vli`80ZKgW0`2Y^^H50:VkiP<0ZKcW0`2Z^>@50:Zji@D0Z[SS
1@2Z^^D50:Zii0/0Z[_V2`2Y_NL20:Vmj0<0ZKgW3P2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000
003oool0oooo0480oooo001>0?ooo`<00000BP2Y_NP:0:Vli`H0ZK[V1@2Y^nH60:Zhi080Z[[U0`2[
]=l50:Zhh`80Z[[U0`2[]N050:Zii0D0ZkWS1@2Z^nH60:ZliP/0ZKgW3@2Y_NP00`000000ZKgX0:Vm
j00S0:Vmj0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?
03D00000000001AO0<Coo`0Y0?ooo`800000B@2Y_NP:0:Vli`D0ZK[U1P2Y^^H50:ZfhPD0Z[ST1P2[
]=l40:Zhh`H0ZkGP0P2Z^N@30:bdgPD0ZkWS0P2Z^nH30:^ih`H0Z[cV1@2Z_>L50:Vmi`d0ZKgX00<0
00000:Vmj02Y_NP0902Y_NP00`000000oooo0?ooo`100?ooo`006@3oool02P3ogi`0B01d0;ooo`3o
ool0oooO05lD000DGl@0oooo0<AO5000=HlV0?ooo`<000000P2Y_NP00`000000ZKgX0:Vmj0140:Vm
j0X0ZKcW0`2Y^ND50:Vji@<0ZK[V0`2Y]>050:ZfhP80Z[ST0`2[/M`50:^dg`D0[;7L1@2[]N060:bd
gPX0ZkWS0`2Z_>H30:^ji0D0Z[cW0P2Y_NL30:Zmi``0ZKgX00<000000:Vmj02Y_NP0902Y_NP00`00
0000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool001T0oooo00/0omnL04P0
M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`030:Vmj0000000000004X0
ZKgX2P2Y_>L60:Vii@D0ZK[U1P2Y]>040:ZfhPH0Zk7L0P2[]=l30:f^f0D0[;7L0P2[]N030:j`f@D0
[;CN1@2]]Mh60:^ih`H0Zk[T102Z_>L60:Zmi`80ZKgX0`2Y_NL70:Vmj0030000002Y_NP0ZKgX02@0
ZKgX00<000000?ooo`3oool0203oool01P3ooml0W4P004RLg`3oool0gia8001d_c40oooo000=0?oo
o`030?oOW0180000000000<0000000<0001d0;ooo`3oool00`3oool02`3ogi`0B01d0;ooo`3oool0
omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo0`0000180:Vmj0D0ZKgW1P2Y_>L:0:Vii@D0
ZK?O1@2Y]>050:^^fPD0Zk7L1@2][]P50:bag0H0[[3I0P2/]=h30;2af@D0[KGN0`2[^N<30:jfg`D0
Zk[T1@2[^nD50:Zmi`H0ZKgW1P2Y_NP00`000000ZKgX0:Vmj00T0:Vmj0030000003oool0oooo00P0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0_ooo
0?ooo`3o_g@001AO0<Coo`3oool0oon?03D0501Oa?l07P3oool3000004T0ZKgX1`2Y_NL30:Vli`<0
ZK[U1`2Y^ND30:Vbg`D0ZK?O0P2Y]>030:Z/f0D0ZjkJ0P2[/M`30:f/ePD0[JkH0P2//M`30;2^e`D0
[[3I1@2`/MT50:fegPL0[[KO0P2[^^@30:jhh@D0Zk_U1@2Z_>H50:Vmi`H0ZKgX00<000000:Vmj02Y
_NP09@2Y_NP00`000000oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`
0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0
oooo0`00001:0:Vmj0X0ZKgW1P2Y^^D40:Vii@H0ZK;O102Y/ml50:Z/f0D0ZjkJ1@2][=H50:f^f0H0
/:kG0P2^/=T30;>ae`D0/;7I0P2]]Mh30;6cf@H0[[KO1P2^^>420:^ki@<0[K[S1@2Z_>H20:Vmi`<0
Z[gW1@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo
_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000CP2Y_NP50:Vmi`D0ZK[V1@2Y^^D50:Rb
g`D0ZK;O1@2YZ]P50:Z/f080ZjkJ0`2][ML50:f/eP80[JkH0`2a/MP50;2^e`D0/k7G1@2`/MT60;6c
f@<0[[KO0`2b]=/50:jhh@H0[K[S102Z_>H60:Zmi`@0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`00
0000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`00603oool0
2`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo0?ooo`34Ga@003F?01L0oooo0`00001A0:Vm
j080ZKgW0`2Y^nH50:VjiPD0Z;;P1@2X/]l20:Vbg`<0Z:WH1@2YZ]P40:Z/f0D0[JgG1@2][=H60;6a
f080/:kG0`2f^mh50;>ae`80/;7I0`2e]=P60;6cf@H0/[CK0P2^^>430;6gg@D0[K[S1@2[_>H50:Zm
i`@0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0540ZKgX1P2Y^nH20:VjiP<0Z;?Q1@2X
/^040:Rbg`D0Z:WH1@2YZ]P50:f_fPD0[JgG0P2][=H30;:kh0D0/K7H1@2f^mh50;>ae`H0]KCH0`2a
/mT30;Nff0D0/[CK1P2a]md20:fjh`<0[k[Q1@2[_>H50:Zmi`<0ZKgX00<000000:Vmj02Y_NP0:02Y
_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo
00<0ZKgX000000000000D`2Y_NP50:Vli`D0ZK_V1@2X/n450:Rbh0D0YjWH1@2XZMP20:VZf0<0[;;M
1@2][mX40:f]e`H0/[_P0P2a/MP30;;Cl@D0][_N0P2c/ML30;S3h`H0]KCH1P2g]]P20;:df`<0]kKH
1@2a]md60:njh@80ZkcV0`2]_>@50:Zmi`80Z[gX00<000000:Zmj02Z_NP0:02Y_NP00`000000oooo
0?ooo`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`00001A0:Vmj0X0ZKcW
1@2X]^<50:Rch@80Z;;P0`2VZMT50:NYf0@0Z:WH1@2//]d50:f_fPD0/L_^1@2b^n060;;Cl@@0][_N
1P2h`n<30;Fdf0<0^LCS2`2g]]P20;6gg@<0][SK1@2_^^460:fli080Z[gW0`2[_NL00`2Z_NP00000
0:Zmj0020:Zmj2P0ZKgX00<000000?ooo`3oool0>P3oool00300oooo0P0000000`2Y_NP000000:Vm
j01?0:Vmj0<0ZKgW1`2Y_>L30:Rhi0D0Z;KS102X/n450:JYf@D0YjWH1@2Z]=l50:bbg@80[JoJ0`2W
g_X50;7;kPD0Q^Kf1@2bdo460:CSo0D0^<?S1P2ia><20;Nff0<0^/7O1@2g]]P60;Jhf`80[k[Q0`2c
^]l50:fli0D0ZkgW0P0000030:Zmj2T0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo00@0ZKgX
0000000000000000DP2Y_NP60:Vmi`@0ZKcW1P2X^>@40:Rfh`D0YJWJ1@2VZMT20:NYf0<0Z;?P1@2Z
]=l40:bbg@H0Ymkj1`1ofod308KVmPL0N=?n102Tho`509OSo@D0^LCS1P2j`Ml20;Nff0<0^kcK1@2f
^=/60;>jg`80[KcT0`2__><01`2[_NL00000000000000000ZkgW0:Zmi`0000000`2Z_NLX0:Vmj003
0000003oool0oooo03T0oooo000[0?ooo`800000E`2Y_NP50:Vmi`D0Z;[V1@2X^>@40:B[g0D0YJWJ
102VZMT60:Rch0@0Z[CO1`2Eio/608W=oPD0Z;gX1@1fZ?8509>dkPD0KKOl102Ghod20;W4h`<0X=kl
1@2j`Ml60;^lf`80][SK0`2j^]X50;>jg`<0[kcS0`0000050:bmiP030000002Z_NL0Z[gW0080Z[gW
:02Y_NP00`000000oooo0?ooo`0h0?ooo`00:@3oool2000005X0ZKgX1@2Y^nL50:RjiPD0YJkN102T
Zm`50:FYfP@0Y[3O1P2X/n020:Zdg`@0Q^Oc1@2D_oD308W=oP<0ZKgX1@2X_NP50:Vmj0D0TkC^1@2M
^N`306BYm`H0X=kl0P2j`Ml30;7Bl@D0^kcK1P2j^]X20;>jg`80]k_M0`000000102__><0/KgS0;6m
h`2a_N<50:bmiP030000002Z_NL0Z[gW0080Z[gW:02Y_NP00`000000oooo0?ooo`0g0?ooo`007@3o
ool01@3ookl0M00000000000B9`0gooo00L0oooo0P00001H0:Vmj0<0ZKcW1@2Y^nL20:RjiP<0Y[;Q
102U[]h50:B[g0D0Y:cM102V/=l50:Rch080Q^Oc1@2O^^`509Bom@H0ZKgX0P2X_NP80:Vmj080TkC^
0`2Y_NP509fik0@0I:Wg102Pg_`60;7Bl@80^kcK0`2kaN850;ZjfP80]k_M0P0000020;Nkg@D0/KgS
1@2/_NH00`2Z_NL000000:Zmi`020:ZmibP0ZKgX00<000000?ooo`3oool0=`3oool001`0oooo00H0
oooO09a80018W=l0oooo0=nLB000M;l70?ooo`030000003oool0000005D0ZKgX1P2Y_>L40:Vki`D0
Y[;Q1@2U[]h20:B[g0<0XZSK1@2T[=d40:J`g`80R>Sd1@2Y_^P509njk1X0ZKgX0P2M^N`30:Vmj0@0
TkC^101U/o/50;7Bl@H0^lGR0P2j^]X0102m_]/000000000000000020;Nkg@<0^[kL102a_N<60:fm
iP040:Zmi`000000Z[gW0:ZmibT0ZKgX00<000000?ooo`3oool0=P3oool001`0oooo00L0oono07@0
M02oool0oooo0?oOW01807@0_ooo00D0oooo0P0000020?ooo`030000002Y_NP0ZKgX05<0ZKgX1@2Y
_>L50:Nfi0D0Y[;Q102U[]h50::Xf`D0Y:cM102Hj?/30;?9j`D0ZKkX902Y_NP409>dkP@0IK?k1@1g
dOl50;_5hP<000000`2m_]/50;Zng080/KgS0`2c_^850:fmiP030:Zmi`000000Z[gW0080Z[gW:@2Y
_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
1@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX05<0ZKgX1@2X^^H50:Nfi0@0Y[;Q
1@2PYm/50::Xf`80Y:cM102TgO/60;?9j`80ZKkX:`2Y_NP507JVl0@0Mm7o00D0^lGR000000000000
00000;3<kP040;fnf`80_L;N102j_]`60;>nhP80[KgV0`2]_^H00`2Z_NL000000:Zmi`020:ZmibP0
ZKgX00<000000?ooo`3oool0=@3oool001`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo
00D0oooo00<000000?ooo`3oool00`3ooomD0:Vmj080ZKcW1@2X^^H40:Nfi0D0X:SL1@2PYm/40::X
f`@0Y=gk0`2jfo050;?9jbh0ZKgX1@2X_NP0101HUo0000000000000000050;3<kP80_KkK102m`]h2
0;Zng080_<3M1@2c_^860:fniP030:Zmi`000000Z[gW0080Z[gW:02Y_NP00`000000oooo0?ooo`0d
0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<0
00000:Vmj02Y_NP0CP2Y_NP50:Vli`D0Z;[V102R[Ml50:2Xg0@0X:OK1P2Vb?460;[Kl3<0ZKgX0P2X
_NP3000000<0F9O`1@2`c>h60;g2gPD0_<3M0P2c_^830;G0hPD0[KkV0P2Z_NL010000000Z[gW0:Zm
i`2Z_NLX0:Vmj0030000003oool0oooo03<0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`050?ooo`030000003oool0oooo00D0oooo00<000000:Vmj02Y_NP0B@2Y_NP50:Vmi`D0
ZKcW1@2T/n<40::]g`@0X:SL1@2R]NH30:K8l@<0^>cf0`2jfo0d0:Vmj0<0000000@0Z;gX0:Vmj02Y
_NP0ZKgX0`1^X_0509O8n0<0_L;N0`2ka>440;c0g@H0]L3R1@2^_nH00`2Z_NL000000:Zmi`020:Zm
ibP0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l6
0?ooo`030000003oool0oooo00L0ooooB`2Y_NP50:Vmi`D0Y[SU1@2T/n<40::]g`@0WZ[O1@2R]NH6
0;S/mS<0ZKgX0`0000080:Vmj0@0KZ;`102Gb?P50;_4h@80_<3M0`2n`]d30;G0hP<0]/;S1@2^_nH0
0`2Z_NP000000:Zmj0020:Zmj2P0ZKgX00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@0
0000000004RL0=ooo`060?ooo`030000003oool0oooo00P0ooooB`2Y_NP20:Vmi`<0Z;_W1@2V^>D4
0:Bch`D0W:KM102NZ]l30::eiP@0Yo7e=02Y_NP2000000/0ZKgX1@2:/>l407BgnP@0^lCQ1P2n`]d6
0;K2h`80[[oV0`2^_nL00`2Z_NP000000:Zmj0020:Zmj2L0ZKgX00<000000?ooo`3oool0<P3oool0
02L0oooo00<000000?ooo`3oool02P3ooom:0:Vmj0H0Z;_W102V^>D509fYg`D0W:KM102NZ]l20:Oa
m@D0ZkoX802Y_NP30:Vcg`d0ZKgX0`00000>0:Vmj0@0R[3_101d]oX20;_4h@<0]l?S102n`]d20;o5
gPD0]/;S1P2^_nL00`000000Z[gX0:Znj0020:Znj2L0ZKgX00<000000?ooo`3oool0<@3oool002L0
oooo00<000000?ooo`3oool02`3ooom60:Vmj0D0ZKcW102X^nL50:6`h`D0WJWO102LY]d50:_@m080
c^SY1@2[_nPM0:Vmj0H0ZK?O2@2Y_NP300000180ZKgX102N^N/305bRm@H0]l?S0P2n`]d40;o5gP80
]/;S0`2f`n@50:joi`030:Znj0000000Z[kX00<0Z[kX9`2Y_NP00`000000oooo0?ooo`0`0?ooo`00
9`3oool00`000000oooo0?ooo`0<0?ooodH0ZKgX1@2Y_>L40:FgiPD0XK3S102MZMl50:2ciP<0Zm3d
103>j>T20:^oj1/0ZKgX1@2TVLX50:Vcg`D0YZCC00@0ZKgX00000000000000005P2Y_NP409jij`<0
G:;e1@2g`n<60;o5gPH0]/?T1@2]_nL00`2Z_^P000000:Znj0020:Znj2L0ZKgX00<000000?ooo`3o
ool0<03oool002L0oooo0P00000>0?ooodH0ZKgX1@2W^nL40:FgiP@0XK3S1@2IYml50:2ciPH0c^SY
6P2Y_NP40::A``D0Y9W:0P2Y/ml30:NB`080YZCC0`0000050:Vbga@0ZKgX0P2N^N/30:Rmj0<0EYC^
1@2d`N@30;o5gP<0`<OO0`2f`n@30;K4i@D0[KoW00<0Z[gX0000002Z_NP00P2Z_NPW0:Vmj0030000
003oool0oooo02l0oooo000W0?ooo`030000003oool0oooo00h0oooo@`2Y_NP30:Vlj0D0Yk_W102U
]nH409VXh0D0VJOO0P2P/nH40;_Wm1`0ZKgX1P2RTL<50:BIbP@0Yi;00`0000020:JTd`80]J731@2Y
/]lC0:Vmj0H0Z;gX0`1FU>h50;C1i0H0`<OO1P2fa>D50:foi`040000002Z_NP0Z[gX0:Zmj2P0ZKgX
00<000000?ooo`3oool0;P3oool002L0oooo00<000000?ooo`3oool03`3ooom00:Vmj0H0ZKcX102W
^nL509j_i0@0VJSP102IYml50;_Wm080_]C[6@2Y_NP90::A``<0Y9W:0P2gW[l300000080Yi;00P2V
Y=<40;FQ``80ZK;O0`2]XldC0:Vmj0D0Z;gX101FU>h20;C1i0<0]<7S0`30aml30<39h@D0]/CU1P2]
_nL010000000Z[gX0:Zmj02Z_NPW0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`8000004@3o
ool00`000000ZKgX0:Vmj00n0:Vmj0@0ZKcX1@2S]^H509j_i0@0VJSP1P2V_NT50;kDja@0ZKgX1@2T
VLX80::A``80Y9W:0`0000050:NB`0H0]J731P2]XldC0:Vmj0D0Z;gX0`1PTNT60;C1h`H0`<WQ1@2d
a>H50:foi`030:Zmj0000000Z[gX0080Z[gX9`2Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool2
000001<0oooo00<000000:Vmj02Y_NP0?P2Y_NP40:Nki`D0XkKV102N[n@509RYhP@0Y[gY0P3;k>`5
0;kDj`l0ZKgX1@2Y/ml40:BIbPL0XY730`0000040;NN_`<0Yi;00P32Zl<40;FQ``80cKC21@2]XldD
0:Vmj0D0Z;gX0`1PTNT30;C1h`<0]l;R1030bN420;o:h`D0]<CV1@2/_nP0102Z_NP000000:Zmj02Z
_NPX0:Vmj0030000003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo
0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?oo
o`030000003oool0oooo01<0oooo00<000000:Vmj02Y_NP0>@2Y_NP50:Vlj0@0Yk_W102S]^H509JX
hPD0V:WR0P2V_NT40<_/k1@0ZKgX102Y/ml50:BIbP@0XY730P0000020:jLa@D0]ijo0P2WT/030<:[
``<0]J730`3=]<840:fSc@80b;W<502Y_NP40:Rmj0@0H97Y1P2g`^820<39h@@0_l[S0P2da>H30;;4
i`@0[;oX00<0Z[gX0000002Z_NP00P2Z_NPW0:Vmj0030000003oool0oooo00X0oooo00D0gia80000
00000000001809cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00<0
omnL04P0001d_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000
oooo0?ooo`0D0?ooo`030000002Y_NP0ZKgX03T0ZKgX1@2Y_>P40:Nki`@0W;3U1@2FZ>8409RYhP@0
bnc/0`2ebnXD0:Vmj0@0ZK?O102TVLX0102RTL<000000000000000050:jLa@@0]ijo1P32Zl<00`2e
XL<0cKC20<fd`P030<fd`P80[J?=1038^L`C0:Vmj0D0W[W[101bUND50;O2hPH0_l[S1@2ba>L50:^n
j0030:Zmj0000000Z[gX0080Z[gX9`2Y_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0gooo
0?ooo`3ooml0W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
103oool00`3ogi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?oooc`0ZKgX
102Y_>P50:>gi`@0W;3U102FZ>860:c0j0H0]L_Z4`2Y_NP40:Vcg`80Y9W:0`0000040:>Fb0@0[Yc5
0`2gW[l20;V/c@D0`Z_31P3=]<850<Ric080e/O<4`2Y_NP509jij`@0LYGU0P2g`^830;_6hP<0_l[S
0`2mbnD20;;4i`<0[l;X1@2[_^P00`2Y_NP000000:Vmj00Y0:Vmj0030000003oool0oooo00`0oooo
00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0
oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo01L0
oooo>P2Y_NP50:Nkj0D0XkOW0`2L/>D509NYh`@0[<3X0P3Ahn@30;G;jQ80ZKgX102LWmH208Eoa@<0
00000`2FSLP40:>Fb0D0[Yc500@0]ijo0;V/c@2i[<d0^Jc=1032Zl<20<:fcP@0cKC20P3?_/X30<Ri
c0@0e/O<4`2Y_NP409jij`@0LYGU1P2ka^850;g;i@H0[l;X0P2[_^P30:Znj0030000002Y_NP0ZKgX
02P0ZKgX00<000000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@0
04RL0=ooo`3oool0oono07@0B02Lgol01P3oool02`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0
oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0603ooolk0:Vmj0@0Yk_X1@2L/^L309BY
i0D0UjWS0P2/`>P40=7Si1D0ZKgX0P2LWmH300000080QGo5102FSLP50:>Fb0@0[Yc51@2i[<d20<:[
``<0`[K>0`3=]<840<nnbP030<Ric03Fal`0e/O<00<0e/O<00<0g=OB0:Vmj02Y_NP04@2Y_NP408Z`
k`@0R9oS0`2ka^830;o;h`<0_L_U0P2ib^L50:o2j0H0Z[kX00<000000:Vmj02Y_NP0:02Y_NP00`00
0000oooo0?ooo`060?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0L0?ooo`00203oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool01@3ookl0M01809cOo`3ookl0M00000<0
000000<0M;oo0?ooo`3oool0103oool2000001/0oooo>`2Y_NP40:Bij0D0W;;W0`2DZN@409NYh`D0
dN?T0`2ne>/B0:Vmj0<0000000<0W9oF08Eoa@25OlD00P25OlD509J=b0@0XiK80P2^W<D30;2[d`@0
^Jc=1P32]/h00`3=]<80ckk:0<nnbP030<nnbPD0e/O<0`3Lem8C0:Vmj0@0R[3_1028Wn<60;o;h`D0
^L[W1@2]`NP50:Znj0030:Vmj0000000ZKgX02T0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0
M000000000020000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`09
0?ooo`030000003oool0oooo01/0oooo>02Y_NP30:Rlj0@0Y;WX102L/^L409BYi0H0Z[_V1P2ne>/>
0:Vmj0<000000P2Y_NP309bOeP@0QGo5102FSLP40:>Fb0H0/:_C0P2i[<d20;Rgf0D0`[K>1@3?_/X2
0=77d@<0e/O<103Lem8D0:Vmj0<0Kj7_1@2M[^<30;o;h`<0`LoU0P2ib^L30;G8j0D0[L7X1@2Z_^P0
0`2Y_NP000000:Vmj00X0:Vmj0030000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool0
00P0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0
B01809cOo`3oool0_g@007Boo`T0oooo00<000000?ooo`3oool0703ooole0:Vmj0H0Z;cX102T^NP4
09>/i`@0TjSU0`2Z^nH40<_Dh@l0ZKgX0`0000050:Vmj0<0W9oF1025OlD409J=b0D0YjOF1@2`Zm<5
0;Rgf0<0`[K>0P31_]L30<nnbP@0dLOA00<0e/O<0=cGdP3Lem800P3Lem820=W^hA@0ZKgX0`1_XNl5
09f^h`D0`LoU1P2eb>P20:g1j0<0[;oX1@2Z_^P00`000000ZKgX0:Vmj00X0:Vmj0030000003oool0
oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0oono07@00000000004RL0=ooo`05
0?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P00000000000000000001d0;ooo`D0
oooo00<000000?ooo`3oool07@3ooole0:Vmj0D0Z;cX1@2N]NP409>/i`@0TjSU1@3;e>420<oVj0`0
ZKgX0P0000050:Vmj0@0PJ;X0P1cO/l408Eoa@D0W:3G1@2WYmH20;2[d`<0[kGM1@2h]mP00`32]/h0
`KkG0<6ne`020<6ne`030<nnbP3Aam40dLOA00<0dLOA103Lem840=W^hA<0ZKgX101_XNl209f^h`<0
[kgT0`31cnD20;o@i`D0]LSX1P2/_nP20:Znj0<0Z[gX00<000000:Vmj02Y_NP09`2Y_NP00`000000
oooo0?ooo`050?ooo`060=nLB000000000000000000007@0_ooo703oool002D0oooo0P00000O0?oo
ocD0ZKgX1@2U^nP509jej0<0TjcW1@2Q/nD30<_Dh@@0cnKX202Y_NP3000000P0ZKgX0`21X^P307=n
c`@0SI?D1@2LX=L40:NWePH0[kGM102h]mP50<6ne`D0dLOA0`3EdMH40=W^h@<0]/g[3P2Y_NP50:Rm
j0<0MHOH1P2__N@50;o@i`D0/<CY1@2/_nP50:Zmj0030:Vmj0000000ZKgX02P0ZKgX00<000000?oo
o`3oool09P3oool002D0oooo00<000000?ooo`3oool07`3ooola0:Vmj0D0Z;gX102U^nP409jej0@0
SjWW1@2Q/nD60<oVj0D0ZKgX0`00000;0:Vmj0@0PJ;X0`1cO/l408fCe0@0W:3G1@2X/n050:neg@D0
][gO0`31_]L20<74g@<0dLOA0`3EdMH30=gQf0H0]/g[3P2Y_NP40:Rmj0@0MHOH0`2__N@30;c<iP80
_m3W0`2jc^T50;34j@D0ZkkX102Z_NP00`2Y_NP000000:Vmj00Y0:Vmj0030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo0200oooo<@2Y_NP50:Rmj0@0X[WY102F/NT408nYi`<0XK?U
102k`n440:^oj0040:Vmj00000000000000000/0ZKgX102K^>d304e`e0@0Lgk?0`2=Tm@50:6^h@D0
Z;?P0P2_]Md30:jkh`D0][gO1@31a=d40=GAeP<0gN7H0P3Um]<50;K=j`l0ZKgX102X_NP407F7f0D0
_<cV1P2jc^T50:g1j0@0ZkkX1P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02D0
oooo000T0?ooo`8000008`3ooola0:Vmj080Z;gX0`2W_>P40::ij@@0U[7Y102?ZNL50;_3h@80dLkF
00@0ZkoX00000000000000003`2Y_NP309^hk@@0CG3D0`1lT]h409BUh@D0XJkQ102X/n060:jkh`80
][gO0`2e`N@30<74g@80`/cR0P3EdMH30=gQf0@0iOKC502Y_NP3086JhPD0UjKP0P2lc>H30<3Cj@<0
^/kY0`2db>X40:g1j0D0Z[gX1P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo02@0
oooo000T0?ooo`030000003oool0oooo02<0oooo<02Y_NP60:Nlj0<0X[WY102F/NT509>/i`<0^l?Q
00@0dLkF00000000000000004`2Y_NP309^hk@<0CG3D101lT]h409BUh@@0XJkQ1@2Y^ND50:jkh`H0
]L7T00<0`LCM0<;<hP32c>800P32c>830=gQf0<0iOKC0`3:in/C0:Vmj0@0PI[R102GY^060<3Cj@H0
]<SZ102[_nP50:Zmj0H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0S0?ooo`00
903oool00`000000oooo0?ooo`0T0?oooc00ZKgX1@2W_>P409bfjP@0SjgZ1@2C[>L300000080dLkF
0P3>dmdC0:Vmj080CiC`101=L=@407bBgP<0U:GQ1@2S]nH50:Vii@D0[[oW1@2e`N@40<;<hP<0b=WV
0P3Um]<60<[Wja<0ZKgX1021V^8209NVh080/L?W0`30dnT30;cBj`<0]<SZ0`2_`nT40:^oj0X0ZKgX
00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool2000002H0oooo<02Y
_NP50:Fkj@@0W;KZ102?[NX01@2S]NH00000000000000000XkGV00<0dLkF103>dmdC0:Vmj080CiC`
0`1=PN<407bBgP@0VK3X1@2S]nH20:Vii@<0ZKkX1@2^_nL50;K7i`80`/cR0`38fNH20=3`j0<0_og9
5`2Y_NP4086JhPD0/L?W1P2ld^/50:o3j@80ZkoX0`2Z_^P:0:Vmj0030000002Y_NP0ZKgX02L0ZKgX
00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?ooob`0ZKgX1@2X_NP40:Fkj@@0W;KZ0P2;
Zn/2000000D0XkGV1P3>dmdD0:Vmj00301efh`1?U?00CH7S0080CH7S1022XnP409V`j0@0XkOV1P2Y
_^P20:joi`<0[/CZ1@2fanL30<SIiP80d?3X0P2ooLT30;K=ja<0ZKgX102FZnD408JCf080/L?W0`2m
dn/30;cBj`<0]/c[102_`nT60:Znj0X0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia8
0080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?ooob/0ZKgX1@2X_NP40:>j
jP80U[?/0`00000308^[j`80XkGV0`2e_^430<kCg@<0`m7U502Y_NP00`0MM^<0CH7S04f1h`0204f1
h`@0PZ?X0`2I/>P50:BljPD0ZKkX1P2^a>X60;SAk080d?3X00<0_og90;K=j`2fcN/0102fcN/C0:Vm
j0@0UZ_U0`26TmP60;gCj`H0]/c[102/`>P50:Znj0/0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`00
0000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd
0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool[0:Vmj0D0Z;cX
0P2S^^X3000000<0U[?/0`2;Zn/60;Fnh@H0`m7U502Y_NP0100MM^<0@Hg]046=k@11SNd408:Sj0@0
VkW]1@2T_>X50:W2k0<0[/CZ0`2_c>l30;SAk0<0_NGc00<0ZOWO0<_ji`3;n^L01@2fcN/C0:Vmj0@0
UZ_U102Y^nL30;gCj`<0_MK/0`2fc>/30:o5jP@0[<3X3`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj080
00008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Bo
o`3oool01@3oool2000002`0oooo:`2Y_NP30:Rlj0<000000P2S^^X5092ak@@0S:g/0`2e_^430<?3
fPD0]<WY502Y_NP0100MM^<0@Hg]046=k@11SNd408>_l@@0VkW]1@2T`Nh50:W2k0H0[lc_102miO<0
0`2YnMl0bo[W0<_ji`020<_jia<0ZKgX1@2NZ=d408>=e0@0ZK_W1P2me^`50:o5jPD0Z[kX3`2Y_NP0
0`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01l0oooo000<0?ooo`070?oOW018B9`0gooo
0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0;03o
oolZ0:Vmj0<000000P2X_>P509nij`@0T;7]102<[N`50<?3fP80blCD102dbNTC0:Vmj0807GKS0`0H
RNP408>_l@D0VL3c102T`Nh50:S:l@<0[lc_102_g_P20:Wig`80bo[W5`2Y_NP409jXg@@0PhgD0P2Y
^nL40;_Dk@D0]/k/0P2_aNX30:c0j@D0Z[kX3`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003o
ool0oooo01l0oooo000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oO
W01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02d0oooo9P2Y_NP30000
00030:Vmj02W_>T0YkcY00<0YkcY1@2O^N/3092ak@D0TK7/0`33`mX40<_4e0@0ZkgW4`2Y_NP204nD
l0<068WX101j^OX509W0l`@0X<[f1@2Xb_440:oNn080TNoY702Y_NP409jXg@<0PhgD102ke>d30;_G
kP@0]/k/1P2/`>T20:Znj0<0Z[gX3P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo
01h0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d0000
00000080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooob80ZKgX0`000006
0:Vmj0@0YkcY1@2L^>`308^`k`D0TK7/00<0`l?J0<_4e03;a=@00P3;a=@20<k4d0@0ZkgW4`2Y_NP5
09^hk@@0N[Wj1@2>b_`40:3:mPH0Xm_k0P2AknTN0:Vmj0@0WZSM1@2W_>P60;_GkP@0[lGZ1@2/`>T6
0:Zmj0h0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0M0?ooo`00303oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q809cOo`090?ooo`800000<@3o
oolN0:Vmj0<000002P2Y_NP40:Jlj@D0W;S/0`2;/>l4096ak0@0blCD103>a=020:^mi`80Z[GQ4`2Y
_NP509^hk@03001Te01D^_/0E;[k0080E;[k102>b_`508oJo`80K]kS0P12`[LH0:Vmj0D0ZKcW102H
VM<408ZCeP80YkcX0`2if>l30;_GkP<0]<g]102_aNX50:Znj0D0Z[gX3`2Y_NP00`000000ZKgX0:Vm
j00V0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo
1@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0340oooo6`2Y_NP2000000h0ZKgX
102V_>T509Zhk@<0Qk3`102G]N`20<_4e0D0c/C@1@2Z]N4H0:Vmj0@0Nj_b0P2K^>`405g<m`80;[Nn
00<0@<;N0:Vmj02Y_NP06`2Y_NP40:Vli`D0V9WC0`2:TmH60;WHk`D0]<g]1@2[`>T50:Znj1@0ZKgX
00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M0000000
0000B9`0gooo00D0oooo00H0gia800000000000000000000M02oool50?ooo`030000003oool0oooo
0380oooo5`2Y_NP300000140ZKgX102U_>T509Zhk@<0Qk3`102G]N`50<k4d080c/?@102Z]N4M0:Vm
j0D0VkS/8@2Y_NP40:Vli`@0V9WC1@2/a^d60;SGk`@0[/CZ1@2[`>TH0:Vmj0030000002Y_NP0ZKgX
02L0ZKgX00<000000?ooo`3oool06`3oool00280oooo0P00000d0?oooa<0ZKgX0`00000E0:Vmj0@0
YKcY102J^>d408Jal@@0VkW]0`3>a=040<k3d0D0/K;J@@2Y_NP40:Vli`D0V:KO0P2/a^d30;SKlP<0
^=O_0`2abn`40:k4jPD0Z[kX602Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01/0
oooo000R0?ooo`030000003oool0oooo03@0oooo3`2Y_NP3000001T0ZKgX102U_>X409VhkP@0Q[7a
102K^Nd50<k3d080blCC1@2a/]Xl0:Vmj0D0YIg>102:R/h409RVg`H0^=_b1@2abn`50:^oj0D0Z[kX
602Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01X0oooo000R0?ooo`030000003o
ool0oooo03D0oooo00<000000:Vmj02Y_NP0202Y_NP3000001X0ZKgX0`2X_NP40:FljP@0VKS^1026
/O4409^kk`<0c/?@103;a=<20;6bfP<0^kCC>02Y_NP40:RXeP@0YIg>1@2:R/h209RVg`80/MGb0`2h
fo830;CBk`<0/L_/0P2/`^T50:^oj1d0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?oo
o`0<0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3o
ool00`000000oooo0?ooo`0g0?ooo`H0ZKgX0`00000K0:Vmj0H0Z;gX102U_>X409RhkP@0QK;b102K
^nl60<_4d`H0^kCC102Y_>L_0:Vmj0D0ZKCP0`2XZ=H50:FMcP@0RX[>1@2aeO860;CBk`D0[<;Y0P2[
_nP30:Znj1`0ZKgX00<000000:Vmj02Y_NP09P2Y_NP2000000`0oooo00X0omnL04P0M02oool0oooo
0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00240oooo0P00000j0?ooo`80ZKgX0`00000P0:Vm
j0@0Z;gX1@2U_>X409RhkP@0QK;b102F^o430<_4d`<0a<GK102k]=<20<Fjd0@0ZKcW:P2Y_NP50:Vl
i`D0ZKCP0`2XZ=H40:FMcPH0Yl?^1@2efO850:k6j`@0[<;Y1P2Z_^PL0:Vmj0030000002Y_NP0ZKgX
02H0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02oool0oooo
0?oOW01807@0_ooo00<0oooo000Q0?ooo`030000003oool0oooo03P0oooo0`00000T0:Vmj0@0Z;gX
1@2U_>X409ZikP@0QK?c102F^o460<C5f`80^kCC1035^]040:NRd2H0ZKgX2@2Y_>L40:Vdh0<0Z:SF
1@2M[N<30:O3kP<0/mce0P2efO830;3<kP@0[/K[2P2Z_^PM0:Vmj0030000002Y_NP0ZKgX02D0ZKgX
00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0oooo0P0000030?ooobD0ZKgX102X_NP5
0:FljP@0V[W^1025/o<408fjm@D0a<GK1@35^]020<g3d0@0Yj;@1@2X[M/N0:Vmj0<0ZKCP202Y_>L5
09ZFcP<0VIkG1@2M[N<50;?Lm@H0/<c^102[`>T50:Znj240ZKgX00<000000:Vmj02Y_NP09P2Y_NP0
0`000000oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0
B02Lgol00`3oool00240oooo0P00000d0?ooo`<000001P3ooolY0:Vmj0D0YKcZ1@2L^^d308Rel`@0
SK[e0P34aM/30;K7i`<0aK[@0`3=`m030:NRd080`KK?1@2X[M/40:Vch1L0ZKgX1P2Y]>020:Vli`80
Y9O8102NU<T409ZFcP@0VIkG1P2^f_H50;7Al@D0[<;Z102[`>TV0:Vmj0030000002Y_NP0ZKgX02H0
ZKgX00<000000?ooo`3oool0203oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo0300oooo0`0000090?ooobX0ZKgX1@2V
_>T509bjk@<0R;Gc0`2=^_D60;K7i`H0cL?@00<0Yj;@0<6fc`31]/l00P31]/l20:R]f`<0/jS=102Y
/n050:R]f`@0ZKgX1@2Y_>L50:Vmj0@0Z:SF1@2Y]>040:BGb0@0WYC9102JU/h209VNe`@0ZM?f1@2`
e_@20;7Al@<0[LC[102/`^X50:Znj2H0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?oo
o`060?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`030?ooo`00103oool03@3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono
07@0B02Lgol0103oool01@3OW4P000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;@3o
ool3000000h0oooo:P2Y_NP40:Jlj@D0Wk_/0`2=]o<508Fim`@0XLKc1@3=`m050<6fc`H0/jS=0P2Y
/n020:fQc0D0Z:gK102VX=050:Vli`D0YYg=102XZ=H50:^NbP@0Y9O8102NU<T309ZFcP@0ZM?f0`2^
fOH40;3Fm0H0[LC[2@2Z_^PV0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3o
ool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo00030?oo
o`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?ooo`070?noM000
B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00000B0?ooobX0
ZKgX102W_NT509nkk0<0SKOc1@22^?L40:76l`80cL?@0`2lb^D30<6fc`80alKI1@2cZ<d50:fQc080
Z:gK0`2bY/`40:JPd0D0YIW8102VWLd20:RXeP<0/JS?102[W/X40:BGb0@0WYC91@2WcO@60:kImPD0
[LO]1@2Z_nT40:Znj2X0ZKgX00<000000:Vmj02Y_NP08@2Y_NP3000000030?ooo`000000oooo00P0
oooo00<0omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00@0oooo00030?ooo`07
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030;md0018W=l0oooo00L0oooo00<0_g@0
07Boo`3oool0103oool2000002T0oooo0`00000F0?ooobX0ZKgX102W_NT50:>lj`@0U;Wa1022^?L3
0:76l`H0_<[U00@0`KK?0<O6f@37a]T0alKI102cZ<d20<S2e@@0[J7<1@2bY/`30:JPd080`;G?102U
VLP40:JMc@D0/JS?1@2[W/X30:BGb0H0YlWb1@2Zf_P50:g:k`80[LO]0`2[`>T50:ZojBh0ZKgX00<0
00000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?ooo`3oool05@3oool000<0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03Oool01`3oool00`2oM000M;oo
0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?ooobX0ZKgX102X_NP50:>lj`@0Vk_^
1028^OH308_0n@D0_<[U1@37a]T20;>Xc@@0b<;E0P2]XL`20<C3f@D0/ZK<00@0YZ3@0<2ec`30]Ll0
`;G?1@2UVLP20:JMc@80][OI1@2aZ<l40:^NbPD0Z<[a1@2Vf_X50:c<l@@0[L[_1P2[`>T20:ZojC40
ZKgX00<000000:Vmj02Y_NP0602Y_NP3000000P0oooo00<000000?ooo`3oool05@3oool000<0oooo
00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02Lgol00P3oool01`3o
gi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R0?ooo`<000007P3o
oolZ0:Vmj0@0Z;gX1@2U_>X409^kkP@0R;Wf0`2;`?T509g9m`@0alKI1P38`]D40<C3f@D0/ZK<1@30
]Ll40:FIb0D0][OI102aZ<l50:W>l`80Z<[a0`2SfO/30:KJnP80Z/cb1@2/c?440:_1jPD0Zl3Y=02Y
_NP00`000000ZKgX0:Vmj00C0:Vmj0@00000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@0
00<0000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000008P3ooolZ0:Vm
j0@0Z;gX1@2U_>X40:6lk0D0Tk_b0`24_?T409g9m`@0ZLkc0`38`]D30:[@m0@0a<?I0P2bY/`30;_9
i@@0`;G?1@2fanL40;Jgf@D0Y]?g102Yc_<60:?In`D0Z/cb1@2Z`^/40:_1jPD0Z[kX<`2Y_NP00`00
0000ZKgX0:Vmj00?0:Vmj0040?ooo`000000000000000100oooo00<000000?ooo`3oool0503oool0
00<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00H0oooo00L0oono07@0B02Lgol0oooo
0?oog`2LB4P0W=oo00T0oooo0P00000N0?ooo`8000009P3oool00`000000ZKgX0:Vmj00W0:Vmj0@0
Z;gX1@2W_NT40:6lk0D0WKc^0`2=_?H508O2n`<0ZLkc1P2Zd?@30<C3f@H0^lWU0P30]Ll20:WBm@D0
]/OW102Pe_/50:KCm`D0X=Sk1P2Xc?<90:[2j`T0Z[kX<`2Y_NP00`000000ZKgX0:Vmj00:0:Vmj080
oooo0`00000C0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3O
W4P007Bo203oool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3o
ool]0:Vmj0D0YkgY102U_NX509flkP<0SKcf1@2<_oP408[6o0@0Z]3d1@2RdOP40;_9i@D0ZM;e1@2H
eOd40:3Fn`H0WMGk1@2Vb_850:W2j`@0Z/;[2@2Z_^Ph0:Vmj0030000002Y_NP0ZKgX00L0ZKgX1000
000F0?ooo`030000003oool0oooo01@0oooo00040?ooo`050?oo_`1d000000000018W03Oool0103o
ool00`3OW4P00000000000030000000307Boo`3oool0gia800<0000000<0001d0;ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`<00000;P3oool]0:Vmj0D0Z;gX102U_NX50:Bmj`@0V[g`102<
_oP408k1n0D0S<Wl102=bO`509KAo0D0Tlom102HeOd509_@nPD0YLSb1@2Y`N/40:W2j`D0ZKkX102Z
_^Pl0:Vmj0030000002Y_NP0ZKgX00D0ZKgX0P00000J0?ooo`030000003oool0oooo01@0oooo000O
0?ooo`030000003oool0oooo01D0oooo0`00000b0?ooobd0ZKgX1@2X_NP40:Rmj@D0Y;g[102S_N`5
09Znl@<0S/7h1P2B`oL308g9o0H0U<Wj102Na_@509c;n0D0YLG`102X`>/50:W1j`T0ZKkX@02Y_NP0
10000000ZKgX0:Vmj02Y_NP2000001d0oooo00<000000?ooo`3oool0503oool001l0oooo0P00000C
0?ooo`<00000=P3ooolb0:Vmj0@0Z;gY1@2W_NT90:>mk0@0W;oa1@2P_nl409[3m0D0XL;`102Na_@5
0:G2kP80YLG`0`2X_nX40:S0j`T0ZKkXA02Y_NP300000200oooo00<000000?ooo`3oool0503oool0
01l0oooo00<000000?ooo`3oool03`3oool3000003X0oooo=P2Y_NP90:Nmj@D0Xkg/102T_^/50:2o
k`@0Y;o]102Q`_050:K0k0@0YL;^1P2X_nX90:Vnj4<0ZKgX0`0000030?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3000003h0
oooo>`2Y_NP90:Nmj@@0Y;k[1@2V_^X40:Bok@@0YkkZ1@2V`>`40:Rnj@<0Z;oZ0`2Y_NP40:Vnj4@0
ZKgX0`0000060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo
00<000000?ooo`3oool02@3oool300000480oooo?`2Y_NP50:Nmj@@0Z;gY102V_^X50:Rnj@@0YkkZ
1@2Y_^T40:RnjDT0ZKgX1000000:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4`3oool001h0oooo0P0000090?ooo`800000AP3ooom40:Vmj0@0Z;gY102Y_NP50:Rnj@@0ZKgX1@2Y
_^U80:Vmj0040?ooo`0000000000000000l0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`<00000B@3ooonN0:Vmj0040?ooo`00
00000000000001<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3o
ool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000ZKgX0:Vmj02F0:Vmj0030?ooo`00
00000000008000005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000N
0?ooo`030000003oool0000000800000D@3oool00`000000ZKgX0:Vmj02C0:Vmj0<000006`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo000N0?ooo`800000E@3oool00`00
0000ZKgX0:Vmj02@0:Vmj08000007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01<0oooo000C0?ooo`030?oOW01807@0_ooo00T0oooo00<000000?ooo`3oool0E03oool00`000000
ZKgX0:Vmj02<0:Vmj0030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000EP3ooon90:Vmj0800000
9`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW018
07@0_ooo00`0oooo00<000000?ooo`3oool0E03ooon50:Vmj0800000:`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00d0oooo00<00000
0?ooo`3oool0E03ooon00:Vmj0800000<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0oooo00<000000?ooo`3oool0E03ooomk0:Vm
j0<00000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0?oOW01807@0_ooo00l0oooo00<000000?ooo`3oool0E03ooomg0:Vmj0<00000=`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo000A0?ooo`050;md000004P0W;nL04P0M02o
ool0403oool2000005D0ooooLP2Y_NP3000003`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0B0?ooo`004P3oool0103o_g@000000000M02ooolB0?ooo`030000003oool0oooo05<0
ooooKP2Y_NP300000400oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`00
4`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003oool0oooo05<0ooooJ@2Y_NP4000004<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`00:P3oool00`000000oooo0?oo
o`1C0?ooofD0ZKgX0`0000180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3o
ool002/0oooo0P00001D0?ooof00ZKgX00@0oooo0000000000000000C03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0140oooo000]0?ooo`030000003oool0oooo0580ooooG02Y_NP4
000004l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;P3oool00`00
0000oooo0?ooo`1B0?oooeP0ZKgX0`00001D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04@3oool002l0oooo00<000000?ooo`3oool0DP3ooomC0:Vmj0040?ooo`00000000000000
05P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`00<03oool00`000000
oooo0?ooo`1B0?ooodl0ZKgX1000001L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00340oooo0P00001C0?ooodX0ZKgX00@0oooo0000000000000000H03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000c0?ooo`030000003oool0oooo0540oooo
AP2Y_NP4000006@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`00=03o
ool00`000000oooo0?ooo`1A0?oood80ZKgX0`00001Y0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool003D0oooo00<000000?ooo`3oool0D@3ooolm0:Vmj0040?ooo`000000
0000000006`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=P3oool2
00000580oooo>@2Y_NP400000700oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@
0?ooo`00>03oool00`000000oooo0?ooo`1@0?ooocD0ZKgX0`00001e0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0403oool003T0oooo00<000000?ooo`3oool0D@3oool_0:Vmj004
0?ooo`0000000000000007T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?oo
o`00>P3oool00`000000oooo0?ooo`1A0?ooob/0ZKgX1000001l0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0403oool003/0oooo00<000000?ooo`3oool0D@3ooolW0:Vmj0<00000
P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo000l0?ooo`800000DP3o
oolR0:Vmj0040?ooo`0000000000000008D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0?0?ooo`00?P3oool00`000000oooo0?ooo`1@0?oooah0ZKgX100000290?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03`3oool003l0oooo00<000000?ooo`3oool0D03ooolJ
0:Vmj0<00000S@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00100?oo
o`030000003oool0oooo0500oooo5P2Y_NP300000940oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`00@@3oool200000540oooo4P2Y_NP3000009D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`1?0?ooo`d0ZKgX
0`00002I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004@0oooo00<0
00000?ooo`3oool0D03oool80:Vmj0<00000W@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00150?ooo`030000003oool0oooo0500oooo102Y_NP300000:40oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00AP3oool200000540oooo0P00002V0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004P0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool004T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3o
ool004/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03P3oool004`0oooo0P00001;0?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00CP3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0=0?ooo`00C`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D03oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`00D@3oool2000004H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo001C0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0[03oool01@000000oooo0?ooo`3oool0000000l0oooo001D0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00E@3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool0
05H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool00000
00l0oooo001G0?ooo`800000?`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0000000h0
oooo001I0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo
001J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001K
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001L0?oo
o`800000>P3oool00`000000oooo0?ooo`2]0?ooo`@00000403oool005h0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`2Y0?ooo`@00000503oool005l0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`2U0?ooo`@00000603oool00600oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`2Q0?ooo`@00000703oool00640oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`2N0?ooo`<00000803oool00680oooo0P00000d0?ooo`030000003oool0oooo
09X0oooo1000000S0?ooo`00I03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09H0
oooo1000000W0?ooo`00I@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0980oooo
1000000[0?ooo`00IP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo08h0oooo1000
000_0?ooo`00I`3oool2000002l0oooo00<000000?ooo`3oool0RP3oool4000003<0oooo001Y0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0Q`3oool3000003L0oooo001Z0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0P`3oool4000003X0oooo001[0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0O`3oool4000003h0oooo001/0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0N`3oool400000480oooo001]0?ooo`800000:@3oool0
0`000000oooo0?ooo`1g0?ooo`@00000AP3oool006l0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`1e0?ooo`<00000BP3oool00700oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`1a0?ooo`@00000C@3oool00740oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000D@3oool00780oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000
001E0?ooo`00M03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06D0oooo1000001I
0?ooo`00M@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo0`00001M0?oo
o`00MP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000001P0?ooo`00
M`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo1000001T0?ooo`00N03o
ool2000001d0oooo00<000000?ooo`3oool0EP3oool4000006P0oooo001j0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0DP3oool4000006`0oooo001k0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0CP3oool400000700oooo001l0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0B`3oool3000007@0oooo001m0?ooo`800000603oool00`000000oooo
0?ooo`170?ooo`@00000M`3oool007l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`130?ooo`@00000N`3oool00800oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o
0?ooo`@00000O`3oool00840oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?oo
o`@00000P`3oool00880oooo0P00000C0?ooo`030000003oool0oooo03P0oooo0`0000270?ooo`00
Q03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo1000002:0?ooo`00Q@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo1000002>0?ooo`00QP3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0oooo1000002B0?ooo`00Q`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo1000002F0?ooo`00R03oool2000000d0
oooo00<000000?ooo`3oool09@3oool3000009X0oooo002:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool08P3oool4000009d0oooo002;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07P3oool400000:40oooo002<0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06P3oool400000:D0oooo002=0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?oo
o`@00000Z@3oool008l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@0
0000[@3oool00900oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000
/@3oool00940oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000]03o
ool00980oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000^03oool009<0oooo0P000000
0`3oool000000?ooo`040?ooo`@00000_03oool009D0oooo0P0000000`3oool00000000000020000
0<00oooo002F0?ooo`800000a03oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool0
0?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .61641 .52744 Mtetra
.61641 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .48541 Mtetra
.75545 .48541 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .61641 .52744 .6107 .52111 Mtetra
.6107 .52111 .61641 .52744 .62773 .52402 .62206 .51766 Mtetra
.62206 .51766 .62773 .52402 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .48541 .75014 .47875 Mtetra
.75014 .47875 .75545 .48541 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51473 Mtetra
.60495 .51473 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51473 .59916 .5083 Mtetra
.59916 .5083 .60495 .51473 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47569 .72744 .46896 Mtetra
.72744 .46896 .73287 .47569 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49119 Mtetra
.62783 .49119 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49174 Mtetra
.59894 .49174 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49119 .62205 .48458 Mtetra
.62205 .48458 .62783 .49119 .63943 .48761 .63368 .48098 Mtetra
.63368 .48098 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48872 Mtetra
.58153 .48872 .58745 .49529 .59894 .49174 .59305 .48514 Mtetra
.59305 .48514 .59894 .49174 .61047 .48816 .60461 .48154 Mtetra
.664 .741 .908 r
.60461 .48154 .61047 .48816 .62205 .48458 .61622 .47793 Mtetra
.61622 .47793 .62205 .48458 .63368 .48098 .62789 .4743 Mtetra
.62789 .4743 .63368 .48098 .64536 .47736 .6396 .47066 Mtetra
.6396 .47066 .64536 .47736 .65708 .47373 .65136 .467 Mtetra
.65136 .467 .65708 .47373 .66886 .47008 .66316 .46332 Mtetra
.664 .741 .907 r
.66316 .46332 .66886 .47008 .68068 .46642 .67502 .45963 Mtetra
.67502 .45963 .68068 .46642 .69256 .46274 .68693 .45592 Mtetra
.68693 .45592 .69256 .46274 .70448 .45905 .69889 .4522 Mtetra
.69889 .4522 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.664 .741 .908 r
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48927 Mtetra
.663 .741 .908 r
.55261 .48927 .55864 .49584 .57006 .49228 .56406 .4857 Mtetra
.56406 .4857 .57006 .49228 .58153 .48872 .57556 .48212 Mtetra
.663 .742 .908 r
.57556 .48212 .58153 .48872 .59305 .48514 .58711 .47854 Mtetra
.663 .742 .909 r
.58711 .47854 .59305 .48514 .60461 .48154 .59871 .47494 Mtetra
.663 .743 .91 r
.59871 .47494 .60461 .48154 .61622 .47793 .61036 .47132 Mtetra
.663 .744 .91 r
.61036 .47132 .61622 .47793 .62789 .4743 .62205 .46767 Mtetra
.664 .744 .91 r
.62205 .46767 .62789 .4743 .6396 .47066 .63379 .464 Mtetra
.63379 .464 .6396 .47066 .65136 .467 .64559 .4603 Mtetra
.665 .744 .909 r
.64559 .4603 .65136 .467 .66316 .46332 .65743 .45658 Mtetra
.65743 .45658 .66316 .46332 .67502 .45963 .66932 .45283 Mtetra
.665 .743 .908 r
.66932 .45283 .67502 .45963 .68693 .45592 .68126 .44907 Mtetra
.664 .742 .908 r
.68126 .44907 .68693 .45592 .69889 .4522 .69325 .44531 Mtetra
.69325 .44531 .69889 .4522 .7109 .44846 .7053 .44153 Mtetra
.664 .741 .908 r
.7053 .44153 .7109 .44846 .72296 .4447 .71739 .43774 Mtetra
.664 .741 .907 r
.71739 .43774 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.664 .741 .908 r
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48982 Mtetra
.663 .741 .908 r
.5237 .48982 .52984 .49638 .5412 .49283 .53509 .48626 Mtetra
.53509 .48626 .5412 .49283 .55261 .48927 .54653 .48271 Mtetra
.662 .742 .91 r
.54653 .48271 .55261 .48927 .56406 .4857 .55802 .47917 Mtetra
.66 .743 .912 r
.55802 .47917 .56406 .4857 .57556 .48212 .56955 .47565 Mtetra
.66 .746 .914 r
.56955 .47565 .57556 .48212 .58711 .47854 .58113 .47214 Mtetra
.659 .749 .916 r
.58113 .47214 .58711 .47854 .59871 .47494 .59277 .46861 Mtetra
.66 .753 .919 r
.59277 .46861 .59871 .47494 .61036 .47132 .60445 .46505 Mtetra
.661 .756 .92 r
.60445 .46505 .61036 .47132 .62205 .46767 .61618 .46143 Mtetra
.663 .758 .921 r
.61618 .46143 .62205 .46767 .63379 .464 .62796 .45773 Mtetra
.665 .759 .92 r
.62796 .45773 .63379 .464 .64559 .4603 .63979 .45395 Mtetra
.667 .758 .918 r
.63979 .45395 .64559 .4603 .65743 .45658 .65166 .45011 Mtetra
.668 .755 .916 r
.65166 .45011 .65743 .45658 .66932 .45283 .66358 .44623 Mtetra
.668 .752 .913 r
.66358 .44623 .66932 .45283 .68126 .44907 .67556 .44234 Mtetra
.667 .748 .911 r
.67556 .44234 .68126 .44907 .69325 .44531 .68758 .43846 Mtetra
.666 .745 .909 r
.68758 .43846 .69325 .44531 .7053 .44153 .69966 .43459 Mtetra
.665 .743 .908 r
.69966 .43459 .7053 .44153 .71739 .43774 .71179 .43074 Mtetra
.664 .742 .908 r
.71179 .43074 .71739 .43774 .72954 .43394 .72397 .42689 Mtetra
.664 .741 .907 r
.72397 .42689 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41918 Mtetra
.74849 .41918 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49037 Mtetra
.663 .741 .908 r
.49482 .49037 .50106 .49693 .51236 .49338 .50614 .48681 Mtetra
.662 .741 .908 r
.50614 .48681 .51236 .49338 .5237 .48982 .51752 .48327 Mtetra
.66 .742 .91 r
.51752 .48327 .5237 .48982 .53509 .48626 .52894 .47977 Mtetra
.657 .744 .914 r
.52894 .47977 .53509 .48626 .54653 .48271 .54041 .47634 Mtetra
.653 .747 .919 r
.54041 .47634 .54653 .48271 .55802 .47917 .55193 .473 Mtetra
.65 .754 .925 r
.55193 .473 .55802 .47917 .56955 .47565 .5635 .46973 Mtetra
.647 .762 .933 r
.5635 .46973 .56955 .47565 .58113 .47214 .57512 .46648 Mtetra
.647 .772 .94 r
.57512 .46648 .58113 .47214 .59277 .46861 .5868 .46319 Mtetra
.649 .782 .945 r
.5868 .46319 .59277 .46861 .60445 .46505 .59852 .45979 Mtetra
.653 .79 .948 r
.59852 .45979 .60445 .46505 .61618 .46143 .61029 .45624 Mtetra
.658 .795 .948 r
.61029 .45624 .61618 .46143 .62796 .45773 .62211 .45251 Mtetra
.665 .797 .946 r
.62211 .45251 .62796 .45773 .63979 .45395 .63397 .44861 Mtetra
.67 .795 .941 r
.63397 .44861 .63979 .45395 .65166 .45011 .64588 .44455 Mtetra
.675 .79 .935 r
.64588 .44455 .65166 .45011 .66358 .44623 .65783 .44038 Mtetra
.676 .781 .929 r
.65783 .44038 .66358 .44623 .67556 .44234 .66983 .43617 Mtetra
.676 .771 .922 r
.66983 .43617 .67556 .44234 .68758 .43846 .68188 .43198 Mtetra
.673 .761 .917 r
.68188 .43198 .68758 .43846 .69966 .43459 .69398 .42785 Mtetra
.67 .753 .912 r
.69398 .42785 .69966 .43459 .71179 .43074 .70614 .42381 Mtetra
.667 .747 .91 r
.70614 .42381 .71179 .43074 .72397 .42689 .71835 .41985 Mtetra
.665 .743 .908 r
.71835 .41985 .72397 .42689 .7362 .42304 .73062 .41592 Mtetra
.664 .742 .908 r
.73062 .41592 .7362 .42304 .74849 .41918 .74295 .41201 Mtetra
.664 .741 .907 r
.74295 .41201 .74849 .41918 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48735 Mtetra
.663 .741 .908 r
.47721 .48735 .48354 .49392 .49482 .49037 .48852 .48379 Mtetra
.661 .741 .909 r
.48852 .48379 .49482 .49037 .50614 .48681 .49988 .48027 Mtetra
.657 .742 .913 r
.49988 .48027 .50614 .48681 .51752 .48327 .51128 .47686 Mtetra
.65 .745 .919 r
.51128 .47686 .51752 .48327 .52894 .47977 .52273 .47362 Mtetra
.641 .751 .929 r
.52273 .47362 .52894 .47977 .54041 .47634 .53424 .47059 Mtetra
.631 .763 .942 r
.53424 .47059 .54041 .47634 .55193 .473 .5458 .46773 Mtetra
.623 .778 .956 r
.5458 .46773 .55193 .473 .5635 .46973 .55741 .46493 Mtetra
.62 .796 .967 r
.55741 .46493 .5635 .46973 .57512 .46648 .56908 .46204 Mtetra
.622 .812 .973 r
.56908 .46204 .57512 .46648 .5868 .46319 .58079 .45897 Mtetra
.629 .824 .975 r
.58079 .45897 .5868 .46319 .59852 .45979 .59256 .45566 Mtetra
.637 .831 .975 r
.59256 .45566 .59852 .45979 .61029 .45624 .60438 .45212 Mtetra
.646 .835 .973 r
.60438 .45212 .61029 .45624 .62211 .45251 .61624 .44836 Mtetra
.655 .837 .97 r
.61624 .44836 .62211 .45251 .63397 .44861 .62815 .4444 Mtetra
.665 .839 .966 r
.62815 .4444 .63397 .44861 .64588 .44455 .6401 .44019 Mtetra
.676 .837 .961 r
.6401 .44019 .64588 .44455 .65783 .44038 .65208 .43575 Mtetra
.685 .83 .953 r
.65208 .43575 .65783 .44038 .66983 .43617 .66411 .43112 Mtetra
.69 .816 .943 r
.66411 .43112 .66983 .43617 .68188 .43198 .67618 .4264 Mtetra
.689 .798 .933 r
.67618 .4264 .68188 .43198 .69398 .42785 .6883 .42173 Mtetra
.683 .779 .923 r
.6883 .42173 .69398 .42785 .70614 .42381 .70047 .41723 Mtetra
.676 .762 .916 r
.70047 .41723 .70614 .42381 .71835 .41985 .71271 .41295 Mtetra
.67 .751 .911 r
.71271 .41295 .71835 .41985 .73062 .41592 .72501 .40883 Mtetra
.667 .745 .909 r
.72501 .40883 .73062 .41592 .74295 .41201 .73736 .40481 Mtetra
.665 .742 .908 r
.73736 .40481 .74295 .41201 .75533 .40809 .74978 .40084 Mtetra
.664 .741 .907 r
.74978 .40084 .75533 .40809 .76776 .40417 .76225 .39688 Mtetra
.76225 .39688 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .48431 Mtetra
.663 .741 .908 r
.45955 .48431 .46595 .49091 .47721 .48735 .47084 .48075 Mtetra
.66 .741 .91 r
.47084 .48075 .47721 .48735 .48852 .48379 .48218 .47726 Mtetra
.653 .742 .915 r
.48218 .47726 .48852 .48379 .49988 .48027 .49356 .47395 Mtetra
.641 .745 .925 r
.49356 .47395 .49988 .48027 .51128 .47686 .50499 .47095 Mtetra
.623 .755 .941 r
.50499 .47095 .51128 .47686 .52273 .47362 .51648 .4683 Mtetra
.605 .771 .959 r
.51648 .4683 .52273 .47362 .53424 .47059 .52802 .4659 Mtetra
.595 .792 .975 r
.52802 .4659 .53424 .47059 .5458 .46773 .53962 .46346 Mtetra
.604 .813 .98 r
.53962 .46346 .5458 .46773 .55741 .46493 .55127 .46068 Mtetra
.629 .822 .975 r
.55127 .46068 .55741 .46493 .56908 .46204 .56297 .45739 Mtetra
.654 .815 .96 r
.56297 .45739 .56908 .46204 .58079 .45897 .57472 .45364 Mtetra
.668 .794 .942 r
.57472 .45364 .58079 .45897 .59256 .45566 .58651 .44966 Mtetra
.669 .772 .927 r
.58651 .44966 .59256 .45566 .60438 .45212 .59836 .4457 Mtetra
.663 .758 .92 r
.59836 .4457 .60438 .45212 .61624 .44836 .61026 .44191 Mtetra
.656 .755 .923 r
.61026 .44191 .61624 .44836 .62815 .4444 .62221 .43831 Mtetra
.654 .768 .933 r
.62221 .43831 .62815 .4444 .6401 .44019 .63422 .43473 Mtetra
.659 .792 .946 r
.63422 .43473 .6401 .44019 .65208 .43575 .64627 .43091 Mtetra
.671 .82 .955 r
.64627 .43091 .65208 .43575 .66411 .43112 .65836 .42663 Mtetra
.688 .839 .955 r
.65836 .42663 .66411 .43112 .67618 .4264 .67048 .42183 Mtetra
.701 .84 .949 r
.67048 .42183 .67618 .4264 .6883 .42173 .68262 .41668 Mtetra
.703 .824 .94 r
.68262 .41668 .6883 .42173 .70047 .41723 .6948 .41149 Mtetra
.696 .798 .929 r
.6948 .41149 .70047 .41723 .71271 .41295 .70705 .40654 Mtetra
.684 .774 .919 r
.70705 .40654 .71271 .41295 .72501 .40883 .71936 .40195 Mtetra
.674 .756 .913 r
.71936 .40195 .72501 .40883 .73736 .40481 .73174 .39767 Mtetra
.668 .747 .909 r
.73174 .39767 .73736 .40481 .74978 .40084 .74418 .39356 Mtetra
.665 .743 .908 r
.74418 .39356 .74978 .40084 .76225 .39688 .75669 .38953 Mtetra
.664 .741 .907 r
.75669 .38953 .76225 .39688 .77477 .3929 .76925 .38552 Mtetra
.76925 .38552 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48126 Mtetra
.663 .741 .908 r
.44182 .48126 .4483 .48789 .45955 .48431 .45309 .47769 Mtetra
.659 .741 .91 r
.45309 .47769 .45955 .48431 .47084 .48075 .46441 .47421 Mtetra
.65 .741 .916 r
.46441 .47421 .47084 .48075 .48218 .47726 .47578 .47097 Mtetra
.632 .745 .929 r
.47578 .47097 .48218 .47726 .49356 .47395 .48719 .46818 Mtetra
.605 .755 .949 r
.48719 .46818 .49356 .47395 .50499 .47095 .49865 .46588 Mtetra
.583 .774 .97 r
.49865 .46588 .50499 .47095 .51648 .4683 .51016 .46381 Mtetra
.59 .8 .98 r
.51016 .46381 .51648 .4683 .52802 .4659 .52174 .46138 Mtetra
.641 .815 .966 r
.52174 .46138 .52802 .4659 .53962 .46346 .53337 .45792 Mtetra
.696 .793 .925 r
.53337 .45792 .53962 .46346 .55127 .46068 .54505 .4532 Mtetra
.716 .739 .87 r
.54505 .4532 .55127 .46068 .56297 .45739 .55676 .44748 Mtetra
.707 .683 .824 r
.55676 .44748 .56297 .45739 .57472 .45364 .5685 .44142 Mtetra
.666 .627 .802 r
.5685 .44142 .57472 .45364 .58651 .44966 .5803 .43686 Mtetra
.648 .611 .799 r
.5803 .43686 .58651 .44966 .59836 .4457 .59216 .43306 Mtetra
.649 .614 .801 r
.59216 .43306 .59836 .4457 .61026 .44191 .60407 .42924 Mtetra
.60407 .42924 .61026 .44191 .62221 .43831 .61603 .4254 Mtetra
.633 .604 .803 r
.61603 .4254 .62221 .43831 .63422 .43473 .62807 .42233 Mtetra
.599 .595 .819 r
.62807 .42233 .63422 .43473 .64627 .43091 .64022 .42077 Mtetra
.606 .641 .859 r
.64022 .42077 .64627 .43091 .65836 .42663 .65243 .41887 Mtetra
.632 .712 .904 r
.65243 .41887 .65836 .42663 .67048 .42183 .66466 .41598 Mtetra
.67 .787 .936 r
.66466 .41598 .67048 .42183 .68262 .41668 .6769 .4118 Mtetra
.702 .832 .944 r
.6769 .4118 .68262 .41668 .6948 .41149 .68913 .40659 Mtetra
.714 .835 .939 r
.68913 .40659 .6948 .41149 .70705 .40654 .70139 .40099 Mtetra
.707 .811 .93 r
.70139 .40099 .70705 .40654 .71936 .40195 .7137 .39562 Mtetra
.691 .781 .92 r
.7137 .39562 .71936 .40195 .73174 .39767 .72609 .39076 Mtetra
.677 .759 .913 r
.72609 .39076 .73174 .39767 .74418 .39356 .73855 .38634 Mtetra
.669 .747 .909 r
.73855 .38634 .74418 .39356 .75669 .38953 .75109 .38216 Mtetra
.665 .743 .908 r
.75109 .38216 .75669 .38953 .76925 .38552 .76369 .37808 Mtetra
.664 .741 .907 r
.76369 .37808 .76925 .38552 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34929 Mtetra
.85348 .34929 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .3409 Mtetra
.87965 .3409 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .4782 Mtetra
.663 .741 .908 r
.42403 .4782 .43059 .48485 .44182 .48126 .43528 .47461 Mtetra
.659 .74 .91 r
.43528 .47461 .44182 .48126 .45309 .47769 .44659 .4711 Mtetra
.649 .74 .916 r
.44659 .4711 .45309 .47769 .46441 .47421 .45793 .46788 Mtetra
.627 .743 .93 r
.45793 .46788 .46441 .47421 .47578 .47097 .46932 .46519 Mtetra
.593 .751 .953 r
.46932 .46519 .47578 .47097 .48719 .46818 .48075 .46314 Mtetra
.57 .771 .974 r
.48075 .46314 .48719 .46818 .49865 .46588 .49224 .46128 Mtetra
.608 .802 .974 r
.49224 .46128 .49865 .46588 .51016 .46381 .5038 .45853 Mtetra
.697 .801 .929 r
.5038 .45853 .51016 .46381 .52174 .46138 .51542 .45376 Mtetra
.745 .743 .85 r
.51542 .45376 .52174 .46138 .53337 .45792 .52707 .44663 Mtetra
.686 .65 .808 r
.52707 .44663 .53337 .45792 .54505 .4532 .53877 .44123 Mtetra
.651 .624 .81 r
.53877 .44123 .54505 .4532 .55676 .44748 .55051 .43744 Mtetra
.658 .662 .843 r
.55051 .43744 .55676 .44748 .5685 .44142 .5623 .43364 Mtetra
.663 .718 .89 r
.5623 .43364 .5685 .44142 .5803 .43686 .57415 .42983 Mtetra
.664 .741 .907 r
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62807 .42233 .62203 .4144 Mtetra
.663 .718 .89 r
.62203 .4144 .62807 .42233 .64022 .42077 .63413 .4105 Mtetra
.658 .662 .843 r
.63413 .4105 .64022 .42077 .65243 .41887 .64628 .40658 Mtetra
.615 .607 .82 r
.64628 .40658 .65243 .41887 .66466 .41598 .65856 .4043 Mtetra
.568 .595 .84 r
.65856 .4043 .66466 .41598 .6769 .4118 .67098 .40378 Mtetra
.631 .707 .901 r
.67098 .40378 .6769 .4118 .68913 .40659 .68336 .40087 Mtetra
.694 .802 .932 r
.68336 .40087 .68913 .40659 .70139 .40099 .6957 .39591 Mtetra
.721 .833 .934 r
.6957 .39591 .70139 .40099 .7137 .39562 .70804 .39005 Mtetra
.715 .815 .927 r
.70804 .39005 .7137 .39562 .72609 .39076 .72042 .38436 Mtetra
.695 .783 .919 r
.72042 .38436 .72609 .39076 .73855 .38634 .73289 .37932 Mtetra
.677 .758 .912 r
.73289 .37932 .73855 .38634 .75109 .38216 .74545 .37482 Mtetra
.668 .746 .909 r
.74545 .37482 .75109 .38216 .76369 .37808 .75808 .37061 Mtetra
.665 .742 .908 r
.75808 .37061 .76369 .37808 .77635 .37401 .77078 .36648 Mtetra
.664 .741 .907 r
.77078 .36648 .77635 .37401 .78906 .36994 .78353 .36237 Mtetra
.78353 .36237 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34929 .84815 .34154 Mtetra
.84815 .34154 .85348 .34929 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .3409 .87441 .33308 Mtetra
.87441 .33308 .87965 .3409 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.663 .741 .908 r
.40617 .47513 .41281 .48181 .42403 .4782 .41741 .47151 Mtetra
.66 .74 .909 r
.41741 .47151 .42403 .4782 .43528 .47461 .4287 .46796 Mtetra
.651 .74 .914 r
.4287 .46796 .43528 .47461 .44659 .4711 .44002 .46466 Mtetra
.628 .74 .928 r
.44002 .46466 .44659 .4711 .45793 .46788 .45139 .46195 Mtetra
.588 .745 .951 r
.45139 .46195 .45793 .46788 .46932 .46519 .46279 .46001 Mtetra
.562 .764 .973 r
.46279 .46001 .46932 .46519 .48075 .46314 .47425 .45832 Mtetra
.624 .798 .966 r
.47425 .45832 .48075 .46314 .49224 .46128 .48579 .45531 Mtetra
.733 .786 .895 r
.48579 .45531 .49224 .46128 .5038 .45853 .49741 .44924 Mtetra
.736 .704 .821 r
.49741 .44924 .5038 .45853 .51542 .45376 .50906 .44181 Mtetra
.651 .625 .811 r
.50906 .44181 .51542 .45376 .52707 .44663 .52074 .43803 Mtetra
.662 .696 .871 r
.52074 .43803 .52707 .44663 .53877 .44123 .53247 .43423 Mtetra
.664 .741 .907 r
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65856 .4043 .65253 .39535 Mtetra
.662 .696 .871 r
.65253 .39535 .65856 .4043 .67098 .40378 .66483 .39136 Mtetra
.562 .58 .83 r
.66483 .39136 .67098 .40378 .68336 .40087 .67735 .39109 Mtetra
.594 .649 .874 r
.67735 .39109 .68336 .40087 .6957 .39591 .68989 .38944 Mtetra
.686 .777 .92 r
.68989 .38944 .6957 .39591 .70804 .39005 .70234 .38468 Mtetra
.727 .827 .927 r
.70234 .38468 .70804 .39005 .72042 .38436 .71475 .37857 Mtetra
.719 .812 .923 r
.71475 .37857 .72042 .38436 .73289 .37932 .72722 .3727 Mtetra
.694 .779 .916 r
.72722 .3727 .73289 .37932 .74545 .37482 .73978 .36762 Mtetra
.675 .755 .911 r
.73978 .36762 .74545 .37482 .75808 .37061 .75243 .36313 Mtetra
.667 .745 .908 r
.75243 .36313 .75808 .37061 .77078 .36648 .76516 .3589 Mtetra
.664 .742 .908 r
.76516 .3589 .77078 .36648 .78353 .36237 .77795 .35474 Mtetra
.664 .741 .907 r
.77795 .35474 .78353 .36237 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.37708 .47569 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46841 Mtetra
.662 .74 .908 r
.39948 .46841 .40617 .47513 .41741 .47151 .41075 .4648 Mtetra
.655 .74 .912 r
.41075 .4648 .41741 .47151 .4287 .46796 .42206 .46138 Mtetra
.635 .739 .923 r
.42206 .46138 .4287 .46796 .44002 .46466 .4334 .45849 Mtetra
.594 .739 .945 r
.4334 .45849 .44002 .46466 .45139 .46195 .44478 .45649 Mtetra
.556 .752 .969 r
.44478 .45649 .45139 .46195 .46279 .46001 .4562 .45498 Mtetra
.618 .79 .964 r
.4562 .45498 .46279 .46001 .47425 .45832 .46772 .45214 Mtetra
.746 .782 .882 r
.46772 .45214 .47425 .45832 .48579 .45531 .47934 .44547 Mtetra
.722 .689 .818 r
.47934 .44547 .48579 .45531 .49741 .44924 .49099 .43861 Mtetra
.655 .65 .833 r
.49099 .43861 .49741 .44924 .50906 .44181 .50265 .43481 Mtetra
.664 .741 .907 r
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67735 .39109 .67125 .37994 Mtetra
.575 .612 .852 r
.67125 .37994 .67735 .39109 .68989 .38944 .68384 .37902 Mtetra
.577 .629 .866 r
.68384 .37902 .68989 .38944 .70234 .38468 .69651 .37792 Mtetra
.692 .773 .914 r
.69651 .37792 .70234 .38468 .71475 .37857 .70903 .37293 Mtetra
.733 .822 .92 r
.70903 .37293 .71475 .37857 .72722 .3727 .72152 .36655 Mtetra
.717 .803 .918 r
.72152 .36655 .72722 .3727 .73978 .36762 .73408 .36069 Mtetra
.689 .77 .913 r
.73408 .36069 .73978 .36762 .75243 .36313 .74675 .35572 Mtetra
.672 .75 .909 r
.74675 .35572 .75243 .36313 .76516 .3589 .7595 .35129 Mtetra
.666 .743 .908 r
.7595 .35129 .76516 .3589 .77795 .35474 .77233 .34705 Mtetra
.664 .741 .907 r
.77233 .34705 .77795 .35474 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.37028 .46896 .37708 .47569 .38826 .47205 .38148 .4653 Mtetra
.663 .741 .908 r
.38148 .4653 .38826 .47205 .39948 .46841 .39273 .46164 Mtetra
.659 .74 .91 r
.39273 .46164 .39948 .46841 .41075 .4648 .40403 .4581 Mtetra
.645 .739 .917 r
.40403 .4581 .41075 .4648 .42206 .46138 .41536 .45494 Mtetra
.608 .736 .936 r
.41536 .45494 .42206 .46138 .4334 .45849 .42671 .45264 Mtetra
.557 .74 .961 r
.42671 .45264 .4334 .45849 .44478 .45649 .4381 .45122 Mtetra
.588 .772 .967 r
.4381 .45122 .44478 .45649 .4562 .45498 .44958 .44903 Mtetra
.735 .787 .894 r
.44958 .44903 .4562 .45498 .46772 .45214 .46119 .44287 Mtetra
.737 .705 .821 r
.46119 .44287 .46772 .45214 .47934 .44547 .47285 .4354 Mtetra
.657 .662 .843 r
.47285 .4354 .47934 .44547 .49099 .43861 .48449 .43159 Mtetra
.664 .741 .907 r
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68384 .37902 .67775 .36836 Mtetra
.554 .613 .867 r
.67775 .36836 .68384 .37902 .69651 .37792 .69047 .36801 Mtetra
.592 .649 .876 r
.69047 .36801 .69651 .37792 .70903 .37293 .70321 .36633 Mtetra
.712 .787 .911 r
.70321 .36633 .70903 .37293 .72152 .36655 .71579 .3606 Mtetra
.735 .816 .914 r
.71579 .3606 .72152 .36655 .73408 .36069 .72836 .35407 Mtetra
.708 .788 .914 r
.72836 .35407 .73408 .36069 .74675 .35572 .74103 .34843 Mtetra
.681 .759 .91 r
.74103 .34843 .74675 .35572 .7595 .35129 .7538 .34367 Mtetra
.669 .746 .908 r
.7538 .34367 .7595 .35129 .77233 .34705 .76667 .3393 Mtetra
.665 .742 .907 r
.76667 .3393 .77233 .34705 .78522 .34284 .7796 .33505 Mtetra
.664 .741 .907 r
.7796 .33505 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30489 Mtetra
.87177 .30489 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .4653 .37465 .45849 Mtetra
.662 .74 .908 r
.37465 .45849 .38148 .4653 .39273 .46164 .38593 .45484 Mtetra
.653 .739 .913 r
.38593 .45484 .39273 .46164 .40403 .4581 .39725 .45143 Mtetra
.628 .736 .925 r
.39725 .45143 .40403 .4581 .41536 .45494 .4086 .44866 Mtetra
.575 .732 .949 r
.4086 .44866 .41536 .45494 .42671 .45264 .41996 .447 Mtetra
.553 .747 .967 r
.41996 .447 .42671 .45264 .4381 .45122 .43138 .44555 Mtetra
.688 .787 .926 r
.43138 .44555 .4381 .45122 .44958 .44903 .44294 .44102 Mtetra
.77 .74 .826 r
.44294 .44102 .44958 .44903 .46119 .44287 .45464 .43218 Mtetra
.655 .65 .833 r
.45464 .43218 .46119 .44287 .47285 .4354 .46627 .42835 Mtetra
.664 .741 .907 r
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.595 .716 .929 r
.53706 .40507 .54345 .4123 .55539 .40839 .54905 .40305 Mtetra
.544 .762 .978 r
.54905 .40305 .55539 .40839 .56739 .40447 .56112 .40148 Mtetra
.618 .878 .99 r
.56112 .40148 .56739 .40447 .57944 .40053 .57322 .39751 Mtetra
.731 .904 .955 r
.57322 .39751 .57944 .40053 .59154 .39657 .58533 .39114 Mtetra
.724 .818 .923 r
.58533 .39114 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.664 .741 .907 r
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69047 .36801 .68433 .35664 Mtetra
.512 .579 .86 r
.68433 .35664 .69047 .36801 .70321 .36633 .69723 .35763 Mtetra
.641 .703 .892 r
.69723 .35763 .70321 .36633 .71579 .3606 .70998 .35422 Mtetra
.733 .803 .907 r
.70998 .35422 .71579 .3606 .72836 .35407 .7226 .34767 Mtetra
.728 .802 .91 r
.7226 .34767 .72836 .35407 .74103 .34843 .73527 .34131 Mtetra
.694 .771 .911 r
.73527 .34131 .74103 .34843 .7538 .34367 .74806 .33609 Mtetra
.673 .75 .909 r
.74806 .33609 .7538 .34367 .76667 .3393 .76095 .33152 Mtetra
.666 .743 .908 r
.76095 .33152 .76667 .3393 .7796 .33505 .77392 .32719 Mtetra
.664 .741 .907 r
.77392 .32719 .7796 .33505 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30489 .8664 .29677 Mtetra
.8664 .29677 .87177 .30489 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.663 .741 .908 r
.35651 .45534 .36342 .46218 .37465 .45849 .36777 .45164 Mtetra
.66 .74 .909 r
.36777 .45164 .37465 .45849 .38593 .45484 .37908 .44802 Mtetra
.645 .738 .916 r
.37908 .44802 .38593 .45484 .39725 .45143 .39042 .4448 Mtetra
.607 .733 .934 r
.39042 .4448 .39725 .45143 .4086 .44866 .40177 .44252 Mtetra
.549 .729 .958 r
.40177 .44252 .4086 .44866 .41996 .447 .41315 .44129 Mtetra
.605 .765 .956 r
.41315 .44129 .41996 .447 .43138 .44555 .42463 .43881 Mtetra
.771 .771 .853 r
.42463 .43881 .43138 .44555 .44294 .44102 .43633 .43059 Mtetra
.692 .67 .824 r
.43633 .43059 .44294 .44102 .45464 .43218 .44798 .42511 Mtetra
.664 .741 .907 r
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.477 .666 .946 r
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40606 Mtetra
.009 .54 .85 r
.51866 .40606 .52513 .409 .53706 .40507 .53064 .40866 Mtetra
.271 0 0 r
.53064 .40866 .53706 .40507 .54905 .40305 .54272 .40843 Mtetra
.213 0 0 r
.54272 .40843 .54905 .40305 .56112 .40148 .55485 .40611 Mtetra
.031 0 0 r
.55485 .40611 .56112 .40148 .57322 .39751 .56703 .40212 Mtetra
0 0 0 r
.56703 .40212 .57322 .39751 .58533 .39114 .57924 .39646 Mtetra
.57924 .39646 .58533 .39114 .59748 .3852 .59144 .38868 Mtetra
.631 .936 .697 r
.59144 .38868 .59748 .3852 .60972 .38118 .6036 .37805 Mtetra
.793 .91 .921 r
.6036 .37805 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.664 .741 .907 r
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.608 .719 .924 r
.67832 .34896 .68433 .35664 .69723 .35763 .69108 .34645 Mtetra
.532 .596 .863 r
.69108 .34645 .69723 .35763 .70998 .35422 .70406 .34675 Mtetra
.703 .763 .899 r
.70406 .34675 .70998 .35422 .7226 .34767 .71679 .34118 Mtetra
.74 .804 .904 r
.71679 .34118 .7226 .34767 .73527 .34131 .72948 .33432 Mtetra
.709 .781 .908 r
.72948 .33432 .73527 .34131 .74806 .33609 .74228 .32854 Mtetra
.68 .756 .908 r
.74228 .32854 .74806 .33609 .76095 .33152 .7552 .3237 Mtetra
.668 .744 .908 r
.7552 .3237 .76095 .33152 .77392 .32719 .7682 .31928 Mtetra
.665 .741 .907 r
.7682 .31928 .77392 .32719 .78695 .3229 .78127 .31493 Mtetra
.664 .741 .907 r
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47065 Mtetra
.28278 .47065 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .4522 Mtetra
.3383 .4522 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.663 .741 .908 r
.34955 .44846 .35651 .45534 .36777 .45164 .36084 .44474 Mtetra
.657 .739 .911 r
.36084 .44474 .36777 .45164 .37908 .44802 .37217 .44118 Mtetra
.635 .736 .921 r
.37217 .44118 .37908 .44802 .39042 .4448 .38353 .43821 Mtetra
.583 .727 .942 r
.38353 .43821 .39042 .4448 .40177 .44252 .39489 .4364 Mtetra
.545 .73 .961 r
.39489 .4364 .40177 .44252 .41315 .44129 .40629 .43519 Mtetra
.684 .775 .92 r
.40629 .43519 .41315 .44129 .42463 .43881 .41787 .43076 Mtetra
.77 .741 .826 r
.41787 .43076 .42463 .43881 .43633 .43059 .42962 .42185 Mtetra
.661 .696 .872 r
.42962 .42185 .43633 .43059 .44798 .42511 .44126 .41798 Mtetra
.664 .741 .907 r
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.325 .59 .94 r
.48831 .40235 .4949 .4096 .50676 .40568 .50015 .405 Mtetra
.356 0 0 r
.50015 .405 .50676 .40568 .51866 .40606 .51208 .40904 Mtetra
.292 0 0 r
.51208 .40904 .51866 .40606 .53064 .40866 .52413 .40956 Mtetra
.104 .656 .704 r
.52413 .40956 .53064 .40866 .54272 .40843 .53626 .40782 Mtetra
.407 .851 .92 r
.53626 .40782 .54272 .40843 .55485 .40611 .54845 .40473 Mtetra
.542 .901 .97 r
.54845 .40473 .55485 .40611 .56703 .40212 .56068 .40071 Mtetra
.607 .925 .969 r
.56068 .40071 .56703 .40212 .57924 .39646 .57296 .39577 Mtetra
.655 .956 .942 r
.57296 .39577 .57924 .39646 .59144 .38868 .58527 .38946 Mtetra
.704 .984 .872 r
.58527 .38946 .59144 .38868 .6036 .37805 .59755 .38087 Mtetra
.752 .984 .749 r
.59755 .38087 .6036 .37805 .61583 .36962 .60977 .3687 Mtetra
.836 .974 .883 r
.60977 .3687 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.664 .741 .907 r
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69108 .34645 .68498 .337 Mtetra
.488 .615 .903 r
.68498 .337 .69108 .34645 .70406 .34675 .69802 .33792 Mtetra
.645 .706 .892 r
.69802 .33792 .70406 .34675 .71679 .34118 .7109 .33429 Mtetra
.739 .794 .897 r
.7109 .33429 .71679 .34118 .72948 .33432 .72364 .32735 Mtetra
.723 .788 .904 r
.72364 .32735 .72948 .33432 .74228 .32854 .73645 .32101 Mtetra
.689 .761 .907 r
.73645 .32101 .74228 .32854 .7552 .3237 .74939 .31585 Mtetra
.67 .746 .908 r
.74939 .31585 .7552 .3237 .7682 .31928 .76243 .3113 Mtetra
.665 .742 .907 r
.76243 .3113 .7682 .31928 .78127 .31493 .77555 .30691 Mtetra
.664 .741 .907 r
.77555 .30691 .78127 .31493 .79441 .31059 .78872 .30253 Mtetra
.78872 .30253 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47065 .27559 .46388 Mtetra
.27559 .46388 .28278 .47065 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .4522 .33125 .44528 Mtetra
.33125 .44528 .3383 .4522 .34955 .44846 .34253 .44152 Mtetra
.662 .74 .908 r
.34253 .44152 .34955 .44846 .36084 .44474 .35385 .4378 Mtetra
.653 .739 .912 r
.35385 .4378 .36084 .44474 .37217 .44118 .3652 .43431 Mtetra
.623 .733 .925 r
.3652 .43431 .37217 .44118 .38353 .43821 .37658 .43161 Mtetra
.564 .721 .947 r
.37658 .43161 .38353 .43821 .39489 .4364 .38795 .43017 Mtetra
.567 .736 .955 r
.38795 .43017 .39489 .4364 .40629 .43519 .39939 .42854 Mtetra
.745 .772 .874 r
.39939 .42854 .40629 .43519 .41787 .43076 .41109 .42167 Mtetra
.729 .71 .833 r
.41109 .42167 .41787 .43076 .42962 .42185 .42282 .4147 Mtetra
.664 .741 .907 r
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.474 .666 .947 r
.46979 .39901 .47647 .40628 .48831 .40235 .48161 .39936 Mtetra
.382 0 0 r
.48161 .39936 .48831 .40235 .50015 .405 .49345 .40568 Mtetra
.245 0 0 r
.49345 .40568 .50015 .405 .51208 .40904 .50544 .4074 Mtetra
.313 .78 .938 r
.50544 .4074 .51208 .40904 .52413 .40956 .51754 .40613 Mtetra
.558 .844 .998 r
.51754 .40613 .52413 .40956 .53626 .40782 .52971 .40329 Mtetra
.628 .828 .977 r
.52971 .40329 .53626 .40782 .54845 .40473 .54194 .39968 Mtetra
.653 .818 .963 r
.54194 .39968 .54845 .40473 .56068 .40071 .55422 .39563 Mtetra
.67 .823 .957 r
.55422 .39563 .56068 .40071 .57296 .39577 .56656 .39115 Mtetra
.696 .846 .955 r
.56656 .39115 .57296 .39577 .58527 .38946 .57893 .38588 Mtetra
.744 .893 .946 r
.57893 .38588 .58527 .38946 .59755 .38087 .59132 .37903 Mtetra
.821 .952 .904 r
.59132 .37903 .59755 .38087 .60977 .3687 .60366 .36916 Mtetra
.894 .981 .807 r
.60366 .36916 .60977 .3687 .62201 .35792 .61588 .35462 Mtetra
.793 .91 .921 r
.61588 .35462 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.664 .741 .907 r
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.55 .693 .934 r
.67892 .32915 .68498 .337 .69802 .33792 .69189 .32803 Mtetra
.57 .648 .888 r
.69189 .32803 .69802 .33792 .7109 .33429 .70494 .32682 Mtetra
.727 .775 .892 r
.70494 .32682 .7109 .33429 .72364 .32735 .71774 .32024 Mtetra
.733 .789 .897 r
.71774 .32024 .72364 .32735 .73645 .32101 .73058 .31346 Mtetra
.697 .766 .905 r
.73058 .31346 .73645 .32101 .74939 .31585 .74354 .30796 Mtetra
.673 .748 .907 r
.74354 .30796 .74939 .31585 .76243 .3113 .75662 .30327 Mtetra
.666 .742 .907 r
.75662 .30327 .76243 .3113 .77555 .30691 .76977 .29881 Mtetra
.664 .741 .907 r
.76977 .29881 .77555 .30691 .78872 .30253 .78299 .29439 Mtetra
.78299 .29439 .78872 .30253 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33545 .43453 Mtetra
.661 .74 .909 r
.33545 .43453 .34253 .44152 .35385 .4378 .3468 .4308 Mtetra
.65 .738 .914 r
.3468 .4308 .35385 .4378 .3652 .43431 .35818 .42739 Mtetra
.613 .729 .929 r
.35818 .42739 .3652 .43431 .37658 .43161 .36957 .42492 Mtetra
.551 .716 .949 r
.36957 .42492 .37658 .43161 .38795 .43017 .38096 .4237 Mtetra
.601 .742 .943 r
.38096 .4237 .38795 .43017 .39939 .42854 .39246 .42139 Mtetra
.783 .765 .837 r
.39246 .42139 .39939 .42854 .41109 .42167 .40428 .41218 Mtetra
.679 .688 .851 r
.40428 .41218 .41109 .42167 .42282 .4147 .41596 .40749 Mtetra
.664 .741 .907 r
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
0 .35 .82 r
.46306 .39167 .46979 .39901 .48161 .39936 .4748 .39857 Mtetra
.366 0 0 r
.4748 .39857 .48161 .39936 .49345 .40568 .4867 .40281 Mtetra
.29 .733 .963 r
.4867 .40281 .49345 .40568 .50544 .4074 .49875 .40273 Mtetra
.569 .803 .987 r
.49875 .40273 .50544 .4074 .51754 .40613 .51089 .4003 Mtetra
.637 .785 .953 r
.51089 .4003 .51754 .40613 .52971 .40329 .5231 .39681 Mtetra
.656 .771 .934 r
.5231 .39681 .52971 .40329 .54194 .39968 .53537 .3929 Mtetra
.662 .764 .926 r
.53537 .3929 .54194 .39968 .55422 .39563 .54769 .38882 Mtetra
.667 .766 .924 r
.54769 .38882 .55422 .39563 .56656 .39115 .56007 .38457 Mtetra
.68 .778 .925 r
.56007 .38457 .56656 .39115 .57893 .38588 .57249 .37989 Mtetra
.712 .807 .923 r
.57249 .37989 .57893 .38588 .59132 .37903 .58495 .37415 Mtetra
.779 .855 .907 r
.58495 .37415 .59132 .37903 .60366 .36916 .59739 .36602 Mtetra
.869 .906 .854 r
.59739 .36602 .60366 .36916 .61588 .35462 .60975 .35353 Mtetra
.911 .947 .812 r
.60975 .35353 .61588 .35462 .62828 .34607 .62201 .3383 Mtetra
.664 .741 .907 r
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.639 .731 .915 r
.6728 .32124 .67892 .32915 .69189 .32803 .68569 .31773 Mtetra
.487 .598 .889 r
.68569 .31773 .69189 .32803 .70494 .32682 .69889 .31884 Mtetra
.708 .757 .89 r
.69889 .31884 .70494 .32682 .71774 .32024 .71178 .31288 Mtetra
.738 .785 .89 r
.71178 .31288 .71774 .32024 .73058 .31346 .72465 .30581 Mtetra
.704 .767 .901 r
.72465 .30581 .73058 .31346 .74354 .30796 .73764 .3 Mtetra
.677 .75 .906 r
.73764 .3 .74354 .30796 .75662 .30327 .75075 .29516 Mtetra
.666 .743 .907 r
.75075 .29516 .75662 .30327 .76977 .29881 .76394 .29065 Mtetra
.664 .741 .907 r
.76394 .29065 .76977 .29881 .78299 .29439 .7772 .28619 Mtetra
.7772 .28619 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .27201 .84444 .26361 Mtetra
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33545 .43453 .32833 .42748 Mtetra
.661 .74 .909 r
.32833 .42748 .33545 .43453 .3468 .4308 .3397 .42374 Mtetra
.647 .737 .915 r
.3397 .42374 .3468 .4308 .35818 .42739 .35111 .42038 Mtetra
.605 .726 .93 r
.35111 .42038 .35818 .42739 .36957 .42492 .36251 .41808 Mtetra
.547 .711 .948 r
.36251 .41808 .36957 .42492 .38096 .4237 .37392 .41695 Mtetra
.63 .744 .93 r
.37392 .41695 .38096 .4237 .39246 .42139 .38548 .41397 Mtetra
.789 .76 .827 r
.38548 .41397 .39246 .42139 .40428 .41218 .39736 .40417 Mtetra
.663 .719 .89 r
.39736 .40417 .40428 .41218 .41596 .40749 .40904 .40022 Mtetra
.664 .741 .907 r
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.593 .717 .93 r
.44439 .38829 .45121 .39565 .46306 .39167 .45624 .3862 Mtetra
0 .139 .6 r
.45624 .3862 .46306 .39167 .4748 .39857 .46796 .39491 Mtetra
.049 .552 .881 r
.46796 .39491 .4748 .39857 .4867 .40281 .47991 .39763 Mtetra
.504 .76 .988 r
.47991 .39763 .4867 .40281 .49875 .40273 .492 .39646 Mtetra
.623 .767 .949 r
.492 .39646 .49875 .40273 .51089 .4003 .50419 .39337 Mtetra
.654 .757 .926 r
.50419 .39337 .51089 .4003 .5231 .39681 .51643 .38954 Mtetra
.662 .75 .916 r
.51643 .38954 .5231 .39681 .53537 .3929 .52874 .38546 Mtetra
.662 .746 .912 r
.52874 .38546 .53537 .3929 .54769 .38882 .5411 .38134 Mtetra
.663 .746 .912 r
.5411 .38134 .54769 .38882 .56007 .38457 .55351 .37719 Mtetra
.67 .753 .913 r
.55351 .37719 .56007 .38457 .57249 .37989 .56598 .3728 Mtetra
.692 .769 .91 r
.56598 .3728 .57249 .37989 .58495 .37415 .57849 .36765 Mtetra
.745 .801 .897 r
.57849 .36765 .58495 .37415 .59739 .36602 .59101 .36056 Mtetra
.829 .841 .856 r
.59101 .36056 .59739 .36602 .60975 .35353 .60346 .34953 Mtetra
.909 .867 .785 r
.60346 .34953 .60975 .35353 .62201 .3383 .61574 .33241 Mtetra
.724 .818 .923 r
.61574 .33241 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.664 .741 .907 r
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68569 .31773 .67952 .30892 Mtetra
.435 .611 .923 r
.67952 .30892 .68569 .31773 .69889 .31884 .69278 .31056 Mtetra
.69 .745 .893 r
.69278 .31056 .69889 .31884 .71178 .31288 .70575 .30523 Mtetra
.74 .779 .885 r
.70575 .30523 .71178 .31288 .72465 .30581 .71866 .29799 Mtetra
.709 .766 .897 r
.71866 .29799 .72465 .30581 .73764 .3 .73169 .29195 Mtetra
.679 .75 .905 r
.73169 .29195 .73764 .3 .75075 .29516 .74483 .28699 Mtetra
.667 .743 .907 r
.74483 .28699 .75075 .29516 .76394 .29065 .75807 .28242 Mtetra
.664 .741 .907 r
.75807 .28242 .76394 .29065 .7772 .28619 .77137 .27791 Mtetra
.77137 .27791 .7772 .28619 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.663 .741 .907 r
.30978 .42422 .31699 .4313 .32833 .42748 .32114 .42038 Mtetra
.66 .74 .909 r
.32114 .42038 .32833 .42748 .3397 .42374 .33254 .41662 Mtetra
.645 .736 .915 r
.33254 .41662 .3397 .42374 .35111 .42038 .34398 .41328 Mtetra
.601 .723 .93 r
.34398 .41328 .35111 .42038 .36251 .41808 .3554 .41104 Mtetra
.547 .707 .945 r
.3554 .41104 .36251 .41808 .37392 .41695 .36683 .40993 Mtetra
.645 .742 .919 r
.36683 .40993 .37392 .41695 .38548 .41397 .37844 .40652 Mtetra
.786 .761 .83 r
.37844 .40652 .38548 .41397 .39736 .40417 .39036 .39687 Mtetra
.664 .741 .907 r
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.474 .667 .947 r
.43752 .38087 .44439 .38829 .45624 .3862 .44934 .38115 Mtetra
0 .174 .618 r
.44934 .38115 .45624 .3862 .46796 .39491 .46109 .3891 Mtetra
.289 .631 .963 r
.46109 .3891 .46796 .39491 .47991 .39763 .47308 .39106 Mtetra
.561 .736 .957 r
.47308 .39106 .47991 .39763 .492 .39646 .48521 .38937 Mtetra
.637 .747 .928 r
.48521 .38937 .492 .39646 .50419 .39337 .49743 .38599 Mtetra
.659 .747 .915 r
.49743 .38599 .50419 .39337 .51643 .38954 .50971 .38198 Mtetra
.663 .744 .91 r
.50971 .38198 .51643 .38954 .52874 .38546 .52205 .37781 Mtetra
.662 .742 .909 r
.52205 .37781 .52874 .38546 .5411 .38134 .53445 .37366 Mtetra
.661 .742 .91 r
.53445 .37366 .5411 .38134 .55351 .37719 .5469 .36953 Mtetra
.665 .745 .909 r
.5469 .36953 .55351 .37719 .56598 .3728 .5594 .36524 Mtetra
.684 .755 .905 r
.5594 .36524 .56598 .3728 .57849 .36765 .57196 .36032 Mtetra
.729 .775 .889 r
.57196 .36032 .57849 .36765 .59101 .36056 .58453 .35369 Mtetra
.805 .802 .849 r
.58453 .35369 .59101 .36056 .60346 .34953 .59706 .34336 Mtetra
.881 .819 .783 r
.59706 .34336 .60346 .34953 .61574 .33241 .60943 .32694 Mtetra
.787 .844 .895 r
.60943 .32694 .61574 .33241 .62834 .32619 .622 .31826 Mtetra
.664 .741 .907 r
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.426 .63 .939 r
.67334 .30084 .67952 .30892 .69278 .31056 .68663 .30225 Mtetra
.679 .742 .898 r
.68663 .30225 .69278 .31056 .70575 .30523 .69966 .29729 Mtetra
.739 .773 .88 r
.69966 .29729 .70575 .30523 .71866 .29799 .71261 .28997 Mtetra
.711 .763 .893 r
.71261 .28997 .71866 .29799 .73169 .29195 .72568 .28379 Mtetra
.68 .749 .903 r
.72568 .28379 .73169 .29195 .74483 .28699 .73886 .27873 Mtetra
.667 .743 .907 r
.73886 .27873 .74483 .28699 .75807 .28242 .75214 .27411 Mtetra
.664 .741 .907 r
.75214 .27411 .75807 .28242 .77137 .27791 .76549 .26957 Mtetra
.76549 .26957 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.663 .741 .907 r
.3025 .41709 .30978 .42422 .32114 .42038 .3139 .41322 Mtetra
.66 .74 .909 r
.3139 .41322 .32114 .42038 .33254 .41662 .32533 .40942 Mtetra
.645 .736 .915 r
.32533 .40942 .33254 .41662 .34398 .41328 .33679 .40606 Mtetra
.601 .722 .929 r
.33679 .40606 .34398 .41328 .3554 .41104 .34824 .40379 Mtetra
.549 .702 .941 r
.34824 .40379 .3554 .41104 .36683 .40993 .3597 .40265 Mtetra
.646 .736 .915 r
.3597 .40265 .36683 .40993 .37844 .40652 .37134 .39921 Mtetra
.788 .766 .833 r
.37134 .39921 .37844 .40652 .39036 .39687 .3833 .38952 Mtetra
.664 .741 .907 r
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.474 .667 .947 r
.43059 .37339 .43752 .38087 .44934 .38115 .44243 .37364 Mtetra
0 .276 .765 r
.44243 .37364 .44934 .38115 .46109 .3891 .45419 .38158 Mtetra
.367 .614 .946 r
.45419 .38158 .46109 .3891 .47308 .39106 .4662 .38352 Mtetra
.572 .711 .936 r
.4662 .38352 .47308 .39106 .48521 .38937 .47836 .3818 Mtetra
.639 .735 .919 r
.47836 .3818 .48521 .38937 .49743 .38599 .49061 .37838 Mtetra
.659 .742 .911 r
.49061 .37838 .49743 .38599 .50971 .38198 .50293 .37434 Mtetra
.663 .744 .91 r
.50293 .37434 .50971 .38198 .52205 .37781 .51531 .37013 Mtetra
.662 .743 .91 r
.51531 .37013 .52205 .37781 .53445 .37366 .52774 .36595 Mtetra
.661 .743 .911 r
.52774 .36595 .53445 .37366 .5469 .36953 .54023 .36179 Mtetra
.665 .744 .909 r
.54023 .36179 .5469 .36953 .5594 .36524 .55277 .35746 Mtetra
.683 .75 .902 r
.55277 .35746 .5594 .36524 .57196 .36032 .56537 .35251 Mtetra
.727 .763 .881 r
.56537 .35251 .57196 .36032 .58453 .35369 .57798 .34583 Mtetra
.796 .778 .837 r
.57798 .34583 .58453 .35369 .59706 .34336 .59056 .33546 Mtetra
.863 .783 .771 r
.59056 .33546 .59706 .34336 .60943 .32694 .60299 .31898 Mtetra
.768 .772 .856 r
.60299 .31898 .60943 .32694 .622 .31826 .61561 .31026 Mtetra
.664 .741 .907 r
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.426 .63 .939 r
.66711 .29269 .67334 .30084 .68663 .30225 .68043 .29407 Mtetra
.679 .747 .902 r
.68043 .29407 .68663 .30225 .69966 .29729 .69351 .28907 Mtetra
.738 .767 .876 r
.69351 .28907 .69966 .29729 .71261 .28997 .70651 .28171 Mtetra
.711 .758 .889 r
.70651 .28171 .71261 .28997 .72568 .28379 .71961 .27549 Mtetra
.68 .747 .902 r
.71961 .27549 .72568 .28379 .73886 .27873 .73284 .27039 Mtetra
.667 .742 .906 r
.73284 .27039 .73886 .27873 .75214 .27411 .74617 .26573 Mtetra
.664 .741 .907 r
.74617 .26573 .75214 .27411 .76549 .26957 .75956 .26115 Mtetra
.75956 .26115 .76549 .26957 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23798 Mtetra
.82746 .23798 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .41322 .30659 .40599 Mtetra
.661 .74 .909 r
.30659 .40599 .3139 .41322 .32533 .40942 .31806 .40216 Mtetra
.647 .736 .914 r
.31806 .40216 .32533 .40942 .33679 .40606 .32955 .39871 Mtetra
.606 .721 .926 r
.32955 .39871 .33679 .40606 .34824 .40379 .34104 .39632 Mtetra
.553 .699 .937 r
.34104 .39632 .34824 .40379 .3597 .40265 .35252 .39511 Mtetra
.632 .726 .915 r
.35252 .39511 .3597 .40265 .37134 .39921 .36416 .39204 Mtetra
.793 .771 .833 r
.36416 .39204 .37134 .39921 .3833 .38952 .37618 .38211 Mtetra
.664 .741 .907 r
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.593 .717 .93 r
.4236 .36584 .43059 .37339 .44243 .37364 .43554 .36367 Mtetra
0 .291 .79 r
.43554 .36367 .44243 .37364 .45419 .38158 .44727 .37234 Mtetra
.373 .566 .912 r
.44727 .37234 .45419 .38158 .4662 .38352 .45928 .375 Mtetra
.56 .679 .919 r
.45928 .375 .4662 .38352 .47836 .3818 .47146 .37374 Mtetra
.63 .72 .912 r
.47146 .37374 .47836 .3818 .49061 .37838 .48375 .37056 Mtetra
.654 .736 .91 r
.48375 .37056 .49061 .37838 .50293 .37434 .4961 .36662 Mtetra
.662 .743 .91 r
.4961 .36662 .50293 .37434 .51531 .37013 .50851 .36243 Mtetra
.662 .744 .911 r
.50851 .36243 .51531 .37013 .52774 .36595 .52098 .35822 Mtetra
.663 .745 .911 r
.52098 .35822 .52774 .36595 .54023 .36179 .5335 .35396 Mtetra
.67 .745 .907 r
.5335 .35396 .54023 .36179 .55277 .35746 .54608 .34946 Mtetra
.69 .748 .896 r
.54608 .34946 .55277 .35746 .56537 .35251 .55871 .3442 Mtetra
.735 .754 .868 r
.55871 .3442 .56537 .35251 .57798 .34583 .57136 .33699 Mtetra
.797 .758 .817 r
.57136 .33699 .57798 .34583 .59056 .33546 .58397 .32582 Mtetra
.85 .751 .753 r
.58397 .32582 .59056 .33546 .60299 .31898 .59645 .30853 Mtetra
.703 .697 .842 r
.59645 .30853 .60299 .31898 .61561 .31026 .60917 .30219 Mtetra
.664 .741 .907 r
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.415 .624 .939 r
.66083 .28447 .66711 .29269 .68043 .29407 .67418 .28603 Mtetra
.691 .757 .902 r
.67418 .28603 .68043 .29407 .69351 .28907 .68729 .28058 Mtetra
.735 .761 .873 r
.68729 .28058 .69351 .28907 .70651 .28171 .70033 .27321 Mtetra
.707 .752 .887 r
.70033 .27321 .70651 .28171 .71961 .27549 .71349 .26705 Mtetra
.679 .745 .901 r
.71349 .26705 .71961 .27549 .73284 .27039 .72677 .26197 Mtetra
.667 .742 .906 r
.72677 .26197 .73284 .27039 .74617 .26573 .74014 .25728 Mtetra
.664 .741 .907 r
.74014 .25728 .74617 .26573 .75956 .26115 .75357 .25266 Mtetra
.75357 .25266 .75956 .26115 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .30659 .40599 .29924 .39871 Mtetra
.661 .74 .908 r
.29924 .39871 .30659 .40599 .31806 .40216 .31073 .39483 Mtetra
.65 .736 .913 r
.31073 .39483 .31806 .40216 .32955 .39871 .32226 .39126 Mtetra
.614 .723 .923 r
.32226 .39126 .32955 .39871 .34104 .39632 .33378 .38865 Mtetra
.56 .697 .932 r
.33378 .38865 .34104 .39632 .35252 .39511 .34529 .38729 Mtetra
.608 .712 .918 r
.34529 .38729 .35252 .39511 .36416 .39204 .35693 .38484 Mtetra
.785 .771 .84 r
.35693 .38484 .36416 .39204 .37618 .38211 .36897 .37543 Mtetra
.69 .77 .913 r
.36897 .37543 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.664 .741 .907 r
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43554 .36367 .42858 .35409 Mtetra
.082 .383 .844 r
.42858 .35409 .43554 .36367 .44727 .37234 .44036 .36092 Mtetra
.343 .496 .866 r
.44036 .36092 .44727 .37234 .45928 .375 .45234 .36506 Mtetra
.526 .628 .895 r
.45234 .36506 .45928 .375 .47146 .37374 .46452 .36485 Mtetra
.61 .692 .902 r
.46452 .36485 .47146 .37374 .48375 .37056 .47683 .36226 Mtetra
.644 .722 .905 r
.47683 .36226 .48375 .37056 .4961 .36662 .48921 .35861 Mtetra
.657 .735 .907 r
.48921 .35861 .4961 .36662 .50851 .36243 .50166 .35453 Mtetra
.662 .74 .908 r
.50166 .35453 .50851 .36243 .52098 .35822 .51416 .35027 Mtetra
.667 .742 .906 r
.51416 .35027 .52098 .35822 .5335 .35396 .52672 .34584 Mtetra
.678 .742 .899 r
.52672 .34584 .5335 .35396 .54608 .34946 .53934 .34099 Mtetra
.705 .742 .88 r
.53934 .34099 .54608 .34946 .55871 .3442 .552 .33506 Mtetra
.75 .741 .843 r
.552 .33506 .55871 .3442 .57136 .33699 .56468 .32671 Mtetra
.802 .732 .787 r
.56468 .32671 .57136 .33699 .58397 .32582 .5773 .31397 Mtetra
.814 .712 .752 r
.5773 .31397 .58397 .32582 .59645 .30853 .58987 .29847 Mtetra
.66 .691 .868 r
.58987 .29847 .59645 .30853 .60917 .30219 .60267 .29405 Mtetra
.664 .741 .907 r
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.639 .731 .915 r
.64145 .28068 .64783 .28893 .66083 .28447 .65453 .27698 Mtetra
.424 .655 .956 r
.65453 .27698 .66083 .28447 .67418 .28603 .66789 .27795 Mtetra
.709 .764 .895 r
.66789 .27795 .67418 .28603 .68729 .28058 .681 .27179 Mtetra
.731 .754 .871 r
.681 .27179 .68729 .28058 .70033 .27321 .6941 .2645 Mtetra
.702 .747 .887 r
.6941 .2645 .70033 .27321 .71349 .26705 .70732 .25849 Mtetra
.676 .743 .901 r
.70732 .25849 .71349 .26705 .72677 .26197 .72064 .25346 Mtetra
.666 .741 .906 r
.72064 .25346 .72677 .26197 .74014 .25728 .73406 .24875 Mtetra
.664 .741 .907 r
.73406 .24875 .74014 .25728 .75357 .25266 .74753 .24409 Mtetra
.74753 .24409 .75357 .25266 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .39871 .29182 .39137 Mtetra
.662 .74 .908 r
.29182 .39137 .29924 .39871 .31073 .39483 .30334 .38743 Mtetra
.653 .737 .911 r
.30334 .38743 .31073 .39483 .32226 .39126 .31491 .38373 Mtetra
.624 .725 .919 r
.31491 .38373 .32226 .39126 .33378 .38865 .32647 .38082 Mtetra
.572 .699 .928 r
.32647 .38082 .33378 .38865 .34529 .38729 .33802 .37919 Mtetra
.582 .696 .92 r
.33802 .37919 .34529 .38729 .35693 .38484 .34965 .37737 Mtetra
.742 .76 .867 r
.34965 .37737 .35693 .38484 .36897 .37543 .36162 .37023 Mtetra
.759 .828 .906 r
.36162 .37023 .36897 .37543 .38082 .37056 .37362 .363 Mtetra
.664 .741 .907 r
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.474 .666 .947 r
.42151 .34639 .42858 .35409 .44036 .36092 .4335 .34657 Mtetra
.306 .416 .81 r
.4335 .34657 .44036 .36092 .45234 .36506 .44541 .35277 Mtetra
.476 .553 .855 r
.44541 .35277 .45234 .36506 .46452 .36485 .45757 .35433 Mtetra
.575 .64 .878 r
.45757 .35433 .46452 .36485 .47683 .36226 .46987 .35285 Mtetra
.625 .688 .889 r
.46987 .35285 .47683 .36226 .48921 .35861 .48227 .34979 Mtetra
.648 .712 .894 r
.48227 .34979 .48921 .35861 .50166 .35453 .49475 .34594 Mtetra
.661 .724 .895 r
.49475 .34594 .50166 .35453 .51416 .35027 .50729 .34165 Mtetra
.673 .728 .891 r
.50729 .34165 .51416 .35027 .52672 .34584 .51989 .33692 Mtetra
.693 .728 .877 r
.51989 .33692 .52672 .34584 .53934 .34099 .53254 .33139 Mtetra
.724 .723 .849 r
.53254 .33139 .53934 .34099 .552 .33506 .54522 .32426 Mtetra
.765 .714 .804 r
.54522 .32426 .552 .33506 .56468 .32671 .55792 .31407 Mtetra
.801 .698 .751 r
.55792 .31407 .56468 .32671 .5773 .31397 .57055 .29915 Mtetra
.715 .637 .77 r
.57055 .29915 .5773 .31397 .58987 .29847 .58327 .2903 Mtetra
.664 .741 .907 r
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.55 .693 .934 r
.63502 .27235 .64145 .28068 .65453 .27698 .64823 .27101 Mtetra
.514 .754 .983 r
.64823 .27101 .65453 .27698 .66789 .27795 .66153 .26957 Mtetra
.724 .763 .883 r
.66153 .26957 .66789 .27795 .681 .27179 .67465 .2627 Mtetra
.724 .746 .869 r
.67465 .2627 .681 .27179 .6941 .2645 .68781 .25562 Mtetra
.694 .742 .888 r
.68781 .25562 .6941 .2645 .70732 .25849 .70109 .24984 Mtetra
.673 .741 .901 r
.70109 .24984 .70732 .25849 .72064 .25346 .71446 .24487 Mtetra
.666 .741 .906 r
.71446 .24487 .72064 .25346 .73406 .24875 .72792 .24014 Mtetra
.664 .741 .907 r
.72792 .24014 .73406 .24875 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39137 .28434 .38397 Mtetra
.663 .74 .908 r
.28434 .38397 .29182 .39137 .30334 .38743 .2959 .37998 Mtetra
.657 .738 .91 r
.2959 .37998 .30334 .38743 .31491 .38373 .3075 .37614 Mtetra
.636 .729 .915 r
.3075 .37614 .31491 .38373 .32647 .38082 .31911 .3729 Mtetra
.59 .705 .923 r
.31911 .3729 .32647 .38082 .33802 .37919 .33071 .37084 Mtetra
.566 .685 .92 r
.33071 .37084 .33802 .37919 .34965 .37737 .34234 .36938 Mtetra
.681 .735 .891 r
.34234 .36938 .34965 .37737 .36162 .37023 .35421 .36465 Mtetra
.797 .818 .868 r
.35421 .36465 .36162 .37023 .37362 .363 .36636 .35537 Mtetra
.664 .741 .907 r
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .4335 .34657 .42653 .33439 Mtetra
.434 .533 .858 r
.42653 .33439 .4335 .34657 .44541 .35277 .43854 .33684 Mtetra
.426 .465 .798 r
.43854 .33684 .44541 .35277 .45757 .35433 .45063 .3407 Mtetra
.528 .558 .83 r
.45063 .3407 .45757 .35433 .46987 .35285 .46291 .34099 Mtetra
.593 .623 .851 r
.46291 .34099 .46987 .35285 .48227 .34979 .47531 .33898 Mtetra
.632 .662 .861 r
.47531 .33898 .48227 .34979 .49475 .34594 .48781 .33559 Mtetra
.657 .682 .862 r
.48781 .33559 .49475 .34594 .50729 .34165 .50037 .33126 Mtetra
.68 .691 .854 r
.50037 .33126 .50729 .34165 .51989 .33692 .513 .32599 Mtetra
.706 .691 .833 r
.513 .32599 .51989 .33692 .53254 .33139 .52568 .31933 Mtetra
.737 .684 .799 r
.52568 .31933 .53254 .33139 .54522 .32426 .53839 .31034 Mtetra
.767 .671 .756 r
.53839 .31034 .54522 .32426 .55792 .31407 .55109 .29774 Mtetra
.734 .631 .744 r
.55109 .29774 .55792 .31407 .57055 .29915 .5638 .28653 Mtetra
.651 .64 .826 r
.5638 .28653 .57055 .29915 .58327 .2903 .57663 .28206 Mtetra
.664 .741 .907 r
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.456 .647 .94 r
.62853 .26396 .63502 .27235 .64823 .27101 .64185 .26463 Mtetra
.636 .793 .958 r
.64185 .26463 .64823 .27101 .66153 .26957 .65509 .26066 Mtetra
.731 .753 .871 r
.65509 .26066 .66153 .26957 .67465 .2627 .66824 .25334 Mtetra
.714 .738 .87 r
.66824 .25334 .67465 .2627 .68781 .25562 .68147 .24663 Mtetra
.686 .738 .89 r
.68147 .24663 .68781 .25562 .70109 .24984 .6948 .24111 Mtetra
.67 .74 .903 r
.6948 .24111 .70109 .24984 .71446 .24487 .70823 .23621 Mtetra
.665 .741 .906 r
.70823 .23621 .71446 .24487 .72792 .24014 .72173 .23147 Mtetra
.664 .741 .907 r
.72173 .23147 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.663 .741 .908 r
.2768 .37651 .28434 .38397 .2959 .37998 .28839 .37247 Mtetra
.66 .739 .909 r
.28839 .37247 .2959 .37998 .3075 .37614 .30003 .36851 Mtetra
.646 .733 .912 r
.30003 .36851 .3075 .37614 .31911 .3729 .31169 .36496 Mtetra
.61 .713 .918 r
.31169 .36496 .31911 .3729 .33071 .37084 .32334 .36235 Mtetra
.569 .684 .918 r
.32334 .36235 .33071 .37084 .34234 .36938 .33499 .36082 Mtetra
.618 .701 .904 r
.33499 .36082 .34234 .36938 .35421 .36465 .34679 .35802 Mtetra
.778 .791 .864 r
.34679 .35802 .35421 .36465 .36636 .35537 .35895 .34935 Mtetra
.718 .802 .917 r
.35895 .34935 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.664 .741 .907 r
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43854 .33684 .43161 .32223 Mtetra
.536 .547 .814 r
.43161 .32223 .43854 .33684 .45063 .3407 .44379 .32233 Mtetra
.487 .474 .768 r
.44379 .32233 .45063 .3407 .46291 .34099 .456 .32468 Mtetra
.555 .537 .789 r
.456 .32468 .46291 .34099 .47531 .33898 .46838 .32415 Mtetra
.606 .583 .802 r
.46838 .32415 .47531 .33898 .48781 .33559 .48087 .32147 Mtetra
.644 .613 .803 r
.48087 .32147 .48781 .33559 .50037 .33126 .49345 .3171 Mtetra
.676 .628 .793 r
.49345 .3171 .50037 .33126 .513 .32599 .5061 .31103 Mtetra
.705 .632 .772 r
.5061 .31103 .513 .32599 .52568 .31933 .51879 .30279 Mtetra
.732 .628 .743 r
.51879 .30279 .52568 .31933 .53839 .31034 .53151 .29164 Mtetra
.692 .589 .736 r
.53151 .29164 .53839 .31034 .55109 .29774 .54425 .28274 Mtetra
.642 .602 .793 r
.54425 .28274 .55109 .29774 .5638 .28653 .55705 .27826 Mtetra
.664 .741 .907 r
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.608 .719 .924 r
.60888 .26009 .61546 .26851 .62853 .26396 .62204 .2572 Mtetra
.45 .699 .973 r
.62204 .2572 .62853 .26396 .64185 .26463 .63538 .25717 Mtetra
.705 .785 .913 r
.63538 .25717 .64185 .26463 .65509 .26066 .64858 .25116 Mtetra
.726 .74 .862 r
.64858 .25116 .65509 .26066 .66824 .25334 .66178 .24384 Mtetra
.702 .732 .874 r
.66178 .24384 .66824 .25334 .68147 .24663 .67507 .2376 Mtetra
.679 .736 .894 r
.67507 .2376 .68147 .24663 .6948 .24111 .68846 .23234 Mtetra
.667 .739 .904 r
.68846 .23234 .6948 .24111 .70823 .23621 .70194 .22748 Mtetra
.665 .741 .907 r
.70194 .22748 .70823 .23621 .72173 .23147 .71549 .22271 Mtetra
.664 .741 .907 r
.71549 .22271 .72173 .23147 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.20052 .39321 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .38521 Mtetra
.22321 .38521 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37247 .28082 .36491 Mtetra
.662 .74 .908 r
.28082 .36491 .28839 .37247 .30003 .36851 .29249 .36085 Mtetra
.653 .736 .91 r
.29249 .36085 .30003 .36851 .31169 .36496 .3042 .35703 Mtetra
.63 .722 .914 r
.3042 .35703 .31169 .36496 .32334 .36235 .31591 .35388 Mtetra
.588 .693 .915 r
.31591 .35388 .32334 .36235 .33499 .36082 .32762 .35185 Mtetra
.581 .678 .907 r
.32762 .35185 .33499 .36082 .34679 .35802 .33938 .35004 Mtetra
.686 .74 .893 r
.33938 .35004 .34679 .35802 .35895 .34935 .35138 .34507 Mtetra
.808 .861 .888 r
.35138 .34507 .35895 .34935 .371 .34348 .36365 .33569 Mtetra
.664 .741 .907 r
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .44379 .32233 .43676 .30992 Mtetra
.651 .64 .827 r
.43676 .30992 .44379 .32233 .456 .32468 .44914 .30556 Mtetra
.593 .529 .752 r
.44914 .30556 .456 .32468 .46838 .32415 .46153 .30314 Mtetra
.582 .508 .736 r
.46153 .30314 .46838 .32415 .48087 .32147 .474 .30117 Mtetra
.623 .538 .737 r
.474 .30117 .48087 .32147 .49345 .3171 .48656 .29675 Mtetra
.658 .557 .73 r
.48656 .29675 .49345 .3171 .5061 .31103 .49921 .28987 Mtetra
.649 .547 .725 r
.49921 .28987 .5061 .31103 .51879 .30279 .5119 .28343 Mtetra
.627 .548 .746 r
.5119 .28343 .51879 .30279 .53151 .29164 .52462 .27895 Mtetra
.651 .64 .827 r
.52462 .27895 .53151 .29164 .54425 .28274 .53741 .27444 Mtetra
.664 .741 .907 r
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.455 .647 .941 r
.60223 .25159 .60888 .26009 .62204 .2572 .61554 .2522 Mtetra
.613 .834 .985 r
.61554 .2522 .62204 .2572 .63538 .25717 .6288 .24832 Mtetra
.725 .756 .877 r
.6288 .24832 .63538 .25717 .64858 .25116 .64201 .24122 Mtetra
.714 .727 .861 r
.64201 .24122 .64858 .25116 .66178 .24384 .65527 .23433 Mtetra
.689 .729 .881 r
.65527 .23433 .66178 .24384 .67507 .2376 .66862 .22859 Mtetra
.673 .736 .898 r
.66862 .22859 .67507 .2376 .68846 .23234 .68207 .22352 Mtetra
.666 .74 .905 r
.68207 .22352 .68846 .23234 .70194 .22748 .6956 .21869 Mtetra
.664 .741 .907 r
.6956 .21869 .70194 .22748 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.19268 .38582 .20052 .39321 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .38521 .21543 .37776 Mtetra
.21543 .37776 .22321 .38521 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .36491 .27319 .35729 Mtetra
.663 .74 .908 r
.27319 .35729 .28082 .36491 .29249 .36085 .28489 .35316 Mtetra
.659 .738 .909 r
.28489 .35316 .29249 .36085 .3042 .35703 .29664 .34915 Mtetra
.645 .73 .911 r
.29664 .34915 .3042 .35703 .31591 .35388 .30841 .34553 Mtetra
.613 .708 .912 r
.30841 .34553 .31591 .35388 .32762 .35185 .32018 .3428 Mtetra
.581 .677 .906 r
.32018 .3428 .32762 .35185 .33938 .35004 .33197 .34096 Mtetra
.61 .689 .899 r
.33197 .34096 .33938 .35004 .35138 .34507 .34386 .33832 Mtetra
.735 .787 .894 r
.34386 .33832 .35138 .34507 .36365 .33569 .35604 .33161 Mtetra
.779 .872 .916 r
.35604 .33161 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.664 .741 .907 r
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46153 .30314 .45445 .29303 Mtetra
.659 .691 .869 r
.45445 .29303 .46153 .30314 .474 .30117 .46698 .28858 Mtetra
.65 .641 .827 r
.46698 .28858 .474 .30117 .48656 .29675 .47956 .28412 Mtetra
.47956 .28412 .48656 .29675 .49921 .28987 .49221 .27964 Mtetra
.659 .691 .869 r
.49221 .27964 .49921 .28987 .5119 .28343 .50492 .27513 Mtetra
.664 .741 .907 r
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.521 .68 .938 r
.58241 .24767 .58915 .2562 .60223 .25159 .59562 .24685 Mtetra
.513 .803 .998 r
.59562 .24685 .60223 .25159 .61554 .2522 .6089 .24467 Mtetra
.712 .788 .911 r
.6089 .24467 .61554 .2522 .6288 .24832 .62213 .23834 Mtetra
.719 .729 .858 r
.62213 .23834 .6288 .24832 .64201 .24122 .63538 .23119 Mtetra
.698 .721 .867 r
.63538 .23119 .64201 .24122 .65527 .23433 .64871 .22495 Mtetra
.679 .73 .889 r
.64871 .22495 .65527 .23433 .66862 .22859 .66213 .2196 Mtetra
.668 .737 .902 r
.66213 .2196 .66862 .22859 .68207 .22352 .67563 .21465 Mtetra
.665 .74 .906 r
.67563 .21465 .68207 .22352 .6956 .21869 .6892 .20981 Mtetra
.664 .741 .907 r
.6892 .20981 .6956 .21869 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20012 Mtetra
.71654 .20012 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35729 .26549 .34961 Mtetra
.26549 .34961 .27319 .35729 .28489 .35316 .27723 .34543 Mtetra
.662 .74 .908 r
.27723 .34543 .28489 .35316 .29664 .34915 .28901 .3413 Mtetra
.655 .735 .909 r
.28901 .3413 .29664 .34915 .30841 .34553 .30084 .33735 Mtetra
.636 .721 .909 r
.30084 .33735 .30841 .34553 .32018 .3428 .31268 .33394 Mtetra
.604 .693 .906 r
.31268 .33394 .32018 .3428 .33197 .34096 .32452 .33144 Mtetra
.586 .67 .898 r
.32452 .33144 .33197 .34096 .34386 .33832 .3364 .32946 Mtetra
.633 .705 .898 r
.3364 .32946 .34386 .33832 .35604 .33161 .34843 .32609 Mtetra
.755 .828 .909 r
.34843 .32609 .35604 .33161 .36833 .32356 .36072 .31878 Mtetra
.762 .852 .918 r
.36072 .31878 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.664 .741 .907 r
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.548 .693 .935 r
.5625 .24373 .56934 .2523 .58241 .24767 .57566 .24228 Mtetra
.498 .775 .994 r
.57566 .24228 .58241 .24767 .59562 .24685 .58891 .24064 Mtetra
.693 .822 .945 r
.58891 .24064 .59562 .24685 .6089 .24467 .60214 .23498 Mtetra
.719 .736 .865 r
.60214 .23498 .6089 .24467 .62213 .23834 .61539 .22791 Mtetra
.703 .715 .858 r
.61539 .22791 .62213 .23834 .63538 .23119 .6287 .22135 Mtetra
.684 .722 .878 r
.6287 .22135 .63538 .23119 .64871 .22495 .6421 .21572 Mtetra
.671 .733 .896 r
.6421 .21572 .64871 .22495 .66213 .2196 .65558 .21063 Mtetra
.666 .738 .904 r
.65558 .21063 .66213 .2196 .67563 .21465 .66913 .20573 Mtetra
.664 .74 .907 r
.66913 .20573 .67563 .21465 .6892 .20981 .68274 .20087 Mtetra
.664 .741 .907 r
.68274 .20087 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20012 .71018 .19108 Mtetra
.71018 .19108 .71654 .20012 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34543 .2695 .33765 Mtetra
.663 .74 .907 r
.2695 .33765 .27723 .34543 .28901 .3413 .28132 .33343 Mtetra
.66 .738 .908 r
.28132 .33343 .28901 .3413 .30084 .33735 .29319 .32929 Mtetra
.651 .731 .908 r
.29319 .32929 .30084 .33735 .31268 .33394 .30509 .3254 Mtetra
.63 .713 .906 r
.30509 .3254 .31268 .33394 .32452 .33144 .31701 .3221 Mtetra
.602 .683 .899 r
.31701 .3221 .32452 .33144 .3364 .32946 .32894 .31962 Mtetra
.594 .668 .891 r
.32894 .31962 .3364 .32946 .34843 .32609 .34092 .31737 Mtetra
.639 .714 .902 r
.34092 .31737 .34843 .32609 .36072 .31878 .35305 .31377 Mtetra
.74 .845 .929 r
.35305 .31377 .36072 .31878 .37306 .31126 .3654 .30699 Mtetra
.779 .872 .916 r
.3654 .30699 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.664 .741 .907 r
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.52 .681 .939 r
.54251 .23978 .54945 .24838 .5625 .24373 .55563 .23893 Mtetra
.518 .805 .998 r
.55563 .23893 .5625 .24373 .57566 .24228 .56884 .23665 Mtetra
.684 .839 .957 r
.56884 .23665 .57566 .24228 .58891 .24064 .58206 .23117 Mtetra
.716 .741 .871 r
.58206 .23117 .58891 .24064 .60214 .23498 .59531 .22429 Mtetra
.703 .71 .854 r
.59531 .22429 .60214 .23498 .61539 .22791 .60861 .21765 Mtetra
.686 .714 .87 r
.60861 .21765 .61539 .22791 .6287 .22135 .62199 .21182 Mtetra
.673 .727 .89 r
.62199 .21182 .6287 .22135 .6421 .21572 .63544 .2066 Mtetra
.667 .736 .902 r
.63544 .2066 .6421 .21572 .65558 .21063 .64897 .20164 Mtetra
.664 .74 .906 r
.64897 .20164 .65558 .21063 .66913 .20573 .66257 .19674 Mtetra
.664 .741 .907 r
.66257 .19674 .66913 .20573 .68274 .20087 .67623 .19184 Mtetra
.67623 .19184 .68274 .20087 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15179 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33343 .27356 .32554 Mtetra
.663 .74 .907 r
.27356 .32554 .28132 .33343 .29319 .32929 .28546 .32129 Mtetra
.659 .737 .907 r
.28546 .32129 .29319 .32929 .30509 .3254 .29742 .31712 Mtetra
.649 .728 .906 r
.29742 .31712 .30509 .3254 .31701 .3221 .3094 .31323 Mtetra
.63 .707 .901 r
.3094 .31323 .31701 .3221 .32894 .31962 .32141 .3099 Mtetra
.607 .678 .892 r
.32141 .3099 .32894 .31962 .34092 .31737 .33344 .30723 Mtetra
.601 .667 .886 r
.33344 .30723 .34092 .31737 .35305 .31377 .34552 .30475 Mtetra
.631 .706 .9 r
.34552 .30475 .35305 .31377 .3654 .30699 .35773 .30134 Mtetra
.699 .822 .941 r
.35773 .30134 .3654 .30699 .37785 .2988 .3701 .29584 Mtetra
.77 .914 .936 r
.3701 .29584 .37785 .2988 .39017 .29439 .38263 .28788 Mtetra
.718 .802 .917 r
.38263 .28788 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.664 .741 .907 r
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.607 .719 .925 r
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23752 Mtetra
.506 .728 .973 r
.52244 .23752 .52949 .24445 .54251 .23978 .53553 .23636 Mtetra
.556 .866 .996 r
.53553 .23636 .54251 .23978 .55563 .23893 .54868 .23272 Mtetra
.695 .824 .944 r
.54868 .23272 .55563 .23893 .56884 .23665 .56189 .22696 Mtetra
.71 .734 .87 r
.56189 .22696 .56884 .23665 .58206 .23117 .57513 .22025 Mtetra
.699 .705 .852 r
.57513 .22025 .58206 .23117 .59531 .22429 .58843 .21372 Mtetra
.685 .708 .865 r
.58843 .21372 .59531 .22429 .60861 .21765 .60179 .20785 Mtetra
.674 .722 .885 r
.60179 .20785 .60861 .21765 .62199 .21182 .61523 .20255 Mtetra
.667 .733 .899 r
.61523 .20255 .62199 .21182 .63544 .2066 .62873 .19753 Mtetra
.665 .739 .905 r
.62873 .19753 .63544 .2066 .64897 .20164 .64231 .1926 Mtetra
.664 .74 .907 r
.64231 .1926 .64897 .20164 .66257 .19674 .65595 .18768 Mtetra
.664 .741 .907 r
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15179 .78177 .14232 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32554 .26573 .3176 Mtetra
.26573 .3176 .27356 .32554 .28546 .32129 .27767 .31328 Mtetra
.662 .74 .907 r
.27767 .31328 .28546 .32129 .29742 .31712 .28966 .30897 Mtetra
.659 .736 .907 r
.28966 .30897 .29742 .31712 .3094 .31323 .3017 .30476 Mtetra
.65 .725 .904 r
.3017 .30476 .3094 .31323 .32141 .3099 .31378 .30079 Mtetra
.634 .705 .897 r
.31378 .30079 .32141 .3099 .33344 .30723 .32588 .29728 Mtetra
.617 .679 .886 r
.32588 .29728 .33344 .30723 .34552 .30475 .33802 .29429 Mtetra
.608 .665 .879 r
.33802 .29429 .34552 .30475 .35773 .30134 .35021 .29153 Mtetra
.62 .686 .89 r
.35021 .29153 .35773 .30134 .3701 .29584 .36249 .28838 Mtetra
.655 .76 .927 r
.36249 .28838 .3701 .29584 .38263 .28788 .37489 .28417 Mtetra
.685 .884 .972 r
.37489 .28417 .38263 .28788 .39512 .28171 .3874 .27863 Mtetra
.718 .91 .962 r
.3874 .27863 .39512 .28171 .40759 .27722 .40001 .27205 Mtetra
.74 .851 .932 r
.40001 .27205 .40759 .27722 .42011 .2727 .41267 .26512 Mtetra
.69 .77 .913 r
.41267 .26512 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.664 .741 .907 r
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.638 .732 .916 r
.46353 .24588 .4708 .25443 .48362 .24981 .47638 .24203 Mtetra
.573 .73 .948 r
.47638 .24203 .48362 .24981 .4965 .24516 .48927 .23974 Mtetra
.555 .8 .99 r
.48927 .23974 .4965 .24516 .50944 .2405 .50225 .2371 Mtetra
.559 .867 .996 r
.50225 .2371 .50944 .2405 .52244 .23752 .51532 .23342 Mtetra
.649 .877 .983 r
.51532 .23342 .52244 .23752 .53553 .23636 .52845 .22839 Mtetra
.703 .775 .908 r
.52845 .22839 .53553 .23636 .54868 .23272 .54164 .22229 Mtetra
.701 .716 .86 r
.54164 .22229 .54868 .23272 .56189 .22696 .55487 .21578 Mtetra
.692 .698 .851 r
.55487 .21578 .56189 .22696 .57513 .22025 .56816 .20951 Mtetra
.682 .704 .864 r
.56816 .20951 .57513 .22025 .58843 .21372 .58151 .20375 Mtetra
.673 .719 .883 r
.58151 .20375 .58843 .21372 .60179 .20785 .59493 .19845 Mtetra
.668 .731 .897 r
.59493 .19845 .60179 .20785 .61523 .20255 .60841 .1934 Mtetra
.665 .738 .904 r
.60841 .1934 .61523 .20255 .62873 .19753 .62196 .18845 Mtetra
.664 .74 .907 r
.62196 .18845 .62873 .19753 .64231 .1926 .63558 .1835 Mtetra
.664 .741 .907 r
.63558 .1835 .64231 .1926 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14232 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .3176 .25784 .30959 Mtetra
.25784 .30959 .26573 .3176 .27767 .31328 .26981 .30522 Mtetra
.664 .74 .907 r
.26981 .30522 .27767 .31328 .28966 .30897 .28184 .30085 Mtetra
.663 .739 .907 r
.28184 .30085 .28966 .30897 .3017 .30476 .29392 .29648 Mtetra
.659 .735 .906 r
.29392 .29648 .3017 .30476 .31378 .30079 .30605 .29219 Mtetra
.653 .726 .903 r
.30605 .29219 .31378 .30079 .32588 .29728 .31822 .28808 Mtetra
.641 .708 .895 r
.31822 .28808 .32588 .29728 .33802 .29429 .33043 .28428 Mtetra
.629 .685 .884 r
.33043 .28428 .33802 .29429 .35021 .29153 .34268 .28086 Mtetra
.62 .667 .874 r
.34268 .28086 .35021 .29153 .36249 .28838 .35498 .27768 Mtetra
.62 .668 .874 r
.35498 .27768 .36249 .28838 .37489 .28417 .36735 .27446 Mtetra
.632 .696 .891 r
.36735 .27446 .37489 .28417 .3874 .27863 .37981 .27088 Mtetra
.649 .754 .926 r
.37981 .27088 .3874 .27863 .40001 .27205 .39235 .26676 Mtetra
.656 .832 .967 r
.39235 .26676 .40001 .27205 .41267 .26512 .40497 .26216 Mtetra
.629 .897 .986 r
.40497 .26216 .41267 .26512 .42532 .25973 .41766 .25731 Mtetra
.61 .907 .983 r
.41766 .25731 .42532 .25973 .43799 .25514 .43041 .25247 Mtetra
.604 .9 .986 r
.43041 .25247 .43799 .25514 .45073 .25052 .44321 .24782 Mtetra
.592 .896 .988 r
.44321 .24782 .45073 .25052 .46353 .24588 .45607 .24334 Mtetra
.582 .898 .986 r
.45607 .24334 .46353 .24588 .47638 .24203 .46899 .23889 Mtetra
.614 .893 .988 r
.46899 .23889 .47638 .24203 .48927 .23974 .48197 .23418 Mtetra
.673 .837 .962 r
.48197 .23418 .48927 .23974 .50225 .2371 .49503 .22899 Mtetra
.693 .768 .909 r
.49503 .22899 .50225 .2371 .51532 .23342 .50814 .22325 Mtetra
.694 .719 .868 r
.50814 .22325 .51532 .23342 .52845 .22839 .52131 .21714 Mtetra
.689 .695 .851 r
.52131 .21714 .52845 .22839 .54164 .22229 .53453 .21098 Mtetra
.683 .692 .853 r
.53453 .21098 .54164 .22229 .55487 .21578 .54781 .20507 Mtetra
.676 .703 .867 r
.54781 .20507 .55487 .21578 .56816 .20951 .56114 .19952 Mtetra
.671 .718 .884 r
.56114 .19952 .56816 .20951 .58151 .20375 .57454 .19429 Mtetra
.667 .73 .897 r
.57454 .19429 .58151 .20375 .59493 .19845 .58801 .18925 Mtetra
.665 .737 .904 r
.58801 .18925 .59493 .19845 .60841 .1934 .60154 .18427 Mtetra
.664 .74 .906 r
.60154 .18427 .60841 .1934 .62196 .18845 .61514 .1793 Mtetra
.664 .741 .907 r
.61514 .1793 .62196 .18845 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30085 .27395 .29269 Mtetra
.664 .74 .907 r
.27395 .29269 .28184 .30085 .29392 .29648 .28606 .28825 Mtetra
.663 .739 .907 r
.28606 .28825 .29392 .29648 .30605 .29219 .29823 .28382 Mtetra
.661 .736 .906 r
.29823 .28382 .30605 .29219 .31822 .28808 .31045 .27943 Mtetra
.657 .729 .902 r
.31045 .27943 .31822 .28808 .33043 .28428 .32272 .27514 Mtetra
.65 .715 .896 r
.32272 .27514 .33043 .28428 .34268 .28086 .33504 .27103 Mtetra
.642 .697 .885 r
.33504 .27103 .34268 .28086 .35498 .27768 .34741 .26713 Mtetra
.635 .679 .874 r
.34741 .26713 .35498 .27768 .36735 .27446 .35983 .2634 Mtetra
.632 .667 .866 r
.35983 .2634 .36735 .27446 .37981 .27088 .37231 .25973 Mtetra
.633 .667 .865 r
.37231 .25973 .37981 .27088 .39235 .26676 .38486 .25597 Mtetra
.64 .678 .871 r
.38486 .25597 .39235 .26676 .40497 .26216 .39748 .252 Mtetra
.648 .696 .881 r
.39748 .252 .40497 .26216 .41766 .25731 .41018 .24778 Mtetra
.656 .715 .892 r
.41018 .24778 .41766 .25731 .43041 .25247 .42295 .24332 Mtetra
.663 .727 .897 r
.42295 .24332 .43041 .25247 .44321 .24782 .43578 .23862 Mtetra
.668 .729 .895 r
.43578 .23862 .44321 .24782 .45607 .24334 .44869 .2337 Mtetra
.673 .721 .885 r
.44869 .2337 .45607 .24334 .46899 .23889 .46165 .22852 Mtetra
.677 .707 .87 r
.46165 .22852 .46899 .23889 .48197 .23418 .47468 .22309 Mtetra
.678 .693 .857 r
.47468 .22309 .48197 .23418 .49503 .22899 .48777 .21745 Mtetra
.678 .685 .85 r
.48777 .21745 .49503 .22899 .50814 .22325 .50092 .21171 Mtetra
.676 .685 .851 r
.50092 .21171 .50814 .22325 .52131 .21714 .51412 .20603 Mtetra
.674 .694 .861 r
.51412 .20603 .52131 .21714 .53453 .21098 .52738 .20052 Mtetra
.671 .707 .875 r
.52738 .20052 .53453 .21098 .54781 .20507 .54069 .19522 Mtetra
.668 .721 .889 r
.54069 .19522 .54781 .20507 .56114 .19952 .55407 .19009 Mtetra
.666 .732 .899 r
.55407 .19009 .56114 .19952 .57454 .19429 .56752 .18506 Mtetra
.665 .737 .904 r
.56752 .18506 .57454 .19429 .58801 .18925 .58103 .18008 Mtetra
.664 .74 .906 r
.58103 .18008 .58801 .18925 .60154 .18427 .5946 .17509 Mtetra
.664 .741 .907 r
.5946 .17509 .60154 .18427 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28825 .27813 .27999 Mtetra
.664 .74 .907 r
.27813 .27999 .28606 .28825 .29823 .28382 .29034 .27549 Mtetra
.663 .74 .907 r
.29034 .27549 .29823 .28382 .31045 .27943 .3026 .27098 Mtetra
.662 .737 .906 r
.3026 .27098 .31045 .27943 .32272 .27514 .31492 .26649 Mtetra
.66 .732 .903 r
.31492 .26649 .32272 .27514 .33504 .27103 .32729 .26204 Mtetra
.657 .724 .899 r
.32729 .26204 .33504 .27103 .34741 .26713 .33971 .25766 Mtetra
.653 .712 .891 r
.33971 .25766 .34741 .26713 .35983 .2634 .35219 .25336 Mtetra
.649 .698 .882 r
.35219 .25336 .35983 .2634 .37231 .25973 .36472 .24913 Mtetra
.646 .686 .873 r
.36472 .24913 .37231 .25973 .38486 .25597 .37732 .24492 Mtetra
.646 .677 .865 r
.37732 .24492 .38486 .25597 .39748 .252 .38998 .24065 Mtetra
.648 .672 .86 r
.38998 .24065 .39748 .252 .41018 .24778 .40271 .23627 Mtetra
.651 .671 .856 r
.40271 .23627 .41018 .24778 .42295 .24332 .4155 .23172 Mtetra
.655 .672 .854 r
.4155 .23172 .42295 .24332 .43578 .23862 .42837 .22698 Mtetra
.659 .674 .853 r
.42837 .22698 .43578 .23862 .44869 .2337 .4413 .22205 Mtetra
.663 .676 .852 r
.4413 .22205 .44869 .2337 .46165 .22852 .45429 .21695 Mtetra
.666 .68 .853 r
.45429 .21695 .46165 .22852 .47468 .22309 .46734 .21173 Mtetra
.668 .685 .857 r
.46734 .21173 .47468 .22309 .48777 .21745 .48046 .20646 Mtetra
.668 .694 .865 r
.48046 .20646 .48777 .21745 .50092 .21171 .49363 .2012 Mtetra
.668 .705 .875 r
.49363 .2012 .50092 .21171 .51412 .20603 .50687 .19601 Mtetra
.667 .717 .886 r
.50687 .19601 .51412 .20603 .52738 .20052 .52016 .1909 Mtetra
.666 .727 .895 r
.52016 .1909 .52738 .20052 .54069 .19522 .53352 .18586 Mtetra
.665 .734 .901 r
.53352 .18586 .54069 .19522 .55407 .19009 .54694 .18085 Mtetra
.664 .738 .905 r
.54694 .18085 .55407 .19009 .56752 .18506 .56043 .17586 Mtetra
.664 .74 .906 r
.56043 .17586 .56752 .18506 .58103 .18008 .57399 .17085 Mtetra
.664 .741 .907 r
.57399 .17085 .58103 .18008 .5946 .17509 .58761 .16583 Mtetra
.58761 .16583 .5946 .17509 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .15061 Mtetra
.62887 .15061 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27999 .27014 .27166 Mtetra
.27014 .27166 .27813 .27999 .29034 .27549 .28238 .26712 Mtetra
.28238 .26712 .29034 .27549 .3026 .27098 .29467 .26256 Mtetra
.664 .74 .907 r
.29467 .26256 .3026 .27098 .31492 .26649 .30703 .25798 Mtetra
.663 .739 .906 r
.30703 .25798 .31492 .26649 .32729 .26204 .31944 .2534 Mtetra
.662 .736 .905 r
.31944 .2534 .32729 .26204 .33971 .25766 .33191 .24881 Mtetra
.661 .732 .902 r
.33191 .24881 .33971 .25766 .35219 .25336 .34443 .24424 Mtetra
.66 .725 .898 r
.34443 .24424 .35219 .25336 .36472 .24913 .35702 .23967 Mtetra
.658 .718 .892 r
.35702 .23967 .36472 .24913 .37732 .24492 .36966 .23511 Mtetra
.657 .71 .887 r
.36966 .23511 .37732 .24492 .38998 .24065 .38237 .23054 Mtetra
.657 .704 .881 r
.38237 .23054 .38998 .24065 .40271 .23627 .39513 .22591 Mtetra
.658 .7 .877 r
.39513 .22591 .40271 .23627 .4155 .23172 .40796 .22122 Mtetra
.659 .698 .875 r
.40796 .22122 .4155 .23172 .42837 .22698 .42086 .21643 Mtetra
.661 .699 .874 r
.42086 .21643 .42837 .22698 .4413 .22205 .43382 .21156 Mtetra
.663 .702 .876 r
.43382 .21156 .4413 .22205 .45429 .21695 .44684 .20662 Mtetra
.664 .706 .879 r
.44684 .20662 .45429 .21695 .46734 .21173 .45992 .20163 Mtetra
.665 .713 .884 r
.45992 .20163 .46734 .21173 .48046 .20646 .47307 .19662 Mtetra
.665 .72 .89 r
.47307 .19662 .48046 .20646 .49363 .2012 .48628 .19161 Mtetra
.665 .727 .896 r
.48628 .19161 .49363 .2012 .50687 .19601 .49955 .18661 Mtetra
.665 .733 .901 r
.49955 .18661 .50687 .19601 .52016 .1909 .51289 .18162 Mtetra
.664 .737 .904 r
.51289 .18162 .52016 .1909 .53352 .18586 .52629 .17663 Mtetra
.664 .739 .906 r
.52629 .17663 .53352 .18586 .54694 .18085 .53975 .17163 Mtetra
.664 .74 .907 r
.53975 .17163 .54694 .18085 .56043 .17586 .55328 .1666 Mtetra
.664 .741 .907 r
.55328 .1666 .56043 .17586 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .15061 .62195 .14112 Mtetra
.62195 .14112 .62887 .15061 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26712 .27435 .25868 Mtetra
.27435 .25868 .28238 .26712 .29467 .26256 .28668 .25407 Mtetra
.28668 .25407 .29467 .26256 .30703 .25798 .29907 .24945 Mtetra
.664 .74 .907 r
.29907 .24945 .30703 .25798 .31944 .2534 .31151 .24481 Mtetra
.31151 .24481 .31944 .2534 .33191 .24881 .32402 .24015 Mtetra
.663 .739 .906 r
.32402 .24015 .33191 .24881 .34443 .24424 .33659 .23547 Mtetra
.663 .737 .905 r
.33659 .23547 .34443 .24424 .35702 .23967 .34921 .23078 Mtetra
.663 .735 .903 r
.34921 .23078 .35702 .23967 .36966 .23511 .3619 .22607 Mtetra
.662 .732 .901 r
.3619 .22607 .36966 .23511 .38237 .23054 .37464 .22134 Mtetra
.662 .729 .899 r
.37464 .22134 .38237 .23054 .39513 .22591 .38745 .21658 Mtetra
.662 .727 .897 r
.38745 .21658 .39513 .22591 .40796 .22122 .40032 .21179 Mtetra
.663 .726 .896 r
.40032 .21179 .40796 .22122 .42086 .21643 .41325 .20697 Mtetra
.41325 .20697 .42086 .21643 .43382 .21156 .42624 .2021 Mtetra
.663 .728 .897 r
.42624 .2021 .43382 .21156 .44684 .20662 .4393 .19721 Mtetra
.664 .73 .899 r
.4393 .19721 .44684 .20662 .45992 .20163 .45242 .19229 Mtetra
.664 .733 .901 r
.45242 .19229 .45992 .20163 .47307 .19662 .4656 .18734 Mtetra
.664 .735 .903 r
.4656 .18734 .47307 .19662 .48628 .19161 .47885 .18238 Mtetra
.664 .738 .905 r
.47885 .18238 .48628 .19161 .49955 .18661 .49216 .1774 Mtetra
.664 .739 .906 r
.49216 .1774 .49955 .18661 .51289 .18162 .50554 .1724 Mtetra
.664 .74 .907 r
.50554 .1724 .51289 .18162 .52629 .17663 .51898 .16738 Mtetra
.664 .741 .907 r
.51898 .16738 .52629 .17663 .53975 .17163 .53249 .16233 Mtetra
.53249 .16233 .53975 .17163 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31151 .24481 .30352 .23617 Mtetra
.30352 .23617 .31151 .24481 .32402 .24015 .31606 .23146 Mtetra
.664 .74 .907 r
.31606 .23146 .32402 .24015 .33659 .23547 .32866 .22673 Mtetra
.32866 .22673 .33659 .23547 .34921 .23078 .34133 .22198 Mtetra
.34133 .22198 .34921 .23078 .3619 .22607 .35405 .21721 Mtetra
.664 .739 .906 r
.35405 .21721 .3619 .22607 .37464 .22134 .36683 .21241 Mtetra
.36683 .21241 .37464 .22134 .38745 .21658 .37968 .20759 Mtetra
.664 .738 .905 r
.37968 .20759 .38745 .21658 .40032 .21179 .39259 .20275 Mtetra
.39259 .20275 .40032 .21179 .41325 .20697 .40556 .19788 Mtetra
.40556 .19788 .41325 .20697 .42624 .2021 .41859 .19299 Mtetra
.41859 .19299 .42624 .2021 .4393 .19721 .43169 .18807 Mtetra
.664 .739 .906 r
.43169 .18807 .4393 .19721 .45242 .19229 .44485 .18312 Mtetra
.44485 .18312 .45242 .19229 .4656 .18734 .45807 .17816 Mtetra
.664 .74 .907 r
.45807 .17816 .4656 .18734 .47885 .18238 .47136 .17316 Mtetra
.47136 .17316 .47885 .18238 .49216 .1774 .48471 .16815 Mtetra
.664 .741 .907 r
.48471 .16815 .49216 .1774 .50554 .1724 .49813 .16311 Mtetra
.49813 .16311 .50554 .1724 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .21721 .34613 .20832 Mtetra
.34613 .20832 .35405 .21721 .36683 .21241 .35895 .20348 Mtetra
.35895 .20348 .36683 .21241 .37968 .20759 .37184 .19862 Mtetra
.664 .74 .907 r
.37184 .19862 .37968 .20759 .39259 .20275 .38478 .19373 Mtetra
.38478 .19373 .39259 .20275 .40556 .19788 .39779 .18882 Mtetra
.39779 .18882 .40556 .19788 .41859 .19299 .41086 .18388 Mtetra
.664 .741 .907 r
.41086 .18388 .41859 .19299 .43169 .18807 .424 .17892 Mtetra
.424 .17892 .43169 .18807 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17816 .45047 .16892 Mtetra
.45047 .16892 .45807 .17816 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18882 .38996 .17968 Mtetra
.38996 .17968 .39779 .18882 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19109 Mtetra
.29626 .19109 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13556 Mtetra
.44069 .13556 .44846 .14509 .46194 .13993 .45422 .13036 Mtetra
.45422 .13036 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .2161 Mtetra
.19976 .2161 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19109 .28798 .18197 Mtetra
.28798 .18197 .29626 .19109 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13556 .43285 .12593 Mtetra
.43285 .12593 .44069 .13556 .45422 .13036 .44641 .12069 Mtetra
.44641 .12069 .45422 .13036 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10479 Mtetra
.48753 .10479 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .2161 .19115 .20721 Mtetra
.19115 .20721 .19976 .2161 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18274 Mtetra
.25404 .18274 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16273 Mtetra
.30546 .16273 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14232 Mtetra
.3579 .14232 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10479 .47978 .09488 Mtetra
.47978 .09488 .48753 .10479 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .2271 Mtetra
.10878 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18844 Mtetra
.20751 .18844 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18274 .24553 .17355 Mtetra
.24553 .17355 .25404 .18274 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16273 .2971 .15335 Mtetra
.2971 .15335 .30546 .16273 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01m0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
08<0ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<00000Q@2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0030000003oool0oooo04P0
oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P00001F0:Vmj0<0ZKgW1`2Y_NP30:VmibD0ZKgX
00<000000:Vmj02Y_NP0702Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@000000000
00000000000e08oooa<0oooo00@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0:Vmj0160:Vm
j0D0ZKgW1P2Y_NP60:Vmi`@0ZKgX1P2Y_NL20:Vmj0<0ZKgW7`2Y_NP00`000000ZKgX0:Vmj00M0:Vm
j0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj000000000000480ZKgX0`2Y_NL70:Vmj0<0
ZKcW1@2Y_NL60:Vli`D0ZKgW1@2Y_>L;0:Vmiah0ZKgX00<000000:Vmj02Y_NP07P2Y_NP00`000000
oooo0?ooo`160?ooo`00G`3oool400000480ZKgX1P2Y_NL40:Vmj0H0ZKcW0P2Y_NL30:ZkiPH0ZKcW
0P2Y_NL30:ZkiPD0ZKcW1@2Z_>L;0:VmiaP0ZKgX00<000000:Vmj02Y_NP07P2Y_NP00`000000oooo
0?ooo`160?ooo`00G@3oool0102Y_NP000000000000000100:Vmj0X0ZKgW2P2Y_>L60:ZkiPD0ZKcW
1P2Z^nH20:Vli`<0Z[_V1@2Z_>L20:Vmi`<0Z[cW1P2Y_NLG0:Vmj0030000002Y_NP0ZKgX01l0ZKgX
00<000000?ooo`3oool0A@3oool005/0oooo0`0000110:Vmj0<0ZKcW1`2Y_NL30:VkiPD0ZKcW1@2Z
^^D60:ZkiPD0Z[[U2`2Z^nH:0:Zli`<0ZKgW0`2Z_>LF0:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<0
oooo0000003oool0A@3oool005P0oooo0`0000120:Vmj0H0ZKcW102Y_NL60:VkiP80ZKcW0`2Z^><5
0:Zji@<0Z[_V0`2Z]n850:Zji@D0ZkSS1@2Z^nH50:Zji@`0Z[cW5@2Y_NP00`000000ZKgX0:Vmj00P
0:Vmj0030000003oool0oooo04@0oooo001E0?ooo`030:Vmj000000000000440ZKgX2P2Y_>L50:Vj
iPD0ZK_V1P2Z^><50:Zji@H0Z[OR0P2Z^^D30:^dg`D0ZkSS0P2Z^nH30:^ghPD0Z[[U1@2[^nD60:Zl
i`D0Z[gW402Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0
000000<0ZKgX0000002Y_NP0?P2Y_NP:0:Vli`<0ZK[U1@2Y^^H50:ZfhPH0Z[SS1@2[]=l50:ZghPH0
ZkCO102[^><60:^ghP80Z[[U0`2/^>850:^ki@<0Z[cW0`2Z^nH50:Zmi`D0ZKgW2P2Y_NP00`000000
ZKgX0:Vmj00R0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000@P2Y_NP:0:Vli`H0ZK[U
0P2Y^^H30:Vdh@D0Z[KR0`2Z^><30:^ag@D0ZkCO0P2Z]n830:bag0D0ZkCO1@2]/md50:^ghPH0[;SR
1@2[^nD60:ZkiP80Z[gW0`2Z_>H50:Vmi`T0ZKgX00<000000:Vmj02Y_NP08P2Y_NP00`000000oooo
0?ooo`120?ooo`00CP3oool300000400ZKgX2P2Y_>L50:Vii@D0ZK[U1P2Y]>450:ZfhPD0Zk7M1@2[
]=l60:bag080ZkCO0`2^/MX50:fcg@80ZkOR0`2^]=d;0:bhhPD0Z[_V1P2Z_>H40:Vmi`T0ZKgX00<0
00000:Vmj02Y_NP08`2Y_NP00`000000oooo0?ooo`110?ooo`006@3oool00`3ogi`0B01d0;ooo`02
0?ooo`050?ooS`0e00000000000DG`34ool0:@3oool200000440ZKgX0`2Y_NL70:Vli`P0ZKWU1@2Y
/n060:Vdh@80Z[KR0`2[[m/50:^ag@80ZkCO0`2][mT50:bag0D0[[7J1@2]/md60:jdg@80[;SR0`2_
]Md60:bhhP80Z[_V0`2/^^<50:ZliPD0Z[cW202Y_NP00`000000ZKgX0:Vmj00T0:Vmj0030000003o
ool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@001AOa03oool0a5lD000e
SbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX03`0ZKgX1P2Y_NL40:Vli`P0ZKWU0`2Y/]l50:Vc
h0D0ZKCQ1P2[[m/40:^ag@H0[JoI0P2//M`30;2af@D0[[7J0P2]/md30;6bf@D0[[CM1P2_]Md50:bh
hPH0[;[S0P2Z_>H30:^ki@D0Z[cW1@2Z_NL20:Vmj0030000002Y_NP0ZKgX02@0ZKgX00<000000?oo
o`3oool02P3oool01@3ookl0M00000000000B9`0gooo0340oooo000I0?ooo`0;0?oOW01807@0_ooo
0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool08P3oool00`2Y_NP00000000000100:Vmj0X0
ZKgW1P2Y^^D40:Vii@H0ZK;O1@2Y/n050:Z^fPD0ZjoK2P2][mT50;2af@D0[[7J1P2a/]T20:jdg@<0
/[CJ1P2_]Md50:nfgPD0[;[S1P2[^nD20:Zli`<0ZkcV1@2Z_NL20:Vmj0030000002Y_NP0ZKgX02@0
ZKgX00<000000?ooo`3oool0203oool01P3ooml0W4P004RLg`3oool0gia8001d_c40oooo000=0?oo
o`030?oOW0180000000000<0000000<0001d0;ooo`3oool00`3oool02`3ogi`0B01d0;ooo`3oool0
omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo0`0000130:Vmj0D0ZKgW1@2Y^^H60:Vji@@0
Z;;O1P2Y/]l20:Vch0<0ZJgJ1@2Z[]X20:^_f`<0[K7K1`2][mT30;6hgPD0/;7I0P2^/MX30;>gg0D0
/K;I1P2b]=X30:neg@<0/kGJ1@2_]]h50:nhh0D0Zk_U1P2[_>H40:Zmi`80ZKgX00<000000:Vmj02Y
_NP0902Y_NP00`000000oooo0?ooo`080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`
0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0
oooo0`0000160:Vmj0<0ZKgW0P2Y^nH50:VjiP<0ZK[U0`2X/n040:Rbg`D0ZK;O1@2Y[MX50:Z^fPD0
[K7K1@2][mT50;6hgPD0/;7I1P2c]m`20;6bf@<0]K_N1@2b]=X70;>efP80[kKN0`2c]m/50:nhh080
Zk_U0`2]^^<50:^liPD0Z[gW00<0ZKgX0000002Y_NP09P2Y_NP00`000000oooo0?ooo`070?ooo`07
0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0
omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0oooo0`00001:0:Vmj0D0ZK_V1@2Y^^H50:Rch0D0
Z;;O1@2X[=X50:V]fP80ZZkJ0`2]]=h50:faf`80[JoI0`2aa>P50;6hgP80/;7I0`2ca^P50;>gg0H0
]K_N0P2b]=X30;NmgPH0/kGJ1P2c]m/40:nhh0H0[K[S0P2[_>H30:bli@D0Z[gW00<000000:Zmj02Z
_NP00P2Z_NPT0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0
W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3o
a5l0500e08ooo`0I0?ooo`800000B@2Y_NP50:Vli`D0ZK_V1@2X]>450:Rch080Z;;O0`2W[=X50:R/
fP@0ZJgJ1P2]]=h40:faf`H0/LCX102a^=h60;?6j080/kOL0`2ad_450;FkgPH0]kgN102c]MX20;Rl
g@D0/kOK1@2b^=d50:fjh`H0[;cU102Z_NL00`000000Z[gX0:Zmj0030:Zmj2<0ZKgX00<000000?oo
o`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool001P0oooo00/0okmd
0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<00000B@2Y_NP80:Vl
i`80ZK_V0`2X]N<50:Rdh@@0Z;?P1@2W[=X50:R/fPD0[;SR1@2]]=h50:cFmPD0/LCX1@2Vh?/50;?6
j0H0/M;a0P2e^mh30:oFm0H0]kgN0P2c]MX30;Rlg@@0/kOK0P2h^]/50;:hg@D0/;[Q1@2/_>D40:Zm
i`030000002Z_NL0Z[gX00<0Z[gX902Y_NP00`000000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0503oool3000000030:Vmj0000000ZKgX04L0ZKgX2P2Y_>L60:Reh`@0Z;CQ1@2V
Zm/50:N/fP80Z:cJ0`2[^^D50:bhhP80[KCN0`2Mi?`50:cFmPH0Smgn102Vh?/508kMoPD0/M;a1P2_
e_@50;NmgPH0^;cM0P2c]m/40;Rjf`80/[SM0`2f^]`50;2jh@D0[KcT0`2Z_NL00`000000Z[gW0:Zm
i`040:Zmib@0ZKgX00<000000?ooo`3oool0103oool01P3ooml0W4P007Boo`3oool0gia8001d_c40
oooo000d0?ooo`030:Vmj0000000000004T0ZKgX1@2Y_NL50:Vli`D0Z;OT1@2X]N<50:F/g0D0YZ_K
102W[=X60:^ji@@0[;SR1P2Mi?`608k<o@D0VkS/1@21^_T408kMoPH0Q<ko1@2_e_@50;7Bl@D0^;cM
1P2h^]/60;Jjg080/;[Q0`2c^ml50:fli080ZkgW00<000000:^mi`2[_NL01@2Z_NLS0:Vmj0030000
003oool0oooo00D0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool3000004`0ZKgX
1@2Y_NL50:Rii@D0Z;OT0P2X]N<30:F]g@D0YJcL102VZm/50:Vji@D0Zk[U1P2DiO`509:jlP<0S/cm
0`2Y_NP509^hk0D0ZKgX1P25[_0408C>o`D0OlKn1@2ad_420;Rlg@<0]/WY102h^]/20;W1h0D0][[L
1P2c^ml20:fli0<0[kcS00<0ZkgW0000002[_NL00P2[_NL50:Zmib<0ZKgX00<000000?ooo`3oool0
>P3oool00300oooo0P0000000`2Y_NP000000:Vmj01=0:Vmj080ZKgW0`2Y^nH50:Rii@@0Z;OT1@2U
[Md50:F/g0D0YkOT1@2Y^^D609OUo0H0Xk_Z102B^_860:Vmj0<0VkS/1`2Y_NP308F^l0<0ZKgX1@2<
/Nl407o6oP@0/M;a1P2fbNT20;Rjf`@0^L7P0P2f^]`30;Vmg0D0/k_O1@2__><2000000<0ZkgW1P2Z
_NLS0:Vmj0030000003oool0oooo03T0oooo000/0?ooo`040:Vmj0000000000000000580ZKgX1P2Y
^nH40:Rii@D0YJoO1@2U[Md20:F/g0<0YK;Q1@2W]n@20:Vji@D0V^Kl1@2Y_NP50:>kjQX0ZKgX0P2<
/Nl30:Vmj0@0QJk`1023cOl50;K9j@H0^L7P1P2i_M`20;>kg`<0][cN00L0[kcS0000000000000000
0:nlh`2/_NH0000000<0[;gV1@2Z_NLS0:Vmj0030000003oool0oooo03T0oooo000[0?ooo`800000
DP2Y_NP50:Vli`D0ZK_V102V/^450:F_g`@0YJgM1P2U/^440:Ngi0D0V^Kl;02Y_NP408F^l0@0Plgo
1@2LeO`30;W1h0<0]<SY1@2i_M`30;JlgP<000000P2__><30;6mh`030000002/_NH0[;gV0080[;gV
1@2Z_NLS0:Vmj0030000003oool0oooo03P0oooo000Y0?ooo`800000DP2Y_NP30:Vmi`D0ZKcW1@2W
]^@40:Jbh@D0YJoO102S[Mh60:Fbh@H0W>Sk<`2Y_NP507BUl0@0W=Gl1P2db>T20;Vmg080^l3N0`00
00030;JlgPH0/KgS00<000000:bmiP2]_^H00P2]_^H40:Zmib@0ZKgX00<000000?ooo`3oool0=`3o
ool001d0oooo00D0oono07@00000000004RL0=ooo`070?ooo`800000D02Y_NP60:Vmi`80ZKcW0`2X
^NH50:Nfi0@0Y[;Q1@2RZ]d40:>]gP<0YK;Q102QiO`h0:Vmj0D0VkS/101c/_T50;C8j@80^l3N0P00
00020;_0gP80][cN0`2i_]h50;6mh`030:fniP000000[KkV0080[KkV1@2Z_NLS0:Vmj0030000003o
ool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1`3oool00`000000oooo
0000001@0:Vmj0D0ZKgW1P2X^NH40:Nfi0D0XJ[M1@2RZ]d40:>]gP@0XNGl0`2`aNTh0:Vmj0D0VkS/
101c/_T20;C8j@040:;;m@0000000000000000@0^l3N1@2i_]h30;6mh`<0/koS00@0[KkV0000002]
_^H0[KkV1P2Z_NLS0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`050?ooo`8000000P3oool00`000000ZKgX0:Vmj01>0:Vmj0D0Z;_W1@2X^NH5
0::]g`D0XJ[M102RZ]d60:ODm`H0/<GY>02Y_NP209^hk0<0ZKgX0`1dYO03000000<0X/_e0P2k`=h3
0;W3hP@0^KkN1P2c_n<00`2]_^H000000:fniP020:fniPD0Z[gW902Y_NP00`000000oooo0?ooo`0e
0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?oo
o`020?ooo`030000002Y_NP0ZKgX04`0ZKgX0P2Y_>L50:Rki`80Z;WV0`2T/^840::]g`D0XJ[M1@2V
`Nd30:ODm`<0_MW^1@2`aNTm0:Vmj0<0000000<0M:G`0:;;m@2RboD00`2RboD60;W3hP80^KkN0P2k
`Mh30;>oh`<0]<3S00<0[KkV0000002]_^H00P2]_^H50:Zmib<0ZKgX00<000000?ooo`3oool0=@3o
ool001`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool0
0`3ooom<0:Vmj0D0ZKcW102X^nL50:BbhPD0XZgO0P2QZ]d30:6bi0D0Y/7]1P2mfNhn0:Vmj0<00000
00<0ZKgX07BUl01dYO000P1dYO0508?1n`D0^L?R1@2k`Mh60;C0h`030:fniP000000[[oV0080[[oV
1@2Z_NLS0:Vmj0030000003oool0oooo03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vmj0190:Vmj0D0ZKcW102V]nD50:BbhP@0
XZgO1P2Q/^@20:K1k@@0]nSf?`2Y_NP3000000D0ZKgX102</Nl508?1n`80^L?R0`2e`nD20;_1gP<0
_<;O1@2d`><20:joiP040000002^_nH0[[oV0:joiP80Z[gW0`2Z_^PS0:Vmj0030000003oool0oooo
03<0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000:Vmj02Y_NP0B@2Y_NP50:RjiP@0Y[OU102T/^8509j[g`D0XK;T1@2gj?HK
0:Vmj0D0Z;3N1@2Y_NP50:JSda<0ZKgX0`0000090:Vmj0@0Xk_Z101/Yo@50;G3i@H0_<;O0P2d`><3
0;K2h`030:joiP000000[[oV0080[[oV1P2Z_^PR0:Vmj0030000003oool0oooo03<0oooo000L0?oo
o`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?ooo`070?ooodH0ZKgX1@2Y
_>L50:RjiP@0Y[OU102NZ]l509j[g`<0XK;T102_h_PK0:Vmj0<0YZCC1@2X/=h50:2<_PD0YZ?C1@2T
V//:0:Vmj0<000003@2Y_NP40:>kjP@0K:Od0P2e`nD30;31iPD0_<;O1P2f`^<00`2^_nL000000:jo
i`020:joi`D0Z[kX8`2Y_NP00`000000oooo0?ooo`0b0?ooo`007@3oool01@3ookl0M00000000000
B9`0gooo00H0oooo00<000000?ooo`3oool0203ooom60:Vmj0D0ZKcW102X^^H50:6_hP@0WZ[O1@2N
Zml40:oRn0<0]lgZ602Y_NP60:JTd`80Z;3N0`2VS;T40:2<_P@0YZ?C0P2aU[`50:BJb`D0YZ?C0P2Y
_NP200000100ZKgX102S^nX406bWm0H0/<7V0P2l`]l30;c4h0<0]/;S0`2f`n@00`2^_nL000000:jo
i`020:joi`D0Z[kX8P2Y_NP00`000000oooo0?ooo`0b0?ooo`009`3oool00`000000oooo0?ooo`0:
0?ooodH0ZKgX102Y_>L50:Bei@D0XJoR102NZ]l60:O2k@H0]lgZ4`2Y_NP:0:JTd`D0YXbi1@2PS;h2
0:JSd`<0/IJl102TV//20;^Q_P<0YZ?C0`00000G0:Vmj0@0JYo`1@2``NH60;c4h0H0]/?T00<00000
0:joi`2]_nL00P2]_nL50:Znj280ZKgX00<000000?ooo`3oool0<@3oool002L0oooo00<000000?oo
o`3oool02`3ooom60:Vmj0@0YkWW1@2T]ND40:6_hPD0WZoS0`2W`^d30<GYk`<0]lgZ4P2Y_NP40:R`
gPL0YZCC0`2XS[X40:J<^@D0X8bn1P2aU[`20:BJb`<0^j6n0`0000000`2VXm<0]j?50;NSa@0H0:Vm
j0@0JYo`0P2``NH30:foiP@0_<CP0P2maN450;K3i0030:foi`000000[KoW00<0[KoW1@2Z_^PR0:Vm
j0030000003oool0oooo0300oooo000W0?ooo`030000003oool0oooo00`0oooo@@2Y_NP50:Rli`@0
YkWW102T]ND509^Zh@D0WZoS1P35jNlE0:Vmj0@0Z;3N102VY=<50:R>^PD0YXbi0`2PS;h20;^P_PD0
/IJl00<0Y9[;0;^Q_P0000000P0000000`2kXKh0YZ?C0:JSd`040;NSaAP0ZKgX0`1]XO060:foiP80
_<CP102maN420;K3i0<0]LCU00<0[KoW0000002]_nL00P2]_nL50:Znj280ZKgX00<000000?ooo`3o
ool0<03oool002L0oooo0P00000>0?oood40ZKgX1@2X_>L40:Nii`@0WJgR1@2KZ^4209j_h`@0/];`
6P2Y_NP40:R`gP80YZCC0P2ORK`40:R>^PD0YXbi0P2PS;h30;^P_P@0/IJl0`0000040;^Q_PH0]j?5
1@2X/=hD0:Vmj0<0KJ7`1@2]_nH60;g5h@H0]LCU00<0[KoW0000002]_nL00P2]_nL40:Znj2<0ZKgX
00<000000?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3ooom10:Vmj0@0Z;cW1@2R
]>D409f]hP@0Vj[Q1@2bd_030<OOjQP0ZKgX102X/=h409n9_0D0Z8jj102VS;T60;^P_P<000000P34
Zl450;^Q_P030<fb`02gXlD0]j?500<0]j?500<0d;K00:R`gP2X/=h00`2X/=hC0:Vmj0@0KJ7`1@2]
_ND30;g5h@<0_LOR0`2ea>D30;C4iP040000002]_nL0[KoW0:foi`D0Z[gX8`2Y_NP00`000000oooo
0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0?0?oood00ZKgX1@2V^NL50::di@@0WJgR1P2Q
]>H60<OOjQ<0ZKgX1@2GQl0409B2_0@0WhVl102XS[X30:J<^@80]:750P2kX;h300000080/IJl0`34
Zl440;^Q_P80cK;0102gXlD30=2f`080Z;3N0`2c/]LC0:Vmj0@0KJ7`1@2]_ND60;g7hPH0]<CV00@0
00000:foi`2/_nP0[;oX1@2Z_NPR0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`8000004@3o
ool00`000000ZKgX0:Vmj00i0:Vmj0D0Z;cX102V^NL40::di@D0VJ[R102Q]>H20;gHk@<0amoZ4@2Y
_NP50:JSd`@0UhO0102DP[`409n9_0@0Z8jj0P2VS;T20;BQa@<000000`2kX;h60<B[`@80^j6n103=
//020;NSa@@0d;K01P2c/]LC0:Vmj0@0KJ7`0P2]_ND30;2ni0<0_LOR0`2lb><50;C4iP030:boj000
0000[;oX0080[;oX1@2Z_NPR0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool0
0`000000ZKgX0:Vmj00i0:Vmj0D0Z;cX102Q]>H409^]i0D0VJ[R0P2Q]>H40;gHkA@0ZKgX102VXm<4
09N7`0@0U8:l1@2ORK`30:R>^P040;BQa@000000000000000080]:750`2kX;h20;b_c0D0a:_100<0
^j6n0<fb`03=//000`3=//000`2gXlD0d;K00=2f`0030=2f`0030=W0`02c/]L0/k;G0080/k;G0P34
aM/C0:Vmj0<0Kic/1P2`_^@60;c8h`D0//CW00@0[;oX0000002/_nP0[;oX1P2Z_NPR0:Vmj0030000
003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo
0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0
oooo01<0oooo00<000000:Vmj02Y_NP0>@2Y_NP20:Rlj0<0Y[[W102Q]>H409^]i0@0VJ[R102mf>d3
0<?Jja<0ZKgX102VXm<509N7`0@0U8:l102ORK`20:R>^P8000001@2dXLD20;^P_P<0_:o<1@34Zl46
0<fb`0D0d;K00`3I`<020;>be`@0a<GK4`2Y_NP306nLk0<0/;kT0`2e`N<30;c8h`<0^lWU102ba>L0
0`2[_^P000000:^nj0020:^nj0D0Z[gX8P2Y_NP00`000000oooo0?ooo`0:0?ooo`050=nLB0000000
00000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oO
W0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?oo
o`3oool0503oool00`000000ZKgX0:Vmj00h0:Vmj0H0Y[[W102Q]>H309^]i0H0XkKV1P33f^/C0:Vm
j0@0YZ?C102GQl0409B2_0<0WhVl0`0000020:fPb`D0]:751P2l[l`30<B[`@80`kK=103=//020<fk
b@<0d;K0103I`<060<C5fa<0ZKgX101_W>`60;G1h`D0^lWU0P2ba>L30;32j0030:^nj0000000ZkkX
0080ZkkX1@2Z_NPR0:Vmj0030000003oool0oooo00P0oooo00L0okmd0018W03Oool0oooo0?oog`2L
B7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oO
W0180000M;oo00P0oooo00<0_g@007Boo`3oool01@3oool2000001H0oooo=P2Y_NP50:Rlj0D0Y[[W
1@2J[^H309R[i0<0XkKV1@31dnPF0:Vmj0@0YZ?C102GQl0409B2_0<000000P2TW<d40:fPb`80]:75
0`2d/=D50;b_c080a:_11033]/d20<fb`0@0cK_900<0d;K00=W0`03I`<000`3I`<000`3Lb<D0a<GK
0<C5f`020<C5f`80bMSU3P2Y_NP50:>kjP@0O9WS0`2e`N<30;[6i0@0^lWU1P2``^P00`2[_^P00000
0:^nj0020:^nj0D0Z[gX8P2Y_NP00`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo
00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0
oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G0?ooocH0ZKgX102X_>P50:6fi`D0
VZkV0`2HZn@60<7Cj080amoZ4`2Y_NP308V<d0<0O7W4102GQl001@2KULd00000000000000000ViG=
00@0Y9c=102]X</50;B`e@D0_:o<1P33]/d60<fkb@D0fL300`3Lb<D20<C5f`@0bMSU3P2Y_NP50:>k
jP@0O9WS1@2ja^@20;_9i@<0^LWW1@2``^P00`2[_^P000000:^nj0030:^nj080Z[gX902Y_NP00`00
0000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo0?oo
o`3ookl0M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO09a8
B02Lgol01P3oool00`000000oooo0?ooo`0H0?ooocH0ZKgX102V^nP50:6fi`@0VZkV1@2R]>D30<7C
j0@0amoZ4P2Y_NP308V<d0@0O7W400@0SXW90000000000000000102KULd50:BLc@80[J3;0P2^/=X5
0;B`e@80_:o<0`2i^MT40<>fc@80_kgG103=^lT20<c2d@<0fL30103Lb<D40<WHi@<0^M7/3P2Y_NP4
0:>kjPD0TJGS102ja^@60;W9i`D0[/7X00<0ZkkX0000002[_^P00P2[_^PW0:Vmj0030000003oool0
oooo00H0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo01`0oooo00080?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`070?ooo`050?oo_`1d04P0W=oo0?oo_`1d00000`0000000`1d
_ol0oooo0?ooo`040?ooo`8000006`3ooola0:Vmj0D0Z;cX102V^nP40:6fi`D0UZ_U1@2R]>D60<OO
jQ<0ZKgX0`29S=00101lNL@0000000000000000308j9b@D0ViG=102TW<d50:j`fP@0];3E1P2i^MT2
0<>fc@<0_kgG0`3=^lT40<c2d@030=W0`03Lb<D0g<S500<0g<S50P3QdLP50;WAk0l0ZKgX102</Nl5
096Uh`80^/KT0P2mbnD30;W9i`<0]LOX1@2^`NP00`2Z_^P000000:Znj0020:Znj2L0ZKgX00<00000
0?ooo`3oool01@3oool00`3ookl0M000000000020000000307Boo`3oool0oooo01/0oooo00080?oo
o`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0
_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo01/0oooo<@2Y_NP50:Rlj0@0Y[_X
102J/NL509J[i@80X[CU102lbN@G0:Vmj00408V<d00000000000000000<0O7W4102>RLT409^Ec@D0
Z:kL1@2^/=X20;B`e@80/K[P1@2i^MT60;nme`030<fkb@3<`]40c<;A00<0c<;A1@3Lb<D30>7Ab003
0>SMb02idN`0^M7/0080^M7/402Y_NP408bak`@0TJGS1@2mbnD60;G7j0D0[;oX00@0Z[kX0000002Z
_^P0Z[kX9`2Y_NP00`000000oooo0?ooo`050?ooo`030?oog`2LB4P0W=oo0200oooo00080?ooo`06
0?oog`2LB000M;oo0?ooo`3OW4P007Bo103oool02P3ookl0M01809cOo`3oool0omnL04P0B02Lgol0
oooo0;md001d_ol90?ooo`030000003oool0oooo01`0oooo<@2Y_NP40:Rlj0D0X[SX102J/NL409J[
i@D0_<WT0P3>g><C0:Vmj00406n8f`0000000000000000<0RHc@0`1lNL@408j9b@D0XJWL1@2X[]`4
0:j`fPD0/K[P0P2i^MT30;Bmh@D0_kgG1@3<`]420<_7eP<0g<S50`3QdLP30>SMb1<0ZKgX102</Nl5
0:Fdi080_L_U0`2mcNL30;G7j0<0/LGY1@2/_nP010000000Z[gX0:Zmj02Z_NPW0:Vmj0030000003o
ool0oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0oono07@00000000004RL0=oo
o`050?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P00000000000000000001d0;oo
o`D0oooo00<000000?ooo`3oool07@3oool`0:Vmj0D0YkcX1@2R^>P309Zai`D0W;3V0`2lbN@40<kL
ha40ZKgX0P00000306n8f`<0KGO<0`1lNL@509NOf@D0XJWL102X[]`50:bji0@0/K[P1P2d_N420;nm
e`<0_<7N0`3<`]440<_7eP040=c8a@3QdLP0hM780>7Ab0@0j=g800<0jO;?0:Vmj02Y_NP04@2Y_NP4
07bMi`@0YKCT1P2mcNL60;75j@80[;oX0`2[_^P010000000Z[gX0:Zmj02Z_NPV0:Vmj0030000003o
ool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo
<@2Y_NP40:Nlj0D0W;GY0`2D[NL509b`iPH0c]cS3P2Y_NP300000080ZKgX0`1_R=/406egc0<0QhkD
1@2GWmT40:6Yg0D0ZKWU1@2/^^@50:fmiP@0];gQ1P2l`Mh60<_7eP<0hM78103XgLP20>Wbca@0ZKgX
101lWNL20:Fdi080/l?V0`2mcNL30;[=j0D0/LGY1@2[_^P00`2Z_NP000000:Vmj00X0:Vmj0030000
003oool0oooo02H0oooo000U0?ooo`030000003oool0oooo01l0oooo<@2Y_NP40:Fjj@D0W;GY0`2D
[NL309b`iP@0[kgT1@2gcNX90:Vmj0<000000`2Y_NP307VZlP0304iZc`1_R=/0KhSK00<0KGO<1027
S]@409NOf@D0YKKT1@2Y^ND20:bji0<0Z[gW1@2]_NH40;2oi@<0_<7N0`2j`n440<_7eP<0c/gI103X
gLP20>Wbc`80bnS[3`2Y_NP509^hk0<0R9SL1@2c`nH60;[=j0D0[/;X102[_^P00`2Y_NP000000:Vm
j00Y0:Vmj0030000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo0200oooo;02Y_NP5
0:Rlj0@0YK[Y102L]NT409B]i`D0[kgT0P37b]d50;O=jPD0ZKgX0`0000070:Vmj080NJ[b0`1>J/l4
06egc0<0QhkD1@2O/><50:Ffi0@0ZKWU1P2Z_NL20:fmiP<0ZkkX102`_nD60;[3h@80blOF0`3>cMT2
0=CGf`80j=g80P3Yl/l40<_Xj`l0ZKgX102K^>`408RHg080/l?V0`2kcNP30;[=j0<0]LWY102^`^P5
0:Znj0030:Vmj0000000ZKgX02P0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?oo
ob`0ZKgX1@2X_>P40:Fjj@@0U[7Z102D[NP30:nmi0@0al[M1P2Y_NP3000000X0ZKgX0`1iZ_8304iZ
c`<0NHgJ102CXn0509n`h`@0YKKT1@2Y_NP50:Zmi`H0ZkkX0P2`_nD20:joiPD0^/?Q103>cMT40=CG
f`80jO;?1@3;j>/@0:Vmj0<0VkS/1028V=`60;_=j0D0]LWY1@2/_nP50:Znj0030:Vmj0000000ZKgX
02P0ZKgX00<000000?ooo`3oool0903oool002@0oooo00<000000?ooo`3oool08`3oool/0:Vmj0@0
Z;cX1@2Q^>T409JajP@0U:gX1@37b]d20<cAgP80ZKgX0`00000>0:Vmj00301ARf01iZ_80CV[?0080
CV[?101iSMX409>Sh0@0Wk3S1@2X_>P50:Vmj0D0ZKkY1@2[_^P50:joiP80^/?Q0`2ja^<20<k=f@@0
e=OK0P3NimX30>CkcQ<0ZKgX0`2K^>`50:Bci0<0^lgX0`2ld>T30;G9j@80/<GY1@2/_nP60:Vmj003
0000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0
903oool[0:Vmj0D0YkcX1@2Q^>T309JajPD0W[?W0`37b]d20<cAgP<000004P2Y_NP00`0DH]P0CV[?
04iZc`0204iZc`@0NHgJ0`2CXn050:Bhi`D0Z;cX2P2Y_^T50:Znj0@0[[oV1P2ja^<40=CGf`80g^OJ
0`3Tnlh20=KihQ<0ZKgX0`23U=`50:Bci0H0_=3Y1@2`aNT20:boj0<0Z[kX1@2Y_NP00`000000ZKgX
0:Vmj00W0:Vmj0030000003oool0oooo02<0oooo000T0?ooo`8000009P3oool/0:Vmj0@0YkcX1@2L
]^/4096_j`@0W[?W00D0c=7N00000000000000000<cAgP020<;Cia80ZKgX0P0DH]P305Mng@@0NHgJ
102L/NH50:Bhi`80Z;cX0`2Y_^P:0:Vnj@D0Z[kX102_`NL30;[6h`@0_/gU0`3NimX30>CkcP<0e_WR
4`2Y_NP408>Dg0D0]/WY0`2ld>T30;O=j`@0/<GY1P2Z_^P50:Vmj0030000002Y_NP0ZKgX02L0ZKgX
00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?ooob`0ZKgX1@2U^nT409bfj`@0TJo[0P2^
_>@2000000<0c=7N1032dnL>0:Vmj0@0UkO^00<004[:01ARf01GO]d00P1GO]d408JPi@@0W;7V102T
^>L60:Vnj080ZKkY0`2Y_^P50:Vnj@D0Z[kX102_`NL50;k=i@<0am[X0P3Tnlh20=KihQH0ZKgX1@2G
Y^050;K9j@D0]lg[1@2/`NT50:Znj0H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia8
0080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?ooobH0ZKgX1@2X_NP50:Fk
j@<0W;K[0`2@[n/3000000<0[[cT1P32dnL?0:Vmj0@0UkO^0P00B/X305Mng@@0QZ3U102L/NH40:Nl
j0/0ZKkX0P2Y_^T30:Vmj0D0Z[kX102aa>P30;k=i@<0am[X0P3BlnL20<3k_`80bnS[4`2Y_NP308fL
g@D0UjKP1P2kd^/40;77jPD0[<7Y1@2Z_NP60:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?oo
o`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`070?noM000B9`0
gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo9P2Y_NP50:Rmj0D0X[[Z
0P2G]>`3000000<0T:o[0P2^_>@40;g2g@@0/<GY3P2Y_NP409NgkP<004[:0P1OT>T408JPi@D0XKSY
102W_>P:0:Vnj0H0ZKgX0P2Z_^P30:_0j@@0/LCX1037f^P20=;ci`80`?^o103;j>/B0:Vmj0@0SIcM
0P2GY^030;75j@<0^m;[0`2hcn`40;77jPD0ZkkX102Z_NP60:Vmj0030000002Y_NP0ZKgX02L0ZKgX
0P00000Q0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0203oool00`2oM000
M;oo0?ooo`050?ooo`800000;03ooolV0:Vmj0<0Z;gX0P2X_>P30::jjP<000000P2G]>`4092_j`D0
_L;M0P38aML40;35j@l0ZKgX0`1iZ_800`00A/<004[:001:bP0205n@j@@0Sjg[1@2Q^>T40:Rmj@D0
ZKkX2P2Y_NP60:_0j@80/LCX0`2fc^`30=;ci`030<3k_`3;j>/0bnS[00@0bnS[4P2Y_NP408fLg@H0
/LGY1@2hcn`50:g2j@D0ZkkX2P2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01l0
oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo
00D0oooo00<000000?ooo`3oool0;03ooolV0:Vmj0@0Z;cX0`0000020::jjP@0T[;]102D/^/30;g2
g@@0b<GG4`2Y_NP307VZlP8004K30`1OT>T408n]j`D0Xkc[102X_NT50:Vnj0D0ZKgX1@2Y_^T50:_0
j@@0]/k/0`2ni?80102dnml0XNnb0:7_/P2Qkk8C0:Vmj0@0TicJ102CXMd30;75j@<0^]?]0P2hcn`3
0;78j`D0[L;Y1@2Z_^P:0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07`3oool0
00`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo
0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3ooolV0:Vmj0<0000000<0Z;cX09nij`2O
^N/00`2O^N/409:bk@@0U;;[1@38aML20<_5eA<0ZKgX0`1iZ_801000;9h004K305fMlP1MWO8509:f
k`D0Xkc[102X_nX50:Vnj0X0ZKkY1P2^an`40;kTlP030;Ckg`2Y_NP0ZKgX01H0ZKgX102CW=X409>Q
g@D0^]?]1P2ab>/20:g2j@<0ZkoX102Z_^P:0:Vmj0030000002Y_NP0ZKgX02L0ZKgX00<000000?oo
o`3oool07P3oool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono
07@0000000000P0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo8P2Y_NP3
000000030:Vmj02W_>T0YkcY00<0YkcY102O^N/409:bk@@0VkK[0`38aML40<_5eA<0ZKgX0`1iZ_82
000/WP80GIgb1@2B]^l50:>ok@@0Z;oZ0`2Y_^P20:VojPD0ZKkY1@2Za>`30:k7k0<0/]Sd0P2ni?83
0;WAk1L0ZKgX102CW=X50:o6j`<0^]?]0P2gd>d50;78j`H0ZkoX0P2Z_^P<0:Vmj0030000002Y_NP0
ZKgX02L0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00<0oooo00<0oooO09a8B02Lgol02@3oool200000340oooo7P2Y_NP3000000D0ZKgX1@2W
_>T409fik0@0Sk;^102K]^/60<_5eA@0ZKgX102G]nh00`00;9h0BJ7f04VQmP0508nlm0D0Xko]102X
_nX50:VojP80ZKkY0`2Y`nd50:[4k0D0/]Sd00<0YoCa0;WAk02idN`00`2idN`F0:Vmj0D0V:KO1@2_
a^/50;O@k@D0[L;Y1@2[_nP?0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07@3o
ool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00P0oooo
00<000000?ooo`3oool0<@3ooolK0:Vmj08000002@2Y_NP50:Jlj@@0WKW/102?/^h40:6ijP<0blGE
0`39a=DH0:Vmj003001Id@19XOH0BJ7f00D0Skcd102S_nd50:O1k@@0ZKoZ1P2Y`nd60:_Bm0<0YoCa
00@0^nOd0;WAk02idN`0^M7/4@2Y_NP50:VbgP<0SiCD1@2HY]l50;SEk`D0/<O[1@2]`^T50:Znj0l0
ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M000
00000000B9`0gooo00D0oooo00H0gia800000000000000000000M02oool50?ooo`030000003oool0
oooo0380oooo5`2Y_NP3000000`0ZKgX1@2V_>T309fik0D0SK;_102Q^NX60<W4eAP0ZKgX0P00FM40
0`0<SN40Skcd08nlm00208nlm0D0WlCb1@2W`Nd40:O5k`<0ZL?]0`2WdOH30:_Bm0@0Vnch0`2kio@D
0:Vmj0@0ZK;N102?U=@209RVg`<0/Lg^0`2heNl20;C?kPD0/<O[1@2[_nP40:Znj0l0ZKgX00<00000
0:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool2000003@0oooo4`2Y_NP30000
0100ZKgX1@2U_>T309^hk@D0SK;_0P2Q^NX20:FljP@0bLCE0P39`]@H0:Vmj0<0NJ[b1021`_`509o4
lPD0XlSc102WaNl60:OAmP80Vnch102Nh?dH0:Vmj0<0ZK;N102?U=@60;7=kPD0]<o^1@2/`NT40:^o
j1@0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000
oooo0?ooo`0d0?ooo`l0ZKgX0`00000D0:Vmj0D0YKcY0`2K^>d408fbk`D0YKcZ0P39a=D40<W2e0D0
ZKSS4`2Y_NP207VZlP030:Vmj021`_`0PL;l0080PL;l1@2AcO`50:?8l`D0X=?j102:i_P208_3nQ`0
ZKgX0`2Y/]h50:6diP<0/Lg^0`2feO020;C?kP<0[lK[1@2/`NT40:Zmj1@0ZKgX00<000000:Vmj02Y
_NP09P2Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000
002Y_NP0ZKgX00P0ZKgX0`00000H0:Vmj0@0YKcY1@2I^>d308bcl0D0YKcZ1039`]@20<W2d`D0ZKSS
602Y_NP205>Gl0030:Vmj02AcO`0TLgl0080TLgl1P2>f?l506SIja`0ZKgX1@2MVm43096He`D0XKCV
1@2feO060:o6j`D0Z[kX102Z_NPD0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool0
303oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool00280oooo
00<000000?ooo`3oool0=`3oool60:Vmj0<000006`2Y_NP50:FljPD0VKS]0`2</o050:Fmj`80bL;D
1039`]<50:f`fAd0ZKgX0P1jZ_8R0:Vmj0D0Z:WG102MVm44096He`H0/mCa102bc>d30:o6j`<0Zl3Y
102Z_^PH0:Vmj0030000002Y_NP0ZKgX02H0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3o
oml0W4P004RLg`3oool0gia8001d_`@0oooo000Q0?ooo`800000>P3oool20:Vmj0<000006`2Y_NP5
0:Rmj0@0YKcZ1@2I^Nh308bdl@D0YKg[1039`]<20<S3ePD0[K3I?@2Y_NP40:Vgh`D0Z:WG102MVm42
096He`80ZlW_0`2ce?430;?Bl0@0//c]1P2[`>T20:Znj1X0ZKgX00<000000:Vmj02Y_NP09P2Y_NP0
0`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool00240oooo00<000000?ooo`3oool0>03oool3000001l0ZKgX1@2X_NP40:FljPD0
VKW^0`2<]?450:6nkP80bL;C1038`mH30:f`f@80^[GE?@2Y_NP40:Vgh`@0Z:WG102MVm450:_9k`D0
/m;`1@2]`nX50:_0jAd0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0:0?ooo`0;
0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<0
00000?ooo`3oool0=P3oool2000000<0oooo802Y_NP50:Rmj0@0YKcZ1@2J^Nh308bflPD0XKk^1P38
`mH50;Zee@D0ZK;O=`2Y_NP40:Vgh`D0VjCK102Q]^L60;?GlP@0[/O/1@2]`nX50:Znj1`0ZKgX00<0
00000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@0
04RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo0P00000d0?ooo`<000001P3ooolP0:Vm
j0D0Z;gX102U_>X509ZikP<0S;Kb1@2I_O430<S3eP<0_/GO0`2j]MD20<Fmd`D0ZK;O<`2Y_NP40::J
c@@0VISA1@2KY=/20:6fi`80/=Kd0`2ceo830;3<kP@0[/O/1@2Z_nP40:Znj1d0ZKgX00<000000:Vm
j02Y_NP09P2Y_NP00`000000oooo0?ooo`080?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0<03oool3000000T0oooo
9P2Y_NP40:FljPD0W;[]0`2=]o8509Vml@H0_/GO00<0^[GE0<Fmd`35_M<00P35_M<20:Vbg`<0/J_B
<02Y_NP30:JMc@<0XY[=1@2IV=4409^Tf`D0/=Kd1@2`c>h50:_0j@D0Z[oX8@2Y_NP00`000000ZKgX
0:Vmj00U0:Vmj0030000003oool0oooo00H0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono
07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00040?ooo`0=0?oo_`1d000000000018W03Oool0
oooo0?oOW01807@0_ooo0?ooo`3ookl0M01809cOo`040?ooo`050=nLB000000000000000B02Lgol0
1`3oool00`000000oooo0?ooo`0]0?ooo`<000003P3ooolU0:Vmj0D0Y[cY102L^^d308fglPD0TKcd
1@2naMl50<Fmd`H0/J_B102WY]DY0:Vmj0D0YYg=102RV/d409VHd@D0Zm7d1P2`d?440:c2jPD0Zl3Y
9P2Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000000007@0
_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P004RLg`3o
ool0gia8001d_`D0oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool01P3oool00`000000oooo0?ooo`0Z0?ooo`<000004P3ooolU0:Vmj0D0Y[cY102O^n`4092h
lP@0TKcd1@2_a^/30<Fmd`80aLGJ102aZm820<Fmd`@0YjKE1@2XZMLF0:Vmj0D0ZKOS1@2Y_NP90:JM
c@<0XY[=1@2Xb_830:_Am080[mCc0`2`d?430:g5k0@0[<;Z1@2Z_^PU0:Vmj0030000002Y_NP0ZKgX
0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@0
0000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3o
ool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<000005P3o
oolU0:Vmj0D0YkgY102O^n`4092hlP@0Rk[f1@2_a^/50<G5fP80/J_B0`35_M<30:NVe@80_;CB1@2X
ZML40:NVe@D0ZKgX102Y/]h50:Vmj0@0Z:WG1@2Y]n<50:FLc0P0YYg=102Wa>h50:S:lPD0[mCc1P2]
aN`90:Znj2D0ZKgX00<000000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?ooo`3oool05@3o
ool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03Oool0
1`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?ooobD0ZKgX
1@2W_NT40::lj`@0UK[a102;^_H509[3m0@0aLGJ1P35_M<0102WY]D0_;CB0;bddP2l]=840:RYe`80
^;3A102WY]D50:JOc`@0ZK;N1@2VWll40:RYe`D0ZZ3=102UW<`40:JMc@D0Yl7/102Wa>h50:gFmPD0
[LO]0`2]aN`30:Zoj@@0Z[kX:P2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`000000
oooo0?ooo`0E0?ooo`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o
okl0M01809cOo`020?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003o
ool0oooo0280oooo0`00000N0?ooobD0ZKgX1@2X_NT40::lj`@0UK[a102<^_D509[3m080aLGJ0P2`
bNd50<Fmd`D0_;CB0P2XZML30;R`d@<0YjKE0P2l]=850:JOc`80ZK;N0P2_Y/h50:JOc`80Z:WG0P2d
[]840:ZPc@@0YIc<0P2VWLd30:W2j`@0Yl7/1P2Ze_L40:c:k`D0[LO]1@2Z_nT_0:Vmj0030000002Y
_NP0ZKgX01<0ZKgX1000000<0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000M;l0oooo0?ooo`3ookl0M0000`0000000`1d
_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo0`00000R0?ooobD0ZKgX1@2X_NT40:Fl
jPD0Vk__0`2<^_D409[3m0D0/<W]0P35_M<30;c9i0@0_;CB1P2h/=40102WY]D0_;CB0;bddP2l]=85
0:JOc`@0[jK>1@2VWll40;B^dPD0ZZ3=0`2UW<`60:W2j`D0YmKh1@2[bo040:c:k`D0Zl3Y0`2Z_nT`
0:Vmj0030000002Y_NP0ZKgX00l0ZKgX00@0oooo0000000000000000403oool00`000000oooo0?oo
o`0D0?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01P3oool01`3ookl0M018
09cOo`3oool0oooO09a8B02Lgol02@3oool2000001h0oooo0P00000V0?ooo`030000002Y_NP0ZKgX
0280ZKgX1@2X_NP40:FljPD0X;c/0`2C^o8508fom`<0/<W]1P2lbN@20;bddP80_/SQ1@2h/=450;bd
dP80YYo?0`2n_]T40:nVcP80YYo?0`2g_Mh40;B^dP@0ZZ3=102[aNd30:W2j`<0YMGi0`2We_P20:[<
lPD0Zl_`102[`NX50:_0jC<0ZKgX00<000000:Vmj02Y_NP02P2Y_NP20?ooo`<000004`3oool00`00
0000oooo0?ooo`0D0?ooo`000`3oool01P3ooml0W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd
0018W03Oool0oooo0;md001d_ol80?ooo`800000703oool3000002X0oooo902Y_NP50:Rmj0@0YkgY
1@2P_>`309>klPD0S[gf102FaOL40;c9i0D0_/SQ0P2h/=430;_9i@@0_;CB1P2n_]T30:nVcPH0]kgN
0`2d[]850:_;l@@0ZlG]1P2UeOT50:[<lPD0Z/;[102[`NX50:Znj3<0ZKgX00<000000:Vmj02Y_NP0
1`2Y_NP4000001H0oooo00<000000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL
0=ooo`040?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo
0?ooo`040?ooo`030000003oool0oooo01L0oooo0`00000^0?ooobT0ZKgX102W_NT50:FmjP@0Vkc_
102>_OH408k0n0D0W/[f0`2nb>460;_9i@@0//g]1@2n_]T40;;;k0D0]kgN102Wd?D50:_;l@D0XmCi
1@2Xbo890:[2j`T0Z[kX<`2Y_NP00`000000ZKgX0:Vmj0050:Vmj08000006P3oool00`000000oooo
0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3ooolY0:Vmj0@0Z;gX1@2U
_NX40::mk0@0V;ga102>`?P508o3n@@0Wlcg1@2KcOT40;;=k@D0Y=3g102bbn`50:7Bn@@0Ym3e1@2Q
d_T60:O:lP@0ZL;[1@2Z`^/90:Znj3L0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000
003oool0oooo01@0oooo000O0?ooo`8000004`3oool3000003H0oooo:@2Y_NP40:Rmj0D0YkgY102R
_N`409Rml@@0U[kc1@2?`oT40975n@D0Vlgi102Gc?X50:C@m`D0V]3j102Qd_T509o?n@D0Y/Sa1@2Y
`N/40:W2j`D0ZKkX102Z_^Pk0:Vmj0<00000803oool00`000000oooo0?ooo`0D0?ooo`007`3oool0
0`000000oooo0?ooo`0?0?ooo`<00000>P3oool]0:Vmj0D0YkgY102V_NT50:2mk@<0U[kc1P2G`?<3
0975n@H0ULKh0`2Gc?X509S:n@D0WlOd102NboL50:G5l0<0Y/Sa0P2X`>/50:W1j`T0ZKkX>P2Y_NP3
000000<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`00
0000oooo0?ooo`0<0?ooo`<00000?P3oool]0:Vmj0D0Z;gX102V_NT50:JmjP@0X;k^1@2Q_^d409[1
lPD0Wl7`102JaOD40:73l@D0WlOd102U`nh50:G5l0D0Z<3[2@2Y_^Pk0:Vmj0<000001P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo000O0?ooo`030000003oool0oooo00T0
oooo0`0000120?ooobd0ZKgX2@2X_NP90:JmjPD0XKk]102T_^`409o1l0D0Y<3]102Q`o450:K1k0@0
YL?^1P2X_nX80:Vnj3/0ZKgX1000000:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool04`3oool001h0oooo0P0000090?ooo`800000AP3ooolb0:Vmj0T0Z;gX102V_NX50:NmjP@0Y;k/
102V_^/50:C0k@@0Yko[1@2V`N`40:Rnj@<0Z;oZ0`2Y_NP40:Vnj3X0ZKgX00@0oooo000000000000
00003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000
003oool0oooo00D0oooo0`0000190?ooocH0ZKgX2@2X_NP40:NmjPD0Z;gY102V_^/50:Rnj@@0Yko[
2@2X_^U00:Vmj0040?ooo`0000000000000001<0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000ZKgX
0:Vmj00h0:Vmj0@0Z;gX102Y_NP50:Rmj@@0Z;gX1@2X_^T40:Vmj0@0Z;kY@02Y_NP00`3oool00000
00000002000001H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3o
ool00`000000oooo0000000200000540oooo00<000000:Vmj02Y_NP0A@2Y_NP40:Rmj4X0ZKgX0`00
000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool001h0oooo0P00001E
0?ooo`030000002Y_NP0ZKgX0900ZKgX0P00000O0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool04`3oool001<0oooo00<0omnL04P0M02oool02@3oool00`000000oooo0?ooo`1D0?oo
o`030000002Y_NP0ZKgX08`0ZKgX00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00X0oooo0P00001F0?ooohT0
ZKgX0P00000W0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool001<0oooo
00<0omnL04P0M02oool0303oool00`000000oooo0?ooo`1D0?ooohD0ZKgX0P00000[0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3o
ool00`000000oooo0?ooo`1D0?oooh00ZKgX0P00000`0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03P3oool00`000000oooo0?ooo`1D
0?ooog/0ZKgX0`00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool0
01<0oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?ooogL0ZKgX0`00000g0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000B02L
_i`0B01d0;ooo`0@0?ooo`800000E@3ooomb0:Vmj0<00000?03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oooa80oooo00<000000?oo
o`3oool0D`3ooom^0:Vmj0<00000@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0180oooo000C0?ooo`030?oOW01807@0_ooo01<0oooo00<000000?ooo`3oool0D`3ooomY0:Vmj0@0
0000@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000
003oool0oooo05<0ooooI@2Y_NP3000004P0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0A0?ooo`00:`3oool2000005@0ooooH02Y_NP0103oool0000000000000001<0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool0DP3o
oomL0:Vmj0@00000C`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000^
0?ooo`030000003oool0oooo0580ooooF02Y_NP3000005@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0A0?ooo`00;`3oool00`000000oooo0?ooo`1B0?oooe<0ZKgX00@0oooo0000
000000000000F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?oo
o`030000003oool0oooo0580ooooC`2Y_NP4000005`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`00<@3oool2000005<0ooooBP2Y_NP0103oool0000000000000001P0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool003<0oooo00<000000?ooo`3o
ool0D@3ooom60:Vmj0@00000I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo000d0?ooo`030000003oool0oooo0540oooo@P2Y_NP3000006T0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo0?ooo`1A0?ooocd0ZKgX00@0
oooo0000000000000000K03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo
000f0?ooo`800000DP3oooli0:Vmj0@00000L03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo000h0?ooo`030000003oool0oooo0500oooo=@2Y_NP3000007D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?oo
obl0ZKgX00@0oooo0000000000000000N@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0100oooo000j0?ooo`030000003oool0oooo0540oooo:`2Y_NP4000007`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool00`000000oooo0?ooo`1A0?ooobL0
ZKgX0`0000210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool003`0oooo
0P00001B0?ooob80ZKgX00@0oooo0000000000000000Q@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00l0oooo000n0?ooo`030000003oool0oooo0500oooo7P2Y_NP4000008T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00?`3oool00`000000oooo0?oo
o`1@0?oooaX0ZKgX0`00002=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3o
ool00400oooo00<000000?ooo`3oool0D03ooolF0:Vmj0<00000T@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00110?ooo`800000D@3ooolB0:Vmj0<00000U@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo04l0
oooo3@2Y_NP3000009T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00
A03oool00`000000oooo0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0D03oool40:Vmj0<00000X@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00160?ooo`800000D@3oool2
00000:H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B03oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`00B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00C03oool2000004/0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001>0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo001?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001@0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo001A0?ooo`800000AP3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool005<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`2/0?ooo`050000003oool0oooo0?ooo`0000003`3oool005@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001E
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00
000?0?ooo`00EP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`0000003`3oool005L0oooo0P00000o0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`0000003P3oool005T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2a0?ooo`80
00003P3oool005X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`2a0?ooo`800000
3P3oool005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2a0?ooo`8000003P3o
ool005`0oooo0P00000j0?ooo`030000003oool0oooo0:d0oooo1000000@0?ooo`00GP3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:T0oooo1000000D0?ooo`00G`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0oooo1000000H0?ooo`00H03oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0:40oooo1000000L0?ooo`00H@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo09h0oooo0`00000P0?ooo`00HP3oool2000003@0oooo00<00000
0?ooo`3oool0VP3oool4000002<0oooo001T0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0UP3oool4000002L0oooo001U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0TP3oool4000002/0oooo001V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
SP3oool4000002l0oooo001W0?ooo`800000;`3oool00`000000oooo0?ooo`2:0?ooo`@00000<`3o
ool006T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`270?ooo`<00000=`3oool0
06X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`230?ooo`@00000>P3oool006/0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1o0?ooo`@00000?P3oool006`0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1k0?ooo`@00000@P3oool006d0oooo0P00
000Y0?ooo`030000003oool0oooo07L0oooo100000160?ooo`00K`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo07D0oooo0`00001:0?ooo`00L03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0740oooo1000001=0?ooo`00L@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo06d0oooo1000001A0?ooo`00LP3oool2000002<0oooo00<000000?ooo`3oool0
J@3oool4000005D0oooo001d0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I@3o
ool4000005T0oooo001e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool3
000005d0oooo001f0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool40000
0600oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4000006@0
oooo001h0?ooo`8000007@3oool00`000000oooo0?ooo`1F0?ooo`@00000J03oool007X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`@00000K03oool007/0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000L03oool007`0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`1;0?ooo`<00000M03oool007d0oooo0P00000H0?ooo`03
0000003oool0oooo04L0oooo1000001g0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04<0oooo1000001k0?ooo`00P03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo03l0oooo1000001o0?ooo`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03/0oooo100000230?ooo`00PP3oool2000001<0oooo00<000000?ooo`3oool0>03oool30000
08L0oooo00240?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool4000008X0
oooo00250?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool4000008h0oooo
00260?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;03oool400000980oooo0027
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool4000009H0oooo00280?oo
o`8000003@3oool00`000000oooo0?ooo`0U0?ooo`<00000VP3oool008X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0R0?ooo`@00000W@3oool008/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`@00000X@3oool008`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000Y@3oool008d0oooo0P0000070?ooo`030000003oool0
oooo01H0oooo1000002Y0?ooo`00S`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0180oooo1000002]0?ooo`00T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo0`00002a0?ooo`00T@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
1000002d0?ooo`00TP3oool01@000000oooo0?ooo`3oool0000000T0oooo1000002h0?ooo`00T`3o
ool2000000030?ooo`000000oooo00@0oooo1000002l0?ooo`00U@3oool2000000030?ooo`000000
000000800000`03oool009H0oooo0P0000340?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3o
oomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55715 .53837 .55103 Mtetra
.53837 .55103 .54423 .55715 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .61641 .52744 Mtetra
.61641 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .48541 Mtetra
.75545 .48541 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .4782 Mtetra
.7793 .4782 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .45991 Mtetra
.83981 .45991 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .426 Mtetra
.95198 .426 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .61641 .52744 .6107 .52111 Mtetra
.6107 .52111 .61641 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .48541 .75014 .47875 Mtetra
.75014 .47875 .75545 .48541 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .4782 .77406 .47149 Mtetra
.77406 .47149 .7793 .4782 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .45991 .83474 .45305 Mtetra
.83474 .45305 .83981 .45991 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .426 .94727 .41888 Mtetra
.94727 .41888 .95198 .426 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51473 Mtetra
.60495 .51473 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51473 .59916 .5083 Mtetra
.59916 .5083 .60495 .51473 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47569 .72744 .46896 Mtetra
.72744 .46896 .73287 .47569 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49475 Mtetra
.61629 .49475 .62206 .50127 .63357 .49774 .62783 .49119 Mtetra
.62783 .49119 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48403 Mtetra
.65108 .48403 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53007 Mtetra
.47515 .53007 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49884 Mtetra
.57601 .49884 .58192 .50533 .59333 .50182 .58745 .4953 Mtetra
.58745 .4953 .59333 .50182 .60478 .49829 .59894 .49174 Mtetra
.664 .741 .908 r
.59894 .49174 .60478 .49829 .61629 .49475 .61047 .48818 Mtetra
.61047 .48818 .61629 .49475 .62783 .49119 .62205 .48459 Mtetra
.62205 .48459 .62783 .49119 .63943 .48761 .63368 .48099 Mtetra
.63368 .48099 .63943 .48761 .65108 .48403 .64536 .47738 Mtetra
.64536 .47738 .65108 .48403 .66277 .48042 .65708 .47374 Mtetra
.65708 .47374 .66277 .48042 .67451 .4768 .66886 .4701 Mtetra
.66886 .4701 .67451 .4768 .6863 .47317 .68068 .46643 Mtetra
.664 .741 .907 r
.68068 .46643 .6863 .47317 .69814 .46952 .69256 .46275 Mtetra
.69256 .46275 .69814 .46952 .71003 .46586 .70448 .45906 Mtetra
.70448 .45906 .71003 .46586 .72197 .46218 .71646 .45535 Mtetra
.71646 .45535 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53007 .46893 .52375 Mtetra
.46893 .52375 .47515 .53007 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49585 Mtetra
.663 .741 .908 r
.55864 .49585 .56462 .50236 .57601 .49884 .57006 .49231 Mtetra
.57006 .49231 .57601 .49884 .58745 .4953 .58153 .48875 Mtetra
.663 .742 .908 r
.58153 .48875 .58745 .4953 .59894 .49174 .59305 .4852 Mtetra
.663 .742 .909 r
.59305 .4852 .59894 .49174 .61047 .48818 .60461 .48162 Mtetra
.663 .743 .909 r
.60461 .48162 .61047 .48818 .62205 .48459 .61623 .47803 Mtetra
.663 .744 .91 r
.61623 .47803 .62205 .48459 .63368 .48099 .62789 .47441 Mtetra
.664 .744 .91 r
.62789 .47441 .63368 .48099 .64536 .47738 .6396 .47077 Mtetra
.6396 .47077 .64536 .47738 .65708 .47374 .65136 .4671 Mtetra
.665 .744 .909 r
.65136 .4671 .65708 .47374 .66886 .4701 .66317 .4634 Mtetra
.665 .743 .909 r
.66317 .4634 .66886 .4701 .68068 .46643 .67503 .45969 Mtetra
.665 .743 .908 r
.67503 .45969 .68068 .46643 .69256 .46275 .68693 .45596 Mtetra
.664 .742 .908 r
.68693 .45596 .69256 .46275 .70448 .45906 .69889 .45222 Mtetra
.69889 .45222 .70448 .45906 .71646 .45535 .7109 .44847 Mtetra
.664 .741 .907 r
.7109 .44847 .71646 .45535 .72848 .45162 .72296 .44471 Mtetra
.72296 .44471 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.664 .741 .908 r
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .4964 Mtetra
.663 .741 .908 r
.52984 .4964 .53593 .5029 .54726 .49938 .5412 .49287 Mtetra
.662 .742 .909 r
.5412 .49287 .54726 .49938 .55864 .49585 .55261 .48935 Mtetra
.661 .742 .91 r
.55261 .48935 .55864 .49585 .57006 .49231 .56406 .48584 Mtetra
.66 .744 .912 r
.56406 .48584 .57006 .49231 .58153 .48875 .57557 .48235 Mtetra
.66 .747 .914 r
.57557 .48235 .58153 .48875 .59305 .4852 .58712 .47886 Mtetra
.659 .75 .917 r
.58712 .47886 .59305 .4852 .60461 .48162 .59872 .47536 Mtetra
.66 .753 .919 r
.59872 .47536 .60461 .48162 .61623 .47803 .61037 .47182 Mtetra
.661 .756 .92 r
.61037 .47182 .61623 .47803 .62789 .47441 .62207 .46822 Mtetra
.663 .758 .921 r
.62207 .46822 .62789 .47441 .6396 .47077 .63381 .46455 Mtetra
.665 .759 .92 r
.63381 .46455 .6396 .47077 .65136 .4671 .64561 .46081 Mtetra
.667 .758 .918 r
.64561 .46081 .65136 .4671 .66317 .4634 .65745 .457 Mtetra
.668 .756 .916 r
.65745 .457 .66317 .4634 .67503 .45969 .66933 .45316 Mtetra
.668 .752 .914 r
.66933 .45316 .67503 .45969 .68693 .45596 .68127 .4493 Mtetra
.667 .749 .912 r
.68127 .4493 .68693 .45596 .69889 .45222 .69326 .44545 Mtetra
.666 .746 .91 r
.69326 .44545 .69889 .45222 .7109 .44847 .7053 .44161 Mtetra
.665 .744 .909 r
.7053 .44161 .7109 .44847 .72296 .44471 .7174 .43778 Mtetra
.665 .742 .908 r
.7174 .43778 .72296 .44471 .73507 .44094 .72954 .43395 Mtetra
.664 .741 .908 r
.72954 .43395 .73507 .44094 .74723 .43715 .74174 .43013 Mtetra
.664 .741 .907 r
.74174 .43013 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50047 Mtetra
.664 .741 .908 r
.48981 .50047 .49604 .50695 .50726 .50344 .50106 .49694 Mtetra
.663 .741 .908 r
.50106 .49694 .50726 .50344 .51853 .49992 .51236 .49341 Mtetra
.662 .741 .909 r
.51236 .49341 .51853 .49992 .52984 .4964 .5237 .48991 Mtetra
.66 .742 .911 r
.5237 .48991 .52984 .4964 .5412 .49287 .53509 .48645 Mtetra
.657 .744 .914 r
.53509 .48645 .5412 .49287 .55261 .48935 .54653 .48307 Mtetra
.653 .748 .92 r
.54653 .48307 .55261 .48935 .56406 .48584 .55802 .47976 Mtetra
.65 .755 .926 r
.55802 .47976 .56406 .48584 .57557 .48235 .56956 .4765 Mtetra
.648 .763 .933 r
.56956 .4765 .57557 .48235 .58712 .47886 .58115 .47325 Mtetra
.648 .773 .939 r
.58115 .47325 .58712 .47886 .59872 .47536 .59279 .46995 Mtetra
.65 .781 .944 r
.59279 .46995 .59872 .47536 .61037 .47182 .60449 .46654 Mtetra
.654 .788 .946 r
.60449 .46654 .61037 .47182 .62207 .46822 .61622 .463 Mtetra
.659 .793 .946 r
.61622 .463 .62207 .46822 .63381 .46455 .62801 .4593 Mtetra
.664 .794 .944 r
.62801 .4593 .63381 .46455 .64561 .46081 .63984 .45544 Mtetra
.669 .793 .94 r
.63984 .45544 .64561 .46081 .65745 .457 .65171 .45145 Mtetra
.673 .788 .935 r
.65171 .45145 .65745 .457 .66933 .45316 .66363 .44736 Mtetra
.675 .781 .929 r
.66363 .44736 .66933 .45316 .68127 .4493 .6756 .4432 Mtetra
.675 .771 .923 r
.6756 .4432 .68127 .4493 .69326 .44545 .68761 .43906 Mtetra
.673 .762 .918 r
.68761 .43906 .69326 .44545 .7053 .44161 .69968 .43496 Mtetra
.67 .754 .913 r
.69968 .43496 .7053 .44161 .7174 .43778 .7118 .43093 Mtetra
.668 .748 .91 r
.7118 .43093 .7174 .43778 .72954 .43395 .72397 .42698 Mtetra
.666 .744 .909 r
.72397 .42698 .72954 .43395 .74174 .43013 .73621 .42307 Mtetra
.665 .742 .908 r
.73621 .42307 .74174 .43013 .75399 .42629 .74849 .41919 Mtetra
.664 .741 .908 r
.74849 .41919 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.664 .741 .907 r
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39962 Mtetra
.81073 .39962 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37963 Mtetra
.87435 .37963 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91818 .37495 .91319 .36742 Mtetra
.91319 .36742 .91818 .37495 .9312 .37088 .92625 .36332 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49748 Mtetra
.663 .741 .908 r
.4723 .49748 .47861 .50398 .48981 .50047 .48354 .49394 Mtetra
.662 .741 .908 r
.48354 .49394 .48981 .50047 .50106 .49694 .49482 .49043 Mtetra
.66 .741 .91 r
.49482 .49043 .50106 .49694 .51236 .49341 .50614 .48697 Mtetra
.655 .743 .914 r
.50614 .48697 .51236 .49341 .5237 .48991 .51752 .48363 Mtetra
.648 .747 .921 r
.51752 .48363 .5237 .48991 .53509 .48645 .52894 .48045 Mtetra
.64 .755 .931 r
.52894 .48045 .53509 .48645 .54653 .48307 .54041 .47744 Mtetra
.633 .766 .943 r
.54041 .47744 .54653 .48307 .55802 .47976 .55194 .47454 Mtetra
.628 .781 .954 r
.55194 .47454 .55802 .47976 .56956 .4765 .56352 .47165 Mtetra
.628 .795 .962 r
.56352 .47165 .56956 .4765 .58115 .47325 .57515 .46863 Mtetra
.633 .806 .966 r
.57515 .46863 .58115 .47325 .59279 .46995 .58684 .46543 Mtetra
.64 .814 .967 r
.58684 .46543 .59279 .46995 .60449 .46654 .59857 .46203 Mtetra
.646 .817 .965 r
.59857 .46203 .60449 .46654 .61622 .463 .61035 .45845 Mtetra
.652 .818 .963 r
.61035 .45845 .61622 .463 .62801 .4593 .62218 .45473 Mtetra
.658 .82 .961 r
.62218 .45473 .62801 .4593 .63984 .45544 .63405 .45085 Mtetra
.665 .822 .959 r
.63405 .45085 .63984 .45544 .65171 .45145 .64596 .4468 Mtetra
.673 .823 .956 r
.64596 .4468 .65171 .45145 .66363 .44736 .65792 .44254 Mtetra
.68 .82 .95 r
.65792 .44254 .66363 .44736 .6756 .4432 .66992 .4381 Mtetra
.686 .812 .943 r
.66992 .4381 .6756 .4432 .68761 .43906 .68196 .43354 Mtetra
.686 .798 .934 r
.68196 .43354 .68761 .43906 .69968 .43496 .69404 .42897 Mtetra
.683 .782 .925 r
.69404 .42897 .69968 .43496 .7118 .43093 .70618 .42451 Mtetra
.677 .766 .918 r
.70618 .42451 .7118 .43093 .72397 .42698 .71838 .42021 Mtetra
.672 .754 .913 r
.71838 .42021 .72397 .42698 .73621 .42307 .73063 .41608 Mtetra
.668 .747 .91 r
.73063 .41608 .73621 .42307 .74849 .41919 .74295 .41207 Mtetra
.665 .743 .908 r
.74295 .41207 .74849 .41919 .76083 .4153 .75533 .40811 Mtetra
.664 .741 .907 r
.75533 .40811 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39962 .80538 .39228 Mtetra
.80538 .39228 .81073 .39962 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37963 .86919 .37213 Mtetra
.86919 .37213 .87435 .37963 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36332 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49448 Mtetra
.663 .741 .908 r
.45473 .49448 .46112 .501 .4723 .49748 .46595 .49093 Mtetra
.662 .741 .909 r
.46595 .49093 .4723 .49748 .48354 .49394 .47721 .48743 Mtetra
.658 .741 .912 r
.47721 .48743 .48354 .49394 .49482 .49043 .48852 .48402 Mtetra
.65 .743 .918 r
.48852 .48402 .49482 .49043 .50614 .48697 .49987 .48081 Mtetra
.638 .748 .929 r
.49987 .48081 .50614 .48697 .51752 .48363 .51128 .4779 Mtetra
.623 .759 .944 r
.51128 .4779 .51752 .48363 .52894 .48045 .52273 .47525 Mtetra
.612 .776 .959 r
.52273 .47525 .52894 .48045 .54041 .47744 .53424 .4727 Mtetra
.613 .794 .969 r
.53424 .4727 .54041 .47744 .55194 .47454 .54581 .46997 Mtetra
.629 .807 .968 r
.54581 .46997 .55194 .47454 .56352 .47165 .55743 .46684 Mtetra
.652 .806 .957 r
.55743 .46684 .56352 .47165 .57515 .46863 .56909 .46324 Mtetra
.67 .79 .939 r
.56909 .46324 .57515 .46863 .58684 .46543 .5808 .45927 Mtetra
.675 .766 .919 r
.5808 .45927 .58684 .46543 .59857 .46203 .59255 .45519 Mtetra
.672 .744 .905 r
.59255 .45519 .59857 .46203 .61035 .45845 .60436 .45119 Mtetra
.664 .73 .899 r
.60436 .45119 .61035 .45845 .62218 .45473 .61622 .44744 Mtetra
.656 .728 .902 r
.61622 .44744 .62218 .45473 .63405 .45085 .62813 .44392 Mtetra
.652 .738 .913 r
.62813 .44392 .63405 .45085 .64596 .4468 .64011 .4405 Mtetra
.654 .76 .927 r
.64011 .4405 .64596 .4468 .65792 .44254 .65213 .43696 Mtetra
.663 .788 .941 r
.65213 .43696 .65792 .44254 .66992 .4381 .66419 .43305 Mtetra
.677 .813 .948 r
.66419 .43305 .66992 .4381 .68196 .43354 .67629 .42867 Mtetra
.691 .825 .947 r
.67629 .42867 .68196 .43354 .69404 .42897 .68841 .42387 Mtetra
.697 .819 .94 r
.68841 .42387 .69404 .42897 .70618 .42451 .70056 .41888 Mtetra
.695 .801 .931 r
.70056 .41888 .70618 .42451 .71838 .42021 .71277 .414 Mtetra
.686 .779 .921 r
.71277 .414 .71838 .42021 .73063 .41608 .72504 .40938 Mtetra
.676 .761 .914 r
.72504 .40938 .73063 .41608 .74295 .41207 .73738 .40505 Mtetra
.67 .749 .91 r
.73738 .40505 .74295 .41207 .75533 .40811 .74978 .40092 Mtetra
.666 .744 .908 r
.74978 .40092 .75533 .40811 .76776 .40417 .76225 .3969 Mtetra
.664 .742 .908 r
.76225 .3969 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.664 .741 .907 r
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.663 .741 .908 r
.4371 .49146 .44356 .49802 .45473 .49448 .4483 .48791 Mtetra
.661 .741 .909 r
.4483 .48791 .45473 .49448 .46595 .49093 .45954 .4844 Mtetra
.656 .741 .912 r
.45954 .4844 .46595 .49093 .47721 .48743 .47083 .48102 Mtetra
.645 .743 .92 r
.47083 .48102 .47721 .48743 .48852 .48402 .48217 .47794 Mtetra
.626 .749 .935 r
.48217 .47794 .48852 .48402 .49987 .48081 .49355 .47528 Mtetra
.606 .762 .954 r
.49355 .47528 .49987 .48081 .51128 .4779 .50498 .47294 Mtetra
.6 .782 .968 r
.50498 .47294 .51128 .4779 .52273 .47525 .51647 .47054 Mtetra
.627 .801 .966 r
.51647 .47054 .52273 .47525 .53424 .4727 .52802 .4675 Mtetra
.676 .797 .94 r
.52802 .4675 .53424 .4727 .54581 .46997 .53961 .46338 Mtetra
.709 .76 .892 r
.53961 .46338 .54581 .46997 .55743 .46684 .55125 .45816 Mtetra
.713 .708 .844 r
.55125 .45816 .55743 .46684 .56909 .46324 .56291 .45223 Mtetra
.673 .648 .817 r
.56291 .45223 .56909 .46324 .5808 .45927 .57463 .44759 Mtetra
.652 .628 .813 r
.57463 .44759 .5808 .45927 .59255 .45519 .5864 .44384 Mtetra
.653 .635 .819 r
.5864 .44384 .59255 .45519 .60436 .45119 .59823 .44006 Mtetra
.654 .64 .823 r
.59823 .44006 .60436 .45119 .61622 .44744 .61011 .43627 Mtetra
.61011 .43627 .61622 .44744 .62813 .44392 .62204 .43247 Mtetra
.653 .635 .819 r
.62204 .43247 .62813 .44392 .64011 .4405 .63402 .42865 Mtetra
.632 .619 .819 r
.63402 .42865 .64011 .4405 .65213 .43696 .64608 .42572 Mtetra
.601 .615 .838 r
.64608 .42572 .65213 .43696 .66419 .43305 .65826 .42409 Mtetra
.618 .672 .88 r
.65826 .42409 .66419 .43305 .67629 .42867 .67047 .42175 Mtetra
.649 .742 .918 r
.67047 .42175 .67629 .42867 .68841 .42387 .6827 .41831 Mtetra
.682 .8 .938 r
.6827 .41831 .68841 .42387 .70056 .41888 .69492 .41377 Mtetra
.703 .823 .939 r
.69492 .41377 .70056 .41888 .71277 .414 .70716 .40857 Mtetra
.705 .813 .932 r
.70716 .40857 .71277 .414 .72504 .40938 .71944 .4033 Mtetra
.694 .789 .923 r
.71944 .4033 .72504 .40938 .73738 .40505 .73178 .39836 Mtetra
.681 .765 .915 r
.73178 .39836 .73738 .40505 .74978 .40092 .7442 .39385 Mtetra
.671 .751 .91 r
.7442 .39385 .74978 .40092 .76225 .3969 .7567 .38962 Mtetra
.666 .744 .908 r
.7567 .38962 .76225 .3969 .77477 .3929 .76925 .38554 Mtetra
.665 .742 .908 r
.76925 .38554 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.664 .741 .907 r
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.663 .741 .908 r
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48487 Mtetra
.661 .741 .909 r
.43059 .48487 .4371 .49146 .4483 .48791 .44181 .48134 Mtetra
.656 .741 .912 r
.44181 .48134 .4483 .48791 .45954 .4844 .45309 .47797 Mtetra
.642 .742 .921 r
.45309 .47797 .45954 .4844 .47083 .48102 .4644 .47495 Mtetra
.619 .747 .938 r
.4644 .47495 .47083 .48102 .48217 .47794 .47576 .47245 Mtetra
.594 .76 .958 r
.47576 .47245 .48217 .47794 .49355 .47528 .48716 .47033 Mtetra
.601 .784 .968 r
.48716 .47033 .49355 .47528 .50498 .47294 .49863 .46789 Mtetra
.663 .799 .947 r
.49863 .46789 .50498 .47294 .51647 .47054 .51016 .46409 Mtetra
.725 .768 .886 r
.51016 .46409 .51647 .47054 .52802 .4675 .52174 .45825 Mtetra
.717 .697 .83 r
.52174 .45825 .52802 .4675 .53961 .46338 .53336 .45191 Mtetra
.652 .631 .816 r
.53336 .45191 .53961 .46338 .55125 .45816 .54502 .44817 Mtetra
.658 .661 .842 r
.54502 .44817 .55125 .45816 .56291 .45223 .55673 .44441 Mtetra
.663 .715 .887 r
.55673 .44441 .56291 .45223 .57463 .44759 .56849 .44064 Mtetra
.664 .741 .907 r
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64608 .42572 .64011 .41768 Mtetra
.663 .715 .887 r
.64011 .41768 .64608 .42572 .65826 .42409 .65223 .4138 Mtetra
.658 .661 .842 r
.65223 .4138 .65826 .42409 .67047 .42175 .6644 .4099 Mtetra
.59 .601 .831 r
.6644 .4099 .67047 .42175 .6827 .41831 .67675 .40864 Mtetra
.6 .65 .871 r
.67675 .40864 .6827 .41831 .69492 .41377 .68914 .40687 Mtetra
.66 .751 .917 r
.68914 .40687 .69492 .41377 .70716 .40857 .7015 .40304 Mtetra
.702 .811 .932 r
.7015 .40304 .70716 .40857 .71944 .4033 .71383 .39782 Mtetra
.712 .816 .93 r
.71383 .39782 .71944 .4033 .73178 .39836 .72618 .39227 Mtetra
.7 .793 .922 r
.72618 .39227 .73178 .39836 .7442 .39385 .7386 .38709 Mtetra
.683 .767 .915 r
.7386 .38709 .7442 .39385 .7567 .38962 .75111 .38244 Mtetra
.671 .751 .91 r
.75111 .38244 .7567 .38962 .76925 .38554 .76369 .37816 Mtetra
.666 .744 .908 r
.76369 .37816 .76925 .38554 .78187 .38149 .77635 .37403 Mtetra
.664 .741 .907 r
.77635 .37403 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34929 Mtetra
.85348 .34929 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .3409 Mtetra
.87965 .3409 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .48541 Mtetra
.663 .741 .907 r
.40165 .48541 .40827 .49201 .41941 .48844 .41281 .48182 Mtetra
.662 .741 .908 r
.41281 .48182 .41941 .48844 .43059 .48487 .42402 .47826 Mtetra
.657 .74 .911 r
.42402 .47826 .43059 .48487 .44181 .48134 .43528 .47484 Mtetra
.643 .74 .92 r
.43528 .47484 .44181 .48134 .45309 .47797 .44657 .47179 Mtetra
.616 .743 .937 r
.44657 .47179 .45309 .47797 .4644 .47495 .4579 .46936 Mtetra
.587 .755 .958 r
.4579 .46936 .4644 .47495 .47576 .47245 .46928 .46739 Mtetra
.605 .781 .965 r
.46928 .46739 .47576 .47245 .48716 .47033 .48073 .4649 Mtetra
.692 .792 .927 r
.48073 .4649 .48716 .47033 .49863 .46789 .49225 .46033 Mtetra
.755 .744 .843 r
.49225 .46033 .49863 .46789 .51016 .46409 .50383 .45268 Mtetra
.657 .635 .816 r
.50383 .45268 .51016 .46409 .52174 .45825 .51543 .44874 Mtetra
.659 .672 .851 r
.51543 .44874 .52174 .45825 .53336 .45191 .52707 .44499 Mtetra
.664 .741 .907 r
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67675 .40864 .67075 .3987 Mtetra
.654 .67 .853 r
.67075 .3987 .67675 .40864 .68914 .40687 .68307 .39494 Mtetra
.554 .584 .838 r
.68307 .39494 .68914 .40687 .7015 .40304 .69565 .39495 Mtetra
.637 .709 .899 r
.69565 .39495 .7015 .40304 .71383 .39782 .70814 .39183 Mtetra
.701 .798 .925 r
.70814 .39183 .71383 .39782 .72618 .39227 .72056 .3866 Mtetra
.717 .814 .925 r
.72056 .3866 .72618 .39227 .7386 .38709 .73299 .38083 Mtetra
.702 .791 .92 r
.73299 .38083 .7386 .38709 .75111 .38244 .7455 .37552 Mtetra
.682 .764 .913 r
.7455 .37552 .75111 .38244 .76369 .37816 .7581 .37084 Mtetra
.67 .749 .909 r
.7581 .37084 .76369 .37816 .77635 .37403 .77078 .36654 Mtetra
.665 .743 .908 r
.77078 .36654 .77635 .37403 .78906 .36994 .78353 .36238 Mtetra
.664 .741 .907 r
.78353 .36238 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34929 .84815 .34154 Mtetra
.84815 .34154 .85348 .34929 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .3409 .87441 .33308 Mtetra
.87441 .33308 .87965 .3409 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .48541 .39498 .47876 Mtetra
.663 .741 .908 r
.39498 .47876 .40165 .48541 .41281 .48182 .40617 .47516 Mtetra
.659 .74 .91 r
.40617 .47516 .41281 .48182 .42402 .47826 .41741 .47167 Mtetra
.647 .74 .917 r
.41741 .47167 .42402 .47826 .43528 .47484 .42868 .4685 Mtetra
.62 .74 .933 r
.42868 .4685 .43528 .47484 .44657 .47179 .43999 .46599 Mtetra
.585 .748 .955 r
.43999 .46599 .44657 .47179 .4579 .46936 .45134 .46411 Mtetra
.599 .773 .963 r
.45134 .46411 .4579 .46936 .46928 .46739 .46276 .46177 Mtetra
.702 .789 .918 r
.46276 .46177 .46928 .46739 .48073 .4649 .47427 .45688 Mtetra
.749 .733 .837 r
.47427 .45688 .48073 .4649 .49225 .46033 .48586 .44932 Mtetra
.654 .641 .825 r
.48586 .44932 .49225 .46033 .50383 .45268 .49744 .44557 Mtetra
.664 .735 .903 r
.49744 .44557 .50383 .45268 .51543 .44874 .50906 .44181 Mtetra
.664 .741 .907 r
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68307 .39494 .67718 .38737 Mtetra
.664 .735 .903 r
.67718 .38737 .68307 .39494 .69565 .39495 .68958 .38335 Mtetra
.555 .592 .846 r
.68958 .38335 .69565 .39495 .70814 .39183 .70226 .38321 Mtetra
.628 .694 .892 r
.70226 .38321 .70814 .39183 .72056 .3866 .71485 .38036 Mtetra
.706 .793 .919 r
.71485 .38036 .72056 .3866 .73299 .38083 .72736 .37491 Mtetra
.72 .809 .92 r
.72736 .37491 .73299 .38083 .7455 .37552 .73987 .36898 Mtetra
.7 .784 .916 r
.73987 .36898 .7455 .37552 .7581 .37084 .75247 .36369 Mtetra
.679 .759 .911 r
.75247 .36369 .7581 .37084 .77078 .36654 .76518 .35906 Mtetra
.669 .746 .909 r
.76518 .35906 .77078 .36654 .78353 .36238 .77796 .35477 Mtetra
.665 .742 .908 r
.77796 .35477 .78353 .36238 .79634 .35824 .7908 .35058 Mtetra
.664 .741 .907 r
.7908 .35058 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47569 Mtetra
.663 .741 .908 r
.37708 .47569 .38383 .48236 .39498 .47876 .38825 .47206 Mtetra
.661 .74 .909 r
.38825 .47206 .39498 .47876 .40617 .47516 .39948 .46849 Mtetra
.652 .739 .913 r
.39948 .46849 .40617 .47516 .41741 .47167 .41073 .46516 Mtetra
.629 .738 .926 r
.41073 .46516 .41741 .47167 .42868 .4685 .42203 .46242 Mtetra
.59 .74 .948 r
.42203 .46242 .42868 .4685 .43999 .46599 .43335 .46049 Mtetra
.584 .76 .962 r
.43335 .46049 .43999 .46599 .45134 .46411 .44473 .4585 Mtetra
.688 .787 .926 r
.44473 .4585 .45134 .46411 .46276 .46177 .45622 .45403 Mtetra
.757 .741 .838 r
.45622 .45403 .46276 .46177 .47427 .45688 .46782 .44615 Mtetra
.655 .647 .83 r
.46782 .44615 .47427 .45688 .48586 .44932 .47938 .44239 Mtetra
.664 .741 .907 r
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70226 .38321 .69618 .37182 Mtetra
.544 .592 .853 r
.69618 .37182 .70226 .38321 .71485 .38036 .70898 .37196 Mtetra
.641 .707 .895 r
.70898 .37196 .71485 .38036 .72736 .37491 .72165 .36861 Mtetra
.717 .798 .915 r
.72165 .36861 .72736 .37491 .73987 .36898 .73422 .36274 Mtetra
.719 .801 .916 r
.73422 .36274 .73987 .36898 .75247 .36369 .74682 .35678 Mtetra
.693 .773 .913 r
.74682 .35678 .75247 .36369 .76518 .35906 .75953 .35166 Mtetra
.674 .752 .91 r
.75953 .35166 .76518 .35906 .77796 .35477 .77234 .34713 Mtetra
.666 .744 .908 r
.77234 .34713 .77796 .35477 .7908 .35058 .78522 .34286 Mtetra
.664 .741 .907 r
.78522 .34286 .7908 .35058 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47569 .37028 .46896 Mtetra
.663 .741 .908 r
.37028 .46896 .37708 .47569 .38825 .47206 .38148 .46533 Mtetra
.658 .74 .91 r
.38148 .46533 .38825 .47206 .39948 .46849 .39273 .46183 Mtetra
.641 .738 .919 r
.39273 .46183 .39948 .46849 .41073 .46516 .404 .45878 Mtetra
.605 .736 .938 r
.404 .45878 .41073 .46516 .42203 .46242 .4153 .45657 Mtetra
.572 .744 .958 r
.4153 .45657 .42203 .46242 .43335 .46049 .42665 .45489 Mtetra
.648 .778 .943 r
.42665 .45489 .43335 .46049 .44473 .4585 .4381 .4515 Mtetra
.771 .762 .844 r
.4381 .4515 .44473 .4585 .45622 .45403 .44971 .44317 Mtetra
.659 .647 .827 r
.44971 .44317 .45622 .45403 .46782 .44615 .46126 .43919 Mtetra
.664 .741 .907 r
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.423 .64 .946 r
.53155 .41619 .53792 .42333 .54978 .41947 .54348 .41753 Mtetra
.204 .703 .913 r
.54348 .41753 .54978 .41947 .56169 .41559 .55548 .4176 Mtetra
0 0 0 r
.55548 .4176 .56169 .41559 .57366 .4117 .56753 .41556 Mtetra
.56753 .41556 .57366 .4117 .58567 .40779 .57962 .41162 Mtetra
.57962 .41162 .58567 .40779 .59774 .40386 .59173 .4058 Mtetra
.59 .942 .795 r
.59173 .4058 .59774 .40386 .60985 .39992 .60382 .39784 Mtetra
.813 .941 .91 r
.60382 .39784 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.664 .741 .907 r
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.657 .738 .91 r
.69028 .36426 .69618 .37182 .70898 .37196 .70288 .36035 Mtetra
.531 .583 .852 r
.70288 .36035 .70898 .37196 .72165 .36861 .71581 .36089 Mtetra
.674 .742 .902 r
.71581 .36089 .72165 .36861 .73422 .36274 .72851 .35638 Mtetra
.726 .802 .911 r
.72851 .35638 .73422 .36274 .74682 .35678 .74114 .35011 Mtetra
.71 .788 .912 r
.74114 .35011 .74682 .35678 .75953 .35166 .75386 .34438 Mtetra
.684 .762 .91 r
.75386 .34438 .75953 .35166 .77234 .34713 .76668 .3395 Mtetra
.669 .747 .908 r
.76668 .3395 .77234 .34713 .78522 .34286 .7796 .33509 Mtetra
.665 .742 .908 r
.7796 .33509 .78522 .34286 .79817 .33862 .79259 .3308 Mtetra
.664 .741 .907 r
.79259 .3308 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30489 Mtetra
.87177 .30489 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48403 Mtetra
.29699 .48403 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46219 Mtetra
.661 .74 .909 r
.36342 .46219 .37028 .46896 .38148 .46533 .37465 .45857 Mtetra
.652 .739 .913 r
.37465 .45857 .38148 .46533 .39273 .46183 .38592 .4552 Mtetra
.625 .736 .927 r
.38592 .4552 .39273 .46183 .404 .45878 .39721 .45254 Mtetra
.58 .734 .948 r
.39721 .45254 .404 .45878 .4153 .45657 .40852 .45078 Mtetra
.594 .756 .955 r
.40852 .45078 .4153 .45657 .42665 .45489 .41991 .44862 Mtetra
.734 .776 .887 r
.41991 .44862 .42665 .45489 .4381 .4515 .43147 .44241 Mtetra
.719 .703 .834 r
.43147 .44241 .4381 .4515 .44971 .44317 .44307 .43598 Mtetra
.664 .735 .903 r
.44307 .43598 .44971 .44317 .46126 .43919 .45464 .43218 Mtetra
.664 .741 .907 r
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.418 .638 .947 r
.50144 .41679 .50792 .42392 .51971 .42007 .51324 .41815 Mtetra
.221 0 0 r
.51324 .41815 .51971 .42007 .53155 .41619 .52514 .42187 Mtetra
.416 0 0 r
.52514 .42187 .53155 .41619 .54348 .41753 .53713 .42265 Mtetra
.27 0 0 r
.53713 .42265 .54348 .41753 .55548 .4176 .54919 .42127 Mtetra
.058 0 0 r
.54919 .42127 .55548 .4176 .56753 .41556 .56131 .41843 Mtetra
0 0 0 r
.56131 .41843 .56753 .41556 .57962 .41162 .57347 .41448 Mtetra
.57347 .41448 .57962 .41162 .59173 .4058 .58567 .40941 Mtetra
.58567 .40941 .59173 .4058 .60382 .39784 .59788 .40287 Mtetra
.59788 .40287 .60382 .39784 .6159 .3886 .61007 .39414 Mtetra
.501 .824 .518 r
.61007 .39414 .6159 .3886 .62816 .38459 .62218 .38243 Mtetra
.814 .942 .91 r
.62218 .38243 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.664 .741 .907 r
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70288 .36035 .69695 .35249 Mtetra
.571 .696 .926 r
.69695 .35249 .70288 .36035 .71581 .36089 .7098 .35101 Mtetra
.59 .652 .88 r
.7098 .35101 .71581 .36089 .72851 .35638 .7227 .34932 Mtetra
.711 .777 .904 r
.7227 .34932 .72851 .35638 .74114 .35011 .73542 .34349 Mtetra
.724 .796 .908 r
.73542 .34349 .74114 .35011 .75386 .34438 .74814 .33723 Mtetra
.696 .772 .91 r
.74814 .33723 .75386 .34438 .76668 .3395 .76098 .33189 Mtetra
.674 .751 .909 r
.76098 .33189 .76668 .3395 .7796 .33509 .77393 .32727 Mtetra
.666 .743 .908 r
.77393 .32727 .7796 .33509 .79259 .3308 .78695 .32291 Mtetra
.664 .741 .907 r
.78695 .32291 .79259 .3308 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30489 .8664 .29677 Mtetra
.8664 .29677 .87177 .30489 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48403 .28991 .47736 Mtetra
.28991 .47736 .29699 .48403 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45906 Mtetra
.663 .741 .908 r
.34529 .45906 .35223 .46586 .36342 .46219 .35651 .45537 Mtetra
.659 .74 .91 r
.35651 .45537 .36342 .46219 .37465 .45857 .36777 .45178 Mtetra
.644 .737 .917 r
.36777 .45178 .37465 .45857 .38592 .4552 .37905 .44862 Mtetra
.606 .733 .935 r
.37905 .44862 .38592 .4552 .39721 .45254 .39035 .44636 Mtetra
.568 .734 .953 r
.39035 .44636 .39721 .45254 .40852 .45078 .40169 .44478 Mtetra
.655 .768 .933 r
.40169 .44478 .40852 .45078 .41991 .44862 .41315 .44121 Mtetra
.769 .753 .838 r
.41315 .44121 .41991 .44862 .43147 .44241 .42482 .43276 Mtetra
.658 .672 .852 r
.42482 .43276 .43147 .44241 .44307 .43598 .43637 .42894 Mtetra
.664 .741 .907 r
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.266 .557 .931 r
.48309 .4135 .48966 .42066 .50144 .41679 .49483 .41689 Mtetra
.47 0 0 r
.49483 .41689 .50144 .41679 .51324 .41815 .50666 .42179 Mtetra
.373 0 0 r
.50666 .42179 .51324 .41815 .52514 .42187 .51862 .42297 Mtetra
0 0 0 r
.51862 .42297 .52514 .42187 .53713 .42265 .53067 .42159 Mtetra
.421 .851 .945 r
.53067 .42159 .53713 .42265 .54919 .42127 .54278 .41879 Mtetra
.571 .88 .993 r
.54278 .41879 .54919 .42127 .56131 .41843 .55494 .41524 Mtetra
.621 .873 .989 r
.55494 .41524 .56131 .41843 .57347 .41448 .56715 .41126 Mtetra
.643 .88 .984 r
.56715 .41126 .57347 .41448 .58567 .40941 .57942 .40684 Mtetra
.664 .909 .978 r
.57942 .40684 .58567 .40941 .59788 .40287 .59171 .40167 Mtetra
.692 .955 .951 r
.59171 .40167 .59788 .40287 .61007 .39414 .60402 .39507 Mtetra
.723 .989 .858 r
.60402 .39507 .61007 .39414 .62218 .38243 .61629 .38588 Mtetra
.742 .97 .704 r
.61629 .38588 .62218 .38243 .63437 .37307 .62846 .3729 Mtetra
.841 .988 .861 r
.62846 .3729 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.664 .741 .907 r
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .7098 .35101 .70371 .34057 Mtetra
.518 .605 .879 r
.70371 .34057 .7098 .35101 .7227 .34932 .71678 .3411 Mtetra
.669 .731 .896 r
.71678 .3411 .7227 .34932 .73542 .34349 .72963 .33665 Mtetra
.729 .792 .902 r
.72963 .33665 .73542 .34349 .74814 .33723 .74239 .33013 Mtetra
.709 .78 .907 r
.74239 .33013 .74814 .33723 .76098 .33189 .75524 .32432 Mtetra
.682 .757 .908 r
.75524 .32432 .76098 .33189 .77393 .32727 .76821 .31942 Mtetra
.668 .745 .908 r
.76821 .31942 .77393 .32727 .78695 .32291 .78128 .31496 Mtetra
.665 .741 .907 r
.78128 .31496 .78695 .32291 .80004 .31859 .79441 .3106 Mtetra
.664 .741 .907 r
.79441 .3106 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47065 Mtetra
.28278 .47065 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45592 Mtetra
.3271 .45592 .33412 .46274 .34529 .45906 .3383 .4522 Mtetra
.663 .741 .908 r
.3383 .4522 .34529 .45906 .35651 .45537 .34954 .4485 Mtetra
.656 .739 .911 r
.34954 .4485 .35651 .45537 .36777 .45178 .36083 .44498 Mtetra
.634 .736 .921 r
.36083 .44498 .36777 .45178 .37905 .44862 .37213 .44204 Mtetra
.588 .729 .941 r
.37213 .44204 .37905 .44862 .39035 .44636 .38344 .44015 Mtetra
.579 .739 .952 r
.38344 .44015 .39035 .44636 .40169 .44478 .39481 .43834 Mtetra
.719 .771 .893 r
.39481 .43834 .40169 .44478 .41315 .44121 .40638 .43265 Mtetra
.733 .721 .839 r
.40638 .43265 .41315 .44121 .42482 .43276 .41803 .4257 Mtetra
.664 .741 .907 r
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.414 .638 .948 r
.46468 .4102 .47134 .41739 .48309 .4135 .47639 .41154 Mtetra
.503 0 0 r
.47639 .41154 .48309 .4135 .49483 .41689 .48812 .41848 Mtetra
.343 0 0 r
.48812 .41848 .49483 .41689 .50666 .42179 .50003 .4206 Mtetra
.268 .761 .906 r
.50003 .4206 .50666 .42179 .51862 .42297 .51204 .41939 Mtetra
.576 .843 .995 r
.51204 .41939 .51862 .42297 .53067 .42159 .52413 .41641 Mtetra
.645 .807 .961 r
.52413 .41641 .53067 .42159 .54278 .41879 .53628 .41266 Mtetra
.66 .78 .938 r
.53628 .41266 .54278 .41879 .55494 .41524 .54847 .40868 Mtetra
.661 .767 .928 r
.54847 .40868 .55494 .41524 .56715 .41126 .56073 .40467 Mtetra
.662 .768 .928 r
.56073 .40467 .56715 .41126 .57942 .40684 .57304 .40062 Mtetra
.668 .783 .935 r
.57304 .40062 .57942 .40684 .59171 .40167 .58539 .39635 Mtetra
.692 .82 .944 r
.58539 .39635 .59171 .40167 .60402 .39507 .59779 .39129 Mtetra
.745 .886 .944 r
.59779 .39129 .60402 .39507 .61629 .38588 .61019 .38445 Mtetra
.826 .963 .896 r
.61019 .38445 .61629 .38588 .62846 .3729 .62251 .37422 Mtetra
.889 .99 .779 r
.62251 .37422 .62846 .3729 .64066 .36141 .63468 .3591 Mtetra
.814 .942 .91 r
.63468 .3591 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.664 .741 .907 r
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.549 .692 .934 r
.69774 .33276 .70371 .34057 .71678 .3411 .71075 .33169 Mtetra
.606 .675 .89 r
.71075 .33169 .71678 .3411 .72963 .33665 .72376 .32933 Mtetra
.721 .778 .897 r
.72376 .32933 .72963 .33665 .74239 .33013 .73659 .323 Mtetra
.72 .783 .902 r
.73659 .323 .74239 .33013 .75524 .32432 .74946 .31674 Mtetra
.689 .761 .907 r
.74946 .31674 .75524 .32432 .76821 .31942 .76245 .31154 Mtetra
.671 .747 .907 r
.76245 .31154 .76821 .31942 .78128 .31496 .77555 .30695 Mtetra
.665 .742 .907 r
.77555 .30695 .78128 .31496 .79441 .3106 .78872 .30253 Mtetra
.664 .741 .907 r
.78872 .30253 .79441 .3106 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47065 .27559 .46388 Mtetra
.27559 .46388 .28278 .47065 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45592 .32003 .44903 Mtetra
.32003 .44903 .3271 .45592 .3383 .4522 .33125 .44529 Mtetra
.662 .74 .908 r
.33125 .44529 .3383 .4522 .34954 .4485 .34252 .44158 Mtetra
.653 .739 .912 r
.34252 .44158 .34954 .4485 .36083 .44498 .35383 .43813 Mtetra
.623 .733 .925 r
.35383 .43813 .36083 .44498 .37213 .44204 .36515 .43544 Mtetra
.576 .725 .944 r
.36515 .43544 .37213 .44204 .38344 .44015 .37648 .43377 Mtetra
.607 .744 .942 r
.37648 .43377 .38344 .44015 .39481 .43834 .3879 .43137 Mtetra
.765 .765 .852 r
.3879 .43137 .39481 .43834 .40638 .43265 .3996 .42335 Mtetra
.682 .69 .851 r
.3996 .42335 .40638 .43265 .41803 .4257 .4112 .41858 Mtetra
.664 .741 .907 r
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
0 .201 .703 r
.45797 .40295 .46468 .4102 .47639 .41154 .46957 .41191 Mtetra
.448 0 0 r
.46957 .41191 .47639 .41154 .48812 .41848 .48138 .4163 Mtetra
.254 .731 .936 r
.48138 .4163 .48812 .41848 .50003 .4206 .49335 .41604 Mtetra
.592 .813 .984 r
.49335 .41604 .50003 .4206 .51204 .41939 .50541 .41321 Mtetra
.66 .778 .936 r
.50541 .41321 .51204 .41939 .52413 .41641 .51753 .40924 Mtetra
.671 .751 .911 r
.51753 .40924 .52413 .41641 .53628 .41266 .52971 .40496 Mtetra
.668 .736 .901 r
.52971 .40496 .53628 .41266 .54847 .40868 .54195 .40072 Mtetra
.662 .728 .899 r
.54195 .40072 .54847 .40868 .56073 .40467 .55423 .39667 Mtetra
.655 .726 .901 r
.55423 .39667 .56073 .40467 .57304 .40062 .56658 .39282 Mtetra
.654 .731 .906 r
.56658 .39282 .57304 .40062 .58539 .39635 .57898 .38901 Mtetra
.663 .749 .914 r
.57898 .38901 .58539 .39635 .59779 .39129 .59144 .38489 Mtetra
.698 .789 .921 r
.59144 .38489 .59779 .39129 .61019 .38445 .60392 .37961 Mtetra
.773 .856 .912 r
.60392 .37961 .61019 .38445 .62251 .37422 .61637 .37173 Mtetra
.874 .926 .855 r
.61637 .37173 .62251 .37422 .63468 .3591 .6287 .35913 Mtetra
.93 .958 .772 r
.6287 .35913 .63468 .3591 .64703 .34961 .64085 .34187 Mtetra
.664 .741 .907 r
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.635 .729 .916 r
.69172 .32488 .69774 .33276 .71075 .33169 .70463 .32151 Mtetra
.531 .622 .887 r
.70463 .32151 .71075 .33169 .72376 .32933 .71782 .32148 Mtetra
.705 .759 .894 r
.71782 .32148 .72376 .32933 .73659 .323 .73072 .31568 Mtetra
.726 .782 .897 r
.73072 .31568 .73659 .323 .74946 .31674 .74362 .30912 Mtetra
.697 .765 .904 r
.74362 .30912 .74946 .31674 .76245 .31154 .75664 .3036 Mtetra
.674 .748 .907 r
.75664 .3036 .76245 .31154 .77555 .30695 .76977 .29888 Mtetra
.666 .742 .907 r
.76977 .29888 .77555 .30695 .78872 .30253 .78299 .2944 Mtetra
.664 .741 .907 r
.78299 .2944 .78872 .30253 .80196 .29813 .79627 .28996 Mtetra
.79627 .28996 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.663 .741 .907 r
.31289 .4421 .32003 .44903 .33125 .44529 .32415 .43833 Mtetra
.661 .74 .909 r
.32415 .43833 .33125 .44529 .34252 .44158 .33545 .43461 Mtetra
.649 .737 .914 r
.33545 .43461 .34252 .44158 .35383 .43813 .34678 .43123 Mtetra
.614 .73 .928 r
.34678 .43123 .35383 .43813 .36515 .43544 .35811 .42873 Mtetra
.569 .721 .945 r
.35811 .42873 .36515 .43544 .37648 .43377 .36946 .42718 Mtetra
.639 .749 .928 r
.36946 .42718 .37648 .43377 .3879 .43137 .38094 .42401 Mtetra
.773 .757 .839 r
.38094 .42401 .3879 .43137 .3996 .42335 .39271 .4153 Mtetra
.663 .716 .888 r
.39271 .4153 .3996 .42335 .4112 .41858 .40431 .4114 Mtetra
.664 .741 .907 r
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.413 .638 .949 r
.43941 .39961 .4462 .40689 .45797 .40295 .45109 .4009 Mtetra
.589 .015 0 r
.45109 .4009 .45797 .40295 .46957 .41191 .46272 .4093 Mtetra
.002 .547 .834 r
.46272 .4093 .46957 .41191 .48138 .4163 .4746 .41153 Mtetra
.54 .787 .989 r
.4746 .41153 .48138 .4163 .49335 .41604 .48662 .40967 Mtetra
.654 .771 .935 r
.48662 .40967 .49335 .41604 .50541 .41321 .49872 .40585 Mtetra
.677 .749 .905 r
.49872 .40585 .50541 .41321 .51753 .40924 .51089 .40134 Mtetra
.678 .735 .893 r
.51089 .40134 .51753 .40924 .52971 .40496 .5231 .39675 Mtetra
.671 .725 .89 r
.5231 .39675 .52971 .40496 .54195 .40072 .53537 .39236 Mtetra
.661 .719 .891 r
.53537 .39236 .54195 .40072 .55423 .39667 .54769 .38828 Mtetra
.652 .716 .895 r
.54769 .38828 .55423 .39667 .56658 .39282 .56007 .38451 Mtetra
.645 .716 .9 r
.56007 .38451 .56658 .39282 .57898 .38901 .57251 .38093 Mtetra
.647 .724 .905 r
.57251 .38093 .57898 .38901 .59144 .38489 .58501 .37729 Mtetra
.668 .746 .909 r
.58501 .37729 .59144 .38489 .60392 .37961 .59755 .37295 Mtetra
.726 .791 .904 r
.59755 .37295 .60392 .37961 .61637 .37173 .6101 .36662 Mtetra
.824 .853 .869 r
.6101 .36662 .61637 .37173 .6287 .35913 .62256 .35615 Mtetra
.917 .894 .792 r
.62256 .35615 .6287 .35913 .64085 .34187 .63481 .33938 Mtetra
.813 .941 .91 r
.63481 .33938 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.664 .741 .907 r
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70463 .32151 .69855 .3126 Mtetra
.488 .634 .919 r
.69855 .3126 .70463 .32151 .71782 .32148 .7118 .3132 Mtetra
.683 .741 .895 r
.7118 .3132 .71782 .32148 .73072 .31568 .7248 .30813 Mtetra
.729 .778 .892 r
.7248 .30813 .73072 .31568 .74362 .30912 .73773 .30139 Mtetra
.703 .766 .901 r
.73773 .30139 .74362 .30912 .75664 .3036 .75078 .29561 Mtetra
.677 .75 .906 r
.75078 .29561 .75664 .3036 .76977 .29888 .76395 .29073 Mtetra
.666 .742 .907 r
.76395 .29073 .76977 .29888 .78299 .2944 .77721 .2862 Mtetra
.664 .741 .907 r
.77721 .2862 .78299 .2944 .79627 .28996 .79053 .28171 Mtetra
.79053 .28171 .79627 .28996 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.663 .741 .908 r
.30571 .43511 .31289 .4421 .32415 .43833 .31699 .43131 Mtetra
.661 .74 .909 r
.31699 .43131 .32415 .43833 .33545 .43461 .32832 .42759 Mtetra
.647 .737 .915 r
.32832 .42759 .33545 .43461 .34678 .43123 .33967 .42425 Mtetra
.608 .727 .93 r
.33967 .42425 .34678 .43123 .35811 .42873 .35103 .42189 Mtetra
.569 .719 .943 r
.35103 .42189 .35811 .42873 .36946 .42718 .3624 .42034 Mtetra
.663 .75 .915 r
.3624 .42034 .36946 .42718 .38094 .42401 .37394 .41647 Mtetra
.766 .754 .842 r
.37394 .41647 .38094 .42401 .39271 .4153 .38573 .40809 Mtetra
.664 .741 .907 r
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.085 .448 .881 r
.43256 .39228 .43941 .39961 .45109 .4009 .44416 .39754 Mtetra
.421 0 0 r
.44416 .39754 .45109 .4009 .46272 .4093 .45585 .4045 Mtetra
.337 .692 .981 r
.45585 .4045 .46272 .4093 .4746 .41153 .46777 .4053 Mtetra
.612 .763 .951 r
.46777 .4053 .4746 .41153 .48662 .40967 .47984 .40249 Mtetra
.672 .753 .911 r
.47984 .40249 .48662 .40967 .49872 .40585 .49199 .39813 Mtetra
.684 .743 .895 r
.49199 .39813 .49872 .40585 .51089 .40134 .50419 .39331 Mtetra
.681 .734 .891 r
.50419 .39331 .51089 .40134 .5231 .39675 .51644 .38855 Mtetra
.673 .728 .891 r
.51644 .38855 .5231 .39675 .53537 .39236 .52874 .38407 Mtetra
.662 .723 .894 r
.52874 .38407 .53537 .39236 .54769 .38828 .54109 .37996 Mtetra
.65 .718 .898 r
.54109 .37996 .54769 .38828 .56007 .38451 .5535 .37621 Mtetra
.641 .717 .903 r
.5535 .37621 .56007 .38451 .57251 .38093 .56598 .37274 Mtetra
.638 .719 .906 r
.56598 .37274 .57251 .38093 .58501 .37729 .57852 .36933 Mtetra
.652 .732 .908 r
.57852 .36933 .58501 .37729 .59755 .37295 .59111 .36546 Mtetra
.698 .762 .901 r
.59111 .36546 .59755 .37295 .6101 .36662 .60372 .36003 Mtetra
.786 .808 .87 r
.60372 .36003 .6101 .36662 .62256 .35615 .61628 .35093 Mtetra
.883 .845 .802 r
.61628 .35093 .62256 .35615 .63481 .33938 .62865 .33558 Mtetra
.881 .89 .834 r
.62865 .33558 .63481 .33938 .64729 .32981 .64105 .3219 Mtetra
.664 .741 .907 r
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.489 .662 .939 r
.69246 .30455 .69855 .3126 .7118 .3132 .70573 .30474 Mtetra
.664 .731 .9 r
.70573 .30474 .7118 .3132 .7248 .30813 .71881 .30032 Mtetra
.728 .772 .888 r
.71881 .30032 .7248 .30813 .73773 .30139 .73179 .2935 Mtetra
.707 .765 .897 r
.73179 .2935 .73773 .30139 .75078 .29561 .74487 .28751 Mtetra
.679 .75 .904 r
.74487 .28751 .75078 .29561 .76395 .29073 .75808 .28252 Mtetra
.667 .743 .907 r
.75808 .28252 .76395 .29073 .77721 .2862 .77137 .27793 Mtetra
.664 .741 .907 r
.77137 .27793 .77721 .2862 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.663 .741 .908 r
.29846 .42806 .30571 .43511 .31699 .43131 .30978 .42424 Mtetra
.66 .74 .909 r
.30978 .42424 .31699 .43131 .32832 .42759 .32113 .42049 Mtetra
.645 .736 .915 r
.32113 .42049 .32832 .42759 .33967 .42425 .33251 .41717 Mtetra
.604 .725 .93 r
.33251 .41717 .33967 .42425 .35103 .42189 .34389 .41487 Mtetra
.571 .715 .94 r
.34389 .41487 .35103 .42189 .3624 .42034 .35528 .41329 Mtetra
.676 .748 .906 r
.35528 .41329 .3624 .42034 .37394 .41647 .36688 .40899 Mtetra
.763 .756 .847 r
.36688 .40899 .37394 .41647 .38573 .40809 .3787 .40083 Mtetra
.664 .741 .907 r
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
0 .323 .8 r
.42565 .3849 .43256 .39228 .44416 .39754 .43721 .39202 Mtetra
0 .335 .774 r
.43721 .39202 .44416 .39754 .45585 .4045 .44893 .39818 Mtetra
.454 .697 .971 r
.44893 .39818 .45585 .4045 .46777 .4053 .4609 .39828 Mtetra
.634 .746 .929 r
.4609 .39828 .46777 .4053 .47984 .40249 .47301 .39502 Mtetra
.679 .749 .904 r
.47301 .39502 .47984 .40249 .49199 .39813 .4852 .39041 Mtetra
.688 .745 .895 r
.4852 .39041 .49199 .39813 .50419 .39331 .49743 .38544 Mtetra
.684 .741 .894 r
.49743 .38544 .50419 .39331 .51644 .38855 .50972 .38059 Mtetra
.674 .736 .897 r
.50972 .38059 .51644 .38855 .52874 .38407 .52205 .37605 Mtetra
.662 .732 .901 r
.52205 .37605 .52874 .38407 .54109 .37996 .53444 .3719 Mtetra
.649 .727 .906 r
.53444 .3719 .54109 .37996 .5535 .37621 .54689 .36814 Mtetra
.639 .724 .91 r
.54689 .36814 .5535 .37621 .56598 .37274 .5594 .3647 Mtetra
.634 .724 .913 r
.5594 .3647 .56598 .37274 .57852 .36933 .57197 .36137 Mtetra
.645 .731 .912 r
.57197 .36137 .57852 .36933 .59111 .36546 .58461 .35769 Mtetra
.686 .752 .901 r
.58461 .35769 .59111 .36546 .60372 .36003 .59727 .35263 Mtetra
.767 .785 .867 r
.59727 .35263 .60372 .36003 .61628 .35093 .60989 .34418 Mtetra
.86 .81 .8 r
.60989 .34418 .61628 .35093 .62865 .33558 .62235 .32956 Mtetra
.878 .828 .794 r
.62235 .32956 .62865 .33558 .64105 .3219 .63475 .31393 Mtetra
.664 .741 .907 r
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.501 .668 .938 r
.68632 .29643 .69246 .30455 .70573 .30474 .69961 .29633 Mtetra
.652 .729 .906 r
.69961 .29633 .70573 .30474 .71881 .30032 .71275 .29227 Mtetra
.727 .768 .885 r
.71275 .29227 .71881 .30032 .73179 .2935 .72578 .28542 Mtetra
.709 .762 .893 r
.72578 .28542 .73179 .2935 .74487 .28751 .7389 .2793 Mtetra
.68 .749 .903 r
.7389 .2793 .74487 .28751 .75808 .28252 .75215 .27422 Mtetra
.667 .742 .907 r
.75215 .27422 .75808 .28252 .77137 .27793 .76549 .26958 Mtetra
.664 .741 .907 r
.76549 .26958 .77137 .27793 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.24627 .43628 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.663 .741 .908 r
.29116 .42096 .29846 .42806 .30978 .42424 .3025 .41711 Mtetra
.66 .74 .909 r
.3025 .41711 .30978 .42424 .32113 .42049 .31389 .41333 Mtetra
.645 .736 .915 r
.31389 .41333 .32113 .42049 .33251 .41717 .3253 .40998 Mtetra
.605 .723 .928 r
.3253 .40998 .33251 .41717 .34389 .41487 .3367 .40765 Mtetra
.572 .711 .937 r
.3367 .40765 .34389 .41487 .35528 .41329 .34812 .40604 Mtetra
.675 .744 .903 r
.34812 .40604 .35528 .41329 .36688 .40899 .35975 .40171 Mtetra
.765 .763 .85 r
.35975 .40171 .36688 .40899 .3787 .40083 .37161 .39351 Mtetra
.664 .741 .907 r
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
0 .323 .8 r
.41869 .37745 .42565 .3849 .43721 .39202 .43026 .38456 Mtetra
.003 .393 .848 r
.43026 .38456 .43721 .39202 .44893 .39818 .44199 .3907 Mtetra
.483 .673 .948 r
.44199 .3907 .44893 .39818 .4609 .39828 .45398 .39077 Mtetra
.635 .734 .92 r
.45398 .39077 .4609 .39828 .47301 .39502 .46613 .38749 Mtetra
.679 .748 .904 r
.46613 .38749 .47301 .39502 .4852 .39041 .47835 .38284 Mtetra
.688 .751 .899 r
.47835 .38284 .4852 .39041 .49743 .38544 .49062 .37784 Mtetra
.684 .75 .901 r
.49062 .37784 .49743 .38544 .50972 .38059 .50294 .37295 Mtetra
.675 .747 .905 r
.50294 .37295 .50972 .38059 .52205 .37605 .51531 .36837 Mtetra
.662 .743 .91 r
.51531 .36837 .52205 .37605 .53444 .3719 .52774 .36418 Mtetra
.649 .739 .915 r
.52774 .36418 .53444 .3719 .54689 .36814 .54022 .36039 Mtetra
.638 .735 .918 r
.54022 .36039 .54689 .36814 .5594 .3647 .55277 .35692 Mtetra
.633 .733 .92 r
.55277 .35692 .5594 .3647 .57197 .36137 .56538 .35355 Mtetra
.645 .737 .916 r
.56538 .35355 .57197 .36137 .58461 .35769 .57805 .34984 Mtetra
.686 .751 .901 r
.57805 .34984 .58461 .35769 .59727 .35263 .59075 .34475 Mtetra
.764 .773 .86 r
.59075 .34475 .59727 .35263 .60989 .34418 .60342 .33625 Mtetra
.847 .785 .79 r
.60342 .33625 .60989 .34418 .62235 .32956 .61594 .32158 Mtetra
.857 .785 .78 r
.61594 .32158 .62235 .32956 .63475 .31393 .6284 .30589 Mtetra
.664 .741 .907 r
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.501 .668 .938 r
.68014 .28824 .68632 .29643 .69961 .29633 .69345 .28812 Mtetra
.652 .737 .912 r
.69345 .28812 .69961 .29633 .71275 .29227 .70664 .28402 Mtetra
.727 .764 .882 r
.70664 .28402 .71275 .29227 .72578 .28542 .71972 .27712 Mtetra
.708 .757 .891 r
.71972 .27712 .72578 .28542 .7389 .2793 .73288 .27096 Mtetra
.68 .747 .902 r
.73288 .27096 .7389 .2793 .75215 .27422 .74617 .26585 Mtetra
.667 .742 .906 r
.74617 .26585 .75215 .27422 .76549 .26958 .75956 .26116 Mtetra
.664 .741 .907 r
.75956 .26116 .76549 .26958 .7789 .26501 .77301 .25656 Mtetra
.77301 .25656 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23798 Mtetra
.82746 .23798 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43628 .23879 .42924 Mtetra
.23879 .42924 .24627 .43628 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.663 .741 .907 r
.2838 .4138 .29116 .42096 .3025 .41711 .29517 .40991 Mtetra
.661 .74 .909 r
.29517 .40991 .3025 .41711 .31389 .41333 .30659 .4061 Mtetra
.647 .736 .914 r
.30659 .4061 .31389 .41333 .3253 .40998 .31803 .40267 Mtetra
.609 .722 .926 r
.31803 .40267 .3253 .40998 .3367 .40765 .32946 .40023 Mtetra
.573 .708 .933 r
.32946 .40023 .3367 .40765 .34812 .40604 .34091 .39859 Mtetra
.663 .737 .905 r
.34091 .39859 .34812 .40604 .35975 .40171 .35254 .39463 Mtetra
.772 .77 .851 r
.35254 .39463 .35975 .40171 .37161 .39351 .36446 .38613 Mtetra
.664 .741 .907 r
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.085 .448 .881 r
.41167 .36994 .41869 .37745 .43026 .38456 .42331 .37514 Mtetra
.066 .376 .841 r
.42331 .37514 .43026 .38456 .44199 .3907 .43502 .38206 Mtetra
.468 .632 .926 r
.43502 .38206 .44199 .3907 .45398 .39077 .44702 .38279 Mtetra
.621 .718 .915 r
.44702 .38279 .45398 .39077 .46613 .38749 .45918 .37988 Mtetra
.672 .746 .906 r
.45918 .37988 .46613 .38749 .47835 .38284 .47143 .37542 Mtetra
.686 .756 .905 r
.47143 .37542 .47835 .38284 .49062 .37784 .48375 .37049 Mtetra
.683 .759 .909 r
.48375 .37049 .49062 .37784 .50294 .37295 .49611 .36563 Mtetra
.675 .758 .914 r
.49611 .36563 .50294 .37295 .51531 .36837 .50852 .36104 Mtetra
.662 .755 .919 r
.50852 .36104 .51531 .36837 .52774 .36418 .52098 .35682 Mtetra
.649 .751 .924 r
.52098 .35682 .52774 .36418 .54022 .36039 .5335 .35297 Mtetra
.639 .746 .926 r
.5335 .35297 .54022 .36039 .55277 .35692 .54608 .3494 Mtetra
.636 .744 .926 r
.54608 .3494 .55277 .35692 .56538 .35355 .55873 .34589 Mtetra
.652 .746 .919 r
.55873 .34589 .56538 .35355 .57805 .34984 .57144 .34191 Mtetra
.697 .755 .896 r
.57144 .34191 .57805 .34984 .59075 .34475 .58417 .33637 Mtetra
.773 .764 .846 r
.58417 .33637 .59075 .34475 .60342 .33625 .59687 .32714 Mtetra
.843 .762 .773 r
.59687 .32714 .60342 .33625 .61594 .32158 .60943 .31162 Mtetra
.818 .743 .781 r
.60943 .31162 .61594 .32158 .6284 .30589 .622 .29779 Mtetra
.664 .741 .907 r
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.489 .662 .939 r
.67389 .27998 .68014 .28824 .69345 .28812 .68726 .28009 Mtetra
.664 .749 .913 r
.68726 .28009 .69345 .28812 .70664 .28402 .70047 .27555 Mtetra
.726 .76 .88 r
.70047 .27555 .70664 .28402 .71972 .27712 .71359 .26861 Mtetra
.706 .753 .889 r
.71359 .26861 .71972 .27712 .73288 .27096 .72681 .26249 Mtetra
.679 .745 .901 r
.72681 .26249 .73288 .27096 .74617 .26585 .74014 .25738 Mtetra
.667 .742 .906 r
.74014 .25738 .74617 .26585 .75956 .26116 .75357 .25267 Mtetra
.664 .741 .907 r
.75357 .25267 .75956 .26116 .77301 .25656 .76707 .24803 Mtetra
.76707 .24803 .77301 .25656 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23798 .82171 .22928 Mtetra
.82171 .22928 .82746 .23798 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40659 Mtetra
.663 .741 .907 r
.27638 .40659 .2838 .4138 .29517 .40991 .28778 .40267 Mtetra
.661 .74 .908 r
.28778 .40267 .29517 .40991 .30659 .4061 .29923 .39879 Mtetra
.649 .736 .913 r
.29923 .39879 .30659 .4061 .31803 .40267 .3107 .39526 Mtetra
.616 .723 .923 r
.3107 .39526 .31803 .40267 .32946 .40023 .32217 .39262 Mtetra
.576 .705 .93 r
.32217 .39262 .32946 .40023 .34091 .39859 .33365 .39093 Mtetra
.64 .726 .91 r
.33365 .39093 .34091 .39859 .35254 .39463 .34528 .3876 Mtetra
.779 .773 .848 r
.34528 .3876 .35254 .39463 .36446 .38613 .35725 .37869 Mtetra
.664 .741 .907 r
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.413 .638 .949 r
.40459 .36236 .41167 .36994 .42331 .37514 .41638 .36353 Mtetra
.077 .326 .804 r
.41638 .36353 .42331 .37514 .43502 .38206 .42804 .37188 Mtetra
.422 .569 .896 r
.42804 .37188 .43502 .38206 .44702 .38279 .44002 .374 Mtetra
.59 .685 .908 r
.44002 .374 .44702 .38279 .45918 .37988 .45219 .37199 Mtetra
.656 .735 .908 r
.45219 .37199 .45918 .37988 .47143 .37542 .46446 .36799 Mtetra
.677 .756 .91 r
.46446 .36799 .47143 .37542 .48375 .37049 .47681 .36331 Mtetra
.68 .764 .915 r
.47681 .36331 .48375 .37049 .49611 .36563 .48921 .35854 Mtetra
.673 .766 .921 r
.48921 .35854 .49611 .36563 .50852 .36104 .50166 .35398 Mtetra
.662 .765 .926 r
.50166 .35398 .50852 .36104 .52098 .35682 .51416 .34973 Mtetra
.651 .761 .93 r
.51416 .34973 .52098 .35682 .5335 .35297 .52672 .34578 Mtetra
.643 .757 .931 r
.52672 .34578 .5335 .35297 .54608 .3494 .53934 .34204 Mtetra
.645 .753 .928 r
.53934 .34204 .54608 .3494 .55873 .34589 .55203 .33822 Mtetra
.668 .753 .914 r
.55203 .33822 .55873 .34589 .57144 .34191 .56476 .3337 Mtetra
.72 .755 .881 r
.56476 .3337 .57144 .34191 .58417 .33637 .57753 .32718 Mtetra
.788 .751 .82 r
.57753 .32718 .58417 .33637 .59687 .32714 .59024 .31647 Mtetra
.839 .736 .75 r
.59024 .31647 .59687 .32714 .60943 .31162 .60281 .29941 Mtetra
.748 .686 .792 r
.60281 .29941 .60943 .31162 .622 .29779 .61554 .28961 Mtetra
.664 .741 .907 r
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.471 .653 .939 r
.6676 .27166 .67389 .27998 .68726 .28009 .68102 .27211 Mtetra
.685 .76 .908 r
.68102 .27211 .68726 .28009 .70047 .27555 .69423 .26684 Mtetra
.724 .755 .877 r
.69423 .26684 .70047 .27555 .71359 .26861 .7074 .25989 Mtetra
.701 .748 .888 r
.7074 .25989 .71359 .26861 .72681 .26249 .72067 .25391 Mtetra
.677 .743 .901 r
.72067 .25391 .72681 .26249 .74014 .25738 .73406 .24883 Mtetra
.666 .741 .906 r
.73406 .24883 .74014 .25738 .75357 .25267 .74754 .2441 Mtetra
.664 .741 .907 r
.74754 .2441 .75357 .25267 .76707 .24803 .76108 .23942 Mtetra
.76108 .23942 .76707 .24803 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40659 .2689 .39931 Mtetra
.2689 .39931 .27638 .40659 .28778 .40267 .28033 .39536 Mtetra
.662 .74 .908 r
.28033 .39536 .28778 .40267 .29923 .39879 .29181 .39143 Mtetra
.653 .737 .911 r
.29181 .39143 .29923 .39879 .3107 .39526 .30332 .38776 Mtetra
.624 .725 .919 r
.30332 .38776 .3107 .39526 .32217 .39262 .31483 .38487 Mtetra
.582 .705 .926 r
.31483 .38487 .32217 .39262 .33365 .39093 .32634 .38301 Mtetra
.613 .712 .915 r
.32634 .38301 .33365 .39093 .34528 .3876 .33795 .38041 Mtetra
.767 .769 .855 r
.33795 .38041 .34528 .3876 .35725 .37869 .34994 .37211 Mtetra
.694 .775 .914 r
.34994 .37211 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.664 .741 .907 r
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41638 .36353 .40946 .35057 Mtetra
.101 .313 .788 r
.40946 .35057 .41638 .36353 .42804 .37188 .42109 .35945 Mtetra
.356 .482 .85 r
.42109 .35945 .42804 .37188 .44002 .374 .433 .36372 Mtetra
.537 .627 .888 r
.433 .36372 .44002 .374 .45219 .37199 .44515 .36326 Mtetra
.625 .703 .902 r
.44515 .36326 .45219 .37199 .46446 .36799 .45744 .36021 Mtetra
.661 .743 .91 r
.45744 .36021 .46446 .36799 .47681 .36331 .46982 .356 Mtetra
.671 .76 .917 r
.46982 .356 .47681 .36331 .48921 .35854 .48225 .35148 Mtetra
.669 .768 .924 r
.48225 .35148 .48921 .35854 .50166 .35398 .49474 .34699 Mtetra
.662 .769 .929 r
.49474 .34699 .50166 .35398 .51416 .34973 .50728 .3427 Mtetra
.654 .766 .932 r
.50728 .3427 .51416 .34973 .52672 .34578 .51988 .33861 Mtetra
.653 .762 .93 r
.51988 .33861 .52672 .34578 .53934 .34204 .53254 .33455 Mtetra
.663 .757 .921 r
.53254 .33455 .53934 .34204 .55203 .33822 .54526 .33018 Mtetra
.696 .754 .896 r
.54526 .33018 .55203 .33822 .56476 .3337 .55803 .32464 Mtetra
.748 .745 .849 r
.55803 .32464 .56476 .3337 .57753 .32718 .57081 .31647 Mtetra
.801 .727 .783 r
.57081 .31647 .57753 .32718 .59024 .31647 .58352 .30351 Mtetra
.822 .702 .732 r
.58352 .30351 .59024 .31647 .60281 .29941 .59612 .28584 Mtetra
.648 .623 .812 r
.59612 .28584 .60281 .29941 .61554 .28961 .60903 .28137 Mtetra
.664 .741 .907 r
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.635 .729 .916 r
.6481 .26781 .65449 .27618 .6676 .27166 .66129 .26419 Mtetra
.485 .69 .958 r
.66129 .26419 .6676 .27166 .68102 .27211 .67471 .26395 Mtetra
.705 .764 .898 r
.67471 .26395 .68102 .27211 .69423 .26684 .68793 .25787 Mtetra
.72 .749 .875 r
.68793 .25787 .69423 .26684 .7074 .25989 .70115 .25101 Mtetra
.695 .743 .889 r
.70115 .25101 .7074 .25989 .72067 .25391 .71449 .24521 Mtetra
.673 .741 .901 r
.71449 .24521 .72067 .25391 .73406 .24883 .72793 .24021 Mtetra
.666 .741 .906 r
.72793 .24021 .73406 .24883 .74754 .2441 .74144 .23546 Mtetra
.664 .741 .907 r
.74144 .23546 .74754 .2441 .76108 .23942 .75503 .23074 Mtetra
.75503 .23074 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39536 .27283 .38799 Mtetra
.663 .74 .908 r
.27283 .38799 .28033 .39536 .29181 .39143 .28433 .38401 Mtetra
.656 .738 .91 r
.28433 .38401 .29181 .39143 .30332 .38776 .29588 .38021 Mtetra
.635 .729 .916 r
.29588 .38021 .30332 .38776 .31483 .38487 .30744 .37701 Mtetra
.594 .707 .923 r
.30744 .37701 .31483 .38487 .32634 .38301 .31898 .37486 Mtetra
.591 .699 .918 r
.31898 .37486 .32634 .38301 .33795 .38041 .33059 .3728 Mtetra
.716 .752 .88 r
.33059 .3728 .33795 .38041 .34994 .37211 .34248 .3668 Mtetra
.759 .824 .903 r
.34248 .3668 .34994 .37211 .36178 .3671 .35449 .35951 Mtetra
.664 .741 .907 r
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.414 .638 .948 r
.4023 .34284 .40946 .35057 .42109 .35945 .4142 .34396 Mtetra
.297 .393 .792 r
.4142 .34396 .42109 .35945 .433 .36372 .42602 .35077 Mtetra
.465 .536 .845 r
.42602 .35077 .433 .36372 .44515 .36326 .43811 .35269 Mtetra
.574 .639 .878 r
.43811 .35269 .44515 .36326 .45744 .36021 .45038 .35122 Mtetra
.63 .701 .897 r
.45038 .35122 .45744 .36021 .46982 .356 .46277 .34795 Mtetra
.655 .736 .909 r
.46277 .34795 .46982 .356 .48225 .35148 .47523 .3439 Mtetra
.662 .752 .917 r
.47523 .3439 .48225 .35148 .49474 .34699 .48776 .3396 Mtetra
.662 .759 .922 r
.48776 .3396 .49474 .34699 .50728 .3427 .50034 .33528 Mtetra
.50034 .33528 .50728 .3427 .51988 .33861 .51298 .33092 Mtetra
.669 .755 .914 r
.51298 .33092 .51988 .33861 .53254 .33455 .52568 .32632 Mtetra
.691 .748 .895 r
.52568 .32632 .53254 .33455 .54526 .33018 .53844 .32093 Mtetra
.727 .735 .857 r
.53844 .32093 .54526 .33018 .55803 .32464 .55122 .31372 Mtetra
.77 .716 .801 r
.55122 .31372 .55803 .32464 .57081 .31647 .56401 .30307 Mtetra
.802 .691 .742 r
.56401 .30307 .57081 .31647 .58352 .30351 .57672 .28746 Mtetra
.72 .628 .754 r
.57672 .28746 .58352 .30351 .59612 .28584 .58951 .27756 Mtetra
.664 .741 .907 r
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.549 .692 .934 r
.64166 .25938 .6481 .26781 .66129 .26419 .65498 .25802 Mtetra
.577 .778 .974 r
.65498 .25802 .66129 .26419 .67471 .26395 .66834 .25535 Mtetra
.718 .758 .884 r
.66834 .25535 .67471 .26395 .68793 .25787 .68157 .24864 Mtetra
.713 .742 .875 r
.68157 .24864 .68793 .25787 .70115 .25101 .69485 .24201 Mtetra
.687 .739 .891 r
.69485 .24201 .70115 .25101 .71449 .24521 .70824 .23645 Mtetra
.671 .74 .902 r
.70824 .23645 .71449 .24521 .72793 .24021 .72173 .23151 Mtetra
.665 .74 .906 r
.72173 .23151 .72793 .24021 .74144 .23546 .7353 .22674 Mtetra
.664 .741 .907 r
.7353 .22674 .74144 .23546 .75503 .23074 .74893 .22198 Mtetra
.74893 .22198 .75503 .23074 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20274 Mtetra
.80412 .20274 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38799 .26526 .38056 Mtetra
.663 .741 .908 r
.26526 .38056 .27283 .38799 .28433 .38401 .2768 .37654 Mtetra
.659 .739 .909 r
.2768 .37654 .28433 .38401 .29588 .38021 .28838 .37261 Mtetra
.644 .732 .913 r
.28838 .37261 .29588 .38021 .30744 .37701 .29998 .36912 Mtetra
.61 .714 .919 r
.29998 .36912 .30744 .37701 .31898 .37486 .31158 .36654 Mtetra
.583 .693 .917 r
.31158 .36654 .31898 .37486 .33059 .3728 .32319 .36466 Mtetra
.656 .724 .899 r
.32319 .36466 .33059 .3728 .34248 .3668 .335 .36074 Mtetra
.786 .805 .868 r
.335 .36074 .34248 .3668 .35449 .35951 .34713 .35185 Mtetra
.664 .741 .907 r
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .4142 .34396 .4072 .33079 Mtetra
.414 .503 .841 r
.4072 .33079 .4142 .34396 .42602 .35077 .41913 .33395 Mtetra
.402 .44 .786 r
.41913 .33395 .42602 .35077 .43811 .35269 .43112 .33866 Mtetra
.508 .542 .826 r
.43112 .33866 .43811 .35269 .45038 .35122 .44334 .33956 Mtetra
.582 .623 .858 r
.44334 .33956 .45038 .35122 .46277 .34795 .45571 .33786 Mtetra
.625 .675 .878 r
.45571 .33786 .46277 .34795 .47523 .3439 .46819 .33471 Mtetra
.648 .706 .89 r
.46819 .33471 .47523 .3439 .48776 .3396 .48074 .33079 Mtetra
.661 .721 .894 r
.48074 .33079 .48776 .3396 .50034 .33528 .49335 .32642 Mtetra
.673 .726 .889 r
.49335 .32642 .50034 .33528 .51298 .33092 .50603 .32161 Mtetra
.691 .722 .873 r
.50603 .32161 .51298 .33092 .52568 .32632 .51877 .31603 Mtetra
.717 .71 .843 r
.51877 .31603 .52568 .32632 .53844 .32093 .53155 .30899 Mtetra
.748 .692 .798 r
.53155 .30899 .53844 .32093 .55122 .31372 .54435 .2993 Mtetra
.773 .669 .748 r
.54435 .2993 .55122 .31372 .56401 .30307 .55713 .28576 Mtetra
.736 .624 .734 r
.55713 .28576 .56401 .30307 .57672 .28746 .56992 .27374 Mtetra
.647 .623 .812 r
.56992 .27374 .57672 .28746 .58951 .27756 .58284 .26921 Mtetra
.664 .741 .907 r
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.478 .657 .939 r
.63515 .25087 .64166 .25938 .65498 .25802 .64858 .25107 Mtetra
.67 .79 .938 r
.64858 .25107 .65498 .25802 .66834 .25535 .66189 .2462 Mtetra
.721 .747 .873 r
.66189 .2462 .66834 .25535 .68157 .24864 .67515 .23923 Mtetra
.703 .736 .877 r
.67515 .23923 .68157 .24864 .69485 .24201 .6885 .23296 Mtetra
.68 .737 .894 r
.6885 .23296 .69485 .24201 .70824 .23645 .70195 .22763 Mtetra
.668 .739 .904 r
.70195 .22763 .70824 .23645 .72173 .23151 .71549 .22274 Mtetra
.665 .741 .907 r
.71549 .22274 .72173 .23151 .7353 .22674 .7291 .21794 Mtetra
.664 .741 .907 r
.7291 .21794 .7353 .22674 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20274 .79816 .19373 Mtetra
.79816 .19373 .80412 .20274 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.20052 .39321 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .38521 Mtetra
.22321 .38521 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37308 Mtetra
.25762 .37308 .26526 .38056 .2768 .37654 .2692 .369 Mtetra
.661 .74 .908 r
.2692 .369 .2768 .37654 .28838 .37261 .28081 .36499 Mtetra
.652 .735 .91 r
.28081 .36499 .28838 .37261 .29998 .36912 .29246 .36122 Mtetra
.627 .721 .915 r
.29246 .36122 .29998 .36912 .31158 .36654 .30412 .35817 Mtetra
.591 .696 .916 r
.30412 .35817 .31158 .36654 .32319 .36466 .31577 .35605 Mtetra
.608 .697 .907 r
.31577 .35605 .32319 .36466 .335 .36074 .32751 .35351 Mtetra
.733 .77 .882 r
.32751 .35351 .335 .36074 .34713 .35185 .33956 .34683 Mtetra
.749 .837 .918 r
.33956 .34683 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.664 .741 .907 r
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41913 .33395 .41217 .31859 Mtetra
.508 .522 .806 r
.41217 .31859 .41913 .33395 .43112 .33866 .42426 .31964 Mtetra
.458 .45 .762 r
.42426 .31964 .43112 .33866 .44334 .33956 .43639 .32308 Mtetra
.529 .521 .791 r
.43639 .32308 .44334 .33956 .45571 .33786 .4487 .32353 Mtetra
.584 .58 .815 r
.4487 .32353 .45571 .33786 .46819 .33471 .46116 .32177 Mtetra
.622 .621 .829 r
.46116 .32177 .46819 .33471 .48074 .33079 .47371 .3185 Mtetra
.651 .646 .832 r
.47371 .3185 .48074 .33079 .49335 .32642 .48635 .3141 Mtetra
.675 .656 .824 r
.48635 .3141 .49335 .32642 .50603 .32161 .49906 .30855 Mtetra
.699 .655 .803 r
.49906 .30855 .50603 .32161 .51877 .31603 .51182 .30149 Mtetra
.723 .646 .772 r
.51182 .30149 .51877 .31603 .53155 .30899 .52462 .29219 Mtetra
.743 .632 .737 r
.52462 .29219 .53155 .30899 .54435 .2993 .53743 .27985 Mtetra
.7 .589 .728 r
.53743 .27985 .54435 .2993 .55713 .28576 .55025 .26991 Mtetra
.639 .591 .785 r
.55025 .26991 .55713 .28576 .56992 .27374 .56316 .26536 Mtetra
.664 .741 .907 r
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.569 .702 .931 r
.61538 .24695 .62198 .25549 .63515 .25087 .62869 .24505 Mtetra
.54 .777 .986 r
.62869 .24505 .63515 .25087 .64858 .25107 .64207 .24292 Mtetra
.711 .77 .899 r
.64207 .24292 .64858 .25107 .66189 .2462 .65536 .23656 Mtetra
.713 .735 .868 r
.65536 .23656 .66189 .2462 .67515 .23923 .66868 .22975 Mtetra
.692 .732 .881 r
.66868 .22975 .67515 .23923 .6885 .23296 .68209 .2239 Mtetra
.674 .736 .897 r
.68209 .2239 .6885 .23296 .70195 .22763 .6956 .21877 Mtetra
.666 .74 .905 r
.6956 .21877 .70195 .22763 .71549 .22274 .70919 .21389 Mtetra
.664 .741 .907 r
.70919 .21389 .71549 .22274 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.19268 .38582 .20052 .39321 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .38521 .21543 .37776 Mtetra
.21543 .37776 .22321 .38521 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37308 .24993 .36553 Mtetra
.24993 .36553 .25762 .37308 .2692 .369 .26153 .36142 Mtetra
.663 .74 .908 r
.26153 .36142 .2692 .369 .28081 .36499 .27318 .35733 Mtetra
.658 .738 .909 r
.27318 .35733 .28081 .36499 .29246 .36122 .28488 .35336 Mtetra
.642 .728 .912 r
.28488 .35336 .29246 .36122 .30412 .35817 .29659 .34986 Mtetra
.61 .707 .913 r
.29659 .34986 .30412 .35817 .31577 .35605 .3083 .34721 Mtetra
.59 .686 .908 r
.3083 .34721 .31577 .35605 .32751 .35351 .32004 .34511 Mtetra
.652 .72 .899 r
.32004 .34511 .32751 .35351 .33956 .34683 .33195 .34125 Mtetra
.79 .823 .878 r
.33195 .34125 .33956 .34683 .35166 .33992 .34421 .33231 Mtetra
.671 .749 .909 r
.34421 .33231 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.664 .741 .907 r
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42426 .31964 .4172 .30623 Mtetra
.647 .623 .812 r
.4172 .30623 .42426 .31964 .43639 .32308 .42956 .30185 Mtetra
.524 .471 .739 r
.42956 .30185 .43639 .32308 .4487 .32353 .44183 .30281 Mtetra
.55 .492 .743 r
.44183 .30281 .4487 .32353 .46116 .32177 .45423 .30247 Mtetra
.593 .529 .752 r
.45423 .30247 .46116 .32177 .47371 .3185 .46676 .29996 Mtetra
.629 .556 .754 r
.46676 .29996 .47371 .3185 .48635 .3141 .4794 .29551 Mtetra
.659 .573 .747 r
.4794 .29551 .48635 .3141 .49906 .30855 .49211 .28911 Mtetra
.684 .58 .732 r
.49211 .28911 .49906 .30855 .51182 .30149 .50488 .28052 Mtetra
.692 .573 .717 r
.50488 .28052 .51182 .30149 .52462 .29219 .51768 .27061 Mtetra
.62 .528 .729 r
.51768 .27061 .52462 .29219 .53743 .27985 .5305 .26606 Mtetra
.647 .623 .812 r
.5305 .26606 .53743 .27985 .55025 .26991 .54339 .2615 Mtetra
.664 .741 .907 r
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.657 .738 .91 r
.59553 .24301 .60223 .25159 .61538 .24695 .60873 .23855 Mtetra
.476 .663 .944 r
.60873 .23855 .61538 .24695 .62869 .24505 .62214 .23864 Mtetra
.673 .811 .949 r
.62214 .23864 .62869 .24505 .64207 .24292 .63546 .23356 Mtetra
.717 .744 .873 r
.63546 .23356 .64207 .24292 .65536 .23656 .64878 .22666 Mtetra
.701 .726 .87 r
.64878 .22666 .65536 .23656 .66868 .22975 .66216 .22032 Mtetra
.681 .731 .888 r
.66216 .22032 .66868 .22975 .68209 .2239 .67564 .21485 Mtetra
.669 .737 .901 r
.67564 .21485 .68209 .2239 .6956 .21877 .6892 .20985 Mtetra
.665 .74 .906 r
.6892 .20985 .6956 .21877 .70919 .21389 .70284 .20498 Mtetra
.664 .741 .907 r
.70284 .20498 .70919 .21389 .72285 .20907 .71654 .20012 Mtetra
.71654 .20012 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36142 .25381 .35377 Mtetra
.663 .741 .907 r
.25381 .35377 .26153 .36142 .27318 .35733 .26549 .34962 Mtetra
.661 .739 .908 r
.26549 .34962 .27318 .35733 .28488 .35336 .27722 .34552 Mtetra
.652 .734 .909 r
.27722 .34552 .28488 .35336 .29659 .34986 .28899 .34167 Mtetra
.631 .719 .91 r
.28899 .34167 .29659 .34986 .3083 .34721 .30076 .33842 Mtetra
.601 .693 .908 r
.30076 .33842 .3083 .34721 .32004 .34511 .31254 .336 Mtetra
.604 .687 .901 r
.31254 .336 .32004 .34511 .33195 .34125 .32439 .33352 Mtetra
.687 .751 .9 r
.32439 .33352 .33195 .34125 .34421 .33231 .33646 .32848 Mtetra
.791 .878 .91 r
.33646 .32848 .34421 .33231 .35624 .32784 .34877 .31992 Mtetra
.664 .741 .907 r
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44183 .30281 .43475 .28927 Mtetra
.647 .624 .813 r
.43475 .28927 .44183 .30281 .45423 .30247 .44726 .28481 Mtetra
.631 .566 .763 r
.44726 .28481 .45423 .30247 .46676 .29996 .45982 .28033 Mtetra
.625 .545 .744 r
.45982 .28033 .46676 .29996 .4794 .29551 .47245 .27583 Mtetra
.47245 .27583 .4794 .29551 .49211 .28911 .48513 .27131 Mtetra
.631 .566 .763 r
.48513 .27131 .49211 .28911 .50488 .28052 .49788 .26676 Mtetra
.647 .624 .813 r
.49788 .26676 .50488 .28052 .51768 .27061 .51068 .2622 Mtetra
.664 .741 .907 r
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.5 .669 .939 r
.58877 .23436 .59553 .24301 .60873 .23855 .60212 .23399 Mtetra
.604 .849 .991 r
.60212 .23399 .60873 .23855 .62214 .23864 .61546 .23003 Mtetra
.713 .761 .891 r
.61546 .23003 .62214 .23864 .63546 .23356 .62878 .22346 Mtetra
.706 .725 .864 r
.62878 .22346 .63546 .23356 .64878 .22666 .64214 .21681 Mtetra
.687 .724 .878 r
.64214 .21681 .64878 .22666 .66216 .22032 .65559 .21101 Mtetra
.673 .733 .895 r
.65559 .21101 .66216 .22032 .67564 .21485 .66913 .20582 Mtetra
.666 .738 .904 r
.66913 .20582 .67564 .21485 .6892 .20985 .68274 .20088 Mtetra
.664 .74 .907 r
.68274 .20088 .6892 .20985 .70284 .20498 .69643 .19599 Mtetra
.664 .741 .907 r
.69643 .19599 .70284 .20498 .71654 .20012 .71018 .19108 Mtetra
.71018 .19108 .71654 .20012 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16622 Mtetra
.77994 .16622 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34962 .25773 .34187 Mtetra
.663 .74 .907 r
.25773 .34187 .26549 .34962 .27722 .34552 .2695 .33769 Mtetra
.659 .738 .908 r
.2695 .33769 .27722 .34552 .28899 .34167 .28131 .3336 Mtetra
.647 .729 .909 r
.28131 .3336 .28899 .34167 .30076 .33842 .29315 .32985 Mtetra
.623 .709 .907 r
.29315 .32985 .30076 .33842 .31254 .336 .30499 .32677 Mtetra
.601 .684 .901 r
.30499 .32677 .31254 .336 .32439 .33352 .31686 .32434 Mtetra
.617 .693 .898 r
.31686 .32434 .32439 .33352 .33646 .32848 .32883 .32143 Mtetra
.702 .776 .909 r
.32883 .32143 .33646 .32848 .34877 .31992 .34101 .31589 Mtetra
.784 .875 .915 r
.34101 .31589 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.664 .741 .907 r
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.514 .677 .939 r
.56875 .23037 .57561 .23906 .58877 .23436 .58203 .22966 Mtetra
.583 .837 .993 r
.58203 .22966 .58877 .23436 .60212 .23399 .59535 .22614 Mtetra
.706 .78 .91 r
.59535 .22614 .60212 .23399 .61546 .23003 .60867 .21993 Mtetra
.707 .726 .865 r
.60867 .21993 .61546 .23003 .62878 .22346 .62203 .21323 Mtetra
.691 .718 .869 r
.62203 .21323 .62878 .22346 .64214 .21681 .63546 .20718 Mtetra
.676 .727 .888 r
.63546 .20718 .64214 .21681 .65559 .21101 .64898 .20181 Mtetra
.668 .736 .901 r
.64898 .20181 .65559 .21101 .66913 .20582 .66257 .19678 Mtetra
.665 .739 .906 r
.66257 .19678 .66913 .20582 .68274 .20088 .67623 .19185 Mtetra
.664 .741 .907 r
.67623 .19185 .68274 .20088 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16622 .77376 .15688 Mtetra
.77376 .15688 .77994 .16622 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.663 .741 .907 r
.24991 .33406 .25773 .34187 .2695 .33769 .26171 .32982 Mtetra
.662 .74 .908 r
.26171 .32982 .2695 .33769 .28131 .3336 .27356 .3256 Mtetra
.657 .735 .908 r
.27356 .3256 .28131 .3336 .29315 .32985 .28545 .32153 Mtetra
.644 .724 .907 r
.28545 .32153 .29315 .32985 .30499 .32677 .29736 .31783 Mtetra
.621 .701 .902 r
.29736 .31783 .30499 .32677 .31686 .32434 .3093 .31477 Mtetra
.605 .68 .895 r
.3093 .31477 .31686 .32434 .32883 .32143 .32126 .31218 Mtetra
.623 .696 .897 r
.32126 .31218 .32883 .32143 .34101 .31589 .33333 .30905 Mtetra
.693 .783 .92 r
.33333 .30905 .34101 .31589 .35339 .30757 .34558 .30377 Mtetra
.787 .885 .917 r
.34558 .30377 .35339 .30757 .36559 .3032 .35805 .29528 Mtetra
.671 .749 .909 r
.35805 .29528 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.664 .741 .907 r
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.657 .738 .91 r
.53551 .2311 .54251 .23978 .5556 .23509 .54864 .22658 Mtetra
.505 .679 .944 r
.54864 .22658 .5556 .23509 .56875 .23037 .56188 .22596 Mtetra
.594 .851 .993 r
.56188 .22596 .56875 .23037 .58203 .22966 .57516 .2221 Mtetra
.702 .788 .917 r
.57516 .2221 .58203 .22966 .59535 .22614 .58848 .21604 Mtetra
.705 .726 .866 r
.58848 .21604 .59535 .22614 .60867 .21993 .60183 .20942 Mtetra
.692 .713 .865 r
.60183 .20942 .60867 .21993 .62203 .21323 .61525 .20327 Mtetra
.678 .721 .882 r
.61525 .20327 .62203 .21323 .63546 .20718 .62874 .19778 Mtetra
.669 .732 .897 r
.62874 .19778 .63546 .20718 .64898 .20181 .64231 .19266 Mtetra
.665 .738 .904 r
.64231 .19266 .64898 .20181 .66257 .19678 .65595 .18769 Mtetra
.664 .74 .907 r
.65595 .18769 .66257 .19678 .67623 .19185 .66966 .18274 Mtetra
.664 .741 .907 r
.66966 .18274 .67623 .19185 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14232 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32982 .25385 .32191 Mtetra
.663 .74 .907 r
.25385 .32191 .26171 .32982 .27356 .3256 .26573 .31761 Mtetra
.661 .739 .907 r
.26573 .31761 .27356 .3256 .28545 .32153 .27767 .31336 Mtetra
.656 .733 .907 r
.27767 .31336 .28545 .32153 .29736 .31783 .28964 .30926 Mtetra
.643 .72 .904 r
.28964 .30926 .29736 .31783 .3093 .31477 .30165 .30552 Mtetra
.624 .697 .897 r
.30165 .30552 .3093 .31477 .32126 .31218 .31368 .30233 Mtetra
.611 .678 .89 r
.31368 .30233 .32126 .31218 .33333 .30905 .32574 .29953 Mtetra
.621 .691 .894 r
.32574 .29953 .33333 .30905 .34558 .30377 .3379 .29638 Mtetra
.668 .764 .922 r
.3379 .29638 .34558 .30377 .35805 .29528 .35019 .29182 Mtetra
.731 .896 .954 r
.35019 .29182 .35805 .29528 .37036 .29064 .36266 .28513 Mtetra
.749 .837 .918 r
.36266 .28513 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.664 .741 .907 r
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.566 .702 .933 r
.51534 .22709 .52244 .23581 .53551 .2311 .52845 .2251 Mtetra
.556 .784 .984 r
.52845 .2251 .53551 .2311 .54864 .22658 .54164 .22258 Mtetra
.626 .876 .988 r
.54164 .22258 .54864 .22658 .56188 .22596 .55489 .21791 Mtetra
.702 .775 .908 r
.55489 .21791 .56188 .22596 .57516 .2221 .56819 .21179 Mtetra
.701 .72 .865 r
.56819 .21179 .57516 .2221 .58848 .21604 .58154 .20532 Mtetra
.689 .708 .862 r
.58154 .20532 .58848 .21604 .60183 .20942 .59494 .19924 Mtetra
.678 .717 .878 r
.59494 .19924 .60183 .20942 .61525 .20327 .60842 .1937 Mtetra
.67 .729 .894 r
.60842 .1937 .61525 .20327 .62874 .19778 .62197 .18853 Mtetra
.666 .737 .903 r
.62197 .18853 .62874 .19778 .64231 .19266 .63559 .18352 Mtetra
.664 .74 .906 r
.63559 .18352 .64231 .19266 .65595 .18769 .64927 .17854 Mtetra
.664 .741 .907 r
.64927 .17854 .65595 .18769 .66966 .18274 .66303 .17355 Mtetra
.66303 .17355 .66966 .18274 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14232 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .32191 .24592 .31393 Mtetra
.24592 .31393 .25385 .32191 .26573 .31761 .25784 .30959 Mtetra
.663 .74 .907 r
.25784 .30959 .26573 .31761 .27767 .31336 .26981 .30525 Mtetra
.661 .738 .907 r
.26981 .30525 .27767 .31336 .28964 .30926 .28183 .30094 Mtetra
.656 .732 .906 r
.28183 .30094 .28964 .30926 .30165 .30552 .2939 .29677 Mtetra
.645 .719 .901 r
.2939 .29677 .30165 .30552 .31368 .30233 .306 .2929 Mtetra
.63 .698 .894 r
.306 .2929 .31368 .30233 .32574 .29953 .31813 .28946 Mtetra
.619 .679 .885 r
.31813 .28946 .32574 .29953 .3379 .29638 .3303 .28637 Mtetra
.62 .682 .886 r
.3303 .28637 .3379 .29638 .35019 .29182 .34254 .2832 Mtetra
.642 .725 .908 r
.34254 .2832 .35019 .29182 .36266 .28513 .35489 .27936 Mtetra
.677 .818 .951 r
.35489 .27936 .36266 .28513 .37519 .27791 .36736 .27438 Mtetra
.706 .895 .965 r
.36736 .27438 .37519 .27791 .38763 .2734 .37993 .26825 Mtetra
.737 .851 .933 r
.37993 .26825 .38763 .2734 .40013 .26886 .39258 .26138 Mtetra
.694 .775 .914 r
.39258 .26138 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.664 .741 .907 r
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.634 .73 .917 r
.4691 .23255 .47639 .24122 .48931 .23653 .48205 .22877 Mtetra
.577 .735 .95 r
.48205 .22877 .48931 .23653 .50229 .23182 .49505 .22634 Mtetra
.581 .81 .986 r
.49505 .22634 .50229 .23182 .51534 .22709 .50814 .22317 Mtetra
.608 .871 .992 r
.50814 .22317 .51534 .22709 .52845 .2251 .52131 .21884 Mtetra
.684 .821 .949 r
.52131 .21884 .52845 .2251 .54164 .22258 .53454 .21335 Mtetra
.699 .744 .887 r
.53454 .21335 .54164 .22258 .55489 .21791 .54782 .20718 Mtetra
.693 .709 .861 r
.54782 .20718 .55489 .21791 .56819 .21179 .56116 .20093 Mtetra
.684 .704 .862 r
.56116 .20093 .56819 .21179 .58154 .20532 .57455 .19502 Mtetra
.676 .714 .877 r
.57455 .19502 .58154 .20532 .59494 .19924 .58801 .18954 Mtetra
.669 .727 .892 r
.58801 .18954 .59494 .19924 .60842 .1937 .60154 .18436 Mtetra
.666 .735 .902 r
.60154 .18436 .60842 .1937 .62197 .18853 .61514 .17932 Mtetra
.664 .739 .906 r
.61514 .17932 .62197 .18853 .63559 .18352 .6288 .17432 Mtetra
.664 .74 .907 r
.6288 .17432 .63559 .18352 .64927 .17854 .64253 .16931 Mtetra
.664 .741 .907 r
.64253 .16931 .64927 .17854 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30525 .26189 .29711 Mtetra
.663 .74 .907 r
.26189 .29711 .26981 .30525 .28183 .30094 .27394 .29271 Mtetra
.662 .738 .907 r
.27394 .29271 .28183 .30094 .2939 .29677 .28606 .28834 Mtetra
.658 .732 .905 r
.28606 .28834 .2939 .29677 .306 .2929 .29821 .28406 Mtetra
.65 .721 .9 r
.29821 .28406 .306 .2929 .31813 .28946 .31041 .28 Mtetra
.639 .702 .892 r
.31041 .28 .31813 .28946 .3303 .28637 .32265 .27623 Mtetra
.629 .684 .883 r
.32265 .27623 .3303 .28637 .34254 .2832 .33494 .27273 Mtetra
.625 .676 .878 r
.33494 .27273 .34254 .2832 .35489 .27936 .34728 .26934 Mtetra
.631 .689 .886 r
.34728 .26934 .35489 .27936 .36736 .27438 .3597 .26575 Mtetra
.645 .73 .91 r
.3597 .26575 .36736 .27438 .37993 .26825 .37221 .26174 Mtetra
.659 .795 .947 r
.37221 .26174 .37993 .26825 .39258 .26138 .3848 .25722 Mtetra
.655 .869 .98 r
.3848 .25722 .39258 .26138 .40522 .25585 .39747 .25232 Mtetra
.649 .888 .983 r
.39747 .25232 .40522 .25585 .41787 .25123 .4102 .24729 Mtetra
.65 .877 .982 r
.4102 .24729 .41787 .25123 .43059 .24659 .42298 .24235 Mtetra
.642 .866 .983 r
.42298 .24235 .43059 .24659 .44337 .24193 .43581 .23765 Mtetra
.629 .862 .986 r
.43581 .23765 .44337 .24193 .45621 .23725 .4487 .2332 Mtetra
.617 .867 .99 r
.4487 .2332 .45621 .23725 .4691 .23255 .46165 .22884 Mtetra
.615 .878 .99 r
.46165 .22884 .4691 .23255 .48205 .22877 .47466 .22435 Mtetra
.646 .867 .982 r
.47466 .22435 .48205 .22877 .49505 .22634 .48775 .21947 Mtetra
.682 .802 .939 r
.48775 .21947 .49505 .22634 .50814 .22317 .5009 .21409 Mtetra
.691 .745 .893 r
.5009 .21409 .50814 .22317 .52131 .21884 .51411 .20826 Mtetra
.689 .711 .865 r
.51411 .20826 .52131 .21884 .53454 .21335 .52738 .20224 Mtetra
.683 .699 .858 r
.52738 .20224 .53454 .21335 .54782 .20718 .5407 .19632 Mtetra
.678 .702 .866 r
.5407 .19632 .54782 .20718 .56116 .20093 .55408 .19066 Mtetra
.672 .714 .88 r
.55408 .19066 .56116 .20093 .57455 .19502 .56752 .18531 Mtetra
.668 .727 .893 r
.56752 .18531 .57455 .19502 .58801 .18954 .58103 .18016 Mtetra
.666 .735 .902 r
.58103 .18016 .58801 .18954 .60154 .18436 .5946 .17511 Mtetra
.664 .739 .906 r
.5946 .17511 .60154 .18436 .61514 .17932 .60825 .17009 Mtetra
.664 .74 .907 r
.60825 .17009 .61514 .17932 .6288 .17432 .62196 .16505 Mtetra
.664 .741 .907 r
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24185 .29337 Mtetra
.24185 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27394 .29271 .26599 .28447 Mtetra
.663 .74 .907 r
.26599 .28447 .27394 .29271 .28606 .28834 .27813 .28 Mtetra
.662 .738 .906 r
.27813 .28 .28606 .28834 .29821 .28406 .29034 .27555 Mtetra
.66 .734 .905 r
.29034 .27555 .29821 .28406 .31041 .28 .30259 .27115 Mtetra
.655 .725 .901 r
.30259 .27115 .31041 .28 .32265 .27623 .31489 .26687 Mtetra
.648 .711 .893 r
.31489 .26687 .32265 .27623 .33494 .27273 .32724 .26276 Mtetra
.641 .695 .884 r
.32724 .26276 .33494 .27273 .34728 .26934 .33964 .25882 Mtetra
.637 .682 .876 r
.33964 .25882 .34728 .26934 .3597 .26575 .3521 .25498 Mtetra
.636 .677 .872 r
.3521 .25498 .3597 .26575 .37221 .26174 .36462 .25114 Mtetra
.64 .683 .875 r
.36462 .25114 .37221 .26174 .3848 .25722 .37721 .24717 Mtetra
.646 .699 .885 r
.37721 .24717 .3848 .25722 .39747 .25232 .38988 .24301 Mtetra
.653 .72 .897 r
.38988 .24301 .39747 .25232 .4102 .24729 .40261 .23862 Mtetra
.659 .739 .909 r
.40261 .23862 .4102 .24729 .42298 .24235 .41542 .23405 Mtetra
.664 .752 .915 r
.41542 .23405 .42298 .24235 .43581 .23765 .42829 .22931 Mtetra
.668 .753 .914 r
.42829 .22931 .43581 .23765 .4487 .2332 .44123 .22441 Mtetra
.673 .744 .904 r
.44123 .22441 .4487 .2332 .46165 .22884 .45423 .21932 Mtetra
.676 .728 .889 r
.45423 .21932 .46165 .22884 .47466 .22435 .4673 .214 Mtetra
.678 .71 .873 r
.4673 .214 .47466 .22435 .48775 .21947 .48043 .20849 Mtetra
.678 .698 .862 r
.48043 .20849 .48775 .21947 .5009 .21409 .49362 .20284 Mtetra
.676 .693 .858 r
.49362 .20284 .5009 .21409 .51411 .20826 .50686 .19718 Mtetra
.674 .696 .863 r
.50686 .19718 .51411 .20826 .52738 .20224 .52016 .19163 Mtetra
.672 .706 .873 r
.52016 .19163 .52738 .20224 .5407 .19632 .53352 .18624 Mtetra
.669 .718 .886 r
.53352 .18624 .5407 .19632 .55408 .19066 .54695 .18103 Mtetra
.667 .729 .896 r
.54695 .18103 .55408 .19066 .56752 .18531 .56043 .17592 Mtetra
.665 .736 .903 r
.56043 .17592 .56752 .18531 .58103 .18016 .57399 .17087 Mtetra
.664 .739 .906 r
.57399 .17087 .58103 .18016 .5946 .17511 .58761 .16583 Mtetra
.664 .74 .907 r
.58761 .16583 .5946 .17511 .60825 .17009 .6013 .16078 Mtetra
.664 .741 .907 r
.6013 .16078 .60825 .17009 .62196 .16505 .61505 .15571 Mtetra
.61505 .15571 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13516 Mtetra
.67076 .13516 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32883 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .3116 Mtetra
.16249 .3116 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24185 .29337 .23376 .28515 Mtetra
.23376 .28515 .24185 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .28 .27014 .27166 Mtetra
.664 .74 .907 r
.27014 .27166 .27813 .28 .29034 .27555 .28238 .26713 Mtetra
.663 .739 .907 r
.28238 .26713 .29034 .27555 .30259 .27115 .29467 .26259 Mtetra
.662 .736 .905 r
.29467 .26259 .30259 .27115 .31489 .26687 .30702 .25807 Mtetra
.659 .73 .902 r
.30702 .25807 .31489 .26687 .32724 .26276 .31943 .2536 Mtetra
.656 .721 .897 r
.31943 .2536 .32724 .26276 .33964 .25882 .33188 .24919 Mtetra
.652 .71 .89 r
.33188 .24919 .33964 .25882 .3521 .25498 .3444 .24486 Mtetra
.649 .698 .882 r
.3444 .24486 .3521 .25498 .36462 .25114 .35697 .24057 Mtetra
.647 .688 .875 r
.35697 .24057 .36462 .25114 .37721 .24717 .3696 .23629 Mtetra
.648 .683 .869 r
.3696 .23629 .37721 .24717 .38988 .24301 .3823 .23194 Mtetra
.65 .681 .866 r
.3823 .23194 .38988 .24301 .40261 .23862 .39507 .22748 Mtetra
.653 .681 .864 r
.39507 .22748 .40261 .23862 .41542 .23405 .4079 .22287 Mtetra
.657 .683 .863 r
.4079 .22287 .41542 .23405 .42829 .22931 .4208 .21809 Mtetra
.661 .684 .862 r
.4208 .21809 .42829 .22931 .44123 .22441 .43377 .21314 Mtetra
.664 .686 .86 r
.43377 .21314 .44123 .22441 .45423 .21932 .4468 .20803 Mtetra
.666 .687 .86 r
.4468 .20803 .45423 .21932 .4673 .214 .4599 .20281 Mtetra
.668 .691 .862 r
.4599 .20281 .4673 .214 .48043 .20849 .47305 .19753 Mtetra
.668 .696 .867 r
.47305 .19753 .48043 .20849 .49362 .20284 .48627 .19224 Mtetra
.668 .705 .875 r
.48627 .19224 .49362 .20284 .50686 .19718 .49955 .187 Mtetra
.667 .715 .884 r
.49955 .187 .50686 .19718 .52016 .19163 .51288 .18183 Mtetra
.666 .725 .893 r
.51288 .18183 .52016 .19163 .53352 .18624 .52629 .17672 Mtetra
.665 .732 .9 r
.52629 .17672 .53352 .18624 .54695 .18103 .53975 .17166 Mtetra
.664 .737 .904 r
.53975 .17166 .54695 .18103 .56043 .17592 .55328 .16662 Mtetra
.664 .739 .906 r
.55328 .16662 .56043 .17592 .57399 .17087 .56688 .16156 Mtetra
.664 .74 .907 r
.56688 .16156 .57399 .17087 .58761 .16583 .58055 .15649 Mtetra
.664 .741 .907 r
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .15571 .60808 .14627 Mtetra
.60808 .14627 .61505 .15571 .62887 .1506 .62195 .14113 Mtetra
.62195 .14113 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13516 .66398 .12553 Mtetra
.66398 .12553 .67076 .13516 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32883 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .3116 .15414 .30354 Mtetra
.15414 .30354 .16249 .3116 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26713 .27435 .25868 Mtetra
.664 .74 .907 r
.27435 .25868 .28238 .26713 .29467 .26259 .28668 .25408 Mtetra
.663 .74 .907 r
.28668 .25408 .29467 .26259 .30702 .25807 .29907 .24947 Mtetra
.663 .738 .906 r
.29907 .24947 .30702 .25807 .31943 .2536 .31151 .24485 Mtetra
.662 .735 .904 r
.31151 .24485 .31943 .2536 .33188 .24919 .32402 .24023 Mtetra
.661 .731 .901 r
.32402 .24023 .33188 .24919 .3444 .24486 .33658 .23562 Mtetra
.659 .724 .897 r
.33658 .23562 .3444 .24486 .35697 .24057 .3492 .23102 Mtetra
.658 .717 .892 r
.3492 .23102 .35697 .24057 .3696 .23629 .36188 .22641 Mtetra
.657 .71 .887 r
.36188 .22641 .3696 .23629 .3823 .23194 .37462 .22179 Mtetra
.658 .705 .882 r
.37462 .22179 .3823 .23194 .39507 .22748 .38742 .21711 Mtetra
.658 .702 .879 r
.38742 .21711 .39507 .22748 .4079 .22287 .40029 .21237 Mtetra
.66 .7 .877 r
.40029 .21237 .4079 .22287 .4208 .21809 .41323 .20755 Mtetra
.661 .701 .876 r
.41323 .20755 .4208 .21809 .43377 .21314 .42623 .20264 Mtetra
.663 .703 .877 r
.42623 .20264 .43377 .21314 .4468 .20803 .43929 .19766 Mtetra
.664 .708 .88 r
.43929 .19766 .4468 .20803 .4599 .20281 .45241 .19263 Mtetra
.665 .713 .884 r
.45241 .19263 .4599 .20281 .47305 .19753 .4656 .18758 Mtetra
.665 .72 .89 r
.4656 .18758 .47305 .19753 .48627 .19224 .47885 .18253 Mtetra
.665 .726 .895 r
.47885 .18253 .48627 .19224 .49955 .187 .49216 .17748 Mtetra
.665 .732 .9 r
.49216 .17748 .49955 .187 .51288 .18183 .50554 .17244 Mtetra
.664 .736 .903 r
.50554 .17244 .51288 .18183 .52629 .17672 .51898 .16739 Mtetra
.664 .739 .906 r
.51898 .16739 .52629 .17672 .53975 .17166 .53249 .16234 Mtetra
.664 .74 .907 r
.53249 .16234 .53975 .17166 .55328 .16662 .54607 .15727 Mtetra
.54607 .15727 .55328 .16662 .56688 .16156 .55971 .15218 Mtetra
.664 .741 .907 r
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14113 .61496 .13156 Mtetra
.61496 .13156 .62195 .14113 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25408 .27861 .24552 Mtetra
.27861 .24552 .28668 .25408 .29907 .24947 .29104 .24086 Mtetra
.664 .74 .907 r
.29104 .24086 .29907 .24947 .31151 .24485 .30352 .23617 Mtetra
.30352 .23617 .31151 .24485 .32402 .24023 .31606 .23147 Mtetra
.663 .739 .906 r
.31606 .23147 .32402 .24023 .33658 .23562 .32866 .22676 Mtetra
.663 .737 .905 r
.32866 .22676 .33658 .23562 .3492 .23102 .34132 .22202 Mtetra
.663 .734 .903 r
.34132 .22202 .3492 .23102 .36188 .22641 .35405 .21727 Mtetra
.662 .732 .901 r
.35405 .21727 .36188 .22641 .37462 .22179 .36683 .2125 Mtetra
.662 .729 .899 r
.36683 .2125 .37462 .22179 .38742 .21711 .37967 .2077 Mtetra
.662 .727 .897 r
.37967 .2077 .38742 .21711 .40029 .21237 .39258 .20287 Mtetra
.663 .726 .896 r
.39258 .20287 .40029 .21237 .41323 .20755 .40555 .198 Mtetra
.40555 .198 .41323 .20755 .42623 .20264 .41859 .19309 Mtetra
.663 .728 .897 r
.41859 .19309 .42623 .20264 .43929 .19766 .43168 .18815 Mtetra
.664 .73 .899 r
.43168 .18815 .43929 .19766 .45241 .19263 .44484 .18319 Mtetra
.664 .732 .901 r
.44484 .18319 .45241 .19263 .4656 .18758 .45807 .1782 Mtetra
.664 .735 .903 r
.45807 .1782 .4656 .18758 .47885 .18253 .47136 .17319 Mtetra
.664 .737 .904 r
.47136 .17319 .47885 .18253 .49216 .17748 .48471 .16816 Mtetra
.664 .739 .906 r
.48471 .16816 .49216 .17748 .50554 .17244 .49813 .16312 Mtetra
.664 .74 .907 r
.49813 .16312 .50554 .17244 .51898 .16739 .51162 .15805 Mtetra
.51162 .15805 .51898 .16739 .53249 .16234 .52517 .15296 Mtetra
.664 .741 .907 r
.52517 .15296 .53249 .16234 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23147 .30803 .22271 Mtetra
.30803 .22271 .31606 .23147 .32866 .22676 .32067 .21794 Mtetra
.664 .74 .907 r
.32067 .21794 .32866 .22676 .34132 .22202 .33337 .21315 Mtetra
.33337 .21315 .34132 .22202 .35405 .21727 .34613 .20833 Mtetra
.664 .739 .906 r
.34613 .20833 .35405 .21727 .36683 .2125 .35895 .2035 Mtetra
.35895 .2035 .36683 .2125 .37967 .2077 .37184 .19863 Mtetra
.664 .738 .905 r
.37184 .19863 .37967 .2077 .39258 .20287 .38478 .19375 Mtetra
.38478 .19375 .39258 .20287 .40555 .198 .39779 .18883 Mtetra
.39779 .18883 .40555 .198 .41859 .19309 .41086 .18389 Mtetra
.41086 .18389 .41859 .19309 .43168 .18815 .424 .17893 Mtetra
.664 .739 .906 r
.424 .17893 .43168 .18815 .44484 .18319 .4372 .17394 Mtetra
.4372 .17394 .44484 .18319 .45807 .1782 .45047 .16893 Mtetra
.664 .74 .907 r
.45047 .16893 .45807 .1782 .47136 .17319 .4638 .16389 Mtetra
.4638 .16389 .47136 .17319 .48471 .16816 .47719 .15883 Mtetra
.664 .741 .907 r
.47719 .15883 .48471 .16816 .49813 .16312 .49065 .15375 Mtetra
.49065 .15375 .49813 .16312 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21315 .32534 .20423 Mtetra
.32534 .20423 .33337 .21315 .34613 .20833 .33814 .19937 Mtetra
.33814 .19937 .34613 .20833 .35895 .2035 .351 .19448 Mtetra
.664 .74 .907 r
.351 .19448 .35895 .2035 .37184 .19863 .36392 .18957 Mtetra
.36392 .18957 .37184 .19863 .38478 .19375 .37691 .18464 Mtetra
.37691 .18464 .38478 .19375 .39779 .18883 .38996 .17968 Mtetra
.38996 .17968 .39779 .18883 .41086 .18389 .40307 .1747 Mtetra
.40307 .1747 .41086 .18389 .424 .17893 .41624 .1697 Mtetra
.41624 .1697 .424 .17893 .4372 .17394 .42949 .16467 Mtetra
.664 .741 .907 r
.42949 .16467 .4372 .17394 .45047 .16893 .44279 .15961 Mtetra
.44279 .15961 .45047 .16893 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41624 .1697 .40842 .16039 Mtetra
.40842 .16039 .41624 .1697 .42949 .16467 .4217 .15531 Mtetra
.4217 .15531 .42949 .16467 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11379 Mtetra
.53037 .11379 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26677 Mtetra
.09942 .26677 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13036 Mtetra
.45422 .13036 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11379 .52286 .10396 Mtetra
.52286 .10396 .53037 .11379 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13036 .44641 .12069 Mtetra
.44641 .12069 .45422 .13036 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .03299 Mtetra
.67312 .03299 .68016 .04348 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .1926 Mtetra
.2287 .1926 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18274 Mtetra
.25404 .18274 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16777 Mtetra
.29251 .16777 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14746 Mtetra
.34469 .14746 .35285 .15688 .36602 .15178 .3579 .14232 Mtetra
.3579 .14232 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18844 Mtetra
.20751 .18844 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18274 .24553 .17355 Mtetra
.24553 .17355 .25404 .18274 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16777 .28411 .15844 Mtetra
.28411 .15844 .29251 .16777 .30546 .16272 .2971 .15336 Mtetra
.2971 .15336 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13794 Mtetra
.33645 .13794 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0LP2Y_NP00`000000ZKgX0:Vmj00I
0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08oo
o`0V0?ooo`800000N@2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00001k0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00001n0:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?oo
o`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`000000
0`2Y_NP000000:Vmj01C0:Vmj0<0ZKgW9`2Y_NP00`000000ZKgX0:Vmj00J0:Vmj0030000003oool0
oooo04X0oooo001:0?ooo`030?ooS`0e000000000080000000<0=Hoo0?ooo`3oool06P3oool00`2Y
_NP00000000000120:Vmj0D0ZKgW1@2Y_NP60:Vmi`D0ZKgX1P2Y_NLV0:Vmj0030000002Y_NP0ZKgX
01/0ZKgX00<000000?ooo`3oool0B@3oool004X0oooo00<0ooo405lD501Oa?l07@3oool300000480
ZKgX0`2Y_>L50:Vmi`80ZKgX0`2Y_>L60:Vmi`D0ZKcW2P2Y_NLQ0:Vmj0030000002Y_NP0ZKgX01`0
ZKgX00<000000?ooo`3oool0B03oool004/0oooo00<0ScD003F?o`3oool06P3oool2000003P0ZKgX
1P2Y_NL50:Vmj0H0ZKcW102Y_NL60:Vli`<0ZKgW0`2Z^nH50:Vli`80ZKgW0`2Z_>L:0:Vmia/0ZKgX
00<000000:Vmj02Y_NP0702Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@000000000
00000000000e08oooa<0oooo00@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0:Vmj00c0:Vm
j0T0ZKgW2P2Y_>L50:ZkiPH0ZKcW1P2Z^nH40:Vli`H0Z[cW0P2Y_NL30:ZliPD0ZKgW0`2Y_NP30:Vm
ia@0ZKgX00<000000:Vmj02Y_NP07@2Y_NP00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP0
00000000000i0:Vmj0T0ZKgW0`2Y^nH70:Vli`<0Z[WU1@2Z^nH60:Zii0D0Z[_V1@2Z^^D50:Zli`H0
Z[cV2`2Y_NL20:Vmj0<0ZKgW3P2Y_NP00`000000ZKgX0:Vmj00N0:Vmj0030000003oool0oooo04H0
oooo001O0?ooo`@00000=`2Y_NP60:Vli`D0ZKgW1P2Y^nH40:Vli`H0Z[WU0P2Z^nH30:ZghPH0Z[WT
0P2Z^nH30:^ghPD0Z[[U1@2[^^@;0:ZliP/0ZKgW3@2Y_NP00`000000ZKgX0:Vmj00N0:Vmj0030000
003oool0oooo04H0oooo001M0?ooo`040:Vmj00000000000000003L0ZKgX2@2Y_>L50:VjiPD0ZK_V
1@2Z^><50:Zii@H0Z[OR1@2Z^N@60:^ghP80Z[[U0`2/]^450:^ji080Z[cV0`2[^^@60:ZliPD0Z[cW
1@2Y_NL=0:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00
000h0:Vmj0T0ZKcW0`2Y^^D50:VjiP80ZK_V0`2Z]^850:Zhh`80Z[WU0`2[]=l60:ZghPD0[;CO1@2[
]n860:bfh@X0Zk[T0`2Z_>H30:^ji0D0Z[cW0P2Y_NL30:Zli``0ZKgX00<000000:Vmj02Y_NP07`2Y
_NP00`3oool000000?ooo`150?ooo`00F03oool3000003P0ZKgX2P2Y_>L60:Vji@@0ZK[V1P2Z]^84
0:Zhh`H0ZkCO0`2Z]n830:bbg0D0[;CO0P2[]n830:fcg@D0[;KQ1@2]]^0<0:^ji0X0Z[cW0P2Y_NP3
0:Zmi`H0ZKgX00<000000:Vmj02Y_NP0802Y_NP00`000000oooo0?ooo`140?ooo`00E@3oool00`2Y
_NP000000000000i0:Vmj0P0ZKcW1@2Y^ND50:Vji@D0ZKGQ1@2Z]^850:^bg@H0ZkCO1@2//]`50:bd
g`H0[K?M0P2/]^430:ndg0D0[KKP0P2[^^@30:fgh0H0Zk[T1@2[^nD50:Zli`H0Z[gW1@2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y
_NP0=P2Y_NP80:Vli`P0ZKWU0P2Y^^D30:Vch0D0ZKGQ0P2Z]^830:^`g0D0Zk;M0`2[]=l30:faf`D0
[;;L0P2/]=l30:jbf`D0[K?M1@2_]=`50:ffh0H0[KOP0`2[^^@30:fhh@D0Zk_U1@2[_>H50:Zmi`D0
ZKgX00<000000:Vmj02Y_NP08P2Y_NP00`000000oooo0?ooo`120?ooo`00D@3oool2000003P0ZKgX
1@2Y_NL50:Vli`X0ZKWU1P2Y/n040:Veh@H0Zk3L1@2[/]d60:faf`@0[;;L1P2^/]/20:fcg@<0/KGL
1@2_]=`20:ffh0<0/;GL1P2]]n060:fhh@80Zk_U0`2]^^<50:^liP80Z[gW0`2Z_>L40:Vmj0030000
002Y_NP0ZKgX0280ZKgX00<000000?ooo`3oool0@P3oool004h0oooo0`00000f0:Vmj0X0ZKgW1@2Y
^^D50:Vii@X0ZK?P1@2Z[m`60:^`g080Zk;M0`2]/]`50:faf`D0/;KM1@2^/]/50;6eg0D0[kCL1P2`
]M`30:fgh0<0/KKM1@2]^>460:fjh`@0ZkcV1P2Z_>L20:Vmj0030:Zmi`000000Z[gW02@0ZKgX00<0
00000?ooo`3oool0@@3oool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@0000000000
55l0a?oo02T0oooo0P00000j0:Vmj0L0ZKgW0`2Y^^H50:Vji@80ZKWU0`2X/n070:Vch0<0ZJoL1@2Z
[m`50:^`g0H0[K;L0P2]/M/30;2ni0D0/;KM0P2^/]/30;:nh`D0/KGL0P2_]=`30;>hg@D0/;GL1`2a
]]d20:fhh@<0/;ON1@2]^^<50:bki@D0Z[cW0`2Z_NL00`000000Z[gW0:Zmi`0T0:Vmj0030000003o
ool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@001AOa03oool0a5lD000e
SbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX03P0ZKgX102Y_NL60:VjiP@0ZK[U1P2X/n040:Vc
h0H0ZJoL1@2Z[m`50:feg`D0[K;L1@2`_^@50;2fg@H0/[kS102a]M`60;>hg@80/;GL0`2d^Md60;6f
g@H0/;ON0P2]^^<30:nih0D0[;_U1@2[_>H20:Zmi`030000002Z_NL0Z[gW02@0ZKgX00<000000?oo
o`3oool02P3oool01@3ookl0M00000000000B9`0gooo0340oooo000I0?ooo`0;0?oOW01807@0_ooo
0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool08P3oool00`2Y_NP00000000000100:Vmj0D0
ZK_V1@2Y^^H50:Rch@D0Z;?P2`2Y[m`20:Z_g0<0[K[S1@2]]Ml20:fbg0<0[/g`1@2`_^@20;2fg@<0
[m;b1@2b_^<50;?6j0D0/kSM1P2d^Md30;6fg@<0];WM1@2`]mh60:nih080[;_U0`2^^n<50:^liP80
Z[gW00<000000:Zmi`2Z_NL0902Y_NP00`000000oooo0?ooo`080?ooo`060?oog`2LB000B9cO0?oo
o`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`030?oo
o`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l0803oool300000400
ZKgX0`2Y^nL50:VkiP80ZK[V0`2X]>450:Rch@<0Z;?P0P2X[]`:0:V_g0H0[K[S102]]Ml60:k=l0@0
/;kT1P2_d_820;:nh`<0X>3l1@2ca^P20;>hg@<0/lWZ302d^Md20;2ggP<0];WM1@2_^N060:jkh`@0
ZkcV0P2Z_NL010000000Z[gW0:Zmi`2Z_NL20:Vmj0<0Z[gX7P2Y_NP00`000000oooo0?ooo`080?oo
o`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3o
ool0okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`0000100:Vmj0H0ZK_W102Y^nH60:Rd
h@D0Z;?Q1@2X[]`50:V_g0D0[;kW1@2]^^<50:GMn`D0[/g`1@2Kg_d50:oBlPH0X>3l102ca^P60;?9
jP<0];WM0`2danP;0;Big@80[kWP0`2c^Mh50:jkh`D0[;cU00<0Z[gW0000002Z_NL00P2Z_NL60:Zm
j1h0ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03o
ool001T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0K0?oo
o`<00000?`2Y_NP60:Vli`D0ZK_W102X]N<60:Rdh@D0YjkM1@2X[]`20:V_g0<0Zl3Y1@2/_^L20:fj
h`<0WN3m1@2UgO/609C?o0@0Vmkm1P2>b?/40:3Po0D0V=Wn1@2cbNX70;C7j080];WM0`2f`^@50;Bi
g@H0/kWN0P2^^n<30;6kh@D0[;cU00<000000:^mi`2[_NL00P2[_NL50:Zmj1l0ZKgX00<000000?oo
o`3oool01P3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0<03oool001L0oooo00d0_g@0
0000B02L_i`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0P000011
0:Vmj080ZKgW1P2Y_>L50:Rgi0@0Z;GS0`2X]>430:J^g@D0YjkM102X[]`60:_0j@@0[;kW1P2Mh?d5
09>ll`<0U<ol0`2Y_NP5092ckPD0Z;cX1@21[O4409SIoPH0UMKn1@2danP60;K2i080];WM0`2g_]l5
0;>igPH0/K_Q0P2/_>D20:jli0030000002[_NL0ZkgW00<0ZkgW0P2Z_NP30:Zmiah0ZKgX00<00000
0?ooo`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool001P0oooo00/0
okmd0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<00000@@2Y_NP5
0:Vmi`<0ZKcW0`2X^ND50:Rgi0@0Z;GS1@2V[]d50:N^g@D0ZL3Z1@2[`>T609gMo@D0X[[Z1@2C_?<6
0:Vmj080T;?^0`2Y_NP50:Rlj080PJga0`2Y_NP508>]l0D0UMKn1@2JfOd50;K2i0H0]kkO0P2c^Mh3
0;JlgPD0/K_Q102^_>@00`000000[[cT0:^mi`030:^mi`H0Z[gW7P2Y_NP00`000000oooo0?ooo`05
0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;oo
o`020?ooo`050?ooS`0e00000000000DG`34ool0503oool3000000030:Vmj0000000ZKgX0480ZKgX
1@2Y_NL60:Rii@@0Z;OT1@2U[]h50:J^g@80YjkM0`2X_NP50:W0jPH0XMcl1@2Y_NP50::jjQ00ZKgX
102X_>P60:Vmj080Pjg`0`2Y_NP507n[l0D0V]Wm0P2f`^@30:c?lPD0]kkO1P2f_=h20;6kh@<0/kcP
0`2^_>@00`000000[[cT0:^miP040:^miPD0Z[gW7`2Y_NP00`000000oooo0?ooo`040?ooo`060?oo
g`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo00<0ZKgX000000000000B@2Y_NP50:VkiPD0
Z;WU1@2U/=l50:F^gP@0YZkM1P2X_NP20:W0jP<0Y=gk0`2Qg?`/0:Vmj0D0Oj_`102JfOd60:c?lP80
]kkO0`2faNH50;JlgPH0/kcP0P2^_>@00`000000[kgT0:nmi0050:^miPD0Z[gW7P2Y_NP00`000000
oooo0?ooo`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`0000190:Vmj0<0
ZKcW1@2Y^nH20:Rii@<0Y[;Q1@2U/=l40:F^gPD0YkSU1@2X_NP60:CMnbl0ZKgX1@2X_>P407VYl@D0
[<ob1P2faNH20;JlgP<0^;oO1@2c_>020:nmi0040000002__N@0[kgT0:nmi080ZkgV0`2/_NH50:Zm
iah0ZKgX00<000000?ooo`3oool0>P3oool00300oooo0P0000000`2Y_NP000000:Vmj0170:Vmj0H0
ZKcW102Y^nH60:Jbh@@0YK3O1@2U/^850:Nhi@H0Y^3k=02Y_NP50:Rlj0@0NJWa1@2:a_`50;K5iPH0
^;oO0P2c_>030;Jmg`8000000`2__N@60:bmiPD0Z[gW7P2Y_NP00`000000oooo0?ooo`0i0?ooo`00
;03oool0102Y_NP000000000000000180:Vmj0X0ZKcW1@2V]N<50:Jbh@D0XjkO1@2U/^820:Nhi@@0
Y^?k0`2Vh?/f0:Vmj080Z;cX0`2Y_NP5096ckP@0R/Kl1@2[b_050;Rog`80][gO0`0000000`2f_Ml0
/KkS000000030;6nh`D0[;gV1P2Z_NLM0:Vmj0030000003oool0oooo03T0oooo000[0?ooo`800000
C02Y_NP60:Vli`@0YkSU1@2V]N<30:Jbh@80XZgO1@2S[]l40:FbhPL0Y^?k?P2Y_NP2096ckP<0ZKgX
101jZ?050:_:l080^;oO00@0]l;R00000000000000000`2f_Ml20;Rog`030000002a_^<0/KkS0080
/KkS1@2]_^H50:Zmiah0ZKgX00<000000?ooo`3oool0>03oool002T0oooo0P00001?0:Vmj0<0ZKcW
0`2X^^H40:Nhi@D0Y[GS1@2R[Ml50:>^g`H0YmkjB02Y_NP407ZXl0@0Zl[`0`0000030;O2hP80][gO
102h_ml00`000000/KkS0;>oh`020;>oh`@0[KkV1P2Z_NLN0:Vmj0030000003oool0oooo03L0oooo
000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool200000500ZKgX1P2X^^H40:Nhi@D0XjkP
1@2R[Ml20:>^g`<0Z<_b0`2Wg_X30;76jDL0ZKgX101jZ?0209?7n@80000000<0TlOi0;O2hP2g`^80
0`2g`^860;Rog`030;>oh`000000/koS0080/koS1@2]_^H50:Zmiah0ZKgX00<000000?ooo`3oool0
=`3oool001`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l70?ooo`030000003oool0000004/0
ZKgX1@2Y_>L50:RjiPD0Y;7R1@2S[^040::]g`H0Z<_b1P2aa^U70:Vmj080S;7_0`00000409?7n@D0
]<?U0`2h_ml30;W1h0040;>oh`000000/koS0;>oh`H0[KkV102Z_NLO0:Vmj0030000003oool0oooo
03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`8000000P3oool0
0`000000ZKgX0:Vmj0190:Vmj0D0ZKcW1@2U]^@50:BahP@0XjkP1@2U^^P30:S;lP<0_=W^0`2aa^TL
0:Vmj0D0YIo@1@2Y_NP50:FOcad0ZKgX0`000000102</Nl0X[[Z0::jjP2R^^X407b`m@D0]<?U1@2i
`N000`2c_n<000000;C0h`020;C0h`D0[KkV1@2Z_NLO0:Vmj0030000003oool0oooo03D0oooo000L
0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo0080oooo
00<000000:Vmj02Y_NP0B@2Y_NP30:Vli`80YkWV1@2U]^@40:BahPD0XK3R1@2U^^P60;cIkQ`0ZKgX
0`2QT<<50:FOd0D0WXNj1@2UWll50:>Gb1@0ZKgX0`0000020:Vmj0D0X[[Z1@1l/?D20;C3i@<0[l;X
102i`N020;C0h`040000002d`><0]<3S0;C0h`80[KkV0`2^_nH50:Zmiah0ZKgX00<000000?ooo`3o
ool0=@3oool001`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?oo
o`3oool00`3ooom<0:Vmj0D0YkWV102U]^@509n]h0D0XK3R0P2U^^P40;CUmah0ZKgX1@2QT<<40:FO
d080/I:g102NQkX40:FOc`80/iJj1@2SUlP50:FOc`/0ZKgX0`0000060:Vmj0@0X[[Z1@1l/?D50:o2
j080^L7P0`2i`^420;C0h`030000002d`><0]<3S00H0[[oV1@2Z_NPN0:Vmj0030000003oool0oooo
03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`8000001@3oool0
0`000000ZKgX0:Vmj0140:Vmj0D0Z;_W1@2W^NH40:6_hPD0WjgP102Q/>850;CUma/0ZKgX1@2ORkh5
0:6@``80YIo@0`2aT[L509j7^P80YIo?0`2cU[X40:>Gb080_9nk1@2UWll70:Vmj0<000003P2Y_NP5
07RWl0@0[l;X1P2i`^420;G1i0030000002e`N@0]L7T00<0[[oV0`2^_nL50:Zmj1h0ZKgX00<00000
0?ooo`3oool0<`3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000ZKgX0:Vmj00o0:Vmj0D0ZKcW1@2X^nL50:>ci0@0XJoR102O
[N070:gAlaT0ZKgX2@2ORkh50:6@``D0/I:g1@2NQkX60;>F^P80XiO80`2lWk/50:FOc`@0ZKgX0`00
000B0:Vmj0@0N:O`1@2Y_nT30;W2h@<0^/?Q00<0]L7T0000002e`N@00P2e`N@60:joi`@0Z[gX7P2Y
_NP00`000000oooo0?ooo`0c0?ooo`00703oool01P3ooml0W4P007Boo`3oool0gia8001d_`H0oooo
00<000000?ooo`3oool01`3ooom10:Vmj0D0ZKcW1@2V^>H50:>ci0@0XJoR1@2T^NP30:gAl`<0_mK[
5`2Y_NP20:6@``T0Wh^n0`2QT<<20:nD^`D0/I:g0`2NQkX20;jQ_0D0/iJj00<0XiO80;bO^`2lWk/0
0`2lWk/30:FOc`80^:310`00000F0:Vmj0@0OJW`1@2Y_nT60;[3h@030;G1i0000000]L?T0080]L?T
1@2^_nL50:Znj1h0ZKgX00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@00000000004RL
0=ooo`060?ooo`030000003oool0oooo00P0oooo@@2Y_NP30:Vli`80Z;_W1@2V^>H40:>ci0D0WZkR
1@2T^NP60;oFja@0ZKgX102QT<<909n;_P80XI330`2_U;/50;6B]`80WXNj0`2nXK`50;>F^PH0_9nk
0P2UWll0102hX<4000000000002hX<450:FOca@0ZKgX101mZO020:Voj@<0Y[cY1@2j`n420;G3i004
0000002e`n@0]L?T0;G3i080[[oW0`2]_nL50:Znj1d0ZKgX00<000000?ooo`3oool0<P3oool002L0
oooo00<000000?ooo`3oool02P3ooom10:Vmj0D0Z;_W102V^>H509j]hPD0WZkR0P2T^NP40;_Um1@0
ZKgX1@2UWm030:6@``T0Wh^n1@2_U;/50;6B]`0309j7^P2nXK`0_Z6l0080_Z6l102cU[X20<F[_`D0
_9nk0`0000030;RP`@030=:c^`2UWll0YIo?00<0YIo?4`2Y_NP407fYl0H0Y[cY0P2j`n430;[4hP03
0;G3i0000000]L?T0080]L?T1P2]_nL20:Znj0<0Z[gX7@2Y_NP00`000000oooo0?ooo`0a0?ooo`00
9`3oool00`000000oooo0?ooo`0;0?oooc`0ZKgX1@2Y_>P50:Rki`@0XK;T1@2N[N8409j^hP@0^nGd
0`2[_nPD0:Vmj0@0YIo@102QT<<609n;_P<0Z9:o1@2_U;/40;6B]`H0_Z6l0P2cU[X30<F[_`80_9nk
0`0000000`3=/;d0^:310;RP`@020;RP`@80d[>k102UWll20;n_bQ<0ZKgX1020Zo050:Jlj@H0^/CR
00<0]<?U0000002d`nD00P2d`nD50:foi`H0Z[gX7@2Y_NP00`000000oooo0?ooo`0`0?ooo`009`3o
ool00`000000oooo0?ooo`0<0?oooc`0ZKgX1@2Y_>P50:FhiP@0XK;T102N[N860:_3k0H0ZkoX4`2Y
_NP50:FOd0<0XI33102ORkh50:RB_`D0[iBk0`2aT[L20;VUa@D0_Z6l00@0/iJj0<F[_`35Zkl0aJ^o
0`000000102lWk/0cK2m0<f`_@3=/;d30;RP`@@0d[>k0P2UWll40;n_bQ<0ZKgX1020Zo050:Jji`<0
^/CR0`2jaN<00`2d`nD000000;C3i@020;C3i@D0[KoW1@2Z_NPM0:Vmj0030000003oool0oooo0300
oooo000W0?ooo`8000003P3oooll0:Vmj080ZKcX0`2W^nL50:FhiP@0XK;T1@2N/>@30:_3k0<0bN;Z
102[_nPD0:Vmj0@0YIo@0`2QT<<50:6>`@@0Z9:o1@2_U;/20;6B]`<0^JG51@2nXK`01035Zkl00000
0000000000020<F[_`030;bO^`3=/;d0cK2m00<0cK2m00<0^:310=:c^`3B/k/00`3B/k/60;n_bQ@0
ZKgX1020Zo050:Jji`H0^/GS00<0]<?U0000002ca>H00P2ca>H40:foi`H0Z[gX7@2Y_NP00`000000
oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?oooc/0ZKgX1P2W^nL40:FhiPD0W:gS
1@2N/>@60<WRjQL0ZKgX102UWm0409N7`0@0XHk11@2XT[l40:nD^`H0^JG50P2nXK`3000000D0aJ^o
1P3=/;d60=:c^`030=Jl_`2o[lX0_jo:0080_jo:0P3A_/LD0:Vmj0@0P:_`0P2V^^L30:VkiPD0^/GS
00<0/lCV0000002ca>H00P2ca>H50:boj0D0Z[gX7P2Y_NP00`000000oooo0?ooo`0^0?ooo`009`3o
ool00`000000oooo0?ooo`0?0?ooocL0ZKgX1@2Y_>P40:Nki`D0Wk;U1@2L[N<209j`i0<0/LS[0`39
h^XA0:Vmj0D0YIo?1026N;d408am_P<0UhO0102QS/450:RB_`80[iBk0`2bYld40;VUa@<000000`2o
/L`40<F[_`80aKO=103=/;d20<fjb0@0d[>k0P3F_;l30;n_bP@0dKk74`2Y_NP4082[l0H0ZK_V0P2j
aN<30;[7i0030;?4iP000000/lCV0080//?W1@2/_nP50:Zmj1d0ZKgX00<000000?ooo`3oool0;P3o
ool002L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX03@0ZKgX1@2Y_>P40:Bhi`D0Wk;U102L[N<6
0;78ja@0ZKgX102UWll408Ih_@@0S7fn102GQl040:6>`@@0Z9:o1@2bYld01@2iYLD0000000000000
0000^JG500H0_k7<0P35Zkl30<Fgc@<0cK2m0`3=^/P30=:c^`@0e[bo00<0_jo:0=6na`3A_/L00`3A
_/L00`3Kb<L0ZKgX0:Vmj00A0:Vmj0@0OJW`1@2Y^nH60;[7i0030;;3i`000000//?W0080//?W0P2/
_nP30:^oj0D0Z[gX7@2Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool2000001<0oooo00<00000
0:Vmj02Y_NP0=02Y_NP50:Nkj0@0Y;SW2@2O/^D30;78j`<0b=oZ502Y_NP30:FOc`@0QWRm102<OKh4
09N7`0@0XHk10P2XT[l30:bWdP80/ZO=0`0000020;VUa@<0]kGG1@2o/L`60<Fgc@030<f`_@3=^/P0
cK[800<0cK[800<0d[>k0=Jl_`3F_;l00`3F_;l50=6na`80flS7502Y_NP407fYl0D0[[gU0`2jan@3
0;W8i@040;;3i`000000//?W0;;3i`H0ZkoX102Z_NPN0:Vmj0030000003oool0oooo02`0oooo0009
0?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?oo
o`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000:Vm
j02Y_NP0=02Y_NP50:Nkj0@0Y;SW102J[^D509nbi@H0b=oZ502Y_NP30:FOc`@0QWRm102<OKh409N7
`0<0XHk11@2/Ym82000000<0/ZO=1@2g]ML40;nac080^[cK1@35]ld60<fjb0H0e[bo00@0el?50=6n
a`3A_/L0dKk70`3Kb<LE0:Vmj0@0O:;[1@2^_ND50;W8i@030;32j0000000/<;X0080/<;X1@2[_nP5
0:Zmj1d0ZKgX00<000000?ooo`3oool02P3oool01@3OW4P000000000000004P0W=oo01d0oooo0008
0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00`3ogi`0B00007Boo`040?ooo`070?no
M000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo01@0oooo00<000000:Vm
j02Y_NP0=02Y_NP40:Nkj0D0W[?V102J[^D309nbi@@0/lKX5`2Y_NP30:FOc`@0QWRm102<OKh409N7
`0@0YZGD00D0[:OB00000000000000000:bWdP020;:Wc@<0/;SO1@2g]ML20;nac0<0^[cK1035]ld2
0;nnf@@0cK[80P39`=440=Jl_`<0el?500<0dKk70=_8a`3Kb<L00P3Kb<L00`3Pdl/0ZKgX0:Vmj00C
0:Vmj0@0O:;[0P2^_ND30;C2i080^LSU0`2hb>H00`2``^P000000;32j0020;32j0D0ZkkX1@2Z_NPM
0:Vmj0030000003oool0oooo00P0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo
00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0
oooo00<0_g@007Boo`3oool01@3oool2000001H0oooo=P2Y_NP50:Bij0D0W[?V102J[^D50;?6j080
b^3X4`2Y_NP408:5cP80MG?31026N;d408am_PD0WikD00@0YZGD0000000000000000102/Ym860;2h
g`@0]kGG1P2j_=/20<Fgc@<0_kkI0`3=^/P30<W0d@<0e[bo103G`lD40=_8a`<0h=?;502Y_NP407bR
j`D0]<;T1P2hb>H00`2``^P000000:k1j0020:k1j0D0ZkkX8P2Y_NP00`000000oooo0?ooo`0<0?oo
o`030;md001d_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`05
0?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G
0?oooc40ZKgX1@2X_>P40:Bij0@0W[?V1@2M/ND30;?6j0@0b^3X4P2Y_NP408:5cP<0MG?31027QLX4
09FDd080WikD0`0000040:JUe0@0[;WS1@2`^=l50;2oi@D0^[cK1P2o_]T00`3=^/P0bL3A0<W0d@03
0<W0d@030=Jl_`3G`lD0el?50080el?50P3Hb<X20=_8a`@0h=?;00<0hN?E0:Vmj02Y_NP03@2Y_NP5
0::jjP@0QioS0`2d`^@20;S7i@D0^<SV00<0[/7X0000002^`NP00`2^`NP20:^nj0<0Z[kX8@2Y_NP0
0`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo
0?ooo`3ookl0M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO
09a8B02Lgol01P3oool00`000000oooo0?ooo`0H0?oooc40ZKgX1@2X_>P409nej0@0VJoV1@2M/ND6
0<[Pj1<0ZKgX0`22QLh307Ec``@0QhG:0`2EU=03000000<0WikD0P2VYM@30:Vhi0@0[;WS0P2`^=l3
0:_1j@D0/;oU1@2b`ND50;nnf@H0bL3A103G`lD40=S8bP@0h=?;0`3QhmD?0:Vmj0D0X[[Z1027Wn<5
0;S7i@D0]LOX00<0[/7X0000002^`NP00P2^`NP50:Znj280ZKgX00<000000?ooo`3oool01P3oool0
1`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo
0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0oooo
00@0oooo0P00000K0?oooc40ZKgX0P2X_>P30:Fjj0@0WkGX102I[nH209fai@@0[l3V1@2[_nPB0:Vm
j0@0PXG>0`1eLl<308N5bP<000000P2EU=0409nNe0H0ZKST0`2/^N<60:_1j@80/;oU0`2Y`N/50;;1
i@80_kkI0`2h`N430<W0d@<0aL?H0P3G`lD50=S8bP030=c?c03Pdl/0h=?;00<0hN?E0P3@l>P?0:Vm
j0@0X[[Z1@2K[><20;S7i@<0^/[V1@2eanP00`2/`>P000000:c0j0020:c0j0@0Z[kX8`2Y_NP00`00
0000oooo0?ooo`050?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool06`3oool000P0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0okmd001d_`3oool00P3oool0
1@2oM000M;oo0?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool06`3oool`0:Vmj0H0YK[X102O
]NP309V_iPD0[l3V0P3:d^050:^oj0h0ZKgX0`1YP=L408:5cP<0MG?30`0000000`27QLX0UIC@09FD
d00209FDd0D0YKCS1@2Y^>@50:W2k0@0Zl7Y1P2Y`N/40;;1i@H0^<7Q1P35`mP50=S8bP<0g<o<0`3Q
hmD40=3`j0l0ZKgX102</Nl409^/h`H0^/[V0P2eanP30;;5j0040:c0j0000000[<3X0:c0j0D0Z[gX
8P2Y_NP00`000000oooo0?ooo`050?ooo`030?oog`2LB4P0W=oo0200oooo00080?ooo`060?oog`2L
B000M;oo0?ooo`3OW4P007Bo103oool02P3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooo0;md
001d_ol90?ooo`030000003oool0oooo01`0oooo:`2Y_NP50:Rlj0D0YK[X1@2I/NP309Z_iP<0[l3V
103:d^0B0:Vmj0@0JH3G0`1VL<T3000000@0QhG:1@2O[>050:Fdh`X0ZL;/102W`nh50:W1j`D0Zl3Y
0`2h`N430;;1i@@0aL?H0P33aM`30=S8bP@0g<o<00<0h]S=0=3`j03@l>P0103@l>P?0:Vmj0@0S;7_
0P2K[><30:^ki@D0^/[V1P2baNP010000000ZkoX0:^oj02[_nP50:Zmj280ZKgX00<000000?ooo`3o
ool01@3oool00`2oM000M;oo0?ooo`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0
oooo00D0omnL04P000000000000007Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3o
ool00`000000oooo0?ooo`0M0?ooob`0ZKgX102X_>P50:6hj0D0VK7X0`2J[nH50<[Bh080_mK[4P2Y
_NP306V0e`0406I`b@000000000006I`b@<0PX[C102DWm/509n/h080YKCS0`2Y`>X50:W2k0D0YlC^
102W`nh50:G0k@D0Zl3Y1P2b`ND20<G3f0@0`lGL00<0f<S:0=c?c03Lcl`00P3Lcl`20>;Hc@80j^C:
4`2Y_NP408bak`H0Zk_U0P2jb^H30;W;j0<0//GX0`2_`nP010000000ZkoX0:^oj02[_nPV0:Vmj003
0000003oool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool20000
01l0oooo;02Y_NP50:Jkj0@0XKSX102I/NP50:JhiP80b];P102oe^/?0:Vmj080JJ?b00@0JH3G0000
0000000000000`1VL<T308::d`D0U9oK102O[>060:W0jP80ZL;/0`2Ya>d50:O4kPD0Y<7^102U`>d5
0:Jnj`D0//7U1P33aM`40=c?c080h]S=0`3Zi<X00`3^mLD0ZKgX0:Vmj00A0:Vmj0@0Q9[Q1@2[^nD6
0;W;j0D0[l?X00<0ZkoX0000002Z_^P00P2Z_^PV0:Vmj0030000003oool0oooo02H0oooo000U0?oo
o`030000003oool0oooo01l0oooo;02Y_NP50:Jkj0<0XKSX1@2G[nP50:JhiPH0_mK[3P2Y_NP30000
000304aTbP1YP=L0JH3G00@0IW390`22R]<409BOf`D0YkcX1@2Y`>X60:W4k@D0Y/;^1@2T`Nh40::n
k@D0Y[k[1@2_`>H30<?5g0<0a<SM0P3Lcl`30>;Hc@80j^C:0`3^mLDC0:Vmj0@0Q9[Q1@2fa^L30;W;
j0<0]LWY102_`nP00`2Z_^P000000:Znj0030:Znj2H0ZKgX00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0803oool/0:Vmj080Y[_X0`2T^^T409bdj@@0UjoX0P2V^>H40;_5h@l0
ZKgX0`000000102Y_NP0JJ?b06VSlP1YXo8204aTbP@0IW390`22R]<50:6ci@D0YkcX1@2[a>`30:W4
k@<0ZL?]1@2V`^h50:>nk@@0X[k]0P2V_^/30:FljPD0[l3V1P34b=d30>;Hc@<0j^C:0P3^mLD20=3a
j180ZKgX1@2GY^450;K6i`D0]LWY1@2/`>P00`2Z_^P000000:Znj0020:Znj2H0ZKgX00<000000?oo
o`3oool09@3oool002@0oooo0P00000S0?ooob/0ZKgX1P2T^^T409bdj@<0UjoX1@2kaN420<W>gP/0
ZKgX0`0000050:Vmj00301U@b@1YXo80JJ?b0080C6C:101gRMP309:Sh0D0XK?U1@2[`^X50:_4k0H0
ZL?]0P2V`^h30:K0k0D0Xkk]0`2R_^d60:FljPD0[l3V1034b=d30<W>gP<0j^C:0P3^mLD40=3aj0h0
ZKgX102B/^d509NVh@D0^LgY0`2ebNT20;75j@D0[<3X00<0Z[gX0000002Z_NP00P2Z_NPV0:Vmj003
0000003oool0oooo02@0oooo000T0?ooo`030000003oool0oooo02<0oooo9`2Y_NP40:Rlj0D0Y;[Y
1@2G/^X309^bj0<0^lGQ1039c]h70:Vmj0<00000202Y_NP301U@b@80C6C:101gRMP409:Sh0<0XK?U
0P2Y_^P50:_2jPD0[<C[1@2Y`nd60:K0k0@0Xkk]102R^n/50:FljPH0[l3V0P34b=d30<W>gP<0d][N
00<0k_G50=3aj03@lNP0103@lNP?0:Vmj0@0T[;]0P2GY^430:bmiPD0^LgY1@2aaNT50:^nj0030:Zm
j0000000Z[gX0080Z[gX9P2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?oo
o`0T0?ooobL0ZKgX102X_>P50:2hjPD0Uk;Z0`2K/^P50<W>gP80`];W0`2Y_NP3000000`0ZKgX0`0I
D<T00`1KNmT0C6C:07N9f00307N9f0@0TZ?P1@2Y_^P20:_2jP<0[/?Z1@2/a>/50:W1j`D0Y/3/1@2S
_>/40::kj`D0YK_Y1@2_`>H40<W>gP<0d][N0P3OkMX20>?maa<0ZKgX102B/^d60:bmiPD0^<gZ0P2a
aNT30:g2j@D0ZkkX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool2
000002H0oooo9`2Y_NP50:Jlj0@0X;SZ102G/^X50:NiiP80bLkN0`32d^L3000000d0ZKgX0P1YXo83
01U@b@80Fg_I101gRMP509nciP@0ZKkX1P2^`nX50:c2j@D0ZL7[1@2V_NX50:>lj`@0X[WY1@2U^nT5
0;;3iP80bLkN0`3Bf]h20=o]fP80hog70P3Go=`>0:Vmj0D0Z;cX1027UMX30:bmiP<0]lcZ102hcNX6
0:g2j@80ZkkX0`2Z_^P00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo0280oooo000S0?oo
o`800000:03ooolW0:Vmj0D0Y[cX0`2P^>X509FajPD0YkWV0P32d^L200000080`];W3`2Y_NP206VS
lP0301=Cc@0ID<T06E390080Fg_I1029X><509nciPD0[L7X0`2^`nX20:k2j0D0[<;Y1@2Y_^P50:Jm
jPD0XkWX102R^NT50:Jkj0D0//?V0`3Bf]h30=o]fP030>?ma`3Go=`0eocL0080eocL3P2Y_NP50:Rl
j0@0QiGJ1@2gc>X50;?8jPD0[L;Y1@2Z_^P00`2Y_NP000000:Vmj00X0:Vmj0030000003oool0oooo
0240oooo000=0?ooo`0;0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3OW4P0
0P0000000`0004P0W=oo0?ooo`070?ooo`030000003oool0oooo02P0oooo9P2Y_NP50:Bkj@@0W;K[
102E/NX30;O0h@<000001@2aa^T>0:Vmj0<0JJ?b0P0CDld305]kf@@0RJ3S1@2W_>P50:g1j0D0[/;X
1@2/_nL50:Vnj0D0Y[[W1@2S^NP40:>hi`D0Y[_X1P2ib^L30=o]fP040>?ma`3Go=`0eocL0=Olg140
ZKgX102X_>P50:Bdi@<0]lcZ0P2hcn/50;?8jPD0ZkoX102Z_^P20:Vmj0030000002Y_NP0ZKgX02H0
ZKgX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo902Y
_NP20:Rmj0D0Y;_Y102L]^/309Nbj`<000000P2g`>420<C4fPD0/LKY3P2Y_NP201Ebh@<04e?=0P1/
TND509N_j0D0YkcX1@2_`NL30:k2j080[koV1@2/_nL50:VkiPD0Y[[W1@2T]nL40:>hi`80Y[_X0`2[
_^P40;W:i`<0aM_Y00<0doKU0;gh]02mn;@0502Y_NP408^GfPD0Y;CU1@2hcn/50:k3j@@0ZkoX1P2Y
_NP00`000000ZKgX0:Vmj00W0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oO
W01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo8@2Y_NP50:Rmj0@0Y;_Y
102H]>`300000080Uk;[0P2g`>440<C4fQ<0ZKgX0P0EL^400`0@H=L04e?=01=Cc@0206bAi@D0UjoX
0P2W_>P30:bni`D0[l7W1@2__nH20:boi`<0[;cU1@2Y^nH20:Jji`<0Y[OU1@2T]nL30:>hi`H0ZkkX
0P2ib^L30<GKj@030=?fi@2mn;@0_ORd0080d?7X4`2Y_NP508^GfP80Y;CU0`2dbn/20;S?j`<0/l[[
1@2^`nT40:Znj0H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0O0?ooo`00303o
ool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`050?ooo`03
0000003oool0oooo02`0oooo8@2Y_NP50:Rmj0@0X[[Z0`00000209Rdk0<0Uk;[1@34a=X20<O5fA<0
ZKgX00@005;<01Ebh@0@H=L0463G0`1/TND409N_j0H0[;kW1@2``>H40:noiPH0[;cU102Y^nH60:Jg
i@@0Y;OW102U^NL50:^nj0@0aM_Y00<0doKU0;gh]03@lNP0103@lNPC0:Vmj0@0RiOJ1@2dbn/60;?:
j`D0Zl3X102Z_^P60:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool07`3oool000`0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oo
g`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3ooolQ0:Vmj0D0YkcX0`0000000`2R^^X0V;C/
09Rdk00209Rdk0D0W;KZ0P34a=X40<O5fA<0ZKgX00@005;<011Pe`0@H=L0463G0`1gXNd409jgjP<0
[;kW0`2]_nL50;30iPD0[kgT102/_>D50:Vii0D0Y[OU1@2U]nH40:Fii`H0//W[0P3Cm^D00`2ioM/0
P=:4083BQ00G0:Vmj0D0X;7T0`2dbn/20;O@k0<0/l[[0`2^a>X40:_0j0D0Z[gX1@2Y_NP00`000000
ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01h0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`030?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01@3oool00`00
0000oooo0?ooo`0^0?ooob40ZKgX00D0YkcX00000000000000000:Nlj00409nij`@0U;C]1@2L]^X4
0<O5f@80aLGI4`2Y_NP01000D/`006CI011Pe`0@H=L307NQk@@0W[OZ1P2]_nL20;30iP<0/;kU1@2_
_N@40:bji0D0ZKWT1@2V]nD50:FgiP@0ZKoY0`2bbN/30;kRl@030;Wmf`2Y_NP0ZKgX0100ZKgX1@2Y
_>L408jGf0D0X;7T1@2gd>`60:k4jP80Zl3X0P2Z_^P50:Zmj0D0ZKgX00<000000:Vmj02Y_NP09`2Y
_NP00`000000oooo0?ooo`0M0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
0`3oool00`3ooml0W4Q809cOo`090?ooo`800000<@3ooolN0:Vmj0<000001@2W_>T409nij`@0U;C]
1@2S^NP20<O5f@@0aLGI4`2Y_NP00`00D/`006CI001Tf@0407NQk@@0X[_[1@2]_nL60;2ni@80[kgT
0`2^^n@40:bji0D0ZKST1@2V]nD20:FgiP<0Yk_W102Y_nT40;kRl@030;Wmf`3@l>P0d?3X0180ZKgX
1@2Y_>L408jGf0D0/lc/1@2cbn`50:k4jPD0Z[kX0P2Z_NP80:Vmj0030000002Y_NP0ZKgX02H0ZKgX
00<000000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`03
0;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3ooolK0:Vmj08000001@2Y_NP40:Nlj@@0
WKW/102C]>h50:>ij0H0aLGI4`2Y_NP00`0EL^4005;<001Tf@0407^/lP@0X[_[1@2]_nL50;2ni@H0
[[_T0P2/^^@20:^ih`D0ZKST102V]nD50:Nki`80ZKoY102adO420;Wmf`@0d?3X4P2Y_NP40:Vli`D0
XkGV0P2cc>`30;K@kPD0/l_/1@2[`>P40:Znj0/0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000
oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia800000000
000000000000M02oool50?ooo`030000003oool0oooo0380oooo5`2Y_NP3000000P0ZKgX102V_>T4
09fik0@0TkC^1@2Y_>L30<G5f@<0`l?I4`2Y_NP201Ebh@03001EaP1k[?80Njcb0080Njcb102R_^d5
0:foi`D0[kkU1@2^^n@50:^ih`@0ZKST1@2W^NH40:Nki`@0/M7a0`2am?<30=3`j100ZKgX1@2WZmX4
08fEeP@0XkGV1P2fd>h50:k3jP@0Zl3X3`2Y_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0
oooo01/0oooo000R0?ooo`800000=03ooolC0:Vmj0<00000302Y_NP40:Jlj@@0WKW/102B]Nh50:Vl
i`H0`l?I4P2Y_NP401Ebh@@0M;;h102R_^d50:c0j@D0[kkU1@2]_>@40:^ih`D0ZK[V1@2W^NH50:_8
k`@0/OCc0P2GlL/C0:Vmj0@0Yj_J1@2=UMH20:>eiP80/lo^0`2fd>h30;79k0@0[/?Z1@2Z_^P?0:Vm
j0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06`3oool00280oooo00<000000?ooo`3o
ool0=03oool?0:Vmj0<00000402Y_NP30:Jlj@D0VkS]102B]Nh20:Vli`<0[;kW0`33`mT30<?1f180
ZKgX101YXo8407Bbn0@0W<?c1@2/`>T50:foi`D0[KcT102[_>H50:VjiPD0ZLC]0`2[b>l30:WXnQP0
ZKgX102WZmX408fEePD0/lo^1P2abN`40:^oj0D0Z[kX3`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo01X0oooo000R0?ooo`030000003oool0oooo03D0oooo00<000000:Vmj02Y_NP0
202Y_NP3000001<0ZKgX102U_>T509^hk@<0T[G^1P2/_^L60<?1f1H0ZKgX101F/O/409c3l`80[<3Y
0`2WaNl50:foi`80[KcT0`2[`>T40:^liPX0ZLC]102Yj?XI0:Vmj0@0Yj_J1@2X`>X50;C@kP<0/LW/
0`2]`^T40:^oj1@0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0<0?ooo`030?oO
W01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3oool00`000000oooo
0?ooo`0g0?ooo`H0ZKgX0`00000G0:Vmj0@0YKcY1@2J^Nd409:fk`<0[;kW0P2]_nL40<?1f080a<7G
5P2Y_NP405Jan`<0W<?c1P2WaNl40:foi`H0Zl3Y0P2[_>H20:S7l0D0ZLC]1P2ThO/G0:Vmj0D0UiWD
102IY]h30:S0jP80/m;`1@2dd>h50:g2j@D0Z[kX4`2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0800000
303oool02P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`008@3oool2
000003X0oooo0P2Y_NP3000001/0ZKgX1@2U_>X409Zik@@0T[K_1@2]_nL20<?1f0@0a<7G1@2Y]n<B
0:Vmj080JJ?b00<008cE08[9o@2:bOd00P2:bOd40:O5k`D0Z<O_1@2[`>T50:S7l0H0W]om602Y_NP4
0:RYe`D0UiWD102IY]h50;?Bl0D0[lO[0`2]`^T20:^oj0D0Z[kX4`2Y_NP00`000000ZKgX0:Vmj00V
0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<000006`2Y_NP40:Rmj0D0
YKcZ102J^Nh409:gl0@0[KoW1@34`ML20<G1ePD0ZKOS5@2Y_NP408[9o@@0Um3k1@2Xanl60:G>mPD0
T^7n602Y_NP50:Vgh`@0Z:WG102GVM@50:k<l0D0/Lg^1@2_an/50:^oj080Z[kX5P2Y_NP00`000000
ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`8000000`3o
oolL0:Vmj0@0Z;gX1@2U_>X409ZikP@0T[O`102Y_nX30<C1e`@0aL7F0P2Y]n<30:j`fAX0ZKgX0`2G
d?/609?GoPD0JmWa00<0K:?b0:Vmj02Y_NP06P2Y_NP50:Vgh`<0Z:WG1@2V_N/30:k<l080/]7`1@2a
cNh50:c1j@@0ZkoX602Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00T0oooo00/0
omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool20000
03@0oooo0`0000060?oooa`0ZKgX102X_NP50:FljP@0Vk[^102A^?440:VojPH0aL7F1P2^/=U50:Vm
j0@0ZKOS102N[>450:Jmj`D0/]7`1@2]a>/40:c1j@D0Z[gX602Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3ooolM0:Vmj0@0Z;gX
1@2U_>X409^jkP@0TKSa102S_nd30<G1eP<0`l?J1@2^/=U50:Vmj0D0VIgF102N[>450;3ClP80/]7`
0`2^b>`50:g4j`@0Z[kX1@2Z_NPH0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool0
1P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
0`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0?oo_`1d
04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo02d0oooo
0`00000>0?ooob40ZKgX102U_>X509fjk@<0TKSa102S_nd60<?3fP80[[3I0`2k^=Ho0:Vmj080Yj;A
102QW]4409VMeP80WZcQ0`2]d?840;3ClPH0[/S/1@2[_nP40:Znj1d0ZKgX00<000000:Vmj02Y_NP0
9@2Y_NP00`000000oooo0?ooo`060?ooo`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0
oooo0=nLB000M;l0103oool000<0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l50?ooo`030?oo
g`2LB4P0W=oo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?oo
o`3oool0:P3oool300000180oooo8@2Y_NP40:Jlj@D0WK[]0`2A^?4509^nl@@0`l?J1P2k^=H40:R/
fP<0ZKgX0`2Y_>Lb0:Vmj0@0Yj;A1@2QW]4309VMePH0[M3b1@2_c>l50:_1j@@0ZkoX8@2Y_NP00`00
0000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003oool0203oool00`3ogi`0B01d0;ooo`020?oo
o`050?oo_`1d000000000018W03Oool0103oool000<0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`800000:@3o
ool3000001H0oooo8@2Y_NP40:Jlj@D0Wk_/0`2C^O4509^nl@@0^<GT0`2k^=H30<C0eP@0Z:cJ1P2Y
_>L]0:Vmj0D0Yj?B102WX]440:6Nd@D0ZLW`1@2_co430:o<k`80[<?[1@2[`NT40:Zmj240ZKgX00<0
00000:Vmj02Y_NP0702Y_NP3000000D0oooo00<000000?ooo`3oool05@3oool000<0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03Oool01`3oool00`2oM000M;oo
0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?ooob40ZKgX102W_NT509nkk0<0TkWa
1@2D_O<40;S5i0H0a<3F0P2X[=X20;Rce@D0ZKcW:@2Y_NP90:NSdP@0Yj;A1@2W`^d30:W9l080[]7c
1@2_co450:c3j`D0Z[kX102Z_NPQ0:Vmj0030000002Y_NP0ZKgX01P0ZKgX0`0000080?ooo`030000
003oool0oooo01D0oooo00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`03
0?oo_`1d04P0W=oo0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<00000
0?ooo`3oool08P3oool3000001h0oooo8@2Y_NP40:Nmj@D0X[c[0`2F^_0509Bml`@0YlC^1@34`=H5
0;Rce@D0Z:GC302Y_NP20:Vli`h0ZKgX102Y]n<50:Vmj0@0Yj;A202WXm850:Jlj@D0Yl;]1@2^dO<5
0:c5k080[<?[1`2Z_^PV0:Vmj0030000002Y_NP0ZKgX01<0ZKgX1000000<0?ooo`030000003oool0
oooo01@0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000
M;l0oooo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0
oooo0`00000R0?ooob40ZKgX102W_NT50::lj`<0U[[`1@2A^o<40:O4kPD0^lKS0`2h/mD20<G3f0D0
Z:GC102WYM@50:Vmj0D0ZKcW0P2Y_NP30:R/f@@0ZKgX1@2XZML40:Vgh`D0YZ3@102WX]440:NSdP@0
Yk[V1@2V_>T50:cBm0D0[<O]102/aN`60:Znj2T0ZKgX00<000000:Vmj02Y_NP03`2Y_NP0103oool0
000000000000000@0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`800000
7P3oool2000002H0oooo00<000000:Vmj02Y_NP07P2Y_NP40:Nmj@D0Y;cZ0`2K^nl5096kl`@0V<7d
1@2ka^<50<G3f080Z:GC0`31_MH40:NUe0D0YjCC102Y_>L60:R/f@@0YZ7@1@2XZML20:Vgh`80[:GA
1@2VX=030:NRd@D0ZK[V102W^^H60:[Bm@@0[<W_1@2/and40:Zoj@<0Z[kX;02Y_NP00`000000ZKgX
0:Vmj00:0:Vmj080oooo0`00000C0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2L
B000M;oo0?ooo`3OW4P007Bo203oool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L
0?ooo`<00000:P3ooolP0:Vmj080YkgY0P2X_NP50:BljP<0Vk__1@2D^o8409S1m0D0YLOa1035`mP6
0<6meP80YjGD0P2o^mH50:NTd`@0Z:;@0`2X[=T30;Nbe0@0YZ7@102XZML40:bUd@D0YZ3@102/_^L5
0:VjiP@0Z=7f0`2Zd_D30:_;l0@0[<W_1@2[`>T40:ZojBl0ZKgX00<000000:Vmj02Y_NP01`2Y_NP4
000001H0oooo00<000000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL0=ooo`04
0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo0?ooo`04
0?ooo`030000003oool0oooo01L0oooo0`00000^0?oooal0ZKgX1@2X_NP20:BljP<0Y[gY0`2O_>d5
09BklP@0T[ke1@2Uao440;39k@D0`KgF1@2o^mH20:NTd`<0`KkG102XX]050;Nbe0@0YZ7@1@2f]MP4
0:bUd@80YZ3@0`2/a>/40:bni`D0Y]7f102XdOH50:_;l0D0Zl7Z102[`>Tc0:Vmj0030000002Y_NP0
ZKgX00D0ZKgX0P00000J0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo
01D0oooo0`00000b0?oooal0ZKgX102X_NP60:Jmj@<0Wkc]1@2J_?0409:nm@D0UL;f102`bNd50;?9
j`@0_k_F1P31_]L20:RRd080^LCR1@2g/]@20:JQd080]L;T1@2f]MP30:bUd@D0[<C[0P2/_^L30:GA
m`@0Y]7f1P2Ybo440:[2j`D0Zl7Z102Z_^Pc0:Vmj0040000002Y_NP0ZKgX0:Vmj08000007@3oool0
0`000000oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo0`00000f0?ooob@0ZKgX0`2V_NT20:Rm
j0<0Y;c[1@2J_?0409NmlPD0UL;f102IaOH50;?9j`@0/L[]1@31_]L50;W4hP@0]k;D1@2e`^@40;Je
f0@0Zl[`102/a>/60:GAm`D0Z<_b2@2Z`^/90:Znj380ZKgX0`00000P0?ooo`030000003oool0oooo
01@0oooo000O0?ooo`030000003oool0oooo00l0oooo0`00000j0?ooob@0ZKgX1@2X_NP30:Blj`D0
XKc]102G_O8509Fom0@0VLGf1@2JaoL40;7:k@D0ZLcb102ia>850:g<l0@0]L;T1@2Vc_@40:_:l0D0
Xm3g1P2WbO840:W2j`D0Z/;[202Z_^Pb0:Vmj0<000000`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo00`0oooo0`00000n0?ooob@0ZKgX
102X_NP50:Jmj@@0XKc]102N_Nh509Fom0@0U/7e1@2JaoL409W8m`D0ZLcb102PcOL40:g<l0H0XLkg
0`2Vc_@60:;>m`@0Y/Oa0`2WbO830:W1j`@0ZL;[1@2Y_^P40:Znj380ZKgX0`0000060?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3o
ool300000480oooo:02Y_NP30:Jmj@80Z;gX1@2U_NX309jmkPH0WKk_0`2F`OD509S2m@T0VLSg102P
cOL509c;n0D0X<Od102PboH50:G5l0@0Y/Oa1@2Y`N/90:Vnj380ZKgX1000000:0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool04`3oool001h0oooo0P0000090?ooo`800000AP3ooolX
0:Vmj0D0Z;gX1@2X_NT90:Bmj`@0W[o`102H`_D509_3m0<0VLSg1P2La_D40:;4l@D0X<Od102U`nh5
0:G5l0D0Z<3[2@2Y_^Pa0:Vmj0040?ooo`0000000000000000l0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`<00000B@3ooolX
0:Vmj0<0Z;gX0P2Y_NP50:Rmj@@0YkgY1@2T_N/40:Fnj`@0X;o_1@2S_nd409o2l@D0Xl7^102Ra?45
0:K1k@@0YL?^1@2X_nX20:S0j`L0ZKkX<P2Y_NP0103oool0000000000000000C0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool00P3oool3
000004d0oooo00<000000:Vmj02Y_NP0;`2Y_NP90:Nmj@@0YKk[102V_^/50:>ok@@0YKo[1@2S`Nh4
0:Noj`@0Y/7]1@2X_nT40:RojPH0ZKkX<@2Y_NP00`3oool0000000000002000001H0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo000000020000
0540oooo00<000000:Vmj02Y_NP0<`2Y_NP50:Nmj@@0Z;gY102V_^/50:Nnj@@0YKo[1@2X_^T40:No
j`@0Z;kY1@2X_nTh0:Vmj0<000006`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01<0oooo000N0?ooo`800000E@3oool00`000000ZKgX0:Vmj00h0:Vmj0@0Z;gY102X_NP50:Nnj@@0
Z;gY1@2X_^T40:Vmj0@0Z;kY>P2Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo
00<000000:Vmj02Y_NP0?02Y_NP40:Rmj0D0ZKgX102X_NU30:Vmj0030000003oool0oooo0240oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;oo
o`0:0?ooo`800000EP3ooon90:Vmj08000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0E03ooon5
0:Vmj0800000:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo000C0?oo
o`030?oOW01807@0_ooo00d0oooo00<000000?ooo`3oool0E03ooon00:Vmj0800000<03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0
oooo00<000000?ooo`3oool0E03ooomk0:Vmj0<00000<`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00l0oooo00<000000?ooo`3oool0
E03ooomg0:Vmj0<00000=`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo
000A0?ooo`050;md000004P0W;nL04P0M02oool0403oool2000005D0ooooLP2Y_NP3000003`0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`004P3oool0103o_g@000000000
M02ooolB0?ooo`030000003oool0oooo05<0ooooKP2Y_NP300000400oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003o
ool0oooo05<0ooooJ@2Y_NP4000004<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0A0?ooo`00:P3oool00`000000oooo0?ooo`1C0?ooofD0ZKgX0`0000180?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04@3oool002/0oooo0P00001D0?ooof00ZKgX00@0oooo0000
000000000000C03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000]0?oo
o`030000003oool0oooo0580ooooG02Y_NP4000004l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?oooeP0ZKgX0`00001D0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool002l0oooo00<000000?ooo`3oool0
DP3ooomC0:Vmj0040?ooo`0000000000000005P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0A0?ooo`00<03oool00`000000oooo0?ooo`1B0?ooodl0ZKgX1000001L0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00340oooo0P00001C0?ooodX0ZKgX00@0
oooo0000000000000000H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
000c0?ooo`030000003oool0oooo0540ooooAP2Y_NP4000006@0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`00=03oool00`000000oooo0?ooo`1A0?oood80ZKgX0`00001Y
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003D0oooo00<000000?oo
o`3oool0D@3ooolm0:Vmj0040?ooo`0000000000000006`0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`00=P3oool200000580oooo>@2Y_NP400000700oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`00>03oool00`000000oooo0?ooo`1@0?ooocD0
ZKgX0`00001e0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool003T0oooo
00<000000?ooo`3oool0D@3oool_0:Vmj0040?ooo`0000000000000007T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A0?ooob/0ZKgX
1000001l0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool003/0oooo00<0
00000?ooo`3oool0D@3ooolW0:Vmj0<00000P@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00l0oooo000l0?ooo`800000DP3ooolR0:Vmj0040?ooo`0000000000000008D0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`00?P3oool00`000000oooo0?ooo`1@
0?oooah0ZKgX100000290?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool0
03l0oooo00<000000?ooo`3oool0D03ooolJ0:Vmj0<00000S@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00l0oooo00100?ooo`030000003oool0oooo0500oooo5P2Y_NP300000940
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00@@3oool200000540oooo
4P2Y_NP3000009D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00@`3o
ool00`000000oooo0?ooo`1?0?ooo`d0ZKgX0`00002I0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03`3oool004@0oooo00<000000?ooo`3oool0D03oool80:Vmj0<00000W@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo
0500oooo102Y_NP300000:40oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`00AP3oool200000540oooo0P00002V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool004P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004`0
oooo0P00001;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0>0?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`00C`3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`00D03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool2000004H0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo001C0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0[03oool01@000000oooo0?ooo`3oool00000
00l0oooo001D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0[P3oool010000000
oooo0?ooo`00000?0?ooo`00E@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:h0
oooo00@000000?ooo`3oool000003`3oool005H0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`2_0?ooo`030000003oool0000000l0oooo001G0?ooo`800000?`3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0000000h0oooo001I0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0/@3oool2000000h0oooo001J0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0/@3oool2000000h0oooo001K0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0/@3oool2000000h0oooo001L0?ooo`800000>P3oool00`000000oooo0?ooo`2]0?ooo`@0
0000403oool005h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Y0?ooo`@00000
503oool005l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2U0?ooo`@00000603o
ool00600oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2Q0?ooo`@00000703oool0
0640oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2N0?ooo`<00000803oool00680
oooo0P00000d0?ooo`030000003oool0oooo09X0oooo1000000S0?ooo`00I03oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo09H0oooo1000000W0?ooo`00I@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0980oooo1000000[0?ooo`00IP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo08h0oooo1000000_0?ooo`00I`3oool2000002l0oooo00<000000?oo
o`3oool0RP3oool4000003<0oooo001Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0Q`3oool3000003L0oooo001Z0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
P`3oool4000003X0oooo001[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0O`3o
ool4000003h0oooo001/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0N`3oool4
00000480oooo001]0?ooo`800000:@3oool00`000000oooo0?ooo`1g0?ooo`@00000AP3oool006l0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1e0?ooo`<00000BP3oool00700oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1a0?ooo`@00000C@3oool00740oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000D@3oool00780oooo0P00000S
0?ooo`030000003oool0oooo06T0oooo1000001E0?ooo`00M03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo06D0oooo1000001I0?ooo`00M@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0680oooo0`00001M0?ooo`00MP3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo05h0oooo1000001P0?ooo`00M`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05X0oooo1000001T0?ooo`00N03oool2000001d0oooo00<000000?ooo`3oool0EP3oool4
000006P0oooo001j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool40000
06`0oooo001k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool400000700
oooo001l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool3000007@0oooo
001m0?ooo`800000603oool00`000000oooo0?ooo`170?ooo`@00000M`3oool007l0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`130?ooo`@00000N`3oool00800oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0o0?ooo`@00000O`3oool00840oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0k0?ooo`@00000P`3oool00880oooo0P00000C0?ooo`030000
003oool0oooo03P0oooo0`0000270?ooo`00Q03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo03@0oooo1000002:0?ooo`00Q@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0300oooo1000002>0?ooo`00QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02`0oooo1000002B0?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0
oooo1000002F0?ooo`00R03oool2000000d0oooo00<000000?ooo`3oool09@3oool3000009X0oooo
002:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool4000009d0oooo002;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000:40oooo002<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000:D0oooo002=0?ooo`80
00001`3oool00`000000oooo0?ooo`0F0?ooo`@00000Z@3oool008l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0B0?ooo`@00000[@3oool00900oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0?0?ooo`<00000/@3oool00940oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@00000]03oool00980oooo00D000000?ooo`3oool0oooo00000009
0?ooo`@00000^03oool009<0oooo0P0000000`3oool000000?ooo`040?ooo`@00000_03oool009D0
oooo0P0000000`3oool000000000000200000<00oooo002F0?ooo`800000a03oool00?l0ooooG@3o
ool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3o
ool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .48541 Mtetra
.75545 .48541 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .4782 Mtetra
.7793 .4782 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44875 Mtetra
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44065 .92668 .43364 Mtetra
.92668 .43364 .93144 .44065 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .58411 Mtetra
.4033 .58411 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54822 Mtetra
.52145 .54822 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52402 .62206 .51766 Mtetra
.62206 .51766 .62773 .52402 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .48541 .75014 .47875 Mtetra
.75014 .47875 .75545 .48541 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .4782 .77406 .47149 Mtetra
.77406 .47149 .7793 .4782 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44875 .87177 .44181 Mtetra
.87177 .44181 .87672 .44875 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .58411 .39701 .57819 Mtetra
.39701 .57819 .4033 .58411 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55867 Mtetra
.46098 .55867 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54822 .51547 .54204 Mtetra
.51547 .54204 .52145 .54822 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .4684 Mtetra
.75676 .4684 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55867 .45481 .55256 Mtetra
.45481 .55256 .46098 .55867 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50128 Mtetra
.62206 .50128 .62778 .50776 .63927 .50425 .63357 .49775 Mtetra
.63357 .49775 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47569 .72744 .46896 Mtetra
.72744 .46896 .73287 .47569 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .4684 .7514 .46161 Mtetra
.7514 .46161 .75676 .4684 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50884 Mtetra
.57056 .50884 .57646 .51526 .58779 .51178 .58192 .50534 Mtetra
.58192 .50534 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60479 .4983 Mtetra
.664 .741 .908 r
.60479 .4983 .61059 .50479 .62206 .50128 .61629 .49476 Mtetra
.61629 .49476 .62206 .50128 .63357 .49775 .62783 .4912 Mtetra
.62783 .4912 .63357 .49775 .64514 .4942 .63943 .48763 Mtetra
.63943 .48763 .64514 .4942 .65675 .49064 .65108 .48404 Mtetra
.65108 .48404 .65675 .49064 .66841 .48706 .66277 .48044 Mtetra
.66277 .48044 .66841 .48706 .68012 .48347 .67451 .47682 Mtetra
.67451 .47682 .68012 .48347 .69187 .47986 .6863 .47318 Mtetra
.6863 .47318 .69187 .47986 .70368 .47624 .69814 .46953 Mtetra
.664 .741 .907 r
.69814 .46953 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51633 Mtetra
.51952 .51633 .52558 .52269 .53676 .51925 .53073 .51286 Mtetra
.53073 .51286 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50588 Mtetra
.664 .741 .908 r
.55328 .50588 .55925 .51232 .57056 .50884 .56462 .50238 Mtetra
.663 .741 .908 r
.56462 .50238 .57056 .50884 .58192 .50534 .57602 .49886 Mtetra
.57602 .49886 .58192 .50534 .59333 .50182 .58745 .49534 Mtetra
.663 .742 .909 r
.58745 .49534 .59333 .50182 .60479 .4983 .59894 .49181 Mtetra
.663 .743 .909 r
.59894 .49181 .60479 .4983 .61629 .49476 .61047 .48826 Mtetra
.663 .743 .91 r
.61047 .48826 .61629 .49476 .62783 .4912 .62206 .4847 Mtetra
.663 .744 .91 r
.62206 .4847 .62783 .4912 .63943 .48763 .63368 .48111 Mtetra
.664 .744 .91 r
.63368 .48111 .63943 .48763 .65108 .48404 .64536 .47749 Mtetra
.64536 .47749 .65108 .48404 .66277 .48044 .65709 .47385 Mtetra
.665 .744 .91 r
.65709 .47385 .66277 .48044 .67451 .47682 .66886 .47018 Mtetra
.665 .744 .909 r
.66886 .47018 .67451 .47682 .6863 .47318 .68069 .46649 Mtetra
.665 .743 .909 r
.68069 .46649 .6863 .47318 .69814 .46953 .69256 .46279 Mtetra
.664 .742 .908 r
.69256 .46279 .69814 .46953 .71003 .46586 .70448 .45908 Mtetra
.70448 .45908 .71003 .46586 .72197 .46218 .71646 .45536 Mtetra
.664 .741 .908 r
.71646 .45536 .72197 .46218 .73396 .45848 .72848 .45163 Mtetra
.664 .741 .907 r
.72848 .45163 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51633 .51342 .50991 Mtetra
.51342 .50991 .51952 .51633 .53073 .51286 .52465 .50642 Mtetra
.663 .741 .908 r
.52465 .50642 .53073 .51286 .54198 .50937 .53593 .50292 Mtetra
.53593 .50292 .54198 .50937 .55328 .50588 .54726 .49942 Mtetra
.662 .742 .909 r
.54726 .49942 .55328 .50588 .56462 .50238 .55864 .49594 Mtetra
.661 .743 .91 r
.55864 .49594 .56462 .50238 .57602 .49886 .57006 .49246 Mtetra
.66 .744 .912 r
.57006 .49246 .57602 .49886 .58745 .49534 .58153 .489 Mtetra
.66 .747 .915 r
.58153 .489 .58745 .49534 .59894 .49181 .59306 .48553 Mtetra
.659 .75 .917 r
.59306 .48553 .59894 .49181 .61047 .48826 .60462 .48205 Mtetra
.66 .753 .919 r
.60462 .48205 .61047 .48826 .62206 .4847 .61624 .47853 Mtetra
.661 .756 .92 r
.61624 .47853 .62206 .4847 .63368 .48111 .62791 .47496 Mtetra
.663 .758 .921 r
.62791 .47496 .63368 .48111 .64536 .47749 .63962 .47132 Mtetra
.665 .759 .92 r
.63962 .47132 .64536 .47749 .65709 .47385 .65138 .4676 Mtetra
.666 .758 .919 r
.65138 .4676 .65709 .47385 .66886 .47018 .66319 .46384 Mtetra
.667 .756 .916 r
.66319 .46384 .66886 .47018 .68069 .46649 .67504 .46003 Mtetra
.667 .753 .914 r
.67504 .46003 .68069 .46649 .69256 .46279 .68694 .4562 Mtetra
.667 .749 .912 r
.68694 .4562 .69256 .46279 .70448 .45908 .6989 .45237 Mtetra
.666 .746 .91 r
.6989 .45237 .70448 .45908 .71646 .45536 .7109 .44856 Mtetra
.665 .744 .909 r
.7109 .44856 .71646 .45536 .72848 .45163 .72296 .44475 Mtetra
.665 .742 .908 r
.72296 .44475 .72848 .45163 .74056 .44788 .73507 .44096 Mtetra
.664 .741 .908 r
.73507 .44096 .74056 .44788 .75268 .44413 .74723 .43716 Mtetra
.664 .741 .907 r
.74723 .43716 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.663 .741 .908 r
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50346 Mtetra
.50726 .50346 .51342 .50991 .52465 .50642 .51853 .49997 Mtetra
.661 .741 .909 r
.51853 .49997 .52465 .50642 .53593 .50292 .52984 .49651 Mtetra
.659 .743 .912 r
.52984 .49651 .53593 .50292 .54726 .49942 .5412 .4931 Mtetra
.656 .745 .916 r
.5412 .4931 .54726 .49942 .55864 .49594 .55261 .48975 Mtetra
.653 .75 .921 r
.55261 .48975 .55864 .49594 .57006 .49246 .56407 .48647 Mtetra
.65 .757 .927 r
.56407 .48647 .57006 .49246 .58153 .489 .57558 .48322 Mtetra
.649 .764 .933 r
.57558 .48322 .58153 .489 .59306 .48553 .58714 .47997 Mtetra
.65 .773 .939 r
.58714 .47997 .59306 .48553 .60462 .48205 .59875 .47665 Mtetra
.652 .78 .942 r
.59875 .47665 .60462 .48205 .61624 .47853 .61041 .47324 Mtetra
.655 .786 .944 r
.61041 .47324 .61624 .47853 .62791 .47496 .62211 .4697 Mtetra
.659 .79 .944 r
.62211 .4697 .62791 .47496 .63962 .47132 .63386 .46603 Mtetra
.664 .791 .943 r
.63386 .46603 .63962 .47132 .65138 .4676 .64566 .46223 Mtetra
.668 .79 .939 r
.64566 .46223 .65138 .4676 .66319 .46384 .6575 .4583 Mtetra
.672 .786 .935 r
.6575 .4583 .66319 .46384 .67504 .46003 .66938 .45427 Mtetra
.674 .78 .93 r
.66938 .45427 .67504 .46003 .68694 .4562 .68131 .45018 Mtetra
.674 .772 .924 r
.68131 .45018 .68694 .4562 .6989 .45237 .69329 .44608 Mtetra
.673 .764 .919 r
.69329 .44608 .6989 .45237 .7109 .44856 .70532 .44201 Mtetra
.671 .756 .914 r
.70532 .44201 .7109 .44856 .72296 .44475 .71741 .438 Mtetra
.668 .749 .911 r
.71741 .438 .72296 .44475 .73507 .44096 .72955 .43407 Mtetra
.666 .745 .909 r
.72955 .43407 .73507 .44096 .74723 .43716 .74174 .43017 Mtetra
.665 .743 .908 r
.74174 .43017 .74723 .43716 .75945 .43335 .75399 .42631 Mtetra
.664 .741 .908 r
.75399 .42631 .75945 .43335 .77171 .42953 .7663 .42245 Mtetra
.664 .741 .907 r
.7663 .42245 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50399 Mtetra
.663 .741 .908 r
.47861 .50399 .48487 .51044 .49604 .50695 .48981 .50049 Mtetra
.662 .741 .909 r
.48981 .50049 .49604 .50695 .50726 .50346 .50106 .49702 Mtetra
.659 .742 .911 r
.50106 .49702 .50726 .50346 .51853 .49997 .51236 .49362 Mtetra
.654 .744 .916 r
.51236 .49362 .51853 .49997 .52984 .49651 .5237 .49034 Mtetra
.647 .749 .923 r
.5237 .49034 .52984 .49651 .5412 .4931 .5351 .48721 Mtetra
.641 .757 .933 r
.5351 .48721 .5412 .4931 .55261 .48975 .54654 .48421 Mtetra
.635 .769 .944 r
.54654 .48421 .55261 .48975 .56407 .48647 .55804 .48127 Mtetra
.633 .781 .952 r
.55804 .48127 .56407 .48647 .57558 .48322 .56959 .47828 Mtetra
.636 .793 .958 r
.56959 .47828 .57558 .48322 .58714 .47997 .58119 .47515 Mtetra
.641 .8 .959 r
.58119 .47515 .58714 .47997 .59875 .47665 .59283 .47184 Mtetra
.648 .803 .958 r
.59283 .47184 .59875 .47665 .61041 .47324 .60453 .46837 Mtetra
.653 .803 .955 r
.60453 .46837 .61041 .47324 .62211 .4697 .61627 .46477 Mtetra
.656 .803 .953 r
.61627 .46477 .62211 .4697 .63386 .46603 .62806 .46108 Mtetra
.66 .804 .952 r
.62806 .46108 .63386 .46603 .64566 .46223 .6399 .45728 Mtetra
.664 .807 .951 r
.6399 .45728 .64566 .46223 .6575 .4583 .65179 .45336 Mtetra
.67 .81 .95 r
.65179 .45336 .6575 .4583 .66938 .45427 .66371 .44926 Mtetra
.676 .81 .947 r
.66371 .44926 .66938 .45427 .68131 .45018 .67568 .445 Mtetra
.682 .806 .942 r
.67568 .445 .68131 .45018 .69329 .44608 .68769 .44058 Mtetra
.684 .796 .934 r
.68769 .44058 .69329 .44608 .70532 .44201 .69974 .43612 Mtetra
.682 .783 .927 r
.69974 .43612 .70532 .44201 .71741 .438 .71184 .4317 Mtetra
.678 .769 .919 r
.71184 .4317 .71741 .438 .72955 .43407 .724 .42742 Mtetra
.673 .757 .914 r
.724 .42742 .72955 .43407 .74174 .43017 .73622 .42328 Mtetra
.669 .749 .91 r
.73622 .42328 .74174 .43017 .75399 .42631 .7485 .41927 Mtetra
.666 .744 .908 r
.7485 .41927 .75399 .42631 .7663 .42245 .76083 .41533 Mtetra
.665 .742 .908 r
.76083 .41533 .7663 .42245 .77865 .41858 .77323 .41141 Mtetra
.664 .741 .907 r
.77323 .41141 .77865 .41858 .79106 .4147 .78568 .40749 Mtetra
.78568 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .50101 Mtetra
.663 .741 .908 r
.46112 .50101 .46745 .50749 .47861 .50399 .4723 .49751 Mtetra
.661 .741 .909 r
.4723 .49751 .47861 .50399 .48981 .50049 .48354 .49406 Mtetra
.656 .742 .913 r
.48354 .49406 .48981 .50049 .50106 .49702 .49481 .49074 Mtetra
.647 .745 .921 r
.49481 .49074 .50106 .49702 .51236 .49362 .50614 .48763 Mtetra
.636 .752 .932 r
.50614 .48763 .51236 .49362 .5237 .49034 .51751 .48477 Mtetra
.625 .764 .946 r
.51751 .48477 .5237 .49034 .5351 .48721 .52894 .48206 Mtetra
.621 .779 .957 r
.52894 .48206 .5351 .48721 .54654 .48421 .54042 .47933 Mtetra
.63 .793 .96 r
.54042 .47933 .54654 .48421 .55804 .48127 .55195 .47633 Mtetra
.649 .797 .954 r
.55195 .47633 .55804 .48127 .56959 .47828 .56354 .47289 Mtetra
.667 .787 .938 r
.56354 .47289 .56959 .47828 .58119 .47515 .57516 .46904 Mtetra
.678 .766 .918 r
.57516 .46904 .58119 .47515 .59283 .47184 .58683 .46493 Mtetra
.678 .742 .899 r
.58683 .46493 .59283 .47184 .60453 .46837 .59854 .46077 Mtetra
.672 .721 .886 r
.59854 .46077 .60453 .46837 .61627 .46477 .61031 .45677 Mtetra
.663 .708 .881 r
.61031 .45677 .61627 .46477 .62806 .46108 .62213 .45305 Mtetra
.654 .705 .884 r
.62213 .45305 .62806 .46108 .6399 .45728 .63401 .44959 Mtetra
.65 .713 .894 r
.63401 .44959 .6399 .45728 .65179 .45336 .64595 .4463 Mtetra
.65 .732 .909 r
.64595 .4463 .65179 .45336 .66371 .44926 .65794 .44296 Mtetra
.656 .76 .926 r
.65794 .44296 .66371 .44926 .67568 .445 .66997 .43936 Mtetra
.668 .787 .938 r
.66997 .43936 .67568 .445 .68769 .44058 .68204 .43534 Mtetra
.681 .807 .942 r
.68204 .43534 .68769 .44058 .69974 .43612 .69414 .43088 Mtetra
.69 .81 .939 r
.69414 .43088 .69974 .43612 .71184 .4317 .70627 .42614 Mtetra
.692 .8 .932 r
.70627 .42614 .71184 .4317 .724 .42742 .71845 .42137 Mtetra
.687 .783 .924 r
.71845 .42137 .724 .42742 .73622 .42328 .73068 .41676 Mtetra
.678 .765 .917 r
.73068 .41676 .73622 .42328 .7485 .41927 .74297 .41239 Mtetra
.671 .753 .912 r
.74297 .41239 .7485 .41927 .76083 .41533 .75534 .40824 Mtetra
.667 .745 .909 r
.75534 .40824 .76083 .41533 .77323 .41141 .76776 .40421 Mtetra
.665 .742 .908 r
.76776 .40421 .77323 .41141 .78568 .40749 .78025 .40023 Mtetra
.664 .741 .907 r
.78025 .40023 .78568 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39229 Mtetra
.80538 .39229 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49803 Mtetra
.663 .741 .908 r
.44356 .49803 .44998 .50452 .46112 .50101 .45473 .49452 Mtetra
.66 .741 .91 r
.45473 .49452 .46112 .50101 .4723 .49751 .46595 .49108 Mtetra
.653 .742 .915 r
.46595 .49108 .4723 .49751 .48354 .49406 .4772 .48782 Mtetra
.641 .745 .925 r
.4772 .48782 .48354 .49406 .49481 .49074 .48851 .48487 Mtetra
.624 .753 .939 r
.48851 .48487 .49481 .49074 .50614 .48763 .49986 .48226 Mtetra
.613 .768 .954 r
.49986 .48226 .50614 .48763 .51751 .48477 .51127 .47977 Mtetra
.622 .786 .96 r
.51127 .47977 .51751 .48477 .52894 .48206 .52273 .47696 Mtetra
.657 .793 .947 r
.52273 .47696 .52894 .48206 .54042 .47933 .53425 .47336 Mtetra
.695 .774 .912 r
.53425 .47336 .54042 .47933 .55195 .47633 .5458 .46871 Mtetra
.712 .731 .866 r
.5458 .46871 .55195 .47633 .56354 .47289 .55739 .46317 Mtetra
.687 .676 .833 r
.55739 .46317 .56354 .47289 .57516 .46904 .56902 .4582 Mtetra
.655 .642 .825 r
.56902 .4582 .57516 .46904 .58683 .46493 .58072 .45449 Mtetra
.656 .65 .833 r
.58072 .45449 .58683 .46493 .59854 .46077 .59246 .45076 Mtetra
.658 .66 .841 r
.59246 .45076 .59854 .46077 .61031 .45677 .60425 .44702 Mtetra
.659 .666 .846 r
.60425 .44702 .61031 .45677 .62213 .45305 .6161 .44326 Mtetra
.6161 .44326 .62213 .45305 .63401 .44959 .62799 .43948 Mtetra
.658 .66 .841 r
.62799 .43948 .63401 .44959 .64595 .4463 .63994 .43569 Mtetra
.656 .65 .833 r
.63994 .43569 .64595 .4463 .65794 .44296 .65193 .43188 Mtetra
.625 .628 .834 r
.65193 .43188 .65794 .44296 .66997 .43936 .66403 .42935 Mtetra
.609 .643 .858 r
.66403 .42935 .66997 .43936 .68204 .43534 .67623 .42739 Mtetra
.633 .704 .897 r
.67623 .42739 .68204 .43534 .69414 .43088 .68844 .42453 Mtetra
.664 .765 .925 r
.68844 .42453 .69414 .43088 .70627 .42614 .70066 .42063 Mtetra
.689 .803 .935 r
.70066 .42063 .70627 .42614 .71845 .42137 .71288 .4159 Mtetra
.699 .809 .933 r
.71288 .4159 .71845 .42137 .73068 .41676 .72513 .41085 Mtetra
.695 .793 .926 r
.72513 .41085 .73068 .41676 .74297 .41239 .73744 .40592 Mtetra
.684 .772 .918 r
.73744 .40592 .74297 .41239 .75534 .40824 .74981 .40133 Mtetra
.674 .755 .912 r
.74981 .40133 .75534 .40824 .76776 .40421 .76226 .39705 Mtetra
.668 .746 .909 r
.76226 .39705 .76776 .40421 .78025 .40023 .77477 .39295 Mtetra
.665 .742 .908 r
.77477 .39295 .78025 .40023 .79279 .39626 .78735 .38892 Mtetra
.664 .741 .907 r
.78735 .38892 .79279 .39626 .80538 .39229 .79998 .3849 Mtetra
.79998 .3849 .80538 .39229 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49503 Mtetra
.663 .741 .908 r
.42595 .49503 .43244 .50155 .44356 .49803 .4371 .4915 Mtetra
.66 .741 .91 r
.4371 .4915 .44356 .49803 .45473 .49452 .4483 .48806 Mtetra
.652 .741 .915 r
.4483 .48806 .45473 .49452 .46595 .49108 .45954 .48483 Mtetra
.636 .744 .926 r
.45954 .48483 .46595 .49108 .4772 .48782 .47082 .48199 Mtetra
.615 .752 .943 r
.47082 .48199 .4772 .48782 .48851 .48487 .48215 .47957 Mtetra
.607 .77 .958 r
.48215 .47957 .48851 .48487 .49986 .48226 .49353 .47717 Mtetra
.639 .788 .954 r
.49353 .47717 .49986 .48226 .51127 .47977 .50498 .47401 Mtetra
.699 .781 .915 r
.50498 .47401 .51127 .47977 .52273 .47696 .51648 .46926 Mtetra
.734 .734 .851 r
.51648 .46926 .52273 .47696 .53425 .47336 .52801 .46267 Mtetra
.66 .646 .826 r
.52801 .46267 .53425 .47336 .5458 .46871 .53959 .45877 Mtetra
.658 .66 .841 r
.53959 .45877 .5458 .46871 .55739 .46317 .55122 .45506 Mtetra
.663 .704 .878 r
.55122 .45506 .55739 .46317 .56902 .4582 .5629 .45133 Mtetra
.664 .741 .907 r
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66403 .42935 .65813 .42096 Mtetra
.663 .704 .878 r
.65813 .42096 .66403 .42935 .67623 .42739 .67026 .41709 Mtetra
.652 .658 .843 r
.67026 .41709 .67623 .42739 .68844 .42453 .68246 .41341 Mtetra
.581 .609 .845 r
.68246 .41341 .68844 .42453 .70066 .42063 .69485 .41247 Mtetra
.63 .7 .896 r
.69485 .41247 .70066 .42063 .71288 .4159 .70722 .40965 Mtetra
.678 .777 .925 r
.70722 .40965 .71288 .4159 .72513 .41085 .71956 .40523 Mtetra
.703 .807 .93 r
.71956 .40523 .72513 .41085 .73744 .40592 .73189 .40002 Mtetra
.701 .798 .925 r
.73189 .40002 .73744 .40592 .74981 .40133 .74427 .39483 Mtetra
.688 .775 .918 r
.74427 .39483 .74981 .40133 .76226 .39705 .75673 .39006 Mtetra
.675 .756 .912 r
.75673 .39006 .76226 .39705 .77477 .39295 .76926 .38569 Mtetra
.668 .746 .909 r
.76926 .38569 .77477 .39295 .78735 .38892 .78187 .38153 Mtetra
.665 .742 .908 r
.78187 .38153 .78735 .38892 .79998 .3849 .79454 .37746 Mtetra
.664 .741 .907 r
.79454 .37746 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.663 .741 .908 r
.40827 .49201 .41484 .49856 .42595 .49503 .4194 .48847 Mtetra
.66 .74 .909 r
.4194 .48847 .42595 .49503 .4371 .4915 .43058 .48499 Mtetra
.652 .741 .915 r
.43058 .48499 .4371 .4915 .4483 .48806 .4418 .48174 Mtetra
.634 .742 .926 r
.4418 .48174 .4483 .48806 .45954 .48483 .45306 .47893 Mtetra
.609 .749 .944 r
.45306 .47893 .45954 .48483 .47082 .48199 .46437 .47663 Mtetra
.604 .767 .958 r
.46437 .47663 .47082 .48199 .48215 .47957 .47573 .47429 Mtetra
.657 .787 .944 r
.47573 .47429 .48215 .47957 .49353 .47717 .48716 .47072 Mtetra
.729 .766 .882 r
.48716 .47072 .49353 .47717 .50498 .47401 .49866 .46474 Mtetra
.699 .689 .837 r
.49866 .46474 .50498 .47401 .51648 .46926 .51018 .45934 Mtetra
.657 .661 .841 r
.51018 .45934 .51648 .46926 .52801 .46267 .52175 .45563 Mtetra
.664 .734 .902 r
.52175 .45563 .52801 .46267 .53959 .45877 .53336 .45191 Mtetra
.664 .741 .907 r
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68246 .41341 .67662 .40598 Mtetra
.664 .734 .902 r
.67662 .40598 .68246 .41341 .69485 .41247 .6889 .40204 Mtetra
.614 .641 .854 r
.6889 .40204 .69485 .41247 .70722 .40965 .70132 .39983 Mtetra
.595 .646 .87 r
.70132 .39983 .70722 .40965 .71956 .40523 .71385 .39822 Mtetra
.666 .751 .914 r
.71385 .39822 .71956 .40523 .73189 .40002 .7263 .39414 Mtetra
.705 .802 .925 r
.7263 .39414 .73189 .40002 .74427 .39483 .73872 .38881 Mtetra
.705 .798 .922 r
.73872 .38881 .74427 .39483 .75673 .39006 .75118 .38344 Mtetra
.689 .774 .916 r
.75118 .38344 .75673 .39006 .76926 .38569 .76373 .37857 Mtetra
.675 .755 .911 r
.76373 .37857 .76926 .38569 .78187 .38153 .77636 .37416 Mtetra
.667 .745 .909 r
.77636 .37416 .78187 .38153 .79454 .37746 .78906 .36997 Mtetra
.665 .742 .908 r
.78906 .36997 .79454 .37746 .80727 .37339 .80183 .36585 Mtetra
.664 .741 .907 r
.80183 .36585 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.663 .741 .908 r
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .48542 Mtetra
.661 .741 .909 r
.40165 .48542 .40827 .49201 .4194 .48847 .41281 .4819 Mtetra
.654 .74 .913 r
.41281 .4819 .4194 .48847 .43058 .48499 .42401 .47858 Mtetra
.637 .741 .923 r
.42401 .47858 .43058 .48499 .4418 .48174 .43525 .4757 Mtetra
.609 .745 .941 r
.43525 .4757 .4418 .48174 .45306 .47893 .44653 .47342 Mtetra
.599 .761 .956 r
.44653 .47342 .45306 .47893 .46437 .47663 .45786 .47119 Mtetra
.662 .783 .939 r
.45786 .47119 .46437 .47663 .47573 .47429 .46928 .4675 Mtetra
.746 .76 .864 r
.46928 .4675 .47573 .47429 .48716 .47072 .48078 .46065 Mtetra
.674 .664 .833 r
.48078 .46065 .48716 .47072 .49866 .46474 .49229 .4562 Mtetra
.661 .694 .869 r
.49229 .4562 .49866 .46474 .51018 .45934 .50384 .45248 Mtetra
.664 .741 .907 r
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70132 .39983 .69543 .39075 Mtetra
.641 .685 .876 r
.69543 .39075 .70132 .39983 .71385 .39822 .70789 .38751 Mtetra
.572 .617 .859 r
.70789 .38751 .71385 .39822 .7263 .39414 .72057 .38671 Mtetra
.663 .74 .907 r
.72057 .38671 .7263 .39414 .73872 .38881 .73311 .38271 Mtetra
.709 .798 .92 r
.73311 .38271 .73872 .38881 .75118 .38344 .74561 .37719 Mtetra
.706 .794 .919 r
.74561 .37719 .75118 .38344 .76373 .37857 .75816 .37172 Mtetra
.687 .769 .914 r
.75816 .37172 .76373 .37857 .77636 .37416 .77081 .36687 Mtetra
.673 .752 .91 r
.77081 .36687 .77636 .37416 .78906 .36997 .78354 .36246 Mtetra
.666 .744 .908 r
.78354 .36246 .78906 .36997 .80183 .36585 .79634 .35826 Mtetra
.664 .741 .907 r
.79634 .35826 .80183 .36585 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48237 Mtetra
.662 .741 .908 r
.38383 .48237 .39053 .48899 .40165 .48542 .39498 .4788 Mtetra
.657 .74 .911 r
.39498 .4788 .40165 .48542 .41281 .4819 .40616 .47537 Mtetra
.642 .739 .919 r
.40616 .47537 .41281 .4819 .42401 .47858 .41739 .47234 Mtetra
.614 .741 .936 r
.41739 .47234 .42401 .47858 .43525 .4757 .42864 .46995 Mtetra
.593 .752 .953 r
.42864 .46995 .43525 .4757 .44653 .47342 .43994 .46789 Mtetra
.65 .778 .941 r
.43994 .46789 .44653 .47342 .45786 .47119 .45133 .4645 Mtetra
.749 .764 .865 r
.45133 .4645 .45786 .47119 .46928 .4675 .46284 .45752 Mtetra
.674 .667 .835 r
.46284 .45752 .46928 .4675 .48078 .46065 .47433 .45305 Mtetra
.663 .719 .89 r
.47433 .45305 .48078 .46065 .49229 .4562 .48586 .44932 Mtetra
.664 .741 .907 r
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.626 .728 .92 r
.56794 .42274 .57415 .42983 .58604 .42599 .57989 .41997 Mtetra
.662 .775 .933 r
.57989 .41997 .58604 .42599 .59799 .42215 .59187 .4161 Mtetra
.699 .786 .918 r
.59187 .4161 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.664 .741 .907 r
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70789 .38751 .70204 .37931 Mtetra
.641 .71 .897 r
.70204 .37931 .70789 .38751 .72057 .38671 .7146 .37602 Mtetra
.568 .618 .862 r
.7146 .37602 .72057 .38671 .73311 .38271 .72738 .37531 Mtetra
.672 .747 .907 r
.72738 .37531 .73311 .38271 .74561 .37719 .74 .37093 Mtetra
.714 .798 .917 r
.74 .37093 .74561 .37719 .75816 .37172 .75258 .36518 Mtetra
.703 .786 .916 r
.75258 .36518 .75816 .37172 .77081 .36687 .76523 .35975 Mtetra
.683 .762 .912 r
.76523 .35975 .77081 .36687 .78354 .36246 .77797 .35498 Mtetra
.67 .748 .909 r
.77797 .35498 .78354 .36246 .79634 .35826 .79081 .35062 Mtetra
.665 .742 .908 r
.79081 .35062 .79634 .35826 .80921 .35409 .80371 .3464 Mtetra
.664 .741 .907 r
.80371 .3464 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.663 .741 .908 r
.36595 .47931 .37273 .48596 .38383 .48237 .37708 .47571 Mtetra
.66 .74 .909 r
.37708 .47571 .38383 .48237 .39498 .4788 .38825 .47218 Mtetra
.65 .739 .915 r
.38825 .47218 .39498 .4788 .40616 .47537 .39946 .46892 Mtetra
.625 .738 .929 r
.39946 .46892 .40616 .47537 .41739 .47234 .4107 .46631 Mtetra
.593 .743 .948 r
.4107 .46631 .41739 .47234 .42864 .46995 .42197 .4643 Mtetra
.622 .766 .948 r
.42197 .4643 .42864 .46995 .43994 .46789 .43332 .46156 Mtetra
.735 .772 .882 r
.43332 .46156 .43994 .46789 .45133 .4645 .44481 .45534 Mtetra
.7 .693 .84 r
.44481 .45534 .45133 .4645 .46284 .45752 .45631 .4499 Mtetra
.663 .719 .89 r
.45631 .4499 .46284 .45752 .47433 .45305 .46782 .44615 Mtetra
.664 .741 .907 r
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.322 .587 .939 r
.52611 .42718 .53247 .43423 .54424 .43041 .53795 .42998 Mtetra
.1 0 0 r
.53795 .42998 .54424 .43041 .55607 .42658 .54987 .43125 Mtetra
.296 0 0 r
.54987 .43125 .55607 .42658 .56794 .42274 .56186 .43048 Mtetra
.315 0 0 r
.56186 .43048 .56794 .42274 .57989 .41997 .5739 .42802 Mtetra
.25 0 0 r
.5739 .42802 .57989 .41997 .59187 .4161 .58598 .42413 Mtetra
.166 0 0 r
.58598 .42413 .59187 .4161 .60388 .4111 .59807 .41879 Mtetra
.038 0 0 r
.59807 .41879 .60388 .4111 .61597 .40719 .61017 .41176 Mtetra
0 0 0 r
.61017 .41176 .61597 .40719 .6281 .40326 .62223 .40265 Mtetra
.835 .978 .879 r
.62223 .40265 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.664 .741 .907 r
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .7146 .37602 .70873 .36773 Mtetra
.609 .697 .906 r
.70873 .36773 .7146 .37602 .72738 .37531 .72145 .36538 Mtetra
.589 .647 .876 r
.72145 .36538 .72738 .37531 .74 .37093 .73429 .36383 Mtetra
.693 .766 .908 r
.73429 .36383 .74 .37093 .75258 .36518 .74696 .35871 Mtetra
.715 .795 .913 r
.74696 .35871 .75258 .36518 .76523 .35975 .75962 .35284 Mtetra
.696 .775 .912 r
.75962 .35284 .76523 .35975 .77797 .35498 .77237 .34758 Mtetra
.676 .754 .91 r
.77237 .34758 .77797 .35498 .79081 .35062 .78523 .34297 Mtetra
.667 .744 .908 r
.78523 .34297 .79081 .35062 .80371 .3464 .79817 .33864 Mtetra
.664 .741 .907 r
.79817 .33864 .80371 .3464 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47262 Mtetra
.662 .741 .908 r
.35912 .47262 .36595 .47931 .37708 .47571 .37027 .46901 Mtetra
.656 .74 .911 r
.37027 .46901 .37708 .47571 .38825 .47218 .38147 .46556 Mtetra
.638 .738 .921 r
.38147 .46556 .38825 .47218 .39946 .46892 .39269 .46259 Mtetra
.604 .737 .939 r
.39269 .46259 .39946 .46892 .4107 .46631 .40394 .4604 Mtetra
.595 .75 .951 r
.40394 .4604 .4107 .46631 .42197 .4643 .41525 .45829 Mtetra
.695 .775 .913 r
.41525 .45829 .42197 .4643 .43332 .46156 .42668 .45361 Mtetra
.737 .731 .846 r
.42668 .45361 .43332 .46156 .44481 .45534 .43822 .44673 Mtetra
.661 .694 .87 r
.43822 .44673 .44481 .45534 .45631 .4499 .44972 .44297 Mtetra
.664 .741 .907 r
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.439 .649 .948 r
.49618 .42777 .50265 .43481 .51436 .431 .5079 .4288 Mtetra
.292 0 0 r
.5079 .4288 .51436 .431 .52611 .42718 .51969 .43346 Mtetra
.471 0 .033 r
.51969 .43346 .52611 .42718 .53795 .42998 .53159 .4351 Mtetra
.315 0 0 r
.53159 .4351 .53795 .42998 .54987 .43125 .54357 .43436 Mtetra
.063 0 0 r
.54357 .43436 .54987 .43125 .56186 .43048 .55562 .43207 Mtetra
.193 .716 .694 r
.55562 .43207 .56186 .43048 .5739 .42802 .56771 .42882 Mtetra
.351 .827 .818 r
.56771 .42882 .5739 .42802 .58598 .42413 .57985 .4249 Mtetra
.417 .865 .839 r
.57985 .4249 .58598 .42413 .59807 .41879 .59203 .42031 Mtetra
.427 .866 .786 r
.59203 .42031 .59807 .41879 .61017 .41176 .60424 .41476 Mtetra
.407 .83 .664 r
.60424 .41476 .61017 .41176 .62223 .40265 .61644 .40763 Mtetra
0 0 0 r
.61644 .40763 .62223 .40265 .63425 .39198 .62859 .39809 Mtetra
.62859 .39809 .63425 .39198 .64653 .38798 .64065 .38549 Mtetra
.806 .933 .916 r
.64065 .38549 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.664 .741 .907 r
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72145 .36538 .71551 .35601 Mtetra
.564 .65 .893 r
.71551 .35601 .72145 .36538 .73429 .36383 .72842 .35506 Mtetra
.634 .698 .892 r
.72842 .35506 .73429 .36383 .74696 .35871 .74126 .35188 Mtetra
.712 .784 .908 r
.74126 .35188 .74696 .35871 .75962 .35284 .75398 .34605 Mtetra
.71 .786 .911 r
.75398 .34605 .75962 .35284 .77237 .34758 .76674 .34029 Mtetra
.686 .763 .91 r
.76674 .34029 .77237 .34758 .78523 .34297 .77962 .33532 Mtetra
.671 .748 .908 r
.77962 .33532 .78523 .34297 .79817 .33864 .79259 .33084 Mtetra
.665 .742 .908 r
.79259 .33084 .79817 .33864 .81118 .33439 .80564 .32653 Mtetra
.664 .741 .907 r
.80564 .32653 .81118 .33439 .82424 .33014 .81874 .32224 Mtetra
.81874 .32224 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30489 Mtetra
.87177 .30489 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.663 .741 .908 r
.34109 .46952 .348 .47624 .35912 .47262 .35223 .46587 Mtetra
.661 .74 .909 r
.35223 .46587 .35912 .47262 .37027 .46901 .36341 .46228 Mtetra
.65 .739 .914 r
.36341 .46228 .37027 .46901 .38147 .46556 .37463 .45897 Mtetra
.623 .736 .928 r
.37463 .45897 .38147 .46556 .39269 .46259 .38587 .45636 Mtetra
.589 .737 .946 r
.38587 .45636 .39269 .46259 .40394 .4604 .39713 .45443 Mtetra
.634 .761 .939 r
.39713 .45443 .40394 .4604 .41525 .45829 .4085 .45145 Mtetra
.761 .763 .854 r
.4085 .45145 .41525 .45829 .42668 .45361 .42006 .44376 Mtetra
.663 .668 .844 r
.42006 .44376 .42668 .45361 .43822 .44673 .43155 .43977 Mtetra
.664 .741 .907 r
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.308 .582 .939 r
.47794 .42452 .48449 .43159 .49618 .42777 .48959 .42736 Mtetra
.507 0 0 r
.48959 .42736 .49618 .42777 .5079 .4288 .50132 .43312 Mtetra
.437 0 0 r
.50132 .43312 .5079 .4288 .51969 .43346 .51318 .43495 Mtetra
.032 0 0 r
.51318 .43495 .51969 .43346 .53159 .4351 .52514 .43387 Mtetra
.438 .856 .956 r
.52514 .43387 .53159 .4351 .54357 .43436 .53716 .43109 Mtetra
.605 .862 .992 r
.53716 .43109 .54357 .43436 .55562 .43207 .54924 .42751 Mtetra
.646 .828 .97 r
.54924 .42751 .55562 .43207 .56771 .42882 .56137 .42364 Mtetra
.655 .809 .957 r
.56137 .42364 .56771 .42882 .57985 .4249 .57355 .41969 Mtetra
.657 .81 .957 r
.57355 .41969 .57985 .4249 .59203 .42031 .58579 .41567 Mtetra
.663 .833 .965 r
.58579 .41567 .59203 .42031 .60424 .41476 .59807 .41134 Mtetra
.68 .884 .973 r
.59807 .41134 .60424 .41476 .61644 .40763 .61039 .40622 Mtetra
.711 .955 .95 r
.61039 .40622 .61644 .40763 .62859 .39809 .6227 .39937 Mtetra
.729 .99 .834 r
.6227 .39937 .62859 .39809 .64065 .38549 .63494 .38958 Mtetra
.727 .952 .655 r
.63494 .38958 .64065 .38549 .65284 .37651 .64704 .37577 Mtetra
.835 .98 .877 r
.64704 .37577 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.664 .741 .907 r
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.657 .738 .91 r
.70964 .34832 .71551 .35601 .72842 .35506 .72239 .34435 Mtetra
.546 .612 .87 r
.72239 .34435 .72842 .35506 .74126 .35188 .73546 .34417 Mtetra
.686 .751 .901 r
.73546 .34417 .74126 .35188 .75398 .34605 .74828 .33918 Mtetra
.718 .787 .907 r
.74828 .33918 .75398 .34605 .76674 .34029 .76107 .33308 Mtetra
.697 .772 .909 r
.76107 .33308 .76674 .34029 .77962 .33532 .77396 .32769 Mtetra
.676 .752 .908 r
.77396 .32769 .77962 .33532 .79259 .33084 .78696 .323 Mtetra
.666 .743 .908 r
.78696 .323 .79259 .33084 .80564 .32653 .80005 .31861 Mtetra
.664 .741 .907 r
.80005 .31861 .80564 .32653 .81874 .32224 .81319 .31427 Mtetra
.81319 .31427 .81874 .32224 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30489 .8664 .29677 Mtetra
.8664 .29677 .87177 .30489 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46275 Mtetra
.663 .741 .908 r
.33412 .46275 .34109 .46952 .35223 .46587 .34529 .45908 Mtetra
.659 .74 .91 r
.34529 .45908 .35223 .46587 .36341 .46228 .3565 .45552 Mtetra
.642 .737 .918 r
.3565 .45552 .36341 .46228 .37463 .45897 .36774 .45241 Mtetra
.607 .733 .934 r
.36774 .45241 .37463 .45897 .38587 .45636 .37899 .45014 Mtetra
.59 .74 .947 r
.37899 .45014 .38587 .45636 .39713 .45443 .39028 .44815 Mtetra
.692 .767 .909 r
.39028 .44815 .39713 .45443 .4085 .45145 .40174 .44351 Mtetra
.738 .733 .847 r
.40174 .44351 .4085 .45145 .42006 .44376 .41331 .43657 Mtetra
.664 .735 .902 r
.41331 .43657 .42006 .44376 .43155 .43977 .42482 .43276 Mtetra
.664 .741 .907 r
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.435 .649 .949 r
.45963 .42126 .46627 .42835 .47794 .42452 .47126 .42227 Mtetra
.534 0 0 r
.47126 .42227 .47794 .42452 .48959 .42736 .48288 .42985 Mtetra
.426 0 0 r
.48288 .42985 .48959 .42736 .50132 .43312 .49469 .43251 Mtetra
.201 .725 .852 r
.49469 .43251 .50132 .43312 .51318 .43495 .50661 .43139 Mtetra
.594 .848 .992 r
.50661 .43139 .51318 .43495 .52514 .43387 .51861 .42817 Mtetra
.666 .793 .942 r
.51861 .42817 .52514 .43387 .53716 .43109 .53067 .42404 Mtetra
.675 .753 .909 r
.53067 .42404 .53716 .43109 .54924 .42751 .54278 .41968 Mtetra
.67 .73 .895 r
.54278 .41968 .54924 .42751 .56137 .42364 .55494 .41544 Mtetra
.661 .718 .891 r
.55494 .41544 .56137 .42364 .57355 .41969 .56716 .41146 Mtetra
.653 .715 .894 r
.56716 .41146 .57355 .41969 .58579 .41567 .57943 .40774 Mtetra
.649 .723 .902 r
.57943 .40774 .58579 .41567 .59807 .41134 .59176 .40413 Mtetra
.655 .747 .917 r
.59176 .40413 .59807 .41134 .61039 .40622 .60415 .40031 Mtetra
.683 .798 .936 r
.60415 .40031 .61039 .40622 .6227 .39937 .61657 .39556 Mtetra
.747 .886 .942 r
.61657 .39556 .6227 .39937 .63494 .38958 .62897 .38868 Mtetra
.832 .976 .884 r
.62897 .38868 .63494 .38958 .64704 .37577 .64126 .37797 Mtetra
.876 .991 .743 r
.64126 .37797 .64704 .37577 .65924 .3649 .65336 .36224 Mtetra
.806 .933 .916 r
.65336 .36224 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.664 .741 .907 r
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72239 .34435 .7165 .33635 Mtetra
.55 .686 .928 r
.7165 .33635 .72239 .34435 .73546 .34417 .72954 .33534 Mtetra
.637 .702 .893 r
.72954 .33534 .73546 .34417 .74828 .33918 .74252 .33198 Mtetra
.716 .779 .902 r
.74252 .33198 .74828 .33918 .76107 .33308 .75536 .32588 Mtetra
.708 .777 .906 r
.75536 .32588 .76107 .33308 .77396 .32769 .76826 .32007 Mtetra
.683 .757 .908 r
.76826 .32007 .77396 .32769 .78696 .323 .78129 .31512 Mtetra
.669 .745 .908 r
.78129 .31512 .78696 .323 .80005 .31861 .79441 .31062 Mtetra
.665 .742 .907 r
.79441 .31062 .80005 .31861 .81319 .31427 .8076 .30623 Mtetra
.664 .741 .907 r
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46275 .3271 .45592 Mtetra
.662 .741 .908 r
.3271 .45592 .33412 .46275 .34529 .45908 .3383 .45224 Mtetra
.656 .739 .911 r
.3383 .45224 .34529 .45908 .3565 .45552 .34953 .44875 Mtetra
.633 .735 .922 r
.34953 .44875 .3565 .45552 .36774 .45241 .36078 .44585 Mtetra
.594 .731 .939 r
.36078 .44585 .36774 .45241 .37899 .45014 .37205 .44384 Mtetra
.61 .745 .941 r
.37205 .44384 .37899 .45014 .39028 .44815 .38339 .4414 Mtetra
.743 .765 .87 r
.38339 .4414 .39028 .44815 .40174 .44351 .39496 .43464 Mtetra
.693 .701 .853 r
.39496 .43464 .40174 .44351 .41331 .43657 .4065 .42953 Mtetra
.664 .741 .907 r
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
0 .153 .66 r
.45294 .4141 .45963 .42126 .47126 .42227 .46443 .42362 Mtetra
.512 0 0 r
.46443 .42362 .47126 .42227 .48288 .42985 .47614 .42836 Mtetra
.192 .706 .889 r
.47614 .42836 .48288 .42985 .49469 .43251 .48802 .42809 Mtetra
.615 .823 .98 r
.48802 .42809 .49469 .43251 .50661 .43139 .5 .42484 Mtetra
.681 .769 .918 r
.5 .42484 .50661 .43139 .51861 .42817 .51204 .42029 Mtetra
.689 .735 .886 r
.51204 .42029 .51861 .42817 .53067 .42404 .52413 .41539 Mtetra
.682 .714 .873 r
.52413 .41539 .53067 .42404 .54278 .41968 .53627 .41062 Mtetra
.671 .701 .869 r
.53627 .41062 .54278 .41968 .55494 .41544 .54846 .40618 Mtetra
.659 .693 .87 r
.54846 .40618 .55494 .41544 .56716 .41146 .5607 .40216 Mtetra
.647 .688 .874 r
.5607 .40216 .56716 .41146 .57943 .40774 .57301 .39857 Mtetra
.638 .688 .881 r
.57301 .39857 .57943 .40774 .59176 .40413 .58538 .39531 Mtetra
.633 .695 .89 r
.58538 .39531 .59176 .40413 .60415 .40031 .59781 .3922 Mtetra
.643 .719 .903 r
.59781 .3922 .60415 .40031 .61657 .39556 .6103 .38871 Mtetra
.683 .771 .917 r
.6103 .38871 .61657 .39556 .62897 .38868 .62281 .38393 Mtetra
.772 .859 .915 r
.62281 .38393 .62897 .38868 .64126 .37797 .63527 .37613 Mtetra
.881 .944 .851 r
.63527 .37613 .64126 .37797 .65336 .36224 .64756 .36322 Mtetra
.929 .97 .749 r
.64756 .36322 .65336 .36224 .66571 .35313 .65962 .34542 Mtetra
.664 .741 .907 r
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.621 .724 .92 r
.71056 .3285 .7165 .33635 .72954 .33534 .72352 .32554 Mtetra
.572 .65 .889 r
.72352 .32554 .72954 .33534 .74252 .33198 .73667 .32428 Mtetra
.703 .762 .898 r
.73667 .32428 .74252 .33198 .75536 .32588 .74959 .31858 Mtetra
.716 .779 .902 r
.74959 .31858 .75536 .32588 .76826 .32007 .76252 .31244 Mtetra
.69 .761 .906 r
.76252 .31244 .76826 .32007 .78129 .31512 .77557 .3072 Mtetra
.671 .747 .907 r
.77557 .3072 .78129 .31512 .79441 .31062 .78872 .30258 Mtetra
.665 .742 .907 r
.78872 .30258 .79441 .31062 .8076 .30623 .80196 .29813 Mtetra
.664 .741 .907 r
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45592 .32003 .44904 Mtetra
.662 .74 .908 r
.32003 .44904 .3271 .45592 .3383 .45224 .33125 .44536 Mtetra
.653 .738 .913 r
.33125 .44536 .3383 .45224 .34953 .44875 .34251 .44193 Mtetra
.624 .733 .925 r
.34251 .44193 .34953 .44875 .36078 .44585 .35377 .43924 Mtetra
.587 .728 .941 r
.35377 .43924 .36078 .44585 .37205 .44384 .36506 .43735 Mtetra
.639 .75 .929 r
.36506 .43735 .37205 .44384 .38339 .4414 .37646 .43419 Mtetra
.761 .757 .849 r
.37646 .43419 .38339 .4414 .39496 .43464 .38811 .42629 Mtetra
.662 .705 .879 r
.38811 .42629 .39496 .43464 .4065 .42953 .39963 .42244 Mtetra
.664 .741 .907 r
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.305 .582 .939 r
.43448 .4108 .44126 .41798 .45294 .4141 .44604 .41356 Mtetra
.637 .08 0 r
.44604 .41356 .45294 .4141 .46443 .42362 .45758 .42192 Mtetra
0 .51 .759 r
.45758 .42192 .46443 .42362 .47614 .42836 .46937 .42394 Mtetra
.568 .808 .989 r
.46937 .42394 .47614 .42836 .48802 .42809 .48131 .42151 Mtetra
.682 .77 .918 r
.48131 .42151 .48802 .42809 .5 .42484 .49334 .41694 Mtetra
.699 .738 .881 r
.49334 .41694 .5 .42484 .51204 .42029 .50542 .41164 Mtetra
.695 .718 .868 r
.50542 .41164 .51204 .42029 .52413 .41539 .51754 .40634 Mtetra
.685 .707 .864 r
.51754 .40634 .52413 .41539 .53627 .41062 .52971 .40133 Mtetra
.673 .698 .865 r
.52971 .40133 .53627 .41062 .54846 .40618 .54193 .39678 Mtetra
.659 .691 .868 r
.54193 .39678 .54846 .40618 .5607 .40216 .5542 .39273 Mtetra
.645 .685 .873 r
.5542 .39273 .5607 .40216 .57301 .39857 .56653 .38918 Mtetra
.632 .682 .879 r
.56653 .38918 .57301 .39857 .58538 .39531 .57893 .38609 Mtetra
.622 .683 .886 r
.57893 .38609 .58538 .39531 .59781 .3922 .5914 .3833 Mtetra
.621 .691 .894 r
.5914 .3833 .59781 .3922 .6103 .38871 .60394 .38052 Mtetra
.643 .719 .904 r
.60394 .38052 .6103 .38871 .62281 .38393 .61653 .377 Mtetra
.708 .778 .907 r
.61653 .377 .62281 .38393 .63527 .37613 .6291 .37131 Mtetra
.822 .863 .877 r
.6291 .37131 .63527 .37613 .64756 .36322 .64156 .36111 Mtetra
.923 .918 .793 r
.64156 .36111 .64756 .36322 .65962 .34542 .65376 .34443 Mtetra
.835 .978 .879 r
.65376 .34443 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.664 .741 .907 r
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72352 .32554 .7175 .31626 Mtetra
.526 .643 .907 r
.7175 .31626 .72352 .32554 .73667 .32428 .73075 .31611 Mtetra
.683 .743 .897 r
.73075 .31611 .73667 .32428 .74959 .31858 .74376 .31109 Mtetra
.719 .776 .897 r
.74376 .31109 .74959 .31858 .76252 .31244 .75673 .30476 Mtetra
.697 .764 .904 r
.75673 .30476 .76252 .31244 .77557 .3072 .7698 .29923 Mtetra
.674 .748 .907 r
.7698 .29923 .77557 .3072 .78872 .30258 .78299 .29447 Mtetra
.666 .742 .907 r
.78299 .29447 .78872 .30258 .80196 .29813 .79627 .28996 Mtetra
.664 .741 .907 r
.79627 .28996 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.663 .741 .908 r
.30169 .44586 .30885 .45277 .32003 .44904 .31289 .44211 Mtetra
.661 .74 .909 r
.31289 .44211 .32003 .44904 .33125 .44536 .32414 .43842 Mtetra
.649 .737 .914 r
.32414 .43842 .33125 .44536 .34251 .44193 .33542 .43505 Mtetra
.616 .73 .928 r
.33542 .43505 .34251 .44193 .35377 .43924 .34671 .43253 Mtetra
.586 .726 .94 r
.34671 .43253 .35377 .43924 .36506 .43735 .35802 .43065 Mtetra
.668 .753 .914 r
.35802 .43065 .36506 .43735 .37646 .43419 .36949 .42667 Mtetra
.751 .749 .85 r
.36949 .42667 .37646 .43419 .38811 .42629 .38116 .41917 Mtetra
.664 .741 .907 r
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
0 .263 .753 r
.42766 .40356 .43448 .4108 .44604 .41356 .43909 .41145 Mtetra
.463 0 0 r
.43909 .41145 .44604 .41356 .45758 .42192 .4507 .4178 Mtetra
.375 .736 .99 r
.4507 .4178 .45758 .42192 .46937 .42394 .46256 .41777 Mtetra
.654 .775 .938 r
.46256 .41777 .46937 .42394 .48131 .42151 .47456 .41399 Mtetra
.701 .749 .889 r
.47456 .41399 .48131 .42151 .49334 .41694 .48663 .40864 Mtetra
.706 .731 .87 r
.48663 .40864 .49334 .41694 .50542 .41164 .49875 .40294 Mtetra
.7 .72 .866 r
.49875 .40294 .50542 .41164 .51754 .40634 .5109 .3974 Mtetra
.688 .712 .867 r
.5109 .3974 .51754 .40634 .52971 .40133 .5231 .39227 Mtetra
.675 .705 .87 r
.5231 .39227 .52971 .40133 .54193 .39678 .53535 .38764 Mtetra
.66 .699 .875 r
.53535 .38764 .54193 .39678 .5542 .39273 .54765 .38356 Mtetra
.644 .693 .88 r
.54765 .38356 .5542 .39273 .56653 .38918 .56002 .38001 Mtetra
.629 .688 .886 r
.56002 .38001 .56653 .38918 .57893 .38609 .57245 .37698 Mtetra
.615 .684 .892 r
.57245 .37698 .57893 .38609 .5914 .3833 .58495 .37436 Mtetra
.609 .687 .898 r
.58495 .37436 .5914 .3833 .60394 .38052 .59753 .37191 Mtetra
.619 .701 .903 r
.59753 .37191 .60394 .38052 .61653 .377 .61016 .3691 Mtetra
.668 .739 .904 r
.61016 .3691 .61653 .377 .6291 .37131 .62282 .36472 Mtetra
.769 .806 .882 r
.62282 .36472 .6291 .37131 .64156 .36111 .6354 .35653 Mtetra
.885 .865 .815 r
.6354 .35653 .64156 .36111 .65376 .34443 .64776 .34184 Mtetra
.917 .911 .799 r
.64776 .34184 .65376 .34443 .66617 .33341 .66002 .32553 Mtetra
.664 .741 .907 r
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.528 .681 .936 r
.71151 .30825 .7175 .31626 .73075 .31611 .72476 .30761 Mtetra
.659 .727 .899 r
.72476 .30761 .73075 .31611 .74376 .31109 .73787 .30336 Mtetra
.719 .771 .894 r
.73787 .30336 .74376 .31109 .75673 .30476 .75088 .29695 Mtetra
.702 .764 .9 r
.75088 .29695 .75673 .30476 .7698 .29923 .76399 .29119 Mtetra
.677 .75 .906 r
.76399 .29119 .7698 .29923 .78299 .29447 .77721 .28629 Mtetra
.666 .743 .907 r
.77721 .28629 .78299 .29447 .79627 .28996 .79053 .28173 Mtetra
.664 .741 .907 r
.79053 .28173 .79627 .28996 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26817 Mtetra
.83087 .26817 .83647 .27652 .85 .27201 .84444 .26361 Mtetra
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.663 .741 .908 r
.29447 .4389 .30169 .44586 .31289 .44211 .30571 .43512 Mtetra
.66 .74 .909 r
.30571 .43512 .31289 .44211 .32414 .43842 .31698 .43142 Mtetra
.647 .737 .915 r
.31698 .43142 .32414 .43842 .33542 .43505 .32829 .4281 Mtetra
.61 .728 .929 r
.32829 .4281 .33542 .43505 .34671 .43253 .33959 .42568 Mtetra
.588 .725 .938 r
.33959 .42568 .34671 .43253 .35802 .43065 .35093 .42374 Mtetra
.689 .753 .901 r
.35093 .42374 .35802 .43065 .36949 .42667 .36246 .41907 Mtetra
.742 .747 .856 r
.36246 .41907 .36949 .42667 .38116 .41917 .37415 .412 Mtetra
.664 .741 .907 r
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
0 .041 .552 r
.42077 .39626 .42766 .40356 .43909 .41145 .43213 .40725 Mtetra
0 .387 .774 r
.43213 .40725 .43909 .41145 .4507 .4178 .44379 .41208 Mtetra
.53 .749 .976 r
.44379 .41208 .4507 .4178 .46256 .41777 .45571 .41076 Mtetra
.68 .758 .91 r
.45571 .41076 .46256 .41777 .47456 .41399 .46776 .40619 Mtetra
.709 .746 .88 r
.46776 .40619 .47456 .41399 .48663 .40864 .47987 .40044 Mtetra
.711 .737 .871 r
.47987 .40044 .48663 .40864 .49875 .40294 .49202 .3945 Mtetra
.703 .729 .871 r
.49202 .3945 .49875 .40294 .5109 .3974 .50422 .38883 Mtetra
.691 .723 .874 r
.50422 .38883 .5109 .3974 .5231 .39227 .51645 .38362 Mtetra
.677 .717 .879 r
.51645 .38362 .5231 .39227 .53535 .38764 .52873 .37894 Mtetra
.661 .711 .885 r
.52873 .37894 .53535 .38764 .54765 .38356 .54106 .37481 Mtetra
.644 .705 .891 r
.54106 .37481 .54765 .38356 .56002 .38001 .55346 .37125 Mtetra
.627 .699 .897 r
.55346 .37125 .56002 .38001 .57245 .37698 .56592 .36823 Mtetra
.611 .694 .902 r
.56592 .36823 .57245 .37698 .58495 .37436 .57845 .36567 Mtetra
.601 .692 .906 r
.57845 .36567 .58495 .37436 .59753 .37191 .59106 .36339 Mtetra
.606 .699 .91 r
.59106 .36339 .59753 .37191 .61016 .3691 .60374 .36093 Mtetra
.644 .725 .907 r
.60374 .36093 .61016 .3691 .62282 .36472 .61646 .35728 Mtetra
.736 .776 .885 r
.61646 .35728 .62282 .36472 .6354 .35653 .62913 .35033 Mtetra
.852 .826 .822 r
.62913 .35033 .6354 .35653 .64776 .34184 .64161 .33711 Mtetra
.92 .849 .756 r
.64161 .33711 .64776 .34184 .66002 .32553 .65381 .31759 Mtetra
.664 .741 .907 r
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.548 .691 .933 r
.70546 .30016 .71151 .30825 .72476 .30761 .71873 .29902 Mtetra
.639 .718 .905 r
.71873 .29902 .72476 .30761 .73787 .30336 .73191 .29541 Mtetra
.718 .766 .891 r
.73191 .29541 .73787 .30336 .75088 .29695 .74497 .28899 Mtetra
.705 .763 .897 r
.74497 .28899 .75088 .29695 .76399 .29119 .75812 .28305 Mtetra
.679 .749 .904 r
.75812 .28305 .76399 .29119 .77721 .28629 .77138 .27803 Mtetra
.667 .743 .907 r
.77138 .27803 .77721 .28629 .79053 .28173 .78474 .27342 Mtetra
.664 .741 .907 r
.78474 .27342 .79053 .28173 .80391 .27722 .79817 .26887 Mtetra
.79817 .26887 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26817 .82521 .25973 Mtetra
.82521 .25973 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43189 Mtetra
.663 .741 .908 r
.2872 .43189 .29447 .4389 .30571 .43512 .29846 .42808 Mtetra
.66 .74 .909 r
.29846 .42808 .30571 .43512 .31698 .43142 .30977 .42435 Mtetra
.645 .736 .915 r
.30977 .42435 .31698 .43142 .32829 .4281 .3211 .42104 Mtetra
.608 .726 .929 r
.3211 .42104 .32829 .4281 .33959 .42568 .33242 .41867 Mtetra
.591 .722 .935 r
.33242 .41867 .33959 .42568 .35093 .42374 .34379 .41667 Mtetra
.699 .752 .893 r
.34379 .41667 .35093 .42374 .36246 .41907 .35537 .41159 Mtetra
.738 .751 .863 r
.35537 .41159 .36246 .41907 .37415 .412 .36709 .40477 Mtetra
.664 .741 .907 r
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.625 .729 .921 r
.40207 .3929 .40904 .40022 .42077 .39626 .4138 .39001 Mtetra
.546 .029 0 r
.4138 .39001 .42077 .39626 .43213 .40725 .42514 .40132 Mtetra
.092 .506 .903 r
.42514 .40132 .43213 .40725 .44379 .41208 .43685 .40536 Mtetra
.578 .735 .95 r
.43685 .40536 .44379 .41208 .45571 .41076 .44881 .40341 Mtetra
.689 .753 .9 r
.44881 .40341 .45571 .41076 .46776 .40619 .4609 .39848 Mtetra
.714 .751 .881 r
.4609 .39848 .46776 .40619 .47987 .40044 .47305 .39252 Mtetra
.715 .746 .877 r
.47305 .39252 .47987 .40044 .49202 .3945 .48524 .38646 Mtetra
.707 .742 .879 r
.48524 .38646 .49202 .3945 .50422 .38883 .49747 .38072 Mtetra
.694 .737 .884 r
.49747 .38072 .50422 .38883 .51645 .38362 .50974 .37545 Mtetra
.679 .732 .89 r
.50974 .37545 .51645 .38362 .52873 .37894 .52206 .37073 Mtetra
.662 .726 .897 r
.52206 .37073 .52873 .37894 .54106 .37481 .53443 .36657 Mtetra
.644 .72 .903 r
.53443 .36657 .54106 .37481 .55346 .37125 .54685 .36298 Mtetra
.626 .713 .909 r
.54685 .36298 .55346 .37125 .56592 .36823 .55935 .35995 Mtetra
.608 .707 .914 r
.55935 .35995 .56592 .36823 .57845 .36567 .57191 .35739 Mtetra
.596 .703 .918 r
.57191 .35739 .57845 .36567 .59106 .36339 .58456 .35516 Mtetra
.598 .706 .919 r
.58456 .35516 .59106 .36339 .60374 .36093 .59727 .35284 Mtetra
.633 .725 .914 r
.59727 .35284 .60374 .36093 .61646 .35728 .61004 .34948 Mtetra
.72 .764 .887 r
.61004 .34948 .61646 .35728 .62913 .35033 .62277 .3431 Mtetra
.832 .801 .822 r
.62277 .3431 .62913 .35033 .64161 .33711 .63533 .33062 Mtetra
.904 .813 .747 r
.63533 .33062 .64161 .33711 .65381 .31759 .6476 .31071 Mtetra
.699 .786 .918 r
.6476 .31071 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.664 .741 .907 r
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.56 .697 .932 r
.69937 .292 .70546 .30016 .71873 .29902 .71265 .29053 Mtetra
.626 .718 .912 r
.71265 .29053 .71873 .29902 .73191 .29541 .7259 .28727 Mtetra
.716 .763 .889 r
.7259 .28727 .73191 .29541 .74497 .28899 .73901 .28085 Mtetra
.707 .76 .894 r
.73901 .28085 .74497 .28899 .75812 .28305 .75219 .2748 Mtetra
.68 .749 .903 r
.75219 .2748 .75812 .28305 .77138 .27803 .7655 .2697 Mtetra
.667 .743 .906 r
.7655 .2697 .77138 .27803 .78474 .27342 .7789 .26503 Mtetra
.664 .741 .907 r
.7789 .26503 .78474 .27342 .79817 .26887 .79237 .26044 Mtetra
.79237 .26044 .79817 .26887 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43189 .27987 .42481 Mtetra
.663 .741 .908 r
.27987 .42481 .2872 .43189 .29846 .42808 .29116 .42098 Mtetra
.66 .74 .909 r
.29116 .42098 .29846 .42808 .30977 .42435 .3025 .41722 Mtetra
.645 .736 .915 r
.3025 .41722 .30977 .42435 .3211 .42104 .31385 .41388 Mtetra
.608 .724 .927 r
.31385 .41388 .3211 .42104 .33242 .41867 .3252 .41148 Mtetra
.592 .719 .932 r
.3252 .41148 .33242 .41867 .34379 .41667 .33659 .40945 Mtetra
.699 .75 .891 r
.33659 .40945 .34379 .41667 .35537 .41159 .34821 .40434 Mtetra
.74 .758 .868 r
.34821 .40434 .35537 .41159 .36709 .40477 .35996 .39748 Mtetra
.664 .741 .907 r
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.625 .729 .921 r
.39504 .38551 .40207 .3929 .4138 .39001 .4068 .3826 Mtetra
0 .02 .53 r
.4068 .3826 .4138 .39001 .42514 .40132 .41814 .3939 Mtetra
.193 .519 .917 r
.41814 .3939 .42514 .40132 .43685 .40536 .42987 .39792 Mtetra
.584 .717 .934 r
.42987 .39792 .43685 .40536 .44881 .40341 .44186 .39595 Mtetra
.689 .751 .899 r
.44186 .39595 .44881 .40341 .4609 .39848 .45398 .39098 Mtetra
.716 .758 .886 r
.45398 .39098 .4609 .39848 .47305 .39252 .46617 .38497 Mtetra
.717 .759 .885 r
.46617 .38497 .47305 .39252 .48524 .38646 .4784 .37888 Mtetra
.709 .756 .889 r
.4784 .37888 .48524 .38646 .49747 .38072 .49067 .3731 Mtetra
.696 .753 .895 r
.49067 .3731 .49747 .38072 .50974 .37545 .50298 .3678 Mtetra
.68 .748 .902 r
.50298 .3678 .50974 .37545 .52206 .37073 .51533 .36304 Mtetra
.663 .743 .909 r
.51533 .36304 .52206 .37073 .53443 .36657 .52773 .35885 Mtetra
.644 .736 .916 r
.52773 .35885 .53443 .36657 .54685 .36298 .5402 .35523 Mtetra
.624 .729 .922 r
.5402 .35523 .54685 .36298 .55935 .35995 .55273 .35216 Mtetra
.605 .722 .927 r
.55273 .35216 .55935 .35995 .57191 .35739 .56533 .34957 Mtetra
.593 .717 .93 r
.56533 .34957 .57191 .35739 .58456 .35516 .57801 .34731 Mtetra
.595 .718 .929 r
.57801 .34731 .58456 .35516 .59727 .35284 .59076 .34495 Mtetra
.633 .732 .92 r
.59076 .34495 .59727 .35284 .61004 .34948 .60356 .34156 Mtetra
.719 .762 .886 r
.60356 .34156 .61004 .34948 .62277 .3431 .61633 .33514 Mtetra
.824 .784 .814 r
.61633 .33514 .62277 .3431 .63533 .33062 .62895 .32261 Mtetra
.888 .785 .741 r
.62895 .32261 .63533 .33062 .6476 .31071 .64129 .30264 Mtetra
.696 .752 .895 r
.64129 .30264 .6476 .31071 .66042 .30522 .65415 .29711 Mtetra
.664 .741 .907 r
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.56 .697 .932 r
.69322 .28378 .69937 .292 .71265 .29053 .70654 .28227 Mtetra
.625 .726 .919 r
.70654 .28227 .71265 .29053 .7259 .28727 .71983 .27898 Mtetra
.716 .76 .887 r
.71983 .27898 .7259 .28727 .73901 .28085 .73299 .27251 Mtetra
.706 .757 .892 r
.73299 .27251 .73901 .28085 .75219 .2748 .74621 .26642 Mtetra
.68 .747 .902 r
.74621 .26642 .75219 .2748 .7655 .2697 .75957 .26128 Mtetra
.667 .742 .906 r
.75957 .26128 .7655 .2697 .7789 .26503 .77301 .25657 Mtetra
.664 .741 .907 r
.77301 .25657 .7789 .26503 .79237 .26044 .78653 .25195 Mtetra
.78653 .25195 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41769 Mtetra
.663 .741 .908 r
.27248 .41769 .27987 .42481 .29116 .42098 .2838 .41382 Mtetra
.66 .74 .909 r
.2838 .41382 .29116 .42098 .3025 .41722 .29516 .41002 Mtetra
.647 .736 .914 r
.29516 .41002 .3025 .41722 .31385 .41388 .30655 .40661 Mtetra
.611 .724 .925 r
.30655 .40661 .31385 .41388 .3252 .41148 .31794 .40411 Mtetra
.591 .715 .929 r
.31794 .40411 .3252 .41148 .33659 .40945 .32935 .40209 Mtetra
.688 .745 .895 r
.32935 .40209 .33659 .40945 .34821 .40434 .34098 .39732 Mtetra
.748 .767 .869 r
.34098 .39732 .34821 .40434 .35996 .39748 .35279 .39014 Mtetra
.664 .741 .907 r
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .4068 .3826 .39979 .37401 Mtetra
0 .087 .618 r
.39979 .37401 .4068 .3826 .41814 .3939 .41114 .38498 Mtetra
.208 .481 .893 r
.41114 .38498 .41814 .3939 .42987 .39792 .42284 .38976 Mtetra
.564 .689 .924 r
.42284 .38976 .42987 .39792 .44186 .39595 .43484 .38836 Mtetra
.679 .747 .902 r
.43484 .38836 .44186 .39595 .45398 .39098 .447 .38368 Mtetra
.713 .765 .893 r
.447 .38368 .45398 .39098 .46617 .38497 .45922 .37782 Mtetra
.718 .771 .894 r
.45922 .37782 .46617 .38497 .4784 .37888 .4715 .37176 Mtetra
.71 .771 .9 r
.4715 .37176 .4784 .37888 .49067 .3731 .4838 .36599 Mtetra
.697 .769 .907 r
.4838 .36599 .49067 .3731 .50298 .3678 .49615 .36066 Mtetra
.681 .765 .915 r
.49615 .36066 .50298 .3678 .51533 .36304 .50854 .35588 Mtetra
.663 .76 .922 r
.50854 .35588 .51533 .36304 .52773 .35885 .52099 .35165 Mtetra
.643 .753 .929 r
.52099 .35165 .52773 .35885 .5402 .35523 .53349 .34799 Mtetra
.622 .746 .935 r
.53349 .34799 .5402 .35523 .55273 .35216 .54605 .34487 Mtetra
.603 .738 .94 r
.54605 .34487 .55273 .35216 .56533 .34957 .55869 .34221 Mtetra
.592 .732 .941 r
.55869 .34221 .56533 .34957 .57801 .34731 .57141 .33984 Mtetra
.599 .733 .938 r
.57141 .33984 .57801 .34731 .59076 .34495 .58419 .33728 Mtetra
.643 .744 .923 r
.58419 .33728 .59076 .34495 .60356 .34156 .59702 .33352 Mtetra
.733 .764 .878 r
.59702 .33352 .60356 .34156 .61633 .33514 .60983 .32644 Mtetra
.826 .77 .799 r
.60983 .32644 .61633 .33514 .62895 .32261 .62247 .31307 Mtetra
.871 .759 .736 r
.62247 .31307 .62895 .32261 .64129 .30264 .63488 .29337 Mtetra
.662 .711 .884 r
.63488 .29337 .64129 .30264 .65415 .29711 .64783 .28893 Mtetra
.664 .741 .907 r
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.548 .691 .933 r
.68702 .27548 .69322 .28378 .70654 .28227 .70039 .27424 Mtetra
.638 .739 .922 r
.70039 .27424 .70654 .28227 .71983 .27898 .7137 .27052 Mtetra
.716 .758 .885 r
.7137 .27052 .71983 .27898 .73299 .27251 .7269 .26398 Mtetra
.704 .753 .89 r
.7269 .26398 .73299 .27251 .74621 .26642 .74018 .25791 Mtetra
.679 .745 .901 r
.74018 .25791 .74621 .26642 .75957 .26128 .75358 .25278 Mtetra
.667 .742 .906 r
.75358 .25278 .75957 .26128 .77301 .25657 .76707 .24804 Mtetra
.664 .741 .907 r
.76707 .24804 .77301 .25657 .78653 .25195 .78063 .24337 Mtetra
.78063 .24337 .78653 .25195 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41769 .26503 .4105 Mtetra
.663 .741 .907 r
.26503 .4105 .27248 .41769 .2838 .41382 .27638 .4066 Mtetra
.661 .74 .908 r
.27638 .4066 .2838 .41382 .29516 .41002 .28778 .40275 Mtetra
.649 .736 .913 r
.28778 .40275 .29516 .41002 .30655 .40661 .2992 .39924 Mtetra
.617 .724 .923 r
.2992 .39924 .30655 .40661 .31794 .40411 .31062 .39657 Mtetra
.59 .711 .927 r
.31062 .39657 .31794 .40411 .32935 .40209 .32205 .39455 Mtetra
.668 .737 .902 r
.32205 .39455 .32935 .40209 .34098 .39732 .33368 .39042 Mtetra
.758 .773 .865 r
.33368 .39042 .34098 .39732 .35279 .39014 .34555 .38273 Mtetra
.664 .741 .907 r
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
0 .263 .753 r
.39268 .36647 .39979 .37401 .41114 .38498 .40414 .37431 Mtetra
.175 .413 .851 r
.40414 .37431 .41114 .38498 .42284 .38976 .4158 .38058 Mtetra
.517 .642 .911 r
.4158 .38058 .42284 .38976 .43484 .38836 .42778 .38042 Mtetra
.656 .732 .905 r
.42778 .38042 .43484 .38836 .447 .38368 .43995 .37647 Mtetra
.703 .767 .901 r
.43995 .37647 .447 .38368 .45922 .37782 .45221 .37095 Mtetra
.714 .78 .904 r
.45221 .37095 .45922 .37782 .4715 .37176 .46452 .36506 Mtetra
.71 .785 .911 r
.46452 .36506 .4715 .37176 .4838 .36599 .47687 .35933 Mtetra
.697 .784 .918 r
.47687 .35933 .4838 .36599 .49615 .36066 .48926 .35403 Mtetra
.681 .782 .927 r
.48926 .35403 .49615 .36066 .50854 .35588 .50169 .34922 Mtetra
.662 .777 .934 r
.50169 .34922 .50854 .35588 .52099 .35165 .51418 .34496 Mtetra
.641 .77 .941 r
.51418 .34496 .52099 .35165 .53349 .34799 .52672 .34125 Mtetra
.621 .763 .947 r
.52672 .34125 .53349 .34799 .54605 .34487 .53933 .33805 Mtetra
.603 .754 .951 r
.53933 .33805 .54605 .34487 .55869 .34221 .552 .33527 Mtetra
.596 .749 .95 r
.552 .33527 .55869 .34221 .57141 .33984 .56475 .33265 Mtetra
.612 .748 .942 r
.56475 .33265 .57141 .33984 .58419 .33728 .57757 .32968 Mtetra
.668 .757 .917 r
.57757 .32968 .58419 .33728 .59702 .33352 .59042 .32511 Mtetra
.757 .763 .858 r
.59042 .32511 .59702 .33352 .60983 .32644 .60324 .3167 Mtetra
.832 .752 .775 r
.60324 .3167 .60983 .32644 .62247 .31307 .61589 .30174 Mtetra
.83 .726 .75 r
.61589 .30174 .62247 .31307 .63488 .29337 .62846 .28515 Mtetra
.664 .741 .907 r
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.528 .681 .936 r
.68077 .26711 .68702 .27548 .70039 .27424 .6942 .26632 Mtetra
.659 .753 .919 r
.6942 .26632 .70039 .27424 .7137 .27052 .70752 .26188 Mtetra
.717 .755 .883 r
.70752 .26188 .7137 .27052 .7269 .26398 .72076 .25526 Mtetra
.7 .748 .889 r
.72076 .25526 .7269 .26398 .74018 .25791 .73409 .24929 Mtetra
.677 .743 .901 r
.73409 .24929 .74018 .25791 .75358 .25278 .74754 .24419 Mtetra
.666 .741 .906 r
.74754 .24419 .75358 .25278 .76707 .24804 .76108 .23943 Mtetra
.664 .741 .907 r
.76108 .23943 .76707 .24804 .78063 .24337 .77468 .23473 Mtetra
.77468 .23473 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .4066 .2689 .39932 Mtetra
.662 .74 .908 r
.2689 .39932 .27638 .4066 .28778 .40275 .28033 .39542 Mtetra
.653 .737 .911 r
.28033 .39542 .28778 .40275 .2992 .39924 .29179 .39178 Mtetra
.624 .726 .92 r
.29179 .39178 .2992 .39924 .31062 .39657 .30324 .38889 Mtetra
.593 .71 .925 r
.30324 .38889 .31062 .39657 .32205 .39455 .31471 .3868 Mtetra
.641 .725 .909 r
.31471 .3868 .32205 .39455 .33368 .39042 .32631 .38344 Mtetra
.767 .774 .859 r
.32631 .38344 .33368 .39042 .34555 .38273 .33825 .37526 Mtetra
.664 .741 .907 r
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.305 .582 .939 r
.38551 .35887 .39268 .36647 .40414 .37431 .39719 .36149 Mtetra
.129 .334 .799 r
.39719 .36149 .40414 .37431 .4158 .38058 .40876 .36977 Mtetra
.442 .566 .884 r
.40876 .36977 .4158 .38058 .42778 .38042 .42069 .37163 Mtetra
.612 .695 .903 r
.42069 .37163 .42778 .38042 .43995 .37647 .43285 .36899 Mtetra
.681 .755 .907 r
.43285 .36899 .43995 .37647 .45221 .37095 .44513 .36418 Mtetra
.704 .782 .912 r
.44513 .36418 .45221 .37095 .46452 .36506 .45747 .35862 Mtetra
.704 .793 .92 r
.45747 .35862 .46452 .36506 .47687 .35933 .46987 .35306 Mtetra
.695 .797 .929 r
.46987 .35306 .47687 .35933 .48926 .35403 .4823 .3478 Mtetra
.679 .796 .937 r
.4823 .3478 .48926 .35403 .50169 .34922 .49478 .34301 Mtetra
.66 .792 .945 r
.49478 .34301 .50169 .34922 .51418 .34496 .5073 .33871 Mtetra
.64 .786 .952 r
.5073 .33871 .51418 .34496 .52672 .34125 .51989 .33492 Mtetra
.62 .778 .956 r
.51989 .33492 .52672 .34125 .53933 .33805 .53254 .3316 Mtetra
.608 .771 .958 r
.53254 .3316 .53933 .33805 .552 .33527 .54525 .32858 Mtetra
.609 .764 .954 r
.54525 .32858 .552 .33527 .56475 .33265 .55804 .32557 Mtetra
.64 .764 .938 r
.55804 .32557 .56475 .33265 .57757 .32968 .57088 .3218 Mtetra
.706 .763 .897 r
.57088 .3218 .57757 .32968 .59042 .32511 .58375 .31584 Mtetra
.784 .752 .823 r
.58375 .31584 .59042 .32511 .60324 .3167 .59657 .30531 Mtetra
.833 .727 .747 r
.59657 .30531 .60324 .3167 .61589 .30174 .60921 .28822 Mtetra
.757 .674 .769 r
.60921 .28822 .61589 .30174 .62846 .28515 .62199 .27687 Mtetra
.664 .741 .907 r
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.508 .671 .937 r
.67446 .25868 .68077 .26711 .6942 .26632 .68795 .2583 Mtetra
.684 .762 .91 r
.68795 .2583 .6942 .26632 .70752 .26188 .70127 .253 Mtetra
.715 .75 .88 r
.70127 .253 .70752 .26188 .72076 .25526 .71456 .24638 Mtetra
.694 .744 .89 r
.71456 .24638 .72076 .25526 .73409 .24929 .72795 .24056 Mtetra
.674 .741 .901 r
.72795 .24056 .73409 .24929 .74754 .24419 .74145 .23552 Mtetra
.666 .741 .906 r
.74145 .23552 .74754 .24419 .76108 .23943 .75503 .23075 Mtetra
.664 .741 .907 r
.75503 .23075 .76108 .23943 .77468 .23473 .76869 .226 Mtetra
.76869 .226 .77468 .23473 .78836 .23001 .7824 .22125 Mtetra
.7824 .22125 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39932 .26136 .39199 Mtetra
.662 .74 .908 r
.26136 .39199 .2689 .39932 .28033 .39542 .27282 .38803 Mtetra
.656 .738 .91 r
.27282 .38803 .28033 .39542 .29179 .39178 .28432 .38426 Mtetra
.634 .729 .916 r
.28432 .38426 .29179 .39178 .30324 .38889 .29582 .3811 Mtetra
.599 .71 .922 r
.29582 .3811 .30324 .38889 .31471 .3868 .30731 .37883 Mtetra
.616 .712 .914 r
.30731 .37883 .31471 .3868 .32631 .38344 .3189 .37614 Mtetra
.743 .764 .87 r
.3189 .37614 .32631 .38344 .33825 .37526 .33082 .36904 Mtetra
.706 .789 .915 r
.33082 .36904 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.664 .741 .907 r
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39719 .36149 .39027 .34703 Mtetra
.12 .297 .769 r
.39027 .34703 .39719 .36149 .40876 .36977 .40177 .35647 Mtetra
.353 .465 .835 r
.40177 .35647 .40876 .36977 .42069 .37163 .4136 .36106 Mtetra
.54 .623 .883 r
.4136 .36106 .42069 .37163 .43285 .36899 .42572 .36054 Mtetra
.64 .717 .904 r
.42572 .36054 .43285 .36899 .44513 .36418 .43799 .35699 Mtetra
.682 .766 .915 r
.43799 .35699 .44513 .36418 .45747 .35862 .45036 .35214 Mtetra
.693 .791 .925 r
.45036 .35214 .45747 .35862 .46987 .35306 .46279 .34691 Mtetra
.688 .801 .935 r
.46279 .34691 .46987 .35306 .4823 .3478 .47527 .34182 Mtetra
.675 .805 .944 r
.47527 .34182 .4823 .3478 .49478 .34301 .48779 .33706 Mtetra
.658 .802 .952 r
.48779 .33706 .49478 .34301 .5073 .33871 .50036 .33273 Mtetra
.641 .797 .958 r
.50036 .33273 .5073 .33871 .51989 .33492 .51299 .32884 Mtetra
.627 .79 .96 r
.51299 .32884 .51989 .33492 .53254 .3316 .52568 .32527 Mtetra
.622 .781 .958 r
.52568 .32527 .53254 .3316 .54525 .32858 .53844 .32185 Mtetra
.638 .775 .946 r
.53844 .32185 .54525 .32858 .55804 .32557 .55126 .31806 Mtetra
.684 .768 .915 r
.55126 .31806 .55804 .32557 .57088 .3218 .56413 .31294 Mtetra
.749 .752 .855 r
.56413 .31294 .57088 .3218 .58375 .31584 .577 .30476 Mtetra
.802 .724 .778 r
.577 .30476 .58375 .31584 .59657 .30531 .5898 .29138 Mtetra
.82 .692 .724 r
.5898 .29138 .59657 .30531 .60921 .28822 .60246 .27305 Mtetra
.642 .6 .792 r
.60246 .27305 .60921 .28822 .62199 .27687 .61546 .26851 Mtetra
.664 .741 .907 r
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.621 .724 .92 r
.65485 .25478 .66125 .26326 .67446 .25868 .66816 .2515 Mtetra
.54 .728 .962 r
.66816 .2515 .67446 .25868 .68795 .2583 .68164 .24995 Mtetra
.703 .761 .897 r
.68164 .24995 .68795 .2583 .70127 .253 .69496 .24389 Mtetra
.71 .745 .879 r
.69496 .24389 .70127 .253 .71456 .24638 .7083 .23737 Mtetra
.688 .74 .891 r
.7083 .23737 .71456 .24638 .72795 .24056 .72175 .23176 Mtetra
.671 .74 .902 r
.72175 .23176 .72795 .24056 .74145 .23552 .7353 .22678 Mtetra
.665 .741 .906 r
.7353 .22678 .74145 .23552 .75503 .23075 .74893 .22198 Mtetra
.664 .741 .907 r
.74893 .22198 .75503 .23075 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22125 .7764 .2124 Mtetra
.7764 .2124 .7824 .22125 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39199 .25376 .38459 Mtetra
.663 .741 .908 r
.25376 .38459 .26136 .39199 .27282 .38803 .26525 .38059 Mtetra
.659 .739 .909 r
.26525 .38059 .27282 .38803 .28432 .38426 .27678 .37669 Mtetra
.643 .732 .913 r
.27678 .37669 .28432 .38426 .29582 .3811 .28833 .37326 Mtetra
.611 .715 .919 r
.28833 .37326 .29582 .3811 .30731 .37883 .29987 .37067 Mtetra
.6 .703 .916 r
.29987 .37067 .30731 .37883 .3189 .37614 .31146 .36837 Mtetra
.69 .742 .891 r
.31146 .36837 .3189 .37614 .33082 .36904 .32328 .36336 Mtetra
.758 .813 .896 r
.32328 .36336 .33082 .36904 .34266 .36363 .33528 .35601 Mtetra
.664 .741 .907 r
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.435 .649 .949 r
.38301 .33927 .39027 .34703 .40177 .35647 .39488 .34002 Mtetra
.283 .371 .777 r
.39488 .34002 .40177 .35647 .4136 .36106 .40658 .34746 Mtetra
.45 .517 .835 r
.40658 .34746 .4136 .36106 .42572 .36054 .4186 .34988 Mtetra
.571 .638 .878 r
.4186 .34988 .42572 .36054 .43799 .35699 .43083 .34845 Mtetra
.64 .717 .904 r
.43083 .34845 .43799 .35699 .45036 .35214 .4432 .34487 Mtetra
.669 .763 .921 r
.4432 .34487 .45036 .35214 .46279 .34691 .45566 .34036 Mtetra
.675 .787 .934 r
.45566 .34036 .46279 .34691 .47527 .34182 .46817 .33561 Mtetra
.67 .798 .943 r
.46817 .33561 .47527 .34182 .48779 .33706 .48073 .33099 Mtetra
.659 .8 .95 r
.48073 .33099 .48779 .33706 .50036 .33273 .49335 .32663 Mtetra
.648 .797 .954 r
.49335 .32663 .50036 .33273 .51299 .32884 .50603 .32252 Mtetra
.643 .79 .952 r
.50603 .32252 .51299 .32884 .52568 .32527 .51876 .31854 Mtetra
.653 .781 .942 r
.51876 .31854 .52568 .32527 .53844 .32185 .53156 .31433 Mtetra
.684 .768 .915 r
.53156 .31433 .53844 .32185 .55126 .31806 .54441 .30918 Mtetra
.732 .748 .865 r
.54441 .30918 .55126 .31806 .56413 .31294 .5573 .30184 Mtetra
.777 .717 .797 r
.5573 .30184 .56413 .31294 .577 .30476 .57016 .29061 Mtetra
.802 .684 .734 r
.57016 .29061 .577 .30476 .5898 .29138 .58294 .27426 Mtetra
.71 .614 .748 r
.58294 .27426 .5898 .29138 .60246 .27305 .59583 .26466 Mtetra
.664 .741 .907 r
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.548 .691 .934 r
.64838 .24624 .65485 .25478 .66816 .2515 .66183 .24487 Mtetra
.627 .785 .958 r
.66183 .24487 .66816 .2515 .68164 .24995 .67524 .24111 Mtetra
.712 .753 .884 r
.67524 .24111 .68164 .24995 .69496 .24389 .68858 .23455 Mtetra
.702 .739 .879 r
.68858 .23455 .69496 .24389 .7083 .23737 .70199 .22829 Mtetra
.681 .738 .894 r
.70199 .22829 .7083 .23737 .72175 .23176 .7155 .2229 Mtetra
.668 .74 .904 r
.7155 .2229 .72175 .23176 .7353 .22678 .72911 .21797 Mtetra
.665 .741 .907 r
.72911 .21797 .7353 .22678 .74893 .22198 .74278 .21315 Mtetra
.664 .741 .907 r
.74278 .21315 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.20052 .39321 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .38521 Mtetra
.22321 .38521 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37714 Mtetra
.663 .741 .907 r
.2461 .37714 .25376 .38459 .26525 .38059 .25762 .37309 Mtetra
.661 .74 .908 r
.25762 .37309 .26525 .38059 .27678 .37669 .26919 .3691 Mtetra
.651 .735 .911 r
.26919 .3691 .27678 .37669 .28833 .37326 .28078 .3654 Mtetra
.625 .721 .915 r
.28078 .3654 .28833 .37326 .29987 .37067 .29238 .3624 Mtetra
.598 .701 .915 r
.29238 .3624 .29987 .37067 .31146 .36837 .30398 .36011 Mtetra
.638 .716 .904 r
.30398 .36011 .31146 .36837 .32328 .36336 .31572 .35673 Mtetra
.769 .789 .869 r
.31572 .35673 .32328 .36336 .33528 .35601 .32782 .34854 Mtetra
.671 .749 .909 r
.32782 .34854 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.664 .741 .907 r
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39488 .34002 .3878 .32718 Mtetra
.431 .52 .849 r
.3878 .32718 .39488 .34002 .40658 .34746 .39969 .32975 Mtetra
.378 .415 .773 r
.39969 .32975 .40658 .34746 .4186 .34988 .41157 .3353 Mtetra
.489 .524 .82 r
.41157 .3353 .4186 .34988 .43083 .34845 .42371 .33682 Mtetra
.573 .62 .861 r
.42371 .33682 .43083 .34845 .4432 .34487 .43604 .33536 Mtetra
.626 .69 .891 r
.43604 .33536 .4432 .34487 .45566 .34036 .44849 .33217 Mtetra
.651 .734 .91 r
.44849 .33217 .45566 .34036 .46817 .33561 .46103 .32815 Mtetra
.66 .759 .923 r
.46103 .32815 .46817 .33561 .48073 .33099 .47363 .32383 Mtetra
.662 .769 .929 r
.47363 .32383 .48073 .33099 .49335 .32663 .48629 .31943 Mtetra
.664 .77 .929 r
.48629 .31943 .49335 .32663 .50603 .32252 .499 .31495 Mtetra
.673 .763 .918 r
.499 .31495 .50603 .32252 .51876 .31854 .51178 .31016 Mtetra
.694 .749 .893 r
.51178 .31016 .51876 .31854 .53156 .31433 .52462 .30455 Mtetra
.726 .727 .85 r
.52462 .30455 .53156 .31433 .54441 .30918 .5375 .29717 Mtetra
.758 .697 .794 r
.5375 .29717 .54441 .30918 .5573 .30184 .55039 .28679 Mtetra
.778 .666 .739 r
.55039 .28679 .5573 .30184 .57016 .29061 .56324 .27229 Mtetra
.724 .611 .731 r
.56324 .27229 .57016 .29061 .58294 .27426 .57612 .26079 Mtetra
.648 .629 .817 r
.57612 .26079 .58294 .27426 .59583 .26466 .58915 .2562 Mtetra
.664 .741 .907 r
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.657 .738 .91 r
.62859 .24229 .63515 .25087 .64838 .24624 .64188 .23784 Mtetra
.51 .679 .942 r
.64188 .23784 .64838 .24624 .66183 .24487 .65539 .23725 Mtetra
.688 .779 .92 r
.65539 .23725 .66183 .24487 .67524 .24111 .66877 .23174 Mtetra
.711 .742 .876 r
.66877 .23174 .67524 .24111 .68858 .23455 .68216 .22511 Mtetra
.693 .734 .882 r
.68216 .22511 .68858 .23455 .70199 .22829 .69563 .21919 Mtetra
.675 .737 .897 r
.69563 .21919 .70199 .22829 .7155 .2229 .7092 .21399 Mtetra
.666 .74 .905 r
.7092 .21399 .7155 .2229 .72911 .21797 .72285 .20908 Mtetra
.664 .741 .907 r
.72285 .20908 .72911 .21797 .74278 .21315 .73658 .20423 Mtetra
.73658 .20423 .74278 .21315 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.19268 .38582 .20052 .39321 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .38521 .21543 .37776 Mtetra
.21543 .37776 .22321 .38521 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37714 .23838 .36962 Mtetra
.23838 .36962 .2461 .37714 .25762 .37309 .24993 .36554 Mtetra
.662 .74 .908 r
.24993 .36554 .25762 .37309 .26919 .3691 .26153 .36146 Mtetra
.656 .737 .909 r
.26153 .36146 .26919 .3691 .28078 .3654 .27317 .35756 Mtetra
.639 .727 .912 r
.27317 .35756 .28078 .3654 .29238 .3624 .28482 .35414 Mtetra
.61 .707 .914 r
.28482 .35414 .29238 .3624 .30398 .36011 .29647 .35152 Mtetra
.607 .698 .908 r
.29647 .35152 .30398 .36011 .31572 .35673 .30818 .34898 Mtetra
.693 .748 .894 r
.30818 .34898 .31572 .35673 .32782 .34854 .32012 .34379 Mtetra
.763 .846 .914 r
.32012 .34379 .32782 .34854 .33972 .34413 .33225 .33635 Mtetra
.664 .741 .907 r
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39969 .32975 .39265 .31493 Mtetra
.515 .535 .814 r
.39265 .31493 .39969 .32975 .41157 .3353 .40471 .3156 Mtetra
.433 .428 .754 r
.40471 .3156 .41157 .3353 .42371 .33682 .41673 .31997 Mtetra
.505 .504 .788 r
.41673 .31997 .42371 .33682 .43604 .33536 .42897 .32125 Mtetra
.566 .575 .822 r
.42897 .32125 .43604 .33536 .44849 .33217 .44137 .32009 Mtetra
.61 .632 .848 r
.44137 .32009 .44849 .33217 .46103 .32815 .4539 .31733 Mtetra
.638 .669 .863 r
.4539 .31733 .46103 .32815 .47363 .32383 .46651 .31357 Mtetra
.658 .69 .869 r
.46651 .31357 .47363 .32383 .48629 .31943 .4792 .30913 Mtetra
.675 .696 .862 r
.4792 .30913 .48629 .31943 .499 .31495 .49195 .304 Mtetra
.694 .691 .843 r
.49195 .304 .499 .31495 .51178 .31016 .50477 .29788 Mtetra
.715 .676 .811 r
.50477 .29788 .51178 .31016 .52462 .30455 .51764 .29013 Mtetra
.736 .655 .77 r
.51764 .29013 .52462 .30455 .5375 .29717 .53053 .27992 Mtetra
.75 .633 .73 r
.53053 .27992 .5375 .29717 .55039 .28679 .54342 .26655 Mtetra
.692 .58 .724 r
.54342 .26655 .55039 .28679 .56324 .27229 .55633 .25691 Mtetra
.641 .6 .792 r
.55633 .25691 .56324 .27229 .57612 .26079 .56934 .2523 Mtetra
.664 .741 .907 r
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.548 .691 .934 r
.62198 .23364 .62859 .24229 .64188 .23784 .63541 .23221 Mtetra
.611 .816 .979 r
.63541 .23221 .64188 .23784 .65539 .23725 .64885 .22848 Mtetra
.709 .756 .889 r
.64885 .22848 .65539 .23725 .66877 .23174 .66224 .22203 Mtetra
.702 .732 .874 r
.66224 .22203 .66877 .23174 .68216 .22511 .67568 .21566 Mtetra
.683 .732 .888 r
.67568 .21566 .68216 .22511 .69563 .21919 .68921 .21009 Mtetra
.67 .737 .9 r
.68921 .21009 .69563 .21919 .7092 .21399 .70284 .20503 Mtetra
.665 .74 .906 r
.70284 .20503 .7092 .21399 .72285 .20908 .71654 .20012 Mtetra
.664 .741 .907 r
.71654 .20012 .72285 .20908 .73658 .20423 .73031 .19523 Mtetra
.73031 .19523 .73658 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36554 .24217 .35792 Mtetra
.663 .741 .907 r
.24217 .35792 .24993 .36554 .26153 .36146 .2538 .35379 Mtetra
.66 .739 .908 r
.2538 .35379 .26153 .36146 .27317 .35756 .26548 .34974 Mtetra
.65 .733 .91 r
.26548 .34974 .27317 .35756 .28482 .35414 .27719 .34597 Mtetra
.627 .717 .911 r
.27719 .34597 .28482 .35414 .29647 .35152 .2889 .34285 Mtetra
.604 .697 .909 r
.2889 .34285 .29647 .35152 .30818 .34898 .30062 .34035 Mtetra
.631 .708 .902 r
.30062 .34035 .30818 .34898 .32012 .34379 .31247 .33711 Mtetra
.739 .788 .892 r
.31247 .33711 .32012 .34379 .33225 .33635 .3246 .33026 Mtetra
.721 .804 .917 r
.3246 .33026 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.664 .741 .907 r
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .40471 .3156 .39756 .30252 Mtetra
.648 .63 .818 r
.39756 .30252 .40471 .3156 .41673 .31997 .4099 .29813 Mtetra
.491 .447 .735 r
.4099 .29813 .41673 .31997 .42897 .32125 .42207 .30055 Mtetra
.524 .476 .745 r
.42207 .30055 .42897 .32125 .44137 .32009 .4344 .3014 Mtetra
.568 .521 .763 r
.4344 .3014 .44137 .32009 .4539 .31733 .44687 .30014 Mtetra
.605 .558 .775 r
.44687 .30014 .4539 .31733 .46651 .31357 .45947 .29714 Mtetra
.636 .583 .778 r
.45947 .29714 .46651 .31357 .4792 .30913 .47216 .29265 Mtetra
.661 .596 .771 r
.47216 .29265 .4792 .30913 .49195 .304 .48494 .28667 Mtetra
.683 .599 .755 r
.48494 .28667 .49195 .304 .50477 .29788 .49777 .27895 Mtetra
.702 .595 .733 r
.49777 .27895 .50477 .29788 .51764 .29013 .51065 .26909 Mtetra
.708 .583 .713 r
.51065 .26909 .51764 .29013 .53053 .27992 .52354 .25762 Mtetra
.618 .523 .724 r
.52354 .25762 .53053 .27992 .54342 .26655 .53647 .25301 Mtetra
.648 .63 .818 r
.53647 .25301 .54342 .26655 .55633 .25691 .54945 .24838 Mtetra
.664 .741 .907 r
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.605 .717 .924 r
.60201 .22964 .60872 .23834 .62198 .23364 .61536 .22671 Mtetra
.554 .75 .968 r
.61536 .22671 .62198 .23364 .63541 .23221 .62881 .22459 Mtetra
.695 .784 .919 r
.62881 .22459 .63541 .23221 .64885 .22848 .64222 .21879 Mtetra
.707 .735 .873 r
.64222 .21879 .64885 .22848 .66224 .22203 .65564 .21222 Mtetra
.691 .727 .878 r
.65564 .21222 .66224 .22203 .67568 .21566 .66915 .20628 Mtetra
.675 .733 .894 r
.66915 .20628 .67568 .21566 .68921 .21009 .68275 .201 Mtetra
.667 .738 .903 r
.68275 .201 .68921 .21009 .70284 .20503 .69643 .19601 Mtetra
.664 .74 .907 r
.69643 .19601 .70284 .20503 .71654 .20012 .71018 .19109 Mtetra
.664 .741 .907 r
.71018 .19109 .71654 .20012 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16622 Mtetra
.77994 .16622 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .2538 .35379 .24601 .34607 Mtetra
.662 .74 .908 r
.24601 .34607 .2538 .35379 .26548 .34974 .25773 .34192 Mtetra
.657 .737 .908 r
.25773 .34192 .26548 .34974 .27719 .34597 .26948 .3379 Mtetra
.643 .727 .909 r
.26948 .3379 .27719 .34597 .2889 .34285 .28125 .33429 Mtetra
.619 .707 .908 r
.28125 .33429 .2889 .34285 .30062 .34035 .29304 .33135 Mtetra
.607 .692 .903 r
.29304 .33135 .30062 .34035 .31247 .33711 .30486 .32874 Mtetra
.654 .725 .901 r
.30486 .32874 .31247 .33711 .3246 .33026 .31684 .32474 Mtetra
.764 .827 .901 r
.31684 .32474 .3246 .33026 .33671 .32422 .3291 .31704 Mtetra
.689 .769 .912 r
.3291 .31704 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.664 .741 .907 r
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .42207 .30055 .41497 .2855 Mtetra
.641 .601 .793 r
.41497 .2855 .42207 .30055 .4344 .3014 .42746 .28102 Mtetra
.622 .538 .738 r
.42746 .28102 .4344 .3014 .44687 .30014 .44001 .27652 Mtetra
.597 .501 .716 r
.44001 .27652 .44687 .30014 .45947 .29714 .45258 .27314 Mtetra
.613 .508 .711 r
.45258 .27314 .45947 .29714 .47216 .29265 .46525 .2686 Mtetra
.628 .518 .709 r
.46525 .2686 .47216 .29265 .48494 .28667 .478 .2629 Mtetra
.614 .511 .714 r
.478 .2629 .48494 .28667 .49777 .27895 .49078 .25832 Mtetra
.622 .538 .738 r
.49078 .25832 .49777 .27895 .51065 .26909 .50362 .25372 Mtetra
.641 .601 .793 r
.50362 .25372 .51065 .26909 .52354 .25762 .51652 .24909 Mtetra
.664 .741 .907 r
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.639 .732 .915 r
.58196 .22564 .58877 .23436 .60201 .22964 .59525 .22166 Mtetra
.531 .707 .952 r
.59525 .22166 .60201 .22964 .61536 .22671 .60869 .22034 Mtetra
.671 .815 .953 r
.60869 .22034 .61536 .22671 .62881 .22459 .6221 .21524 Mtetra
.707 .744 .881 r
.6221 .21524 .62881 .22459 .64222 .21879 .63552 .20871 Mtetra
.695 .724 .872 r
.63552 .20871 .64222 .21879 .65564 .21222 .64901 .20251 Mtetra
.68 .728 .886 r
.64901 .20251 .65564 .21222 .66915 .20628 .66258 .197 Mtetra
.669 .735 .899 r
.66258 .197 .66915 .20628 .68275 .201 .67623 .1919 Mtetra
.665 .739 .905 r
.67623 .1919 .68275 .201 .69643 .19601 .68996 .18693 Mtetra
.664 .741 .907 r
.68996 .18693 .69643 .19601 .71018 .19109 .70376 .18197 Mtetra
.70376 .18197 .71018 .19109 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16622 .77376 .15688 Mtetra
.77376 .15688 .77994 .16622 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.663 .741 .907 r
.23816 .3383 .24601 .34607 .25773 .34192 .2499 .33408 Mtetra
.661 .739 .908 r
.2499 .33408 .25773 .34192 .26948 .3379 .2617 .32991 Mtetra
.654 .734 .908 r
.2617 .32991 .26948 .3379 .28125 .33429 .27353 .32593 Mtetra
.638 .72 .907 r
.27353 .32593 .28125 .33429 .29304 .33135 .28538 .32241 Mtetra
.616 .699 .903 r
.28538 .32241 .29304 .33135 .30486 .32874 .29724 .31951 Mtetra
.614 .691 .899 r
.29724 .31951 .30486 .32874 .31684 .32474 .30917 .31667 Mtetra
.664 .739 .905 r
.30917 .31667 .31684 .32474 .3291 .31704 .32125 .31229 Mtetra
.765 .853 .917 r
.32125 .31229 .3291 .31704 .34124 .31193 .3336 .30465 Mtetra
.689 .769 .912 r
.3336 .30465 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.664 .741 .907 r
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45258 .27314 .44533 .26361 Mtetra
.662 .712 .885 r
.44533 .26361 .45258 .27314 .46525 .2686 .45803 .25903 Mtetra
.45803 .25903 .46525 .2686 .478 .2629 .4708 .25443 Mtetra
.664 .741 .907 r
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.639 .732 .915 r
.56182 .22161 .56875 .23037 .58196 .22564 .57509 .21762 Mtetra
.536 .71 .952 r
.57509 .21762 .58196 .22564 .59525 .22166 .58848 .21615 Mtetra
.652 .837 .971 r
.58848 .21615 .59525 .22166 .60869 .22034 .60188 .21136 Mtetra
.705 .753 .89 r
.60188 .21136 .60869 .22034 .6221 .21524 .6153 .205 Mtetra
.697 .722 .869 r
.6153 .205 .6221 .21524 .63552 .20871 .62877 .19869 Mtetra
.682 .722 .88 r
.62877 .19869 .63552 .20871 .64901 .20251 .64232 .193 Mtetra
.672 .731 .895 r
.64232 .193 .64901 .20251 .66258 .197 .65595 .18778 Mtetra
.666 .738 .903 r
.65595 .18778 .66258 .197 .67623 .1919 .66966 .18275 Mtetra
.664 .74 .906 r
.66966 .18275 .67623 .1919 .68996 .18693 .68343 .17777 Mtetra
.664 .741 .907 r
.68343 .17777 .68996 .18693 .70376 .18197 .69727 .17278 Mtetra
.69727 .17278 .70376 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14746 Mtetra
.76752 .14746 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33047 Mtetra
.23024 .33047 .23816 .3383 .2499 .33408 .24202 .3262 Mtetra
.663 .74 .907 r
.24202 .3262 .2499 .33408 .2617 .32991 .25385 .32194 Mtetra
.66 .738 .907 r
.25385 .32194 .2617 .32991 .27353 .32593 .26572 .31774 Mtetra
.652 .731 .907 r
.26572 .31774 .27353 .32593 .28538 .32241 .27763 .31377 Mtetra
.636 .715 .904 r
.27763 .31377 .28538 .32241 .29724 .31951 .28957 .31027 Mtetra
.618 .694 .898 r
.28957 .31027 .29724 .31951 .30917 .31667 .30152 .30727 Mtetra
.619 .691 .896 r
.30152 .30727 .30917 .31667 .32125 .31229 .31355 .30424 Mtetra
.661 .741 .91 r
.31355 .30424 .32125 .31229 .3336 .30465 .32572 .29993 Mtetra
.741 .856 .933 r
.32572 .29993 .3336 .30465 .34583 .29948 .33809 .2931 Mtetra
.721 .804 .917 r
.33809 .2931 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.664 .741 .907 r
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.604 .718 .925 r
.54161 .21757 .54863 .22637 .56182 .22161 .55486 .21458 Mtetra
.563 .754 .967 r
.55486 .21458 .56182 .22161 .57509 .21762 .5682 .2122 Mtetra
.657 .842 .971 r
.5682 .2122 .57509 .21762 .58848 .21615 .58158 .20726 Mtetra
.702 .755 .894 r
.58158 .20726 .58848 .21615 .60188 .21136 .59499 .20102 Mtetra
.695 .72 .868 r
.59499 .20102 .60188 .21136 .6153 .205 .60845 .19473 Mtetra
.683 .718 .875 r
.60845 .19473 .6153 .205 .62877 .19869 .62198 .18896 Mtetra
.673 .727 .891 r
.62198 .18896 .62877 .19869 .64232 .193 .63559 .18365 Mtetra
.667 .735 .901 r
.63559 .18365 .64232 .193 .65595 .18778 .64927 .17857 Mtetra
.665 .739 .906 r
.64927 .17857 .65595 .18778 .66966 .18275 .66303 .17355 Mtetra
.664 .74 .907 r
.66303 .17355 .66966 .18275 .68343 .17777 .67685 .16854 Mtetra
.664 .741 .907 r
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14746 .76122 .13794 Mtetra
.76122 .13794 .76752 .14746 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33047 .22225 .32257 Mtetra
.22225 .32257 .23024 .33047 .24202 .3262 .23406 .31826 Mtetra
.23406 .31826 .24202 .3262 .25385 .32194 .24592 .31394 Mtetra
.663 .74 .907 r
.24592 .31394 .25385 .32194 .26572 .31774 .25784 .30963 Mtetra
.659 .737 .907 r
.25784 .30963 .26572 .31774 .27763 .31377 .2698 .3054 Mtetra
.652 .728 .905 r
.2698 .3054 .27763 .31377 .28957 .31027 .2818 .30139 Mtetra
.637 .712 .901 r
.2818 .30139 .28957 .31027 .30152 .30727 .29382 .29778 Mtetra
.622 .692 .894 r
.29382 .29778 .30152 .30727 .31355 .30424 .30588 .2946 Mtetra
.621 .689 .892 r
.30588 .2946 .31355 .30424 .32572 .29993 .318 .29145 Mtetra
.647 .728 .908 r
.318 .29145 .32572 .29993 .33809 .2931 .33023 .28748 Mtetra
.701 .826 .942 r
.33023 .28748 .33809 .2931 .35047 .28687 .34262 .28186 Mtetra
.758 .853 .921 r
.34262 .28186 .35047 .28687 .3628 .2824 .35517 .27431 Mtetra
.671 .749 .909 r
.35517 .27431 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.664 .741 .907 r
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.657 .738 .91 r
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21373 Mtetra
.552 .702 .939 r
.52132 .21373 .52844 .22234 .54161 .21757 .53454 .212 Mtetra
.604 .819 .982 r
.53454 .212 .54161 .21757 .55486 .21458 .54783 .20831 Mtetra
.678 .822 .953 r
.54783 .20831 .55486 .21458 .5682 .2122 .56118 .20294 Mtetra
.699 .746 .888 r
.56118 .20294 .5682 .2122 .58158 .20726 .57458 .19675 Mtetra
.692 .715 .867 r
.57458 .19675 .58158 .20726 .59499 .20102 .58803 .19057 Mtetra
.681 .714 .873 r
.58803 .19057 .59499 .20102 .60845 .19473 .60155 .18482 Mtetra
.673 .724 .888 r
.60155 .18482 .60845 .19473 .62198 .18896 .61514 .17948 Mtetra
.667 .734 .899 r
.61514 .17948 .62198 .18896 .63559 .18365 .6288 .17436 Mtetra
.665 .738 .905 r
.6288 .17436 .63559 .18365 .64927 .17857 .64253 .16932 Mtetra
.664 .74 .907 r
.64253 .16932 .64927 .17857 .66303 .17355 .65633 .16428 Mtetra
.664 .741 .907 r
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32257 .2142 .3146 Mtetra
.2142 .3146 .22225 .32257 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31394 .23793 .3059 Mtetra
.23793 .3059 .24592 .31394 .25784 .30963 .24988 .30152 Mtetra
.663 .74 .907 r
.24988 .30152 .25784 .30963 .2698 .3054 .26188 .29716 Mtetra
.66 .736 .906 r
.26188 .29716 .2698 .3054 .2818 .30139 .27393 .29287 Mtetra
.653 .728 .904 r
.27393 .29287 .2818 .30139 .29382 .29778 .28602 .28875 Mtetra
.642 .712 .899 r
.28602 .28875 .29382 .29778 .30588 .2946 .29815 .28496 Mtetra
.629 .694 .891 r
.29815 .28496 .30588 .2946 .318 .29145 .31031 .28151 Mtetra
.624 .686 .888 r
.31031 .28151 .318 .29145 .33023 .28748 .32253 .27819 Mtetra
.635 .706 .898 r
.32253 .27819 .33023 .28748 .34262 .28186 .33483 .27453 Mtetra
.663 .768 .928 r
.33483 .27453 .34262 .28186 .35517 .27431 .34724 .27003 Mtetra
.691 .869 .966 r
.34724 .27003 .35517 .27431 .3676 .26956 .35977 .26443 Mtetra
.727 .85 .939 r
.35977 .26443 .3676 .26956 .38008 .26501 .3724 .25789 Mtetra
.706 .789 .915 r
.3724 .25789 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.664 .741 .907 r
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.62 .725 .921 r
.47475 .21904 .48206 .22782 .49509 .22308 .4878 .2156 Mtetra
.589 .751 .955 r
.4878 .2156 .49509 .22308 .50817 .2183 .50091 .21275 Mtetra
.609 .821 .981 r
.50091 .21275 .50817 .2183 .52132 .21373 .51411 .20896 Mtetra
.647 .86 .98 r
.51411 .20896 .52132 .21373 .53454 .212 .52738 .20406 Mtetra
.691 .778 .917 r
.52738 .20406 .53454 .212 .54783 .20831 .54071 .19831 Mtetra
.693 .727 .876 r
.54071 .19831 .54783 .20831 .56118 .20294 .55409 .1922 Mtetra
.686 .709 .866 r
.55409 .1922 .56118 .20294 .57458 .19675 .56753 .18622 Mtetra
.678 .712 .874 r
.56753 .18622 .57458 .19675 .58803 .19057 .58104 .18059 Mtetra
.671 .723 .888 r
.58104 .18059 .58803 .19057 .60155 .18482 .59461 .17527 Mtetra
.667 .732 .899 r
.59461 .17527 .60155 .18482 .61514 .17948 .60825 .17013 Mtetra
.665 .738 .904 r
.60825 .17013 .61514 .17948 .6288 .17436 .62196 .16506 Mtetra
.664 .74 .907 r
.62196 .16506 .6288 .17436 .64253 .16932 .63574 .16 Mtetra
.664 .741 .907 r
.63574 .16 .64253 .16932 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14751 .32817 Mtetra
.14751 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .3059 .22987 .29779 Mtetra
.22987 .29779 .23793 .3059 .24988 .30152 .24185 .29337 Mtetra
.664 .74 .907 r
.24185 .29337 .24988 .30152 .26188 .29716 .25389 .28894 Mtetra
.663 .739 .907 r
.25389 .28894 .26188 .29716 .27393 .29287 .26598 .28451 Mtetra
.66 .736 .906 r
.26598 .28451 .27393 .29287 .28602 .28875 .27812 .28013 Mtetra
.655 .729 .903 r
.27812 .28013 .28602 .28875 .29815 .28496 .29031 .27588 Mtetra
.647 .716 .898 r
.29031 .27588 .29815 .28496 .31031 .28151 .30254 .27185 Mtetra
.638 .699 .89 r
.30254 .27185 .31031 .28151 .32253 .27819 .31481 .26807 Mtetra
.632 .687 .884 r
.31481 .26807 .32253 .27819 .33483 .27453 .32713 .26445 Mtetra
.632 .689 .885 r
.32713 .26445 .33483 .27453 .34724 .27003 .33952 .2608 Mtetra
.642 .714 .9 r
.33952 .2608 .34724 .27003 .35977 .26443 .35199 .25685 Mtetra
.657 .764 .929 r
.35199 .25685 .35977 .26443 .3724 .25789 .36455 .25245 Mtetra
.665 .831 .963 r
.36455 .25245 .3724 .25789 .38504 .25194 .37719 .24761 Mtetra
.666 .867 .976 r
.37719 .24761 .38504 .25194 .39767 .24731 .3899 .24248 Mtetra
.671 .855 .97 r
.3899 .24248 .39767 .24731 .41037 .24265 .40267 .2373 Mtetra
.668 .839 .965 r
.40267 .2373 .41037 .24265 .42312 .23797 .41548 .23228 Mtetra
.658 .827 .964 r
.41548 .23228 .42312 .23797 .43594 .23327 .42835 .22755 Mtetra
.645 .823 .968 r
.42835 .22755 .43594 .23327 .44881 .22855 .44127 .22309 Mtetra
.635 .829 .975 r
.44127 .22309 .44881 .22855 .46175 .22381 .45425 .21879 Mtetra
.63 .843 .982 r
.45425 .21879 .46175 .22381 .47475 .21904 .46729 .21444 Mtetra
.635 .859 .984 r
.46729 .21444 .47475 .21904 .4878 .2156 .48041 .20981 Mtetra
.666 .832 .963 r
.48041 .20981 .4878 .2156 .50091 .21275 .4936 .20473 Mtetra
.685 .773 .918 r
.4936 .20473 .50091 .21275 .51411 .20896 .50685 .19919 Mtetra
.687 .73 .883 r
.50685 .19919 .51411 .20896 .52738 .20406 .52016 .19334 Mtetra
.684 .709 .867 r
.52016 .19334 .52738 .20406 .54071 .19831 .53353 .18746 Mtetra
.679 .705 .867 r
.53353 .18746 .54071 .19831 .55409 .1922 .54695 .18173 Mtetra
.674 .712 .877 r
.54695 .18173 .55409 .1922 .56753 .18622 .56044 .17626 Mtetra
.669 .723 .89 r
.56044 .17626 .56753 .18622 .58104 .18059 .57399 .171 Mtetra
.666 .732 .899 r
.57399 .171 .58104 .18059 .59461 .17527 .58761 .16587 Mtetra
.665 .738 .904 r
.58761 .16587 .59461 .17527 .60825 .17013 .6013 .16079 Mtetra
.664 .74 .906 r
.6013 .16079 .60825 .17013 .62196 .16506 .61505 .15571 Mtetra
.664 .741 .907 r
.61505 .15571 .62196 .16506 .63574 .16 .62887 .15061 Mtetra
.62887 .15061 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14751 .32817 .13917 .32025 Mtetra
.13917 .32025 .14751 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24185 .29337 .23376 .28515 Mtetra
.23376 .28515 .24185 .29337 .25389 .28894 .24583 .28068 Mtetra
.664 .74 .907 r
.24583 .28068 .25389 .28894 .26598 .28451 .25796 .27619 Mtetra
.663 .74 .907 r
.25796 .27619 .26598 .28451 .27812 .28013 .27014 .27169 Mtetra
.662 .737 .906 r
.27014 .27169 .27812 .28013 .29031 .27588 .28237 .26722 Mtetra
.658 .731 .903 r
.28237 .26722 .29031 .27588 .30254 .27185 .29466 .26281 Mtetra
.653 .721 .899 r
.29466 .26281 .30254 .27185 .31481 .26807 .30699 .25853 Mtetra
.647 .708 .892 r
.30699 .25853 .31481 .26807 .32713 .26445 .31937 .2544 Mtetra
.642 .695 .884 r
.31937 .2544 .32713 .26445 .33952 .2608 .33181 .2504 Mtetra
.639 .687 .879 r
.33181 .2504 .33952 .2608 .35199 .25685 .3443 .24645 Mtetra
.64 .689 .879 r
.3443 .24645 .35199 .25685 .36455 .25245 .35687 .24245 Mtetra
.645 .7 .886 r
.35687 .24245 .36455 .25245 .37719 .24761 .3695 .23829 Mtetra
.651 .72 .899 r
.3695 .23829 .37719 .24761 .3899 .24248 .38221 .23394 Mtetra
.657 .743 .913 r
.38221 .23394 .3899 .24248 .40267 .2373 .39498 .22941 Mtetra
.661 .763 .925 r
.39498 .22941 .40267 .2373 .41548 .23228 .40783 .22474 Mtetra
.664 .775 .932 r
.40783 .22474 .41548 .23228 .42835 .22755 .42074 .21996 Mtetra
.667 .775 .93 r
.42074 .21996 .42835 .22755 .44127 .22309 .43371 .21507 Mtetra
.671 .766 .921 r
.43371 .21507 .44127 .22309 .45425 .21879 .44675 .21004 Mtetra
.675 .749 .906 r
.44675 .21004 .45425 .21879 .46729 .21444 .45985 .20482 Mtetra
.677 .729 .889 r
.45985 .20482 .46729 .21444 .48041 .20981 .47302 .19941 Mtetra
.678 .712 .875 r
.47302 .19941 .48041 .20981 .4936 .20473 .48625 .19385 Mtetra
.677 .702 .866 r
.48625 .19385 .4936 .20473 .50685 .19919 .49954 .18822 Mtetra
.675 .701 .866 r
.49954 .18822 .50685 .19919 .52016 .19334 .51288 .18264 Mtetra
.672 .706 .873 r
.51288 .18264 .52016 .19334 .53353 .18746 .52629 .17718 Mtetra
.669 .716 .883 r
.52629 .17718 .53353 .18746 .54695 .18173 .53975 .17188 Mtetra
.667 .726 .894 r
.53975 .17188 .54695 .18173 .56044 .17626 .55328 .1667 Mtetra
.665 .734 .901 r
.55328 .1667 .56044 .17626 .57399 .171 .56688 .16159 Mtetra
.664 .738 .905 r
.56688 .16159 .57399 .171 .58761 .16587 .58055 .1565 Mtetra
.664 .74 .907 r
.58055 .1565 .58761 .16587 .6013 .16079 .59428 .15139 Mtetra
.664 .741 .907 r
.59428 .15139 .6013 .16079 .61505 .15571 .60808 .14627 Mtetra
.60808 .14627 .61505 .15571 .62887 .15061 .62195 .14112 Mtetra
.62195 .14112 .62887 .15061 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27619 .24986 .26782 Mtetra
.664 .74 .907 r
.24986 .26782 .25796 .27619 .27014 .27169 .26207 .26326 Mtetra
.663 .74 .907 r
.26207 .26326 .27014 .27169 .28237 .26722 .27435 .2587 Mtetra
.663 .738 .906 r
.27435 .2587 .28237 .26722 .29466 .26281 .28667 .25413 Mtetra
.661 .735 .904 r
.28667 .25413 .29466 .26281 .30699 .25853 .29906 .24959 Mtetra
.659 .728 .901 r
.29906 .24959 .30699 .25853 .31937 .2544 .3115 .24509 Mtetra
.655 .719 .896 r
.3115 .24509 .31937 .2544 .33181 .2504 .32399 .24065 Mtetra
.652 .709 .889 r
.32399 .24065 .33181 .2504 .3443 .24645 .33654 .23628 Mtetra
.65 .699 .882 r
.33654 .23628 .3443 .24645 .35687 .24245 .34914 .23194 Mtetra
.649 .692 .877 r
.34914 .23194 .35687 .24245 .3695 .23829 .36182 .22758 Mtetra
.65 .689 .874 r
.36182 .22758 .3695 .23829 .38221 .23394 .37455 .22315 Mtetra
.652 .689 .872 r
.37455 .22315 .38221 .23394 .39498 .22941 .38736 .21861 Mtetra
.655 .691 .872 r
.38736 .21861 .39498 .22941 .40783 .22474 .40023 .21393 Mtetra
.658 .693 .871 r
.40023 .21393 .40783 .22474 .42074 .21996 .41317 .20911 Mtetra
.662 .694 .87 r
.41317 .20911 .42074 .21996 .43371 .21507 .42618 .20414 Mtetra
.665 .695 .868 r
.42618 .20414 .43371 .21507 .44675 .21004 .43925 .19903 Mtetra
.667 .695 .867 r
.43925 .19903 .44675 .21004 .45985 .20482 .45238 .19381 Mtetra
.668 .696 .867 r
.45238 .19381 .45985 .20482 .47302 .19941 .46558 .18851 Mtetra
.668 .7 .87 r
.46558 .18851 .47302 .19941 .48625 .19385 .47884 .18319 Mtetra
.668 .706 .876 r
.47884 .18319 .48625 .19385 .49954 .18822 .49216 .17791 Mtetra
.667 .714 .883 r
.49216 .17791 .49954 .18822 .51288 .18264 .50554 .17268 Mtetra
.666 .723 .892 r
.50554 .17268 .51288 .18264 .52629 .17718 .51898 .16751 Mtetra
.665 .731 .898 r
.51898 .16751 .52629 .17718 .53975 .17188 .53249 .16239 Mtetra
.665 .736 .903 r
.53249 .16239 .53975 .17188 .55328 .1667 .54607 .15729 Mtetra
.664 .739 .906 r
.54607 .15729 .55328 .1667 .56688 .16159 .55971 .15218 Mtetra
.664 .74 .907 r
.55971 .15218 .56688 .16159 .58055 .1565 .57342 .14706 Mtetra
.664 .741 .907 r
.57342 .14706 .58055 .1565 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26782 .24169 .25938 Mtetra
.24169 .25938 .24986 .26782 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .2587 .26625 .25016 Mtetra
.664 .74 .907 r
.26625 .25016 .27435 .2587 .28667 .25413 .27861 .24553 Mtetra
.663 .739 .907 r
.27861 .24553 .28667 .25413 .29906 .24959 .29103 .24088 Mtetra
.663 .738 .905 r
.29103 .24088 .29906 .24959 .3115 .24509 .30352 .23622 Mtetra
.662 .734 .904 r
.30352 .23622 .3115 .24509 .32399 .24065 .31605 .23157 Mtetra
.661 .729 .9 r
.31605 .23157 .32399 .24065 .33654 .23628 .32865 .22692 Mtetra
.659 .723 .896 r
.32865 .22692 .33654 .23628 .34914 .23194 .34131 .22228 Mtetra
.658 .717 .892 r
.34131 .22228 .34914 .23194 .36182 .22758 .35403 .21763 Mtetra
.657 .711 .887 r
.35403 .21763 .36182 .22758 .37455 .22315 .36681 .21296 Mtetra
.658 .706 .883 r
.36681 .21296 .37455 .22315 .38736 .21861 .37965 .20823 Mtetra
.658 .703 .88 r
.37965 .20823 .38736 .21861 .40023 .21393 .39256 .20344 Mtetra
.66 .702 .878 r
.39256 .20344 .40023 .21393 .41317 .20911 .40553 .19858 Mtetra
.661 .703 .878 r
.40553 .19858 .41317 .20911 .42618 .20414 .41857 .19363 Mtetra
.663 .705 .879 r
.41857 .19363 .42618 .20414 .43925 .19903 .43167 .18861 Mtetra
.664 .709 .881 r
.43167 .18861 .43925 .19903 .45238 .19381 .44483 .18355 Mtetra
.665 .713 .884 r
.44483 .18355 .45238 .19381 .46558 .18851 .45806 .17846 Mtetra
.665 .719 .889 r
.45806 .17846 .46558 .18851 .47884 .18319 .47136 .17335 Mtetra
.665 .725 .894 r
.47136 .17335 .47884 .18319 .49216 .17791 .48471 .16826 Mtetra
.665 .731 .899 r
.48471 .16826 .49216 .17791 .50554 .17268 .49813 .16316 Mtetra
.664 .735 .903 r
.49813 .16316 .50554 .17268 .51898 .16751 .51162 .15807 Mtetra
.664 .738 .905 r
.51162 .15807 .51898 .16751 .53249 .16239 .52517 .15297 Mtetra
.664 .74 .906 r
.52517 .15297 .53249 .16239 .54607 .15729 .53879 .14785 Mtetra
.664 .74 .907 r
.53879 .14785 .54607 .15729 .55971 .15218 .55248 .14271 Mtetra
.664 .741 .907 r
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27375 Mtetra
.17289 .27375 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24158 Mtetra
.25807 .24158 .26625 .25016 .27861 .24553 .27048 .23689 Mtetra
.27048 .23689 .27861 .24553 .29103 .24088 .28293 .23219 Mtetra
.664 .74 .907 r
.28293 .23219 .29103 .24088 .30352 .23622 .29545 .22747 Mtetra
.29545 .22747 .30352 .23622 .31605 .23157 .30803 .22273 Mtetra
.663 .738 .906 r
.30803 .22273 .31605 .23157 .32865 .22692 .32067 .21797 Mtetra
.663 .737 .905 r
.32067 .21797 .32865 .22692 .34131 .22228 .33337 .21319 Mtetra
.663 .734 .903 r
.33337 .21319 .34131 .22228 .35403 .21763 .34613 .2084 Mtetra
.662 .732 .901 r
.34613 .2084 .35403 .21763 .36681 .21296 .35895 .20358 Mtetra
.662 .729 .899 r
.35895 .20358 .36681 .21296 .37965 .20823 .37183 .19874 Mtetra
.662 .727 .898 r
.37183 .19874 .37965 .20823 .39256 .20344 .38478 .19387 Mtetra
.663 .726 .897 r
.38478 .19387 .39256 .20344 .40553 .19858 .39779 .18895 Mtetra
.663 .726 .896 r
.39779 .18895 .40553 .19858 .41857 .19363 .41086 .184 Mtetra
.663 .728 .897 r
.41086 .184 .41857 .19363 .43167 .18861 .424 .17902 Mtetra
.664 .729 .898 r
.424 .17902 .43167 .18861 .44483 .18355 .4372 .17401 Mtetra
.664 .732 .9 r
.4372 .17401 .44483 .18355 .45806 .17846 .45046 .16897 Mtetra
.664 .735 .902 r
.45046 .16897 .45806 .17846 .47136 .17335 .4638 .16392 Mtetra
.664 .737 .904 r
.4638 .16392 .47136 .17335 .48471 .16826 .47719 .15885 Mtetra
.664 .739 .906 r
.47719 .15885 .48471 .16826 .49813 .16316 .49065 .15375 Mtetra
.664 .74 .906 r
.49065 .15375 .49813 .16316 .51162 .15807 .50418 .14864 Mtetra
.664 .74 .907 r
.50418 .14864 .51162 .15807 .52517 .15297 .51778 .1435 Mtetra
.664 .741 .907 r
.51778 .1435 .52517 .15297 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27375 .16441 .26536 Mtetra
.16441 .26536 .17289 .27375 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24158 .24983 .23291 Mtetra
.24983 .23291 .25807 .24158 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22747 .28732 .21867 Mtetra
.28732 .21867 .29545 .22747 .30803 .22273 .29993 .21388 Mtetra
.664 .74 .907 r
.29993 .21388 .30803 .22273 .32067 .21797 .31261 .20907 Mtetra
.31261 .20907 .32067 .21797 .33337 .21319 .32534 .20423 Mtetra
.32534 .20423 .33337 .21319 .34613 .2084 .33814 .19938 Mtetra
.664 .739 .906 r
.33814 .19938 .34613 .2084 .35895 .20358 .351 .1945 Mtetra
.351 .1945 .35895 .20358 .37183 .19874 .36392 .18959 Mtetra
.664 .738 .905 r
.36392 .18959 .37183 .19874 .38478 .19387 .37691 .18466 Mtetra
.37691 .18466 .38478 .19387 .39779 .18895 .38996 .1797 Mtetra
.38996 .1797 .39779 .18895 .41086 .184 .40307 .17472 Mtetra
.40307 .17472 .41086 .184 .424 .17902 .41624 .16971 Mtetra
.664 .739 .906 r
.41624 .16971 .424 .17902 .4372 .17401 .42949 .16468 Mtetra
.42949 .16468 .4372 .17401 .45046 .16897 .44279 .15962 Mtetra
.664 .74 .906 r
.44279 .15962 .45046 .16897 .4638 .16392 .45616 .15453 Mtetra
.664 .74 .907 r
.45616 .15453 .4638 .16392 .47719 .15885 .4696 .14943 Mtetra
.4696 .14943 .47719 .15885 .49065 .15375 .48311 .1443 Mtetra
.664 .741 .907 r
.48311 .1443 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27514 Mtetra
.10817 .27514 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19938 .33008 .19033 Mtetra
.33008 .19033 .33814 .19938 .351 .1945 .34298 .1854 Mtetra
.664 .74 .907 r
.34298 .1854 .351 .1945 .36392 .18959 .35594 .18045 Mtetra
.35594 .18045 .36392 .18959 .37691 .18466 .36896 .17547 Mtetra
.36896 .17547 .37691 .18466 .38996 .1797 .38205 .17047 Mtetra
.38205 .17047 .38996 .1797 .40307 .17472 .3952 .16544 Mtetra
.3952 .16544 .40307 .17472 .41624 .16971 .40842 .16039 Mtetra
.40842 .16039 .41624 .16971 .42949 .16468 .4217 .15531 Mtetra
.664 .741 .907 r
.4217 .15531 .42949 .16468 .44279 .15962 .43505 .15021 Mtetra
.43505 .15021 .44279 .15962 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14943 .46194 .13993 Mtetra
.46194 .13993 .4696 .14943 .48311 .1443 .47549 .13476 Mtetra
.47549 .13476 .48311 .1443 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27514 .09942 .26676 Mtetra
.09942 .26676 .10817 .27514 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16622 Mtetra
.36094 .16622 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13556 Mtetra
.44069 .13556 .44846 .14509 .46194 .13993 .45422 .13036 Mtetra
.45422 .13036 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .2161 Mtetra
.19976 .2161 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13556 .43285 .12593 Mtetra
.43285 .12593 .44069 .13556 .45422 .13036 .44641 .12069 Mtetra
.44641 .12069 .45422 .13036 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .2161 .19115 .20721 Mtetra
.19115 .20721 .19976 .2161 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .1926 Mtetra
.2287 .1926 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18274 Mtetra
.25404 .18274 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30545 .16273 Mtetra
.30545 .16273 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .2271 Mtetra
.10878 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18274 .24553 .17355 Mtetra
.24553 .17355 .25404 .18274 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30545 .16273 .2971 .15335 Mtetra
.2971 .15335 .30545 .16273 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj01W0:Vmj0030000002Y_NP0ZKgX01L0ZKgX00<000000?ooo`3oool0CP3oool007l0oooo0P00
001`0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00001b
0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD0000
00000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0=P2Y_NP30:Vmi`L0ZKgX0`2Y_NL_
0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<000000?ooo`3oool0C03oool004X0oooo00L0ohle000D
G`34ool0oooo0?ooa01O53D0Sooo02H0oooo0P00000j0:Vmj0H0ZKgW102Y_NP60:Vmi`<0ZKgX0`2Y
_NLY0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C03oool004l0oooo00<0ScD0
03F?o`3oool08P3oool3000002l0ZKgX0`2Y_NL60:Vmj0X0ZKgW1@2Y_>L<0:Vmi``0ZKgX0`2Y_NLI
0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<000000?ooo`3oool0B`3oool00480oooo00<0olAO01@0
000000000`0000000`0003D0Sooo0?ooo`040?ooo`0308le000eSol0oooo0200oooo0P00000`0:Vm
j0H0ZKgW0`2Y_NP30:Vli`L0ZKgW202Y_>L30:Vmi`<0Z[cW1@2Y_NL50:Vli`D0ZKgX1P2Y_NLH0:Vm
j0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool004X0oooo00L0olAO01@0501O
a?l0oooo0?ooa01O51@0GlCo01h0oooo0`0000000`2Y_NP000000:Vmj00[0:Vmj0/0ZKgW1P2Y_>L4
0:Vmi`X0ZKcW1`2Z_>L20:Vmi`<0Z[_V1@2Y_>L20:Vmj0<0Z[cW1P2Y_NLG0:Vmj0030000002Y_NP0
ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool004X0oooo00<0oon?03D0000000000P0000000`0e
Sol0oooo0?ooo`0J0?ooo`030:Vmj0000000000002l0ZKgX2`2Y_NL30:VliPD0ZKcW1@2Z^nH50:Vl
i`H0Z[_U1@2Z_>L60:ZkiP@0ZKcW1P2Z_>L30:Vmi`<0Z[cW5P2Y_NP00`000000ZKgX0:Vmj00K0:Vm
j0030000003oool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`00000_0:Vmj0X0
ZKgW1`2Y_>H20:Vli`<0Z[WT1@2Z^nH20:Vli`<0Z[WT1P2Z^nD50:Zii0X0Z[_V302Z_>LE0:Vmj003
0000002Y_NP0ZKgX01`0ZKgX00<000000?ooo`3oool0B03oool004/0oooo00<0ScD003F?o`3oool0
6P3oool2000002h0ZKgX1@2Y_>L50:Vmi`H0ZK_V1@2Y_>H60:Zii0@0Z[_V1P2Z^N@30:Zki@<0ZkOR
1@2Z^N@20:ZkiP<0ZkWS2P2Z^nH;0:Zlia00ZKgX00<000000:Vmj02Y_NP0702Y_NP00`000000oooo
0?ooo`180?ooo`00B`3oool01P34Ga@00000000000000000000e08oooa<0oooo00@0ZKgX00000000
000000000P2Y_NP00`000000ZKgX0:Vmj00Y0:Vmj0P0ZKcW0P2Y_NL30:Vji@H0ZK_V1@2Z^><50:Zi
i0D0Z[KR1P2Z^N@60:^ghP@0Z[WT1P2[^N<20:ZkiP<0ZkWS1@2Z^nH30:Zli`<0Z[_V1@2Z_>L50:Zm
i`X0ZKgX00<000000:Vmj02Y_NP07@2Y_NP00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP0
00000000000_0:Vmj0X0ZKcW1P2Y^^D30:VkiP<0Z[KR1@2Z^><20:Zii0<0ZkCP1@2Z]^830:Zii0<0
[;CO1@2[]n850:bfh0/0ZkWS2`2Z^nH20:Zli`<0Z[cV1@2Z_NL20:Vmj0<0ZKgW102Y_NP00`000000
ZKgX0:Vmj00N0:Vmj0030000003oool0oooo04H0oooo001O0?ooo`@00000;@2Y_NP:0:Vli`/0ZK[U
1P2Z]^840:Zhh`H0ZkCP102Z]^870:bdg`80ZkOR0`2]]=d50:bfh080ZkWS0`2]]]l50:^ih`H0[;WS
1@2Z^nH60:ZliP@0Z[gW1P2Y_NL30:Vmj0030000002Y_NP0ZKgX01h0ZKgX00<000000?ooo`3oool0
AP3oool005d0oooo00@0ZKgX0000000000000000;@2Y_NP:0:Vli`<0ZKWU1P2Y^^D50:Veh@D0Z[KR
1@2[/mh50:^dh0D0[;?M1P2/]=l50:fdg@D0[;KP1P2]]]l20:^ih`<0[[KO1P2/^N<20:ZkiP<0[;[T
1@2Z_>H50:Zli`D0ZKgW0`2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030000003oool0oooo04D0oooo
001K0?ooo`<00000;P2Y_NP:0:Vli`H0ZKWU0`2Y^^D30:Vdh@D0ZKGQ0P2Z]^830:^bg@D0Zk?N0P2[
]>030:fcg@D0[;?M0`2/]=l30:neg@D0[KCM0P2/]^030:neg@D0[KKO1P2^]]l50:bih`H0[;[T0P2Z
_>H30:bki@D0Z[cW1@2Z_NL20:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<0oooo0000003oool0A@3o
ool005P0oooo0`00000]0:Vmj0D0ZKgW1P2Y_>L:0:Vii@D0ZKCQ1@2Y]N450:^bg@D0Zk?N1P2]/md5
0:bcg@H0[kGM102]]=d60:neg@80[KKO0`2a]md50:jfg`H0[[OO1@2/^^@60:bki@80Z[cW0`2[_>H5
0:Zmi`030:Vmj0000000ZKgX0240ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX0000
00000000;P2Y_NP80:Vmi`<0ZKcW0`2Y^^D70:Vii@<0ZK?P1@2Y]>420:Veh@<0Z[7M1@2[/]d20:^c
gP<0[KKO1P2]/md20:bcg@<0[k[R1@2_]Md50;6jh0D0[kGM1P2a]md20:jfg`<0/KSN1P2^]ml20:bj
i0<0[[SQ1@2/^nD60:^liP@0Z[gW00<0ZKgX0000002Y_NP08P2Y_NP00`000000oooo0?ooo`130?oo
o`00D`3oool3000000030:Vmj0000000ZKgX02/0ZKgX2`2Y_NL60:Vji@@0ZKWU1P2Y/n040:Vdh@H0
Z[7M102[/]d60:ffg`D0[K?M1P2_^^820:neg@<0/<OZ1@2a^^020:neg@<0/[kS1@2a]md60;6hgPD0
[[OO1P2^^>420:bki@<0[[[R1@2[_>H50:Zli`030000002Y_NP0ZKgX0280ZKgX00<000000?ooo`3o
ool0@P3oool00540oooo0P00000c0:Vmj0D0ZKgW1@2Y^^H50:Vji@D0Z;?P1@2Y/n050:ZagPD0Z[7M
1@2]^^<60:ffg`D0[lG[1@2_^^860;37jP@0/K[P1P2b_^<20;6gg@<0/l7T1P2a^=h50;:hgPD0[[SQ
1P2^^^820:^liP<0[;_T102Z_>L00`000000Z[gW0:Zmi`030:Zmial0ZKgX00<000000?ooo`3oool0
@P3oool004h0oooo0`00000f0:Vmj0D0ZK_V1@2Y^^H50:Rch@D0Z;?P0P2Y/n030:VagPD0Z[7N0P2Z
/Md30:boi`D0[K[S0`2]]]l30:[DmPD0[lG[0P2_^^830:GLnPD0/<OZ1@2]d_<50;:nh`H0/l7T0`2a
^=h30;C0h`D0/[SN0P2^^>430;6ig`D0[[[R1P2/^n@20:Zli`030:^liP000000ZkcV00D0Z[gW7`2Y
_NP00`000000oooo0?ooo`110?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e0000
0000000DG`34ool0:@3oool2000003L0ZKgX0`2Y^nL50:VkiP80ZK[V0`2X]>850:Rch@@0Z;?P1@2Y
/Mh50:ZagPH0[;oW1@2]^^<60:[DmP@0[lG[1P2Ug?X20;37jP<0V]7k1@2]d_<20;:nh`<0Z=Oh1@2c
`N@60;C0h`D0/[SN1P2a^Ml20:jjhP<0/;[P1@2/^n@30:^liP030000002[_>H0ZkcV00@0Z[gW802Y
_NP00`000000oooo0?ooo`100?ooo`006@3oool02P3ogi`0B01d0;ooo`3oool0oooO05lD000DGl@0
oooo0<AO5000=HlV0?ooo`<000000P2Y_NP00`000000ZKgX0:Vmj00b0:Vmj0H0ZK_W102Y^nH50:Rd
hPD0Z;?Q1@2X/Mh50:VagP80Z[7N0`2[a>/60:boi`D0X]_k1@2Ze?H609_Bn`@0YMcj1P2JdO/40:gB
l`H0Z=Oh0P2c`N@30:KFn0H0]<3S0P2b^=h30;Bnh@D0/KWO1P2`^^020:bki0<0[[_S0P2[_>H00`00
0000ZkcV0:^liP050:Zmial0ZKgX00<000000?ooo`3oool02P3oool01@3ookl0M00000000000B9`0
gooo0340oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?
ool08P3oool00`2Y_NP000000000000f0:Vmj0D0ZKcW1@2Y^nL50:Rfh`D0Z;CR0P2X/n430:N`g`D0
Z;7N102Y/Mh60:_4j`<0[;oW0`2Qeo/50:;Kn`D0U/3d0`2Kd_/30:Rlj0D0SK?`1@2J]n`50931m`@0
Z=Oh1P2Ve_P50;C0h`H0];kQ0P2a^Ml30;Blg`D0/;[P1P2^^n<20:^liP030000002/_>D0[;cU00D0
Z[gW1@2Z_NPJ0:Vmj0030000003oool0oooo00P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;la
0?ooo`003@3oool00`3ogi`0B00000000003000000030000M02oool0oooo00<0oooo00/0omnL04P0
M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0P0?ooo`<00000=P2Y_NP80:Vli`80
ZK_W0`2X]n@50:Rfh`@0Z;CR1P2W/=l40:RagPH0Z/K^1@2[a>/60:7Gn`D0W[W[1@2F`?@60:Rlj080
SK?`0`2Y_NP509Zgk080T<7g0`2S^nX408Vel`H0Y]Kh1@2[d?<50;Bnh@H0];cO0P2`^^030;>kg`D0
[[_S0P2/_>D010000000[;cU0:bli@2/_>D20:Zmi`<0ZkgW1@2Z_NPI0:Vmj0030000003oool0oooo
00P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0
_ooo0?ooo`3o_g@001AO0<Coo`3oool0oon?03D0501Oa?l07P3oool3000003H0ZKgX2P2Y_>L60:Rg
i0@0Z;KS1@2V/=l60:N`g`D0ZLK^1@2Za^h60:;Dn@D0ZKgX1@2N^N/50:Vmj0D0Z;cX1P2Y_NP409Zg
k0H0Xk_Z1029]O<608Ndl`D0Zm3c1@2ab>/50;Blg`H0/k_O0P2^^n<30;6kh@030:bli@000000[;cU
0080[;cU1P2[_NL40:Zmj1X0ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3o
ohl0=@0D05o4o`0K0?ooo`<00000>P2Y_NP50:Vli`D0Z;WU1P2X]n@90:J`g`<0Yk3O0`2Y`n`50:W6
kPD0YM;g0`2Re?TQ0:Vmj0/0Xk_Z1@27]?<508fom`D0/LS[0P2d_=l30;G1h`D0/k_O1P2a^n400`00
0000[;cU0:jli0020:jli0D0ZkgW1@2Z_NLJ0:Vmj0030000003oool0oooo00H0oooo00L0okmd0018
W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo
0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000?P2Y_NP30:Vli`80ZK[V1@2X^ND3
0:Rgi0<0Y[7P2@2V/=l60:W3k080ZLK^0`2XdoH50:GBmbT0ZKgX1P2S^nX509Zgk0D0SKog102ab>/6
0;G1h`80/k_O0`2f_N050;6kh@030000002^_>@0[[cT00<0[[cT0P2[_NL30:^miPD0Z[gW6@2Y_NP0
0`000000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`00603o
ool02`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo0?ooo`34Ga@003F?01L0oooo0`000011
0:Vmj0D0ZK[V1@2X^ND50:Jah0D0Y[3O1@2X_^T50:W3k0H0Z=?f=02Y_NP509Zgk0@0SKog1@2Ld?X5
0;G1h`H0][gP102c_N400`000000[[cT0:jli0030:jli0H0ZkgV1@2Z_NLI0:Vmj0030000003oool0
oooo00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`030?oOW018
07@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D0?ooo`<0000000<0ZKgX0000002Y_NP0
?@2Y_NP50:Vki`D0ZK[V1@2V/^450:Jah080Y[3O0`2V^>H50:Rnj@H0ZmKg>@2Y_NP209Zgk0<0ZKgX
1@2</>l409c@nPD0/<O[0`2f_N030;K0hP<0/kgQ00<000000;>mh@2`_N@0102`_N@50:^miPH0Z[gW
6@2Y_NP00`000000oooo0?ooo`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0
oooo00<0ZKgX000000000000?`2Y_NP50:Vli`D0ZK_W1@2V]N<50:Jbh@@0Y[7P1P2V^>H20:Rnj@<0
Zm[h0`2[e_M10:Vmj080S;3_0`2X_>P408:]l@D0/<O[1P2f`>820;>mh@030000002e_^40]KkQ00D0
/;gT1@2/_NH50:ZmiaT0ZKgX00<000000?ooo`3oool01@3oool01@3ookl0M00000000000B9`0gooo
0340oooo000b0?ooo`<00000@P2Y_NP50:Vli`80ZK_W0`2W^>D50:Jeh`@0Y[;Q1@2U/n850:JhiPH0
Zm[h@`2Y_NP60:Rlj0@0PZga0P2`an/30:38m@D0]/3R0P2e_^4010000000]KkQ0;Fnh@2e_^420;2m
i0<0/KkS1@2/_NH50:ZmiaT0ZKgX00<000000?ooo`3oool0>P3oool00300oooo0P0000000`2Y_NP0
00000:Vmj0130:Vmj0@0ZKcW1P2W^>D40:Jeh`D0Xk3Q1@2U/n860:[MnDP0ZKgX1@2X_>P408:]l@H0
X<Se0P2f`>830;?2i@8000000`2e_^460;6nh`80[;gV0`2]_^H50:ZmiaT0ZKgX00<000000?ooo`3o
ool0>@3oool002`0oooo00@0ZKgX0000000000000000B02Y_NP60:RjiP@0YkSU1@2S[n450:>`h@80
YK?R102Ze?H30:[MnDl0ZKgX102</>l50:38m@80/l;U0`0000000`2c`^D0]KkQ000000030;Noh@D0
/KkS1P2]_^H40:ZmiaT0ZKgX00<000000?ooo`3oool0>@3oool002/0oooo0P0000180:Vmj0@0ZKcW
1P2X^^H40:BahPD0XjoQ102S/>470:[DmR@0ZKgX1@2TVL/50:Vmj0D0YJ7A7`2Y_NP408b`k`<0R[[f
0`0000040;?2i@030;Noh@000000]koQ00<0]koQ0P2a_^<30;>oh`D0[KkV1@2Z_NLI0:Vmj0030000
003oool0oooo03P0oooo000Y0?ooo`800000B02Y_NP70:Vli`<0Z;[V0`2U]N@40:BahPD0XjoQ1@2X
`nd30:[DmP<0]<WZ5`2Y_NP30:VfhPL0ZKgX0`2ORK`50:BIb`D0WXFi1@2UXM450:BIbQT0ZKgX102N
^N/3000000<0R[[f0P2c`^D30:o3j0030;Noh@000000]koQ0080]koQ1@2c_n<60:fniP@0Z[gW6P2Y
_NP00`000000oooo0?ooo`0g0?ooo`007@3oool01@3ookl0M00000000000B9`0gooo00L0oooo0P00
00160:Vmj0X0ZKcW1@2U]N@50:BahPD0Y;KV1@2X`nd60;C9jQ@0ZKgX1P2Y]^840:Vmj0D0WhVl102T
VL/20;FE]P@0WXFi102UXM420;6D^@D0Y9W:1@2UXM4D0:Vmj00309jij`00000000000080W[W[102:
^_H60:o3j0030;Noh@000000]l7R0080]l7R102c_n<60:fniPD0Z[gW6@2Y_NP00`000000oooo0?oo
o`0g0?ooo`00703oool01P3ooml0W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000
AP2Y_NP50:Vli`D0YkSV1@2U]N@20:BahP<0XK3R1@2T]^H20:S3k@<0^]W`0`2dbNXB0:Vmj0X0ZKKR
1@2MP[H509n9_080Y9W;0`2eUKH509j5^@80YJ7A0`2aU;T40:BIbP80^Ibk1@2UXM4A0:Vmj0<00000
1@2Y_NP408:[k`D0[l?X0P2g`N800`000000]l7R0;O1hP050;C0h`D0[KkV1P2Z_NLI0:Vmj0030000
003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`80
00000P3oool00`000000ZKgX0:Vmj0140:Vmj0D0Z;_W1@2W^>H40:Fei0H0XK3R102T]^H60;[Il1D0
ZKgX1`2Y]^830:24]@@0WH:f1@2ORK`00`2TVL/0]IFf0;FE]P020;FE]PD0WXFi1P2aU;T20:BIbP<0
^Ibk1@2UXM4>0:Vmj0<00000202Y_NP508:[k`D0Z<3[00<0]l7R0000002g`^800P2g`^850;C0h`D0
[[oV1@2Z_NLJ0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP0@P2Y_NP20:Vl
i`D0Z;_W102W^>H50:6_hPD0XK3R1P2`g_LJ0:Vmj0@0ZKKR1@2PQ;D409f2]PD0WhVl1P2eUKH309j5
^@80_j:j1@2aU;T00`2TVLX0^Ibk0;VL^`030;VL^`<0YJ7A0P2eWKl:0:Vmj0<00000302Y_NP508N^
k`@0Z<3[0P2g`^8010000000]l;R0;O2hP2g`^820;C0h`<0]<7T1@2^_nH50:ZniaT0ZKgX00<00000
0?ooo`3oool0=@3oool001`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0
00000?ooo`3oool00`3ooom20:Vmj0D0ZKcW1@2X^nL40:>bh`D0XJoR0P2Q/>840:W4k@<0/=kg0P2[
_nPI0:Vmj0D0W8:f102PQ;D509f2]P<0WhVl0P2cV;/50;FE]P80WXFi0`2oX[X50;6D^@H0^Ibk0P2U
XM440;FM_`D0Y9W:00@0ZKgX0000000000000000402Y_NP408N^k`80Z<3[0`2S_N`20;O2hP030000
002g`^80]l;R00H0]<7T0P2^_nH30:joi`D0Z[kW6@2Y_NP00`000000oooo0?ooo`0d0?ooo`00703o
ool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<000000:Vmj02Y
_NP0?`2Y_NP50:Vli`D0YKOU102S/^<40:6_hPL0ZLC]1@2[_nPD0:Vmj0D0V82g102LP[H50:24]@@0
WH:f0P2ORK`30;>H^`D0]IFf00<0WXFi0;nR^P2oX[X00P2oX[X40;6D^@80ajZm1@2iW;/60;FM_`03
0=6a^@2TVLX0Y9W:00<000004`2Y_NP408N^k`H0Xkg/0P2g`^800`000000]l;S0;O2h`050;C1i0H0
[[oW0P2Z_^L30:Znj1T0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00L0oono07@0M02oool0
oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool01@3oool00`000000ZKgX0:Vmj00o0:Vm
j0D0Yk[W1@2U]nD40:>bh`D0X[CU0`2Ya>d30<;Jj`D0ZkoX4@2Y_NP309n9_0@0V82g102LP[H50:24
]@@0WH:f1@2cV;/50;FE]PH0_j:j0P2aU;T30<NZ_@@0^Ibk0P3=[k/40;FM_`040=6a^@0000000000
00000080Y9W:0P31[<@C0:Vmj0@0S;3^1@2S_N`20;O2h`040000002g`^<0]l;S0;O2h`80]<7T0`2d
`^@50:joi`H0Z[kX602Y_NP00`000000oooo0?ooo`0c0?ooo`00703oool01P3ooml0W4P007Boo`3o
ool0gia8001d_`H0oooo00<000000?ooo`3oool01`3oooln0:Vmj0<0Z;cW1@2W^^L40:Fgi@D0WjoS
1@2R]>D60<;Jja<0ZKgX1@2ORK`409R0]`D0W8:f102PQ;D209f2]P<0[YW11@2cV;/30;FE]P80_:O5
1@2oX[X00`2aU;T0ajZm0<NZ_@030<NZ_@80^Ibk0`3=[k/20;FM_`<000000P3A/KT20:BIbP@0`Jc4
4`2Y_NP408b`kPD0WkW[0P2g`^<00`000000]l;S0;O2h`060;C2i0D0[KoW1@2Z_^PI0:Vmj0030000
003oool0oooo0380oooo000M0?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo
0?ooo`080?oooc/0ZKgX1P2X_>L40:Nji`D0XK7T1@2O[n<20::di@@0/m?a502Y_NP40:BIb`@0WhVl
1@2HP;L409b2]P@0X8Be1@2^VL450;>H^`80]IFf0`2lYlD50;nR^PH0ajZm00<0^Ibk0<f_^`3=[k/0
0P3=[k/2000000030;FM_`3A/KT0dK6i0080dK6i00<0Y9W:0<6/a031[<@00`31[<@D0:Vmj0@0Sk;^
1@2O^N/20;O3h`030000002g`n<0]l?S00<0]<;T0`2d`nD50:foi`D0Z[kX602Y_NP00`000000oooo
0?ooo`0b0?ooo`009`3oool00`000000oooo0?ooo`0:0?oooc`0ZKgX1@2X_>L40:BfiPD0XK7T102O
[n<40;?Cl@<0^<gZ502Y_NP30:BIb`D0WhVl102HP;L409b2]P80X8Be0`2YV<D40:jI`@D0/iRk1P2l
YlD30;nR^P80`[;;1@37Z[d20<f_^`<0000000<0cJnk0;FM_`3A/KT0103A/KT60<6/a0030=Bi_`2Y
_NP0ZKgX0180ZKgX102?/^h50:2gj@030;O3h`000000]l?S0080]l?S1P2d`nD50:foi`D0Z[kX602Y
_NP00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`0;0?oooc`0ZKgX1@2W^^L4
0:BfiP@0XK7T1P2U^^P60;S=jQ<0ZKgX102TVL/409n9_0@0V82g102LP[H50:VHa@D0[YW10`2cV;/2
0;N]c`D0_:O50P2oX[X30<:bb`@0ajZm0`0000040<f_^`H0dK6i00<0eKZo0<6/a031[<@00P31[<@3
0=Bi_`@0ZKKR3`2Y_NP508nbkPD0X;OY00<0]l?S0000002ga>@00P2ga>@50;C3i@H0[KoW0P2Z_^P3
0:Zmj1P0ZKgX00<000000?ooo`3oool0<03oool002L0oooo00<000000?ooo`3oool0303ooolg0:Vm
j0D0Z;cW1@2W^^L40:BfiPD0W[3T0`2U^^P30;gKkP@0^<gZ502Y_NP30:BIb`@0WhVl102HP;L50::E
a`@0ZIS51@2^VL420;>H^`<0]jg?1@2lYlD60<:bb`<000000P36]l`40<f_^`80cKW7103A/KT20=Fj
_`<0`Jc4103D^Kl00`3N`[`0ZKKR0:VfhP020:VfhPl0ZKgX1@2?/^h40:2gj@80]lCT00@000000;O4
i02ga>@0]lCT1@2c`nH50:foi`D0Z[gX602Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool20000
00h0oooo=`2Y_NP50:Rli`@0Yk[W1@2O/N@509j`i0H0_M_^5`2Y_NP40:BIb`<0WhVl1@2JS/H40::E
a`D0ZIS5102^VL460;N]c`<0_:O50P2i^]T20<:bb`<0000000<0ajZm0<Jgc036]l`00`36]l`20<f_
^`<0cKW70`3A/KT40=Fj_`030<6/a03D^Kl0e;Vo0080e;Vo0P3N`[`20:VfhP<0//3U3`2Y_NP408nb
kPD0XkOW0P2ga>@010000000^<GT0;S5i02haN@40;?3iPH0[;oX102Z_NPI0:Vmj0030000003oool0
oooo02l0oooo000W0?ooo`030000003oool0oooo00h0oooo=`2Y_NP40:Rli`D0XkKV1@2O/N@209j`
i0<0ZKgX0`2mfnh30;34j@h0ZKgX1@2UXM4407eb_0<0QWVn102AQL<409Z>aPD0XYG7102YV<D20:jI
`@<0/K3G1@2g[Ll20;bWa@80^K[I0`0000030<:bb`H0a[O<00<0cJnk0<fia`3=^LL00`3=^LL00`3A
/KT0eKZo0=Fj_`030=Fj_`@0e;Vo0`3N`[`60;;0i@l0ZKgX102</>h50:>gi`030;S5i0000000^<GT
00<0^<GT0P2c`nH20;;3i`D0[;oX1@2Z_NPI0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`03
0000003oool0oooo00l0oooo=`2Y_NP50:Jji`@0XkKV102O/N@60:Vmj0H0/<CY3P2Y_NP40:FQd@@0
OG:l1026NKh30965``D0VXk6102RULL40:VHa@H0/K3G102g[Ll0102i^]T000000000000000020;Vj
f@80`[;;0`2k_md50<Jgc0H0cKW71@3E^[l20=C0aP<0e;Vo0`3N`[`00`3Sb;d0//3U0;;0i@030;;0
iA00ZKgX102</>h20:>gi`<0Z;[V00<0^<GT0000002haN@00P2haN@50;;3i`80[;oX0`2[_nP50:Zm
j1P0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX02l0
ZKgX1@2X_>P50:Jji`<0XkKV1@2N/>D30:Vmj0<0`m[Z1@2`a>T?0:Vmj0<0YJ7A101mL[`408Ii_P@0
THG3102JS/H40::Ea`D0[;;L1@2a/=L20;6oi0<000001@2i^]T60;^og@80a[O<0`2o`=X40<fia`80
b<3B0`3E^[l40=C0aP040=Bi_`3N`[`0g/:l0=k2_0<0hlRm0P2b`>D30;;9j`l0ZKgX102</>h60:Rj
iP030;S5i0000000^<KU0080^<KU102b`nL60:^oj0D0Z[gX602Y_NP00`000000oooo0?ooo`0]0?oo
o`009P3oool2000001<0oooo00<000000:Vmj02Y_NP0;`2Y_NP50:Rlj080Y[[W0`2R]nL409jai@@0
W[3U1P33f^XD0:Vmj0<0YJ7A101mL[`408Ii_P<0THG3102JS/H50:R`gPD0[;;L0P2a/=L0102/`n/0
00000000000000040;6oi080^K[I0`2_a>X50;^og@H0_l3J0P3=^LL40<S0dP030=Fj_`3D`<H0e<36
00<0e<36103N`[`30>?8_@H0//W[3`2Y_NP408N^k`D0Z;[V0P2ha^D00`000000^<KU0;S6i@050;32
i`D0ZkoX1P2Z_NPH0:Vmj0030000003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018
W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo
0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000:Vmj02Y_NP0;`2Y_NP40:Rlj0H0X[OW
102N/ND50:Vmi`<0`m[Z0`2`a>TB0:Vmj0<0YJ7A101mL[`408Ii_P@0THG30P2JS/H20:>[g0D0Z;3N
102//]`00`2/`n/00000000000030:c3j`@0/KoT1P2_a>X20;^og@<0[lCZ1@2o`=X60<S0dPD0e<36
0P3CaL`20=k2_0@0hlRm00@0im2o0;;9j`2bbN/0//W[4P2Y_NP408N^k`D0[[kU00<0^<KU0000002g
anH00P2ganH50;32i`D0ZkkX1@2Z_NPH0:Vmj0030000003oool0oooo00X0oooo00D0gia800000000
0000001809cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00<0omnL
04P0001d_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo
0?ooo`0D0?ooo`030000002Y_NP0ZKgX02h0ZKgX1@2V^nP50::gi`D0WK3V1@2Y_NL60;34j@h0ZKgX
1023R=0206i]`@@0OG:l1026NKh40965``D0Xj_L102X/=h20:W5k@<000001@2/`n/50:O7l@/0[lCZ
0P2o`=X30;C3i@@0b<3B0P31`m/30=C0aP@0dlG<00@0g/:l0>?8_@3Sb;d0hlRm0`3Wd;lE0:Vmj0@0
QZCX102^_^D20;O7iP040000002ganH0]lOV0;O7iPD0[/7X1@2[_^PM0:Vmj0030000003oool0oooo
00P0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0
_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3oool0
1@3oool2000001H0oooo;@2Y_NP50:Rlj0@0Y[_X1@2M/^L509f`iP80ZKgW0`33dnH30;34jA00ZKgX
1023R=0306i]`@<0PH791@2@Tm8409bQf@D0Xj_L0P2X/=h3000000@0ZLG]1@2Tb_<50:O7l@D0XlKb
1@2_a>X60;C3i@80b<3B1031`m/00`3D`<H0dlG<0=?5c0030=?5c0@0hlRm0`3Wd;l00`3[fL40ZKgX
0:Vmj00B0:Vmj0@0QZCX0P2^_^D30;?3i@80]lOV00@000000;G6i`2ea^L0]LKW1@2^`NP50:Znj1d0
ZKgX00<000000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3ogi`0B4RL
0=ooo`3oool0oono07@0B02Lgol01@3oool00`3ookl0M00004RLg`070?ooo`030;md001d_ol0oooo
00D0oooo00<000000?ooo`3oool05`3oool/0:Vmj0D0Z;cX102S^>P509fbi`@0WK3V1P33dnHC0:Vm
j0<0PhS@0`1^KL440861b@@0T9?B1@2LXMT30:>[g0<00000102Ya>d40:G<m0D0Y<[c1@2OaoD50:?6
lPD0Xl?`1@2d`nD60<73f`D0dlG<0P3Bb=020>?8_@<0im2o0`3[fL4C0:Vmj0@0QZCX1P2c`nD00`2e
a^L000000;G6i`030;G6i`80[/7X0`2]`>P40:Znj1d0ZKgX00<000000?ooo`3oool0303oool00`2o
M000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01P3oool0
2`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?oo
o`3oool0603oool/0:Vmj0D0Yk_X102S^>P409fbi`D0YkWV0`33dnH30;S=jQ80ZKgX1023R=0206i]
`@@0PH791@2@Tm8409bQf@<000000P2X`^`30:W4k@<0Z<cc102Uc?@50:3:m@D0WlOe1@2K`o@50:?3
l0D0Zl7Z1031`m/20;_3h0<0dlG<103Bb=00103Sb;d0im2o0>O@_`3Wd;l30>_I`@030>[Yc02Y_NP0
ZKgX00`0ZKgX1@2N^N/409:Vh`<0/l?U0`2ganH00`2ea^L000000;G6i`020;G6i`D0[L3X0P2Z_^P3
0:Zmj1d0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0
703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02L
gol0oono07@000030000000307Boo`3oool0oooo00@0oooo0P00000K0?ooob`0ZKgX1@2W^nP40:>h
j0@0Vk7W1@2W^NH60;S=jPh0ZKgX101^QMT00`1PJ/D0PhS@08>8d00306i]`@@0PH79102@Tm801@2V
^nP00000000000000000Y[_X00D0Z<;/1P2Xc?<50:C<m@@0X<[e1@2KaOD509_3m0D0W;oa1@2[`NX2
0<73f`@0^l?P00<0dlG<0=;8d03Bb=000`3Bb=030>O@_`<0jmW10`3ZjL`>0:Vmj0D0W[W[102BY^<6
0;O7iP030;;5j0000000//GX0080//GX102]`>P60:Zmj1d0ZKgX00<000000?ooo`3oool01@3oool0
0`3ookl0M000000000020000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q8
09cOo`090?ooo`030000003oool0oooo01/0oooo;02Y_NP40:Nkj0D0W[CX102K/NL30:NiiP@0_LWT
4P2Y_NP306j5f@<0H6[50`1^KL440861b@80X;3T0`0000050:Jkj0D0Zlca0`2Xc?<30:S=l`D0Y<ce
102Nao@509_5m@D0V;oc1@2L_o440:_1jPH0^l?P1@3Bb=020=C=dP80im2o0P3[fL430>[Yc080eO[Q
3P2Y_NP409jij`D0Xk?T0`2ganH30;O9j0040;;5j0000000//GX0;;5j0D0ZkoX1@2Z_NPM0:Vmj003
0000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool000P0oooo00H0oooO09a8001d_ol0
oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0B01809cOo`3oool0_g@007Boo`T0
oooo00<000000?ooo`3oool0703oool[0:Vmj0D0Y;[X1@2N]>P409^ai`D0_LWT0P33f>TB0:Vmj080
KXGI101PJ/D207f6d@<0TYkL0`0000040:2`i080Y[_X0`2/bNl50:_<l@H0Z<gc1@2SbO<409k7m0D0
V/7c1@2H_o<409bol@D0Y;k/0`2k`n030;S3hP<0d/S@103DcM820>_I`@<0j^W<103En^4>0:Vmj0@0
S:o]1@2S/n@60;O9j0040000002baNP0[l?X0:o3j0D0ZkoX8P2Y_NP00`000000oooo0?ooo`050?oo
o`030;md001d_ol0oooo01l0oooo00090?ooo`050?oo_`1d000000000018W03Oool01@3oool01@3o
gi`0B000000000000000M;oo0080oooo00H0gia800000000000000000000M02oool50?ooo`030000
003oool0oooo01d0oooo9`2Y_NP50:Rlj0@0Y;[X102N]>P50:6eiP<0_LWT1033f>T>0:Vmj0@0KjKb
0P1^QMT3061Za@<0OHKA0P00000309:Ng0@0X;3T1P2/bNl60:c>l@D0Z<[a1@2SbO<509k3lP@0V/7c
1@2G^o0409Vkl0D0Y;k/1P2h`n850=C=dP80f]?B0`3ZjL`50=Gjh@l0ZKgX102<[nd20:>ci0<0[l3V
1@2gbNP00`2_`nP000000:o3j0020:o3j0D0Z[kX8@2Y_NP00`000000oooo0?ooo`050?ooo`060=nL
B000000000000000000007@0_ooo703oool002D0oooo0P00000O0?ooobL0ZKgX1@2X_>P40:2gj@@0
V[;X1@2Q]NH60<?Hj@l0ZKgX0`1_Y_800`18G/H0KXGI061Za@02061Za@<0000000<0OHKA09:Ng02B
W]`00P2BW]`50:_3j`<0[<W_0`2`cNl30:c>l@<0[L__1@2Xb_450:C5l0D0W/?b102J_?0509Nkl0@0
VK_`1@2R^n/30;S3hP<0^<?S0`3DcM830=[CdP80h]g@0P3En^4C0:Vmj0@0S:o]1P2_`>H50;G9j@03
0:o3j0000000[L7X0080[L7X1@2Z_^PQ0:Vmj0030000003oool0oooo02H0oooo000U0?ooo`030000
003oool0oooo01l0oooo9`2Y_NP50:Jkj0@0X;OY102J/^P60;6oi0D0ZkoX3P2Y_NP406nVlP0504QN
aP00000000000000001PJ/D0101mQ]440:>gi`D0Zl?[1P2`cNl60:g;k`D0ZLK_1@2TaO0509nnk`@0
V[c`102G^o0509Rgk@D0X[_[1P2h`n<0103DcM80f]?B0=[CdP3Jdm830>;Md080k>_;00<0kORo0:Vm
j02Y_NP0302Y_NP50:Rlj0@0RicN0`2_`>H30;K8j0@0]LWY00<0[L7X0000002]`NP00`2]`NP20:Zn
j0<0Z[gX8@2Y_NP00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P0?ooobD0
ZKgX0P2X_NP50:Jkj0@0X;OY102K/^P40;6oi080a<WN1@2[_nP>0:Vmj00501i<a000000000000000
0018G/H0101cQ=D409:Sh0@0XkOW1P2ab^`50;7<k@<0[L__0`2^b>d50:W6k`D0Y<3]1@2O_^l409Zh
k@@0UkO^1@2H]nd50::ij@D0^<?S103Jdm820>;Md080k>_;0`3]n;l>0:Vmj0D0Z;cX102;W=h50;K8
j0D0//KY00<0[L7X0000002]`NP00P2]`NP50:Zmj240ZKgX00<000000?ooo`3oool09@3oool002@0
oooo0P00000S0?ooob80ZKgX1@2X_NP40:Jkj0D0W;CY102K/^P20;6oi0@0a<WN402Y_NP300000080
7Tc40P18G/H407>4e@D0TZ?P0P2S]nL30:k4jP<0/L[/0P2dbn/50;7<k@H0[/S]1@2Y`^`50:C0k@D0
Wk[/102J^>d409NgkPD0VKC[1@2R^NT20;S3h`<0_<KR0P3Jdm830>;Md0040>c[b`3]n;l0kORo0>gh
_`80c^kZ3P2Y_NP40:Rlj0D0X[;T0`2fb>P20;O;j@D0//KY00<0ZkoX0000002[_nP00P2[_nP40:Zm
j280ZKgX00<000000?ooo`3oool0903oool002@0oooo00<000000?ooo`3oool08`3ooolR0:Vmj0D0
Z;gX102S^^T509bdj@@0Vk;X1034bMh20<;@i@`0ZKgX0`0000030:Vmj0<07Tc400<0FWOE04QNaP1c
Q=D00`1cQ=D409:Sh0H0[/CZ1@2dbn/50;;8j`<0[/S]0`2^`nX50:W2k0D0Y;cZ1@2O^^`309Zhk@D0
V;?[1@2I]>/40::ij@H0_<KR0`3RgM020>c[b`80kORo103>k^X>0:Vmj0@0T:KT1@2R/^@50;O;j@D0
[/?Y00<0ZkoX0000002[_nP00P2[_nPV0:Vmj0030000003oool0oooo02<0oooo000T0?ooo`030000
003oool0oooo02@0oooo8P2Y_NP50:Nlj0@0Xk[Y102L]>T50:>gi`80a<WN1032d>D80:Vmj0<00000
102Y_NP204jDl0<07Tc40P1JMmD407>4e@D0XkOW0`2^a>X30;C8j@<0]<_[0`2eb>T40;;8j`H0[/?Z
1@2Y_^P50:BljP@0Wk[/102K]>T509Rcj`@0VKC[1@2T^NP30;c6hP@0a<kQ0P3/jl/00`3]n;l0c^kZ
0<k^jP040<k^jPl0ZKgX102@Y^@20::bi0<0/LCX0P2gbnT30;?9jPD0[/?Y00<000000:Znj02Z_^P0
0P2Z_^PU0:Vmj0030000003oool0oooo02<0oooo000T0?ooo`8000009P3ooolR0:Vmj0D0YkcX102O
^>X409VcjPD0XkOW1P32d>D40:Vmj0<00000202Y_NP204jDl003025Ec00NC<@07Tc40080FWOE102:
Wn850:>gi`H0]<SY1P2eb>T40;;4j0<0[/?Z0`2^_nH50:Vnj080Y;cZ0`2T^>L40:2fj0@0VkCY102H
/n/509^bj0D0Y;WX1@34c^420=;Lh080hO7I0P3PoKhC0:Vmj0@0T:KT1@2aa>P60;?9jP80[/?Y0`2/
`>P010000000Z[kX0:Znj02Z_^PV0:Vmj0030000003oool0oooo0280oooo000S0?ooo`800000:03o
oolR0:Vmj0D0Y[cY102O^>X409VcjPH0/;gT1@2dbNX00`2Y_NP000000000000;0:Vmj080CYC`0P0Q
EL`0100NC<@0FWOE05Yge@1JMmD408ZOhPD0[/7X0`2db>T30;K7i`<0]LSY0`2eaNH40;;4j0H0[[oV
102Y_^P60:Bhi`@0X;KX102L/NH409Vai`D0Vk;X1@2[_NL30<C>h@80d]cP0P3QlMT20>3m_P80eO[P
3P2Y_NP509^bi`@0UZGP0P2aa>P30;K<jPD0/lWZ1@2/`>P00`2Z_^P000000:Zmj0020:Zmj2H0ZKgX
00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@00000000004RL0=ooo`3oool0omnL04P0
M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo00<000000?ooo`3oool0:03ooolQ
0:Vmj0D0Y[cY102O^>X509VcjP<0/;gT0P2n`mh20;C9jP<000003P2Y_NP01000@l00CYC`025Ec00Q
EL`305Yge@D0W;7W1@2^`NP60;K7i`H0]LGV0P2ba>P20;;0i@D0[[oV1@2Y^ND50:Bhi`D0X;;U102L
/NH409Vai`D0W[?W1@2[_NL30=;Lh080hO7I0P3PoKh40=Gjh0h0ZKgX1@2K/^L309JUh0H0]/cZ1@2_
a>T40:c0j080Z[gX00@000000:Zmj02Z_NP0Z[gX9@2Y_NP00`000000oooo0?ooo`0Q0?ooo`00303o
ool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo00H0oooo00<000000?ooo`3oool0:P3ooolQ0:Vmj0@0Y[cY1@2L]n/509VcjP<0_/?N0`00000B
0:Vmj0040013`00QEL`08EG<025Ec0<0LI3R1@2L/NL20:k1j0<0/lCV0`2fanL30;O5i0D0]LGV1@2b
`>D50:fkh`D0ZKWU1@2T]>@50:2bi@<0W;7V1@2K[nD509jci`80ZkgW102eanP20>7af@030>3m_P3E
n^00eO[P0080eO[P4@2Y_NP409^bi`@0[;oX0`2fc>X30;C;j`@0[lCY1@2Z_^P00`2Z_NP000000:Zm
j0020:Zmj2H0ZKgX0P00000Q0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
203oool00`2oM000M;oo0?ooo`050?ooo`800000;03ooolQ0:Vmj0@0Y;_Y1@2L]n/409ffj@<00000
00@0_/?N0<C6f`34a]/0a<KK4P2Y_NP010005Yh0;6WI025Ec00QEL`3076@hP@0W;7W1P2ca>H60;O5
i0D0]L7S0`2b`>D20;6lhPD0[K_S1@2Y]^850:Bdi0@0X;;U102M[n@509^_i@@0W[?W1@2eanP20<GK
jP80e?WR0P2jljL?0:Vmj0D0Y;GU102AW]`40:boj0H0]<_[102/`NT50:Znj0030:Vmj0000000ZKgX
02P0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0/0?oooa`0ZKgX1@2X_NP4
0:Bkj@D0VKG/0`00000209ffj@030;k3gP34a]/0a<KK00<0a<KK4P2Y_NP00`005Yh0;6WI02aYf@04
076@hP@0Yk_W0`2ca>H30;K3i0<0]lGT0`2g`^850;G1h`D0/KcR0`2]^n<20:fgh@D0ZKKR102T]>@5
0:6`hP@0WJoT102K[nD50:Bhi`<0]LOX0P35fnX20=CihP040;[cY`3>k^X0c^kZ0<k^jPl0ZKgX102T
]ND4096Ng0D0]Lc[0`2dbn/30;36jP@0[<7Y1@2Z_NP00`2Y_NP000000:Vmj00W0:Vmj0030000003o
ool0oooo01l0oooo000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oO
W01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02d0oooo7@2Y_NP40:Rm
j0D0X[[Z0`0000000`2I]N`0WKKY09ffj@0209ffj@D0a<KK0P32aMd>0:Vmj0@0Wk[[00<001JN02aY
f@0/JMT01024Y>T40:Nki`H0]/?T1P2g`^820;G1h`<0];gQ1@2a_>850:fgh@@0ZKKR1@2T/N450:6`
hP<0WJoT1@2N/>@50:Bhi`<0aM_Z0`3DnN850<k^jPl0ZKgX102T]ND2096Ng080ZKgX1@2ec>/50;36
jPD0ZkkX1@2Z_NP00`000000ZKgX0:Vmj00W0:Vmj0030000003oool0oooo01h0oooo000<0?ooo`07
0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d000000000080000000<0M;oo
0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?oooad0ZKgX102W_>P01@2R^^X0000000000000
0000X[[Z00<0VKG/1@2T^NP30<C6f`@0`/GM3P2Y_NP409njj`03000FWP0eNn@0;6WI00@0Q:CY1@2]
_nH30;K3i0L0]l;R1P2d_N450;2ig`@0[KOQ1@2X/]l50:Bah@D0XJkQ0`2O[^8509j`i0H0[/GZ0`3D
nN82000001<0ZKgX102T]ND50:Vmj0D0]<c/0`2`a^X20:c1j@D0ZkkX1@2Y_NP00`000000ZKgX0:Vm
j00W0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`030?oog`2LB4P0W=oo00T0oooo0P00000a0?oooad0ZKgX00@0YkcX000000000000
00001@2O^N/309Nek0D0Y;WX1P32aMd?0:Vmj0<0Wk[[00<000F7000FWP0eNn@01@2@/>`50:foiPD0
]l;R1@2g_^030;Bmh@<0/k[N1@2`^Ml40:bdgPD0Z;;O1@2U[ml40:6^h@@0WjkR1@2T^>L30:k5jP@0
_n;a4P2Y_NP50:B_h0@0TYgK0P2Y_NP30;C=k0D0]<c/1@2/`NT20:^nj0<0Z[gX1@2Y_NP00`000000
ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`060?oog`2LB000M;oo0?ooo`3O
W4P007Bo1@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0340oooo6`2Y_NP20000
00D0YkcY102O^N/309Nek0D0ZkcV0`32aMd30;o4gPh0ZKgX102O^^/00`2;1`00=G_T03Eki005092`
k0D0/<3V0`2g`^820;K0h@D0]kkP1P2c^]h20;2ig`<0/;KM102/]=h20:Rbg`<0Z;3N1@2U[ml30:6^
h@D0X[7S1@2T^>L50;oRl@030=Gjh@2Y_NP0ZKgX0140ZKgX102T[n0409:Mf`H0]<g/1@2`a^/40:c1
j@D0Z[gX1P2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo01`0oooo000=0?ooo`05
0?oo_`1d000000000018W03Oool01@3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<0
00000?ooo`3oool0<P3ooolG0:Vmj0<000000`2Y_NP50:Nlj@<0WkW[1@2G]^d40:^liPH0_lCN3P2Y
_NP409njj`0308/7000aQ>X0<HCZ00D0UKO_1@2``>H50;K0h@80]kkP0`2f_=h50;>jgPH0/;KM0`2/
]=h60:R`gP@0YJoO102S/>450::ah`80Y;SW0`2^c>l30;oRl@<0eO[Q4`2Y_NP30:B_h0D0Z/3Y0`2d
cN`30;?<k0@0/<K[1@2[_^P40:Zmj0H0ZKgX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?oo
o`0K0?ooo`008P3oool2000003@0oooo4`2Y_NP3000000L0ZKgX0P2W_>T30:Jlj@<0WKW/1@2G]^d4
0;2ni@<0_lCN0`2m`]hC0:Vmj080<HCZ1@2E]nl50;30iP@0]/3Q1P2f_=h20;>jgP<0/kSM1@2`]]d4
0:bbg@D0Z;3N1@2U/=l40:>`h@@0X[7S1P2^c>l00`2fm?<0eO[Q0=Gjh@0E0:Vmj0@0V:GN1@2Z`>T5
0;?<k0D0[<7Y1@2[_^P:0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06`3oool0
0280oooo00<000000?ooo`3oool0=03oool?0:Vmj0<000002P2Y_NP60:Jlj@<0WKW/1@2G]nd40;2n
i@H0_L;N4`2Y_NP201N1i`@0UKO_1P2``>H20;K0h@80]KkQ1@2f_=h60;>hg@80/;KM0`2_]=d40:bb
g@80Z;3N0`2X/Mh50:F`g`<0Xk3Q1@2W_nX30:k<k`80]_Cc00<0eO[Q0:Vmj02Y_NP03`2Y_NP30:Vk
iP@0WJCJ102HYMh50;?>kP<0/lc/0P2_aN/50:c1j@D0Z[gX2P2Y_NP00`000000ZKgX0:Vmj00V0:Vm
j0030000003oool0oooo01X0oooo000R0?ooo`030000003oool0oooo03D0oooo00<000000:Vmj02Y
_NP0202Y_NP3000000h0ZKgX1@2V_>T409bik0D0UkO]0P2`_^D30;:oi0<0_L;N0P2l`=`C0:Vmj080
5h7W102C_?<50;30iPD0]KkQ1@2d^mh50;>hg@H0[kCM0`2//]d60:RagP@0YK3O102V^NH50:NojP80
]_Cc4P2Y_NP60:VkiP<0WJCJ0P2HYMh30:g6k0D0/lk^1@2_aN/50:Znj0@0Z[gX2`2Y_NP00`000000
ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00`0oooo00<0omnL04P0M02oool00P3oool01@3ookl0
M00000000000B9`0gooo00@0oooo000R0?ooo`030000003oool0oooo03L0oooo1P2Y_NP300000180
ZKgX1@2U_>T409bik0@0UkO]1P2b_n@50;c0g1<0ZKgX00<004?0001SaP2C_?<00`2C_?<50:k2j0<0
]KkQ0P2c_n<50;BkgPD0/KON1@2_]=d40:^cgPD0Z;7N1@2W]n@40:JiiP@0[^;i5@2Y_NP50:VkiP<0
WJCJ1P2]a^`50;7;k@D0Zl3Y1@2Z_^P>0:Vmj0030000002Y_NP0ZKgX02H0ZKgX0P00000<0?ooo`0:
0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0oooo000Q0?ooo`800000>P3o
ool20:Vmj0<000004P2Y_NP50:Rmj0@0YKcY1@2K^Nd309NhkP<0/[oT0`2b`>@30;c0g080_KoK4`2Y
_NP204jDl004001SaP27_oT0Qkoi08Non@D0[/;X1@2c_n<30;BkgP80/[cQ1@2a]mh50:jfg`@0Zk?N
1@2Y]n@50:Ngi0D0ZMGg00<0//W[0:Vmj02Y_NP05@2Y_NP509BKf0<0XK?U0`2]a^`30;;?kP<0/L_]
0P2]`nX50:_0j@D0Z[gX3P2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00X0oooo
00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool0
0`000000oooo0?ooo`0h0?ooo`<000005P2Y_NP50:Rmj0@0YKcZ1@2K^Nd309NhkPH0//3T00<0_<3L
0;fof`2m_m/00P2m_m/F0:Vmj0<0Qkoi1@2Wa_050;>oh`D0/[cQ0P2a]mh30;2lhPD0[[KO0P2[/mh2
0:^ji@D0ZKOT0P2W]n@30:S?m080ZMGg102bbN/B0:Vmj0D0YZSG102DVmP40:6ci@H0//o^1@2]`nX2
0:_0j@<0Z[kX102Z_NP?0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool02P3oool0
2`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`03
0000003oool0oooo03H0oooo0P0000030?oooaL0ZKgX1@2X_NP40:FljPD0VkW]0`2G^>l50;;0i0D0
_KoK602Y_NP205nlo@D0YlK`1@2^aN/40;:lh@H0/;cR102^]]l50:^ji@@0ZKOT1@2Xco@00`1ZgMH0
ZLK^0:Vmj00B0:Vmj0@0ZKCP1@2VZ=L309BKf0H0/<g_1@2_b>`40:g3jPD0Z[kX0P2Z_NPA0:Vmj003
0000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool02@3oool02`3ogi`0B01d0;ooo`3oool0okmd
0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`800000=03oool3000000H0oooo5`2Y
_NP50:Rmj0@0YKcZ1@2K^Nd309Nhk`D0/<3V0`2m_m/30<2ofAL0ZKgX00<0KjKb0022`P2Ac_d0102A
c_d50:k5j`@0[/C[1@2`_>850:c0j0@0Zk[U1P2Wco@206[MeP80ZLK^5@2Y_NP40:Vdh0@0YZSG102Y
`n`30;3=k`<0/Lc^102_b>`50:^oj0@0Z[kX502Y_NP00`000000ZKgX0:Vmj00V0:Vmj0030000003o
ool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`03
0?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3ooolH0:Vmj0D0Z;gX102U_>X409^i
k@@0U[W`1@2``>H60<2of@@0ZKCQ5P2Y_NP4097>o@D0WM;j102^a>/50:[;l@@0[<3X1P2UdoP205WC
d@@0X;[[5`2Y_NP40:Vdh0D0X[CU102Y`n`60;7<kP@0[<7Y1@2[_nPH0:Vmj0030000002Y_NP0ZKgX
02D0ZKgX00<000000?ooo`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d
0;ooo`3oool0omnL04P0M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0
omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?oo
o`030000003oool0oooo02d0oooo0`00000>0?oooaL0ZKgX1@2X_NP50:FljP<0W;[]102F^O050:_0
j@<0`;oI0`32`MT40:VdhAL0ZKgX0`0a]><509gBnP@0V=Wm1@2Zbo4509[Lo@80<KNa7`2Y_NP509^T
f`D0X[CU1@2`co050:g4j`@0[<7Y1@2Z_^PH0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?oo
o`3oool01P3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0
oooo00030?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00
000B0?oooaL0ZKgX1@2X_NP50:FljP<0W;[]1@2F^O040:_0j@H0`/7I102a/mXJ0:Vmj0H0<kWJ0`2H
fOd6073Km1l0ZKgX0`2WY]D309nPe@D0VjCK1@2^c_420;3?l0<0[/S]102]a>/90:Znj1P0ZKgX00<0
00000:Vmj02Y_NP08@2Y_NP3000000030?ooo`000000oooo00P0oooo00<0omnL04P0M02oool00P3o
ool01@3ookl0M00000000000B9`0gooo00@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`050?ooo`030;md0018W=l0oooo00L0oooo00<0_g@007Boo`3oool0103oool2000002T0
oooo0`00000F0?oooaL0ZKgX1@2X_NP50:Jlj@<0WK[]1@2F^O040:>ok@<0`/7I0`2n`mh40;6cfPD0
ZKcV@02Y_NP50:NVe@@0Wj3E0P2KY=/30:_9l0@0[/ka1P2^b>d40:^oj@D0Z[kX702Y_NP00`000000
ZKgX0:Vmj00L0:Vmj0<000001@3oool00`000000oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL
0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo
00@0oooo00<000000?ooo`3oool09@3oool3000001X0oooo5`2Y_NP30:Rmj080ZKgX1@2V_>T309fj
k@D0U[[`102S_nd60;k3gP80/K?J0P2l^mP50:VliS/0ZKgX1@2XZ=L50:NVe@<0Wj3E1P2[bO050:o;
k`D0Zl7Y102[_nTQ0:Vmj0030000002Y_NP0ZKgX01P0ZKgX0`0000080?ooo`030000003oool0oooo
01D0oooo00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0
W=oo0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool0
8P3oool3000001h0oooo702Y_NP50:Nlj@<0Wk_/1@2F^_0409bnl0D0_/?N1@2l^mP50:V[f3L0ZKgX
102XZ]P50:RXe`@0YjKE1@2W`^d50:k>l@80[l__0`2/`n/40:_1j@D0Z[gX8@2Y_NP00`000000ZKgX
0:Vmj00C0:Vmj0@00000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@000<0000000<0M;oo
0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000008P3ooolL0:Vmj0D0YkcY0`2O^n`5
09Rkl0@0W;k`1@2aa>P30;bkf080`/?J1@2YZmP40:VagRh0ZKgX2@2XZ]P40:RXe`D0Y[_X0P2W`^d3
0:g?lP@0[/ka1P2/`n/40:Znj0D0Z[gX802Y_NP00`000000ZKgX0:Vmj00?0:Vmj0040?ooo`000000
000000000100oooo00<000000?ooo`3oool0503oool000<0oooo00L0oono07@0M02oool0oooo0?oO
W01807@0_ooo00H0oooo00L0oono07@0B02Lgol0oooo0?oog`2LB4P0W=oo00T0oooo0P00000N0?oo
o`8000009P3oool00`000000ZKgX0:Vmj00I0:Vmj0@0YkcY102R_>`509Rkl0@0Ukgb1@2aa>P50<;3
fP80ZJ_H0`2l^mP40:VagPD0ZKSS9@2Y_NP40:RXe`P0Z:[H1@2V]^@40:Jkj0H0[Lob102/aN`30:c3
j`L0Z[kX9@2Y_NP00`000000ZKgX0:Vmj00:0:Vmj080oooo0`00000C0?ooo`030000003oool0oooo
01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo203oool01P3o_g@004RL0=ooo`3o
ool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3ooolJ0:Vmj0D0YkgY102R_>`509^kk`@0Ukgb
1@2R`_040<;3fPH0_;_H0P2Y/Mh20;>ae`T0ZKSS302Y_NP30:VkiP@0ZKgX1@2Y]>040:Vmj0D0YjKE
102XZ=L40:RZf0@0YkCR1@2V]^@50:_?l`D0[<O^102/aN`70:Znj2P0ZKgX00<000000:Vmj02Y_NP0
1`2Y_NP4000001H0oooo00<000000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL
0=ooo`040?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo
0?ooo`040?ooo`030000003oool0oooo01L0oooo0`00000^0?oooa/0ZKgX102W_NT40:Blj`D0Vk__
102F_?850:;2l0@0/LKY1@2l^mP50;>ae`D0[:[E102Y^><50:VagP@0ZKgX1P2Y^nH20:Vmj080Z:SG
102Y]>050:NTd`@0YjKE102XZ=L50:Veh@@0YkCR1@2Yc_<50:c9k`@0[<O^1@2Z_nT40:Znj2X0ZKgX
00<000000:Vmj02Y_NP01@2Y_NP2000001X0oooo00<000000?ooo`3oool0503oool001l0oooo00<0
00000?ooo`3oool05@3oool300000380oooo6`2Y_NP40:Rmj0@0Y;c[1@2O_>d409JllPD0V;oc102a
a^T50;c5h@<0/k7G0P2o`md50:bZe@@0[:WE1@2Y/Mh40:RYe`D0ZK_V1@2XZ=L20:Vdh080[jgE1@2W
Y=<30:NVe@D0[;SR102Y]N450:S=l`<0ZLkc0P2[b_050:c9k`@0Z/3Y1@2Z_nT^0:Vmj0040000002Y
_NP0ZKgX0:Vmj08000007@3oool00`000000oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo0`00
000f0?oooa/0ZKgX102X_NP50:Jmj@@0Wkc]102J_?0509Rol`@0WlCb1@2laN450;o3g@80[:[E0`2n
`]d40:bYe@D0/[3F102XZML50:RUd`@0Z:SG102_[MD50:NTd`@0[KgV1@2/^>840:O=l`D0Z<gc1@2[
b_050:[1jP@0Z/3Y<P2Y_NP300000200oooo00<000000?ooo`3oool0503oool001l0oooo00<00000
0?ooo`3oool03`3oool3000003X0oooo7`2Y_NP50:Jmj@@0Xkc[102J_?0509NnlP@0WlCb1@2Vao04
0;o3g@H0_/;M0P2/ZMD20;[4h@D0/[3F0P2XZML20;^kf@@0Z:GC0P2XZ=L30;Jkg@@0[jgE0P2WY=<3
0:g4j`@0[KgV1@2WcO@40:O=l`H0ZL[a102Z`^/40:[1jPD0Z[kX;@2Y_NP3000000<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0<0?oo
o`<00000?P3ooolO0:Vmj0D0YkgY102S_>/409nlk@D0Ukkb102G`?<50:K7l0@0ZLS`1@2n`]d50;[4
h@@0/[3F1@2k^mT30:RUd`H0][_M0`2_[MD60:g4j`80[KgV0P2UcOD50:O=m0D0Z<[a2@2Z`^/90:Zn
j2T0ZKgX0`0000060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0
oooo00<000000?ooo`3oool02@3oool300000480oooo7`2Y_NP50:Nmj@@0Y[gZ102O_>d509fmk`@0
Ul3c1@2I`_@40:W8l0D0Z<Wa102ja>450;;7jP@0^k_I102aa^T50;Jkg@@0Z/W`1@2]a>/50:G=m@D0
YlWa1@2Y`^/40:[2j`T0Z[kX:@2Y_NP4000000X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0C0?ooo`007P3oool2000000T0oooo0P0000160?oooal0ZKgX1@2X_NP40:JmjP@0Y;g[
1@2M_Nl409^nl0D0VL;d102Ja?D50:S9l@@0XlWd102banX50:S;lP@0/LKY1P2Vc?@30:[9l0H0Y<ce
102Vao430:O9l@80ZL7[1@2Y`^/40:Vnj0D0Z[kX:02Y_NP0103oool0000000000000000?0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool0
1@3oool3000004T0oooo7`2Y_NP50:Rmj0@0Z;gY102T_N/50:>mk0@0Vkk`1@2K_o4409[4m@D0VlGe
102SbO@409o9m@D0Z<_b1@2QboD50:;7l`@0X/_e1@2VaO040:K7l@D0ZL7[2@2Y_^PY0:Vmj0040?oo
o`0000000000000001<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`00
7P3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000ZKgX0:Vmj00Q0:Vmj0@0Z;gY
102W_NT50:>mk0D0X[g]102K_o4509g0l@<0VlGe1P2La?@309o9m@H0W/Od102Ra?440:;7l`D0Y/?^
102VaO060:S0j`P0ZKkX:@2Y_NP00`3oool0000000000002000001H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0000000200000540oooo00<0
00000:Vmj02Y_NP09@2Y_NP40:Nmj@X0Y[gZ1@2R_^d40:Bnk0@0Wl3`1@2R`>h409o3lPD0Y<7^102R
a?440:K1k@D0Y/?^102X_nX30:S0j`L0ZKkX:P2Y_NP3000001/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0C0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP09@2Y_NP4
0:Rmj0<0Y[gZ0`2X_NP40:JmjPD0YkgZ102T_^`40:Fnj`D0X/3^102U_n`50:C1kP@0Yko[102V`Nd9
0:RojPD0ZKkX;02Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vm
j02Y_NP09@2Y_NP>0:Rmj0D0YkgZ102W_NT40:Fnj`D0YkkZ102U_n`50:NnjP@0Yko[102X_^T50:Ro
jPD0ZKkX;02Y_NP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04P3oool001<0oooo00<0omnL04P0M02oool02P3oool2000005H0oooo<@2Y_NP40:Rmj0D0
ZKgX102W_NT40:Rmj@D0YkkZ102X_^T40:NnjPD0ZKkX102X_^T50:Vmj080ZKkX:P2Y_NP2000002L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d
0;ooo`0<0?ooo`030000003oool0oooo05@0oooo?P2Y_NP40:Rmj@D0ZKgX102X_^T40:Vmj0D0ZKkX
<@2Y_NP2000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`004`3o
ool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05@0ooooP02Y_NP200000300oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>
0?ooo`030000003oool0oooo05@0ooooN`2Y_NP3000003<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0?0?ooo`030000003oool0oooo
05@0ooooM`2Y_NP3000003L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?oo
o`004@3oool01@2oM000001809boW01807@0_ooo0100oooo0P00001E0?ooog80ZKgX0`00000l0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool00180oooo00@0okmd00000000
07@0_ooo4P3oool00`000000oooo0?ooo`1C0?ooofh0ZKgX0`0000100?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool04`3oool00`000000
oooo0?ooo`1C0?ooofT0ZKgX100000130?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool002X0oooo00<000000?ooo`3oool0D`3ooomU0:Vmj0<00000B03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0140oooo000[0?ooo`800000E03ooomP0:Vmj0040?ooo`00
00000000000004`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;@3o
ool00`000000oooo0?ooo`1B0?oooe`0ZKgX1000001?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool002h0oooo00<000000?ooo`3oool0DP3ooomH0:Vmj0<00000E03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo
0580ooooD`2Y_NP0103oool0000000000000001H0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00300oooo00<000000?ooo`3oool0DP3ooom?0:Vmj0@00000G03oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000a0?ooo`800000D`3ooom:0:Vmj004
0?ooo`000000000000000600oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`00<`3oool00`000000oooo0?ooo`1A0?ooodH0ZKgX1000001T0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool003@0oooo00<000000?ooo`3oool0D@3ooom20:Vmj0<00000
J@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000e0?ooo`030000003o
ool0oooo0540oooo?@2Y_NP0103oool0000000000000001/0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool003H0oooo0P00001B0?ooocT0ZKgX1000001`0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool003P0oooo00<000000?ooo`3oool0D03ooole
0:Vmj0<00000M@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000i0?oo
o`030000003oool0oooo0540oooo;`2Y_NP0103oool0000000000000001i0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool003X0oooo00<000000?ooo`3oool0D@3oool[0:Vm
j0@00000O03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000k0?ooo`03
0000003oool0oooo0540oooo9`2Y_NP300000840oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0?0?ooo`00?03oool200000580oooo8P2Y_NP0103oool000000000000000250?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0
D03ooolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo
000o0?ooo`030000003oool0oooo0500oooo6P2Y_NP3000008d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`00@03oool00`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00440oooo0P00001A0?oo
oa80ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004<0
oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00140?ooo`030000003oool0oooo0500oooo202Y_NP3000009d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?oo
o`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3o
ool004H0oooo0P00001A0?ooo`800000YP3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00180?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00190?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo001;0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001<
0?ooo`800000B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool004l0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00500oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00540oooo0P0000160?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00D`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo0:`0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:h0oooo00@00000
0?ooo`3oool000003`3oool005D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2^
0?ooo`040000003oool0oooo000000l0oooo001F0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0000000?0?ooo`00E`3oool2000003l0oooo00<000000?oo
o`3oool0/03oool00`000000oooo0000000>0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0oooo00<000000?ooo`3oool0[@3oool4
00000100oooo001N0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0Z@3oool40000
01@0oooo001O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0Y@3oool4000001P0
oooo001P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X@3oool4000001`0oooo
001Q0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0WP3oool300000200oooo001R
0?ooo`800000=03oool00`000000oooo0?ooo`2J0?ooo`@000008`3oool006@0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2F0?ooo`@000009`3oool006D0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3oool006H0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool006L0oooo0P00000_0?ooo`030000003o
ool0oooo08X0oooo1000000c0?ooo`00J@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
08<0oooo1000000j0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0
oooo1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo
100000120?ooo`00K@3oool2000002T0oooo00<000000?ooo`3oool0M`3oool4000004H0oooo001_
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0M@3oool3000004X0oooo001`0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0L@3oool4000004d0oooo001a0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool400000540oooo001b0?ooo`800000
8`3oool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool007@0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M0?ooo`030000003oool0oooo05H0oooo
1000001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000
001/0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04h0oooo1000001`
0?ooo`00O03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo0`00001d0?oo
o`00O@3oool2000001P0oooo00<000000?ooo`3oool0A`3oool4000007L0oooo001o0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4000007/0oooo00200?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0?`3oool4000007l0oooo00210?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0>`3oool4000008<0oooo00220?ooo`8000004`3oool00`00
0000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0/0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X
0?ooo`@00000UP3oool008P0oooo0P00000=0?ooo`030000003oool0oooo02D0oooo0`00002J0?oo
o`00RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo1000002M0?ooo`00
R`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000002Q0?ooo`00S03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000002U0?ooo`00S@3oool2
000000L0oooo00<000000?ooo`3oool05P3oool400000:T0oooo002?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04P3oool400000:d0oooo002@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03`3oool300000;40oooo002A0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool400000;@0oooo002B0?ooo`050000003oool0oooo0?ooo`000000
2@3oool400000;P0oooo002C0?ooo`80000000<0oooo0000003oool0103oool400000;`0oooo002E
0?ooo`80000000<0oooo0000000000000P0000300?ooo`00UP3oool200000<@0oooo003o0?oooed0
oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0
oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .48541 Mtetra
.75545 .48541 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .4782 Mtetra
.7793 .4782 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47093 Mtetra
.80335 .47093 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .48541 .75014 .47875 Mtetra
.75014 .47875 .75545 .48541 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .4782 .77406 .47149 Mtetra
.77406 .47149 .7793 .4782 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47093 .79818 .46416 Mtetra
.79818 .46416 .80335 .47093 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51473 Mtetra
.60495 .51473 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50074 Mtetra
.6508 .50074 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52217 Mtetra
.55394 .52217 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51179 Mtetra
.58779 .51179 .59361 .51819 .60495 .51473 .59917 .5083 Mtetra
.664 .741 .908 r
.59917 .5083 .60495 .51473 .61635 .51125 .61059 .5048 Mtetra
.61059 .5048 .61635 .51125 .62778 .50776 .62206 .50129 Mtetra
.62206 .50129 .62778 .50776 .63927 .50425 .63357 .49776 Mtetra
.63357 .49776 .63927 .50425 .6508 .50074 .64514 .49422 Mtetra
.64514 .49422 .6508 .50074 .66238 .4972 .65675 .49066 Mtetra
.65675 .49066 .66238 .4972 .67401 .49365 .66841 .48708 Mtetra
.66841 .48708 .67401 .49365 .68568 .49009 .68012 .48349 Mtetra
.68012 .48349 .68568 .49009 .69741 .48651 .69187 .47988 Mtetra
.69187 .47988 .69741 .48651 .70918 .48292 .70368 .47625 Mtetra
.664 .741 .907 r
.70368 .47625 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47569 .72744 .46896 Mtetra
.72744 .46896 .73287 .47569 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52217 .54798 .5158 Mtetra
.54798 .5158 .55394 .52217 .56518 .51872 .55925 .51233 Mtetra
.664 .741 .908 r
.55925 .51233 .56518 .51872 .57646 .51526 .57056 .50885 Mtetra
.663 .741 .908 r
.57056 .50885 .57646 .51526 .58779 .51179 .58192 .50537 Mtetra
.663 .742 .908 r
.58192 .50537 .58779 .51179 .59917 .5083 .59333 .50187 Mtetra
.663 .742 .909 r
.59333 .50187 .59917 .5083 .61059 .5048 .60479 .49837 Mtetra
.663 .743 .909 r
.60479 .49837 .61059 .5048 .62206 .50129 .61629 .49485 Mtetra
.663 .743 .91 r
.61629 .49485 .62206 .50129 .63357 .49776 .62784 .49131 Mtetra
.663 .744 .91 r
.62784 .49131 .63357 .49776 .64514 .49422 .63944 .48775 Mtetra
.664 .744 .91 r
.63944 .48775 .64514 .49422 .65675 .49066 .65108 .48416 Mtetra
.664 .745 .91 r
.65108 .48416 .65675 .49066 .66841 .48708 .66277 .48055 Mtetra
.664 .744 .91 r
.66277 .48055 .66841 .48708 .68012 .48349 .67451 .47691 Mtetra
.665 .744 .909 r
.67451 .47691 .68012 .48349 .69187 .47988 .6863 .47325 Mtetra
.665 .743 .909 r
.6863 .47325 .69187 .47988 .70368 .47625 .69814 .46957 Mtetra
.665 .743 .908 r
.69814 .46957 .70368 .47625 .71554 .47261 .71003 .46589 Mtetra
.664 .742 .908 r
.71003 .46589 .71554 .47261 .72744 .46896 .72197 .4622 Mtetra
.664 .741 .908 r
.72197 .4622 .72744 .46896 .73939 .46529 .73396 .45849 Mtetra
.664 .741 .907 r
.73396 .45849 .73939 .46529 .7514 .46161 .746 .45478 Mtetra
.746 .45478 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51633 Mtetra
.664 .741 .908 r
.51952 .51633 .52558 .52269 .53676 .51925 .53073 .51287 Mtetra
.663 .741 .908 r
.53073 .51287 .53676 .51925 .54798 .5158 .54198 .5094 Mtetra
.54198 .5094 .54798 .5158 .55925 .51233 .55328 .50593 Mtetra
.662 .742 .909 r
.55328 .50593 .55925 .51233 .57056 .50885 .56463 .50248 Mtetra
.661 .743 .911 r
.56463 .50248 .57056 .50885 .58192 .50537 .57602 .49903 Mtetra
.66 .745 .913 r
.57602 .49903 .58192 .50537 .59333 .50187 .58746 .49559 Mtetra
.66 .748 .915 r
.58746 .49559 .59333 .50187 .60479 .49837 .59895 .49215 Mtetra
.66 .751 .917 r
.59895 .49215 .60479 .49837 .61629 .49485 .61048 .4887 Mtetra
.66 .754 .919 r
.61048 .4887 .61629 .49485 .62784 .49131 .62207 .4852 Mtetra
.662 .756 .92 r
.62207 .4852 .62784 .49131 .63944 .48775 .6337 .48164 Mtetra
.663 .758 .921 r
.6337 .48164 .63944 .48775 .65108 .48416 .64538 .47803 Mtetra
.665 .758 .92 r
.64538 .47803 .65108 .48416 .66277 .48055 .65711 .47435 Mtetra
.666 .758 .919 r
.65711 .47435 .66277 .48055 .67451 .47691 .66888 .47062 Mtetra
.667 .756 .917 r
.66888 .47062 .67451 .47691 .6863 .47325 .6807 .46684 Mtetra
.667 .753 .914 r
.6807 .46684 .6863 .47325 .69814 .46957 .69257 .46305 Mtetra
.667 .75 .912 r
.69257 .46305 .69814 .46957 .71003 .46589 .70449 .45925 Mtetra
.666 .747 .91 r
.70449 .45925 .71003 .46589 .72197 .4622 .71646 .45546 Mtetra
.666 .745 .909 r
.71646 .45546 .72197 .4622 .73396 .45849 .72848 .45168 Mtetra
.665 .743 .908 r
.72848 .45168 .73396 .45849 .746 .45478 .74056 .44791 Mtetra
.664 .742 .908 r
.74056 .44791 .746 .45478 .75809 .45105 .75268 .44414 Mtetra
.664 .741 .907 r
.75268 .44414 .75809 .45105 .77023 .4473 .76486 .44036 Mtetra
.76486 .44036 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .5134 Mtetra
.663 .741 .908 r
.50223 .5134 .50836 .51978 .51952 .51633 .51342 .50993 Mtetra
.662 .741 .908 r
.51342 .50993 .51952 .51633 .53073 .51287 .52465 .50648 Mtetra
.661 .742 .91 r
.52465 .50648 .53073 .51287 .54198 .5094 .53593 .50306 Mtetra
.659 .743 .912 r
.53593 .50306 .54198 .5094 .55328 .50593 .54727 .49968 Mtetra
.656 .746 .916 r
.54727 .49968 .55328 .50593 .56463 .50248 .55864 .49637 Mtetra
.653 .751 .922 r
.55864 .49637 .56463 .50248 .57602 .49903 .57007 .49311 Mtetra
.651 .758 .928 r
.57007 .49311 .57602 .49903 .58746 .49559 .58155 .48987 Mtetra
.65 .765 .933 r
.58155 .48987 .58746 .49559 .59895 .49215 .59308 .48661 Mtetra
.651 .773 .938 r
.59308 .48661 .59895 .49215 .61048 .4887 .60465 .48328 Mtetra
.653 .779 .941 r
.60465 .48328 .61048 .4887 .62207 .4852 .61628 .47987 Mtetra
.656 .784 .942 r
.61628 .47987 .62207 .4852 .6337 .48164 .62795 .47634 Mtetra
.66 .787 .942 r
.62795 .47634 .6337 .48164 .64538 .47803 .63967 .4727 Mtetra
.664 .788 .941 r
.63967 .4727 .64538 .47803 .65711 .47435 .65143 .46894 Mtetra
.667 .787 .938 r
.65143 .46894 .65711 .47435 .66888 .47062 .66324 .46507 Mtetra
.671 .784 .934 r
.66324 .46507 .66888 .47062 .6807 .46684 .67509 .46111 Mtetra
.673 .779 .93 r
.67509 .46111 .6807 .46684 .69257 .46305 .68699 .45708 Mtetra
.674 .772 .925 r
.68699 .45708 .69257 .46305 .70449 .45925 .69893 .45303 Mtetra
.673 .764 .919 r
.69893 .45303 .70449 .45925 .71646 .45546 .71093 .449 Mtetra
.671 .757 .915 r
.71093 .449 .71646 .45546 .72848 .45168 .72298 .44502 Mtetra
.669 .75 .912 r
.72298 .44502 .72848 .45168 .74056 .44791 .73508 .44109 Mtetra
.667 .746 .909 r
.73508 .44109 .74056 .44791 .75268 .44414 .74724 .43722 Mtetra
.665 .743 .908 r
.74724 .43722 .75268 .44414 .76486 .44036 .75945 .43337 Mtetra
.664 .742 .908 r
.75945 .43337 .76486 .44036 .77709 .43657 .77171 .42954 Mtetra
.664 .741 .907 r
.77171 .42954 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51393 Mtetra
.663 .741 .908 r
.47374 .51393 .47998 .52031 .49108 .51686 .48487 .51046 Mtetra
.48487 .51046 .49108 .51686 .50223 .5134 .49604 .507 Mtetra
.661 .741 .909 r
.49604 .507 .50223 .5134 .51342 .50993 .50726 .50358 Mtetra
.658 .742 .912 r
.50726 .50358 .51342 .50993 .52465 .50648 .51853 .50023 Mtetra
.653 .745 .918 r
.51853 .50023 .52465 .50648 .53593 .50306 .52984 .49701 Mtetra
.647 .751 .925 r
.52984 .49701 .53593 .50306 .54727 .49968 .54121 .49391 Mtetra
.641 .76 .934 r
.54121 .49391 .54727 .49968 .55864 .49637 .55262 .49091 Mtetra
.638 .771 .943 r
.55262 .49091 .55864 .49637 .57007 .49311 .56409 .48791 Mtetra
.639 .781 .95 r
.56409 .48791 .57007 .49311 .58155 .48987 .5756 .48483 Mtetra
.643 .789 .952 r
.5756 .48483 .58155 .48987 .59308 .48661 .58717 .48159 Mtetra
.649 .793 .952 r
.58717 .48159 .59308 .48661 .60465 .48328 .59878 .4782 Mtetra
.654 .793 .949 r
.59878 .4782 .60465 .48328 .61628 .47987 .61044 .47467 Mtetra
.657 .791 .946 r
.61044 .47467 .61628 .47987 .62795 .47634 .62215 .47106 Mtetra
.659 .789 .944 r
.62215 .47106 .62795 .47634 .63967 .4727 .63391 .46739 Mtetra
.661 .79 .943 r
.63391 .46739 .63967 .4727 .65143 .46894 .64571 .46367 Mtetra
.663 .793 .944 r
.64571 .46367 .65143 .46894 .66324 .46507 .65756 .45986 Mtetra
.667 .797 .944 r
.65756 .45986 .66324 .46507 .67509 .46111 .66946 .45591 Mtetra
.672 .8 .943 r
.66946 .45591 .67509 .46111 .68699 .45708 .68139 .4518 Mtetra
.678 .8 .94 r
.68139 .4518 .68699 .45708 .69893 .45303 .69337 .44754 Mtetra
.681 .794 .935 r
.69337 .44754 .69893 .45303 .71093 .449 .70539 .44318 Mtetra
.681 .784 .928 r
.70539 .44318 .71093 .449 .72298 .44502 .71746 .43883 Mtetra
.678 .771 .921 r
.71746 .43883 .72298 .44502 .73508 .44109 .72958 .43457 Mtetra
.674 .759 .915 r
.72958 .43457 .73508 .44109 .74724 .43722 .74176 .43044 Mtetra
.669 .751 .911 r
.74176 .43044 .74724 .43722 .75945 .43337 .754 .42643 Mtetra
.667 .745 .909 r
.754 .42643 .75945 .43337 .77171 .42954 .7663 .42249 Mtetra
.665 .742 .908 r
.7663 .42249 .77171 .42954 .78403 .4257 .77865 .41859 Mtetra
.664 .741 .907 r
.77865 .41859 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.663 .741 .908 r
.45634 .51098 .46266 .51739 .47374 .51393 .46745 .50751 Mtetra
.662 .741 .908 r
.46745 .50751 .47374 .51393 .48487 .51046 .47861 .50405 Mtetra
.659 .741 .911 r
.47861 .50405 .48487 .51046 .49604 .507 .48981 .50067 Mtetra
.654 .743 .915 r
.48981 .50067 .49604 .507 .50726 .50358 .50106 .49742 Mtetra
.645 .747 .923 r
.50106 .49742 .50726 .50358 .51853 .50023 .51236 .49439 Mtetra
.636 .755 .934 r
.51236 .49439 .51853 .50023 .52984 .49701 .5237 .49154 Mtetra
.63 .768 .946 r
.5237 .49154 .52984 .49701 .54121 .49391 .5351 .48875 Mtetra
.632 .78 .952 r
.5351 .48875 .54121 .49391 .55262 .49091 .54655 .48582 Mtetra
.645 .788 .95 r
.54655 .48582 .55262 .49091 .56409 .48791 .55805 .48255 Mtetra
.663 .784 .938 r
.55805 .48255 .56409 .48791 .5756 .48483 .56959 .47885 Mtetra
.677 .768 .919 r
.56959 .47885 .5756 .48483 .58717 .48159 .58118 .47481 Mtetra
.681 .744 .898 r
.58118 .47481 .58717 .48159 .59878 .4782 .59281 .47058 Mtetra
.678 .72 .881 r
.59281 .47058 .59878 .4782 .61044 .47467 .60448 .46638 Mtetra
.671 .701 .869 r
.60448 .46638 .61044 .47467 .62215 .47106 .61621 .46239 Mtetra
.661 .689 .865 r
.61621 .46239 .62215 .47106 .63391 .46739 .62799 .45869 Mtetra
.653 .685 .868 r
.62799 .45869 .63391 .46739 .64571 .46367 .63983 .45529 Mtetra
.647 .692 .878 r
.63983 .45529 .64571 .46367 .65756 .45986 .65174 .45209 Mtetra
.646 .708 .893 r
.65174 .45209 .65756 .45986 .66946 .45591 .6637 .44892 Mtetra
.65 .734 .91 r
.6637 .44892 .66946 .45591 .68139 .4518 .67571 .44558 Mtetra
.66 .763 .926 r
.67571 .44558 .68139 .4518 .69337 .44754 .68775 .44187 Mtetra
.673 .787 .935 r
.68775 .44187 .69337 .44754 .70539 .44318 .69983 .43774 Mtetra
.683 .799 .937 r
.69983 .43774 .70539 .44318 .71746 .43883 .71193 .43326 Mtetra
.688 .797 .932 r
.71193 .43326 .71746 .43883 .72958 .43457 .72407 .42863 Mtetra
.686 .785 .926 r
.72407 .42863 .72958 .43457 .74176 .43044 .73627 .42406 Mtetra
.68 .769 .918 r
.73627 .42406 .74176 .43044 .754 .42643 .74853 .41968 Mtetra
.673 .756 .913 r
.74853 .41968 .754 .42643 .7663 .42249 .76085 .41551 Mtetra
.668 .747 .91 r
.76085 .41551 .7663 .42249 .77865 .41859 .77323 .41147 Mtetra
.665 .743 .908 r
.77323 .41147 .77865 .41859 .79106 .4147 .78568 .40751 Mtetra
.664 .742 .908 r
.78568 .40751 .79106 .4147 .80353 .4108 .79818 .40357 Mtetra
.664 .741 .907 r
.79818 .40357 .80353 .4108 .81604 .40689 .81073 .39962 Mtetra
.81073 .39962 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37963 Mtetra
.87435 .37963 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.663 .741 .908 r
.43888 .50803 .44527 .51446 .45634 .51098 .44997 .50454 Mtetra
.662 .741 .909 r
.44997 .50454 .45634 .51098 .46745 .50751 .46111 .50109 Mtetra
.658 .741 .911 r
.46111 .50109 .46745 .50751 .47861 .50405 .4723 .49774 Mtetra
.65 .743 .918 r
.4723 .49774 .47861 .50405 .48981 .50067 .48353 .4946 Mtetra
.637 .748 .929 r
.48353 .4946 .48981 .50067 .50106 .49742 .4948 .49174 Mtetra
.625 .759 .942 r
.4948 .49174 .50106 .49742 .51236 .49439 .50613 .48909 Mtetra
.624 .773 .952 r
.50613 .48909 .51236 .49439 .5237 .49154 .51751 .48637 Mtetra
.645 .785 .949 r
.51751 .48637 .5237 .49154 .5351 .48875 .52894 .48313 Mtetra
.679 .779 .926 r
.52894 .48313 .5351 .48875 .54655 .48582 .54042 .47902 Mtetra
.704 .749 .886 r
.54042 .47902 .54655 .48582 .55805 .48255 .55194 .47399 Mtetra
.702 .703 .849 r
.55194 .47399 .55805 .48255 .56959 .47885 .56349 .46868 Mtetra
.657 .653 .835 r
.56349 .46868 .56959 .47885 .58118 .47481 .5751 .46501 Mtetra
.658 .662 .842 r
.5751 .46501 .58118 .47481 .59281 .47058 .58676 .46133 Mtetra
.66 .675 .853 r
.58676 .46133 .59281 .47058 .60448 .46638 .59847 .45763 Mtetra
.661 .687 .864 r
.59847 .45763 .60448 .46638 .61621 .46239 .61023 .45391 Mtetra
.662 .695 .87 r
.61023 .45391 .61621 .46239 .62799 .45869 .62204 .45018 Mtetra
.62204 .45018 .62799 .45869 .63983 .45529 .6339 .44644 Mtetra
.661 .687 .864 r
.6339 .44644 .63983 .45529 .65174 .45209 .64581 .44268 Mtetra
.66 .675 .853 r
.64581 .44268 .65174 .45209 .6637 .44892 .65777 .4389 Mtetra
.658 .662 .842 r
.65777 .4389 .6637 .44892 .67571 .44558 .66979 .43511 Mtetra
.615 .634 .846 r
.66979 .43511 .67571 .44558 .68775 .44187 .68193 .43297 Mtetra
.622 .673 .878 r
.68193 .43297 .68775 .44187 .69983 .43774 .69412 .43057 Mtetra
.648 .732 .91 r
.69412 .43057 .69983 .43774 .71193 .43326 .70633 .42722 Mtetra
.674 .778 .928 r
.70633 .42722 .71193 .43326 .72407 .42863 .71854 .423 Mtetra
.69 .798 .932 r
.71854 .423 .72407 .42863 .73627 .42406 .73077 .41825 Mtetra
.693 .794 .927 r
.73077 .41825 .73627 .42406 .74853 .41968 .74304 .41341 Mtetra
.686 .777 .92 r
.74304 .41341 .74853 .41968 .76085 .41551 .75537 .40878 Mtetra
.677 .76 .914 r
.75537 .40878 .76085 .41551 .77323 .41147 .76778 .40444 Mtetra
.67 .749 .91 r
.76778 .40444 .77323 .41147 .78568 .40751 .78025 .40031 Mtetra
.666 .744 .908 r
.78025 .40031 .78568 .40751 .79818 .40357 .79279 .39628 Mtetra
.664 .742 .908 r
.79279 .39628 .79818 .40357 .81073 .39962 .80538 .39229 Mtetra
.664 .741 .907 r
.80538 .39229 .81073 .39962 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37963 .86919 .37213 Mtetra
.86919 .37213 .87435 .37963 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50857 Mtetra
.41032 .50857 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.663 .741 .908 r
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50157 Mtetra
.662 .741 .909 r
.43244 .50157 .43888 .50803 .44997 .50454 .44356 .4981 Mtetra
.657 .741 .912 r
.44356 .4981 .44997 .50454 .46111 .50109 .45473 .49476 Mtetra
.647 .742 .919 r
.45473 .49476 .46111 .50109 .4723 .49774 .46594 .49168 Mtetra
.631 .747 .932 r
.46594 .49168 .4723 .49774 .48353 .4946 .47719 .48897 Mtetra
.618 .759 .946 r
.47719 .48897 .48353 .4946 .4948 .49174 .48849 .48646 Mtetra
.628 .776 .951 r
.48849 .48646 .4948 .49174 .50613 .48909 .49985 .48363 Mtetra
.672 .782 .932 r
.49985 .48363 .50613 .48909 .51751 .48637 .51127 .47971 Mtetra
.718 .756 .882 r
.51127 .47971 .51751 .48637 .52894 .48313 .52273 .47419 Mtetra
.692 .691 .845 r
.52273 .47419 .52894 .48313 .54042 .47902 .53423 .46924 Mtetra
.658 .661 .842 r
.53423 .46924 .54042 .47902 .55194 .47399 .54578 .46557 Mtetra
.662 .694 .87 r
.54578 .46557 .55194 .47399 .56349 .46868 .55738 .46189 Mtetra
.664 .741 .907 r
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68193 .43297 .67608 .42422 Mtetra
.662 .694 .87 r
.67608 .42422 .68193 .43297 .69412 .43057 .68823 .42036 Mtetra
.625 .647 .852 r
.68823 .42036 .69412 .43057 .70633 .42722 .7005 .41781 Mtetra
.608 .657 .873 r
.7005 .41781 .70633 .42722 .71854 .423 .71288 .41584 Mtetra
.654 .738 .911 r
.71288 .41584 .71854 .423 .73077 .41825 .72522 .41225 Mtetra
.688 .788 .927 r
.72522 .41225 .73077 .41825 .74304 .41341 .73754 .40754 Mtetra
.698 .797 .926 r
.73754 .40754 .74304 .41341 .75537 .40878 .74989 .4025 Mtetra
.691 .782 .92 r
.74989 .4025 .75537 .40878 .76778 .40444 .7623 .39766 Mtetra
.679 .762 .914 r
.7623 .39766 .76778 .40444 .78025 .40031 .77479 .3932 Mtetra
.67 .75 .91 r
.77479 .3932 .78025 .40031 .79279 .39628 .78736 .38899 Mtetra
.666 .744 .908 r
.78736 .38899 .79279 .39628 .80538 .39229 .79999 .38492 Mtetra
.664 .742 .908 r
.79999 .38492 .80538 .39229 .81803 .38829 .81267 .38087 Mtetra
.664 .741 .907 r
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50857 .40378 .50209 Mtetra
.663 .741 .908 r
.40378 .50209 .41032 .50857 .42136 .50506 .41484 .49857 Mtetra
.662 .741 .908 r
.41484 .49857 .42136 .50506 .43244 .50157 .42594 .49509 Mtetra
.657 .74 .911 r
.42594 .49509 .43244 .50157 .44356 .4981 .43709 .49173 Mtetra
.646 .741 .919 r
.43709 .49173 .44356 .4981 .45473 .49476 .44828 .48866 Mtetra
.627 .746 .932 r
.44828 .48866 .45473 .49476 .46594 .49168 .45951 .48603 Mtetra
.613 .757 .948 r
.45951 .48603 .46594 .49168 .47719 .48897 .47079 .48362 Mtetra
.635 .776 .948 r
.47079 .48362 .47719 .48897 .48849 .48646 .48213 .48063 Mtetra
.698 .776 .912 r
.48213 .48063 .48849 .48646 .49985 .48363 .49354 .47593 Mtetra
.725 .73 .855 r
.49354 .47593 .49985 .48363 .51127 .47971 .505 .4698 Mtetra
.657 .659 .84 r
.505 .4698 .51127 .47971 .52273 .47419 .51648 .46614 Mtetra
.663 .704 .878 r
.51648 .46614 .52273 .47419 .53423 .46924 .52801 .46246 Mtetra
.664 .741 .907 r
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .7005 .41781 .69469 .4093 Mtetra
.663 .704 .878 r
.69469 .4093 .7005 .41781 .71288 .41584 .70698 .40538 Mtetra
.592 .629 .857 r
.70698 .40538 .71288 .41584 .72522 .41225 .71948 .40396 Mtetra
.631 .699 .894 r
.71948 .40396 .72522 .41225 .73754 .40754 .73196 .4011 Mtetra
.683 .775 .92 r
.73196 .4011 .73754 .40754 .74989 .4025 .74438 .3965 Mtetra
.701 .796 .924 r
.74438 .3965 .74989 .4025 .7623 .39766 .75682 .39129 Mtetra
.694 .782 .919 r
.75682 .39129 .7623 .39766 .77479 .3932 .76931 .38631 Mtetra
.68 .762 .913 r
.76931 .38631 .77479 .3932 .78736 .38899 .78189 .38176 Mtetra
.67 .749 .91 r
.78189 .38176 .78736 .38899 .79999 .38492 .79455 .37752 Mtetra
.666 .743 .908 r
.79455 .37752 .79999 .38492 .81267 .38087 .80727 .3734 Mtetra
.664 .741 .907 r
.80727 .3734 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49557 Mtetra
.663 .741 .908 r
.39718 .49557 .40378 .50209 .41484 .49857 .40827 .49206 Mtetra
.659 .74 .91 r
.40827 .49206 .41484 .49857 .42594 .49509 .4194 .48864 Mtetra
.647 .74 .917 r
.4194 .48864 .42594 .49509 .43709 .49173 .43057 .48553 Mtetra
.627 .743 .931 r
.43057 .48553 .43709 .49173 .44828 .48866 .44178 .48289 Mtetra
.61 .753 .946 r
.44178 .48289 .44828 .48866 .45951 .48603 .45303 .48056 Mtetra
.637 .773 .945 r
.45303 .48056 .45951 .48603 .47079 .48362 .46435 .47754 Mtetra
.713 .772 .899 r
.46435 .47754 .47079 .48362 .48213 .48063 .47576 .47231 Mtetra
.709 .711 .85 r
.47576 .47231 .48213 .48063 .49354 .47593 .4872 .4667 Mtetra
.659 .675 .854 r
.4872 .4667 .49354 .47593 .505 .4698 .49867 .46303 Mtetra
.664 .741 .907 r
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71948 .40396 .71361 .39412 Mtetra
.607 .651 .868 r
.71361 .39412 .71948 .40396 .73196 .4011 .72617 .39212 Mtetra
.615 .676 .885 r
.72617 .39212 .73196 .4011 .74438 .3965 .73878 .38975 Mtetra
.683 .767 .915 r
.73878 .38975 .74438 .3965 .75682 .39129 .7513 .3851 Mtetra
.704 .794 .92 r
.7513 .3851 .75682 .39129 .76931 .38631 .76381 .37975 Mtetra
.694 .779 .917 r
.76381 .37975 .76931 .38631 .78189 .38176 .7764 .3747 Mtetra
.678 .759 .912 r
.7764 .3747 .78189 .38176 .79455 .37752 .78908 .37015 Mtetra
.669 .747 .909 r
.78908 .37015 .79455 .37752 .80727 .3734 .80183 .36589 Mtetra
.665 .742 .908 r
.80183 .36589 .80727 .3734 .82006 .36931 .81466 .36174 Mtetra
.664 .741 .907 r
.81466 .36174 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.663 .741 .908 r
.37946 .49256 .38613 .4991 .39718 .49557 .39053 .48901 Mtetra
.66 .74 .909 r
.39053 .48901 .39718 .49557 .40827 .49206 .40164 .48554 Mtetra
.651 .74 .915 r
.40164 .48554 .40827 .49206 .4194 .48864 .4128 .48231 Mtetra
.631 .741 .927 r
.4128 .48231 .4194 .48864 .43057 .48553 .42398 .47958 Mtetra
.609 .747 .943 r
.42398 .47958 .43057 .48553 .44178 .48289 .43521 .47729 Mtetra
.628 .767 .946 r
.43521 .47729 .44178 .48289 .45303 .48056 .44651 .47448 Mtetra
.713 .772 .899 r
.44651 .47448 .45303 .48056 .46435 .47754 .4579 .46921 Mtetra
.709 .712 .85 r
.4579 .46921 .46435 .47754 .47576 .47231 .46934 .46359 Mtetra
.661 .688 .864 r
.46934 .46359 .47576 .47231 .4872 .4667 .48079 .4599 Mtetra
.664 .741 .907 r
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.596 .717 .929 r
.55051 .43744 .55673 .44441 .56849 .44064 .56232 .43551 Mtetra
.489 .739 .983 r
.56232 .43551 .56849 .44064 .5803 .43686 .57422 .43493 Mtetra
.449 .842 .98 r
.57422 .43493 .5803 .43686 .59216 .43306 .58617 .43269 Mtetra
.466 .885 .921 r
.58617 .43269 .59216 .43306 .60407 .42924 .59814 .42885 Mtetra
.598 .941 .935 r
.59814 .42885 .60407 .42924 .61603 .4254 .61012 .4234 Mtetra
.75 .938 .947 r
.61012 .4234 .61603 .4254 .62805 .42155 .62209 .41627 Mtetra
.723 .818 .924 r
.62209 .41627 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.664 .741 .907 r
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72617 .39212 .72032 .38273 Mtetra
.605 .663 .88 r
.72032 .38273 .72617 .39212 .73878 .38975 .73298 .38068 Mtetra
.615 .676 .885 r
.73298 .38068 .73878 .38975 .7513 .3851 .74569 .37828 Mtetra
.689 .77 .913 r
.74569 .37828 .7513 .3851 .76381 .37975 .75828 .37336 Mtetra
.706 .79 .917 r
.75828 .37336 .76381 .37975 .7764 .3747 .77089 .36789 Mtetra
.691 .773 .914 r
.77089 .36789 .7764 .3747 .78908 .37015 .78357 .36288 Mtetra
.675 .754 .91 r
.78357 .36288 .78908 .37015 .80183 .36589 .79635 .35838 Mtetra
.667 .745 .908 r
.79635 .35838 .80183 .36589 .81466 .36174 .80921 .35412 Mtetra
.665 .742 .908 r
.80921 .35412 .81466 .36174 .82754 .3576 .82213 .34993 Mtetra
.664 .741 .907 r
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32883 Mtetra
.88763 .32883 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48597 Mtetra
.662 .741 .908 r
.37273 .48597 .37946 .49256 .39053 .48901 .38383 .48243 Mtetra
.655 .74 .912 r
.38383 .48243 .39053 .48901 .40164 .48554 .39497 .47907 Mtetra
.639 .739 .921 r
.39497 .47907 .40164 .48554 .4128 .48231 .40614 .47614 Mtetra
.612 .742 .938 r
.40614 .47614 .4128 .48231 .42398 .47958 .41734 .4738 Mtetra
.614 .757 .947 r
.41734 .4738 .42398 .47958 .43521 .47729 .4286 .47133 Mtetra
.697 .773 .911 r
.4286 .47133 .43521 .47729 .44651 .47448 .43997 .46664 Mtetra
.724 .728 .853 r
.43997 .46664 .44651 .47448 .4579 .46921 .45142 .46047 Mtetra
.661 .688 .865 r
.45142 .46047 .4579 .46921 .46934 .46359 .46285 .45677 Mtetra
.664 .741 .907 r
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.311 .582 .938 r
.52074 .43803 .52707 .44499 .53877 .44123 .53248 .44095 Mtetra
.221 0 0 r
.53248 .44095 .53877 .44123 .55051 .43744 .54432 .44317 Mtetra
.394 0 0 r
.54432 .44317 .55051 .43744 .56232 .43551 .55623 .44332 Mtetra
.367 0 .034 r
.55623 .44332 .56232 .43551 .57422 .43493 .5682 .4418 Mtetra
.267 0 0 r
.5682 .4418 .57422 .43493 .58617 .43269 .58021 .43899 Mtetra
.173 0 0 r
.58021 .43899 .58617 .43269 .59814 .42885 .59227 .43513 Mtetra
.098 0 0 r
.59227 .43513 .59814 .42885 .61012 .4234 .60435 .43021 Mtetra
.043 0 0 r
.60435 .43021 .61012 .4234 .62209 .41627 .61644 .42401 Mtetra
0 0 0 r
.61644 .42401 .62209 .41627 .63413 .4105 .62851 .4161 Mtetra
.62851 .4161 .63413 .4105 .64628 .40658 .64053 .40609 Mtetra
.835 .982 .875 r
.64053 .40609 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.664 .741 .907 r
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73298 .38068 .72712 .37119 Mtetra
.588 .655 .883 r
.72712 .37119 .73298 .38068 .74569 .37828 .73992 .36965 Mtetra
.633 .698 .892 r
.73992 .36965 .74569 .37828 .75828 .37336 .75268 .36659 Mtetra
.7 .778 .912 r
.75268 .36659 .75828 .37336 .77089 .36789 .76534 .36126 Mtetra
.704 .785 .914 r
.76534 .36126 .77089 .36789 .78357 .36288 .77804 .35578 Mtetra
.686 .765 .912 r
.77804 .35578 .78357 .36288 .79635 .35838 .79083 .35089 Mtetra
.672 .749 .909 r
.79083 .35089 .79635 .35838 .80921 .35412 .80372 .34646 Mtetra
.666 .743 .908 r
.80372 .34646 .80921 .35412 .82213 .34993 .81668 .3422 Mtetra
.664 .741 .907 r
.81668 .3422 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32883 .88239 .32091 Mtetra
.88239 .32091 .88763 .32883 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.663 .741 .908 r
.35486 .48292 .36167 .48954 .37273 .48597 .36595 .47934 Mtetra
.66 .74 .91 r
.36595 .47934 .37273 .48597 .38383 .48243 .37707 .47584 Mtetra
.647 .739 .916 r
.37707 .47584 .38383 .48243 .39497 .47907 .38823 .47268 Mtetra
.622 .739 .93 r
.38823 .47268 .39497 .47907 .40614 .47614 .39941 .47013 Mtetra
.604 .746 .945 r
.39941 .47013 .40614 .47614 .41734 .4738 .41064 .46791 Mtetra
.662 .768 .928 r
.41064 .46791 .41734 .4738 .4286 .47133 .42197 .46424 Mtetra
.745 .752 .858 r
.42197 .46424 .4286 .47133 .43997 .46664 .43343 .45734 Mtetra
.659 .675 .854 r
.43343 .45734 .43997 .46664 .45142 .46047 .44485 .45363 Mtetra
.664 .741 .907 r
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.515 .685 .944 r
.49099 .43861 .49744 .44557 .50906 .44181 .50262 .43835 Mtetra
0 .31 .69 r
.50262 .43835 .50906 .44181 .52074 .43803 .51431 .4438 Mtetra
.5 .015 .036 r
.51431 .4438 .52074 .43803 .53248 .44095 .52612 .44624 Mtetra
.359 0 0 r
.52612 .44624 .53248 .44095 .54432 .44317 .53801 .44606 Mtetra
.076 0 0 r
.53801 .44606 .54432 .44317 .55623 .44332 .54997 .44409 Mtetra
.264 .772 .789 r
.54997 .44409 .55623 .44332 .5682 .4418 .56198 .44108 Mtetra
.469 .881 .939 r
.56198 .44108 .5682 .4418 .58021 .43899 .57404 .43751 Mtetra
.547 .9 .974 r
.57404 .43751 .58021 .43899 .59227 .43513 .58616 .43363 Mtetra
.57 .908 .975 r
.58616 .43363 .59227 .43513 .60435 .43021 .59831 .42942 Mtetra
.564 .923 .95 r
.59831 .42942 .60435 .43021 .61644 .42401 .61051 .42466 Mtetra
.53 .922 .868 r
.61051 .42466 .61644 .42401 .62851 .4161 .62272 .41884 Mtetra
.471 .871 .699 r
.62272 .41884 .62851 .4161 .64053 .40609 .6349 .4112 Mtetra
0 0 0 r
.6349 .4112 .64053 .40609 .65253 .39535 .64702 .40091 Mtetra
.578 .856 .523 r
.64702 .40091 .65253 .39535 .66483 .39136 .65901 .38755 Mtetra
.772 .887 .927 r
.65901 .38755 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.664 .741 .907 r
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73992 .36965 .734 .35951 Mtetra
.567 .632 .875 r
.734 .35951 .73992 .36965 .75268 .36659 .74695 .35866 Mtetra
.664 .732 .901 r
.74695 .35866 .75268 .36659 .76534 .36126 .75974 .35449 Mtetra
.708 .784 .911 r
.75974 .35449 .76534 .36126 .77804 .35578 .77247 .34882 Mtetra
.698 .776 .912 r
.77247 .34882 .77804 .35578 .79083 .35089 .78528 .34349 Mtetra
.679 .756 .91 r
.78528 .34349 .79083 .35089 .80372 .34646 .79819 .33878 Mtetra
.668 .745 .908 r
.79819 .33878 .80372 .34646 .81668 .3422 .81118 .33442 Mtetra
.665 .742 .907 r
.81118 .33442 .81668 .3422 .8297 .33797 .82425 .33014 Mtetra
.664 .741 .907 r
.82425 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47625 Mtetra
.662 .741 .908 r
.348 .47625 .35486 .48292 .36595 .47934 .35911 .47267 Mtetra
.655 .74 .912 r
.35911 .47267 .36595 .47934 .37707 .47584 .37026 .46927 Mtetra
.636 .738 .922 r
.37026 .46927 .37707 .47584 .38823 .47268 .38143 .46638 Mtetra
.607 .738 .938 r
.38143 .46638 .38823 .47268 .39941 .47013 .39263 .46414 Mtetra
.622 .754 .941 r
.39263 .46414 .39941 .47013 .41064 .46791 .4039 .46147 Mtetra
.728 .767 .883 r
.4039 .46147 .41064 .46791 .42197 .46424 .41534 .45551 Mtetra
.693 .7 .852 r
.41534 .45551 .42197 .46424 .43343 .45734 .42678 .45047 Mtetra
.664 .741 .907 r
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.415 .639 .949 r
.47285 .4354 .47938 .44239 .49099 .43861 .48443 .43676 Mtetra
.487 0 0 r
.48443 .43676 .49099 .43861 .50262 .43835 .49604 .44329 Mtetra
.491 0 0 r
.49604 .44329 .50262 .43835 .51431 .4438 .50781 .44587 Mtetra
.124 0 0 r
.50781 .44587 .51431 .4438 .52612 .44624 .51967 .44513 Mtetra
.434 .856 .951 r
.51967 .44513 .52612 .44624 .53801 .44606 .53161 .44234 Mtetra
.633 .852 .983 r
.53161 .44234 .53801 .44606 .54997 .44409 .5436 .43854 Mtetra
.667 .796 .943 r
.5436 .43854 .54997 .44409 .56198 .44108 .55564 .43441 Mtetra
.668 .76 .919 r
.55564 .43441 .56198 .44108 .57404 .43751 .56773 .4303 Mtetra
.662 .743 .91 r
.56773 .4303 .57404 .43751 .58616 .43363 .57987 .42639 Mtetra
.656 .74 .912 r
.57987 .42639 .58616 .43363 .59831 .42942 .59208 .42266 Mtetra
.653 .755 .925 r
.59208 .42266 .59831 .42942 .61051 .42466 .60434 .41896 Mtetra
.66 .794 .946 r
.60434 .41896 .61051 .42466 .62272 .41884 .61665 .41493 Mtetra
.685 .866 .968 r
.61665 .41493 .62272 .41884 .6349 .4112 .62897 .40987 Mtetra
.721 .959 .945 r
.62897 .40987 .6349 .4112 .64702 .40091 .64127 .40273 Mtetra
.727 .986 .797 r
.64127 .40273 .64702 .40091 .65901 .38755 .65347 .39223 Mtetra
.707 .93 .607 r
.65347 .39223 .65901 .38755 .67125 .37994 .6655 .3777 Mtetra
.811 .945 .912 r
.6655 .3777 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.664 .741 .907 r
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.62 .723 .92 r
.72822 .35185 .734 .35951 .74695 .35866 .74107 .34902 Mtetra
.596 .66 .883 r
.74107 .34902 .74695 .35866 .75974 .35449 .75406 .34715 Mtetra
.695 .764 .905 r
.75406 .34715 .75974 .35449 .77247 .34882 .76686 .34188 Mtetra
.708 .781 .909 r
.76686 .34188 .77247 .34882 .78528 .34349 .77969 .33617 Mtetra
.688 .764 .91 r
.77969 .33617 .78528 .34349 .79819 .33878 .79261 .33111 Mtetra
.672 .748 .908 r
.79261 .33111 .79819 .33878 .81118 .33442 .80564 .32659 Mtetra
.666 .742 .908 r
.80564 .32659 .81118 .33442 .82425 .33014 .81874 .32224 Mtetra
.664 .741 .907 r
.81874 .32224 .82425 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30489 Mtetra
.87177 .30489 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.663 .741 .908 r
.33 .47317 .33694 .47986 .348 .47625 .34109 .46954 Mtetra
.661 .74 .909 r
.34109 .46954 .348 .47625 .35911 .47267 .35223 .46597 Mtetra
.649 .738 .915 r
.35223 .46597 .35911 .47267 .37026 .46927 .36339 .46272 Mtetra
.622 .736 .928 r
.36339 .46272 .37026 .46927 .38143 .46638 .37458 .46014 Mtetra
.601 .74 .942 r
.37458 .46014 .38143 .46638 .39263 .46414 .3858 .45797 Mtetra
.668 .763 .921 r
.3858 .45797 .39263 .46414 .4039 .46147 .39715 .45412 Mtetra
.74 .746 .856 r
.39715 .45412 .4039 .46147 .41534 .45551 .40865 .4473 Mtetra
.662 .704 .878 r
.40865 .4473 .41534 .45551 .42678 .45047 .42007 .44355 Mtetra
.664 .741 .907 r
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.513 .685 .945 r
.45464 .43218 .46126 .43919 .47285 .4354 .4662 .4319 Mtetra
.502 0 0 r
.4662 .4319 .47285 .4354 .48443 .43676 .47771 .44006 Mtetra
.493 0 0 r
.47771 .44006 .48443 .43676 .49604 .44329 .48941 .4434 Mtetra
.092 .65 .754 r
.48941 .4434 .49604 .44329 .50781 .44587 .50125 .44255 Mtetra
.603 .857 .992 r
.50125 .44255 .50781 .44587 .51967 .44513 .51317 .43913 Mtetra
.684 .784 .926 r
.51317 .43913 .51967 .44513 .53161 .44234 .52514 .43455 Mtetra
.69 .734 .884 r
.52514 .43455 .53161 .44234 .5436 .43854 .53715 .42965 Mtetra
.682 .704 .865 r
.53715 .42965 .5436 .43854 .55564 .43441 .54922 .4249 Mtetra
.67 .687 .857 r
.54922 .4249 .55564 .43441 .56773 .4303 .56133 .4205 Mtetra
.658 .677 .857 r
.56133 .4205 .56773 .4303 .57987 .42639 .5735 .41655 Mtetra
.646 .672 .861 r
.5735 .41655 .57987 .42639 .59208 .42266 .58574 .41305 Mtetra
.636 .674 .869 r
.58574 .41305 .59208 .42266 .60434 .41896 .59804 .4099 Mtetra
.632 .685 .882 r
.59804 .4099 .60434 .41896 .61665 .41493 .6104 .4069 Mtetra
.64 .717 .903 r
.6104 .4069 .61665 .41493 .62897 .40987 .62282 .40359 Mtetra
.675 .783 .93 r
.62282 .40359 .62897 .40987 .64127 .40273 .63526 .3991 Mtetra
.753 .893 .941 r
.63526 .3991 .64127 .40273 .65347 .39223 .64766 .39202 Mtetra
.836 .989 .862 r
.64766 .39202 .65347 .39223 .6655 .3777 .6599 .38066 Mtetra
.858 .985 .703 r
.6599 .38066 .6655 .3777 .67775 .36836 .67192 .36438 Mtetra
.772 .887 .927 r
.67192 .36438 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.664 .741 .907 r
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74107 .34902 .73518 .33992 Mtetra
.564 .66 .901 r
.73518 .33992 .74107 .34902 .75406 .34715 .74826 .33886 Mtetra
.66 .725 .898 r
.74826 .33886 .75406 .34715 .76686 .34188 .7612 .33474 Mtetra
.71 .778 .905 r
.7612 .33474 .76686 .34188 .77969 .33617 .77406 .32889 Mtetra
.698 .771 .908 r
.77406 .32889 .77969 .33617 .79261 .33111 .787 .32345 Mtetra
.677 .753 .908 r
.787 .32345 .79261 .33111 .80564 .32659 .80005 .31871 Mtetra
.667 .744 .908 r
.80005 .31871 .80564 .32659 .81874 .32224 .8132 .31429 Mtetra
.664 .741 .907 r
.8132 .31429 .81874 .32224 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30489 .8664 .29677 Mtetra
.8664 .29677 .87177 .30489 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46643 Mtetra
.663 .741 .908 r
.323 .46643 .33 .47317 .34109 .46954 .33412 .46278 Mtetra
.658 .74 .91 r
.33412 .46278 .34109 .46954 .35223 .46597 .34528 .45925 Mtetra
.641 .737 .918 r
.34528 .45925 .35223 .46597 .36339 .46272 .35647 .45618 Mtetra
.609 .734 .934 r
.35647 .45618 .36339 .46272 .37458 .46014 .36767 .45387 Mtetra
.612 .744 .939 r
.36767 .45387 .37458 .46014 .3858 .45797 .37893 .45143 Mtetra
.719 .764 .888 r
.37893 .45143 .3858 .45797 .39715 .45412 .39038 .4458 Mtetra
.704 .715 .857 r
.39038 .4458 .39715 .45412 .40865 .4473 .40185 .44035 Mtetra
.664 .741 .907 r
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
0 .185 .688 r
.44798 .42511 .45464 .43218 .4662 .4319 .45937 .43408 Mtetra
.562 .02 0 r
.45937 .43408 .4662 .4319 .47771 .44006 .47097 .43936 Mtetra
.086 .641 .799 r
.47097 .43936 .47771 .44006 .48941 .4434 .48276 .43928 Mtetra
.627 .835 .98 r
.48276 .43928 .48941 .4434 .50125 .44255 .49466 .43574 Mtetra
.7 .764 .902 r
.49466 .43574 .50125 .44255 .51317 .43913 .50661 .43062 Mtetra
.703 .721 .863 r
.50661 .43062 .51317 .43913 .52514 .43455 .51862 .42504 Mtetra
.695 .696 .847 r
.51862 .42504 .52514 .43455 .53715 .42965 .53066 .41959 Mtetra
.683 .681 .842 r
.53066 .41959 .53715 .42965 .54922 .4249 .54275 .41454 Mtetra
.67 .671 .842 r
.54275 .41454 .54922 .4249 .56133 .4205 .55489 .41 Mtetra
.656 .663 .845 r
.55489 .41 .56133 .4205 .5735 .41655 .56709 .40602 Mtetra
.642 .657 .849 r
.56709 .40602 .5735 .41655 .58574 .41305 .57934 .40259 Mtetra
.628 .653 .856 r
.57934 .40259 .58574 .41305 .59804 .4099 .59167 .39967 Mtetra
.617 .654 .864 r
.59167 .39967 .59804 .4099 .6104 .4069 .60407 .39716 Mtetra
.612 .663 .875 r
.60407 .39716 .6104 .4069 .62282 .40359 .61655 .39478 Mtetra
.624 .692 .893 r
.61655 .39478 .62282 .40359 .63526 .3991 .62907 .39195 Mtetra
.673 .757 .914 r
.62907 .39195 .63526 .3991 .64766 .39202 .64161 .38752 Mtetra
.776 .868 .916 r
.64161 .38752 .64766 .39202 .6599 .38066 .65406 .37958 Mtetra
.887 .963 .839 r
.65406 .37958 .6599 .38066 .67192 .36438 .66629 .36617 Mtetra
.907 .983 .734 r
.66629 .36617 .67192 .36438 .68433 .35664 .67832 .34896 Mtetra
.664 .741 .907 r
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.607 .718 .923 r
.72933 .3321 .73518 .33992 .74826 .33886 .74235 .32956 Mtetra
.606 .678 .892 r
.74235 .32956 .74826 .33886 .7612 .33474 .75545 .32721 Mtetra
.702 .765 .901 r
.75545 .32721 .7612 .33474 .77406 .32889 .76838 .32158 Mtetra
.706 .774 .905 r
.76838 .32158 .77406 .32889 .787 .32345 .78134 .3158 Mtetra
.683 .757 .907 r
.78134 .3158 .787 .32345 .80005 .31871 .79442 .3108 Mtetra
.669 .745 .908 r
.79442 .3108 .80005 .31871 .8132 .31429 .8076 .30627 Mtetra
.665 .742 .907 r
.8076 .30627 .8132 .31429 .8264 .30992 .82085 .30185 Mtetra
.664 .741 .907 r
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46699 Mtetra
.29379 .46699 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46643 .31595 .45963 Mtetra
.662 .741 .908 r
.31595 .45963 .323 .46643 .33412 .46278 .3271 .45597 Mtetra
.655 .739 .911 r
.3271 .45597 .33412 .46278 .34528 .45925 .33828 .4525 Mtetra
.633 .735 .922 r
.33828 .4525 .34528 .45925 .35647 .45618 .34948 .44963 Mtetra
.601 .732 .937 r
.34948 .44963 .35647 .45618 .36767 .45387 .3607 .44747 Mtetra
.637 .749 .93 r
.3607 .44747 .36767 .45387 .37893 .45143 .37202 .44442 Mtetra
.751 .758 .858 r
.37202 .44442 .37893 .45143 .39038 .4458 .38357 .43715 Mtetra
.661 .695 .871 r
.38357 .43715 .39038 .4458 .40185 .44035 .39501 .43335 Mtetra
.664 .741 .907 r
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.293 .577 .938 r
.42962 .42185 .43637 .42894 .44798 .42511 .44108 .42473 Mtetra
.65 .099 0 r
.44108 .42473 .44798 .42511 .45937 .43408 .45252 .43322 Mtetra
.162 0 0 r
.45252 .43322 .45937 .43408 .47097 .43936 .46421 .43533 Mtetra
.583 .825 .99 r
.46421 .43533 .47097 .43936 .48276 .43928 .47607 .43255 Mtetra
.703 .768 .902 r
.47607 .43255 .48276 .43928 .49466 .43574 .48802 .42731 Mtetra
.715 .726 .859 r
.48802 .42731 .49466 .43574 .50661 .43062 .50002 .42123 Mtetra
.708 .704 .844 r
.50002 .42123 .50661 .43062 .51862 .42504 .51206 .41515 Mtetra
.697 .69 .839 r
.51206 .41515 .51862 .42504 .53066 .41959 .52413 .40944 Mtetra
.685 .681 .841 r
.52413 .40944 .53066 .41959 .54275 .41454 .53625 .40424 Mtetra
.671 .674 .844 r
.53625 .40424 .54275 .41454 .55489 .41 .54841 .39963 Mtetra
.656 .667 .848 r
.54841 .39963 .55489 .41 .56709 .40602 .56063 .39561 Mtetra
.641 .661 .853 r
.56063 .39561 .56709 .40602 .57934 .40259 .57291 .39218 Mtetra
.625 .654 .859 r
.57291 .39218 .57934 .40259 .59167 .39967 .58526 .38934 Mtetra
.61 .65 .865 r
.58526 .38934 .59167 .39967 .60407 .39716 .59769 .38702 Mtetra
.598 .65 .872 r
.59769 .38702 .60407 .39716 .61655 .39478 .6102 .38508 Mtetra
.596 .66 .882 r
.6102 .38508 .61655 .39478 .62907 .39195 .62278 .38314 Mtetra
.621 .693 .896 r
.62278 .38314 .62907 .39195 .64161 .38752 .63541 .38037 Mtetra
.696 .768 .907 r
.63541 .38037 .64161 .38752 .65406 .37958 .64801 .3751 Mtetra
.825 .874 .881 r
.64801 .3751 .65406 .37958 .66629 .36617 .66045 .36486 Mtetra
.927 .938 .788 r
.66045 .36486 .66629 .36617 .67832 .34896 .67259 .34809 Mtetra
.835 .982 .875 r
.67259 .34809 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.664 .741 .907 r
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74235 .32956 .73638 .31992 Mtetra
.553 .645 .895 r
.73638 .31992 .74235 .32956 .75545 .32721 .74963 .31918 Mtetra
.684 .747 .899 r
.74963 .31918 .75545 .32721 .76838 .32158 .76265 .31412 Mtetra
.711 .774 .901 r
.76265 .31412 .76838 .32158 .78134 .3158 .77564 .30811 Mtetra
.69 .761 .906 r
.77564 .30811 .78134 .3158 .79442 .3108 .78875 .30284 Mtetra
.672 .747 .907 r
.78875 .30284 .79442 .3108 .8076 .30627 .80196 .29818 Mtetra
.665 .742 .907 r
.80196 .29818 .8076 .30627 .82085 .30185 .81525 .29372 Mtetra
.664 .741 .907 r
.81525 .29372 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46699 .28663 .46019 Mtetra
.28663 .46019 .29379 .46699 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45963 .30885 .45278 Mtetra
.662 .74 .908 r
.30885 .45278 .31595 .45963 .3271 .45597 .32002 .44911 Mtetra
.652 .738 .913 r
.32002 .44911 .3271 .45597 .33828 .4525 .33123 .44571 Mtetra
.625 .733 .925 r
.33123 .44571 .33828 .4525 .34948 .44963 .34244 .44301 Mtetra
.599 .731 .937 r
.34244 .44301 .34948 .44963 .3607 .44747 .35369 .44089 Mtetra
.667 .753 .915 r
.35369 .44089 .3607 .44747 .37202 .44442 .36507 .43701 Mtetra
.741 .748 .858 r
.36507 .43701 .37202 .44442 .38357 .43715 .37664 .43012 Mtetra
.664 .741 .907 r
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
0 .18 .683 r
.42282 .4147 .42962 .42185 .44108 .42473 .43413 .42362 Mtetra
.505 0 0 r
.43413 .42362 .44108 .42473 .45252 .43322 .44565 .42971 Mtetra
.387 .763 .991 r
.44565 .42971 .45252 .43322 .46421 .43533 .45743 .42919 Mtetra
.683 .782 .925 r
.45743 .42919 .46421 .43533 .47607 .43255 .46935 .42462 Mtetra
.721 .741 .867 r
.46935 .42462 .47607 .43255 .48802 .42731 .48135 .41838 Mtetra
.721 .718 .847 r
.48135 .41838 .48802 .42731 .50002 .42123 .49339 .4118 Mtetra
.713 .706 .842 r
.49339 .4118 .50002 .42123 .51206 .41515 .50545 .40547 Mtetra
.701 .697 .843 r
.50545 .40547 .51206 .41515 .52413 .40944 .51756 .39963 Mtetra
.688 .69 .847 r
.51756 .39963 .52413 .40944 .53625 .40424 .5297 .39437 Mtetra
.673 .685 .852 r
.5297 .39437 .53625 .40424 .54841 .39963 .54189 .3897 Mtetra
.658 .678 .858 r
.54189 .3897 .54841 .39963 .56063 .39561 .55413 .38564 Mtetra
.642 .672 .863 r
.55413 .38564 .56063 .39561 .57291 .39218 .56644 .3822 Mtetra
.625 .665 .868 r
.56644 .3822 .57291 .39218 .58526 .38934 .57882 .37935 Mtetra
.607 .657 .874 r
.57882 .37935 .58526 .38934 .59769 .38702 .59128 .37709 Mtetra
.591 .653 .879 r
.59128 .37709 .59769 .38702 .6102 .38508 .60381 .37533 Mtetra
.581 .653 .886 r
.60381 .37533 .6102 .38508 .62278 .38314 .61643 .37383 Mtetra
.59 .669 .894 r
.61643 .37383 .62278 .38314 .63541 .38037 .62912 .372 Mtetra
.642 .716 .901 r
.62912 .372 .63541 .38037 .64801 .3751 .64183 .36848 Mtetra
.757 .802 .889 r
.64183 .36848 .64801 .3751 .66045 .36486 .65443 .36084 Mtetra
.888 .882 .822 r
.65443 .36084 .66045 .36486 .67259 .34809 .66675 .34646 Mtetra
.931 .93 .782 r
.66675 .34646 .67259 .34809 .68498 .337 .67892 .32915 Mtetra
.664 .741 .907 r
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.553 .693 .932 r
.73048 .31193 .73638 .31992 .74963 .31918 .74373 .31074 Mtetra
.661 .728 .899 r
.74373 .31074 .74963 .31918 .76265 .31412 .75685 .30645 Mtetra
.712 .77 .898 r
.75685 .30645 .76265 .31412 .77564 .30811 .76989 .30035 Mtetra
.696 .763 .903 r
.76989 .30035 .77564 .30811 .78875 .30284 .78302 .29483 Mtetra
.674 .749 .907 r
.78302 .29483 .78875 .30284 .80196 .29818 .79627 .29004 Mtetra
.666 .742 .907 r
.79627 .29004 .80196 .29818 .81525 .29372 .80961 .28551 Mtetra
.664 .741 .907 r
.80961 .28551 .81525 .29372 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.663 .741 .908 r
.29052 .44961 .29771 .45649 .30885 .45278 .30168 .44588 Mtetra
.661 .74 .909 r
.30168 .44588 .30885 .45278 .32002 .44911 .31289 .4422 Mtetra
.649 .738 .914 r
.31289 .4422 .32002 .44911 .33123 .44571 .32412 .43886 Mtetra
.618 .731 .927 r
.32412 .43886 .33123 .44571 .34244 .44301 .33535 .4363 Mtetra
.601 .731 .936 r
.33535 .4363 .34244 .44301 .35369 .44089 .34662 .4341 Mtetra
.692 .755 .9 r
.34662 .4341 .35369 .44089 .36507 .43701 .35808 .42938 Mtetra
.727 .741 .862 r
.35808 .42938 .36507 .43701 .37664 .43012 .36966 .42304 Mtetra
.664 .741 .907 r
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.594 .718 .93 r
.40431 .4114 .4112 .41858 .42282 .4147 .41589 .40937 Mtetra
.589 .055 0 r
.41589 .40937 .42282 .4147 .43413 .42362 .42715 .42039 Mtetra
0 .413 .756 r
.42715 .42039 .43413 .42362 .44565 .42971 .43875 .42436 Mtetra
.584 .779 .973 r
.43875 .42436 .44565 .42971 .45743 .42919 .45061 .422 Mtetra
.712 .759 .889 r
.45061 .422 .45743 .42919 .46935 .42462 .46259 .41633 Mtetra
.73 .736 .856 r
.46259 .41633 .46935 .42462 .48135 .41838 .47463 .40953 Mtetra
.727 .723 .847 r
.47463 .40953 .48135 .41838 .49339 .4118 .4867 .40269 Mtetra
.717 .715 .847 r
.4867 .40269 .49339 .4118 .50545 .40547 .4988 .39623 Mtetra
.705 .709 .852 r
.4988 .39623 .50545 .40547 .51756 .39963 .51093 .39033 Mtetra
.691 .704 .857 r
.51093 .39033 .51756 .39963 .5297 .39437 .52311 .38502 Mtetra
.676 .698 .863 r
.52311 .38502 .5297 .39437 .54189 .3897 .53533 .38032 Mtetra
.66 .693 .87 r
.53533 .38032 .54189 .3897 .55413 .38564 .5476 .37623 Mtetra
.643 .686 .875 r
.5476 .37623 .55413 .38564 .56644 .3822 .55994 .37274 Mtetra
.624 .678 .881 r
.55994 .37274 .56644 .3822 .57882 .37935 .57234 .36987 Mtetra
.605 .67 .886 r
.57234 .36987 .57882 .37935 .59128 .37709 .58482 .3676 Mtetra
.586 .662 .891 r
.58482 .3676 .59128 .37709 .60381 .37533 .59739 .3659 Mtetra
.571 .658 .896 r
.59739 .3659 .60381 .37533 .61643 .37383 .61004 .3646 Mtetra
.571 .664 .901 r
.61004 .3646 .61643 .37383 .62912 .372 .62278 .36326 Mtetra
.607 .694 .904 r
.62278 .36326 .62912 .372 .64183 .36848 .63555 .36079 Mtetra
.707 .76 .893 r
.63555 .36079 .64183 .36848 .65443 .36084 .64827 .35495 Mtetra
.844 .835 .837 r
.64827 .35495 .65443 .36084 .66675 .34646 .66075 .34267 Mtetra
.93 .87 .757 r
.66075 .34267 .66675 .34646 .67892 .32915 .67289 .32316 Mtetra
.723 .818 .924 r
.67289 .32316 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.664 .741 .907 r
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.576 .704 .929 r
.72452 .30387 .73048 .31193 .74373 .31074 .73778 .30205 Mtetra
.636 .713 .903 r
.73778 .30205 .74373 .31074 .75685 .30645 .751 .29857 Mtetra
.71 .765 .895 r
.751 .29857 .75685 .30645 .76989 .30035 .76408 .29247 Mtetra
.7 .763 .9 r
.76408 .29247 .76989 .30035 .78302 .29483 .77725 .28674 Mtetra
.677 .749 .906 r
.77725 .28674 .78302 .29483 .79627 .29004 .79054 .28182 Mtetra
.667 .743 .907 r
.79054 .28182 .79627 .29004 .80961 .28551 .80391 .27723 Mtetra
.664 .741 .907 r
.80391 .27723 .80961 .28551 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.663 .741 .908 r
.28328 .44268 .29052 .44961 .30168 .44588 .29447 .43892 Mtetra
.66 .74 .909 r
.29447 .43892 .30168 .44588 .31289 .4422 .3057 .43523 Mtetra
.647 .737 .915 r
.3057 .43523 .31289 .4422 .32412 .43886 .31695 .43193 Mtetra
.614 .729 .928 r
.31695 .43193 .32412 .43886 .33535 .4363 .32821 .42945 Mtetra
.605 .73 .933 r
.32821 .42945 .33535 .4363 .34662 .4341 .33951 .42714 Mtetra
.709 .755 .888 r
.33951 .42714 .34662 .4341 .35808 .42938 .35103 .42173 Mtetra
.716 .74 .87 r
.35103 .42173 .35808 .42938 .36966 .42304 .36262 .41589 Mtetra
.664 .741 .907 r
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.414 .641 .95 r
.39736 .40417 .40431 .4114 .41589 .40937 .40886 .40536 Mtetra
.609 .054 0 r
.40886 .40536 .41589 .40937 .42715 .42039 .42015 .41545 Mtetra
.181 .596 .941 r
.42015 .41545 .42715 .42039 .43875 .42436 .43182 .41792 Mtetra
.644 .763 .936 r
.43182 .41792 .43875 .42436 .45061 .422 .44374 .41443 Mtetra
.724 .753 .875 r
.44374 .41443 .45061 .422 .46259 .41633 .45577 .40814 Mtetra
.737 .741 .855 r
.45577 .40814 .46259 .41633 .47463 .40953 .46785 .40104 Mtetra
.732 .734 .852 r
.46785 .40104 .47463 .40953 .4867 .40269 .47996 .39405 Mtetra
.722 .729 .856 r
.47996 .39405 .4867 .40269 .4988 .39623 .4921 .38752 Mtetra
.709 .724 .862 r
.4921 .38752 .4988 .39623 .51093 .39033 .50426 .38157 Mtetra
.694 .719 .869 r
.50426 .38157 .51093 .39033 .52311 .38502 .51647 .37624 Mtetra
.678 .714 .876 r
.51647 .37624 .52311 .38502 .53533 .38032 .52872 .3715 Mtetra
.661 .708 .882 r
.52872 .3715 .53533 .38032 .5476 .37623 .54103 .36738 Mtetra
.643 .701 .889 r
.54103 .36738 .5476 .37623 .55994 .37274 .55339 .36385 Mtetra
.624 .694 .894 r
.55339 .36385 .55994 .37274 .57234 .36987 .56583 .36094 Mtetra
.603 .685 .9 r
.56583 .36094 .57234 .36987 .58482 .3676 .57834 .35865 Mtetra
.582 .676 .905 r
.57834 .35865 .58482 .3676 .59739 .3659 .59093 .35695 Mtetra
.563 .668 .909 r
.59093 .35695 .59739 .3659 .61004 .3646 .60361 .35573 Mtetra
.558 .669 .912 r
.60361 .35573 .61004 .3646 .62278 .36326 .61638 .35462 Mtetra
.586 .689 .913 r
.61638 .35462 .62278 .36326 .63555 .36079 .62921 .35271 Mtetra
.676 .741 .9 r
.62921 .35271 .63555 .36079 .64827 .35495 .64201 .34795 Mtetra
.812 .805 .845 r
.64201 .34795 .64827 .35495 .66075 .34267 .65461 .33712 Mtetra
.907 .836 .764 r
.65461 .33712 .66075 .34267 .67289 .32316 .66687 .31851 Mtetra
.81 .878 .895 r
.66687 .31851 .67289 .32316 .68564 .31693 .67952 .30892 Mtetra
.664 .741 .907 r
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.597 .713 .925 r
.71852 .29575 .72452 .30387 .73778 .30205 .73178 .29334 Mtetra
.615 .705 .909 r
.73178 .29334 .73778 .30205 .751 .29857 .74508 .29049 Mtetra
.707 .761 .894 r
.74508 .29049 .751 .29857 .76408 .29247 .75822 .28444 Mtetra
.703 .762 .898 r
.75822 .28444 .76408 .29247 .77725 .28674 .77142 .27856 Mtetra
.679 .749 .904 r
.77142 .27856 .77725 .28674 .79054 .28182 .78475 .27353 Mtetra
.667 .743 .907 r
.78475 .27353 .79054 .28182 .80391 .27723 .79817 .26888 Mtetra
.664 .741 .907 r
.79817 .26888 .80391 .27723 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25974 Mtetra
.82521 .25974 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.663 .741 .908 r
.27598 .43569 .28328 .44268 .29447 .43892 .28719 .4319 Mtetra
.66 .74 .909 r
.28719 .4319 .29447 .43892 .3057 .43523 .29845 .4282 Mtetra
.645 .736 .915 r
.29845 .4282 .3057 .43523 .31695 .43193 .30973 .4249 Mtetra
.612 .727 .928 r
.30973 .4249 .31695 .43193 .32821 .42945 .32101 .42245 Mtetra
.608 .728 .93 r
.32101 .42245 .32821 .42945 .33951 .42714 .33234 .42005 Mtetra
.718 .755 .882 r
.33234 .42005 .33951 .42714 .35103 .42173 .34392 .41425 Mtetra
.71 .744 .878 r
.34392 .41425 .35103 .42173 .36262 .41589 .35552 .40869 Mtetra
.664 .741 .907 r
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.293 .577 .939 r
.39036 .39687 .39736 .40417 .40886 .40536 .40181 .39965 Mtetra
.47 0 0 r
.40181 .39965 .40886 .40536 .42015 .41545 .41313 .40917 Mtetra
.333 .637 .963 r
.41313 .40917 .42015 .41545 .43182 .41792 .42485 .41087 Mtetra
.663 .752 .917 r
.42485 .41087 .43182 .41792 .44374 .41443 .43681 .40685 Mtetra
.73 .756 .873 r
.43681 .40685 .44374 .41443 .45577 .40814 .44889 .40026 Mtetra
.742 .752 .86 r
.44889 .40026 .45577 .40814 .46785 .40104 .46101 .39302 Mtetra
.737 .748 .861 r
.46101 .39302 .46785 .40104 .47996 .39405 .47316 .38594 Mtetra
.726 .744 .866 r
.47316 .38594 .47996 .39405 .4921 .38752 .48533 .37936 Mtetra
.712 .74 .873 r
.48533 .37936 .4921 .38752 .50426 .38157 .49754 .37338 Mtetra
.697 .736 .881 r
.49754 .37338 .50426 .38157 .51647 .37624 .50978 .36801 Mtetra
.68 .731 .888 r
.50978 .36801 .51647 .37624 .52872 .3715 .52206 .36325 Mtetra
.663 .725 .895 r
.52206 .36325 .52872 .3715 .54103 .36738 .5344 .35909 Mtetra
.644 .718 .902 r
.5344 .35909 .54103 .36738 .55339 .36385 .5468 .35553 Mtetra
.623 .71 .908 r
.5468 .35553 .55339 .36385 .56583 .36094 .55927 .35258 Mtetra
.601 .701 .914 r
.55927 .35258 .56583 .36094 .57834 .35865 .57181 .35025 Mtetra
.577 .691 .919 r
.57181 .35025 .57834 .35865 .59093 .35695 .58443 .34853 Mtetra
.556 .682 .923 r
.58443 .34853 .59093 .35695 .60361 .35573 .59715 .34732 Mtetra
.548 .68 .925 r
.59715 .34732 .60361 .35573 .61638 .35462 .60995 .34629 Mtetra
.573 .694 .923 r
.60995 .34629 .61638 .35462 .62921 .35271 .62282 .34461 Mtetra
.661 .737 .906 r
.62282 .34461 .62921 .35271 .64201 .34795 .63567 .34033 Mtetra
.795 .788 .847 r
.63567 .34033 .64201 .34795 .65461 .33712 .64836 .33021 Mtetra
.889 .809 .763 r
.64836 .33021 .65461 .33712 .66687 .31851 .66072 .31211 Mtetra
.826 .827 .849 r
.66072 .31211 .66687 .31851 .67952 .30892 .67334 .30084 Mtetra
.664 .741 .907 r
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.609 .718 .923 r
.71247 .28756 .71852 .29575 .73178 .29334 .72574 .28479 Mtetra
.601 .705 .917 r
.72574 .28479 .73178 .29334 .74508 .29049 .73911 .28227 Mtetra
.706 .758 .893 r
.73911 .28227 .74508 .29049 .75822 .28444 .7523 .27624 Mtetra
.704 .759 .895 r
.7523 .27624 .75822 .28444 .77142 .27856 .76554 .27027 Mtetra
.68 .749 .903 r
.76554 .27027 .77142 .27856 .78475 .27353 .77891 .26516 Mtetra
.667 .743 .906 r
.77891 .26516 .78475 .27353 .79817 .26888 .79237 .26046 Mtetra
.664 .741 .907 r
.79237 .26046 .79817 .26888 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.663 .741 .908 r
.26862 .42865 .27598 .43569 .28719 .4319 .27986 .42483 Mtetra
.66 .74 .909 r
.27986 .42483 .28719 .4319 .29845 .4282 .29115 .4211 Mtetra
.645 .736 .915 r
.29115 .4211 .29845 .4282 .30973 .4249 .30246 .41777 Mtetra
.612 .726 .926 r
.30246 .41777 .30973 .4249 .32101 .42245 .31376 .41529 Mtetra
.609 .725 .927 r
.31376 .41529 .32101 .42245 .33234 .42005 .32512 .41286 Mtetra
.718 .754 .881 r
.32512 .41286 .33234 .42005 .34392 .41425 .33673 .40703 Mtetra
.711 .753 .884 r
.33673 .40703 .34392 .41425 .35552 .40869 .34837 .40144 Mtetra
.664 .741 .907 r
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.293 .577 .939 r
.3833 .38952 .39036 .39687 .40181 .39965 .39477 .39228 Mtetra
0 .135 .641 r
.39477 .39228 .40181 .39965 .41313 .40917 .40609 .40179 Mtetra
.377 .624 .949 r
.40609 .40179 .41313 .40917 .42485 .41087 .41783 .40347 Mtetra
.663 .743 .91 r
.41783 .40347 .42485 .41087 .43681 .40685 .42982 .39941 Mtetra
.731 .761 .877 r
.42982 .39941 .43681 .40685 .44889 .40026 .44194 .39279 Mtetra
.745 .764 .868 r
.44194 .39279 .44889 .40026 .46101 .39302 .4541 .3855 Mtetra
.741 .763 .871 r
.4541 .3855 .46101 .39302 .47316 .38594 .46629 .37839 Mtetra
.73 .761 .877 r
.46629 .37839 .47316 .38594 .48533 .37936 .47851 .37177 Mtetra
.715 .757 .885 r
.47851 .37177 .48533 .37936 .49754 .37338 .49075 .36576 Mtetra
.699 .753 .893 r
.49075 .36576 .49754 .37338 .50978 .36801 .50303 .36035 Mtetra
.682 .748 .901 r
.50303 .36035 .50978 .36801 .52206 .36325 .51535 .35555 Mtetra
.663 .742 .909 r
.51535 .35555 .52206 .36325 .5344 .35909 .52773 .35136 Mtetra
.643 .735 .916 r
.52773 .35136 .5344 .35909 .5468 .35553 .54016 .34776 Mtetra
.621 .727 .922 r
.54016 .34776 .5468 .35553 .55927 .35258 .55266 .34478 Mtetra
.597 .718 .928 r
.55266 .34478 .55927 .35258 .57181 .35025 .56524 .34242 Mtetra
.572 .707 .934 r
.56524 .34242 .57181 .35025 .58443 .34853 .57789 .34067 Mtetra
.55 .698 .937 r
.57789 .34067 .58443 .34853 .59715 .34732 .59064 .33942 Mtetra
.541 .694 .938 r
.59064 .33942 .59715 .34732 .60995 .34629 .60348 .33837 Mtetra
.569 .706 .934 r
.60348 .33837 .60995 .34629 .62282 .34461 .61638 .33665 Mtetra
.661 .743 .911 r
.61638 .33665 .62282 .34461 .63567 .34033 .62928 .33233 Mtetra
.792 .78 .842 r
.62928 .33233 .63567 .34033 .64836 .33021 .64201 .32217 Mtetra
.877 .787 .758 r
.64201 .32217 .64836 .33021 .66072 .31211 .65443 .30401 Mtetra
.809 .782 .828 r
.65443 .30401 .66072 .31211 .67334 .30084 .66711 .29269 Mtetra
.664 .741 .907 r
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.609 .718 .923 r
.70636 .27929 .71247 .28756 .72574 .28479 .71968 .27649 Mtetra
.599 .714 .925 r
.71968 .27649 .72574 .28479 .73911 .28227 .73308 .27393 Mtetra
.705 .757 .892 r
.73308 .27393 .73911 .28227 .7523 .27624 .74632 .26787 Mtetra
.704 .756 .893 r
.74632 .26787 .7523 .27624 .76554 .27027 .75961 .26185 Mtetra
.68 .747 .902 r
.75961 .26185 .76554 .27027 .77891 .26516 .77302 .2567 Mtetra
.667 .742 .906 r
.77302 .2567 .77891 .26516 .79237 .26046 .78653 .25196 Mtetra
.664 .741 .907 r
.78653 .25196 .79237 .26046 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.663 .741 .908 r
.2612 .42155 .26862 .42865 .27986 .42483 .27247 .4177 Mtetra
.66 .74 .909 r
.27247 .4177 .27986 .42483 .29115 .4211 .28379 .41393 Mtetra
.647 .736 .914 r
.28379 .41393 .29115 .4211 .30246 .41777 .29513 .41053 Mtetra
.614 .725 .925 r
.29513 .41053 .30246 .41777 .31376 .41529 .30646 .40797 Mtetra
.607 .721 .926 r
.30646 .40797 .31376 .41529 .32512 .41286 .31784 .40557 Mtetra
.708 .751 .885 r
.31784 .40557 .32512 .41286 .33673 .40703 .32947 .40007 Mtetra
.721 .763 .886 r
.32947 .40007 .33673 .40703 .34837 .40144 .34116 .39412 Mtetra
.664 .741 .907 r
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.414 .641 .95 r
.37618 .38211 .3833 .38952 .39477 .39228 .38774 .38324 Mtetra
0 .158 .686 r
.38774 .38324 .39477 .39228 .40609 .40179 .39903 .3933 Mtetra
.362 .582 .926 r
.39903 .3933 .40609 .40179 .41783 .40347 .41076 .3957 Mtetra
.646 .73 .91 r
.41076 .3957 .41783 .40347 .42982 .39941 .42277 .39212 Mtetra
.727 .766 .884 r
.42277 .39212 .42982 .39941 .44194 .39279 .43492 .38572 Mtetra
.746 .776 .878 r
.43492 .38572 .44194 .39279 .4541 .3855 .44712 .3785 Mtetra
.744 .779 .881 r
.44712 .3785 .4541 .3855 .46629 .37839 .45936 .37139 Mtetra
.733 .778 .889 r
.45936 .37139 .46629 .37839 .47851 .37177 .47161 .36475 Mtetra
.718 .775 .897 r
.47161 .36475 .47851 .37177 .49075 .36576 .4839 .35869 Mtetra
.701 .771 .906 r
.4839 .35869 .49075 .36576 .50303 .36035 .49622 .35325 Mtetra
.683 .766 .914 r
.49622 .35325 .50303 .36035 .51535 .35555 .50858 .34841 Mtetra
.663 .76 .922 r
.50858 .34841 .51535 .35555 .52773 .35136 .521 .34418 Mtetra
.641 .753 .93 r
.521 .34418 .52773 .35136 .54016 .34776 .53347 .34055 Mtetra
.618 .745 .937 r
.53347 .34055 .54016 .34776 .55266 .34478 .54601 .33754 Mtetra
.592 .735 .943 r
.54601 .33754 .55266 .34478 .56524 .34242 .55862 .33515 Mtetra
.566 .724 .948 r
.55862 .33515 .56524 .34242 .57789 .34067 .57131 .33336 Mtetra
.543 .714 .951 r
.57131 .33336 .57789 .34067 .59064 .33942 .58409 .33204 Mtetra
.538 .71 .951 r
.58409 .33204 .59064 .33942 .60348 .33837 .59696 .33084 Mtetra
.575 .723 .943 r
.59696 .33084 .60348 .33837 .61638 .33665 .60989 .32883 Mtetra
.677 .754 .909 r
.60989 .32883 .61638 .33665 .62928 .33233 .62281 .32396 Mtetra
.8 .774 .829 r
.62281 .32396 .62928 .33233 .64201 .32217 .63557 .31299 Mtetra
.87 .767 .746 r
.63557 .31299 .64201 .32217 .65443 .30401 .64803 .29419 Mtetra
.768 .737 .824 r
.64803 .29419 .65443 .30401 .66711 .29269 .66083 .28447 Mtetra
.664 .741 .907 r
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.597 .713 .925 r
.70021 .27096 .70636 .27929 .71968 .27649 .71358 .26845 Mtetra
.611 .729 .929 r
.71358 .26845 .71968 .27649 .73308 .27393 .727 .26549 Mtetra
.707 .756 .891 r
.727 .26549 .73308 .27393 .74632 .26787 .74028 .25931 Mtetra
.702 .753 .891 r
.74028 .25931 .74632 .26787 .75961 .26185 .75362 .25331 Mtetra
.679 .745 .901 r
.75362 .25331 .75961 .26185 .77302 .2567 .76708 .24815 Mtetra
.667 .742 .906 r
.76708 .24815 .77302 .2567 .78653 .25196 .78063 .24339 Mtetra
.664 .741 .907 r
.78063 .24339 .78653 .25196 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.663 .741 .908 r
.25372 .4144 .2612 .42155 .27247 .4177 .26503 .41052 Mtetra
.661 .74 .909 r
.26503 .41052 .27247 .4177 .28379 .41393 .27637 .40669 Mtetra
.649 .736 .913 r
.27637 .40669 .28379 .41393 .29513 .41053 .28774 .4032 Mtetra
.619 .725 .922 r
.28774 .4032 .29513 .41053 .30646 .40797 .29911 .40049 Mtetra
.604 .717 .924 r
.29911 .40049 .30646 .40797 .31784 .40557 .31051 .39816 Mtetra
.691 .745 .893 r
.31051 .39816 .31784 .40557 .32947 .40007 .32213 .39327 Mtetra
.735 .772 .882 r
.32213 .39327 .32947 .40007 .34116 .39412 .33389 .38675 Mtetra
.664 .741 .907 r
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.594 .718 .93 r
.36901 .37464 .37618 .38211 .38774 .38324 .38073 .37246 Mtetra
0 .151 .692 r
.38073 .37246 .38774 .38324 .39903 .3933 .39198 .38346 Mtetra
.306 .514 .894 r
.39198 .38346 .39903 .3933 .41076 .3957 .40365 .38732 Mtetra
.608 .701 .91 r
.40365 .38732 .41076 .3957 .42277 .39212 .41566 .38482 Mtetra
.712 .764 .893 r
.41566 .38482 .42277 .39212 .43492 .38572 .42783 .37896 Mtetra
.742 .786 .888 r
.42783 .37896 .43492 .38572 .44712 .3785 .44007 .37198 Mtetra
.745 .794 .893 r
.44007 .37198 .44712 .3785 .45936 .37139 .45235 .36494 Mtetra
.736 .796 .9 r
.45235 .36494 .45936 .37139 .47161 .36475 .46465 .35829 Mtetra
.721 .794 .91 r
.46465 .35829 .47161 .36475 .4839 .35869 .47698 .3522 Mtetra
.703 .79 .919 r
.47698 .3522 .4839 .35869 .49622 .35325 .48934 .34671 Mtetra
.683 .785 .927 r
.48934 .34671 .49622 .35325 .50858 .34841 .50175 .34184 Mtetra
.662 .779 .936 r
.50175 .34184 .50858 .34841 .521 .34418 .5142 .33757 Mtetra
.639 .772 .944 r
.5142 .33757 .521 .34418 .53347 .34055 .52672 .33391 Mtetra
.613 .763 .951 r
.52672 .33391 .53347 .34055 .54601 .33754 .53929 .33088 Mtetra
.586 .753 .957 r
.53929 .33088 .54601 .33754 .55862 .33515 .55194 .32845 Mtetra
.559 .741 .962 r
.55194 .32845 .55862 .33515 .57131 .33336 .56467 .32659 Mtetra
.539 .732 .964 r
.56467 .32659 .57131 .33336 .58409 .33204 .57749 .32514 Mtetra
.543 .73 .961 r
.57749 .32514 .58409 .33204 .59696 .33084 .59039 .32364 Mtetra
.597 .744 .947 r
.59039 .32364 .59696 .33084 .60989 .32883 .60335 .321 Mtetra
.708 .766 .897 r
.60335 .321 .60989 .32883 .62281 .32396 .61628 .31496 Mtetra
.814 .765 .807 r
.61628 .31496 .62281 .32396 .63557 .31299 .62904 .30243 Mtetra
.863 .745 .732 r
.62904 .30243 .63557 .31299 .64803 .29419 .64152 .28261 Mtetra
.696 .679 .829 r
.64152 .28261 .64803 .29419 .66083 .28447 .65449 .27618 Mtetra
.664 .741 .907 r
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.576 .704 .929 r
.69399 .26255 .70021 .27096 .71358 .26845 .70744 .26056 Mtetra
.633 .745 .928 r
.70744 .26056 .71358 .26845 .727 .26549 .72086 .25689 Mtetra
.709 .755 .888 r
.72086 .25689 .727 .26549 .74028 .25931 .73418 .25059 Mtetra
.698 .749 .891 r
.73418 .25059 .74028 .25931 .75362 .25331 .74757 .24465 Mtetra
.677 .743 .901 r
.74757 .24465 .75362 .25331 .76708 .24815 .76109 .23953 Mtetra
.667 .741 .906 r
.76109 .23953 .76708 .24815 .78063 .24339 .77469 .23474 Mtetra
.664 .741 .907 r
.77469 .23474 .78063 .24339 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .41052 .25752 .40327 Mtetra
.662 .74 .908 r
.25752 .40327 .26503 .41052 .27637 .40669 .2689 .39939 Mtetra
.652 .737 .912 r
.2689 .39939 .27637 .40669 .28774 .4032 .2803 .39578 Mtetra
.625 .726 .92 r
.2803 .39578 .28774 .4032 .29911 .40049 .29171 .39288 Mtetra
.603 .714 .923 r
.29171 .39288 .29911 .40049 .31051 .39816 .30313 .39056 Mtetra
.666 .735 .902 r
.30313 .39056 .31051 .39816 .32213 .39327 .31473 .38646 Mtetra
.748 .775 .875 r
.31473 .38646 .32213 .39327 .33389 .38675 .32657 .37931 Mtetra
.664 .741 .907 r
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38073 .37246 .37362 .363 Mtetra
0 .242 .755 r
.37362 .363 .38073 .37246 .39198 .38346 .38494 .37185 Mtetra
.226 .423 .846 r
.38494 .37185 .39198 .38346 .40365 .38732 .39653 .37784 Mtetra
.542 .647 .902 r
.39653 .37784 .40365 .38732 .41566 .38482 .40849 .37713 Mtetra
.682 .747 .901 r
.40849 .37713 .41566 .38482 .42783 .37896 .42067 .37232 Mtetra
.731 .789 .899 r
.42067 .37232 .42783 .37896 .44007 .37198 .43294 .36582 Mtetra
.742 .806 .903 r
.43294 .36582 .44007 .37198 .45235 .36494 .44526 .35896 Mtetra
.735 .812 .912 r
.44526 .35896 .45235 .36494 .46465 .35829 .45761 .35238 Mtetra
.722 .813 .921 r
.45761 .35238 .46465 .35829 .47698 .3522 .46998 .34627 Mtetra
.703 .809 .931 r
.46998 .34627 .47698 .3522 .48934 .34671 .48239 .34075 Mtetra
.683 .805 .94 r
.48239 .34075 .48934 .34671 .50175 .34184 .49484 .33584 Mtetra
.66 .799 .949 r
.49484 .33584 .50175 .34184 .5142 .33757 .50734 .33154 Mtetra
.634 .791 .957 r
.50734 .33154 .5142 .33757 .52672 .33391 .5199 .32786 Mtetra
.608 .782 .964 r
.5199 .32786 .52672 .33391 .53929 .33088 .53252 .32477 Mtetra
.579 .771 .97 r
.53252 .32477 .53929 .33088 .55194 .32845 .54521 .32229 Mtetra
.554 .76 .974 r
.54521 .32229 .55194 .32845 .56467 .32659 .55798 .32031 Mtetra
.541 .751 .974 r
.55798 .32031 .56467 .32659 .57749 .32514 .57084 .31859 Mtetra
.562 .752 .967 r
.57084 .31859 .57749 .32514 .59039 .32364 .58377 .31654 Mtetra
.638 .765 .94 r
.58377 .31654 .59039 .32364 .60335 .321 .59674 .31277 Mtetra
.749 .769 .869 r
.59674 .31277 .60335 .321 .61628 .31496 .60966 .30484 Mtetra
.827 .747 .776 r
.60966 .30484 .61628 .31496 .62904 .30243 .6224 .29007 Mtetra
.83 .715 .737 r
.6224 .29007 .62904 .30243 .64152 .28261 .63502 .27235 Mtetra
.66 .692 .869 r
.63502 .27235 .64152 .28261 .65449 .27618 .6481 .26781 Mtetra
.664 .741 .907 r
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.553 .693 .932 r
.68773 .25407 .69399 .26255 .70744 .26056 .70125 .25265 Mtetra
.661 .757 .921 r
.70125 .25265 .70744 .26056 .72086 .25689 .71466 .24809 Mtetra
.709 .752 .885 r
.71466 .24809 .72086 .25689 .73418 .25059 .72802 .2417 Mtetra
.694 .745 .891 r
.72802 .2417 .73418 .25059 .74757 .24465 .74148 .23589 Mtetra
.674 .742 .901 r
.74148 .23589 .74757 .24465 .76109 .23953 .75504 .23082 Mtetra
.666 .741 .906 r
.75504 .23082 .76109 .23953 .77469 .23474 .76869 .22601 Mtetra
.664 .741 .907 r
.76869 .22601 .77469 .23474 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40327 .24995 .39597 Mtetra
.662 .74 .908 r
.24995 .39597 .25752 .40327 .2689 .39939 .26136 .39203 Mtetra
.655 .738 .91 r
.26136 .39203 .2689 .39939 .2803 .39578 .2728 .38829 Mtetra
.633 .729 .917 r
.2728 .38829 .2803 .39578 .29171 .39288 .28425 .38516 Mtetra
.605 .714 .921 r
.28425 .38516 .29171 .39288 .30313 .39056 .2957 .38275 Mtetra
.639 .723 .909 r
.2957 .38275 .30313 .39056 .31473 .38646 .30727 .37942 Mtetra
.755 .771 .866 r
.30727 .37942 .31473 .38646 .32657 .37931 .31918 .37182 Mtetra
.664 .741 .907 r
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.293 .577 .938 r
.36636 .35537 .37362 .363 .38494 .37185 .37797 .35806 Mtetra
.152 .331 .79 r
.37797 .35806 .38494 .37185 .39653 .37784 .38944 .36646 Mtetra
.446 .556 .874 r
.38944 .36646 .39653 .37784 .40849 .37713 .40131 .36837 Mtetra
.625 .702 .9 r
.40131 .36837 .40849 .37713 .42067 .37232 .41346 .36531 Mtetra
.704 .775 .907 r
.41346 .36531 .42067 .37232 .43294 .36582 .42574 .35975 Mtetra
.73 .809 .913 r
.42574 .35975 .43294 .36582 .44526 .35896 .43809 .35333 Mtetra
.731 .824 .922 r
.43809 .35333 .44526 .35896 .45761 .35238 .45049 .34691 Mtetra
.719 .828 .932 r
.45049 .34691 .45761 .35238 .46998 .34627 .46291 .34087 Mtetra
.702 .828 .943 r
.46291 .34087 .46998 .34627 .48239 .34075 .47537 .33535 Mtetra
.68 .824 .952 r
.47537 .33535 .48239 .34075 .49484 .33584 .48787 .33041 Mtetra
.656 .818 .961 r
.48787 .33041 .49484 .33584 .50734 .33154 .50041 .32608 Mtetra
.629 .81 .969 r
.50041 .32608 .50734 .33154 .5199 .32786 .51302 .32234 Mtetra
.601 .8 .976 r
.51302 .32234 .5199 .32786 .53252 .32477 .52568 .31921 Mtetra
.574 .789 .981 r
.52568 .31921 .53252 .32477 .54521 .32229 .53842 .31659 Mtetra
.555 .778 .982 r
.53842 .31659 .54521 .32229 .55798 .32031 .55123 .31437 Mtetra
.559 .772 .978 r
.55123 .31437 .55798 .32031 .57084 .31859 .56412 .31214 Mtetra
.605 .774 .961 r
.56412 .31214 .57084 .31859 .58377 .31654 .57708 .30906 Mtetra
.697 .775 .912 r
.57708 .30906 .58377 .31654 .59674 .31277 .59005 .30344 Mtetra
.786 .754 .824 r
.59005 .30344 .59674 .31277 .60966 .30484 .60295 .29278 Mtetra
.83 .719 .742 r
.60295 .29278 .60966 .30484 .6224 .29007 .61567 .27549 Mtetra
.751 .66 .76 r
.61567 .27549 .6224 .29007 .63502 .27235 .62853 .26396 Mtetra
.664 .741 .907 r
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.535 .684 .935 r
.68141 .24552 .68773 .25407 .70125 .25265 .69499 .24449 Mtetra
.686 .761 .909 r
.69499 .24449 .70125 .25265 .71466 .24809 .7084 .23907 Mtetra
.707 .747 .883 r
.7084 .23907 .71466 .24809 .72802 .2417 .72181 .23269 Mtetra
.688 .741 .892 r
.72181 .23269 .72802 .2417 .74148 .23589 .73532 .22705 Mtetra
.671 .741 .902 r
.73532 .22705 .74148 .23589 .75504 .23082 .74894 .22203 Mtetra
.665 .741 .906 r
.74894 .22203 .75504 .23082 .76869 .22601 .76263 .21721 Mtetra
.664 .741 .907 r
.76263 .21721 .76869 .22601 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39597 .24232 .3886 Mtetra
.663 .74 .908 r
.24232 .3886 .24995 .39597 .26136 .39203 .25376 .38462 Mtetra
.658 .739 .909 r
.25376 .38462 .26136 .39203 .2728 .38829 .26524 .38076 Mtetra
.642 .732 .914 r
.26524 .38076 .2728 .38829 .28425 .38516 .27673 .37736 Mtetra
.613 .716 .919 r
.27673 .37736 .28425 .38516 .2957 .38275 .28822 .37474 Mtetra
.618 .713 .913 r
.28822 .37474 .2957 .38275 .30727 .37942 .29978 .37198 Mtetra
.717 .756 .883 r
.29978 .37198 .30727 .37942 .31918 .37182 .31162 .36597 Mtetra
.719 .803 .916 r
.31162 .36597 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.664 .741 .907 r
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37797 .35806 .371 .34348 Mtetra
.148 .315 .776 r
.371 .34348 .37797 .35806 .38944 .36646 .38243 .35235 Mtetra
.34 .443 .821 r
.38243 .35235 .38944 .36646 .40131 .36837 .39416 .35745 Mtetra
.535 .614 .878 r
.39416 .35745 .40131 .36837 .41346 .36531 .40622 .35707 Mtetra
.651 .727 .905 r
.40622 .35707 .41346 .36531 .42574 .35975 .41849 .35318 Mtetra
.702 .79 .919 r
.41849 .35318 .42574 .35975 .43809 .35333 .43086 .34766 Mtetra
.717 .822 .93 r
.43086 .34766 .43809 .35333 .45049 .34691 .44329 .34168 Mtetra
.712 .836 .941 r
.44329 .34168 .45049 .34691 .46291 .34087 .45576 .33582 Mtetra
.696 .84 .952 r
.45576 .33582 .46291 .34087 .47537 .33535 .46826 .33038 Mtetra
.675 .839 .962 r
.46826 .33038 .47537 .33535 .48787 .33041 .48081 .32544 Mtetra
.651 .834 .971 r
.48081 .32544 .48787 .33041 .50041 .32608 .49341 .32108 Mtetra
.624 .826 .978 r
.49341 .32108 .50041 .32608 .51302 .32234 .50606 .31727 Mtetra
.599 .816 .983 r
.50606 .31727 .51302 .32234 .52568 .31921 .51877 .31399 Mtetra
.579 .805 .985 r
.51877 .31399 .52568 .31921 .53842 .31659 .53155 .31111 Mtetra
.575 .796 .983 r
.53155 .31111 .53842 .31659 .55123 .31437 .54441 .30838 Mtetra
.604 .79 .97 r
.54441 .30838 .55123 .31437 .56412 .31214 .55733 .30518 Mtetra
.673 .783 .932 r
.55733 .30518 .56412 .31214 .57708 .30906 .57031 .30034 Mtetra
.754 .76 .858 r
.57031 .30034 .57708 .30906 .59005 .30344 .58327 .29192 Mtetra
.805 .721 .771 r
.58327 .29192 .59005 .30344 .60295 .29278 .59614 .27794 Mtetra
.809 .681 .722 r
.59614 .27794 .60295 .29278 .61567 .27549 .60888 .26009 Mtetra
.641 .599 .791 r
.60888 .26009 .61567 .27549 .62853 .26396 .62198 .25549 Mtetra
.664 .741 .907 r
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.607 .718 .923 r
.66168 .24157 .6681 .25016 .68141 .24552 .67512 .23864 Mtetra
.586 .762 .962 r
.67512 .23864 .68141 .24552 .69499 .24449 .68866 .2359 Mtetra
.701 .757 .895 r
.68866 .2359 .69499 .24449 .7084 .23907 .70208 .22982 Mtetra
.702 .742 .882 r
.70208 .22982 .7084 .23907 .72181 .23269 .71554 .22359 Mtetra
.682 .739 .894 r
.71554 .22359 .72181 .23269 .73532 .22705 .72912 .21815 Mtetra
.669 .74 .903 r
.72912 .21815 .73532 .22705 .74894 .22203 .74278 .21318 Mtetra
.665 .741 .907 r
.74278 .21318 .74894 .22203 .76263 .21721 .75653 .20833 Mtetra
.664 .741 .907 r
.75653 .20833 .76263 .21721 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.663 .741 .908 r
.23463 .38118 .24232 .3886 .25376 .38462 .2461 .37715 Mtetra
.661 .74 .908 r
.2461 .37715 .25376 .38462 .26524 .38076 .25761 .37319 Mtetra
.649 .734 .911 r
.25761 .37319 .26524 .38076 .27673 .37736 .26915 .36955 Mtetra
.624 .721 .916 r
.26915 .36955 .27673 .37736 .28822 .37474 .28069 .36659 Mtetra
.608 .707 .914 r
.28069 .36659 .28822 .37474 .29978 .37198 .29226 .36406 Mtetra
.667 .733 .899 r
.29226 .36406 .29978 .37198 .31162 .36597 .304 .35979 Mtetra
.754 .799 .889 r
.304 .35979 .31162 .36597 .32348 .36014 .316 .35249 Mtetra
.664 .741 .907 r
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.513 .685 .945 r
.36365 .33569 .371 .34348 .38243 .35235 .37553 .33507 Mtetra
.269 .351 .764 r
.37553 .33507 .38243 .35235 .39416 .35745 .38711 .34308 Mtetra
.429 .493 .824 r
.38711 .34308 .39416 .35745 .40622 .35707 .39903 .34616 Mtetra
.564 .63 .875 r
.39903 .34616 .40622 .35707 .41849 .35318 .41122 .34494 Mtetra
.647 .729 .908 r
.41122 .34494 .41849 .35318 .43086 .34766 .42358 .34109 Mtetra
.685 .789 .929 r
.42358 .34109 .43086 .34766 .44329 .34168 .43602 .33606 Mtetra
.695 .822 .943 r
.43602 .33606 .44329 .34168 .45576 .33582 .44853 .33069 Mtetra
.687 .837 .955 r
.44853 .33069 .45576 .33582 .46826 .33038 .46108 .32548 Mtetra
.67 .842 .966 r
.46108 .32548 .46826 .33038 .48081 .32544 .47368 .32062 Mtetra
.649 .84 .974 r
.47368 .32062 .48081 .32544 .49341 .32108 .48633 .31622 Mtetra
.627 .834 .98 r
.48633 .31622 .49341 .32108 .50606 .31727 .49903 .31227 Mtetra
.61 .824 .982 r
.49903 .31227 .50606 .31727 .51877 .31399 .51179 .30868 Mtetra
.606 .814 .98 r
.51179 .30868 .51877 .31399 .53155 .31111 .52462 .30525 Mtetra
.627 .803 .967 r
.52462 .30525 .53155 .31111 .54441 .30838 .53752 .30149 Mtetra
.676 .787 .933 r
.53752 .30149 .54441 .30838 .55733 .30518 .55047 .29652 Mtetra
.739 .758 .868 r
.55047 .29652 .55733 .30518 .57031 .30034 .56345 .2889 Mtetra
.784 .716 .789 r
.56345 .2889 .57031 .30034 .58327 .29192 .57639 .2769 Mtetra
.801 .676 .726 r
.57639 .2769 .58327 .29192 .59614 .27794 .58922 .25988 Mtetra
.687 .595 .747 r
.58922 .25988 .59614 .27794 .60888 .26009 .60223 .25159 Mtetra
.664 .741 .907 r
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.551 .692 .933 r
.6552 .23291 .66168 .24157 .67512 .23864 .66876 .23142 Mtetra
.658 .782 .94 r
.66876 .23142 .67512 .23864 .68866 .2359 .68224 .22681 Mtetra
.706 .748 .884 r
.68224 .22681 .68866 .2359 .70208 .22982 .6957 .22042 Mtetra
.694 .737 .884 r
.6957 .22042 .70208 .22982 .71554 .22359 .70923 .21445 Mtetra
.676 .738 .897 r
.70923 .21445 .71554 .22359 .72912 .21815 .72286 .20919 Mtetra
.667 .74 .905 r
.72286 .20919 .72912 .21815 .74278 .21318 .73658 .20425 Mtetra
.664 .741 .907 r
.73658 .20425 .74278 .21318 .75653 .20833 .75037 .19937 Mtetra
.75037 .19937 .75653 .20833 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37715 .23838 .36963 Mtetra
.662 .74 .908 r
.23838 .36963 .2461 .37715 .25761 .37319 .24992 .36559 Mtetra
.655 .737 .91 r
.24992 .36559 .25761 .37319 .26915 .36955 .26151 .36173 Mtetra
.636 .726 .913 r
.26151 .36173 .26915 .36955 .28069 .36659 .2731 .3584 Mtetra
.612 .709 .914 r
.2731 .3584 .28069 .36659 .29226 .36406 .2847 .35573 Mtetra
.628 .712 .907 r
.2847 .35573 .29226 .36406 .304 .35979 .29639 .35262 Mtetra
.729 .77 .885 r
.29639 .35262 .304 .35979 .316 .35249 .30837 .34612 Mtetra
.708 .789 .915 r
.30837 .34612 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.664 .741 .907 r
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .37553 .33507 .36833 .32356 Mtetra
.48 .575 .873 r
.36833 .32356 .37553 .33507 .38711 .34308 .38022 .32456 Mtetra
.356 .393 .762 r
.38022 .32456 .38711 .34308 .39903 .34616 .39198 .33087 Mtetra
.466 .502 .811 r
.39198 .33087 .39903 .34616 .41122 .34494 .40403 .33311 Mtetra
.562 .612 .86 r
.40403 .33311 .41122 .34494 .42358 .34109 .41631 .33196 Mtetra
.627 .701 .899 r
.41631 .33196 .42358 .34109 .43602 .33606 .42874 .32869 Mtetra
.66 .761 .925 r
.42874 .32869 .43602 .33606 .44853 .33069 .44126 .32438 Mtetra
.669 .797 .943 r
.44126 .32438 .44853 .33069 .46108 .32548 .45384 .31972 Mtetra
.665 .815 .955 r
.45384 .31972 .46108 .32548 .47368 .32062 .46648 .3151 Mtetra
.655 .82 .963 r
.46648 .3151 .47368 .32062 .48633 .31622 .47918 .31066 Mtetra
.646 .818 .966 r
.47918 .31066 .48633 .31622 .49903 .31227 .49193 .30641 Mtetra
.646 .809 .961 r
.49193 .30641 .49903 .31227 .51179 .30868 .50474 .30219 Mtetra
.662 .795 .946 r
.50474 .30219 .51179 .30868 .52462 .30525 .51762 .29762 Mtetra
.695 .772 .911 r
.51762 .29762 .52462 .30525 .53752 .30149 .53055 .292 Mtetra
.735 .739 .854 r
.53055 .292 .53752 .30149 .55047 .29652 .54353 .28424 Mtetra
.766 .698 .787 r
.54353 .28424 .55047 .29652 .56345 .2889 .5565 .27303 Mtetra
.78 .66 .73 r
.5565 .27303 .56345 .2889 .57639 .2769 .56942 .25768 Mtetra
.702 .593 .731 r
.56942 .25768 .57639 .2769 .58922 .25988 .58241 .24767 Mtetra
.653 .655 .839 r
.58241 .24767 .58922 .25988 .60223 .25159 .59553 .24301 Mtetra
.664 .741 .907 r
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.62 .723 .92 r
.63529 .22892 .64187 .23761 .6552 .23291 .64873 .22555 Mtetra
.573 .744 .957 r
.64873 .22555 .6552 .23291 .66876 .23142 .66229 .22316 Mtetra
.695 .767 .907 r
.66229 .22316 .66876 .23142 .68224 .22681 .67576 .21729 Mtetra
.702 .738 .879 r
.67576 .21729 .68224 .22681 .6957 .22042 .68926 .21096 Mtetra
.685 .734 .888 r
.68926 .21096 .6957 .22042 .70923 .21445 .70286 .2053 Mtetra
.671 .737 .9 r
.70286 .2053 .70923 .21445 .72286 .20919 .71655 .20018 Mtetra
.665 .74 .906 r
.71655 .20018 .72286 .20919 .73658 .20425 .73031 .19524 Mtetra
.664 .741 .907 r
.73031 .19524 .73658 .20425 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36963 .23059 .36205 Mtetra
.663 .74 .908 r
.23059 .36205 .23838 .36963 .24992 .36559 .24217 .35795 Mtetra
.66 .739 .908 r
.24217 .35795 .24992 .36559 .26151 .36173 .25379 .35393 Mtetra
.648 .732 .911 r
.25379 .35393 .26151 .36173 .2731 .3584 .26544 .35026 Mtetra
.625 .716 .912 r
.26544 .35026 .2731 .3584 .2847 .35573 .27709 .34721 Mtetra
.612 .703 .909 r
.27709 .34721 .2847 .35573 .29639 .35262 .28877 .3445 Mtetra
.663 .731 .9 r
.28877 .3445 .29639 .35262 .30837 .34612 .30063 .3403 Mtetra
.76 .814 .895 r
.30063 .3403 .30837 .34612 .32033 .34057 .31276 .33276 Mtetra
.664 .741 .907 r
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38022 .32456 .37306 .31126 Mtetra
.551 .579 .835 r
.37306 .31126 .38022 .32456 .39198 .33087 .38512 .31055 Mtetra
.411 .409 .747 r
.38512 .31055 .39198 .33087 .40403 .33311 .39703 .3157 Mtetra
.483 .485 .783 r
.39703 .3157 .40403 .33311 .41631 .33196 .40918 .31776 Mtetra
.55 .566 .824 r
.40918 .31776 .41631 .33196 .42874 .32869 .42153 .31712 Mtetra
.602 .639 .86 r
.42153 .31712 .42874 .32869 .44126 .32438 .43401 .31462 Mtetra
.634 .692 .887 r
.43401 .31462 .44126 .32438 .45384 .31972 .4466 .31105 Mtetra
.652 .727 .904 r
.4466 .31105 .45384 .31972 .46648 .3151 .45927 .30691 Mtetra
.662 .744 .911 r
.45927 .30691 .46648 .3151 .47918 .31066 .472 .30243 Mtetra
.672 .747 .907 r
.472 .30243 .47918 .31066 .49193 .30641 .4848 .29762 Mtetra
.686 .738 .891 r
.4848 .29762 .49193 .30641 .50474 .30219 .49765 .29223 Mtetra
.706 .718 .859 r
.49765 .29223 .50474 .30219 .51762 .29762 .51057 .28576 Mtetra
.728 .691 .814 r
.51057 .28576 .51762 .29762 .53055 .292 .52353 .2774 Mtetra
.746 .659 .765 r
.52353 .2774 .53055 .292 .54353 .28424 .53652 .26631 Mtetra
.755 .63 .723 r
.53652 .26631 .54353 .28424 .5565 .27303 .54948 .25207 Mtetra
.673 .565 .725 r
.54948 .25207 .5565 .27303 .56942 .25768 .5625 .24373 Mtetra
.647 .624 .813 r
.5625 .24373 .56942 .25768 .58241 .24767 .57561 .23906 Mtetra
.664 .741 .907 r
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.545 .69 .934 r
.62866 .22014 .63529 .22892 .64873 .22555 .64222 .21874 Mtetra
.662 .798 .948 r
.64222 .21874 .64873 .22555 .66229 .22316 .65572 .21392 Mtetra
.704 .746 .885 r
.65572 .21392 .66229 .22316 .67576 .21729 .66921 .20755 Mtetra
.693 .731 .88 r
.66921 .20755 .67576 .21729 .68926 .21096 .68278 .20153 Mtetra
.677 .734 .893 r
.68278 .20153 .68926 .21096 .70286 .2053 .69644 .19615 Mtetra
.668 .738 .903 r
.69644 .19615 .70286 .2053 .71655 .20018 .71018 .19111 Mtetra
.665 .74 .906 r
.71018 .19111 .71655 .20018 .73031 .19524 .72399 .18616 Mtetra
.664 .741 .907 r
.72399 .18616 .73031 .19524 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16622 Mtetra
.77994 .16622 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35795 .23435 .35026 Mtetra
.662 .74 .908 r
.23435 .35026 .24217 .35795 .25379 .35393 .24601 .34614 Mtetra
.655 .736 .909 r
.24601 .34614 .25379 .35393 .26544 .35026 .2577 .34219 Mtetra
.639 .725 .91 r
.2577 .34219 .26544 .35026 .27709 .34721 .26941 .3387 Mtetra
.618 .707 .909 r
.26941 .3387 .27709 .34721 .28877 .3445 .28114 .33581 Mtetra
.623 .704 .904 r
.28114 .33581 .28877 .3445 .30063 .3403 .29293 .33277 Mtetra
.696 .758 .9 r
.29293 .33277 .30063 .3403 .31276 .33276 .30495 .32744 Mtetra
.745 .831 .917 r
.30495 .32744 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.664 .741 .907 r
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38512 .31055 .37785 .2988 Mtetra
.653 .655 .84 r
.37785 .2988 .38512 .31055 .39703 .3157 .39017 .29439 Mtetra
.485 .447 .74 r
.39017 .29439 .39703 .3157 .40918 .31776 .40227 .2969 Mtetra
.501 .462 .745 r
.40227 .2969 .40918 .31776 .42153 .31712 .41451 .29868 Mtetra
.547 .512 .769 r
.41451 .29868 .42153 .31712 .43401 .31462 .42692 .29831 Mtetra
.586 .559 .79 r
.42692 .29831 .43401 .31462 .4466 .31105 .43947 .29621 Mtetra
.619 .595 .804 r
.43947 .29621 .4466 .31105 .45927 .30691 .45212 .29279 Mtetra
.644 .618 .809 r
.45212 .29279 .45927 .30691 .472 .30243 .46487 .28826 Mtetra
.665 .628 .803 r
.46487 .28826 .472 .30243 .4848 .29762 .4777 .28265 Mtetra
.685 .627 .785 r
.4777 .28265 .4848 .29762 .49765 .29223 .49058 .27569 Mtetra
.701 .617 .76 r
.49058 .27569 .49765 .29223 .51057 .28576 .50353 .26698 Mtetra
.715 .604 .731 r
.50353 .26698 .51057 .28576 .52353 .2774 .5165 .25609 Mtetra
.708 .582 .712 r
.5165 .25609 .52353 .2774 .53652 .26631 .52949 .24445 Mtetra
.619 .528 .729 r
.52949 .24445 .53652 .26631 .54948 .25207 .54251 .23978 Mtetra
.653 .655 .84 r
.54251 .23978 .54948 .25207 .5625 .24373 .5556 .23509 Mtetra
.664 .741 .907 r
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.575 .704 .93 r
.60857 .21609 .6153 .2249 .62866 .22014 .62206 .21392 Mtetra
.615 .801 .971 r
.62206 .21392 .62866 .22014 .64222 .21874 .63557 .21017 Mtetra
.699 .762 .901 r
.63557 .21017 .64222 .21874 .65572 .21392 .64907 .20407 Mtetra
.697 .731 .877 r
.64907 .20407 .65572 .21392 .66921 .20755 .66262 .19782 Mtetra
.682 .729 .886 r
.66262 .19782 .66921 .20755 .68278 .20153 .67625 .19217 Mtetra
.671 .735 .898 r
.67625 .19217 .68278 .20153 .69644 .19615 .68996 .18699 Mtetra
.665 .739 .905 r
.68996 .18699 .69644 .19615 .71018 .19111 .70376 .18199 Mtetra
.664 .74 .907 r
.70376 .18199 .71018 .19111 .72399 .18616 .71762 .177 Mtetra
.664 .741 .907 r
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16622 .77376 .15688 Mtetra
.77376 .15688 .77994 .16622 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36332 Mtetra
.16877 .36332 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35026 .22646 .34252 Mtetra
.663 .74 .907 r
.22646 .34252 .23435 .35026 .24601 .34614 .23816 .33832 Mtetra
.66 .739 .908 r
.23816 .33832 .24601 .34614 .2577 .34219 .24989 .3342 Mtetra
.651 .732 .909 r
.24989 .3342 .2577 .34219 .26941 .3387 .26166 .33033 Mtetra
.633 .717 .908 r
.26166 .33033 .26941 .3387 .28114 .33581 .27345 .32697 Mtetra
.617 .701 .904 r
.27345 .32697 .28114 .33581 .29293 .33277 .28525 .32407 Mtetra
.635 .711 .902 r
.28525 .32407 .29293 .33277 .30495 .32744 .29716 .32062 Mtetra
.716 .784 .906 r
.29716 .32062 .30495 .32744 .31711 .32058 .30931 .31461 Mtetra
.728 .812 .917 r
.30931 .31461 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.664 .741 .907 r
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40227 .2969 .39512 .28171 Mtetra
.64 .599 .792 r
.39512 .28171 .40227 .2969 .41451 .29868 .40759 .27722 Mtetra
.587 .509 .734 r
.40759 .27722 .41451 .29868 .42692 .29831 .42004 .27463 Mtetra
.561 .478 .719 r
.42004 .27463 .42692 .29831 .43947 .29621 .43253 .27345 Mtetra
.59 .503 .724 r
.43253 .27345 .43947 .29621 .45212 .29279 .44515 .27055 Mtetra
.617 .523 .725 r
.44515 .27055 .45212 .29279 .46487 .28826 .45788 .26598 Mtetra
.64 .537 .721 r
.45788 .26598 .46487 .28826 .4777 .28265 .4707 .25973 Mtetra
.66 .544 .712 r
.4707 .25973 .4777 .28265 .49058 .27569 .48359 .25175 Mtetra
.639 .526 .709 r
.48359 .25175 .49058 .27569 .50353 .26698 .4965 .24516 Mtetra
.619 .528 .729 r
.4965 .24516 .50353 .26698 .5165 .25609 .50944 .2405 Mtetra
.64 .599 .792 r
.50944 .2405 .5165 .25609 .52949 .24445 .52244 .23581 Mtetra
.664 .741 .907 r
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.596 .713 .926 r
.58839 .21203 .59523 .22088 .60857 .21609 .60183 .20926 Mtetra
.595 .774 .966 r
.60183 .20926 .60857 .21609 .62206 .21392 .61533 .20613 Mtetra
.691 .782 .92 r
.61533 .20613 .62206 .21392 .63557 .21017 .62883 .20038 Mtetra
.699 .734 .878 r
.62883 .20038 .63557 .21017 .64907 .20407 .64236 .19406 Mtetra
.686 .725 .88 r
.64236 .19406 .64907 .20407 .66262 .19782 .65597 .18821 Mtetra
.674 .731 .893 r
.65597 .18821 .66262 .19782 .67625 .19217 .66966 .18288 Mtetra
.667 .737 .902 r
.66966 .18288 .67625 .19217 .68996 .18699 .68343 .17779 Mtetra
.664 .74 .906 r
.68343 .17779 .68996 .18699 .70376 .18199 .69728 .17278 Mtetra
.664 .741 .907 r
.69728 .17278 .70376 .18199 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14746 Mtetra
.76752 .14746 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36332 .16067 .35569 Mtetra
.16067 .35569 .16877 .36332 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34252 .21851 .33472 Mtetra
.21851 .33472 .22646 .34252 .23816 .33832 .23024 .33047 Mtetra
.663 .74 .908 r
.23024 .33047 .23816 .33832 .24989 .3342 .24201 .32624 Mtetra
.658 .737 .908 r
.24201 .32624 .24989 .3342 .26166 .33033 .25383 .32212 Mtetra
.648 .728 .907 r
.25383 .32212 .26166 .33033 .27345 .32697 .26568 .3183 Mtetra
.63 .711 .905 r
.26568 .3183 .27345 .32697 .28525 .32407 .27754 .31497 Mtetra
.619 .697 .9 r
.27754 .31497 .28525 .32407 .29716 .32062 .28944 .31196 Mtetra
.643 .718 .902 r
.28944 .31196 .29716 .32062 .30931 .31461 .30145 .30823 Mtetra
.717 .8 .916 r
.30145 .30823 .30931 .31461 .32152 .30825 .31369 .30218 Mtetra
.728 .812 .917 r
.31369 .30218 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.664 .741 .907 r
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42004 .27463 .4127 .26431 Mtetra
.659 .693 .87 r
.4127 .26431 .42004 .27463 .43253 .27345 .42532 .25973 Mtetra
.646 .626 .815 r
.42532 .25973 .43253 .27345 .44515 .27055 .43799 .25514 Mtetra
.64 .6 .793 r
.43799 .25514 .44515 .27055 .45788 .26598 .45073 .25052 Mtetra
.45073 .25052 .45788 .26598 .4707 .25973 .46353 .24588 Mtetra
.646 .626 .815 r
.46353 .24588 .4707 .25973 .48359 .25175 .47639 .24122 Mtetra
.659 .693 .87 r
.47639 .24122 .48359 .25175 .4965 .24516 .48931 .23653 Mtetra
.664 .741 .907 r
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.596 .714 .926 r
.56814 .20795 .57508 .21683 .58839 .21203 .58154 .20516 Mtetra
.595 .775 .966 r
.58154 .20516 .58839 .21203 .60183 .20926 .59501 .20199 Mtetra
.684 .796 .934 r
.59501 .20199 .60183 .20926 .61533 .20613 .6085 .19646 Mtetra
.698 .737 .881 r
.6085 .19646 .61533 .20613 .62883 .20038 .62202 .19018 Mtetra
.688 .722 .876 r
.62202 .19018 .62883 .20038 .64236 .19406 .63561 .18422 Mtetra
.676 .727 .888 r
.63561 .18422 .64236 .19406 .65597 .18821 .64928 .17876 Mtetra
.668 .735 .9 r
.64928 .17876 .65597 .18821 .66966 .18288 .66303 .1736 Mtetra
.665 .739 .905 r
.66303 .1736 .66966 .18288 .68343 .17779 .67685 .16854 Mtetra
.664 .74 .907 r
.67685 .16854 .68343 .17779 .69728 .17278 .69074 .1635 Mtetra
.664 .741 .907 r
.69074 .1635 .69728 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14746 .76122 .13795 Mtetra
.76122 .13795 .76752 .14746 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33047 .22225 .32257 Mtetra
.663 .741 .907 r
.22225 .32257 .23024 .33047 .24201 .32624 .23406 .31827 Mtetra
.662 .739 .907 r
.23406 .31827 .24201 .32624 .25383 .32212 .24592 .31401 Mtetra
.657 .735 .907 r
.24592 .31401 .25383 .32212 .26568 .3183 .25782 .30987 Mtetra
.646 .724 .906 r
.25782 .30987 .26568 .3183 .27754 .31497 .26975 .30603 Mtetra
.63 .707 .901 r
.26975 .30603 .27754 .31497 .28944 .31196 .2817 .30264 Mtetra
.622 .696 .897 r
.2817 .30264 .28944 .31196 .30145 .30823 .2937 .29948 Mtetra
.642 .718 .903 r
.2937 .29948 .30145 .30823 .31369 .30218 .3058 .29571 Mtetra
.701 .797 .925 r
.3058 .29571 .31369 .30218 .32598 .29575 .31808 .29015 Mtetra
.745 .831 .917 r
.31808 .29015 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.664 .741 .907 r
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.573 .704 .931 r
.5478 .20385 .55484 .21277 .56814 .20795 .56117 .20162 Mtetra
.614 .8 .971 r
.56117 .20162 .56814 .20795 .58154 .20516 .5746 .19787 Mtetra
.685 .796 .933 r
.5746 .19787 .58154 .20516 .59501 .20199 .58807 .1923 Mtetra
.696 .737 .883 r
.58807 .1923 .59501 .20199 .6085 .19646 .60159 .1861 Mtetra
.687 .719 .874 r
.60159 .1861 .6085 .19646 .62202 .19018 .61516 .18012 Mtetra
.676 .723 .885 r
.61516 .18012 .62202 .19018 .63561 .18422 .62881 .1746 Mtetra
.669 .732 .897 r
.62881 .1746 .63561 .18422 .64928 .17876 .64254 .16938 Mtetra
.665 .738 .904 r
.64254 .16938 .64928 .17876 .66303 .1736 .65633 .16429 Mtetra
.664 .74 .906 r
.65633 .16429 .66303 .1736 .67685 .16854 .6702 .15922 Mtetra
.664 .741 .907 r
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13795 .75486 .12835 Mtetra
.75486 .12835 .76122 .13795 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32257 .2142 .3146 Mtetra
.2142 .3146 .22225 .32257 .23406 .31827 .22604 .31026 Mtetra
.663 .74 .907 r
.22604 .31026 .23406 .31827 .24592 .31401 .23793 .30592 Mtetra
.662 .739 .907 r
.23793 .30592 .24592 .31401 .25782 .30987 .24987 .3016 Mtetra
.657 .734 .906 r
.24987 .3016 .25782 .30987 .26975 .30603 .26186 .29741 Mtetra
.647 .723 .904 r
.26186 .29741 .26975 .30603 .2817 .30264 .27388 .29349 Mtetra
.634 .706 .898 r
.27388 .29349 .2817 .30264 .2937 .29948 .28593 .28995 Mtetra
.626 .695 .894 r
.28593 .28995 .2937 .29948 .3058 .29571 .29803 .28662 Mtetra
.637 .71 .9 r
.29803 .28662 .3058 .29571 .31808 .29015 .31021 .28295 Mtetra
.675 .773 .924 r
.31021 .28295 .31808 .29015 .33051 .28309 .32253 .27813 Mtetra
.728 .851 .939 r
.32253 .27813 .33051 .28309 .34281 .2786 .33501 .27163 Mtetra
.708 .789 .915 r
.33501 .27163 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.664 .741 .907 r
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.619 .724 .921 r
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .20112 Mtetra
.588 .751 .955 r
.52738 .20112 .53453 .20869 .5478 .20385 .54071 .19825 Mtetra
.641 .833 .974 r
.54071 .19825 .5478 .20385 .56117 .20162 .55411 .19366 Mtetra
.689 .779 .919 r
.55411 .19366 .56117 .20162 .5746 .19787 .56756 .18792 Mtetra
.692 .73 .88 r
.56756 .18792 .5746 .19787 .58807 .1923 .58106 .18181 Mtetra
.684 .716 .873 r
.58106 .18181 .58807 .1923 .60159 .1861 .59462 .17591 Mtetra
.675 .72 .883 r
.59462 .17591 .60159 .1861 .61516 .18012 .60826 .17039 Mtetra
.669 .73 .895 r
.60826 .17039 .61516 .18012 .62881 .1746 .62196 .16514 Mtetra
.666 .737 .903 r
.62196 .16514 .62881 .1746 .64254 .16938 .63574 .16002 Mtetra
.664 .74 .906 r
.63574 .16002 .64254 .16938 .65633 .16429 .64958 .15492 Mtetra
.664 .74 .907 r
.64958 .15492 .65633 .16429 .6702 .15922 .6635 .14982 Mtetra
.664 .741 .907 r
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14751 .32817 Mtetra
.14751 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30592 .22987 .29779 Mtetra
.663 .74 .907 r
.22987 .29779 .23793 .30592 .24987 .3016 .24185 .29339 Mtetra
.662 .738 .907 r
.24185 .29339 .24987 .3016 .26186 .29741 .25388 .28902 Mtetra
.657 .733 .905 r
.25388 .28902 .26186 .29741 .27388 .29349 .26596 .28475 Mtetra
.65 .723 .902 r
.26596 .28475 .27388 .29349 .28593 .28995 .27808 .28069 Mtetra
.639 .708 .896 r
.27808 .28069 .28593 .28995 .29803 .28662 .29023 .27693 Mtetra
.631 .695 .891 r
.29023 .27693 .29803 .28662 .31021 .28295 .30243 .27339 Mtetra
.634 .7 .894 r
.30243 .27339 .31021 .28295 .32253 .27813 .3147 .26975 Mtetra
.651 .737 .912 r
.3147 .26975 .32253 .27813 .33501 .27163 .32706 .26557 Mtetra
.681 .812 .946 r
.32706 .26557 .33501 .27163 .34749 .26571 .33954 .26048 Mtetra
.712 .845 .946 r
.33954 .26048 .34749 .26571 .35995 .26114 .35213 .2544 Mtetra
.719 .803 .916 r
.35213 .2544 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.664 .741 .907 r
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.605 .719 .925 r
.48048 .20535 .48781 .21425 .50094 .20944 .49362 .20225 Mtetra
.607 .77 .958 r
.49362 .20225 .50094 .20944 .51413 .2046 .50685 .19886 Mtetra
.635 .826 .974 r
.50685 .19886 .51413 .2046 .52738 .20112 .52016 .19447 Mtetra
.675 .812 .949 r
.52016 .19447 .52738 .20112 .54071 .19825 .53353 .18916 Mtetra
.69 .75 .898 r
.53353 .18916 .54071 .19825 .55411 .19366 .54696 .18329 Mtetra
.686 .719 .875 r
.54696 .18329 .55411 .19366 .56756 .18792 .56045 .17733 Mtetra
.68 .713 .874 r
.56045 .17733 .56756 .18792 .58106 .18181 .574 .17157 Mtetra
.673 .72 .884 r
.574 .17157 .58106 .18181 .59462 .17591 .58761 .16611 Mtetra
.668 .729 .895 r
.58761 .16611 .59462 .17591 .60826 .17039 .6013 .16087 Mtetra
.665 .736 .902 r
.6013 .16087 .60826 .17039 .62196 .16514 .61505 .15573 Mtetra
.664 .739 .906 r
.61505 .15573 .62196 .16514 .63574 .16002 .62887 .15061 Mtetra
.664 .74 .907 r
.62887 .15061 .63574 .16002 .64958 .15492 .64277 .14548 Mtetra
.664 .741 .907 r
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14751 .32817 .13917 .32025 Mtetra
.13917 .32025 .14751 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24185 .29339 .23376 .28516 Mtetra
.663 .74 .907 r
.23376 .28516 .24185 .29339 .25388 .28902 .24583 .2807 Mtetra
.662 .739 .907 r
.24583 .2807 .25388 .28902 .26596 .28475 .25795 .27625 Mtetra
.659 .734 .905 r
.25795 .27625 .26596 .28475 .27808 .28069 .27012 .27187 Mtetra
.653 .725 .902 r
.27012 .27187 .27808 .28069 .29023 .27693 .28234 .26764 Mtetra
.646 .712 .896 r
.28234 .26764 .29023 .27693 .30243 .27339 .2946 .26362 Mtetra
.638 .699 .89 r
.2946 .26362 .30243 .27339 .3147 .26975 .3069 .25979 Mtetra
.636 .694 .887 r
.3069 .25979 .3147 .26975 .32706 .26557 .31926 .25602 Mtetra
.64 .707 .895 r
.31926 .25602 .32706 .26557 .33954 .26048 .3317 .25209 Mtetra
.653 .741 .915 r
.3317 .25209 .33954 .26048 .35213 .2544 .34422 .24779 Mtetra
.666 .797 .945 r
.34422 .24779 .35213 .2544 .36478 .24802 .35683 .24305 Mtetra
.671 .849 .968 r
.35683 .24305 .36478 .24802 .37739 .24337 .36952 .23793 Mtetra
.681 .838 .959 r
.36952 .23793 .37739 .24337 .39007 .2387 .38227 .23261 Mtetra
.682 .82 .949 r
.38227 .23261 .39007 .2387 .4028 .234 .39507 .22732 Mtetra
.675 .801 .943 r
.39507 .22732 .4028 .234 .41559 .22928 .40792 .22223 Mtetra
.664 .788 .941 r
.40792 .22223 .41559 .22928 .42844 .22454 .42082 .21745 Mtetra
.652 .785 .945 r
.42082 .21745 .42844 .22454 .44136 .21978 .43377 .21297 Mtetra
.642 .792 .954 r
.43377 .21297 .44136 .21978 .45434 .21499 .44679 .2087 Mtetra
.636 .807 .965 r
.44679 .2087 .45434 .21499 .46737 .21018 .45986 .20446 Mtetra
.639 .827 .973 r
.45986 .20446 .46737 .21018 .48048 .20535 .47301 .20003 Mtetra
.65 .844 .975 r
.47301 .20003 .48048 .20535 .49362 .20225 .48623 .1952 Mtetra
.675 .8 .941 r
.48623 .1952 .49362 .20225 .50685 .19886 .49952 .18993 Mtetra
.684 .752 .903 r
.49952 .18993 .50685 .19886 .52016 .19447 .51287 .18428 Mtetra
.683 .722 .879 r
.51287 .18428 .52016 .19447 .53353 .18916 .52629 .17846 Mtetra
.679 .71 .872 r
.52629 .17846 .53353 .18916 .54696 .18329 .53976 .1727 Mtetra
.675 .712 .876 r
.53976 .1727 .54696 .18329 .56045 .17733 .55329 .16714 Mtetra
.67 .72 .887 r
.55329 .16714 .56045 .17733 .574 .17157 .56688 .16178 Mtetra
.667 .73 .896 r
.56688 .16178 .574 .17157 .58761 .16611 .58055 .15656 Mtetra
.665 .736 .903 r
.58055 .15656 .58761 .16611 .6013 .16087 .59428 .15141 Mtetra
.664 .739 .906 r
.59428 .15141 .6013 .16087 .61505 .15573 .60808 .14628 Mtetra
.664 .74 .907 r
.60808 .14628 .61505 .15573 .62887 .15061 .62195 .14113 Mtetra
.664 .741 .907 r
.62195 .14113 .62887 .15061 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28516 .22559 .27687 Mtetra
.22559 .27687 .23376 .28516 .24583 .2807 .2377 .27236 Mtetra
.663 .74 .907 r
.2377 .27236 .24583 .2807 .25795 .27625 .24986 .26783 Mtetra
.663 .739 .907 r
.24986 .26783 .25795 .27625 .27012 .27187 .26207 .26331 Mtetra
.661 .736 .905 r
.26207 .26331 .27012 .27187 .28234 .26764 .27434 .25882 Mtetra
.657 .729 .902 r
.27434 .25882 .28234 .26764 .2946 .26362 .28665 .2544 Mtetra
.652 .719 .897 r
.28665 .2544 .2946 .26362 .3069 .25979 .29902 .25011 Mtetra
.647 .707 .891 r
.29902 .25011 .3069 .25979 .31926 .25602 .31144 .24595 Mtetra
.643 .697 .885 r
.31144 .24595 .31926 .25602 .3317 .25209 .32391 .24188 Mtetra
.642 .695 .883 r
.32391 .24188 .3317 .25209 .34422 .24779 .33644 .23781 Mtetra
.645 .702 .888 r
.33644 .23781 .34422 .24779 .35683 .24305 .34905 .23364 Mtetra
.65 .718 .898 r
.34905 .23364 .35683 .24305 .36952 .23793 .36172 .2293 Mtetra
.656 .741 .912 r
.36172 .2293 .36952 .23793 .38227 .23261 .37447 .22479 Mtetra
.661 .765 .927 r
.37447 .22479 .38227 .23261 .39507 .22732 .38729 .22013 Mtetra
.663 .785 .939 r
.38729 .22013 .39507 .22732 .40792 .22223 .40017 .21537 Mtetra
.663 .796 .946 r
.40017 .21537 .40792 .22223 .42082 .21745 .41312 .21055 Mtetra
.665 .797 .945 r
.41312 .21055 .42082 .21745 .43377 .21297 .42613 .20566 Mtetra
.668 .787 .937 r
.42613 .20566 .43377 .21297 .44679 .2087 .4392 .20067 Mtetra
.672 .769 .923 r
.4392 .20067 .44679 .2087 .45986 .20446 .45234 .19554 Mtetra
.676 .747 .905 r
.45234 .19554 .45986 .20446 .47301 .20003 .46555 .19022 Mtetra
.677 .727 .888 r
.46555 .19022 .47301 .20003 .48623 .1952 .47882 .18473 Mtetra
.677 .713 .876 r
.47882 .18473 .48623 .1952 .49952 .18993 .49215 .17914 Mtetra
.675 .707 .872 r
.49215 .17914 .49952 .18993 .51287 .18428 .50553 .17355 Mtetra
.673 .708 .874 r
.50553 .17355 .51287 .18428 .52629 .17846 .51898 .16805 Mtetra
.67 .715 .882 r
.51898 .16805 .52629 .17846 .53976 .1727 .53249 .16267 Mtetra
.668 .724 .891 r
.53249 .16267 .53976 .1727 .55329 .16714 .54607 .15741 Mtetra
.666 .732 .899 r
.54607 .15741 .55329 .16714 .56688 .16178 .55971 .15223 Mtetra
.665 .737 .904 r
.55971 .15223 .56688 .16178 .58055 .15656 .57342 .14708 Mtetra
.664 .739 .906 r
.57342 .14708 .58055 .15656 .59428 .15141 .5872 .14192 Mtetra
.664 .74 .907 r
.5872 .14192 .59428 .15141 .60808 .14628 .60105 .13675 Mtetra
.664 .741 .907 r
.60105 .13675 .60808 .14628 .62195 .14113 .61496 .13156 Mtetra
.61496 .13156 .62195 .14113 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27236 .2295 .26396 Mtetra
.2295 .26396 .2377 .27236 .24986 .26783 .24169 .25938 Mtetra
.664 .74 .907 r
.24169 .25938 .24986 .26783 .26207 .26331 .25394 .25479 Mtetra
.663 .74 .907 r
.25394 .25479 .26207 .26331 .27434 .25882 .26624 .25019 Mtetra
.662 .737 .906 r
.26624 .25019 .27434 .25882 .28665 .2544 .27861 .24559 Mtetra
.661 .733 .903 r
.27861 .24559 .28665 .2544 .29902 .25011 .29102 .24102 Mtetra
.658 .726 .9 r
.29102 .24102 .29902 .25011 .31144 .24595 .3035 .2365 Mtetra
.655 .718 .895 r
.3035 .2365 .31144 .24595 .32391 .24188 .31602 .23203 Mtetra
.652 .708 .889 r
.31602 .23203 .32391 .24188 .33644 .23781 .32861 .22761 Mtetra
.65 .701 .883 r
.32861 .22761 .33644 .23781 .34905 .23364 .34125 .22321 Mtetra
.65 .696 .88 r
.34125 .22321 .34905 .23364 .36172 .2293 .35396 .21877 Mtetra
.651 .696 .878 r
.35396 .21877 .36172 .2293 .37447 .22479 .36674 .21426 Mtetra
.654 .697 .878 r
.36674 .21426 .37447 .22479 .38729 .22013 .37958 .20965 Mtetra
.657 .701 .879 r
.37958 .20965 .38729 .22013 .40017 .21537 .39249 .20491 Mtetra
.66 .703 .879 r
.39249 .20491 .40017 .21537 .41312 .21055 .40547 .20004 Mtetra
.663 .704 .878 r
.40547 .20004 .41312 .21055 .42613 .20566 .41852 .19505 Mtetra
.665 .704 .876 r
.41852 .19505 .42613 .20566 .4392 .20067 .43163 .18992 Mtetra
.667 .702 .873 r
.43163 .18992 .4392 .20067 .45234 .19554 .4448 .1847 Mtetra
.668 .702 .872 r
.4448 .1847 .45234 .19554 .46555 .19022 .45804 .17939 Mtetra
.669 .703 .873 r
.45804 .17939 .46555 .19022 .47882 .18473 .47134 .17405 Mtetra
.668 .707 .877 r
.47134 .17405 .47882 .18473 .49215 .17914 .4847 .16872 Mtetra
.668 .714 .883 r
.4847 .16872 .49215 .17914 .50553 .17355 .49813 .16344 Mtetra
.667 .722 .89 r
.49813 .16344 .50553 .17355 .51898 .16805 .51162 .15822 Mtetra
.665 .729 .897 r
.51162 .15822 .51898 .16805 .53249 .16267 .52517 .15303 Mtetra
.665 .735 .902 r
.52517 .15303 .53249 .16267 .54607 .15741 .53879 .14788 Mtetra
.664 .738 .905 r
.53879 .14788 .54607 .15741 .55971 .15223 .55248 .14272 Mtetra
.664 .74 .906 r
.55248 .14272 .55971 .15223 .57342 .14708 .56623 .13755 Mtetra
.664 .74 .907 r
.56623 .13755 .57342 .14708 .5872 .14192 .58006 .13236 Mtetra
.664 .741 .907 r
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25479 .24573 .24624 Mtetra
.24573 .24624 .25394 .25479 .26624 .25019 .25807 .24158 Mtetra
.664 .74 .907 r
.25807 .24158 .26624 .25019 .27861 .24559 .27047 .23691 Mtetra
.663 .739 .906 r
.27047 .23691 .27861 .24559 .29102 .24102 .28293 .23222 Mtetra
.663 .737 .905 r
.28293 .23222 .29102 .24102 .3035 .2365 .29545 .22753 Mtetra
.662 .734 .903 r
.29545 .22753 .3035 .2365 .31602 .23203 .30802 .22283 Mtetra
.66 .729 .9 r
.30802 .22283 .31602 .23203 .32861 .22761 .32066 .21815 Mtetra
.659 .723 .896 r
.32066 .21815 .32861 .22761 .34125 .22321 .33335 .21346 Mtetra
.658 .717 .892 r
.33335 .21346 .34125 .22321 .35396 .21877 .3461 .20877 Mtetra
.658 .712 .888 r
.3461 .20877 .35396 .21877 .36674 .21426 .35892 .20405 Mtetra
.658 .708 .884 r
.35892 .20405 .36674 .21426 .37958 .20965 .3718 .19928 Mtetra
.659 .705 .882 r
.3718 .19928 .37958 .20965 .39249 .20491 .38475 .19444 Mtetra
.66 .705 .88 r
.38475 .19444 .39249 .20491 .40547 .20004 .39776 .18953 Mtetra
.661 .705 .88 r
.39776 .18953 .40547 .20004 .41852 .19505 .41084 .18454 Mtetra
.663 .707 .88 r
.41084 .18454 .41852 .19505 .43163 .18992 .42398 .17949 Mtetra
.664 .71 .882 r
.42398 .17949 .43163 .18992 .4448 .1847 .43719 .17438 Mtetra
.664 .714 .885 r
.43719 .17438 .4448 .1847 .45804 .17939 .45046 .16925 Mtetra
.665 .719 .889 r
.45046 .16925 .45804 .17939 .47134 .17405 .46379 .1641 Mtetra
.665 .725 .894 r
.46379 .1641 .47134 .17405 .4847 .16872 .47719 .15896 Mtetra
.665 .73 .898 r
.47719 .15896 .4847 .16872 .49813 .16344 .49065 .15381 Mtetra
.664 .734 .902 r
.49065 .15381 .49813 .16344 .51162 .15822 .50418 .14867 Mtetra
.664 .738 .905 r
.50418 .14867 .51162 .15822 .52517 .15303 .51778 .14352 Mtetra
.664 .739 .906 r
.51778 .14352 .52517 .15303 .53879 .14788 .53144 .13835 Mtetra
.664 .74 .907 r
.53144 .13835 .53879 .14788 .55248 .14272 .54517 .13316 Mtetra
.664 .741 .907 r
.54517 .13316 .55248 .14272 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24158 .24983 .23291 Mtetra
.24983 .23291 .25807 .24158 .27047 .23691 .26227 .22819 Mtetra
.664 .74 .907 r
.26227 .22819 .27047 .23691 .28293 .23222 .27476 .22345 Mtetra
.27476 .22345 .28293 .23222 .29545 .22753 .28732 .21868 Mtetra
.663 .739 .906 r
.28732 .21868 .29545 .22753 .30802 .22283 .29993 .2139 Mtetra
.663 .738 .906 r
.29993 .2139 .30802 .22283 .32066 .21815 .3126 .2091 Mtetra
.663 .736 .904 r
.3126 .2091 .32066 .21815 .33335 .21346 .32534 .20429 Mtetra
.663 .734 .903 r
.32534 .20429 .33335 .21346 .3461 .20877 .33814 .19945 Mtetra
.662 .731 .901 r
.33814 .19945 .3461 .20877 .35892 .20405 .35099 .19459 Mtetra
.662 .729 .899 r
.35099 .19459 .35892 .20405 .3718 .19928 .36392 .1897 Mtetra
.662 .727 .898 r
.36392 .1897 .3718 .19928 .38475 .19444 .3769 .18478 Mtetra
.663 .726 .897 r
.3769 .18478 .38475 .19444 .39776 .18953 .38995 .17983 Mtetra
.663 .727 .897 r
.38995 .17983 .39776 .18953 .41084 .18454 .40306 .17483 Mtetra
.663 .728 .897 r
.40306 .17483 .41084 .18454 .42398 .17949 .41624 .16981 Mtetra
.664 .729 .898 r
.41624 .16981 .42398 .17949 .43719 .17438 .42948 .16475 Mtetra
.664 .732 .9 r
.42948 .16475 .43719 .17438 .45046 .16925 .44279 .15967 Mtetra
.664 .734 .902 r
.44279 .15967 .45046 .16925 .46379 .1641 .45616 .15457 Mtetra
.664 .736 .904 r
.45616 .15457 .46379 .1641 .47719 .15896 .4696 .14945 Mtetra
.664 .738 .905 r
.4696 .14945 .47719 .15896 .49065 .15381 .48311 .1443 Mtetra
.664 .739 .906 r
.48311 .1443 .49065 .15381 .50418 .14867 .49668 .13914 Mtetra
.664 .74 .907 r
.49668 .13914 .50418 .14867 .51778 .14352 .51032 .13396 Mtetra
.664 .741 .907 r
.51032 .13396 .51778 .14352 .53144 .13835 .52403 .12875 Mtetra
.52403 .12875 .53144 .13835 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22345 .26652 .21462 Mtetra
.26652 .21462 .27476 .22345 .28732 .21868 .27911 .20981 Mtetra
.27911 .20981 .28732 .21868 .29993 .2139 .29176 .20498 Mtetra
.664 .74 .907 r
.29176 .20498 .29993 .2139 .3126 .2091 .30447 .20012 Mtetra
.30447 .20012 .3126 .2091 .32534 .20429 .31724 .19524 Mtetra
.664 .739 .906 r
.31724 .19524 .32534 .20429 .33814 .19945 .33008 .19034 Mtetra
.33008 .19034 .33814 .19945 .35099 .19459 .34298 .18542 Mtetra
.664 .738 .906 r
.34298 .18542 .35099 .19459 .36392 .1897 .35594 .18047 Mtetra
.664 .738 .905 r
.35594 .18047 .36392 .1897 .3769 .18478 .36896 .17549 Mtetra
.36896 .17549 .3769 .18478 .38995 .17983 .38205 .17049 Mtetra
.38205 .17049 .38995 .17983 .40306 .17483 .3952 .16546 Mtetra
.3952 .16546 .40306 .17483 .41624 .16981 .40842 .16041 Mtetra
.40842 .16041 .41624 .16981 .42948 .16475 .4217 .15533 Mtetra
.664 .739 .906 r
.4217 .15533 .42948 .16475 .44279 .15967 .43505 .15022 Mtetra
.664 .74 .906 r
.43505 .15022 .44279 .15967 .45616 .15457 .44846 .14509 Mtetra
.664 .74 .907 r
.44846 .14509 .45616 .15457 .4696 .14945 .46194 .13994 Mtetra
.46194 .13994 .4696 .14945 .48311 .1443 .47549 .13476 Mtetra
.664 .741 .907 r
.47549 .13476 .48311 .1443 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20498 .28351 .19599 Mtetra
.28351 .19599 .29176 .20498 .30447 .20012 .29626 .19109 Mtetra
.29626 .19109 .30447 .20012 .31724 .19524 .30907 .18616 Mtetra
.30907 .18616 .31724 .19524 .33008 .19034 .32194 .18121 Mtetra
.664 .74 .907 r
.32194 .18121 .33008 .19034 .34298 .18542 .33488 .17624 Mtetra
.33488 .17624 .34298 .18542 .35594 .18047 .34788 .17124 Mtetra
.34788 .17124 .35594 .18047 .36896 .17549 .36094 .16622 Mtetra
.36094 .16622 .36896 .17549 .38205 .17049 .37407 .16117 Mtetra
.37407 .16117 .38205 .17049 .3952 .16546 .38726 .1561 Mtetra
.38726 .1561 .3952 .16546 .40842 .16041 .40052 .151 Mtetra
.40052 .151 .40842 .16041 .4217 .15533 .41385 .14588 Mtetra
.664 .741 .907 r
.41385 .14588 .4217 .15533 .43505 .15022 .42724 .14073 Mtetra
.42724 .14073 .43505 .15022 .44846 .14509 .44069 .13556 Mtetra
.44069 .13556 .44846 .14509 .46194 .13994 .45422 .13035 Mtetra
.45422 .13035 .46194 .13994 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .1093 Mtetra
.50899 .1093 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19109 .28798 .18197 Mtetra
.28798 .18197 .29626 .19109 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16622 .35285 .15688 Mtetra
.35285 .15688 .36094 .16622 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13556 .43285 .12593 Mtetra
.43285 .12593 .44069 .13556 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .1093 .50137 .09943 Mtetra
.50137 .09943 .50899 .1093 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .1926 Mtetra
.2287 .1926 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18274 Mtetra
.25404 .18274 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08948 Mtetra
.49367 .08948 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .2271 Mtetra
.10878 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18274 .24553 .17355 Mtetra
.24553 .17355 .25404 .18274 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08948 .4859 .07942 Mtetra
.4859 .07942 .49367 .08948 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000IP2Y_NP0
0`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?ooo`<00000J02Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<00000JP2Y_NP00`000000
ZKgX0:Vmj00F0:Vmj0030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX
0:Vmj00Y0:Vmj0<0ZKgW1`2Y_NP30:Vmi`P0ZKgX0`2Y_NLV0:Vmj0030000002Y_NP0ZKgX01L0ZKgX
00<000000?ooo`3oool0CP3oool007l0oooo0P00000_0:Vmj0L0ZKgW102Y_NP60:Vmi`@0ZKgX1`2Y
_NL20:Vmj0<0ZKgW802Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04d0oooo001l
0?ooo`<000009@2Y_NP30:Vmi`L0ZKgX0`2Y_>L60:Vmi`D0ZKcW1@2Y_NL60:Vli`/0ZKgW7`2Y_NP0
0`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04d0oooo001;0?ooo`050<AO500000000000
0000501Oa?l0:@3oool3000000030:Vmj0000000ZKgX02<0ZKgX1P2Y_NL40:Vmj0H0ZKcW0`2Y_NL3
0:VkiPD0ZKcW0P2Y_NL30:ZliPH0ZKcW1@2Z_>L:0:VmiaX0ZKgX00<000000:Vmj02Y_NP06@2Y_NP0
0`000000oooo0?ooo`1<0?ooo`00BP3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09P3o
ool2000002D0ZKgX2P2Y_NL;0:Vli`H0ZK_V102Y_>L60:ZliP<0ZKcW0`2Z^nH50:Zli`80ZKgW0`2Z
_>L;0:Vmia@0ZKgX00<000000:Vmj02Y_NP0602Y_NP00`000000oooo0?ooo`1<0?ooo`00C`3oool0
0`2?=@00=Hoo0?ooo`0R0?ooo`<000009@2Y_NP30:Vli`L0ZKgW0`2Y^nH60:Vli`D0Z[[U1@2Y^nH5
0:Zji@H0Z[cV1P2Z^nH:0:Zli`80ZKgW0`2Z_>H60:Vmi`80ZKgX0`2Y_NL>0:Vmj0030000002Y_NP0
ZKgX01T0ZKgX00<000000?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`00
03D0Sooo0?ooo`040?ooo`0308le000eSol0oooo0200oooo0P00000V0:Vmj0H0ZKcW102Y_NL60:Vk
iP<0ZKcW0`2Z^N@50:Zji@80ZK_V0`2Z^><50:Zji@<0Z[cV0`2[^N@50:ZkiPD0Z[[U1@2Z_>L60:Zl
iP/0ZKgW3@2Y_NP00`000000ZKgX0:Vmj00J0:Vmj0030000003oool0oooo04X0oooo001:0?ooo`07
0?o4G`0D01@0GlCo0?ooo`3ool@0Ga@D05o4o`0N0?ooo`<0000000<0ZKgX0000002Y_NP08@2Y_NP:
0:Vli`/0ZK_V1P2Z^N@40:Zji@H0Z[SS102Z^^D70:^ii080Z[_V0`2[^><50:Zji@80Z[cW0`2[^^D6
0:ZliPD0Z[cW2P2Y_NL80:Vmj0030000002Y_NP0ZKgX01X0ZKgX00<000000?ooo`3oool0BP3oool0
04X0oooo00<0oon?03D0000000000P0000000`0eSol0oooo0?ooo`0J0?ooo`030:Vmj00000000000
02D0ZKgX2P2Y_>L30:Vji@P0ZK_V0`2Z^><50:Zii0D0ZkKR1@2Z^><50:^gh@H0ZkWT1P2[^><40:Zj
i@H0Zk[U0`2Z_>H30:^ji@D0Z[cW0P2Y_NL30:Zli`D0ZKgW1`2Y_NP00`000000ZKgX0:Vmj00K0:Vm
j0030000003oool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`00000U0:Vmj0X0
ZKcW1P2Y^^D40:VkiPL0Z[SS0P2Z^N@30:^dh0D0ZkKR0P2Z^><30:beg`D0ZkOQ0`2[^N@30:bfh0D0
ZkSS1@2/^>8<0:^ji@X0Z[cW0P2Y_NL30:Zmi`H0ZKgX00<000000:Vmj02Y_NP0702Y_NP00`000000
oooo0?ooo`180?ooo`00B`3oool00`2?=@00=Hoo0?ooo`0J0?ooo`800000902Y_NP:0:Vli`X0ZK[U
1@2Y]^860:Zhh`D0ZkCP1@2[]^860:beg`D0ZkOQ1P2/]^020:^hh`<0[[KO1@2/^>820:^ji@<0[;SR
1P2[^^D50:^ki@D0Z[cW1P2Z_NL50:Vmj0030000002Y_NP0ZKgX01`0ZKgX00<000000?ooo`3oool0
B03oool004/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`040:Vmj000000000000000
0080ZKgX00<000000:Vmj02Y_NP07`2Y_NP:0:Vli`X0ZK[U0`2Y]N450:VfhP<0Z[SS0`2[/ml50:^d
h080ZkKR0`2/]=l60:beg`D0[KGO1@2/]^060:jfg`X0[;SR0`2[^^D30:fihPD0Zk_U1@2[_>H50:Zm
i`D0ZKgW00<000000:Vmj02Y_NP07@2Y_NP00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP0
00000000000U0:Vmj0X0ZKcW2P2Y^^D60:Veh@D0ZKKR1P2[/ml40:^dh0H0[;CO0`2/]Ml30:jhh@D0
[KGO0P2/]^030:nhg`D0[[KO1@2_]ml60:bhhPH0[KWR0P2[^nD30:fjh`D0ZkcV0P2Z_NL30:ZliP@0
ZKgW00<000000:Vmj02Y_NP07P2Y_NP00`000000oooo0?ooo`160?ooo`00G`3oool4000002D0ZKgX
202Y_>L50:Vii@D0ZK[U1@2Y]>460:Veh@X0Zk?O1@2]]^050:bdg`H0[[SQ1@2]]Ml60:nhg`80[[KO
0`2a^^450:ngg`<0[;SR0`2_^=l50:fihPH0[K[S102[_>H60:ZliP80ZKgW00<0Z[gW0000002Z_NL0
7`2Y_NP00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP0000000000000000U0:Vmj0P0ZKcW
0`2Y^^D50:Vii@80ZK[U202Y]>430:Veh@<0Z[?O1`2[/ml30:fjh`D0[KKP0P2/]=l30:o0i`H0[[SQ
0P2]]Ml30;2oi@D0[kSO1@2a^^450:ngg`L0[kSO0P2]^N830;2hh0D0[K[S1@2/^n@50:ZliP<0Z[gW
00<000000:Zmi`2Z_NL07`2Y_NP00`000000oooo0?ooo`150?ooo`00F`3oool3000002@0ZKgX1@2Y
_NL50:Vli`H0ZK[U102Y^ND;0:Vdh@D0Z[?O1@2[/ml60:fjh`@0[KKP1P2_`>L50:jhh@H0/;oU0P2_
^=l30;37j`D0/K[Q0P2_]ml30;:lhPH0[kSO1P2`^>020:fjh`<0[kWQ1@2/^n@20:ZliP<0ZkcU0P2Z
_NL00`000000Z[gW0:Zmi`060:ZmiaT0ZKgX00<0oooo0000003oool0A@3oool005P0oooo0`00000S
0:Vmj0X0ZKgW1@2Y^^H60:Vji@@0Z;CQ1P2Y]>450:Zdh0D0Z[?O0P2[/ml30:foi`D0[K[S1@2/c?06
0:o0i`D0[<ob1@2`_nD60;37j`@0/K[Q1P2b_>830:nhg`<0/[cQ1@2`^>060:nih@@0[;_T1P2[_>D0
0`2Z_NL000000:^li`020:^li`D0Z[gW6P2Y_NP00`000000oooo0?ooo`140?ooo`00E@3oool00`2Y
_NP000000000000W0:Vmj0L0ZKgW0`2Y^nH50:VjiP<0ZK[U1`2X]>430:Vdh@<0ZKCP1@2Z]>040:Zc
g`H0[KoW0P2]^^<30:KHn@D0[<c`0`2_`>L30:;Cn@D0[<ob1@2TeOT50;37j`D0[l_^1@2b_>870;:l
h@80/;SP0`2b^n050:nih@D0[[[R1@2[_>D00`2[_>L000000:^li`030:^li`D0Z[gW6P2Y_NP00`00
0000oooo0?ooo`130?ooo`00D`3oool3000000030:Vmj0000000ZKgX02L0ZKgX102Y_NL60:VkiPD0
ZK[V2P2X]>450:Vdh0D0Z[CP1@2/a>`50:foi`H0Y]Si1@2/c?060:;Cn@D0U/3d1@2TeOT509g<n0D0
[l_^0P2b_>830:o;k`H0/[cQ1P2b^n020:nih@<0/[_P1@2^^^850:fki0030000002[_>L0ZkcW0080
ZkcW1P2Z_NLJ0:Vmj0030000003oool0oooo0480oooo001A0?ooo`800000;@2Y_NP50:Vki`H0ZK_V
1@2X]N850:Rdh@D0Z;?Q1@2Y]>020:Zdh0<0ZlW_1@2/a>`60:?Cn@D0Y]Si1P2KaOD509jij`D0U/3d
1@2B]>h509g<n0@0[l_^1P2_bnl30;:lh@<0/<S[2`2b^n020:jjhP<0/K_Q102]^n@00`000000ZkcW
0:^li`030:^liPD0Z[gW6P2Y_NP00`000000oooo0?ooo`120?ooo`00CP3oool3000002h0ZKgX0P2Y
_>L50:Vki`<0ZK_V0`2X]^<50:RehP80Z;CQ202X/n440:Vdh0H0ZlW_0P2/a>`40:;>m`D0Xm?i1@2J
^>`309_5m@<0ZKgX1@2N^N/209K0m0<0ZKgX1@2B]>h409g<n0D0V<Kg1P2_bnl60;38j`80/[_P0`2b
`nH50;:kh0H0/K_Q0`2]^n@00`000000ZkcV0:^liP040:^liPD0Z[gW6P2Y_NP00`000000oooo0?oo
o`110?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e00000000000DG`34ool0:@3o
ool2000002l0ZKgX1@2Y_>L50:Vki`H0Z;KS102X]N8:0:Rch@D0Z/ca1@2[bNl70:;>m`D0ZKgX1@2J
^>`60:Vmj0@0W[W[1P2Y_NP209:dkP<0ZKgX102H]^d;09S6m`D0/<S[1P2b`nH20;:kh0<0];kR1@2a
^n430:nkh`030000002_^n<0ZkcV00@0ZkcV1P2Z_NL20:Vmj0<0Z[gX5@2Y_NP00`000000oooo0?oo
o`100?ooo`006@3oool02P3ogi`0B01d0;ooo`3oool0oooO05lD000DGl@0oooo0<AO5000=HlV0?oo
o`<000000P2Y_NP00`000000ZKgX0:Vmj00X0:Vmj0X0ZKcW1@2X]n@50:Rfh`D0Yk;P1`2X/n430:W;
lPD0Z/ca1`2Tb_@T0:Vmj0X0V;K]1@2Ha_L509g=n0D0//?V1P2d_^820;6kh@<0/kcQ0P2_^n<00`00
0000[k_S0:nkh`050:fli@D0Z[gW1P2Z_NPD0:Vmj0030000003oool0oooo00X0oooo00D0oono07@0
0000000004RL0=ooo`0a0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo
0?o4G`0D03D0Sooo0280oooo00<0ZKgX000000000000;P2Y_NP30:Vmi`D0ZKcW1@2X^ND50:Rgi080
Z;KS0`2V/^050:Nbh0@0Z;?Q1P2Ybo860:K8l@<0Y<[d:`2Y_NP609Rfk@D0TkC^1@2McOP20;;3iP<0
ZLcb1@2d_^860;>lh@80[k_S00<000000;6lhP2a_>801@2]_>D50:^mi`D0Z[gX5@2Y_NP00`000000
oooo0?ooo`080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0
000000000`0000000`0007@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Co
o`3oool0oon?03D0501Oa?l0803oool3000002h0ZKgX1P2Y_NL20:Vli`<0Z;[V1@2X^ND40:Rgi0H0
Y[;P102W/^060:W8l0<0ZL_b0`2YbO050:K8lC@0ZKgX1@2C]>h409g=n0H0ZLcb0P2d_^830;74j0D0
/kcQ0P2a_>8010000000/KcR0;6lhP2a_>820:fli@<0[[gT1@2[_NL20:Zmj0<0Z[gW502Y_NP00`00
0000oooo0?ooo`080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool0
2`3ogi`0B01d0;ooo`3oool0okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0oooo0`00000a0:Vm
j0D0ZKgW1P2X^^H40:Rii@D0Y[;Q1@2V/^060:W3k@D0ZLS`1P2YbO0i0:Vmj080TkC^0`2Y_NP408^`
k`D0ZLcb1P2aa>P20;>lh@<0];oR00<0/KcR0000002a_>800P2a_>860:jmi0@0ZkgW1P2Z_NLD0:Vm
j0030000003oool0oooo00L0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000I
0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l06`3oool30000
03D0ZKgX1@2Y^nL50:RjiPD0Y[?R1@2V/^430:Jbh080YkgY1P2Y`nd50:c=l@<0ZLW`@@2Y_NP408^`
k`D0T[kd1@2aa>P60;BohP030000002a_>80/kgQ0080/kgQ1@2^_N@50:^miPD0Z[gW5@2Y_NP00`00
0000oooo0?ooo`060?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool0
3@2oM000001809boW01807@0_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool2
000003L0ZKgX0P2Y_>L50:Vki`<0Z;[V0P2V]N<50:JchPD0Y[;Q1@2W_NT30:W3k@<0[]7b1@2/cO53
0:Vmj0D0W[W[1@2B__@50:S8l0D0];oR00<000000;>mh@2c_N400`2c_N420:jmi0<0/;gT1@2[_NH5
0:Zmia@0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
<03oool001P0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G
0?ooo`<00000=`2Y_NP50:Vli`D0ZK_W1@2V]N<50:JchPD0Y[OU1@2W_NT60:kAlTP0ZKgX1@2N^N/5
08fakPD0Z<S`0P2d_n820;?1i@030000002c_N40/kgQ00<0/kgQ1P2`_N@20:^miP<0[;gV1@2Z_NLD
0:Vmj0030000003oool0oooo00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo
000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D0?ooo`<00000
00<0ZKgX0000002Y_NP0<`2Y_NP50:Vmi`D0ZKcW1@2W]nD50:Jeh`D0YK?S1@2V]nD50:kFm@<0[]7b
D02Y_NP508fakP@0Z<S`102c`ND010000000/l7U0;>mh@2c_N430;BohPD0/;gT1P2/_NH50:Zmia@0
ZKgX00<000000?ooo`3oool0103oool01P3ooml0W4P007Boo`3oool0gia8001d_c40oooo000d0?oo
o`030:Vmj0000000000003X0ZKgX1@2Y_NL50:RiiPD0YkOU0P2V]N<30:BahPD0YK?S0P2V]nD30:_I
m`D0[]Ke6P2Y_NP50:RagPD0ZKgX1@2SVLX50:Vmj0H0YjOG7`2Y_NP408fakPD0U/?f0`2c`ND00`00
0000/l7U0;BohP050;BohP80/;gT0`2a_^@50:bmiPH0Z[gW4`2Y_NP00`000000oooo0?ooo`050?oo
o`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`00000m0:Vmj080ZKgW0`2Y^nL50:Ri
iP@0YkOU1P2T/N840:Fch`H0ZmWg702Y_NP30:FPd0D0Z;7N0P2Y_NP309j7^PD0XiW:1@2NQkX60:NW
e`D0YIo@6@2Y_NP509^gk0D0U/?f0P2_`^P00`000000[l;X0:o2j0050;BohPH0/KkT0P2/_NH30:fn
iPD0Z[gW502Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX03d0
ZKgX1P2Y^nL40:RiiPD0Y;;R1@2T/N850:[<l@<0ZmWg702Y_NP60:FPd0@0Z;7N1P2NQkX40:>IbP03
0;FD]P2NQkX0WXNj00<0WXNj102WYmL20:b@^@D0YIo@1@2WYmHD0:Vmj0D0VkO/1@28[nl2000000<0
[l;X0P2d_n830;G0hPD0/KkT1P2]_^H50:Zmia@0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo
00@0ZKgX0000000000000000?`2Y_NP50:Vli`@0ZK_W1@2U]>@50:BbhP80Y;7R102W_NX40:[<lA/0
ZKgX102SVL/60:FPd080Z;7N0P2SQ[D509j7^P<0XiW:0P2eU;H609j7^P80YjOG0`2/T;T40:FOd080
/iNk1@2WYmHI0:Vmj00708R_k`000000000000000028[nl0[l;X000000020:o2j0H0]L3R1@2b_n@5
0:fniPH0Z[gW4`2Y_NP00`000000oooo0?ooo`0i0?ooo`00:`3oool2000004<0ZKgX1@2Y_>L40:Jh
i@D0YKCT102T/^870:NmjPD0^<gZ5`2Y_NP70:>Ib`D0YJ3@102SQ[D609j7^P030:>IbP2eU;H0]IBf
0080]IBf1@2NQkX60:b@^@80YIo@0`2cUk/50:NWeQL0ZKgX0`00000408R_k`030:W1j`000000ZL7[
0080ZL7[0`2e`>830;G1h`D0/[oT1@2]_^H50:Zmia@0ZKgX00<000000?ooo`3oool0>03oool002T0
oooo0P0000160:Vmj080ZKcW0`2X^^H40:Jhi@D0YKCT1@2S]>D30:NmjP<0]]Sb1@2hcNXD0:Vmj0X0
XiW;0P2UX=030:R;]P@0XhJe1@2NQkX50;FD]P@0WXNj0P31XKT50:b@^@H0/iNk0P2WYmH30:nH_a<0
ZKgX0`0000040:Vmj0@0SK7^00<0ZL7[0000002Y`N/00P2Y`N/60;G1h`80/[oT0`2c`>@40:fniPH0
Z[gW502Y_NP00`000000oooo0?ooo`0g0?ooo`007@3oool01@3ookl0M00000000000B9`0gooo00L0
oooo0P0000160:Vmj0H0Z;[V102V^>D50::ah`D0XkCU1P2ff?820;S=jQ80ZKgX1@2UX=090:>Ib`D0
Z8^f102SQ[D409j7^P80]iZk1@2eU;H209j7^P<0`J6i1@2/T;T00`37Z;X0/iNk0;>G^`030;>G^`H0
[iRo1@2TVLX;0:Vmj08000001`2Y_NP508fakP030::nk@000000X[k]0080X[k]1@2e`N<50;?0i080
[KkV0`2^_nH50:Zmia@0ZKgX00<000000?ooo`3oool0=`3oool001`0oooo00H0oooO09a80018W=l0
oooo0=nLB000M;l70?ooo`030000003oool000000440ZKgX1@2Y_>L50:RjiPD0Xk;S1@2R/N<20:>d
i@<0[/ob1@2ff?8@0:Vmj0D0Z;7N102UX=070:>Ib`<0XhVh102XRkH50:>6]@80WXNj0`2gV[/50;FD
]P0309j7^P31XKT0`J6i0080`J6i102/T;T20<NX^PD0/iNk00<0cJfi0:nH_`2_V;l00`2_V;l00`3?
[[P0Y9W:0:BIbP030:BIbPL0ZKgX0`0000090:Vmj0H0TkC]00@0X[k]0000002R_^d0X[k]0`2e`N<3
0;C1i0@0/l3T1P2^_nH20:Zmi`<0Z[kW502Y_NP00`000000oooo0?ooo`0f0?ooo`00703oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y_NP0?`2Y
_NP50:Vli`D0YKKU1@2S/^<40::ah`H0[/ob5@2Y_NP40:RagPD0YJ3@102SVL/50:>9^0D0Z8^f102S
Q[D50;NJ^`D0]IBf1P31XKT20:b@^@<0ajRj102cUk/20<f]^@@0[iRo0P3?[[P40:BIbP80`:S20`2Y
_NP3000000d0ZKgX1@2C]>d0102R_^d000000::nk@2R_^d60;C1i080/l3T0`2d`N@50:joiPH0Z[kW
502Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02L
gol01@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX03l0ZKgX0`2Y_>L20:NiiPD0
YKKU102S/^<50:Jlj@<0[/ob102ebNXC0:Vmj0D0Z;7N102UX=0509f5^@@0XhVh1@2XRkH30:>6]@80
/ig21@2gV[/30;FD]P80_ZS31@31XKT00`2/T;T0ajRj0<NX^P030<NX^P80/iNk0`3=[KT30:nH_`@0
cjjh0P2TVLX30<2X`P<000004@2Y_NP409>dk@80W;[]00<0000009bjk@2L^^d02`2d`N@50:joi`D0
Z[kW502Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0
B02Lgol01@3oool00`000000oooo0?ooo`030?oood80ZKgX1@2W^NH50:Ffi@@0X[?T1@2V_>T70;G9
jQ<0ZKgX102X/Mh509N0^@@0WHFi1@2SRKP40:R;]P80XhJe0`2cWL850;NJ^`80]IBf0`2nZ<<50<6Q
^@H0ajRj00<0/iNk0<f]^@3=[KT00`3=[KT20:nH_`@0cjjh00<0Y9W:0<2X`P0000000P0000000`30
Z<80Z;7N0:RagP030:RagPh0ZKgX1@2H]^`209bjk@030000002L^^d0W;[]00P0]<7T0`2d`^D50:jo
i`D0Z[kX502Y_NP00`000000oooo0?ooo`0d0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono
07@0B02Lgol01@3oool2000000D0oooo00<000000:Vmj02Y_NP0>P2Y_NP50:Rki`D0YkWV1@2Q/N@4
0::ci0<0Y[cY0`2jfO030;G9jQD0ZKgX1@2?N[P409N0^@@0WHFi1@2SRKP40:R;]PD0/ig21@2gV[/5
0;jX``@0`J6i0P34//T50<NX^PH0cJfi00<0[iRo0<n^^03?[[P00P3?[[P3000000@0`:S200<0e;Nl
0:RagP2X/Mh00P2X/Mh?0:Vmj0D0V;K/0P2I]^`00`000000VKK/09Vfk0050;C1i0H0]<;U0P2^_nL3
0:foi`D0Z[kX502Y_NP00`000000oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0
omnL04P0M02oool01@3oool00`000000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX03X0ZKgX1@2X
^nL50:>ei@D0XK7T102R/n@60;[Il180ZKgX0P2SVLX409J2^`@0SgZh102GP;T509f5^@@0XhVh0P2X
RkH30:nPb0D0/ig20`2gV[/20;Z`d0D0_ZS30P31XKT30<Bbb@@0ajRj0P38]lT50<f]^@80cjjh0`00
00000`3?[[P0e;Rm0<2X`P030<2X`P<0e;Nl0P2X/Mh20;:]e0l0ZKgX1@2K]n`00`2I]^`0000009Vf
k00209Vfk080]<7T0`2d`^@50;C2i@H0[KoW1@2Z_^PC0:Vmj0030000003oool0oooo03<0oooo000L
0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?ooo`070?oooc`0ZKgX
0P2X^nL30:JiiPD0XkGU102Q/N@60:c5k1@0ZKgX102SVLX409J2^`@0SgZh1@2GP;T409f5^@@0XhVh
1@2_X<P50;>M`P80]iZk0`2j/=050;jX``030<6Q^@34//T0a;;900<0a;;90P37Z;X30<Rgb@@0cJfi
0`0000030<n^^080e;Rm0`30Z<840=Bg_0D0/ZgD3`2Y_NP509^gk00409Vfk0000000VKK/09Vfk0H0
]<;T0P2d`^D30;?3i@D0[KoW1P2Z_^PC0:Vmj0030000003oool0oooo0380oooo000M0?ooo`050?oo
_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`080?oooc/0ZKgX1P2V^NH40:>ei@D0
XkGV0`2/aN`30;kDjQ@0ZKgX102SVLX309J2^`D0SgZh102GP;T409f5^@80XhVh0`2ZX<d50:nPb0@0
/ig21P2j/=040;jX``H0a;;900<0ajRj0<Rgb@38]lT00`38]lT00`3=[KT00000000000020<jha@<0
cjjh103D^;d00`30Z<80e;Nl0=Bg_0030=Bg_0030=bn^`2b[M@0/ZgD0080/ZgD402Y_NP409^gk080
VKCZ00<0000009VdjP2I]>X01@2d`^@60;?3i@D0[KoW1@2Z_^PC0:Vmj0030000003oool0oooo0380
oooo000W0?ooo`030000003oool0oooo00X0oooo=`2Y_NP50:Rki`@0Y[WV1@2P/N@50:>eiPH0_]CZ
4`2Y_NP40:>IbP@0UX:k102?N[P409N0^@@0WHFi1@2ZX<d50:nPb080/ig20`2d]m/50;Z`d080_ZS3
0`2l_MX50<Bbb@@0b;O90`0000050<jha@030<n^^03D^;d0e;Rm00<0e;Rm1@3D]k`20=bn^`<0/ZgD
0P34_=8?0:Vmj0D0VkO/00<0VKCZ0000002I]>X00P2I]>X50;C2i0<0/l?U0`2c`nH50:foi`D0Z[gX
4`2Y_NP00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`0;0?oooc80ZKgX1@2Y
_>P50:Rki`@0X[CU1@2P/N@30:>eiP<0/lc/102ne>XD0:Vmj0@0XiW:0`2FP[/408mj^0@0Uh2i1@2T
W/l50:ZPc@@0[j381@2d]m/50;Z`d0H0_;gJ0P34//T30;g2gP<000000P38]lT60<jha@H0e;Rm00@0
dko60=Bg_03D]k`0e;Nl103L_[/00`2b[M@0a;cB0<BldP020<BldPl0ZKgX1@2K]n`00`2M]>P00000
09fdj00209fdj0D0]<;T1P2c`nH20:foi`<0[;oX102Z_NPD0:Vmj0030000003oool0oooo0300oooo
000W0?ooo`030000003oool0oooo00`0oooo<P2Y_NP50:Vlj080Z;_W0`2U^NL40::di@D0X;7T1P2c
c>`G0:Vmj0@0XiW:0`2FP[/408mj^0D0WYS=102TW/l50:ZPc@80[j380`2__>@50;Bgf`80^[3@0`2a
aNT50;bmfP80_L;N0`0000000`2m`]h0b;O90<Rgb@030<72f`@0c[S50P39`M840=Bh_@80dko60`3D
]k`40=bn^`@0a;cB0P3?b=<?0:Vmj0D0V;K/00<0WKCX0000002M]>P00P2M]>P20;C2i0<0]L?U1@2c
`nH50:boj0D0Z[gX4`2Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool2000000h0oooo<P2Y_NP4
0:Vlj0H0YKWW102R]>D50:Bgi`<0/lc/0`2jcnX>0:Vmj0D0YjOG101lL[d3081f_P<0UX:k1@2FSlX4
09jHc@D0Y9k?102ZX<d60:nli0@0];OK1P2aaNT20;bmfP040:g9kP0000000000000000@0_L;N1P31
`]/20<jha@<0bL7B0`3D^;d40=>oaP030=Bg_03L_[/0g;jk00<0g;jk00<0g/Bn0<BldP34_=80103?
b=<?0:Vmj0D0V;K/00@0WKCX0000002M]>P0WKCX1P2e`nD50;;3i`@0[;oX1P2Z_NPC0:Vmj0030000
003oool0oooo02l0oooo000W0?ooo`030000003oool0oooo00h0oooo<P2Y_NP50:Rki`@0YKWW1@2O
/^D50:Bgi`H0^/oZ3P2Y_NP40:NWe`@0O7:m1020M[h308b3a0@0UXo:1@2NV<d40:BNc`D0[;oX1@2_
_>@50:W;lPD0/LGY0`0000030:g9kP80_L;N0`2/b>h50<72f`H0bL7B00<0e;Rm0=>oaP3C_lH00`3C
_lH50=bn^`80g/Bn00<0a;cB0<o8d`3?b=<00`3?b=<@0:Vmj0@0V;K/00<0X[KW0000002R]^L00P2R
]^L30;G3i@<0]/GU102b`nL50:boj0D0Z[gX502Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool0
0`000000oooo0?ooo`0?0?oooc80ZKgX1@2X^nL40:6diPD0Wk;U0P2T]nL30;O<jPD0^/oZ3`2Y_NP3
0:NWe`@0O7:m1020M[h308b3a0D0UXo:102NV<d50:Vnj@D0[;oX1@2UcoH50:W;lP050:3=m`000000
00000000002PcOL01@2]bNh60:c8kP80`L;K0`2ba^T50<W1dPD0dko60P3@`lh30=bn^`<0g/Bn1@3?
b=<20=?Cf@l0ZKgX1@2C]>d00`2R]^L000000::fi`020::fi`D0]/GU0P2b`nL30;32i`D0[;oX1@2Z
_NPC0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`8000004@3oool00`000000ZKgX0:Vmj00_
0:Vmj0D0YKWW102Q]>H409nbi@H0]lcZ502Y_NP30:NWe`@0O7:m0`20M[h408b3a0@0UXo:0P2NV<d3
0:Jji`D0ZKkY0P2/_nP30:GAm`D0YLof0P2Kd?X3000000D0X<gg1@2Jb_P50:c8kPH0//KY0P39`M83
0;o4gP<0dko6103@`lh00`3L_[/0g/Bn0=k4_P020=k4_P040>39`P3?b=<0clSC0<o8d`@0dm?I3`2Y
_NP509>dk@030::fi`000000ZK[V0080ZK[V102faND60;32i`80[;oX0`2[_^P50:Zmj1<0ZKgX00<0
00000?ooo`3oool0;@3oool002H0oooo0P00000C0?ooo`030000002Y_NP0ZKgX02`0ZKgX0`2X_>P5
0:Fii`@0XKCV1@2T]nH30;O<jP<0^/oZ4P2Y_NP30:NWe`@0O7:m1020M[h308b3a0@0UXo:1P2V^^L4
0:Vnj@H0YM7g0`2Ld_/3000000@0Vm3j1@2Cbo/509[:n0D0V/Kf1@2ba^T60;o4gP030=>oaP3@`lh0
d<?>00<0d<?>103Na;h30>39`PD0dm?I0P3?h>D?0:Vmj0@0TkC]0P2Y^^H00`000000ZK[V0:VjiP02
0;K5i@<0]/KV1@2``^L60:^nj080Z[gX5P2Y_NP00`000000oooo0?ooo`0/0?ooo`002@3oool02P3o
okl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3OW4P50000000307Boo`3oool0gia80080
000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000002Y_NP0ZKgX02T0
ZKgX1P2X_>P40:Fii`D0W[;V1@2T]nH60;[?jPh0ZKgX102=U=D206UX_`@0O7:m1020M[h308b3a0H0
X[7S102V^^L60:OAmPD0X=Gj0P00000309cBn`H0U<kl102Cbo/508o5nPD0V/Kf1@2S`o050;o4gPD0
d<?>0P3<a]@30=k4_P<0h<W200@0hlo30=?Cf@3CdmT0dm?I103?h>D?0:Vmj0@0SK7^00@0ZK[V0000
002Y^^H0ZK[V1P2fa^H50:k1j0D0ZkkX602Y_NP00`000000oooo0?ooo`0:0?ooo`050=nLB0000000
00000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oO
W0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?oo
o`3oool0503oool00`000000ZKgX0:Vmj00Z0:Vmj0@0Z;cX1@2Q]^L509jbiP80Y;OV0`2gb>L30;[?
jQ00ZKgX102=U=D306UX_`<0Ngc81020M[h409ZSg0H0X[7S1@2Zd?@30:OAmP<0Y]Oi0`0000000`2P
eOX0VM3k09W@n`0409W@n`D0T/Wk1@2>ao/408o5nPD0Sl3g1@2S`o020;o4gP<0]LCU0`3@`lh40<c6
e0040=k4_P3PbL80h<W20>39`P<0hlo3103?h>D30;WAk0h0ZKgX102=/Nh20:noiP030000002__nH0
[koV00<0]/KV0`2da^L50:k1j0D0Z[kX602Y_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0
gooo0?ooo`3ooml0W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool0103oool00`3ogi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?ooobd0
ZKgX102U^^P50:6fi`@0W[;V1P2gb>LC0:Vmj0<0SICE0`1YJ;l407]lb0@0S93B102JXm`30::ah`<0
Zlca1@2Zd?@20:KGn@<0000000<0Y]Oi09oCnP2OdoX00`2OdoX509W<n@D0T/Wk1@2=`_T408[0n@D0
Sl3g102S`o060;G4i@030=33cP3<a]@0c<KD00<0c<KD103PbL830>??``80j=K31P2idN`>0:Vmj0@0
SJGU0P2__nH00`000000[koV0:noiP060;C6i`D0[L3X102Z_^PI0:Vmj0030000003oool0oooo00`0
oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo
00D0oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo
01L0oooo9`2Y_NP50:Rlj0@0YK[X102Q]^L50::fiP<0]lSW0`2ne>X@0:Vmj080NY?O102=U=D306UX
_`<0Ngc81@2<T=8409ZSg0H0Zlca0`2[eoL3000000H0Y]Gh1@2QcoP409W<n@D0U<Gh1@2=`_T408[0
n@@0Sl3g1@2H__850;G4i@D0c<KD0P3:amL20>39`P<0hlo30`3Xe/<00`3^g/40^M7/0;WAk0030;WA
k0l0ZKgX102=YND00`2__nH000000;?3iP020;?3iP<0]<KW0`2baNP40:g0j0D0Z[gX602Y_NP00`00
0000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo0?oo
o`3ookl0M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO09a8
B02Lgol01P3oool00`000000oooo0?ooo`0H0?ooobL0ZKgX1@2X_>P40:Fjj0D0WK?W102R]^H60;kD
jPl0ZKgX0`1jTml00`1KI<<0SICE08fDe@0306UX_`@0Ngc8102<T=850:S2k0<0Zlca0P2_e_@30000
00040:_Gm`2/e_H0[=Kf0:cFmP<0Y]Gh0`2WdOH50:7?n0@0VlSf1@2DaOP508nmmP@0RK_f102;^_H5
09RnlPD0[L7X0`3<a]@40<[7e`030>39`P3Scl<0hlo300<0j=K30`3^g/4C0:Vmj0@0SJGU0P2c`nH0
10000000/l?V0;?3iP2c`nH50;;5j080[L3X0`2/_nP50:Zmj1P0ZKgX00<000000?ooo`3oool01P3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0
oooo00@0oooo0P00000K0?ooobL0ZKgX102X_>P50::gj0D0WK?W1P2b`^HC0:Vmj080NY?O0`1KI<<3
06UX_`@0Ngc81@2P/nH50:S2k0040:oFm0000000000000000080[mKd1P2/e_H60:OAmPD0X/[d102K
b?H509K0m0D0Skgf1029^oH408^jmPD0TkWa1@2]`NP60<[7e`<0hlo30P3Xe/<40>kN`@030>k^b02Y
_NP0ZKgX00`0ZKgX1@2K]n`409^]i080/l?V00@000000;G7i`2eanL0]LOW102baNP60:boj0D0Z[gX
602Y_NP00`000000oooo0?ooo`050?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0
6`3oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0okmd001d_`3o
ool00P3oool01@2oM000M;oo0?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool06`3ooolW0:Vm
j0@0Y[_X1@2R]nP509ndi`@0//;V0P32d>DB0:Vmj0<0NY?O0`1KI<<307N0c`@0SicL1@2P/nH20;7B
l@<0000000<0/M;a0;;Gl`2beo<0102beo<60:kBl`D0Z<cb1@2Rb_@509c3l`@0U/3d1@2@^O8408^f
l`@0RKGc1@2C^O450:Vnj@@0b/OG0P3;bMP0103Scl<0j=K30>SF``3Xe/<30>kN`@<0k^k83P2Y_NP5
09^gk0@0VjgT0P2eanL010000000]LOW0;G7i`2eanL40;33j0D0[;oX1P2Z_NPG0:Vmj0030000003o
ool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool000P0oooo00H0oooO09a8001d_ol0oooo0=nL
B000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0B01809cOo`3oool0_g@007Boo`T0oooo00<0
00000?ooo`3oool0703ooolR0:Vmj0D0Z;gX102V^nP509jdj0D0WkCW0P2b`^H40<;@i@h0ZKgX1023
[o400`14FL<0NY?O05]T``0205]T``@0Mh3?102?W=`20:2ciP040:o9k@000000000000000080/M;a
0`2fe_030;;Gl`<0/m?a0`2^d_<30:k>l0D0Z<cb1@2SaO4509c3l`@0Ukca1@2@^O8408^fl`@0RKGc
1@2A]>l50:Vnj@80b/OG0`3;bMP30>SF``<0k]k1103^k/P?0:Vmj0@0VkO/1@2X^ND00`2eanL00000
0;G7i`030;G7j0@0/<?X1@2[_^P50:Zmj1P0ZKgX00<000000?ooo`3oool01@3oool00`2oM000M;oo
0?ooo`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P000000000
000007Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`000000oooo0?ooo`0M
0?ooob80ZKgX1@2X_NP40:>ij0D0W[CX102O]>L60<;@i@l0ZKgX0`23[o4204AI``@0FfC3101gP<l3
08nLg0030:o9k@000000000000<0[lW]1P2fe_060;?Cl@H0[/k`1@2Yanl50:?5l@D0W[k_102G_?44
092ilPD0S;;_102:/O05096dk`@0ZKkY103;bMP30<o>f0<0k]k1103^k/P20=Gkg`l0ZKgX102@Z>H5
0:Rii@030;G7j0000000]LOX0080]LOX0P2``nP30:g1j0D0ZkkX702Y_NP00`000000oooo0?ooo`05
0?ooo`060=nLB000000000000000000007@0_ooo703oool002D0oooo0P00000O0?ooob80ZKgX1@2W
_>P40:>ij0@0W[CX1P2Y^nH50;G9jPh0ZKgX1023[o4204AI``<0KGkB101gP<l01@2U^^P000000000
00000000YK[X00<0[lW]0P2gd^h30;KFl0@0^=?^1@2ccnh30:k>l0<0[/S]1@2Yanl50:C0kPD0W[k_
102H]nd409:dk`D0S;;_102:/O04096dk`D0ZKcW0P3;bMP40<o>f080f=GF103^k/P40=Gkg`l0ZKgX
102@Z>H20:Rii@<0/L?W00@0]LOX0000002eanP0]LOX1P2]`NP50:Znj1`0ZKgX00<000000?ooo`3o
ool09P3oool002D0oooo00<000000?ooo`3oool07`3ooolR0:Vmj0D0YkcX102S^NP509bcj0<0ZK_V
0`2jaN840;G9jPh0ZKgX00<09E3608>_l@23[o400P14FL<406endP04092Qg`0000000000000000D0
YK[X1@2gd^h50;SCkP<0^=3[102ccnh60:k8k@D0ZL;/1@2T`>h509jjk0@0V;O]102B]>l408bbk`D0
S:k/102B/N`50:Vli`@0clkH0`3HeMH20>?QdP80eO_O4`2Y_NP4092XiPD0/L?W00<0//KY0000002b
a^T00P2ba^T30:g1j0<0[;oX102Z_^PM0:Vmj0030000003oool0oooo02D0oooo000U0?ooo`030000
003oool0oooo0200oooo8P2Y_NP40:Nlj0D0WkOY1@2L/nP60;[5hQ40ZKgX0`0UD<H304AI``0406en
dP0000000000000000@0T:7O1@2cb^/30;OBkP@0^m;/1P2hd>/40;?:j`<0[/S]0`2^a>T50:W2k0D0
Y;cZ1@2N^^`309Rgk@D0Tk3[102>[^`508b^k0@0T[7/1@2]_NH20<o>f0<0f=GF0`3ShM820>g`b@03
0>Sk^`2Y_NP0ZKgX00`0ZKgX1@2N^N/409RXhP80/L?W0`2eb>T00`2ba^T000000;;6j@020;;6j@D0
[;oX0P2Z_^P30:Zmj1`0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?ooob80ZKgX
1@2U^nT409ngj@D0X;KX0`2jaN830<7<ha40ZKgX0`0UD<H3000000<0KGkB0P2@XMl30:Jji`D0/l[[
102kd^`30;c?j@<0^=3[0`2hbnP40;?:j`H0[/CY1@2Y_NP50:BljPD0WkGX0`2I/nT509>`j`@0SZk/
102<[^`509J`j@D0[KgV0`3HeMH30>?QdP80kO390`3Xnk/>0:Vmj0D0W[W[0`2HZ>860;G8j@030:o3
j@000000[l?Y0080[l?Y102/_nP60:Zmj1`0ZKgX00<000000?ooo`3oool0903oool002@0oooo00<0
00000?ooo`3oool08`3ooolM0:Vmj0D0Z;gX1@2U^nT409bej@D0X;KX1P31c><>0:Vmj080Bi?`0`00
000205MadP@0KGkB1P2V^^L60;[?j@H0_<oY1P2hbnP40;?5i`<0[/CY0`2^_nH50:Vmj0D0Y;OV1@2O
]NP309Vcj@@0Tk3[1@2@ZnP408j[j@D0U[3Y0P2]_NH30;C2i0040=SEeP3ShM80hn7B0>?QdP80kO39
103Xnk/?0:Vmj0@0W[W[102Y^nH30;G8j@<0]<SY00<0[l?Y0000002_`nT00P2_`nT40:Znj0D0Z[gX
7@2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T0?oooah0ZKgX102X
_NP50::ij@@0W;GY0P2P]^P30:ZkiPD0`LcS3@2Y_NP30000000404^Cl00VE<X09E3602E@aP80Eg7B
1028WN030:Jji`<0]<KX0`2jcnT30;g>i`<0_<oY0`2lbnH30;S;j0<0]lKU102caNL60:joiP80ZKgX
0`2Y^ND50:BgiP@0WkGX102J[nH409B]i`D0T:_X102>ZnT409J`j@D0]<;T0`3ShM820>g`b@<0j?^k
0`35hnd?0:Vmj0@0TJ7O102Y^nH60;C8j@030000002/`NP0[<7X0080[<7X102Z_^PQ0:Vmj0030000
003oool0oooo02<0oooo000T0?ooo`8000009P3ooolN0:Vmj0@0YkcX1@2R^NT309bej@H0Z[_V1@2h
cNX90:Vmj0<000000`2Y_NP01000?L40Bi?`02IDbP0UD<H305MadP@0R9gP1P2da^P60;g>i`H0_<_V
1P2ga^D40;;0i0D0[[oV1P2Y^ND40:BgiPD0Wk7T102J[nH409B]i`@0T:_X102>ZnT509^ai`<0]<;T
0`31cN<20>g`b@80j?^k1@35hnd?0:Vmj0@0TJ7O0P2Y^nH30;?7j@<0]<SY0`2`aNT010000000[<7X
0:c1j02/`NP50:Zmj240ZKgX00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?oooah0ZKgX
102W_>P40::ij@D0VkCY0`2Z^nH30;O1hP@0^<gZ1P2Y_NP2000000L0ZKgX00<003g104^Cl00VE<X0
101GLM8409nciP<0]<KX0`2kbNH30;g>i`<0_/_T0`2lbnH30;_7h`<0]lKU0`2g`N840;;0i0D0[[_S
1@2Y^ND50:Bch`D0Wk7T0`2J[nH509JYi0@0TZSU102BZNH509^ai`@0`LgS0`3Cgn420>?feP80fobc
4P2Y_NP4096Qg`H0/lOY1@2`aNT00`2/`NP000000:^oj0020:^oj0D0Z[gX8@2Y_NP00`000000oooo
0?ooo`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0
gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?oooad0ZKgX0P2W_>P2
0:Jkj@@0WkSZ1@2K]>T60;O1hPH0ZKgX0`0000090:Vmj08003g10P0VE<X407:>g`@0Wk?V1P2kbNH6
0;k;i0H0^lOS1P2g`N820;;0i0<0/[cQ102^^n<50:Veh@D0Y;?S102O/N@409Z[hPD0UZWT102BZ>D4
09:YiPD0Y;OV0P31cN<30=?Oh@80hoKF0P3Ko;<20<oaj@h0ZKgX102FYn840::bi0<0/lOY0`2db^X4
0;35j@80ZkoX00@000000:^oj02[_nP0ZkoX0P2Z_NPS0:Vmj0030000003oool0oooo0240oooo000<
0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool01P3oool00`000000oooo0?ooo`0Z0?oooa`0ZKgX1@2V^nT409nhjPD0W[KY0`2g`N830<75
g@80ZKgX0`0000090:Vmj0@0V;O^0P00?L400`0iK=P09UC:07:>g`0307:>g`80Wk?V0`2^_nH30;_9
iP80_LWS0`2nbn@30;k7h@<0^lOS0`2j`^050;O1hPH0/[cQ102]]^050:Veh@D0Y:oO102O[N4409Z[
hP@0UZWT102BZ>D509N[i0@0Y;OV103Cgn420>?feP80fobc0`3?lNT?0:Vmj0@0UZOR102R/^@60;C:
jP@0[L;Y00<0ZkoX0000002[_nP00P2[_nPV0:Vmj08000008@3oool000`0oooo00L0oono07@0M02o
ool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo702Y_NP5
0:Jkj@@0W;O[1@2N]^T40<75g@<000003@2Y_NP309RgkP04000V/@00?L40>FcH03U/f0@0LXkO1P2^
_nH50;g9h`H0_/OQ1P2j`^050;Jmg`<0/[cQ0`2a^=h40:ffh080ZKGQ0`2X/Mh50:B_g`<0WjgQ102J
Zn8509NWh@@0U:OR1@2GZn@20:BgiP80//CX0P3Cgn420>?feP030=_l/`3?lNT0co7Y0080co7Y402Y
_NP409JWhPD0/<GY0`2db^X30;77jP@0[L;Y00<0Z[kX0000002Z_^P00P2Z_^PV0:Vmj0030000003o
ool0oooo01l0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md
001d_ol0oooo00D0oooo00<000000?ooo`3oool0;03ooolL0:Vmj0D0Y;_Y102L]n/50:>ij0<00000
00<0`LGM0;o6g`2oa]l03P2Y_NP309RgkP04000V/@00?L40>FcH03U/f0@0RZGV0`2^_nH30;K3i0<0
_LWS0`2na^030;k7h@80_L?N0`2j`^030;Vng@D0][gO1P2a^=h30:ffh0H0Z;7N102T[ml409nZgP@0
VjSO1@2GYn4409BWhP@0Uj_T1@2ba>P20>?feP040=Kmg02dkY/0]>jK0;C^Va80ZKgX1@2M[N850;35
j@D0/LOZ1@2[_nP00`2Z_^P000000:Znj0020:Znj2D0ZKgX00<000000?ooo`3oool07`3oool000`0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oo
g`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3ooolH0:Vmj0@0Z;gX1@2T^nT409Zfj`050:>i
j000000000000000002S^NP00P31aMd40;o6g`h0ZKgX0P1YY?<2000V/@<0>FcH102:YNH60;K3i0H0
_/KP1@2m`mh60;Vng@80][gO0`2e^M`50;6hgP@0[K;L1@2X/Mh50:B/g0@0Wj[N102KZ=l409NWh@@0
U:OR1@2N/ND30;;4j080a]kZ00<0e_gL0;C^V`2dkY/00`35hnd>0:Vmj0@0VZWQ1@2M[N850;C;j`80
/LOZ0`2^`nT50:^oj0030000002Y_NP0ZKgX02L0ZKgX00<000000?ooo`3oool07P3oool000`0oooo
00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d
_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo602Y_NP40:Rmj0D0X[[Z00@0V[K[0000
000000000000102S^NP60;o6g`l0ZKgX0`1YY?<00`009[40CX?T04j3i00509^cj0<0]/?T0`2ja>84
0;k6h080_/?N0`2m`mh20;bog0D0^KkM1P2e^M`20;6hgP<0/;CK102]/]`20:RagP<0Z:gK1@2T[=`3
09nZgP@0VjSO1@2IY]l409RXh@D0W[7U0`36g^X00`3FoM`0]>jK0<GSk@040<GSk@l0ZKgX102JZN42
09f]hP<0[/CZ102dbn/60:k3j@D0Z[kX00<000000:Vmj02Y_NP09`2Y_NP00`000000oooo0?ooo`0M
0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q809cO
o`090?ooo`800000<@3ooolH0:Vmj0D0YkcX00@0X[[Z0000000000000000102J]^/40:ZliP<0_lKO
0`2laN4>0:Vmj0@0JJCc00<002Ja04j3i01>Pn@01@2K/nP60;[4hP80_/KP102n`mh00`2m`mh0_;oL
0;bog0020;bog080^KkM0`2h^]/50;Fig0H0/;CK0`2]/]`60:R]f`@0Y:cL102OYm/409bVg@D0VJKO
102HZ>450:c1j@80e_gL00@0^_c<09?KQ@2CfhD0Tm^54P2Y_NP409ZYh@H0[/CZ102ab>/30:k3j@<0
ZkoX102Z_^P00`2Y_NP000000:Vmj00W0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`060?oo
g`2LB000M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo
0340oooo602Y_NP30:Nlj08000000`2R^^X509Zfk0@0Z[cV1P2laN4>0:Vmj0@0Bi?`0`1>Pn@50:Fj
j0D0^/CR1P2n`mh50;bog0H0^;[K0P2e^M`30;BefPD0/;CK102/[mX50:R]f`D0Y:WJ0`2OYm/509bV
g@@0VJKO1@2O/N@30:c1j@80`>C`00<0^_c<0:Vmj02Y_NP0402Y_NP509^VgP@0WJgR0`2^a>X30;?;
k0@0/LS[1@2[_nP20:Znj0@0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0L0?oo
o`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia800000000000000000000M02o
ool50?ooo`030000003oool0oooo0380oooo5`2Y_NP3000000<0Y[cY0`2O^N/509Zfk0D0/;kT0`2l
aN420;S3hPh0ZKgX101;To0305bDk@D0YK[X0P2ja>830;_2h0<0_/?N0`2m`=`30;bog080^k_J1@2h
^]/60;BefP80/;CK0`2`/=P40:b_fP80Z:gK0`2WZ]T50:BYfP<0WjOK102LY]d509bYg`D0Wk7T0`30
i?000`2jo<`0eO_O0=Gkg`0B0:Vmj0D0VjKN102M[N850;?;k0D0[L?Y102[_nP60:Vmj0030000002Y
_NP0ZKgX02L0ZKgX00<000000?ooo`3oool06`3oool00280oooo0P00000d0?oooa<0ZKgX0`000000
0`2Y_NP0Y[cY0:Jlj@040:Jlj@<0WkW[1@2J]n`50;2ni0D0^<?R3P2Y_NP304^Cl004000RY01LU>d0
G9C]05bDk@@0YK[X1P2k`^060;g0g0D0^k_J0P2h^]/30;Ngf0D0];GJ1P2`/=P30:b_fPD0Yj[I1@2T
ZMX309nWf`D0WJOM1@2LZMl209nai0<0[<S^00<0`>C`0;[lc03Enml00`3EnmlB0:Vmj0@0VjKN1@2^
a^/50;38j`D0[L?Y102Z_^P60:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool06`3o
ool00280oooo00<000000?ooo`3oool0=03oool?0:Vmj0<000001P2Y_NP40:Jlj@D0W[W/102J]n`5
0;G0hP<0^<?R0`2f`>8=0:Vmj0@0Bi?`0`1PWo840:Vnj0<0^l;P0`2j`Ml30;g0g0<0_;gJ102k^mX6
0;Ngf0D0/k;G1@2`/=P40:^/f0D0Yj[I0P2TZMX30:BXf@<0X:OK1@2MYmd409bYg`D0[<S^00<0^?Ga
0=Gkg`3Enml00`3EnmlB0:Vmj0D0XK;T0`2^a^/20;;<k@D0/<S[1@2[_nP40:Znj0H0ZKgX00<00000
0:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?oo
o`030000002Y_NP0ZKgX00P0ZKgX0`00000:0:Vmj0@0Y[cY1@2N^N`409^hk@D0]L3R1P2f`>8=0:Vm
j0@0JJCc0`1PWo840:Vnj0H0^/7O1P2l_MX20;^kfP<0^[WH0`2g]mP20;Jde`D0/k;G0P2`/=P30:n^
e`@0ZjcH102WZ]T50:BXf@@0X:OK102MYmd50:>gi`<0[<S^00<0^?Ga0=Gkg`3Enml04@2Y_NP20:Vd
h0@0Uj7K1@2Q/^@50;;<k@D0[L;Y102[_nP;0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?oo
o`3oool0303oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool0
0280oooo00<000000?ooo`3oool0=`3oool60:Vmj0<000003P2Y_NP40:Jlj@D0WKW/102K^>d20;G0
hP<0]l7Q0`2f`>830;Fnh0d0ZKgX101YY?<305FSmP@0ZL3Z0`2j`Ml30;W0g`D0_;gJ1P2j^MP50;Jd
e`@0/k;G1P2_[]L30:^/f0D0YjWH1@2TZ=T30:2Wf`D0XJoQ1@2S]nL20;SelA80ZKgX102Y]>0509NQ
f`D0/<W]0P2bc>d30:o6j`D0[L;Y102Z_^P:0:Vmj0030000002Y_NP0ZKgX02H0ZKgX0P00000<0?oo
o`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0oooo000Q0?ooo`800000
>P3oool20:Vmj0<000004P2Y_NP50:Flj@@0WKW/0`2K^>d60;O1h@H0]KkP3P2Y_NP309RgkP<0EJ?f
102Y`>X60;W0g`80_;gJ0`2j_=/30;Zif0<0^;OH102f]=L50;:`ePD0[jkG102[ZmL50:NYf0@0Y:SI
102R[=h50:6_h@@0[mgg00<0N=jb0;WAk02Y_NP04P2Y_NP40:Vdh080Uj7K0`2W_>T40;39k@H0[lK[
1@2[_nP40:Znj0X0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oO
W01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00240oooo00<00000
0?ooo`3oool0>03oool300000140ZKgX1@2X_NP50:Flj@@0W;W]102K^Nd50;O1h@D0]KkP4P2Y_NP3
02jHl0D0Y<?_102i`=l60;Zlf`H0^;OH0P2f]=L20;Fdf0D0/[3F0P2_[]L30:j^e`@0Zj_G102WZMP5
0:F/g0@0XZcN1P2Xbo8207SN/P<0^M7/4P2Y_NP40:Vdh0H0YkcY102abnd30:o6j`<0[<7Y102[_nP?
0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3o
ool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0
oooo0P0000030?oooa<0ZKgX102X_NP50:FljP@0W;W]102K^Nd50;O1h@D0]kgN4P2Y_NP302jHl0D0
Y<?_102f`^<30;Zlf`<0^;gM1@2h]mP50;Fdf0@0/[3F1@2^[]L40:^[e`D0Z:gK1@2U[=`20::/gP80
Yl7/0`2Xbo8208O/gP030;o`lP2Y_NP0ZKgX0140ZKgX102OYMX409^Xg`<0YkcY0`2`c>h40;7;k@D0
[<7Y0P2[_nP30:Zmj0h0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`090?ooo`0;
0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo0P00
000d0?ooo`<000001P3ooolC0:Vmj0@0Z;gX1@2U_>X309bik@D0Vk[^0`2g`N420;G1h`D0]kgN4`2Y
_NP00`1;To0006W109G7n@0409G7n@@0]/;S1P2h_Md20;Rgf0<0]kWK102e]=P50;6bf0@0[ZkG1@2[
[m/50:R]f`@0YJcL1@2W`N`208O/gQ80ZKgX1@2Y/Mh409nUfP@0VjSO1@2`c>h50:k4j`@0[<7Y1P2Z
_NP>0:Vmj0030000002Y_NP0ZKgX02H0ZKgX00<000000?ooo`3oool0203oool02`3ogi`0B01d0;oo
o`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo
0300oooo0`0000090?oooa@0ZKgX102X_NP50:FljP<0W;[]1@2K^^h50;G1h`80]kgN0`2j_M`C0:Vm
j080Bi?`1@2EaoT20;K2h`80[/S/1@2h_Md60;Nif`80]KCH0P2c^=`50;6bf080[ZkG0P2^]=d50:^_
f`@0Z:gK1@2W_NT20:O1k080T>cc5@2Y_NP50:VagP<0WjGJ1P2/and40:o8k@D0[/C[102Z_^P50:Zm
j0l0ZKgX00<000000:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?ooo`0=0;md000004P0W;nL
04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`00103oool03@3ookl0
M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@0B02Lgol0103oool01@3OW4P0
00000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;@3oool3000000h0oooo4`2Y_NP40:Rm
j0D0YKcZ0`2L^^d509ZjkP@0]L7S1P2j_M`E0:Vmj0@0ULOi1@2^b>`20;Rmg@<0/lCV1@2g^M/50;>h
g0@0/K;H1@2^]=d40:^_f`D0ZKkX102W_NT2093/laP0ZKgX102Y/Mh40:Fkj0<0[<O]0`2`c>h40:o8
k@D0Zl3Y102Z_^PD0:Vmj0030000002Y_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool02`3o
_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo00030?ooo`060?oo
g`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?ooo`070?noM000B9`0gooo
0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00000B0?oooa<0ZKgX102X
_NP50:FljP@0WK[]102J^^h50;71iP<0^[gL0P2m_m/F0:Vmj0@0Hl?m0`2^b>`60;?4iP80]kWK0`2c
`nH40;>hg0D0/;_R102^]=d50:_2j`D0ZKkX0P2Aj?TK0:Vmj0D0WjcP102U^nP50;3<kPD0[<;Z102[
`>TH0:Vmj0030000002Y_NP0ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW018
07@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;oo
o`3oool0omnL04P0M02oool01@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0
oooo0P00000Y0?ooo`<000005P3ooolC0:Vmj0@0Z;gX1@2U_>X409fjk@@0VK__1@2a`NH50;fof`D0
ZK7N4`2Y_NP00`23[o40:@0009GCo@0209GCo@D0/lCV1P2c`nH20;>hg080[lS]1@2`^n840:[;l@D0
Zl;[102<i_TG0:Vmj0<0Z:WG102MX]P409n/h0D0[/c_0`2`c>h20:g5j`D0[<;Z102Z_^PH0:Vmj003
0000002Y_NP0ZKgX01`0ZKgX0`0000050?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Bo
o`3oool0103oool00`000000oooo0?ooo`0U0?ooo`<000006P3ooolB0:Vmj0D0Z;gX102U_>X509jk
k@@0VK__1@2Z`>X30;fof`80`<;K1@2Y/MhE0:Vmj0<0UM?m1@2PeOX50;?3iPD0[lS]0P2`^n830:;J
n`@0Z/_a1P1hhO0G0:Vmj0D0Z:WG1@2MX]P40:c9k`D0[/c_1@2]aN/90:Znj1P0ZKgX00<000000:Vm
j02Y_NP0602Y_NP3000000P0oooo00<000000?ooo`3oool05@3oool000<0oooo00L0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02Lgol00P3oool01`3ogi`0B01809cOo`3o
ool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R0?ooo`<000007P3ooolB0:Vmj0D0Z;gX
102V_>T509jkk@@0VK__1@2Z`>X50<32f`80ZK7N0`2d]m/I0:Vmj0@0X=Gj1P2Jfod30:o8k@H0X][k
0P13aLTK0:Vmj0@0Z:cJ1@2XZML209fRf0<0Z<?]102/bNl50:k8k@D0ZkoY102Z_^PM0:Vmj0030000
002Y_NP0ZKgX01<0ZKgX1000000<0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000M;l0oooo0?ooo`3ookl0M0000`000000
0`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo0`00000R0?oooaL0ZKgX102V_>T5
09nkk0@0VK__1@2S_nh40<32f`H0];OK102Y]>0O0:Vmj0@0Km_c7@2Y_NP50:V_g@@0Z:cJ102XZML5
0:S3k@D0[/__0`2^b>d20:_1jPD0ZkoY802Y_NP00`000000ZKgX0:Vmj00?0:Vmj0040?ooo`000000
000000000100oooo00<000000?ooo`3oool0503oool000<0oooo00L0oono07@0M02oool0oooo0?oO
W01807@0_ooo00H0oooo00L0oono07@0B02Lgol0oooo0?oog`2LB4P0W=oo00T0oooo0P00000N0?oo
o`8000009P3oool00`000000ZKgX0:Vmj00D0:Vmj0@0Y[cY1@2O^n`409Vkk`D0Xko^102h`n<30;Bg
f`<0_KkK102Y]>0l0:Vmj0@0ZK7N1@2Y[md30:R/fPH0Y[_X102]c?050:k;k`D0Zl7Z1@2Z_^PP0:Vm
j0030000002Y_NP0ZKgX00X0ZKgX0P3oool3000001<0oooo00<000000?ooo`3oool0503oool000<0
oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0gooo0?ooo`2oM000M;oo
203oool2000001`0oooo0`00000Z0?oooaH0ZKgX102V_>T50::lk0@0VK__1@2L__040;S3h`H0_KkK
0P2Y]>020;6cfSL0ZKgX2@2Y/Mh40:V_g@@0YKGT0`2V^nP30:c<l@@0[Lc`1@2/`n/20:_1jPL0Z[kX
8@2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103o
ool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo
0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo
5P2Y_NP50:Nmj@@0X[c/102K^nl509bnl0@0Zl?[1@2m_]/50;6cfPD0Z:cJ;@2Y_NP50:V_g@P0ZK7N
1@2U/N040:Fei0D0[<ca1@2/aN`40:c3j`H0Z[kX902Y_NP00`000000ZKgX0:Vmj0050:Vmj0800000
6P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3o
oolF0:Vmj0D0YkgY102T_>/409^kk`D0VKga102[`n/50;[4hP<0/K?J0P2n`=/50:R/fP@0ZK3M9@2Y
_NP40:R/fPD0ZJoM0`2Y/Mh50:N_gP@0YK7P1P2Zc?440:c7kPD0[<G/102Z_nP30:Znj2L0ZKgX00@0
00000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000003oool0oooo01@0oooo000O0?ooo`8000004`3o
ool3000003H0oooo5P2Y_NP50:Rmj0@0Y;c[1@2O_>d409Vml@@0Wl7`1@2ja>850;k0f`80Z:cJ0`2i
^]X90:V`gA/0ZKgX1@2XZML40:R/fP@0ZJoM102Y/=d50:N_gPD0ZL_a1@2[b>l40:c7kPD0Z[oY102Z
_nPY0:Vmj0<00000803oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0?
0?ooo`<00000>P3ooolF0:Vmj0D0Z;gX102V_>X509nlk@@0Vkc`102O`O050:W4k@@0_/3K1P2i^]X2
0:V`g@80]KKI1@2Y/=d40:R/fPD0ZKgX102Y]>040:Vmj0D0ZK7N0`2Y_NP20:RWe@D0Z:WG0`2X[=X5
0:^cgP@0ZK3M1@2Yb_430:W;l@80Z/W`102[b>l50:[0j@@0Z[oY:@2Y_NP3000000<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0<0?oo
o`<00000?P3ooolK0:Vmj0@0Y[cZ1@2R_>`409^ll0@0V[ka1@2Ya>d40;;5j@D0^K[J1@2e]]T20:V`
g@<0]KKI102X[=X50:RXe`@0ZKCP102XZML50:VagPD0Z:OE102XZML40:fhh@D0Zk?N102XbO450:W:
l@D0Z/W`102Z`NX50:[0j@@0Z[kX9@2Y_NP3000000H0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`<00000@P3ooolK0:Vmj0@0
YkgY1@2R_>`409nmkP@0V[ka1@2M`O840;;5j@D0]/GV2P2e]]T20:R/fP80^K[J102XZ=L50;6`f0@0
Z:WG1@2c/mT40:RWe@D0[[kU102]^>450:S:lP@0Z<Wa1@2YbO050:[2j`@0Z/7Z2@2Z_^PP0:Vmj0@0
00002P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo000N0?ooo`800000
2@3oool2000004H0oooo6`2Y_NP40:Nmj@D0YKgZ102O_Nh409bml0D0WL7b102Pa?890;K5iPD0]KKI
1@2i^]X20:RXe`80]l7Q1@2a/=P20:RYe`80];oR1@2c/mT20:RWe@80[LC[1@2^_^D40:O;lP@0Z<[b
1P2XbO490:[2j`P0Z[kX802Y_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0oooo
6`2Y_NP40:Rmj0D0YKgZ102S_N/409bml0D0Vkoa102Pa?850:?5l@@0]/GV1@2ba^T40;VjfPD0]l7Q
102a/=P50;BohP@0/k?I1@2]a>/50:K;l`@0Yl_b102Wb?430:S9l@<0ZL;[102Z`^/50:Vnj0@0Z[kX
802Y_NP0103oool0000000000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool04`3oool001h0oooo00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP0
602Y_NP40:Rmj0D0YkgY102S_N/40:6mk@D0Vkoa102L`?850:?5l@@0X/Kb102ba^T50:c8kP@0]l7Q
1@2]and40;BohPD0ZLS`1@2TbO<40:K;l`D0YlO`102Wb?450:W2j`T0ZKkX802Y_NP00`3oool00000
00000002000001H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3o
ool00`000000oooo0000000200000540oooo00<000000:Vmj02Y_NP0702Y_NP50:Nmj@@0Y[gZ102Q
_Nd50:2nkP@0W<3b1@2L`O840:;6lP@0X<Kc1@2/b>h40:G8lPD0[LO]1@2UbO<40:?7l`D0Y<Wc102V
aO050:O7l0D0ZL7[2@2Y_^PQ0:Vmj0<000006`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01<0oooo000N0?ooo`800000E@3oool00`000000ZKgX0:Vmj00L0:Vmj0D0Z;gX102V_NX4
0:FmjPT0X;k^1@2L`O8409k2lP@0X<Kc1@2OaO<40:G8lPH0XLOc102SaO440:?7l`D0Y/?^102VaO05
0:S1j`T0ZKkX8`2Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vm
j02Y_NP0702Y_NP90:Rmj0@0YKgZ1P2U_N/30:2nkPH0XKo^0`2N`_8509o2l@@0WlGc1@2Qa?850:C2
k`@0XlGa102V`^d50:K3kP@0Z<3Z0`2X`N/70:Vnj2<0ZKgX00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00X0
oooo0P00001F0?ooob<0ZKgX102X_NP40:Rmj@<0YKg[0`2X_NT40:Fmj`D0Y[k[102S_nd40:Fok0D0
X/7_102U`>`40:C2k`D0Yl3/102V`^d50:RojP@0Z<3Z1@2Y_^PS0:Vmj08000009`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00`0oooo
00<000000?ooo`3oool0E03ooolW0:Vmj0h0Z;gY102V_^/50:NnjP@0YKo/1@2W_^/40:G0k0@0YkkZ
1@2W`>`40:Rnj@@0Z;oZ1P2Y_^PS0:Vmj0800000:`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00d0oooo00<000000?ooo`3oool0E03o
oola0:Vmj0P0Z;gY1@2W_^X40:Rmj@@0Ykk[1@2X_^T40:NnjPD0ZKkY102X_^T40:Vmj0<0ZKkX8@2Y
_NP200000300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool0
0`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0oooo=@2Y_NP40:Rmj@D0ZKgX102X_NT4
0:Vmj0D0Z;kY102Y_NP40:VnjBP0ZKgX0`00000c0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?oo
ogL0ZKgX0`00000g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140
oooo00D0_g@00000B02L_i`0B01d0;ooo`0@0?ooo`800000E@3ooomb0:Vmj0<00000?03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oo
oa80oooo00<000000?ooo`3oool0D`3ooom^0:Vmj0<00000@03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo01<0oooo00<000000?ooo`3o
ool0D`3ooomY0:Vmj0@00000@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo000Z0?ooo`030000003oool0oooo05<0ooooI@2Y_NP3000004P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0ooooH02Y_NP0103oool000000000
0000001<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002d0oooo00<0
00000?ooo`3oool0DP3ooomL0:Vmj0@00000C`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0140oooo000^0?ooo`030000003oool0oooo0580ooooF02Y_NP3000005@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00;`3oool00`000000oooo0?ooo`1B0?oo
oe<0ZKgX00@0oooo0000000000000000F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0140oooo000`0?ooo`030000003oool0oooo0580ooooC`2Y_NP4000005`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0ooooBP2Y_NP0103oool0
000000000000001P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool003<0
oooo00<000000?ooo`3oool0D@3ooom60:Vmj0@00000I03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo000d0?ooo`030000003oool0oooo0540oooo@P2Y_NP3000006T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo0?oo
o`1A0?ooocd0ZKgX00@0oooo0000000000000000K03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo000f0?ooo`800000DP3oooli0:Vmj0@00000L03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo000h0?ooo`030000003oool0oooo0500oooo=@2Y_NP3
000007D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`00>@3oool00`00
0000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo0000000000000000N@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo000j0?ooo`030000003oool0oooo0540oooo:`2Y_NP40000
07`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool00`000000
oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03`3oool003`0oooo0P00001B0?ooob80ZKgX00@0oooo0000000000000000Q@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo000n0?ooo`030000003oool0oooo0500oooo
7P2Y_NP4000008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00?`3o
ool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00002=0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03`3oool00400oooo00<000000?ooo`3oool0D03ooolF0:Vmj0<00000T@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00110?ooo`800000D@3ooolB0:Vm
j0<00000U@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00130?ooo`03
0000003oool0oooo04l0oooo3@2Y_NP3000009T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0?0?ooo`00A03oool00`000000oooo0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0D03o
ool40:Vmj0<00000X@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo0016
0?ooo`800000D@3oool200000:H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`00B03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B@3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00
BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00C03oool2
000004/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo001?0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0
oooo001@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo001A0?ooo`800000AP3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool005<0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`2/0?ooo`050000003oool0oooo0?ooo`0000003`3o
ool005@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`040000003oool0
oooo000000l0oooo001E0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0[P3oool0
10000000oooo0?ooo`00000?0?ooo`00EP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`0000003`3oool005L0oooo0P00000o0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`0000003P3oool005T0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`2a0?ooo`8000003P3oool005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`2a0?ooo`8000003P3oool005`0oooo0P00000j0?ooo`030000003oool0oooo0:d0oooo1000000@
0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:T0oooo1000000D0?oo
o`00G`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0oooo1000000H0?ooo`00
H03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:40oooo1000000L0?ooo`00H@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo09h0oooo0`00000P0?ooo`00HP3oool2
000003@0oooo00<000000?ooo`3oool0VP3oool4000002<0oooo001T0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0UP3oool4000002L0oooo001U0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0TP3oool4000002/0oooo001V0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0SP3oool4000002l0oooo001W0?ooo`800000;`3oool00`000000oooo0?oo
o`2:0?ooo`@00000<`3oool006T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`27
0?ooo`<00000=`3oool006X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`230?oo
o`@00000>P3oool006/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1o0?ooo`@0
0000?P3oool006`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1k0?ooo`@00000
@P3oool006d0oooo0P00000Y0?ooo`030000003oool0oooo07L0oooo100000160?ooo`00K`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo0`00001:0?ooo`00L03oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0740oooo1000001=0?ooo`00L@3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001A0?ooo`00LP3oool2000002<0oooo
00<000000?ooo`3oool0J@3oool4000005D0oooo001d0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0I@3oool4000005T0oooo001e0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0HP3oool3000005d0oooo001f0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0GP3oool400000600oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0FP3oool4000006@0oooo001h0?ooo`8000007@3oool00`000000oooo0?ooo`1F0?ooo`@00000
J03oool007X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`@00000K03o
ool007/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000L03oool0
07`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`<00000M03oool007d0
oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000001g0?ooo`00O`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000001k0?ooo`00P03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo03l0oooo1000001o0?ooo`00P@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo03/0oooo100000230?ooo`00PP3oool2000001<0oooo00<000000?oo
o`3oool0>03oool3000008L0oooo00240?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0=03oool4000008X0oooo00250?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
<03oool4000008h0oooo00260?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;03o
ool400000980oooo00270?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool4
000009H0oooo00280?ooo`8000003@3oool00`000000oooo0?ooo`0U0?ooo`<00000VP3oool008X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`@00000W@3oool008/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000X@3oool008`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000Y@3oool008d0oooo0P000007
0?ooo`030000003oool0oooo01H0oooo1000002Y0?ooo`00S`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0180oooo1000002]0?ooo`00T03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00l0oooo0`00002a0?ooo`00T@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo1000002d0?ooo`00TP3oool01@000000oooo0?ooo`3oool0000000T0oooo
1000002h0?ooo`00T`3oool2000000030?ooo`000000oooo00@0oooo1000002l0?ooo`00U@3oool2
000000030?ooo`000000000000800000`03oool009H0oooo0P0000340?ooo`00o`3ooomM0?ooo`00
o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00
o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53712 .60512 .53085 Mtetra
.60512 .53085 .61081 .53712 .62207 .53373 .61641 .52744 Mtetra
.61641 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .49911 .7318 .49256 Mtetra
.7318 .49256 .73714 .49911 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .4782 Mtetra
.7793 .4782 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47093 Mtetra
.80335 .47093 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44442 .91411 .43744 Mtetra
.91411 .43744 .91891 .44442 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .426 Mtetra
.95198 .426 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52455 Mtetra
.59939 .52455 .60512 .53085 .61641 .52744 .6107 .52111 Mtetra
.6107 .52111 .61641 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51072 Mtetra
.64492 .51072 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50372 Mtetra
.66797 .50372 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49666 Mtetra
.6912 .49666 .69669 .50317 .70834 .49965 .70289 .49311 Mtetra
.70289 .49311 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .4782 .77406 .47149 Mtetra
.77406 .47149 .7793 .4782 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47093 .79818 .46416 Mtetra
.79818 .46416 .80335 .47093 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .4599 .83474 .45305 Mtetra
.83474 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43042 Mtetra
.90928 .43042 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .426 .94727 .41888 Mtetra
.94727 .41888 .95198 .426 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52455 .59361 .51819 Mtetra
.59361 .51819 .59939 .52455 .6107 .52111 .60496 .51473 Mtetra
.664 .741 .908 r
.60496 .51473 .6107 .52111 .62206 .51766 .61635 .51126 Mtetra
.61635 .51126 .62206 .51766 .63347 .51419 .62778 .50777 Mtetra
.62778 .50777 .63347 .51419 .64492 .51072 .63927 .50427 Mtetra
.63927 .50427 .64492 .51072 .65642 .50722 .6508 .50076 Mtetra
.6508 .50076 .65642 .50722 .66797 .50372 .66238 .49722 Mtetra
.66238 .49722 .66797 .50372 .67956 .50019 .67401 .49367 Mtetra
.67401 .49367 .67956 .50019 .6912 .49666 .68568 .4901 Mtetra
.68568 .4901 .6912 .49666 .70289 .49311 .69741 .48652 Mtetra
.69741 .48652 .70289 .49311 .71463 .48954 .70918 .48293 Mtetra
.664 .741 .907 r
.70918 .48293 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47569 Mtetra
.73287 .47569 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43042 .90441 .42333 Mtetra
.90441 .42333 .90928 .43042 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52217 Mtetra
.664 .741 .908 r
.55394 .52217 .55985 .52849 .57106 .52507 .56518 .51873 Mtetra
.56518 .51873 .57106 .52507 .58231 .52164 .57646 .51528 Mtetra
.663 .741 .908 r
.57646 .51528 .58231 .52164 .59361 .51819 .58779 .51182 Mtetra
.663 .742 .908 r
.58779 .51182 .59361 .51819 .60496 .51473 .59917 .50836 Mtetra
.663 .742 .909 r
.59917 .50836 .60496 .51473 .61635 .51126 .61059 .50488 Mtetra
.663 .743 .909 r
.61059 .50488 .61635 .51126 .62778 .50777 .62206 .50139 Mtetra
.663 .744 .91 r
.62206 .50139 .62778 .50777 .63927 .50427 .63358 .49788 Mtetra
.63358 .49788 .63927 .50427 .6508 .50076 .64514 .49434 Mtetra
.664 .745 .91 r
.64514 .49434 .6508 .50076 .66238 .49722 .65675 .49078 Mtetra
.65675 .49078 .66238 .49722 .67401 .49367 .66841 .48719 Mtetra
.66841 .48719 .67401 .49367 .68568 .4901 .68012 .48358 Mtetra
.665 .744 .909 r
.68012 .48358 .68568 .4901 .69741 .48652 .69188 .47995 Mtetra
.665 .743 .909 r
.69188 .47995 .69741 .48652 .70918 .48293 .70368 .4763 Mtetra
.665 .743 .908 r
.70368 .4763 .70918 .48293 .721 .47931 .71554 .47265 Mtetra
.664 .742 .908 r
.71554 .47265 .721 .47931 .73287 .47569 .72744 .46898 Mtetra
.72744 .46898 .73287 .47569 .74479 .47205 .7394 .4653 Mtetra
.664 .741 .907 r
.7394 .4653 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52613 Mtetra
.51445 .52613 .5205 .53242 .5316 .52902 .52558 .5227 Mtetra
.664 .741 .908 r
.52558 .5227 .5316 .52902 .54275 .5256 .53676 .51927 Mtetra
.663 .741 .908 r
.53676 .51927 .54275 .5256 .55394 .52217 .54798 .51583 Mtetra
.663 .741 .909 r
.54798 .51583 .55394 .52217 .56518 .51873 .55925 .51239 Mtetra
.662 .742 .91 r
.55925 .51239 .56518 .51873 .57646 .51528 .57057 .50897 Mtetra
.661 .743 .911 r
.57057 .50897 .57646 .51528 .58779 .51182 .58193 .50555 Mtetra
.66 .745 .913 r
.58193 .50555 .58779 .51182 .59917 .50836 .59334 .50214 Mtetra
.66 .748 .915 r
.59334 .50214 .59917 .50836 .61059 .50488 .6048 .49872 Mtetra
.66 .751 .917 r
.6048 .49872 .61059 .50488 .62206 .50139 .6163 .49528 Mtetra
.661 .754 .919 r
.6163 .49528 .62206 .50139 .63358 .49788 .62785 .49181 Mtetra
.662 .756 .92 r
.62785 .49181 .63358 .49788 .64514 .49434 .63945 .48828 Mtetra
.663 .758 .92 r
.63945 .48828 .64514 .49434 .65675 .49078 .6511 .48469 Mtetra
.665 .758 .92 r
.6511 .48469 .65675 .49078 .66841 .48719 .66279 .48104 Mtetra
.666 .757 .919 r
.66279 .48104 .66841 .48719 .68012 .48358 .67453 .47734 Mtetra
.667 .756 .917 r
.67453 .47734 .68012 .48358 .69188 .47995 .68632 .47361 Mtetra
.667 .753 .915 r
.68632 .47361 .69188 .47995 .70368 .4763 .69816 .46984 Mtetra
.667 .75 .913 r
.69816 .46984 .70368 .4763 .71554 .47265 .71004 .46608 Mtetra
.666 .747 .911 r
.71004 .46608 .71554 .47265 .72744 .46898 .72198 .46231 Mtetra
.666 .745 .909 r
.72198 .46231 .72744 .46898 .7394 .4653 .73396 .45856 Mtetra
.665 .743 .908 r
.73396 .45856 .7394 .4653 .7514 .46161 .746 .45481 Mtetra
.665 .742 .908 r
.746 .45481 .7514 .46161 .76346 .45791 .75809 .45106 Mtetra
.664 .741 .908 r
.75809 .45106 .76346 .45791 .77556 .4542 .77023 .44731 Mtetra
.664 .741 .907 r
.77023 .44731 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53007 Mtetra
.47515 .53007 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52323 Mtetra
.664 .741 .908 r
.49725 .52323 .50337 .52954 .51445 .52613 .50836 .51979 Mtetra
.663 .741 .908 r
.50836 .51979 .51445 .52613 .52558 .5227 .51952 .51636 Mtetra
.662 .741 .909 r
.51952 .51636 .52558 .5227 .53676 .51927 .53073 .51294 Mtetra
.66 .742 .91 r
.53073 .51294 .53676 .51927 .54798 .51583 .54198 .50956 Mtetra
.658 .744 .913 r
.54198 .50956 .54798 .51583 .55925 .51239 .55328 .50622 Mtetra
.656 .747 .917 r
.55328 .50622 .55925 .51239 .57057 .50897 .56463 .50294 Mtetra
.653 .752 .922 r
.56463 .50294 .57057 .50897 .58193 .50555 .57603 .4997 Mtetra
.652 .758 .928 r
.57603 .4997 .58193 .50555 .59334 .50214 .58747 .49646 Mtetra
.652 .765 .933 r
.58747 .49646 .59334 .50214 .6048 .49872 .59897 .49319 Mtetra
.653 .772 .936 r
.59897 .49319 .6048 .49872 .6163 .49528 .61051 .48986 Mtetra
.655 .777 .939 r
.61051 .48986 .6163 .49528 .62785 .49181 .62211 .48644 Mtetra
.657 .781 .94 r
.62211 .48644 .62785 .49181 .63945 .48828 .63374 .48292 Mtetra
.66 .783 .94 r
.63374 .48292 .63945 .48828 .6511 .48469 .64543 .47931 Mtetra
.663 .784 .938 r
.64543 .47931 .6511 .48469 .66279 .48104 .65716 .47559 Mtetra
.667 .784 .936 r
.65716 .47559 .66279 .48104 .67453 .47734 .66893 .47178 Mtetra
.669 .782 .933 r
.66893 .47178 .67453 .47734 .68632 .47361 .68075 .46789 Mtetra
.672 .778 .929 r
.68075 .46789 .68632 .47361 .69816 .46984 .69262 .46392 Mtetra
.673 .772 .925 r
.69262 .46392 .69816 .46984 .71004 .46608 .70453 .45992 Mtetra
.672 .765 .92 r
.70453 .45992 .71004 .46608 .72198 .46231 .71649 .45593 Mtetra
.671 .758 .916 r
.71649 .45593 .72198 .46231 .73396 .45856 .7285 .45198 Mtetra
.669 .752 .912 r
.7285 .45198 .73396 .45856 .746 .45481 .74057 .44807 Mtetra
.667 .747 .91 r
.74057 .44807 .746 .45481 .75809 .45106 .75269 .44422 Mtetra
.666 .744 .909 r
.75269 .44422 .75809 .45106 .77023 .44731 .76486 .44039 Mtetra
.665 .742 .908 r
.76486 .44039 .77023 .44731 .78243 .44355 .77709 .43658 Mtetra
.664 .741 .907 r
.77709 .43658 .78243 .44355 .79467 .43977 .78937 .43277 Mtetra
.78937 .43277 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53007 .46893 .52375 Mtetra
.46893 .52375 .47515 .53007 .48618 .52665 .47998 .52032 Mtetra
.663 .741 .908 r
.47998 .52032 .48618 .52665 .49725 .52323 .49108 .51688 Mtetra
.662 .741 .908 r
.49108 .51688 .49725 .52323 .50836 .51979 .50223 .51346 Mtetra
.66 .741 .91 r
.50223 .51346 .50836 .51979 .51952 .51636 .51342 .51008 Mtetra
.657 .743 .914 r
.51342 .51008 .51952 .51636 .53073 .51294 .52465 .50679 Mtetra
.652 .747 .919 r
.52465 .50679 .53073 .51294 .54198 .50956 .53594 .50361 Mtetra
.647 .753 .927 r
.53594 .50361 .54198 .50956 .55328 .50622 .54727 .50054 Mtetra
.643 .762 .935 r
.54727 .50054 .55328 .50622 .56463 .50294 .55866 .49751 Mtetra
.642 .771 .942 r
.55866 .49751 .56463 .50294 .57603 .4997 .57009 .49446 Mtetra
.644 .78 .946 r
.57009 .49446 .57603 .4997 .58747 .49646 .58157 .49128 Mtetra
.649 .785 .946 r
.58157 .49128 .58747 .49646 .59897 .49319 .59311 .48796 Mtetra
.655 .785 .944 r
.59311 .48796 .59897 .49319 .61051 .48986 .60468 .48449 Mtetra
.659 .782 .94 r
.60468 .48449 .61051 .48986 .62211 .48644 .61631 .48093 Mtetra
.661 .779 .936 r
.61631 .48093 .62211 .48644 .63374 .48292 .62798 .47731 Mtetra
.661 .776 .934 r
.62798 .47731 .63374 .48292 .64543 .47931 .6397 .47367 Mtetra
.6397 .47367 .64543 .47931 .65716 .47559 .65147 .47 Mtetra
.662 .779 .936 r
.65147 .47 .65716 .47559 .66893 .47178 .66329 .46629 Mtetra
.665 .784 .938 r
.66329 .46629 .66893 .47178 .68075 .46789 .67515 .46247 Mtetra
.669 .79 .938 r
.67515 .46247 .68075 .46789 .69262 .46392 .68706 .45851 Mtetra
.674 .792 .937 r
.68706 .45851 .69262 .46392 .70453 .45992 .69901 .45439 Mtetra
.678 .79 .934 r
.69901 .45439 .70453 .45992 .71649 .45593 .71099 .45016 Mtetra
.679 .783 .928 r
.71099 .45016 .71649 .45593 .7285 .45198 .72303 .44589 Mtetra
.678 .772 .922 r
.72303 .44589 .7285 .45198 .74057 .44807 .73512 .44166 Mtetra
.674 .762 .916 r
.73512 .44166 .74057 .44807 .75269 .44422 .74726 .43754 Mtetra
.67 .752 .912 r
.74726 .43754 .75269 .44422 .76486 .44039 .75946 .43353 Mtetra
.667 .746 .91 r
.75946 .43353 .76486 .44039 .77709 .43658 .77172 .4296 Mtetra
.665 .743 .908 r
.77172 .4296 .77709 .43658 .78937 .43277 .78404 .42572 Mtetra
.664 .742 .908 r
.78404 .42572 .78937 .43277 .80171 .42894 .79641 .42186 Mtetra
.664 .741 .907 r
.79641 .42186 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .5174 Mtetra
.663 .741 .908 r
.46266 .5174 .46893 .52375 .47998 .52032 .47374 .51396 Mtetra
.661 .741 .909 r
.47374 .51396 .47998 .52032 .49108 .51688 .48487 .51055 Mtetra
.658 .742 .912 r
.48487 .51055 .49108 .51688 .50223 .51346 .49604 .50724 Mtetra
.652 .744 .917 r
.49604 .50724 .50223 .51346 .51342 .51008 .50726 .50407 Mtetra
.644 .75 .926 r
.50726 .50407 .51342 .51008 .52465 .50679 .51853 .50108 Mtetra
.637 .759 .936 r
.51853 .50108 .52465 .50679 .53594 .50361 .52984 .49821 Mtetra
.635 .77 .944 r
.52984 .49821 .53594 .50361 .54727 .50054 .54121 .4953 Mtetra
.643 .779 .946 r
.54121 .4953 .54727 .50054 .55866 .49751 .55263 .49216 Mtetra
.658 .781 .939 r
.55263 .49216 .55866 .49751 .57009 .49446 .5641 .48865 Mtetra
.673 .77 .923 r
.5641 .48865 .57009 .49446 .58157 .49128 .5756 .48475 Mtetra
.682 .749 .902 r
.5756 .48475 .58157 .49128 .59311 .48796 .58715 .48055 Mtetra
.683 .725 .882 r
.58715 .48055 .59311 .48796 .60468 .48449 .59874 .47626 Mtetra
.677 .702 .866 r
.59874 .47626 .60468 .48449 .61631 .48093 .61037 .47205 Mtetra
.669 .684 .856 r
.61037 .47205 .61631 .48093 .62798 .47731 .62206 .46806 Mtetra
.66 .674 .852 r
.62206 .46806 .62798 .47731 .6397 .47367 .63381 .46439 Mtetra
.652 .67 .855 r
.63381 .46439 .6397 .47367 .65147 .47 .64561 .46103 Mtetra
.646 .675 .864 r
.64561 .46103 .65147 .47 .66329 .46629 .65748 .45791 Mtetra
.643 .689 .878 r
.65748 .45791 .66329 .46629 .67515 .46247 .66941 .45486 Mtetra
.646 .712 .896 r
.66941 .45486 .67515 .46247 .68706 .45851 .68139 .45172 Mtetra
.654 .74 .913 r
.68139 .45172 .68706 .45851 .69901 .45439 .69341 .44828 Mtetra
.665 .767 .926 r
.69341 .44828 .69901 .45439 .71099 .45016 .70546 .44446 Mtetra
.676 .786 .932 r
.70546 .44446 .71099 .45016 .72303 .44589 .71754 .44024 Mtetra
.683 .792 .932 r
.71754 .44024 .72303 .44589 .73512 .44166 .72966 .43579 Mtetra
.684 .785 .927 r
.72966 .43579 .73512 .44166 .74726 .43754 .74182 .4313 Mtetra
.68 .772 .92 r
.74182 .4313 .74726 .43754 .75946 .43353 .75404 .42693 Mtetra
.674 .759 .915 r
.75404 .42693 .75946 .43353 .77172 .4296 .76632 .42274 Mtetra
.669 .75 .911 r
.76632 .42274 .77172 .4296 .78404 .42572 .77866 .41869 Mtetra
.666 .744 .909 r
.77866 .41869 .78404 .42572 .79641 .42186 .79107 .41473 Mtetra
.665 .742 .908 r
.79107 .41473 .79641 .42186 .80883 .41798 .80353 .41081 Mtetra
.664 .741 .907 r
.80353 .41081 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40296 Mtetra
.82862 .40296 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51447 Mtetra
.663 .741 .908 r
.44527 .51447 .45162 .52084 .46266 .5174 .45634 .51102 Mtetra
.66 .741 .909 r
.45634 .51102 .46266 .5174 .47374 .51396 .46745 .50763 Mtetra
.656 .742 .913 r
.46745 .50763 .47374 .51396 .48487 .51055 .4786 .50436 Mtetra
.647 .745 .921 r
.4786 .50436 .48487 .51055 .49604 .50724 .4898 .50132 Mtetra
.636 .751 .932 r
.4898 .50132 .49604 .50724 .50726 .50407 .50105 .49851 Mtetra
.63 .763 .942 r
.50105 .49851 .50726 .50407 .51853 .50108 .51235 .49576 Mtetra
.639 .775 .946 r
.51235 .49576 .51853 .50108 .52984 .49821 .5237 .49274 Mtetra
.665 .778 .933 r
.5237 .49274 .52984 .49821 .54121 .4953 .5351 .48907 Mtetra
.693 .761 .904 r
.5351 .48907 .54121 .4953 .55263 .49216 .54654 .48455 Mtetra
.707 .726 .864 r
.54654 .48455 .55263 .49216 .5641 .48865 .55802 .47924 Mtetra
.664 .67 .845 r
.55802 .47924 .5641 .48865 .5756 .48475 .56955 .47541 Mtetra
.659 .67 .849 r
.56955 .47541 .5756 .48475 .58715 .48055 .58113 .47177 Mtetra
.661 .684 .861 r
.58113 .47177 .58715 .48055 .59874 .47626 .59276 .46811 Mtetra
.662 .701 .875 r
.59276 .46811 .59874 .47626 .61037 .47205 .60443 .46444 Mtetra
.663 .716 .888 r
.60443 .46444 .61037 .47205 .62206 .46806 .61616 .46076 Mtetra
.664 .725 .895 r
.61616 .46076 .62206 .46806 .63381 .46439 .62794 .45706 Mtetra
.62794 .45706 .63381 .46439 .64561 .46103 .63976 .45334 Mtetra
.663 .716 .888 r
.63976 .45334 .64561 .46103 .65748 .45791 .65164 .44961 Mtetra
.662 .701 .875 r
.65164 .44961 .65748 .45791 .66941 .45486 .66357 .44586 Mtetra
.661 .684 .861 r
.66357 .44586 .66941 .45486 .68139 .45172 .67554 .4421 Mtetra
.654 .668 .851 r
.67554 .4421 .68139 .45172 .69341 .44828 .68758 .43853 Mtetra
.614 .648 .86 r
.68758 .43853 .69341 .44828 .70546 .44446 .69976 .43645 Mtetra
.635 .701 .893 r
.69976 .43645 .70546 .44446 .71754 .44024 .71195 .43359 Mtetra
.66 .751 .918 r
.71195 .43359 .71754 .44024 .72966 .43579 .72415 .42985 Mtetra
.68 .783 .928 r
.72415 .42985 .72966 .43579 .74182 .4313 .73636 .42546 Mtetra
.689 .79 .927 r
.73636 .42546 .74182 .4313 .75404 .42693 .7486 .42079 Mtetra
.686 .78 .922 r
.7486 .42079 .75404 .42693 .76632 .42274 .7609 .41618 Mtetra
.679 .765 .916 r
.7609 .41618 .76632 .42274 .77866 .41869 .77326 .41179 Mtetra
.671 .752 .911 r
.77326 .41179 .77866 .41869 .79107 .41473 .78569 .40763 Mtetra
.667 .745 .909 r
.78569 .40763 .79107 .41473 .80353 .41081 .79818 .4036 Mtetra
.665 .742 .908 r
.79818 .4036 .80353 .41081 .81604 .40689 .81073 .39963 Mtetra
.664 .741 .907 r
.81073 .39963 .81604 .40689 .82862 .40296 .82335 .39565 Mtetra
.82335 .39565 .82862 .40296 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37963 Mtetra
.87435 .37963 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91818 .37495 .91319 .36742 Mtetra
.91319 .36742 .91818 .37495 .9312 .37088 .92625 .36332 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.663 .741 .908 r
.42783 .51152 .43425 .51792 .44527 .51447 .43888 .50807 Mtetra
.66 .741 .91 r
.43888 .50807 .44527 .51447 .45634 .51102 .44997 .50467 Mtetra
.654 .741 .914 r
.44997 .50467 .45634 .51102 .46745 .50763 .46111 .50145 Mtetra
.642 .744 .923 r
.46111 .50145 .46745 .50763 .4786 .50436 .47229 .4985 Mtetra
.629 .752 .936 r
.47229 .4985 .4786 .50436 .4898 .50132 .48351 .49582 Mtetra
.628 .765 .945 r
.48351 .49582 .4898 .50132 .50105 .49851 .49479 .4931 Mtetra
.653 .776 .939 r
.49479 .4931 .50105 .49851 .51235 .49576 .50613 .48973 Mtetra
.696 .767 .907 r
.50613 .48973 .51235 .49576 .5237 .49274 .51751 .48512 Mtetra
.713 .727 .861 r
.51751 .48512 .5237 .49274 .5351 .48907 .52894 .47959 Mtetra
.659 .666 .846 r
.52894 .47959 .5351 .48907 .54654 .48455 .54041 .47596 Mtetra
.661 .688 .864 r
.54041 .47596 .54654 .48455 .55802 .47924 .55192 .47233 Mtetra
.664 .734 .902 r
.55192 .47233 .55802 .47924 .56955 .47541 .56349 .46868 Mtetra
.664 .741 .907 r
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68758 .43853 .68185 .4313 Mtetra
.664 .734 .902 r
.68185 .4313 .68758 .43853 .69976 .43645 .69396 .42747 Mtetra
.661 .688 .864 r
.69396 .42747 .69976 .43645 .71195 .43359 .70613 .42363 Mtetra
.608 .643 .86 r
.70613 .42363 .71195 .43359 .72415 .42985 .71847 .42173 Mtetra
.632 .699 .894 r
.71847 .42173 .72415 .42985 .73636 .42546 .73081 .41889 Mtetra
.67 .761 .919 r
.73081 .41889 .73636 .42546 .7486 .42079 .74314 .41479 Mtetra
.69 .788 .925 r
.74314 .41479 .7486 .42079 .7609 .41618 .75546 .41003 Mtetra
.691 .785 .922 r
.75546 .41003 .7609 .41618 .77326 .41179 .76784 .40522 Mtetra
.682 .768 .916 r
.76784 .40522 .77326 .41179 .78569 .40763 .78028 .40068 Mtetra
.673 .754 .912 r
.78028 .40068 .78569 .40763 .79818 .4036 .7928 .39642 Mtetra
.667 .746 .909 r
.7928 .39642 .79818 .4036 .81073 .39963 .80538 .39233 Mtetra
.665 .742 .908 r
.80538 .39233 .81073 .39963 .82335 .39565 .81803 .3883 Mtetra
.664 .741 .907 r
.81803 .3883 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37963 .86919 .37213 Mtetra
.86919 .37213 .87435 .37963 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36332 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50857 Mtetra
.663 .741 .908 r
.41032 .50857 .41682 .51499 .42783 .51152 .42136 .5051 Mtetra
.66 .741 .909 r
.42136 .5051 .42783 .51152 .43888 .50807 .43243 .50169 Mtetra
.653 .741 .914 r
.43243 .50169 .43888 .50807 .44997 .50467 .44355 .49846 Mtetra
.64 .743 .924 r
.44355 .49846 .44997 .50467 .46111 .50145 .45471 .49556 Mtetra
.625 .751 .937 r
.45471 .49556 .46111 .50145 .47229 .4985 .46591 .49297 Mtetra
.628 .765 .945 r
.46591 .49297 .47229 .4985 .48351 .49582 .47717 .49023 Mtetra
.67 .775 .929 r
.47717 .49023 .48351 .49582 .49479 .4931 .48849 .48643 Mtetra
.723 .754 .877 r
.48849 .48643 .49479 .4931 .50613 .48973 .49987 .48071 Mtetra
.674 .682 .849 r
.49987 .48071 .50613 .48973 .51751 .48512 .51128 .47652 Mtetra
.661 .688 .864 r
.51128 .47652 .51751 .48512 .52894 .47959 .52273 .47289 Mtetra
.664 .741 .907 r
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71847 .42173 .71269 .4126 Mtetra
.646 .681 .869 r
.71269 .4126 .71847 .42173 .73081 .41889 .72503 .40927 Mtetra
.601 .651 .871 r
.72503 .40927 .73081 .41889 .74314 .41479 .73754 .40751 Mtetra
.657 .737 .909 r
.73754 .40751 .74314 .41479 .75546 .41003 .74998 .40379 Mtetra
.69 .782 .922 r
.74998 .40379 .75546 .41003 .76784 .40522 .7624 .39898 Mtetra
.694 .785 .921 r
.7624 .39898 .76784 .40522 .78028 .40068 .77486 .39402 Mtetra
.684 .769 .916 r
.77486 .39402 .78028 .40068 .7928 .39642 .78739 .38936 Mtetra
.673 .754 .911 r
.78739 .38936 .7928 .39642 .80538 .39233 .8 .38504 Mtetra
.667 .745 .909 r
.8 .38504 .80538 .39233 .81803 .3883 .81268 .3809 Mtetra
.665 .742 .908 r
.81268 .3809 .81803 .3883 .83074 .38428 .82542 .37683 Mtetra
.664 .741 .907 r
.82542 .37683 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .50561 Mtetra
.663 .741 .908 r
.39276 .50561 .39934 .51205 .41032 .50857 .40378 .50211 Mtetra
.661 .74 .909 r
.40378 .50211 .41032 .50857 .42136 .5051 .41483 .49867 Mtetra
.654 .741 .913 r
.41483 .49867 .42136 .5051 .43243 .50169 .42593 .4954 Mtetra
.64 .742 .922 r
.42593 .4954 .43243 .50169 .44355 .49846 .43707 .49249 Mtetra
.623 .748 .936 r
.43707 .49249 .44355 .49846 .45471 .49556 .44825 .48995 Mtetra
.627 .762 .944 r
.44825 .48995 .45471 .49556 .46591 .49297 .45949 .48724 Mtetra
.68 .773 .921 r
.45949 .48724 .46591 .49297 .47717 .49023 .4708 .48314 Mtetra
.728 .744 .865 r
.4708 .48314 .47717 .49023 .48849 .48643 .48218 .47708 Mtetra
.659 .67 .849 r
.48218 .47708 .48849 .48643 .49987 .48071 .49357 .47345 Mtetra
.664 .724 .894 r
.49357 .47345 .49987 .48071 .51128 .47652 .505 .4698 Mtetra
.664 .741 .907 r
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .72503 .40927 .71933 .40144 Mtetra
.664 .724 .894 r
.71933 .40144 .72503 .40927 .73754 .40751 .73173 .39748 Mtetra
.592 .639 .866 r
.73173 .39748 .73754 .40751 .74998 .40379 .74435 .396 Mtetra
.648 .721 .902 r
.74435 .396 .74998 .40379 .7624 .39898 .75691 .39253 Mtetra
.691 .779 .918 r
.75691 .39253 .7624 .39898 .77486 .39402 .76941 .38763 Mtetra
.696 .784 .919 r
.76941 .38763 .77486 .39402 .78739 .38936 .78195 .38255 Mtetra
.684 .767 .914 r
.78195 .38255 .78739 .38936 .8 .38504 .79458 .37784 Mtetra
.672 .752 .91 r
.79458 .37784 .8 .38504 .81268 .3809 .80728 .3735 Mtetra
.667 .744 .908 r
.80728 .3735 .81268 .3809 .82542 .37683 .82006 .36933 Mtetra
.664 .742 .907 r
.82006 .36933 .82542 .37683 .83822 .37276 .8329 .36522 Mtetra
.664 .741 .907 r
.8329 .36522 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34446 Mtetra
.89798 .34446 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.663 .741 .908 r
.37513 .50263 .38179 .5091 .39276 .50561 .38613 .49912 Mtetra
.662 .741 .908 r
.38613 .49912 .39276 .50561 .40378 .50211 .39718 .49563 Mtetra
.656 .74 .912 r
.39718 .49563 .40378 .50211 .41483 .49867 .40826 .49229 Mtetra
.643 .741 .92 r
.40826 .49229 .41483 .49867 .42593 .4954 .41938 .4893 Mtetra
.623 .744 .934 r
.41938 .4893 .42593 .4954 .43707 .49249 .43053 .48676 Mtetra
.623 .758 .943 r
.43053 .48676 .43707 .49249 .44825 .48995 .44174 .48415 Mtetra
.679 .771 .921 r
.44174 .48415 .44825 .48995 .45949 .48724 .45304 .48008 Mtetra
.727 .743 .864 r
.45304 .48008 .45949 .48724 .4708 .48314 .46442 .47401 Mtetra
.66 .676 .854 r
.46442 .47401 .4708 .48314 .48218 .47708 .47579 .47036 Mtetra
.664 .741 .907 r
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.545 .697 .939 r
.54502 .44817 .55122 .45506 .5629 .45133 .55676 .44741 Mtetra
.348 .717 .986 r
.55676 .44741 .5629 .45133 .57463 .44759 .56859 .44787 Mtetra
.091 .649 .739 r
.56859 .44787 .57463 .44759 .5864 .44384 .58047 .44683 Mtetra
.049 0 0 r
.58047 .44683 .5864 .44384 .59823 .44006 .59239 .44436 Mtetra
.043 0 0 r
.59239 .44436 .59823 .44006 .61011 .43627 .60435 .44056 Mtetra
0 0 0 r
.60435 .44056 .61011 .43627 .62204 .43247 .61631 .43541 Mtetra
.366 .805 .646 r
.61631 .43541 .62204 .43247 .63402 .42865 .62828 .42882 Mtetra
.723 .985 .897 r
.62828 .42882 .63402 .42865 .64605 .42481 .64022 .4207 Mtetra
.757 .866 .928 r
.64022 .4207 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.664 .741 .907 r
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74435 .396 .73854 .38613 Mtetra
.592 .644 .872 r
.73854 .38613 .74435 .396 .75691 .39253 .75126 .38461 Mtetra
.65 .721 .9 r
.75126 .38461 .75691 .39253 .76941 .38763 .76391 .38104 Mtetra
.695 .779 .916 r
.76391 .38104 .76941 .38763 .78195 .38255 .7765 .37597 Mtetra
.696 .78 .916 r
.7765 .37597 .78195 .38255 .79458 .37784 .78913 .37082 Mtetra
.682 .763 .913 r
.78913 .37082 .79458 .37784 .80728 .3735 .80185 .36614 Mtetra
.671 .749 .909 r
.80185 .36614 .80728 .3735 .82006 .36933 .81466 .3618 Mtetra
.666 .743 .908 r
.81466 .3618 .82006 .36933 .8329 .36522 .82754 .35761 Mtetra
.664 .741 .907 r
.82754 .35761 .8329 .36522 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34446 .89283 .33667 Mtetra
.89283 .33667 .89798 .34446 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.663 .741 .908 r
.36843 .49611 .37513 .50263 .38613 .49912 .37945 .49259 Mtetra
.659 .74 .91 r
.37945 .49259 .38613 .49912 .39718 .49563 .39052 .48916 Mtetra
.648 .74 .916 r
.39052 .48916 .39718 .49563 .40826 .49229 .40163 .48604 Mtetra
.628 .741 .929 r
.40163 .48604 .40826 .49229 .41938 .4893 .41276 .48339 Mtetra
.617 .751 .941 r
.41276 .48339 .41938 .4893 .43053 .48676 .42394 .48094 Mtetra
.665 .768 .927 r
.42394 .48094 .43053 .48676 .44174 .48415 .43521 .47725 Mtetra
.735 .752 .866 r
.43521 .47725 .44174 .48415 .45304 .48008 .44659 .47092 Mtetra
.659 .676 .854 r
.44659 .47092 .45304 .48008 .46442 .47401 .45794 .46727 Mtetra
.664 .741 .907 r
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.372 .616 .946 r
.51543 .44874 .52175 .45563 .53336 .45191 .52708 .45083 Mtetra
.228 0 0 r
.52708 .45083 .53336 .45191 .54502 .44817 .53882 .45382 Mtetra
.434 0 0 r
.53882 .45382 .54502 .44817 .55676 .44741 .55065 .45474 Mtetra
.388 0 .032 r
.55065 .45474 .55676 .44741 .56859 .44787 .56254 .45387 Mtetra
.271 0 0 r
.56254 .45387 .56859 .44787 .58047 .44683 .57448 .45169 Mtetra
.14 0 0 r
.57448 .45169 .58047 .44683 .59239 .44436 .58647 .44858 Mtetra
.03 0 0 r
.58647 .44858 .59239 .44436 .60435 .44056 .5985 .44475 Mtetra
0 0 0 r
.5985 .44475 .60435 .44056 .61631 .43541 .61056 .44021 Mtetra
.61056 .44021 .61631 .43541 .62828 .42882 .62264 .43472 Mtetra
.62264 .43472 .62828 .42882 .64022 .4207 .63472 .42791 Mtetra
.63472 .42791 .64022 .4207 .65223 .4138 .64676 .41929 Mtetra
.64676 .41929 .65223 .4138 .6644 .4099 .65873 .40855 Mtetra
.823 .965 .898 r
.65873 .40855 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.664 .741 .907 r
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75126 .38461 .74544 .37464 Mtetra
.584 .641 .873 r
.74544 .37464 .75126 .38461 .76391 .38104 .75828 .37332 Mtetra
.662 .734 .903 r
.75828 .37332 .76391 .38104 .7765 .37597 .77099 .36929 Mtetra
.7 .78 .914 r
.77099 .36929 .7765 .37597 .78913 .37082 .78366 .364 Mtetra
.694 .775 .914 r
.78366 .364 .78913 .37082 .80185 .36614 .79639 .35889 Mtetra
.678 .757 .911 r
.79639 .35889 .80185 .36614 .81466 .3618 .80922 .35427 Mtetra
.668 .746 .908 r
.80922 .35427 .81466 .3618 .82754 .35761 .82213 .34997 Mtetra
.665 .742 .908 r
.82213 .34997 .82754 .35761 .84048 .35345 .83511 .34575 Mtetra
.664 .741 .907 r
.83511 .34575 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32883 Mtetra
.88763 .32883 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.663 .741 .908 r
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48955 Mtetra
.661 .74 .909 r
.36167 .48955 .36843 .49611 .37945 .49259 .37272 .48605 Mtetra
.654 .74 .913 r
.37272 .48605 .37945 .49259 .39052 .48916 .38381 .48275 Mtetra
.635 .739 .923 r
.38381 .48275 .39052 .48916 .40163 .48604 .39493 .47992 Mtetra
.615 .744 .938 r
.39493 .47992 .40163 .48604 .41276 .48339 .40609 .47752 Mtetra
.641 .761 .935 r
.40609 .47752 .41276 .48339 .42394 .48094 .41732 .47444 Mtetra
.731 .763 .878 r
.41732 .47444 .42394 .48094 .43521 .47725 .42869 .4684 Mtetra
.675 .689 .855 r
.42869 .4684 .43521 .47725 .44659 .47092 .44004 .46416 Mtetra
.664 .741 .907 r
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.607 .722 .927 r
.48586 .44932 .49229 .4562 .50384 .45248 .49742 .44714 Mtetra
0 .36 .8 r
.49742 .44714 .50384 .45248 .51543 .44874 .50901 .45314 Mtetra
.515 .007 0 r
.50901 .45314 .51543 .44874 .52708 .45083 .52072 .45638 Mtetra
.403 0 0 r
.52072 .45638 .52708 .45083 .53882 .45382 .53252 .45679 Mtetra
.112 0 0 r
.53252 .45679 .53882 .45382 .55065 .45474 .54439 .4551 Mtetra
.308 .801 .836 r
.54439 .4551 .55065 .45474 .56254 .45387 .55631 .45214 Mtetra
.547 .891 .982 r
.55631 .45214 .56254 .45387 .57448 .45169 .56829 .44855 Mtetra
.62 .87 .989 r
.56829 .44855 .57448 .45169 .58647 .44858 .58031 .44474 Mtetra
.637 .849 .981 r
.58031 .44474 .58647 .44858 .5985 .44475 .59239 .44089 Mtetra
.639 .85 .981 r
.59239 .44089 .5985 .44475 .61056 .44021 .60452 .43699 Mtetra
.634 .874 .986 r
.60452 .43699 .61056 .44021 .62264 .43472 .61669 .43286 Mtetra
.622 .917 .978 r
.61669 .43286 .62264 .43472 .63472 .42791 .6289 .42811 Mtetra
.583 .943 .899 r
.6289 .42811 .63472 .42791 .64676 .41929 .64111 .42207 Mtetra
.502 .885 .699 r
.64111 .42207 .64676 .41929 .65873 .40855 .65327 .4139 Mtetra
0 0 0 r
.65327 .4139 .65873 .40855 .67075 .3987 .66533 .40284 Mtetra
.717 .942 .635 r
.66533 .40284 .67075 .3987 .68306 .39473 .67725 .38896 Mtetra
.713 .807 .923 r
.67725 .38896 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.664 .741 .907 r
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.646 .734 .913 r
.73974 .3671 .74544 .37464 .75828 .37332 .75247 .36358 Mtetra
.592 .653 .878 r
.75247 .36358 .75828 .37332 .77099 .36929 .76539 .36191 Mtetra
.681 .754 .906 r
.76539 .36191 .77099 .36929 .78366 .364 .77815 .35719 Mtetra
.702 .78 .912 r
.77815 .35719 .78366 .364 .79639 .35889 .7909 .35177 Mtetra
.688 .767 .911 r
.7909 .35177 .79639 .35889 .80922 .35427 .80375 .34679 Mtetra
.673 .751 .909 r
.80375 .34679 .80922 .35427 .82213 .34997 .81669 .34228 Mtetra
.666 .743 .908 r
.81669 .34228 .82213 .34997 .83511 .34575 .8297 .33799 Mtetra
.664 .741 .907 r
.8297 .33799 .83511 .34575 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32883 .88239 .32091 Mtetra
.88239 .32091 .88763 .32883 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.663 .741 .908 r
.34383 .48651 .35066 .4931 .36167 .48955 .35486 .48295 Mtetra
.659 .74 .91 r
.35486 .48295 .36167 .48955 .37272 .48605 .36594 .4795 Mtetra
.645 .739 .917 r
.36594 .4795 .37272 .48605 .38381 .48275 .37705 .4764 Mtetra
.621 .739 .931 r
.37705 .4764 .38381 .48275 .39493 .47992 .38818 .47389 Mtetra
.62 .75 .939 r
.38818 .47389 .39493 .47992 .40609 .47752 .39937 .47134 Mtetra
.696 .766 .905 r
.39937 .47134 .40609 .47752 .41732 .47444 .41068 .46666 Mtetra
.713 .726 .86 r
.41068 .46666 .41732 .47444 .42869 .4684 .42207 .46104 Mtetra
.664 .724 .894 r
.42207 .46104 .42869 .4684 .44004 .46416 .43343 .45734 Mtetra
.664 .741 .907 r
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.541 .697 .941 r
.46782 .44615 .47433 .45305 .48586 .44932 .47934 .44539 Mtetra
.381 0 0 r
.47934 .44539 .48586 .44932 .49742 .44714 .49084 .45251 Mtetra
.534 .048 .048 r
.49084 .45251 .49742 .44714 .50901 .45314 .5025 .45591 Mtetra
.229 0 0 r
.5025 .45591 .50901 .45314 .52072 .45638 .51428 .45568 Mtetra
.398 .843 .927 r
.51428 .45568 .52072 .45638 .53252 .45679 .52612 .45295 Mtetra
.651 .85 .976 r
.52612 .45295 .53252 .45679 .54439 .4551 .53803 .4489 Mtetra
.685 .776 .92 r
.53803 .4489 .54439 .4551 .55631 .45214 .54997 .44437 Mtetra
.681 .729 .887 r
.54997 .44437 .55631 .45214 .56829 .44855 .56197 .43984 Mtetra
.671 .703 .871 r
.56197 .43984 .56829 .44855 .58031 .44474 .57402 .43558 Mtetra
.659 .689 .866 r
.57402 .43558 .58031 .44474 .59239 .44089 .58612 .43169 Mtetra
.649 .684 .87 r
.58612 .43169 .59239 .44089 .60452 .43699 .59828 .42818 Mtetra
.641 .691 .881 r
.59828 .42818 .60452 .43699 .61669 .43286 .61051 .42493 Mtetra
.64 .715 .902 r
.61051 .42493 .61669 .43286 .6289 .42811 .6228 .4217 Mtetra
.653 .767 .933 r
.6228 .4217 .6289 .42811 .64111 .42207 .63513 .41798 Mtetra
.687 .86 .965 r
.63513 .41798 .64111 .42207 .65327 .4139 .64747 .41292 Mtetra
.729 .97 .933 r
.64747 .41292 .65327 .4139 .66533 .40284 .65975 .40533 Mtetra
.715 .974 .748 r
.65975 .40533 .66533 .40284 .67725 .38896 .67189 .39404 Mtetra
.691 .911 .569 r
.67189 .39404 .67725 .38896 .68958 .38335 .68384 .37894 Mtetra
.757 .867 .929 r
.68384 .37894 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.664 .741 .907 r
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75247 .36358 .74672 .35537 Mtetra
.601 .698 .911 r
.74672 .35537 .75247 .36358 .76539 .36191 .75965 .3532 Mtetra
.633 .699 .893 r
.75965 .3532 .76539 .36191 .77815 .35719 .77257 .35006 Mtetra
.697 .77 .908 r
.77257 .35006 .77815 .35719 .7909 .35177 .78538 .34474 Mtetra
.698 .774 .911 r
.78538 .34474 .7909 .35177 .80375 .34679 .79824 .33937 Mtetra
.68 .757 .91 r
.79824 .33937 .80375 .34679 .81669 .34228 .8112 .33459 Mtetra
.669 .746 .908 r
.8112 .33459 .81669 .34228 .8297 .33799 .82425 .33017 Mtetra
.665 .742 .907 r
.82425 .33017 .8297 .33799 .84278 .33374 .83737 .32587 Mtetra
.664 .741 .907 r
.83737 .32587 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47988 Mtetra
.662 .74 .908 r
.33694 .47988 .34383 .48651 .35486 .48295 .348 .47632 Mtetra
.654 .739 .912 r
.348 .47632 .35486 .48295 .36594 .4795 .3591 .47296 Mtetra
.634 .738 .923 r
.3591 .47296 .36594 .4795 .37705 .4764 .37022 .47013 Mtetra
.612 .74 .937 r
.37022 .47013 .37705 .4764 .38818 .47389 .38137 .46778 Mtetra
.65 .758 .928 r
.38137 .46778 .38818 .47389 .39937 .47134 .39262 .46447 Mtetra
.739 .756 .866 r
.39262 .46447 .39937 .47134 .41068 .46666 .40403 .45791 Mtetra
.661 .688 .865 r
.40403 .45791 .41068 .46666 .42207 .46104 .41538 .4542 Mtetra
.664 .741 .907 r
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.606 .722 .927 r
.44972 .44297 .45631 .4499 .46782 .44615 .46123 .44076 Mtetra
0 .14 .605 r
.46123 .44076 .46782 .44615 .47934 .44539 .47263 .44931 Mtetra
.546 .034 0 r
.47263 .44931 .47934 .44539 .49084 .45251 .48422 .45348 Mtetra
.056 0 0 r
.48422 .45348 .49084 .45251 .5025 .45591 .49596 .45308 Mtetra
.594 .87 .994 r
.49596 .45308 .5025 .45591 .51428 .45568 .50779 .44962 Mtetra
.699 .783 .916 r
.50779 .44962 .51428 .45568 .52612 .45295 .51967 .44463 Mtetra
.703 .722 .865 r
.51967 .44463 .52612 .45295 .53803 .4489 .5316 .43916 Mtetra
.692 .687 .841 r
.5316 .43916 .53803 .4489 .54997 .44437 .54357 .43379 Mtetra
.68 .667 .831 r
.54357 .43379 .54997 .44437 .56197 .43984 .55558 .42881 Mtetra
.667 .654 .828 r
.55558 .42881 .56197 .43984 .57402 .43558 .56765 .42433 Mtetra
.653 .645 .829 r
.56765 .42433 .57402 .43558 .58612 .43169 .57977 .4204 Mtetra
.64 .639 .833 r
.57977 .4204 .58612 .43169 .59828 .42818 .59196 .41704 Mtetra
.628 .637 .84 r
.59196 .41704 .59828 .42818 .61051 .42493 .60422 .41419 Mtetra
.617 .64 .851 r
.60422 .41419 .61051 .42493 .6228 .4217 .61655 .41172 Mtetra
.614 .656 .867 r
.61655 .41172 .6228 .4217 .63513 .41798 .62896 .40936 Mtetra
.626 .694 .893 r
.62896 .40936 .63513 .41798 .64747 .41292 .64141 .40653 Mtetra
.673 .777 .928 r
.64141 .40653 .64747 .41292 .65975 .40533 .65387 .40215 Mtetra
.764 .91 .939 r
.65387 .40215 .65975 .40533 .67189 .39404 .66624 .39466 Mtetra
.836 .998 .829 r
.66624 .39466 .67189 .39404 .68384 .37894 .67842 .3825 Mtetra
.836 .973 .666 r
.67842 .3825 .68384 .37894 .69618 .37182 .69036 .36586 Mtetra
.713 .807 .923 r
.69036 .36586 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.664 .741 .907 r
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .75965 .3532 .75379 .34348 Mtetra
.576 .649 .885 r
.75379 .34348 .75965 .3532 .77257 .35006 .76689 .34222 Mtetra
.675 .743 .902 r
.76689 .34222 .77257 .35006 .78538 .34474 .7798 .33761 Mtetra
.704 .776 .908 r
.7798 .33761 .78538 .34474 .79824 .33937 .79269 .33201 Mtetra
.689 .764 .909 r
.79269 .33201 .79824 .33937 .8112 .33459 .80567 .32689 Mtetra
.673 .749 .908 r
.80567 .32689 .8112 .33459 .82425 .33017 .81875 .32231 Mtetra
.666 .743 .908 r
.81875 .32231 .82425 .33017 .83737 .32587 .83191 .31794 Mtetra
.664 .741 .907 r
.83191 .31794 .83737 .32587 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .47681 Mtetra
.663 .741 .908 r
.31895 .47681 .32592 .48347 .33694 .47988 .32999 .47319 Mtetra
.66 .74 .909 r
.32999 .47319 .33694 .47988 .348 .47632 .34108 .46965 Mtetra
.648 .738 .915 r
.34108 .46965 .348 .47632 .3591 .47296 .3522 .46644 Mtetra
.622 .736 .928 r
.3522 .46644 .3591 .47296 .37022 .47013 .36334 .46387 Mtetra
.615 .743 .937 r
.36334 .46387 .37022 .47013 .38137 .46778 .37452 .46141 Mtetra
.696 .762 .903 r
.37452 .46141 .38137 .46778 .39262 .46447 .38586 .45669 Mtetra
.713 .728 .862 r
.38586 .45669 .39262 .46447 .40403 .45791 .39727 .45105 Mtetra
.664 .741 .907 r
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
0 .285 .77 r
.44307 .43598 .44972 .44297 .46123 .44076 .4544 .44354 Mtetra
.601 .081 0 r
.4544 .44354 .46123 .44076 .47263 .44931 .46589 .44949 Mtetra
.063 0 0 r
.46589 .44949 .47263 .44931 .48422 .45348 .47757 .44986 Mtetra
.625 .851 .985 r
.47757 .44986 .48422 .45348 .49596 .45308 .48938 .44623 Mtetra
.714 .763 .891 r
.48938 .44623 .49596 .45308 .50779 .44962 .50126 .44062 Mtetra
.715 .711 .845 r
.50126 .44062 .50779 .44962 .51967 .44463 .51318 .43439 Mtetra
.705 .683 .826 r
.51318 .43439 .51967 .44463 .5316 .43916 .52514 .42824 Mtetra
.692 .666 .82 r
.52514 .42824 .5316 .43916 .54357 .43379 .53713 .42253 Mtetra
.68 .656 .819 r
.53713 .42253 .54357 .43379 .55558 .42881 .54916 .41735 Mtetra
.666 .647 .822 r
.54916 .41735 .55558 .42881 .56765 .42433 .56125 .41278 Mtetra
.652 .64 .825 r
.56125 .41278 .56765 .42433 .57977 .4204 .57339 .40882 Mtetra
.638 .634 .83 r
.57339 .40882 .57977 .4204 .59196 .41704 .5856 .40548 Mtetra
.623 .628 .835 r
.5856 .40548 .59196 .41704 .60422 .41419 .59788 .40274 Mtetra
.609 .624 .841 r
.59788 .40274 .60422 .41419 .61655 .41172 .61024 .40056 Mtetra
.597 .624 .85 r
.61024 .40056 .61655 .41172 .62896 .40936 .62268 .39881 Mtetra
.593 .636 .863 r
.62268 .39881 .62896 .40936 .64141 .40653 .6352 .39716 Mtetra
.608 .67 .884 r
.6352 .39716 .64141 .40653 .65387 .40215 .64777 .39489 Mtetra
.669 .752 .913 r
.64777 .39489 .65387 .40215 .66624 .39466 .66032 .3906 Mtetra
.788 .885 .916 r
.66032 .3906 .66624 .39466 .67842 .3825 .67275 .38226 Mtetra
.891 .979 .818 r
.67275 .38226 .67842 .3825 .69036 .36586 .68491 .36822 Mtetra
.86 .989 .723 r
.68491 .36822 .69036 .36586 .70287 .36014 .69695 .35249 Mtetra
.664 .741 .907 r
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.598 .713 .925 r
.74803 .33569 .75379 .34348 .76689 .34222 .7611 .33343 Mtetra
.633 .702 .895 r
.7611 .33343 .76689 .34222 .7798 .33761 .77416 .3302 Mtetra
.701 .768 .904 r
.77416 .3302 .7798 .33761 .79269 .33201 .7871 .32464 Mtetra
.697 .769 .907 r
.7871 .32464 .79269 .33201 .80567 .32689 .8001 .3192 Mtetra
.678 .753 .908 r
.8001 .3192 .80567 .32689 .81875 .32231 .81321 .31441 Mtetra
.667 .744 .908 r
.81321 .31441 .81875 .32231 .83191 .31794 .82641 .30995 Mtetra
.664 .741 .907 r
.82641 .30995 .83191 .31794 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48098 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .47681 .31192 .47009 Mtetra
.663 .741 .908 r
.31192 .47009 .31895 .47681 .32999 .47319 .323 .46646 Mtetra
.658 .74 .91 r
.323 .46646 .32999 .47319 .34108 .46965 .33411 .46296 Mtetra
.641 .737 .919 r
.33411 .46296 .34108 .46965 .3522 .46644 .34525 .45992 Mtetra
.613 .735 .933 r
.34525 .45992 .3522 .46644 .36334 .46387 .3564 .45754 Mtetra
.634 .748 .931 r
.3564 .45754 .36334 .46387 .37452 .46141 .36763 .45462 Mtetra
.738 .759 .87 r
.36763 .45462 .37452 .46141 .38586 .45669 .37908 .4481 Mtetra
.667 .696 .868 r
.37908 .4481 .38586 .45669 .39727 .45105 .39045 .44413 Mtetra
.664 .741 .907 r
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.359 .613 .947 r
.42482 .43276 .43155 .43977 .44307 .43598 .43621 .43481 Mtetra
.647 .089 0 r
.43621 .43481 .44307 .43598 .4544 .44354 .44754 .44352 Mtetra
.278 0 0 r
.44754 .44352 .4544 .44354 .46589 .44949 .45913 .44599 Mtetra
.577 .841 .995 r
.45913 .44599 .46589 .44949 .47757 .44986 .47091 .44312 Mtetra
.718 .768 .892 r
.47091 .44312 .47757 .44986 .48938 .44623 .48278 .43735 Mtetra
.726 .717 .841 r
.48278 .43735 .48938 .44623 .50126 .44062 .4947 .43057 Mtetra
.719 .692 .823 r
.4947 .43057 .50126 .44062 .51318 .43439 .50665 .42374 Mtetra
.707 .677 .819 r
.50665 .42374 .51318 .43439 .52514 .42824 .51863 .41733 Mtetra
.695 .668 .82 r
.51863 .41733 .52514 .42824 .53713 .42253 .53065 .41148 Mtetra
.681 .661 .824 r
.53065 .41148 .53713 .42253 .54916 .41735 .54271 .40625 Mtetra
.668 .655 .828 r
.54271 .40625 .54916 .41735 .56125 .41278 .55481 .40164 Mtetra
.654 .649 .833 r
.55481 .40164 .56125 .41278 .57339 .40882 .56698 .39764 Mtetra
.639 .643 .838 r
.56698 .39764 .57339 .40882 .5856 .40548 .5792 .39427 Mtetra
.623 .636 .842 r
.5792 .39427 .5856 .40548 .59788 .40274 .5915 .39151 Mtetra
.606 .628 .847 r
.5915 .39151 .59788 .40274 .61024 .40056 .60388 .38939 Mtetra
.59 .622 .852 r
.60388 .38939 .61024 .40056 .62268 .39881 .61635 .38784 Mtetra
.576 .62 .859 r
.61635 .38784 .62268 .39881 .6352 .39716 .6289 .38672 Mtetra
.575 .632 .87 r
.6289 .38672 .6352 .39716 .64777 .39489 .64154 .38556 Mtetra
.604 .672 .888 r
.64154 .38556 .64777 .39489 .66032 .3906 .65421 .38339 Mtetra
.692 .764 .907 r
.65421 .38339 .66032 .3906 .67275 .38226 .66683 .37828 Mtetra
.835 .891 .881 r
.66683 .37828 .67275 .38226 .68491 .36822 .67923 .36772 Mtetra
.929 .956 .777 r
.67923 .36772 .68491 .36822 .69695 .35249 .6913 .35076 Mtetra
.823 .965 .898 r
.6913 .35076 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.664 .741 .907 r
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.657 .738 .91 r
.74223 .32784 .74803 .33569 .7611 .33343 .7552 .32378 Mtetra
.578 .656 .89 r
.7552 .32378 .7611 .33343 .77416 .3302 .76844 .32235 Mtetra
.687 .752 .901 r
.76844 .32235 .77416 .3302 .7871 .32464 .78146 .3172 Mtetra
.703 .771 .904 r
.78146 .3172 .7871 .32464 .8001 .3192 .79448 .3115 Mtetra
.684 .757 .907 r
.79448 .3115 .8001 .3192 .81321 .31441 .80762 .30646 Mtetra
.669 .746 .908 r
.80762 .30646 .81321 .31441 .82641 .30995 .82086 .30189 Mtetra
.665 .742 .907 r
.82086 .30189 .82641 .30995 .83968 .30556 .83417 .29745 Mtetra
.664 .741 .907 r
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28413 Mtetra
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47065 Mtetra
.28278 .47065 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47009 .30485 .46332 Mtetra
.662 .741 .908 r
.30485 .46332 .31192 .47009 .323 .46646 .31595 .45968 Mtetra
.655 .739 .912 r
.31595 .45968 .323 .46646 .33411 .46296 .32708 .45624 Mtetra
.633 .735 .922 r
.32708 .45624 .33411 .46296 .34525 .45992 .33823 .45338 Mtetra
.609 .734 .934 r
.33823 .45338 .34525 .45992 .3564 .45754 .34941 .45105 Mtetra
.66 .752 .918 r
.34941 .45105 .3564 .45754 .36763 .45462 .36071 .4474 Mtetra
.734 .749 .864 r
.36071 .4474 .36763 .45462 .37908 .4481 .37218 .44094 Mtetra
.664 .734 .902 r
.37218 .44094 .37908 .4481 .39045 .44413 .38357 .43715 Mtetra
.664 .741 .907 r
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
0 .182 .683 r
.41803 .4257 .42482 .43276 .43621 .43481 .42925 .4345 Mtetra
.545 0 0 r
.42925 .4345 .43621 .43481 .44754 .44352 .44067 .44063 Mtetra
.364 .771 .983 r
.44067 .44063 .44754 .44352 .45913 .44599 .45237 .43996 Mtetra
.703 .786 .916 r
.45237 .43996 .45913 .44599 .47091 .44312 .46422 .43482 Mtetra
.735 .733 .849 r
.46422 .43482 .47091 .44312 .48278 .43735 .47615 .42781 Mtetra
.732 .706 .826 r
.47615 .42781 .48278 .43735 .4947 .43057 .4881 .42042 Mtetra
.722 .692 .821 r
.4881 .42042 .4947 .43057 .50665 .42374 .50008 .41337 Mtetra
.71 .685 .823 r
.50008 .41337 .50665 .42374 .51863 .41733 .51209 .40686 Mtetra
.697 .679 .828 r
.51209 .40686 .51863 .41733 .53065 .41148 .52413 .40099 Mtetra
.684 .674 .834 r
.52413 .40099 .53065 .41148 .54271 .40625 .53622 .39575 Mtetra
.671 .669 .84 r
.53622 .39575 .54271 .40625 .55481 .40164 .54835 .39113 Mtetra
.656 .664 .845 r
.54835 .39113 .55481 .40164 .56698 .39764 .56053 .3871 Mtetra
.641 .657 .85 r
.56053 .3871 .56698 .39764 .5792 .39427 .57278 .38366 Mtetra
.625 .649 .855 r
.57278 .38366 .5792 .39427 .5915 .39151 .5851 .38085 Mtetra
.607 .641 .859 r
.5851 .38085 .5915 .39151 .60388 .38939 .5975 .37867 Mtetra
.587 .631 .863 r
.5975 .37867 .60388 .38939 .61635 .38784 .60999 .37714 Mtetra
.569 .624 .867 r
.60999 .37714 .61635 .38784 .6289 .38672 .62257 .37618 Mtetra
.557 .622 .873 r
.62257 .37618 .6289 .38672 .64154 .38556 .63525 .37557 Mtetra
.566 .64 .883 r
.63525 .37557 .64154 .38556 .65421 .38339 .64799 .37458 Mtetra
.623 .696 .896 r
.64799 .37458 .65421 .38339 .66683 .37828 .66074 .3717 Mtetra
.753 .802 .893 r
.66074 .3717 .66683 .37828 .67923 .36772 .67335 .36428 Mtetra
.893 .9 .825 r
.67335 .36428 .67923 .36772 .6913 .35076 .68563 .34991 Mtetra
.931 .95 .777 r
.68563 .34991 .6913 .35076 .70371 .34057 .69774 .33276 Mtetra
.664 .741 .907 r
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .7552 .32378 .74937 .3156 Mtetra
.571 .694 .925 r
.74937 .3156 .7552 .32378 .76844 .32235 .76264 .31404 Mtetra
.666 .733 .9 r
.76264 .31404 .76844 .32235 .78146 .3172 .77576 .30959 Mtetra
.706 .769 .901 r
.77576 .30959 .78146 .3172 .79448 .3115 .78882 .30375 Mtetra
.69 .76 .905 r
.78882 .30375 .79448 .3115 .80762 .30646 .80199 .29847 Mtetra
.672 .747 .907 r
.80199 .29847 .80762 .30646 .82086 .30189 .81526 .29377 Mtetra
.665 .742 .907 r
.81526 .29377 .82086 .30189 .83417 .29745 .82861 .28928 Mtetra
.664 .741 .907 r
.82861 .28928 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28413 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47065 .27559 .46388 Mtetra
.27559 .46388 .28278 .47065 .29379 .46698 .28663 .46019 Mtetra
.664 .741 .908 r
.28663 .46019 .29379 .46698 .30485 .46332 .29771 .4565 Mtetra
.661 .74 .908 r
.29771 .4565 .30485 .46332 .31595 .45968 .30884 .45286 Mtetra
.652 .738 .913 r
.30884 .45286 .31595 .45968 .32708 .45624 .32 .44947 Mtetra
.626 .734 .924 r
.32 .44947 .32708 .45624 .33823 .45338 .33117 .44676 Mtetra
.61 .734 .933 r
.33117 .44676 .33823 .45338 .34941 .45105 .34237 .44438 Mtetra
.688 .755 .902 r
.34237 .44438 .34941 .45105 .36071 .4474 .35374 .43984 Mtetra
.719 .738 .867 r
.35374 .43984 .36071 .4474 .37218 .44094 .36522 .43394 Mtetra
.664 .741 .907 r
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.54 .698 .942 r
.39963 .42244 .4065 .42953 .41803 .4257 .41109 .42159 Mtetra
.63 .082 0 r
.41109 .42159 .41803 .4257 .42925 .4345 .42227 .43209 Mtetra
0 .403 .708 r
.42227 .43209 .42925 .4345 .44067 .44063 .43379 .4356 Mtetra
.617 .799 .969 r
.43379 .4356 .44067 .44063 .45237 .43996 .44558 .43256 Mtetra
.732 .755 .871 r
.44558 .43256 .45237 .43996 .46422 .43482 .45749 .426 Mtetra
.743 .725 .834 r
.45749 .426 .46422 .43482 .47615 .42781 .46946 .4183 Mtetra
.737 .71 .825 r
.46946 .4183 .47615 .42781 .4881 .42042 .48145 .41065 Mtetra
.726 .702 .827 r
.48145 .41065 .4881 .42042 .50008 .41337 .49347 .4035 Mtetra
.714 .697 .832 r
.49347 .4035 .50008 .41337 .51209 .40686 .50551 .39699 Mtetra
.7 .693 .839 r
.50551 .39699 .51209 .40686 .52413 .40099 .51758 .39113 Mtetra
.687 .689 .846 r
.51758 .39113 .52413 .40099 .53622 .39575 .52969 .3859 Mtetra
.673 .684 .852 r
.52969 .3859 .53622 .39575 .54835 .39113 .54184 .38126 Mtetra
.659 .679 .858 r
.54184 .38126 .54835 .39113 .56053 .3871 .55406 .3772 Mtetra
.643 .673 .863 r
.55406 .3772 .56053 .3871 .57278 .38366 .56633 .3737 Mtetra
.626 .665 .868 r
.56633 .3737 .57278 .38366 .5851 .38085 .57868 .37081 Mtetra
.607 .656 .872 r
.57868 .37081 .5851 .38085 .5975 .37867 .5911 .36855 Mtetra
.586 .645 .876 r
.5911 .36855 .5975 .37867 .60999 .37714 .60361 .36696 Mtetra
.564 .634 .879 r
.60361 .36696 .60999 .37714 .62257 .37618 .61621 .36602 Mtetra
.546 .627 .883 r
.61621 .36602 .62257 .37618 .63525 .37557 .62891 .3656 Mtetra
.542 .63 .889 r
.62891 .3656 .63525 .37557 .64799 .37458 .64171 .36524 Mtetra
.578 .664 .897 r
.64171 .36524 .64799 .37458 .66074 .3717 .65454 .36374 Mtetra
.687 .745 .896 r
.65454 .36374 .66074 .3717 .67335 .36428 .6673 .35867 Mtetra
.84 .844 .848 r
.6673 .35867 .67335 .36428 .68563 .34991 .67978 .3469 Mtetra
.935 .892 .763 r
.67978 .3469 .68563 .34991 .69774 .33276 .69188 .32795 Mtetra
.757 .866 .928 r
.69188 .32795 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.664 .741 .907 r
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.592 .71 .926 r
.74351 .30757 .74937 .3156 .76264 .31404 .75677 .30537 Mtetra
.64 .714 .901 r
.75677 .30537 .76264 .31404 .77576 .30959 .77 .30176 Mtetra
.704 .764 .899 r
.77 .30176 .77576 .30959 .78882 .30375 .78311 .29591 Mtetra
.695 .761 .903 r
.78311 .29591 .78882 .30375 .80199 .29847 .79631 .29041 Mtetra
.675 .749 .906 r
.79631 .29041 .80199 .29847 .81526 .29377 .80961 .28559 Mtetra
.666 .743 .907 r
.80961 .28559 .81526 .29377 .82861 .28928 .82301 .28103 Mtetra
.664 .741 .907 r
.82301 .28103 .82861 .28928 .84203 .28481 .83647 .27653 Mtetra
.83647 .27653 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26747 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.663 .741 .908 r
.27941 .45334 .28663 .46019 .29771 .4565 .29052 .44963 Mtetra
.661 .74 .909 r
.29052 .44963 .29771 .4565 .30884 .45286 .30168 .44597 Mtetra
.649 .738 .914 r
.30168 .44597 .30884 .45286 .32 .44947 .31286 .44264 Mtetra
.621 .732 .926 r
.31286 .44264 .32 .44947 .33117 .44676 .32405 .44003 Mtetra
.615 .734 .931 r
.32405 .44003 .33117 .44676 .34237 .44438 .33528 .43752 Mtetra
.71 .756 .888 r
.33528 .43752 .34237 .44438 .35374 .43984 .34673 .43214 Mtetra
.702 .732 .874 r
.34673 .43214 .35374 .43984 .36522 .43394 .35821 .42688 Mtetra
.664 .741 .907 r
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.24 .548 .929 r
.39271 .4153 .39963 .42244 .41109 .42159 .40404 .41868 Mtetra
.615 .05 0 r
.40404 .41868 .41109 .42159 .42227 .43209 .41527 .42785 Mtetra
.242 .657 .961 r
.41527 .42785 .42227 .43209 .43379 .4356 .42688 .42926 Mtetra
.685 .775 .919 r
.42688 .42926 .43379 .4356 .44558 .43256 .43874 .42463 Mtetra
.745 .746 .853 r
.43874 .42463 .44558 .43256 .45749 .426 .45071 .41723 Mtetra
.75 .729 .833 r
.45071 .41723 .45749 .426 .46946 .4183 .46273 .40918 Mtetra
.742 .72 .831 r
.46273 .40918 .46946 .4183 .48145 .41065 .47475 .4014 Mtetra
.73 .715 .836 r
.47475 .4014 .48145 .41065 .49347 .4035 .4868 .39423 Mtetra
.717 .711 .844 r
.4868 .39423 .49347 .4035 .50551 .39699 .49887 .38773 Mtetra
.703 .708 .851 r
.49887 .38773 .50551 .39699 .51758 .39113 .51097 .38189 Mtetra
.689 .704 .859 r
.51097 .38189 .51758 .39113 .52969 .3859 .52311 .37666 Mtetra
.675 .7 .865 r
.52311 .37666 .52969 .3859 .54184 .38126 .5353 .37201 Mtetra
.661 .695 .871 r
.5353 .37201 .54184 .38126 .55406 .3772 .54754 .36791 Mtetra
.645 .689 .877 r
.54754 .36791 .55406 .3772 .56633 .3737 .55984 .36436 Mtetra
.627 .682 .882 r
.55984 .36436 .56633 .3737 .57868 .37081 .57222 .36139 Mtetra
.608 .672 .886 r
.57222 .36139 .57868 .37081 .5911 .36855 .58466 .35904 Mtetra
.585 .661 .89 r
.58466 .35904 .5911 .36855 .60361 .36696 .5972 .35737 Mtetra
.561 .649 .894 r
.5972 .35737 .60361 .36696 .61621 .36602 .60982 .35638 Mtetra
.538 .637 .897 r
.60982 .35638 .61621 .36602 .62891 .3656 .62255 .35602 Mtetra
.525 .634 .9 r
.62255 .35602 .62891 .3656 .64171 .36524 .63538 .35595 Mtetra
.547 .652 .904 r
.63538 .35595 .64171 .36524 .65454 .36374 .64828 .35523 Mtetra
.64 .715 .902 r
.64828 .35523 .65454 .36374 .6673 .35867 .66114 .3517 Mtetra
.794 .804 .86 r
.66114 .3517 .6673 .35867 .67978 .3469 .67378 .34201 Mtetra
.909 .855 .777 r
.67378 .34201 .67978 .3469 .69188 .32795 .68603 .32437 Mtetra
.857 .911 .869 r
.68603 .32437 .69188 .32795 .70458 .32058 .69855 .3126 Mtetra
.664 .741 .907 r
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.617 .721 .921 r
.7376 .29948 .74351 .30757 .75677 .30537 .75085 .29654 Mtetra
.614 .701 .906 r
.75085 .29654 .75677 .30537 .77 .30176 .76418 .29374 Mtetra
.701 .759 .897 r
.76418 .29374 .77 .30176 .78311 .29591 .77735 .28796 Mtetra
.698 .761 .901 r
.77735 .28796 .78311 .29591 .79631 .29041 .79057 .28228 Mtetra
.677 .749 .905 r
.79057 .28228 .79631 .29041 .80961 .28559 .80392 .27733 Mtetra
.667 .743 .907 r
.80392 .27733 .80961 .28559 .82301 .28103 .81736 .27272 Mtetra
.664 .741 .907 r
.81736 .27272 .82301 .28103 .83647 .27653 .83087 .26817 Mtetra
.83087 .26817 .83647 .27653 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26747 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.663 .741 .908 r
.27214 .44644 .27941 .45334 .29052 .44963 .28328 .4427 Mtetra
.66 .74 .909 r
.28328 .4427 .29052 .44963 .30168 .44597 .29446 .43903 Mtetra
.647 .737 .915 r
.29446 .43903 .30168 .44597 .31286 .44264 .30566 .43574 Mtetra
.617 .73 .927 r
.30566 .43574 .31286 .44264 .32405 .44003 .31687 .43318 Mtetra
.621 .734 .927 r
.31687 .43318 .32405 .44003 .33528 .43752 .32814 .43052 Mtetra
.725 .756 .877 r
.32814 .43052 .33528 .43752 .34673 .43214 .33966 .42448 Mtetra
.688 .731 .884 r
.33966 .42448 .34673 .43214 .35821 .42688 .35114 .41977 Mtetra
.664 .741 .907 r
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
0 .375 .835 r
.38573 .40809 .39271 .4153 .40404 .41868 .39696 .41422 Mtetra
.453 0 0 r
.39696 .41422 .40404 .41868 .41527 .42785 .40825 .42225 Mtetra
.441 .713 .981 r
.40825 .42225 .41527 .42785 .42688 .42926 .41993 .42225 Mtetra
.71 .763 .894 r
.41993 .42225 .42688 .42926 .43874 .42463 .43186 .41667 Mtetra
.753 .748 .848 r
.43186 .41667 .43874 .42463 .45071 .41723 .44388 .4088 Mtetra
.756 .739 .837 r
.44388 .4088 .45071 .41723 .46273 .40918 .45593 .40056 Mtetra
.747 .734 .839 r
.45593 .40056 .46273 .40918 .47475 .4014 .468 .39272 Mtetra
.735 .73 .847 r
.468 .39272 .47475 .4014 .4868 .39423 .48008 .38554 Mtetra
.721 .727 .855 r
.48008 .38554 .4868 .39423 .49887 .38773 .49218 .37904 Mtetra
.706 .723 .863 r
.49218 .37904 .49887 .38773 .51097 .38189 .50432 .37321 Mtetra
.692 .72 .871 r
.50432 .37321 .51097 .38189 .52311 .37666 .51649 .36797 Mtetra
.677 .716 .878 r
.51649 .36797 .52311 .37666 .5353 .37201 .52871 .3633 Mtetra
.662 .711 .884 r
.52871 .3633 .5353 .37201 .54754 .36791 .54098 .35917 Mtetra
.646 .705 .89 r
.54098 .35917 .54754 .36791 .55984 .36436 .55332 .35557 Mtetra
.628 .697 .895 r
.55332 .35557 .55984 .36436 .57222 .36139 .56572 .35254 Mtetra
.608 .688 .9 r
.56572 .35254 .57222 .36139 .58466 .35904 .57819 .35011 Mtetra
.584 .677 .904 r
.57819 .35011 .58466 .35904 .5972 .35737 .59075 .34836 Mtetra
.557 .664 .908 r
.59075 .34836 .5972 .35737 .60982 .35638 .60341 .34732 Mtetra
.53 .65 .911 r
.60341 .34732 .60982 .35638 .62255 .35602 .61616 .34695 Mtetra
.512 .642 .914 r
.61616 .34695 .62255 .35602 .63538 .35595 .62902 .347 Mtetra
.526 .653 .916 r
.62902 .347 .63538 .35595 .64828 .35523 .64196 .34668 Mtetra
.61 .703 .911 r
.64196 .34668 .64828 .35523 .66114 .3517 .6549 .34405 Mtetra
.763 .781 .868 r
.6549 .34405 .66114 .3517 .67378 .34201 .66765 .33573 Mtetra
.885 .826 .784 r
.66765 .33573 .67378 .34201 .68603 .32437 .68003 .31919 Mtetra
.881 .859 .815 r
.68003 .31919 .68603 .32437 .69855 .3126 .69246 .30455 Mtetra
.664 .741 .907 r
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.637 .73 .916 r
.73164 .29132 .7376 .29948 .75085 .29654 .74489 .28775 Mtetra
.592 .693 .913 r
.74489 .28775 .75085 .29654 .76418 .29374 .7583 .28555 Mtetra
.697 .755 .897 r
.7583 .28555 .76418 .29374 .77735 .28796 .77153 .27986 Mtetra
.7 .76 .898 r
.77153 .27986 .77735 .28796 .79057 .28228 .78479 .27405 Mtetra
.679 .749 .904 r
.78479 .27405 .79057 .28228 .80392 .27733 .79818 .269 Mtetra
.667 .743 .907 r
.79818 .269 .80392 .27733 .81736 .27272 .81166 .26433 Mtetra
.664 .741 .907 r
.81166 .26433 .81736 .27272 .83087 .26817 .82521 .25974 Mtetra
.82521 .25974 .83087 .26817 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43949 Mtetra
.663 .741 .908 r
.26481 .43949 .27214 .44644 .28328 .4427 .27598 .43571 Mtetra
.66 .74 .909 r
.27598 .43571 .28328 .4427 .29446 .43903 .28719 .43203 Mtetra
.646 .736 .915 r
.28719 .43203 .29446 .43903 .30566 .43574 .29842 .42874 Mtetra
.616 .728 .926 r
.29842 .42874 .30566 .43574 .31687 .43318 .30965 .4262 Mtetra
.624 .732 .924 r
.30965 .4262 .31687 .43318 .32814 .43052 .32095 .42343 Mtetra
.732 .756 .872 r
.32095 .42343 .32814 .43052 .33966 .42448 .33252 .41701 Mtetra
.679 .736 .893 r
.33252 .41701 .33966 .42448 .35114 .41977 .34401 .4126 Mtetra
.664 .741 .907 r
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
0 .276 .761 r
.3787 .40083 .38573 .40809 .39696 .41422 .38988 .40828 Mtetra
0 .233 .696 r
.38988 .40828 .39696 .41422 .40825 .42225 .4012 .41567 Mtetra
.513 .712 .962 r
.4012 .41567 .40825 .42225 .41993 .42225 .41293 .41496 Mtetra
.72 .759 .884 r
.41293 .41496 .41993 .42225 .43186 .41667 .42491 .40893 Mtetra
.759 .756 .85 r
.42491 .40893 .43186 .41667 .44388 .4088 .43697 .40084 Mtetra
.761 .752 .844 r
.43697 .40084 .44388 .4088 .45593 .40056 .44907 .3925 Mtetra
.752 .749 .849 r
.44907 .3925 .45593 .40056 .468 .39272 .46118 .38462 Mtetra
.739 .746 .857 r
.46118 .38462 .468 .39272 .48008 .38554 .4733 .37741 Mtetra
.724 .743 .866 r
.4733 .37741 .48008 .38554 .49218 .37904 .48544 .37091 Mtetra
.709 .739 .875 r
.48544 .37091 .49218 .37904 .50432 .37321 .49761 .36506 Mtetra
.694 .735 .883 r
.49761 .36506 .50432 .37321 .51649 .36797 .50982 .35981 Mtetra
.679 .731 .89 r
.50982 .35981 .51649 .36797 .52871 .3633 .52207 .35511 Mtetra
.663 .726 .896 r
.52207 .35511 .52871 .3633 .54098 .35917 .53438 .35094 Mtetra
.646 .72 .902 r
.53438 .35094 .54098 .35917 .55332 .35557 .54674 .3473 Mtetra
.628 .713 .908 r
.54674 .3473 .55332 .35557 .56572 .35254 .55918 .34422 Mtetra
.606 .704 .913 r
.55918 .34422 .56572 .35254 .57819 .35011 .57168 .34174 Mtetra
.581 .692 .918 r
.57168 .34174 .57819 .35011 .59075 .34836 .58427 .33993 Mtetra
.552 .679 .923 r
.58427 .33993 .59075 .34836 .60341 .34732 .59695 .33883 Mtetra
.522 .665 .926 r
.59695 .33883 .60341 .34732 .61616 .34695 .60974 .33843 Mtetra
.501 .654 .928 r
.60974 .33843 .61616 .34695 .62902 .347 .62263 .33851 Mtetra
.511 .661 .929 r
.62263 .33851 .62902 .347 .64196 .34668 .63561 .33835 Mtetra
.593 .704 .921 r
.63561 .33835 .64196 .34668 .6549 .34405 .64859 .33611 Mtetra
.747 .771 .873 r
.64859 .33611 .6549 .34405 .66765 .33573 .66143 .32844 Mtetra
.869 .805 .784 r
.66143 .32844 .66765 .33573 .68003 .31919 .6739 .31249 Mtetra
.878 .82 .787 r
.6739 .31249 .68003 .31919 .69246 .30455 .68632 .29643 Mtetra
.664 .741 .907 r
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.648 .734 .912 r
.72563 .28309 .73164 .29132 .74489 .28775 .73889 .27914 Mtetra
.578 .694 .921 r
.73889 .27914 .74489 .28775 .7583 .28555 .75237 .27725 Mtetra
.695 .753 .897 r
.75237 .27725 .7583 .28555 .77153 .27986 .76565 .27161 Mtetra
.701 .758 .896 r
.76565 .27161 .77153 .27986 .78479 .27405 .77896 .26571 Mtetra
.68 .748 .903 r
.77896 .26571 .78479 .27405 .79818 .269 .79238 .26059 Mtetra
.668 .743 .906 r
.79238 .26059 .79818 .269 .81166 .26433 .80591 .25587 Mtetra
.664 .741 .907 r
.80591 .25587 .81166 .26433 .82521 .25974 .81951 .25123 Mtetra
.81951 .25123 .82521 .25974 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43949 .25742 .43247 Mtetra
.663 .741 .908 r
.25742 .43247 .26481 .43949 .27598 .43571 .26862 .42867 Mtetra
.66 .74 .909 r
.26862 .42867 .27598 .43571 .28719 .43203 .27985 .42496 Mtetra
.646 .736 .915 r
.27985 .42496 .28719 .43203 .29842 .42874 .29111 .42164 Mtetra
.616 .727 .925 r
.29111 .42164 .29842 .42874 .30965 .4262 .30237 .41907 Mtetra
.625 .73 .922 r
.30237 .41907 .30965 .4262 .32095 .42343 .3137 .41627 Mtetra
.732 .756 .872 r
.3137 .41627 .32095 .42343 .33252 .41701 .32531 .40982 Mtetra
.68 .745 .9 r
.32531 .40982 .33252 .41701 .34401 .4126 .33683 .40538 Mtetra
.664 .741 .907 r
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
0 .276 .761 r
.37161 .39351 .3787 .40083 .38988 .40828 .3828 .40095 Mtetra
0 .287 .77 r
.3828 .40095 .38988 .40828 .4012 .41567 .39412 .40832 Mtetra
.526 .694 .945 r
.39412 .40832 .4012 .41567 .41293 .41496 .40588 .40759 Mtetra
.719 .758 .883 r
.40588 .40759 .41293 .41496 .42491 .40893 .41789 .40152 Mtetra
.762 .766 .856 r
.41789 .40152 .42491 .40893 .43697 .40084 .43 .39339 Mtetra
.766 .767 .853 r
.43 .39339 .43697 .40084 .44907 .3925 .44214 .38501 Mtetra
.758 .766 .859 r
.44214 .38501 .44907 .3925 .46118 .38462 .45429 .37709 Mtetra
.744 .763 .868 r
.45429 .37709 .46118 .38462 .4733 .37741 .46645 .36985 Mtetra
.728 .76 .877 r
.46645 .36985 .4733 .37741 .48544 .37091 .47863 .3633 Mtetra
.712 .756 .886 r
.47863 .3633 .48544 .37091 .49761 .36506 .49084 .35742 Mtetra
.696 .751 .894 r
.49084 .35742 .49761 .36506 .50982 .35981 .50309 .35213 Mtetra
.68 .746 .901 r
.50309 .35213 .50982 .35981 .52207 .35511 .51538 .3474 Mtetra
.664 .741 .908 r
.51538 .3474 .52207 .35511 .53438 .35094 .52772 .34319 Mtetra
.646 .735 .914 r
.52772 .34319 .53438 .35094 .54674 .3473 .54012 .33952 Mtetra
.626 .728 .92 r
.54012 .33952 .54674 .3473 .55918 .34422 .55259 .3364 Mtetra
.603 .719 .926 r
.55259 .3364 .55918 .34422 .57168 .34174 .56513 .33389 Mtetra
.576 .708 .932 r
.56513 .33389 .57168 .34174 .58427 .33993 .57775 .33205 Mtetra
.545 .694 .937 r
.57775 .33205 .58427 .33993 .59695 .33883 .59046 .33092 Mtetra
.513 .679 .941 r
.59046 .33092 .59695 .33883 .60974 .33843 .60328 .33049 Mtetra
.49 .668 .942 r
.60328 .33049 .60974 .33843 .62263 .33851 .6162 .33054 Mtetra
.501 .674 .942 r
.6162 .33054 .62263 .33851 .63561 .33835 .62921 .33035 Mtetra
.591 .715 .93 r
.62921 .33035 .63561 .33835 .64859 .33611 .64223 .32808 Mtetra
.747 .77 .872 r
.64223 .32808 .64859 .33611 .66143 .32844 .65511 .32037 Mtetra
.861 .789 .779 r
.65511 .32037 .66143 .32844 .6739 .31249 .66765 .30436 Mtetra
.862 .789 .777 r
.66765 .30436 .6739 .31249 .68632 .29643 .68014 .28824 Mtetra
.664 .741 .907 r
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.648 .734 .912 r
.71957 .27479 .72563 .28309 .73889 .27914 .73287 .2708 Mtetra
.576 .703 .929 r
.73287 .2708 .73889 .27914 .75237 .27725 .74639 .26888 Mtetra
.695 .753 .896 r
.74639 .26888 .75237 .27725 .76565 .27161 .75971 .26319 Mtetra
.701 .755 .894 r
.75971 .26319 .76565 .27161 .77896 .26571 .77307 .25726 Mtetra
.68 .747 .902 r
.77307 .25726 .77896 .26571 .79238 .26059 .78654 .25209 Mtetra
.668 .742 .906 r
.78654 .25209 .79238 .26059 .80591 .25587 .80011 .24733 Mtetra
.664 .741 .907 r
.80011 .24733 .80591 .25587 .81951 .25123 .81375 .24266 Mtetra
.81375 .24266 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .42541 Mtetra
.663 .741 .908 r
.24997 .42541 .25742 .43247 .26862 .42867 .2612 .42157 Mtetra
.66 .74 .909 r
.2612 .42157 .26862 .42867 .27985 .42496 .27247 .41782 Mtetra
.647 .736 .914 r
.27247 .41782 .27985 .42496 .29111 .42164 .28375 .41443 Mtetra
.618 .726 .924 r
.28375 .41443 .29111 .42164 .30237 .41907 .29504 .41179 Mtetra
.622 .726 .921 r
.29504 .41179 .30237 .41907 .3137 .41627 .30639 .40905 Mtetra
.725 .755 .876 r
.30639 .40905 .3137 .41627 .32531 .40982 .31801 .4029 Mtetra
.691 .757 .902 r
.31801 .4029 .32531 .40982 .33683 .40538 .32959 .39809 Mtetra
.664 .741 .907 r
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
0 .375 .835 r
.36446 .38613 .37161 .39351 .3828 .40095 .37571 .39222 Mtetra
0 .282 .781 r
.37571 .39222 .3828 .40095 .39412 .40832 .38701 .40021 Mtetra
.502 .662 .933 r
.38701 .40021 .39412 .40832 .40588 .40759 .39877 .40013 Mtetra
.709 .755 .888 r
.39877 .40013 .40588 .40759 .41789 .40152 .4108 .39445 Mtetra
.762 .776 .865 r
.4108 .39445 .41789 .40152 .43 .39339 .42295 .38646 Mtetra
.77 .782 .863 r
.42295 .38646 .43 .39339 .44214 .38501 .43513 .3781 Mtetra
.763 .783 .87 r
.43513 .3781 .44214 .38501 .45429 .37709 .44733 .37014 Mtetra
.749 .781 .879 r
.44733 .37014 .45429 .37709 .46645 .36985 .45953 .36284 Mtetra
.733 .777 .889 r
.45953 .36284 .46645 .36985 .47863 .3633 .47176 .35623 Mtetra
.715 .773 .897 r
.47176 .35623 .47863 .3633 .49084 .35742 .48401 .35028 Mtetra
.699 .768 .905 r
.48401 .35028 .49084 .35742 .50309 .35213 .49629 .34494 Mtetra
.681 .763 .913 r
.49629 .34494 .50309 .35213 .51538 .3474 .50862 .34017 Mtetra
.664 .757 .92 r
.50862 .34017 .51538 .3474 .52772 .34319 .52101 .33593 Mtetra
.645 .751 .926 r
.52101 .33593 .52772 .34319 .54012 .33952 .53345 .33223 Mtetra
.623 .743 .933 r
.53345 .33223 .54012 .33952 .55259 .3364 .54595 .3291 Mtetra
.599 .735 .94 r
.54595 .3291 .55259 .3364 .56513 .33389 .55853 .32657 Mtetra
.569 .723 .946 r
.55853 .32657 .56513 .33389 .57775 .33205 .57118 .32473 Mtetra
.536 .71 .952 r
.57118 .32473 .57775 .33205 .59046 .33092 .58393 .32359 Mtetra
.501 .695 .955 r
.58393 .32359 .59046 .33092 .60328 .33049 .59678 .32313 Mtetra
.479 .684 .956 r
.59678 .32313 .60328 .33049 .6162 .33054 .60973 .3231 Mtetra
.499 .692 .954 r
.60973 .3231 .6162 .33054 .62921 .33035 .62277 .32269 Mtetra
.604 .732 .935 r
.62277 .32269 .62921 .33035 .64223 .32808 .63582 .31995 Mtetra
.76 .773 .863 r
.63582 .31995 .64223 .32808 .65511 .32037 .64872 .3115 Mtetra
.858 .774 .767 r
.64872 .3115 .65511 .32037 .66765 .30436 .66128 .29479 Mtetra
.835 .759 .779 r
.66128 .29479 .66765 .30436 .68014 .28824 .67389 .27998 Mtetra
.664 .741 .907 r
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.637 .73 .916 r
.71345 .26641 .71957 .27479 .73287 .2708 .72682 .26273 Mtetra
.586 .718 .934 r
.72682 .26273 .73287 .2708 .74639 .26888 .74036 .26043 Mtetra
.697 .754 .895 r
.74036 .26043 .74639 .26888 .75971 .26319 .75372 .25461 Mtetra
.699 .752 .893 r
.75372 .25461 .75971 .26319 .77307 .25726 .76712 .24868 Mtetra
.678 .745 .902 r
.76712 .24868 .77307 .25726 .78654 .25209 .78064 .24351 Mtetra
.667 .742 .906 r
.78064 .24351 .78654 .25209 .80011 .24733 .79426 .23872 Mtetra
.664 .741 .907 r
.79426 .23872 .80011 .24733 .81375 .24266 .80795 .234 Mtetra
.80795 .234 .81375 .24266 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23328 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .42541 .24247 .41828 Mtetra
.663 .741 .907 r
.24247 .41828 .24997 .42541 .2612 .42157 .25372 .41442 Mtetra
.661 .74 .909 r
.25372 .41442 .2612 .42157 .27247 .41782 .26502 .41061 Mtetra
.649 .736 .913 r
.26502 .41061 .27247 .41782 .28375 .41443 .27634 .40714 Mtetra
.621 .726 .922 r
.27634 .40714 .28375 .41443 .29504 .41179 .28766 .40438 Mtetra
.617 .722 .921 r
.28766 .40438 .29504 .41179 .30639 .40905 .29902 .40173 Mtetra
.709 .751 .884 r
.29902 .40173 .30639 .40905 .31801 .4029 .31064 .39618 Mtetra
.708 .768 .899 r
.31064 .39618 .31801 .4029 .32959 .39809 .32229 .39075 Mtetra
.664 .741 .907 r
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.24 .548 .929 r
.35725 .37869 .36446 .38613 .37571 .39222 .36865 .38198 Mtetra
0 .245 .76 r
.36865 .38198 .37571 .39222 .38701 .40021 .37989 .3911 Mtetra
.443 .607 .917 r
.37989 .3911 .38701 .40021 .39877 .40013 .39161 .3924 Mtetra
.683 .743 .896 r
.39161 .3924 .39877 .40013 .4108 .39445 .40364 .3876 Mtetra
.756 .783 .876 r
.40364 .3876 .4108 .39445 .42295 .38646 .41582 .38001 Mtetra
.771 .797 .874 r
.41582 .38001 .42295 .38646 .43513 .3781 .42805 .37175 Mtetra
.767 .801 .88 r
.42805 .37175 .43513 .3781 .44733 .37014 .44029 .36377 Mtetra
.754 .8 .89 r
.44029 .36377 .44733 .37014 .45953 .36284 .45254 .3564 Mtetra
.737 .796 .9 r
.45254 .3564 .45953 .36284 .47176 .35623 .46481 .34971 Mtetra
.719 .792 .909 r
.46481 .34971 .47176 .35623 .48401 .35028 .47711 .34369 Mtetra
.701 .786 .917 r
.47711 .34369 .48401 .35028 .49629 .34494 .48944 .33828 Mtetra
.682 .78 .925 r
.48944 .33828 .49629 .34494 .50862 .34017 .50181 .33345 Mtetra
.663 .774 .932 r
.50181 .33345 .50862 .34017 .52101 .33593 .51423 .32918 Mtetra
.642 .768 .939 r
.51423 .32918 .52101 .33593 .53345 .33223 .52671 .32546 Mtetra
.619 .76 .946 r
.52671 .32546 .53345 .33223 .54595 .3291 .53925 .32233 Mtetra
.591 .751 .954 r
.53925 .32233 .54595 .3291 .55853 .32657 .55187 .31982 Mtetra
.559 .739 .96 r
.55187 .31982 .55853 .32657 .57118 .32473 .56457 .31799 Mtetra
.523 .725 .966 r
.56457 .31799 .57118 .32473 .58393 .32359 .57735 .31684 Mtetra
.488 .71 .969 r
.57735 .31684 .58393 .32359 .59678 .32313 .59024 .31634 Mtetra
.472 .702 .969 r
.59024 .31634 .59678 .32313 .60973 .3231 .60322 .31612 Mtetra
.511 .715 .964 r
.60322 .31612 .60973 .3231 .62277 .32269 .61629 .31525 Mtetra
.637 .754 .933 r
.61629 .31525 .62277 .32269 .63582 .31995 .62934 .31154 Mtetra
.784 .773 .843 r
.62934 .31154 .63582 .31995 .64872 .3115 .64223 .30161 Mtetra
.857 .757 .751 r
.64223 .30161 .64872 .3115 .66128 .29479 .65481 .28368 Mtetra
.788 .722 .79 r
.65481 .28368 .66128 .29479 .67389 .27998 .6676 .27166 Mtetra
.664 .741 .907 r
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.617 .721 .921 r
.70729 .25797 .71345 .26641 .72682 .26273 .72073 .25485 Mtetra
.609 .735 .935 r
.72073 .25485 .72682 .26273 .74036 .26043 .73427 .25186 Mtetra
.7 .754 .893 r
.73427 .25186 .74036 .26043 .75372 .25461 .74766 .24588 Mtetra
.697 .749 .892 r
.74766 .24588 .75372 .25461 .76712 .24868 .76112 .23999 Mtetra
.677 .744 .901 r
.76112 .23999 .76712 .24868 .78064 .24351 .77469 .23484 Mtetra
.667 .741 .906 r
.77469 .23484 .78064 .24351 .79426 .23872 .78836 .23003 Mtetra
.664 .741 .907 r
.78836 .23003 .79426 .23872 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .41442 .24619 .4072 Mtetra
.661 .74 .908 r
.24619 .4072 .25372 .41442 .26502 .41061 .25751 .40335 Mtetra
.652 .737 .912 r
.25751 .40335 .26502 .41061 .27634 .40714 .26887 .39976 Mtetra
.627 .727 .919 r
.26887 .39976 .27634 .40714 .28766 .40438 .28022 .39684 Mtetra
.613 .719 .921 r
.28022 .39684 .28766 .40438 .29902 .40173 .29161 .39427 Mtetra
.687 .743 .894 r
.29161 .39427 .29902 .40173 .31064 .39618 .3032 .3895 Mtetra
.727 .774 .89 r
.3032 .3895 .31064 .39618 .32229 .39075 .31493 .38335 Mtetra
.664 .741 .907 r
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.54 .698 .942 r
.34999 .37119 .35725 .37869 .36865 .38198 .36162 .37015 Mtetra
0 .201 .729 r
.36162 .37015 .36865 .38198 .37989 .3911 .37278 .38061 Mtetra
.352 .524 .887 r
.37278 .38061 .37989 .3911 .39161 .3924 .38441 .38399 Mtetra
.634 .711 .902 r
.38441 .38399 .39161 .3924 .40364 .3876 .39642 .38073 Mtetra
.738 .781 .888 r
.39642 .38073 .40364 .3876 .41582 .38001 .40861 .3739 Mtetra
.768 .808 .885 r
.40861 .3739 .41582 .38001 .42805 .37175 .42088 .36592 Mtetra
.769 .817 .891 r
.42088 .36592 .42805 .37175 .44029 .36377 .43317 .35799 Mtetra
.758 .819 .901 r
.43317 .35799 .44029 .36377 .45254 .3564 .44547 .35056 Mtetra
.741 .816 .911 r
.44547 .35056 .45254 .3564 .46481 .34971 .45779 .34379 Mtetra
.722 .812 .921 r
.45779 .34379 .46481 .34971 .47711 .34369 .47013 .33767 Mtetra
.703 .806 .929 r
.47013 .33767 .47711 .34369 .48944 .33828 .48251 .33218 Mtetra
.682 .8 .937 r
.48251 .33218 .48944 .33828 .50181 .33345 .49493 .3273 Mtetra
.661 .793 .945 r
.49493 .3273 .50181 .33345 .51423 .32918 .50739 .32299 Mtetra
.638 .786 .953 r
.50739 .32299 .51423 .32918 .52671 .32546 .51991 .31926 Mtetra
.612 .778 .961 r
.51991 .31926 .52671 .32546 .53925 .32233 .5325 .31614 Mtetra
.581 .768 .968 r
.5325 .31614 .53925 .32233 .55187 .31982 .54516 .31365 Mtetra
.546 .756 .974 r
.54516 .31365 .55187 .31982 .56457 .31799 .55789 .31184 Mtetra
.508 .741 .979 r
.55789 .31184 .56457 .31799 .57735 .31684 .57072 .31069 Mtetra
.477 .727 .98 r
.57072 .31069 .57735 .31684 .59024 .31634 .58365 .31006 Mtetra
.476 .723 .979 r
.58365 .31006 .59024 .31634 .60322 .31612 .59666 .3095 Mtetra
.545 .744 .968 r
.59666 .3095 .60322 .31612 .61629 .31525 .60974 .30777 Mtetra
.689 .773 .915 r
.60974 .30777 .61629 .31525 .62934 .31154 .62279 .30242 Mtetra
.808 .764 .812 r
.62279 .30242 .62934 .31154 .64223 .30161 .63565 .2903 Mtetra
.854 .735 .732 r
.63565 .2903 .64223 .30161 .65481 .28368 .64823 .27093 Mtetra
.711 .668 .806 r
.64823 .27093 .65481 .28368 .6676 .27166 .66125 .26326 Mtetra
.664 .741 .907 r
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.592 .71 .926 r
.70106 .24945 .70729 .25797 .72073 .25485 .7146 .247 Mtetra
.638 .751 .93 r
.7146 .247 .72073 .25485 .73427 .25186 .72812 .24313 Mtetra
.703 .752 .89 r
.72812 .24313 .73427 .25186 .74766 .24588 .74155 .23699 Mtetra
.693 .746 .892 r
.74155 .23699 .74766 .24588 .76112 .23999 .75507 .2312 Mtetra
.674 .742 .902 r
.75507 .2312 .76112 .23999 .77469 .23484 .76869 .22609 Mtetra
.666 .741 .906 r
.76869 .22609 .77469 .23484 .78836 .23003 .7824 .22126 Mtetra
.664 .741 .907 r
.7824 .22126 .78836 .23003 .80209 .22527 .79619 .21647 Mtetra
.79619 .21647 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20684 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .4072 .23859 .39993 Mtetra
.662 .74 .908 r
.23859 .39993 .24619 .4072 .25751 .40335 .24995 .39602 Mtetra
.655 .738 .911 r
.24995 .39602 .25751 .40335 .26887 .39976 .26134 .39231 Mtetra
.633 .729 .917 r
.26134 .39231 .26887 .39976 .28022 .39684 .27273 .38918 Mtetra
.612 .717 .92 r
.27273 .38918 .28022 .39684 .29161 .39427 .28414 .38661 Mtetra
.66 .733 .903 r
.28414 .38661 .29161 .39427 .3032 .3895 .29571 .38267 Mtetra
.74 .773 .88 r
.29571 .38267 .3032 .3895 .31493 .38335 .30751 .37589 Mtetra
.664 .741 .907 r
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36162 .37015 .35449 .35951 Mtetra
0 .27 .776 r
.35449 .35951 .36162 .37015 .37278 .38061 .36572 .36823 Mtetra
.245 .419 .836 r
.36572 .36823 .37278 .38061 .38441 .38399 .37722 .37423 Mtetra
.551 .645 .896 r
.37722 .37423 .38441 .38399 .39642 .38073 .38915 .37331 Mtetra
.7 .76 .898 r
.38915 .37331 .39642 .38073 .40861 .3739 .40133 .36785 Mtetra
.754 .81 .897 r
.40133 .36785 .40861 .3739 .42088 .36592 .41362 .36049 Mtetra
.766 .831 .902 r
.41362 .36049 .42088 .36592 .43317 .35799 .42596 .35275 Mtetra
.759 .837 .912 r
.42596 .35275 .43317 .35799 .44547 .35056 .43831 .34534 Mtetra
.744 .838 .922 r
.43831 .34534 .44547 .35056 .45779 .34379 .45068 .33849 Mtetra
.725 .834 .932 r
.45068 .33849 .45779 .34379 .47013 .33767 .46308 .33229 Mtetra
.704 .829 .942 r
.46308 .33229 .47013 .33767 .48251 .33218 .4755 .32672 Mtetra
.681 .822 .951 r
.4755 .32672 .48251 .33218 .49493 .3273 .48797 .32177 Mtetra
.657 .815 .959 r
.48797 .32177 .49493 .3273 .50739 .32299 .50048 .31743 Mtetra
.631 .807 .967 r
.50048 .31743 .50739 .32299 .51991 .31926 .51305 .31369 Mtetra
.601 .798 .975 r
.51305 .31369 .51991 .31926 .5325 .31614 .52568 .31058 Mtetra
.567 .787 .982 r
.52568 .31058 .5325 .31614 .54516 .31365 .53838 .30811 Mtetra
.529 .773 .987 r
.53838 .30811 .54516 .31365 .55789 .31184 .55116 .30631 Mtetra
.493 .758 .989 r
.55116 .30631 .55789 .31184 .57072 .31069 .56403 .30507 Mtetra
.473 .747 .989 r
.56403 .30507 .57072 .31069 .58365 .31006 .57699 .30418 Mtetra
.502 .752 .985 r
.57699 .30418 .58365 .31006 .59666 .3095 .59004 .30292 Mtetra
.609 .774 .959 r
.59004 .30292 .59666 .3095 .60974 .30777 .60312 .29973 Mtetra
.747 .776 .877 r
.60312 .29973 .60974 .30777 .62279 .30242 .61615 .29193 Mtetra
.825 .743 .774 r
.61615 .29193 .62279 .30242 .63565 .2903 .62897 .27706 Mtetra
.823 .704 .733 r
.62897 .27706 .63565 .2903 .64823 .27093 .64166 .25938 Mtetra
.656 .666 .848 r
.64166 .25938 .64823 .27093 .66125 .26326 .65485 .25478 Mtetra
.664 .741 .907 r
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.569 .7 .93 r
.69479 .24086 .70106 .24945 .7146 .247 .7084 .23899 Mtetra
.667 .76 .92 r
.7084 .23899 .7146 .247 .72812 .24313 .72191 .23418 Mtetra
.703 .749 .887 r
.72191 .23418 .72812 .24313 .74155 .23699 .73539 .22797 Mtetra
.688 .743 .893 r
.73539 .22797 .74155 .23699 .75507 .2312 .74896 .22232 Mtetra
.672 .741 .902 r
.74896 .22232 .75507 .2312 .76869 .22609 .76264 .21726 Mtetra
.665 .741 .906 r
.76264 .21726 .76869 .22609 .7824 .22126 .7764 .21241 Mtetra
.664 .741 .907 r
.7764 .21241 .7824 .22126 .79619 .21647 .79023 .20758 Mtetra
.79023 .20758 .79619 .21647 .81004 .21166 .80412 .20274 Mtetra
.80412 .20274 .81004 .21166 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39993 .23093 .3926 Mtetra
.663 .74 .908 r
.23093 .3926 .23859 .39993 .24995 .39602 .24232 .38864 Mtetra
.658 .739 .909 r
.24232 .38864 .24995 .39602 .26134 .39231 .25374 .38481 Mtetra
.641 .732 .914 r
.25374 .38481 .26134 .39231 .27273 .38918 .26518 .38145 Mtetra
.616 .718 .918 r
.26518 .38145 .27273 .38918 .28414 .38661 .27662 .37875 Mtetra
.636 .722 .91 r
.27662 .37875 .28414 .38661 .29571 .38267 .28816 .3755 Mtetra
.74 .766 .874 r
.28816 .3755 .29571 .38267 .30751 .37589 .30002 .36858 Mtetra
.671 .749 .909 r
.30002 .36858 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.664 .741 .907 r
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.359 .613 .947 r
.34713 .35185 .35449 .35951 .36572 .36823 .35873 .35365 Mtetra
.159 .322 .78 r
.35873 .35365 .36572 .36823 .37722 .37423 .37009 .36226 Mtetra
.436 .539 .864 r
.37009 .36226 .37722 .37423 .38915 .37331 .38188 .3645 Mtetra
.63 .703 .899 r
.38188 .3645 .38915 .37331 .40133 .36785 .394 .36128 Mtetra
.722 .792 .907 r
.394 .36128 .40133 .36785 .41362 .36049 .4063 .35511 Mtetra
.753 .833 .913 r
.4063 .35511 .41362 .36049 .42596 .35275 .41866 .3479 Mtetra
.755 .851 .922 r
.41866 .3479 .42596 .35275 .43831 .34534 .43107 .34064 Mtetra
.743 .856 .933 r
.43107 .34064 .43831 .34534 .45068 .33849 .44349 .33381 Mtetra
.725 .856 .944 r
.44349 .33381 .45068 .33849 .46308 .33229 .45594 .32755 Mtetra
.702 .851 .954 r
.45594 .32755 .46308 .33229 .4755 .32672 .46842 .32192 Mtetra
.678 .845 .963 r
.46842 .32192 .4755 .32672 .48797 .32177 .48093 .31692 Mtetra
.651 .837 .972 r
.48093 .31692 .48797 .32177 .50048 .31743 .49349 .31254 Mtetra
.621 .828 .98 r
.49349 .31254 .50048 .31743 .51305 .31369 .50611 .30879 Mtetra
.587 .818 .987 r
.50611 .30879 .51305 .31369 .52568 .31058 .51879 .30568 Mtetra
.55 .805 .992 r
.51879 .30568 .52568 .31058 .53838 .30811 .53154 .3032 Mtetra
.514 .79 .995 r
.53154 .3032 .53838 .30811 .55116 .30631 .54436 .3013 Mtetra
.488 .776 .996 r
.54436 .3013 .55116 .30631 .56403 .30507 .55728 .29984 Mtetra
.496 .773 .994 r
.55728 .29984 .56403 .30507 .57699 .30418 .57028 .29835 Mtetra
.568 .784 .98 r
.57028 .29835 .57699 .30418 .59004 .30292 .58334 .29581 Mtetra
.694 .788 .923 r
.58334 .29581 .59004 .30292 .60312 .29973 .59642 .29027 Mtetra
.791 .755 .82 r
.59642 .29027 .60312 .29973 .61615 .29193 .6094 .27919 Mtetra
.827 .711 .737 r
.6094 .27919 .61615 .29193 .62897 .27706 .62218 .26158 Mtetra
.735 .644 .759 r
.62218 .26158 .62897 .27706 .64166 .25938 .63515 .25087 Mtetra
.664 .741 .907 r
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.657 .738 .91 r
.67504 .23689 .68141 .24552 .69479 .24086 .68847 .23241 Mtetra
.563 .704 .936 r
.68847 .23241 .69479 .24086 .7084 .23899 .70212 .23061 Mtetra
.688 .759 .906 r
.70212 .23061 .7084 .23899 .72191 .23418 .71563 .22502 Mtetra
.7 .744 .886 r
.71563 .22502 .72191 .23418 .73539 .22797 .72916 .21886 Mtetra
.682 .74 .894 r
.72916 .21886 .73539 .22797 .74896 .22232 .7428 .21337 Mtetra
.669 .74 .903 r
.7428 .21337 .74896 .22232 .76264 .21726 .75653 .20836 Mtetra
.665 .741 .907 r
.75653 .20836 .76264 .21726 .7764 .21241 .77034 .20348 Mtetra
.664 .741 .907 r
.77034 .20348 .7764 .21241 .79023 .20758 .78422 .19862 Mtetra
.78422 .19862 .79023 .20758 .80412 .20274 .79816 .19373 Mtetra
.79816 .19373 .80412 .20274 .81809 .19786 .81217 .18882 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.20052 .39321 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .3926 .22321 .38521 Mtetra
.663 .741 .908 r
.22321 .38521 .23093 .3926 .24232 .38864 .23463 .3812 Mtetra
.66 .739 .909 r
.23463 .3812 .24232 .38864 .25374 .38481 .24609 .37727 Mtetra
.648 .734 .912 r
.24609 .37727 .25374 .38481 .26518 .38145 .25757 .37367 Mtetra
.624 .721 .916 r
.25757 .37367 .26518 .38145 .27662 .37875 .26906 .37072 Mtetra
.62 .714 .913 r
.26906 .37072 .27662 .37875 .28816 .3755 .28059 .36789 Mtetra
.694 .747 .892 r
.28059 .36789 .28816 .3755 .30002 .36858 .29235 .36275 Mtetra
.727 .804 .913 r
.29235 .36275 .30002 .36858 .31173 .36426 .30422 .35664 Mtetra
.664 .741 .907 r
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35873 .35365 .35166 .33992 Mtetra
.195 .362 .804 r
.35166 .33992 .35873 .35365 .37009 .36226 .36306 .34732 Mtetra
.32 .418 .806 r
.36306 .34732 .37009 .36226 .38188 .3645 .37468 .35307 Mtetra
.521 .597 .871 r
.37468 .35307 .38188 .3645 .394 .36128 .38667 .35311 Mtetra
.655 .731 .905 r
.38667 .35311 .394 .36128 .4063 .35511 .39892 .34906 Mtetra
.72 .81 .921 r
.39892 .34906 .4063 .35511 .41866 .3479 .41129 .34297 Mtetra
.739 .849 .931 r
.41129 .34297 .41866 .3479 .43107 .34064 .42373 .33625 Mtetra
.735 .867 .942 r
.42373 .33625 .43107 .34064 .44349 .33381 .43621 .32961 Mtetra
.719 .872 .953 r
.43621 .32961 .44349 .33381 .45594 .32755 .44871 .32341 Mtetra
.697 .871 .964 r
.44871 .32341 .45594 .32755 .46842 .32192 .46124 .31776 Mtetra
.67 .866 .973 r
.46124 .31776 .46842 .32192 .48093 .31692 .47381 .31272 Mtetra
.641 .859 .982 r
.47381 .31272 .48093 .31692 .49349 .31254 .48642 .30831 Mtetra
.608 .849 .989 r
.48642 .30831 .49349 .31254 .50611 .30879 .49909 .30453 Mtetra
.573 .836 .995 r
.49909 .30453 .50611 .30879 .51879 .30568 .51182 .30136 Mtetra
.538 .822 .998 r
.51182 .30136 .51879 .30568 .53154 .3032 .52462 .29876 Mtetra
.512 .808 .999 r
.52462 .29876 .53154 .3032 .54436 .3013 .5375 .2966 Mtetra
.513 .8 .998 r
.5375 .2966 .54436 .3013 .55728 .29984 .55045 .29453 Mtetra
.565 .801 .988 r
.55045 .29453 .55728 .29984 .57028 .29835 .56348 .29183 Mtetra
.667 .799 .945 r
.56348 .29183 .57028 .29835 .58334 .29581 .57656 .28707 Mtetra
.763 .765 .854 r
.57656 .28707 .58334 .29581 .59642 .29027 .58961 .27816 Mtetra
.808 .715 .762 r
.58961 .27816 .59642 .29027 .6094 .27919 .60253 .26341 Mtetra
.791 .666 .726 r
.60253 .26341 .6094 .27919 .62218 .26158 .61538 .24695 Mtetra
.644 .613 .803 r
.61538 .24695 .62218 .26158 .63515 .25087 .62859 .24229 Mtetra
.664 .741 .907 r
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.598 .713 .925 r
.66861 .22819 .67504 .23689 .68847 .23241 .68217 .22546 Mtetra
.623 .778 .955 r
.68217 .22546 .68847 .23241 .70212 .23061 .69577 .22176 Mtetra
.699 .753 .893 r
.69577 .22176 .70212 .23061 .71563 .22502 .7093 .21567 Mtetra
.694 .739 .886 r
.7093 .21567 .71563 .22502 .72916 .21886 .72289 .20969 Mtetra
.677 .738 .897 r
.72289 .20969 .72916 .21886 .7428 .21337 .73658 .20437 Mtetra
.667 .74 .904 r
.73658 .20437 .7428 .21337 .75653 .20836 .75037 .19939 Mtetra
.664 .741 .907 r
.75037 .19939 .75653 .20836 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78422 .19862 .77815 .18957 Mtetra
.77815 .18957 .78422 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18882 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.19268 .38582 .20052 .39321 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .38521 .21543 .37776 Mtetra
.21543 .37776 .22321 .38521 .23463 .3812 .22688 .37371 Mtetra
.662 .74 .908 r
.22688 .37371 .23463 .3812 .24609 .37727 .23837 .3697 Mtetra
.654 .737 .91 r
.23837 .3697 .24609 .37727 .25757 .37367 .2499 .36589 Mtetra
.635 .726 .914 r
.2499 .36589 .25757 .37367 .26906 .37072 .26143 .36262 Mtetra
.617 .712 .914 r
.26143 .36262 .26906 .37072 .28059 .36789 .27298 .35984 Mtetra
.651 .725 .903 r
.27298 .35984 .28059 .36789 .29235 .36275 .28467 .35607 Mtetra
.746 .784 .884 r
.28467 .35607 .29235 .36275 .30422 .35664 .29665 .34896 Mtetra
.664 .741 .907 r
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.606 .722 .927 r
.34422 .3321 .35166 .33992 .36306 .34732 .35616 .32945 Mtetra
.257 .337 .754 r
.35616 .32945 .36306 .34732 .37468 .35307 .36761 .33784 Mtetra
.403 .465 .81 r
.36761 .33784 .37468 .35307 .38667 .35311 .37943 .34173 Mtetra
.549 .614 .87 r
.37943 .34173 .38667 .35311 .39892 .34906 .39156 .34093 Mtetra
.65 .734 .91 r
.39156 .34093 .39892 .34906 .41129 .34297 .40389 .33697 Mtetra
.701 .81 .933 r
.40389 .33697 .41129 .34297 .42373 .33625 .41633 .33144 Mtetra
.714 .852 .947 r
.41633 .33144 .42373 .33625 .43621 .32961 .42884 .32543 Mtetra
.707 .872 .959 r
.42884 .32543 .43621 .32961 .44871 .32341 .44139 .3195 Mtetra
.688 .879 .97 r
.44139 .3195 .44871 .32341 .46124 .31776 .45397 .31397 Mtetra
.662 .878 .979 r
.45397 .31397 .46124 .31776 .47381 .31272 .4666 .30896 Mtetra
.632 .872 .987 r
.4666 .30896 .47381 .31272 .48642 .30831 .47927 .30452 Mtetra
.6 .862 .993 r
.47927 .30452 .48642 .30831 .49909 .30453 .49199 .30064 Mtetra
.57 .849 .996 r
.49199 .30064 .49909 .30453 .51182 .30136 .50477 .29729 Mtetra
.549 .836 .998 r
.50477 .29729 .51182 .30136 .52462 .29876 .51763 .29434 Mtetra
.552 .826 .997 r
.51763 .29434 .52462 .29876 .5375 .2966 .53055 .29148 Mtetra
.594 .819 .986 r
.53055 .29148 .5375 .2966 .55045 .29453 .54355 .28813 Mtetra
.672 .804 .946 r
.54355 .28813 .55045 .29453 .56348 .29183 .5566 .28321 Mtetra
.749 .764 .866 r
.5566 .28321 .56348 .29183 .57656 .28707 .56967 .27508 Mtetra
.79 .712 .778 r
.56967 .27508 .57656 .28707 .58961 .27816 .58268 .26216 Mtetra
.798 .667 .719 r
.58268 .26216 .58961 .27816 .60253 .26341 .59557 .24465 Mtetra
.655 .573 .75 r
.59557 .24465 .60253 .26341 .61538 .24695 .60872 .23834 Mtetra
.664 .741 .907 r
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.561 .696 .931 r
.66212 .21941 .66861 .22819 .68217 .22546 .67578 .21763 Mtetra
.676 .773 .924 r
.67578 .21763 .68217 .22546 .69577 .22176 .68934 .21244 Mtetra
.7 .743 .885 r
.68934 .21244 .69577 .22176 .7093 .21567 .70291 .20622 Mtetra
.686 .736 .888 r
.70291 .20622 .7093 .21567 .72289 .20969 .71657 .20049 Mtetra
.672 .738 .9 r
.71657 .20049 .72289 .20969 .73658 .20437 .73032 .19531 Mtetra
.666 .74 .905 r
.73032 .19531 .73658 .20437 .75037 .19939 .74415 .19034 Mtetra
.664 .741 .907 r
.74415 .19034 .75037 .19939 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .37371 .21906 .36616 Mtetra
.663 .74 .908 r
.21906 .36616 .22688 .37371 .23837 .3697 .23059 .36208 Mtetra
.659 .738 .909 r
.23059 .36208 .23837 .3697 .2499 .36589 .24215 .35811 Mtetra
.645 .731 .911 r
.24215 .35811 .2499 .36589 .26143 .36262 .25374 .35451 Mtetra
.624 .716 .913 r
.25374 .35451 .26143 .36262 .27298 .35984 .26534 .3515 Mtetra
.625 .711 .908 r
.26534 .3515 .27298 .35984 .28467 .35607 .27699 .34845 Mtetra
.695 .752 .895 r
.27699 .34845 .28467 .35607 .29665 .34896 .28887 .34321 Mtetra
.728 .811 .916 r
.28887 .34321 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.664 .741 .907 r
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35616 .32945 .34877 .31992 Mtetra
.555 .658 .905 r
.34877 .31992 .35616 .32945 .36761 .33784 .36073 .31869 Mtetra
.338 .374 .752 r
.36073 .31869 .36761 .33784 .37943 .34173 .37236 .32558 Mtetra
.442 .476 .799 r
.37236 .32558 .37943 .34173 .39156 .34093 .38431 .32864 Mtetra
.547 .597 .855 r
.38431 .32864 .39156 .34093 .40389 .33697 .39653 .32795 Mtetra
.626 .705 .902 r
.39653 .32795 .40389 .33697 .41633 .33144 .40892 .32468 Mtetra
.67 .783 .934 r
.40892 .32468 .41633 .33144 .42884 .32543 .42143 .32005 Mtetra
.683 .83 .954 r
.42143 .32005 .42884 .32543 .44139 .3195 .434 .31491 Mtetra
.676 .855 .968 r
.434 .31491 .44139 .3195 .45397 .31397 .44663 .30978 Mtetra
.659 .865 .978 r
.44663 .30978 .45397 .31397 .4666 .30896 .45931 .30492 Mtetra
.636 .865 .985 r
.45931 .30492 .4666 .30896 .47927 .30452 .47203 .30044 Mtetra
.616 .859 .989 r
.47203 .30044 .47927 .30452 .49199 .30064 .48481 .29634 Mtetra
.604 .849 .99 r
.48481 .29634 .49199 .30064 .50477 .29729 .49765 .29252 Mtetra
.612 .837 .986 r
.49765 .29252 .50477 .29729 .51763 .29434 .51056 .2887 Mtetra
.645 .82 .967 r
.51056 .2887 .51763 .29434 .53055 .29148 .52353 .28438 Mtetra
.697 .791 .923 r
.52353 .28438 .53055 .29148 .54355 .28813 .53656 .27868 Mtetra
.746 .745 .851 r
.53656 .27868 .54355 .28813 .5566 .28321 .54963 .27037 Mtetra
.773 .694 .776 r
.54963 .27037 .5566 .28321 .56967 .27508 .56268 .25824 Mtetra
.779 .652 .722 r
.56268 .25824 .56967 .27508 .58268 .26216 .57566 .2422 Mtetra
.671 .572 .735 r
.57566 .2422 .58268 .26216 .59557 .24465 .58877 .23436 Mtetra
.66 .699 .875 r
.58877 .23436 .59557 .24465 .60872 .23834 .60201 .22964 Mtetra
.664 .741 .907 r
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.597 .713 .925 r
.64209 .21536 .64867 .22417 .66212 .21941 .65566 .21259 Mtetra
.621 .785 .96 r
.65566 .21259 .66212 .21941 .67578 .21763 .66927 .20883 Mtetra
.696 .756 .898 r
.66927 .20883 .67578 .21763 .68934 .21244 .68284 .20281 Mtetra
.694 .735 .883 r
.68284 .20281 .68934 .21244 .70291 .20622 .69647 .19675 Mtetra
.678 .734 .893 r
.69647 .19675 .70291 .20622 .71657 .20049 .71019 .19129 Mtetra
.668 .738 .902 r
.71019 .19129 .71657 .20049 .73032 .19531 .724 .1862 Mtetra
.665 .74 .906 r
.724 .1862 .73032 .19531 .74415 .19034 .73788 .18121 Mtetra
.664 .741 .907 r
.73788 .18121 .74415 .19034 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16622 Mtetra
.77994 .16622 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.663 .741 .907 r
.21118 .35856 .21906 .36616 .23059 .36208 .22274 .35443 Mtetra
.661 .74 .908 r
.22274 .35443 .23059 .36208 .24215 .35811 .23434 .35034 Mtetra
.654 .735 .909 r
.23434 .35034 .24215 .35811 .25374 .35451 .24598 .34646 Mtetra
.636 .724 .911 r
.24598 .34646 .25374 .35451 .26534 .3515 .25763 .34307 Mtetra
.62 .709 .909 r
.25763 .34307 .26534 .3515 .27699 .34845 .2693 .34012 Mtetra
.644 .72 .903 r
.2693 .34012 .27699 .34845 .28887 .34321 .28109 .33647 Mtetra
.736 .785 .892 r
.28109 .33647 .28887 .34321 .30086 .337 .29315 .32974 Mtetra
.683 .762 .911 r
.29315 .32974 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.664 .741 .907 r
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36073 .31869 .35339 .30757 Mtetra
.611 .648 .863 r
.35339 .30757 .36073 .31869 .37236 .32558 .36551 .30482 Mtetra
.394 .395 .741 r
.36551 .30482 .37236 .32558 .38431 .32864 .3773 .31052 Mtetra
.461 .464 .775 r
.3773 .31052 .38431 .32864 .39653 .32795 .38935 .31336 Mtetra
.533 .553 .821 r
.38935 .31336 .39653 .32795 .40892 .32468 .40163 .31327 Mtetra
.594 .639 .866 r
.40163 .31327 .40892 .32468 .42143 .32005 .41407 .31101 Mtetra
.634 .711 .902 r
.41407 .31101 .42143 .32005 .434 .31491 .42663 .30743 Mtetra
.654 .761 .928 r
.42663 .30743 .434 .31491 .44663 .30978 .43928 .3032 Mtetra
.66 .791 .944 r
.43928 .3032 .44663 .30978 .45931 .30492 .45199 .29873 Mtetra
.659 .804 .952 r
.45199 .29873 .45931 .30492 .47203 .30044 .46476 .29422 Mtetra
.66 .804 .952 r
.46476 .29422 .47203 .30044 .48481 .29634 .47759 .28965 Mtetra
.669 .793 .941 r
.47759 .28965 .48481 .29634 .49765 .29252 .49048 .28484 Mtetra
.689 .772 .914 r
.49048 .28484 .49765 .29252 .51056 .2887 .50344 .27939 Mtetra
.716 .739 .869 r
.50344 .27939 .51056 .2887 .52353 .28438 .51646 .2726 Mtetra
.739 .698 .812 r
.51646 .2726 .52353 .28438 .53656 .27868 .52951 .2636 Mtetra
.753 .658 .757 r
.52951 .2636 .53656 .27868 .54963 .27037 .54258 .25162 Mtetra
.755 .626 .716 r
.54258 .25162 .54963 .27037 .56268 .25824 .55561 .23673 Mtetra
.644 .546 .728 r
.55561 .23673 .56268 .25824 .57566 .2422 .56875 .23037 Mtetra
.655 .666 .849 r
.56875 .23037 .57566 .2422 .58877 .23436 .58196 .22564 Mtetra
.664 .741 .907 r
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.646 .734 .913 r
.62197 .21129 .62866 .22014 .64209 .21536 .63546 .20707 Mtetra
.575 .721 .942 r
.63546 .20707 .64209 .21536 .65566 .21259 .6491 .20475 Mtetra
.683 .778 .923 r
.6491 .20475 .65566 .21259 .66927 .20883 .66268 .19928 Mtetra
.697 .739 .884 r
.66268 .19928 .66927 .20883 .68284 .20281 .67629 .19308 Mtetra
.685 .731 .886 r
.67629 .19308 .68284 .20281 .69647 .19675 .68998 .18733 Mtetra
.672 .735 .897 r
.68998 .18733 .69647 .19675 .71019 .19129 .70376 .18207 Mtetra
.666 .739 .904 r
.70376 .18207 .71019 .19129 .724 .1862 .71762 .17702 Mtetra
.664 .74 .907 r
.71762 .17702 .724 .1862 .73788 .18121 .73155 .17201 Mtetra
.664 .741 .907 r
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16622 .77376 .15688 Mtetra
.77376 .15688 .77994 .16622 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36332 Mtetra
.16877 .36332 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35443 .21482 .34672 Mtetra
.663 .74 .908 r
.21482 .34672 .22274 .35443 .23434 .35034 .22646 .34255 Mtetra
.659 .738 .908 r
.22646 .34255 .23434 .35034 .24598 .34646 .23814 .33848 Mtetra
.648 .731 .909 r
.23814 .33848 .24598 .34646 .25763 .34307 .24985 .33472 Mtetra
.63 .716 .909 r
.24985 .33472 .25763 .34307 .2693 .34012 .26157 .33145 Mtetra
.623 .706 .905 r
.26157 .33145 .2693 .34012 .28109 .33647 .27333 .32838 Mtetra
.665 .736 .902 r
.27333 .32838 .28109 .33647 .29315 .32974 .28526 .32403 Mtetra
.749 .819 .907 r
.28526 .32403 .29315 .32974 .30513 .32488 .29743 .31693 Mtetra
.664 .741 .907 r
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36551 .30482 .35806 .29507 Mtetra
.66 .699 .876 r
.35806 .29507 .36551 .30482 .3773 .31052 .37036 .29064 Mtetra
.5 .47 .755 r
.37036 .29064 .3773 .31052 .38935 .31336 .38243 .29224 Mtetra
.482 .448 .743 r
.38243 .29224 .38935 .31336 .40163 .31327 .39457 .29477 Mtetra
.527 .501 .77 r
.39457 .29477 .40163 .31327 .41407 .31101 .40691 .29515 Mtetra
.571 .557 .8 r
.40691 .29515 .41407 .31101 .42663 .30743 .4194 .29367 Mtetra
.606 .606 .825 r
.4194 .29367 .42663 .30743 .43928 .3032 .43202 .29083 Mtetra
.633 .642 .842 r
.43202 .29083 .43928 .3032 .45199 .29873 .44473 .28702 Mtetra
.653 .664 .848 r
.44473 .28702 .45199 .29873 .46476 .29422 .45753 .28246 Mtetra
.67 .671 .842 r
.45753 .28246 .46476 .29422 .47759 .28965 .4704 .27715 Mtetra
.686 .665 .823 r
.4704 .27715 .47759 .28965 .49048 .28484 .48333 .27087 Mtetra
.702 .65 .795 r
.48333 .27087 .49048 .28484 .50344 .27939 .49633 .26321 Mtetra
.715 .629 .761 r
.49633 .26321 .50344 .27939 .51646 .2726 .50937 .25366 Mtetra
.723 .608 .728 r
.50937 .25366 .51646 .2726 .52951 .2636 .52244 .24192 Mtetra
.697 .575 .713 r
.52244 .24192 .52951 .2636 .54258 .25162 .53551 .2311 Mtetra
.623 .541 .741 r
.53551 .2311 .54258 .25162 .55561 .23673 .54863 .22637 Mtetra
.66 .699 .876 r
.54863 .22637 .55561 .23673 .56875 .23037 .56182 .22161 Mtetra
.664 .741 .907 r
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.567 .7 .931 r
.61522 .20236 .62197 .21129 .63546 .20707 .62883 .20034 Mtetra
.659 .804 .953 r
.62883 .20034 .63546 .20707 .6491 .20475 .64242 .19551 Mtetra
.697 .748 .891 r
.64242 .19551 .6491 .20475 .66268 .19928 .65602 .18937 Mtetra
.689 .729 .881 r
.65602 .18937 .66268 .19928 .67629 .19308 .66969 .18341 Mtetra
.676 .731 .892 r
.66969 .18341 .67629 .19308 .68998 .18733 .68344 .17796 Mtetra
.668 .737 .902 r
.68344 .17796 .68998 .18733 .70376 .18207 .69728 .17282 Mtetra
.665 .74 .906 r
.69728 .17282 .70376 .18207 .71762 .17702 .71119 .16777 Mtetra
.664 .741 .907 r
.71119 .16777 .71762 .17702 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14746 Mtetra
.76752 .14746 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36332 .16067 .35569 Mtetra
.16067 .35569 .16877 .36332 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34672 .20684 .33895 Mtetra
.663 .741 .907 r
.20684 .33895 .21482 .34672 .22646 .34255 .21851 .33473 Mtetra
.662 .74 .908 r
.21851 .33473 .22646 .34255 .23814 .33848 .23023 .33054 Mtetra
.656 .736 .908 r
.23023 .33054 .23814 .33848 .24985 .33472 .24199 .32649 Mtetra
.644 .726 .908 r
.24199 .32649 .24985 .33472 .26157 .33145 .25377 .3228 Mtetra
.627 .71 .906 r
.25377 .3228 .26157 .33145 .27333 .32838 .26557 .31958 Mtetra
.629 .707 .903 r
.26557 .31958 .27333 .32838 .28526 .32403 .27744 .31628 Mtetra
.679 .751 .906 r
.27744 .31628 .28526 .32403 .29743 .31693 .28948 .31146 Mtetra
.744 .829 .917 r
.28948 .31146 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.664 .741 .907 r
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38243 .29224 .37519 .27791 Mtetra
.643 .613 .804 r
.37519 .27791 .38243 .29224 .39457 .29477 .38763 .2734 Mtetra
.565 .497 .738 r
.38763 .2734 .39457 .29477 .40691 .29515 .40001 .27197 Mtetra
.541 .47 .725 r
.40001 .27197 .40691 .29515 .4194 .29367 .41242 .27183 Mtetra
.57 .498 .734 r
.41242 .27183 .4194 .29367 .43202 .29083 .42498 .27011 Mtetra
.598 .524 .742 r
.42498 .27011 .43202 .29083 .44473 .28702 .43766 .2669 Mtetra
.623 .543 .744 r
.43766 .2669 .44473 .28702 .45753 .28246 .45045 .26229 Mtetra
.644 .555 .739 r
.45045 .26229 .45753 .28246 .4704 .27715 .46332 .25628 Mtetra
.662 .56 .729 r
.46332 .25628 .4704 .27715 .48333 .27087 .47627 .24877 Mtetra
.676 .56 .716 r
.47627 .24877 .48333 .27087 .49633 .26321 .48928 .23966 Mtetra
.655 .539 .71 r
.48928 .23966 .49633 .26321 .50937 .25366 .50229 .23182 Mtetra
.619 .529 .731 r
.50229 .23182 .50937 .25366 .52244 .24192 .51534 .22709 Mtetra
.643 .613 .804 r
.51534 .22709 .52244 .24192 .53551 .2311 .52844 .22234 Mtetra
.664 .741 .907 r
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.576 .705 .93 r
.59492 .19824 .60178 .20721 .61522 .20236 .60848 .19594 Mtetra
.641 .809 .964 r
.60848 .19594 .61522 .20236 .62883 .20034 .62206 .19152 Mtetra
.694 .758 .901 r
.62206 .19152 .62883 .20034 .64242 .19551 .63566 .18553 Mtetra
.691 .729 .88 r
.63566 .18553 .64242 .19551 .65602 .18937 .64931 .17946 Mtetra
.679 .728 .887 r
.64931 .17946 .65602 .18937 .66969 .18341 .66304 .17386 Mtetra
.67 .734 .898 r
.66304 .17386 .66969 .18341 .68344 .17796 .67685 .16861 Mtetra
.665 .738 .905 r
.67685 .16861 .68344 .17796 .69728 .17282 .69074 .16351 Mtetra
.664 .74 .907 r
.69074 .16351 .69728 .17282 .71119 .16777 .70469 .15844 Mtetra
.664 .741 .907 r
.70469 .15844 .71119 .16777 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14746 .76122 .13795 Mtetra
.76122 .13795 .76752 .14746 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33473 .21049 .32686 Mtetra
.663 .74 .907 r
.21049 .32686 .21851 .33473 .23023 .33054 .22225 .32259 Mtetra
.661 .739 .908 r
.22225 .32259 .23023 .33054 .24199 .32649 .23405 .31837 Mtetra
.654 .733 .907 r
.23405 .31837 .24199 .32649 .25377 .3228 .24589 .31433 Mtetra
.641 .721 .906 r
.24589 .31433 .25377 .3228 .26557 .31958 .25775 .31066 Mtetra
.628 .706 .902 r
.25775 .31066 .26557 .31958 .27744 .31628 .26964 .30738 Mtetra
.633 .709 .901 r
.26964 .30738 .27744 .31628 .28948 .31146 .2816 .30391 Mtetra
.681 .76 .911 r
.2816 .30391 .28948 .31146 .30172 .30455 .29373 .29898 Mtetra
.744 .829 .917 r
.29373 .29898 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.664 .741 .907 r
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40001 .27197 .39262 .26044 Mtetra
.655 .667 .85 r
.39262 .26044 .40001 .27197 .41242 .27183 .40522 .25585 Mtetra
.637 .592 .786 r
.40522 .25585 .41242 .27183 .42498 .27011 .41787 .25123 Mtetra
.627 .556 .755 r
.41787 .25123 .42498 .27011 .43766 .2669 .43059 .24659 Mtetra
.623 .542 .742 r
.43059 .24659 .43766 .2669 .45045 .26229 .44337 .24193 Mtetra
.44337 .24193 .45045 .26229 .46332 .25628 .45621 .23725 Mtetra
.627 .556 .755 r
.45621 .23725 .46332 .25628 .47627 .24877 .4691 .23255 Mtetra
.637 .592 .786 r
.4691 .23255 .47627 .24877 .48928 .23966 .48206 .22782 Mtetra
.655 .667 .85 r
.48206 .22782 .48928 .23966 .50229 .23182 .49509 .22308 Mtetra
.664 .741 .907 r
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.576 .705 .93 r
.57454 .1941 .5815 .20311 .59492 .19824 .58806 .19179 Mtetra
.639 .808 .964 r
.58806 .19179 .59492 .19824 .60848 .19594 .60162 .18739 Mtetra
.691 .765 .908 r
.60162 .18739 .60848 .19594 .62206 .19152 .6152 .1815 Mtetra
.691 .729 .88 r
.6152 .1815 .62206 .19152 .63566 .18553 .62884 .17542 Mtetra
.68 .725 .883 r
.62884 .17542 .63566 .18553 .64931 .17946 .64255 .16972 Mtetra
.671 .731 .895 r
.64255 .16972 .64931 .17946 .66304 .17386 .65634 .16439 Mtetra
.666 .737 .903 r
.65634 .16439 .66304 .17386 .67685 .16861 .6702 .15924 Mtetra
.664 .74 .906 r
.6702 .15924 .67685 .16861 .69074 .16351 .68414 .15414 Mtetra
.664 .741 .907 r
.68414 .15414 .69074 .16351 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13795 .75486 .12835 Mtetra
.75486 .12835 .76122 .13795 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32686 .20241 .31892 Mtetra
.20241 .31892 .21049 .32686 .22225 .32259 .21419 .31461 Mtetra
.663 .74 .907 r
.21419 .31461 .22225 .32259 .23405 .31837 .22603 .31029 Mtetra
.66 .738 .907 r
.22603 .31029 .23405 .31837 .24589 .31433 .23792 .30604 Mtetra
.653 .731 .906 r
.23792 .30604 .24589 .31433 .25775 .31066 .24984 .30198 Mtetra
.641 .718 .904 r
.24984 .30198 .25775 .31066 .26964 .30738 .26179 .29825 Mtetra
.63 .704 .899 r
.26179 .29825 .26964 .30738 .2816 .30391 .27377 .29485 Mtetra
.635 .708 .9 r
.27377 .29485 .2816 .30391 .29373 .29898 .28583 .29128 Mtetra
.672 .756 .914 r
.28583 .29128 .29373 .29898 .30606 .292 .29803 .28659 Mtetra
.735 .835 .926 r
.29803 .28659 .30606 .292 .31826 .28756 .31042 .27989 Mtetra
.683 .762 .911 r
.31042 .27989 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.664 .741 .907 r
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.645 .734 .913 r
.54069 .19486 .5478 .20385 .56114 .19899 .55408 .19055 Mtetra
.585 .726 .94 r
.55408 .19055 .56114 .19899 .57454 .1941 .56756 .18788 Mtetra
.65 .819 .965 r
.56756 .18788 .57454 .1941 .58806 .19179 .58109 .18316 Mtetra
.69 .763 .908 r
.58109 .18316 .58806 .19179 .60162 .18739 .59466 .17729 Mtetra
.689 .728 .88 r
.59466 .17729 .60162 .18739 .6152 .1815 .60828 .17125 Mtetra
.68 .722 .881 r
.60828 .17125 .6152 .1815 .62884 .17542 .62197 .16553 Mtetra
.672 .728 .892 r
.62197 .16553 .62884 .17542 .64255 .16972 .63574 .16015 Mtetra
.667 .735 .901 r
.63574 .16015 .64255 .16972 .65634 .16439 .64958 .15496 Mtetra
.665 .739 .905 r
.64958 .15496 .65634 .16439 .6702 .15924 .6635 .14983 Mtetra
.664 .74 .907 r
.6635 .14983 .6702 .15924 .68414 .15414 .67748 .14469 Mtetra
.664 .741 .907 r
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .21419 .31461 .20607 .30657 Mtetra
.20607 .30657 .21419 .31461 .22603 .31029 .21794 .3022 Mtetra
.663 .74 .907 r
.21794 .3022 .22603 .31029 .23792 .30604 .22987 .29783 Mtetra
.66 .737 .907 r
.22987 .29783 .23792 .30604 .24984 .30198 .24184 .29353 Mtetra
.654 .73 .905 r
.24184 .29353 .24984 .30198 .26179 .29825 .25385 .28939 Mtetra
.643 .717 .902 r
.25385 .28939 .26179 .29825 .27377 .29485 .2659 .28555 Mtetra
.633 .704 .897 r
.2659 .28555 .27377 .29485 .28583 .29128 .27798 .28198 Mtetra
.634 .705 .897 r
.27798 .28198 .28583 .29128 .29803 .28659 .29012 .27836 Mtetra
.657 .741 .912 r
.29012 .27836 .29803 .28659 .31042 .27989 .30238 .27406 Mtetra
.7 .821 .94 r
.30238 .27406 .31042 .27989 .32275 .27479 .31478 .26844 Mtetra
.728 .811 .916 r
.31478 .26844 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.664 .741 .907 r
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.595 .714 .927 r
.52016 .19071 .52738 .19974 .54069 .19486 .53353 .18783 Mtetra
.621 .784 .959 r
.53353 .18783 .54069 .19486 .55408 .19055 .54697 .18397 Mtetra
.669 .815 .953 r
.54697 .18397 .55408 .19055 .56756 .18788 .56047 .17878 Mtetra
.689 .752 .899 r
.56047 .17878 .56756 .18788 .58109 .18316 .57402 .17289 Mtetra
.686 .724 .879 r
.57402 .17289 .58109 .18316 .59466 .17729 .58763 .16693 Mtetra
.678 .72 .881 r
.58763 .16693 .59466 .17729 .60828 .17125 .60131 .16126 Mtetra
.671 .727 .891 r
.60131 .16126 .60828 .17125 .62197 .16553 .61506 .15587 Mtetra
.667 .734 .9 r
.61506 .15587 .62197 .16553 .63574 .16015 .62888 .15065 Mtetra
.665 .738 .905 r
.62888 .15065 .63574 .16015 .64958 .15496 .64277 .14549 Mtetra
.664 .74 .907 r
.64277 .14549 .64958 .15496 .6635 .14983 .65673 .14033 Mtetra
.664 .741 .907 r
.65673 .14033 .6635 .14983 .67748 .14469 .67076 .13516 Mtetra
.67076 .13516 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32883 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .3116 Mtetra
.16249 .3116 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21794 .3022 .20979 .29405 Mtetra
.664 .74 .907 r
.20979 .29405 .21794 .3022 .22987 .29783 .22174 .28962 Mtetra
.663 .74 .907 r
.22174 .28962 .22987 .29783 .24184 .29353 .23376 .2852 Mtetra
.66 .737 .906 r
.23376 .2852 .24184 .29353 .25385 .28939 .24582 .28082 Mtetra
.655 .73 .904 r
.24582 .28082 .25385 .28939 .2659 .28555 .25792 .27658 Mtetra
.647 .718 .9 r
.25792 .27658 .2659 .28555 .27798 .28198 .27006 .27256 Mtetra
.638 .705 .895 r
.27006 .27256 .27798 .28198 .29012 .27836 .28225 .26878 Mtetra
.635 .702 .894 r
.28225 .26878 .29012 .27836 .30238 .27406 .29449 .26506 Mtetra
.645 .72 .903 r
.29449 .26506 .30238 .27406 .31478 .26844 .30681 .26106 Mtetra
.668 .771 .927 r
.30681 .26106 .31478 .26844 .3273 .26185 .31924 .25636 Mtetra
.696 .834 .949 r
.31924 .25636 .3273 .26185 .33974 .25726 .33179 .25075 Mtetra
.721 .81 .92 r
.33179 .25075 .33974 .25726 .35223 .25265 .34443 .24431 Mtetra
.671 .749 .909 r
.34443 .24431 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.664 .741 .907 r
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.657 .738 .91 r
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19169 Mtetra
.603 .724 .93 r
.48628 .19169 .49364 .20049 .50687 .19561 .49953 .18857 Mtetra
.625 .785 .958 r
.49953 .18857 .50687 .19561 .52016 .19071 .51287 .18462 Mtetra
.655 .825 .965 r
.51287 .18462 .52016 .19071 .53353 .18783 .52629 .17975 Mtetra
.683 .776 .922 r
.52629 .17975 .53353 .18783 .54697 .18397 .53976 .17417 Mtetra
.686 .734 .888 r
.53976 .17417 .54697 .18397 .56047 .17878 .5533 .1683 Mtetra
.681 .718 .877 r
.5533 .1683 .56047 .17878 .57402 .17289 .56689 .16248 Mtetra
.675 .718 .882 r
.56689 .16248 .57402 .17289 .58763 .16693 .58055 .1569 Mtetra
.67 .726 .892 r
.58055 .1569 .58763 .16693 .60131 .16126 .59428 .15154 Mtetra
.666 .734 .9 r
.59428 .15154 .60131 .16126 .61506 .15587 .60808 .14631 Mtetra
.665 .738 .905 r
.60808 .14631 .61506 .15587 .62888 .15065 .62195 .14114 Mtetra
.664 .74 .907 r
.62195 .14114 .62888 .15065 .64277 .14549 .63589 .13595 Mtetra
.664 .741 .907 r
.63589 .13595 .64277 .14549 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13516 .66398 .12553 Mtetra
.66398 .12553 .67076 .13516 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10438 Mtetra
.721 .10438 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09364 Mtetra
.10759 .32091 .11606 .32883 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .3116 .15414 .30354 Mtetra
.15414 .30354 .16249 .3116 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22174 .28962 .21355 .28137 Mtetra
.664 .74 .907 r
.21355 .28137 .22174 .28962 .23376 .2852 .22559 .27688 Mtetra
.663 .74 .907 r
.22559 .27688 .23376 .2852 .24582 .28082 .23769 .27239 Mtetra
.661 .737 .906 r
.23769 .27239 .24582 .28082 .25792 .27658 .24985 .26793 Mtetra
.657 .732 .904 r
.24985 .26793 .25792 .27658 .27006 .27256 .26205 .26356 Mtetra
.652 .722 .9 r
.26205 .26356 .27006 .27256 .28225 .26878 .27429 .25934 Mtetra
.645 .71 .895 r
.27429 .25934 .28225 .26878 .29449 .26506 .28658 .2553 Mtetra
.64 .701 .891 r
.28658 .2553 .29449 .26506 .30681 .26106 .29893 .25138 Mtetra
.641 .705 .893 r
.29893 .25138 .30681 .26106 .31924 .25636 .31133 .24742 Mtetra
.649 .727 .906 r
.31133 .24742 .31924 .25636 .33179 .25075 .32382 .24321 Mtetra
.662 .769 .929 r
.32382 .24321 .33179 .25075 .34443 .24431 .33639 .23859 Mtetra
.672 .826 .958 r
.33639 .23859 .34443 .24431 .35703 .23942 .34905 .23355 Mtetra
.684 .826 .952 r
.34905 .23355 .35703 .23942 .36968 .23472 .36178 .2282 Mtetra
.688 .809 .94 r
.36178 .2282 .36968 .23472 .38239 .23001 .37457 .22274 Mtetra
.685 .787 .928 r
.37457 .22274 .38239 .23001 .39516 .22527 .38741 .21735 Mtetra
.676 .768 .92 r
.38741 .21735 .39516 .22527 .40799 .22051 .4003 .21221 Mtetra
.665 .755 .918 r
.4003 .21221 .40799 .22051 .42088 .21573 .41323 .20738 Mtetra
.653 .752 .922 r
.41323 .20738 .42088 .21573 .43384 .21092 .42622 .20288 Mtetra
.644 .758 .932 r
.42622 .20288 .43384 .21092 .44685 .20609 .43926 .19861 Mtetra
.639 .774 .945 r
.43926 .19861 .44685 .20609 .45993 .20124 .45237 .19443 Mtetra
.639 .795 .957 r
.45237 .19443 .45993 .20124 .47307 .19636 .46555 .19014 Mtetra
.647 .816 .965 r
.46555 .19014 .47307 .19636 .48628 .19169 .4788 .18552 Mtetra
.662 .824 .961 r
.4788 .18552 .48628 .19169 .49953 .18857 .49213 .18049 Mtetra
.679 .774 .923 r
.49213 .18049 .49953 .18857 .51287 .18462 .50553 .17504 Mtetra
.682 .738 .893 r
.50553 .17504 .51287 .18462 .52629 .17975 .51898 .16934 Mtetra
.68 .719 .879 r
.51898 .16934 .52629 .17975 .53976 .17417 .5325 .16358 Mtetra
.676 .714 .878 r
.5325 .16358 .53976 .17417 .5533 .1683 .54607 .15794 Mtetra
.671 .719 .885 r
.54607 .15794 .5533 .1683 .56689 .16248 .55972 .15249 Mtetra
.668 .727 .894 r
.55972 .15249 .56689 .16248 .58055 .1569 .57342 .14718 Mtetra
.666 .734 .901 r
.57342 .14718 .58055 .1569 .59428 .15154 .5872 .14195 Mtetra
.664 .738 .905 r
.5872 .14195 .59428 .15154 .60808 .14631 .60105 .13676 Mtetra
.664 .74 .907 r
.60105 .13676 .60808 .14631 .62195 .14114 .61496 .13156 Mtetra
.664 .741 .907 r
.61496 .13156 .62195 .14114 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10438 .71435 .09446 Mtetra
.71435 .09446 .721 .10438 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09364 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27688 .21736 .26852 Mtetra
.21736 .26852 .22559 .27688 .23769 .27239 .22949 .26397 Mtetra
.663 .74 .907 r
.22949 .26397 .23769 .27239 .24985 .26793 .24169 .2594 Mtetra
.662 .738 .906 r
.24169 .2594 .24985 .26793 .26205 .26356 .25393 .25485 Mtetra
.66 .734 .904 r
.25393 .25485 .26205 .26356 .27429 .25934 .26623 .25035 Mtetra
.656 .726 .901 r
.26623 .25035 .27429 .25934 .28658 .2553 .27858 .24592 Mtetra
.651 .716 .896 r
.27858 .24592 .28658 .2553 .29893 .25138 .29098 .24161 Mtetra
.647 .706 .89 r
.29098 .24161 .29893 .25138 .31133 .24742 .30343 .23741 Mtetra
.645 .701 .887 r
.30343 .23741 .31133 .24742 .32382 .24321 .31594 .23324 Mtetra
.645 .703 .889 r
.31594 .23324 .32382 .24321 .33639 .23859 .32852 .22904 Mtetra
.649 .716 .896 r
.32852 .22904 .33639 .23859 .34905 .23355 .34116 .2247 Mtetra
.655 .736 .909 r
.34116 .2247 .34905 .23355 .36178 .2282 .35388 .22021 Mtetra
.66 .761 .925 r
.35388 .22021 .36178 .2282 .37457 .22274 .36667 .21555 Mtetra
.663 .786 .94 r
.36667 .21555 .37457 .22274 .38741 .21735 .37953 .21077 Mtetra
.662 .805 .951 r
.37953 .21077 .38741 .21735 .4003 .21221 .39245 .20594 Mtetra
.661 .815 .957 r
.39245 .20594 .4003 .21221 .41323 .20738 .40543 .20107 Mtetra
.40543 .20107 .41323 .20738 .42622 .20288 .41848 .19617 Mtetra
.664 .805 .951 r
.41848 .19617 .42622 .20288 .43926 .19861 .43159 .19121 Mtetra
.669 .788 .937 r
.43159 .19121 .43926 .19861 .45237 .19443 .44477 .18614 Mtetra
.673 .765 .92 r
.44477 .18614 .45237 .19443 .46555 .19014 .45801 .1809 Mtetra
.676 .743 .901 r
.45801 .1809 .46555 .19014 .4788 .18552 .47132 .17549 Mtetra
.676 .725 .886 r
.47132 .17549 .4788 .18552 .49213 .18049 .48469 .16995 Mtetra
.675 .714 .878 r
.48469 .16995 .49213 .18049 .50553 .17504 .49812 .16436 Mtetra
.673 .711 .877 r
.49812 .16436 .50553 .17504 .51898 .16934 .51161 .15882 Mtetra
.67 .715 .882 r
.51161 .15882 .51898 .16934 .5325 .16358 .52517 .15337 Mtetra
.668 .722 .89 r
.52517 .15337 .5325 .16358 .54607 .15794 .53879 .14804 Mtetra
.666 .73 .897 r
.53879 .14804 .54607 .15794 .55972 .15249 .55248 .14278 Mtetra
.665 .735 .902 r
.55248 .14278 .55972 .15249 .57342 .14718 .56623 .13757 Mtetra
.664 .739 .905 r
.56623 .13757 .57342 .14718 .5872 .14195 .58006 .13236 Mtetra
.664 .74 .907 r
.58006 .13236 .5872 .14195 .60105 .13676 .59395 .12714 Mtetra
.664 .741 .907 r
.59395 .12714 .60105 .13676 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26852 .20905 .26009 Mtetra
.20905 .26009 .21736 .26852 .22949 .26397 .22122 .25549 Mtetra
.22122 .25549 .22949 .26397 .24169 .2594 .23345 .25088 Mtetra
.664 .74 .907 r
.23345 .25088 .24169 .2594 .25393 .25485 .24573 .24625 Mtetra
.663 .739 .907 r
.24573 .24625 .25393 .25485 .26623 .25035 .25807 .24161 Mtetra
.662 .736 .905 r
.25807 .24161 .26623 .25035 .27858 .24592 .27047 .23699 Mtetra
.66 .732 .903 r
.27047 .23699 .27858 .24592 .29098 .24161 .28292 .23239 Mtetra
.657 .725 .899 r
.28292 .23239 .29098 .24161 .30343 .23741 .29543 .22783 Mtetra
.655 .717 .894 r
.29543 .22783 .30343 .23741 .31594 .23324 .30799 .22333 Mtetra
.652 .709 .889 r
.30799 .22333 .31594 .23324 .32852 .22904 .32061 .21886 Mtetra
.651 .703 .885 r
.32061 .21886 .32852 .22904 .34116 .2247 .33329 .21439 Mtetra
.651 .701 .883 r
.33329 .21439 .34116 .2247 .35388 .22021 .34604 .20987 Mtetra
.653 .702 .883 r
.34604 .20987 .35388 .22021 .36667 .21555 .35885 .20528 Mtetra
.655 .706 .884 r
.35885 .20528 .36667 .21555 .37953 .21077 .37174 .20059 Mtetra
.658 .71 .886 r
.37174 .20059 .37953 .21077 .39245 .20594 .38469 .1958 Mtetra
.661 .713 .886 r
.38469 .1958 .39245 .20594 .40543 .20107 .3977 .19089 Mtetra
.663 .714 .885 r
.3977 .19089 .40543 .20107 .41848 .19617 .41079 .18586 Mtetra
.666 .712 .883 r
.41079 .18586 .41848 .19617 .43159 .19121 .42394 .18073 Mtetra
.667 .71 .88 r
.42394 .18073 .43159 .19121 .44477 .18614 .43716 .17549 Mtetra
.668 .708 .877 r
.43716 .17549 .44477 .18614 .45801 .1809 .45043 .17018 Mtetra
.669 .708 .877 r
.45043 .17018 .45801 .1809 .47132 .17549 .46378 .16482 Mtetra
.668 .709 .879 r
.46378 .16482 .47132 .17549 .48469 .16995 .47718 .15946 Mtetra
.668 .714 .883 r
.47718 .15946 .48469 .16995 .49812 .16436 .49065 .15412 Mtetra
.667 .721 .889 r
.49065 .15412 .49812 .16436 .51161 .15882 .50418 .14884 Mtetra
.666 .728 .896 r
.50418 .14884 .51161 .15882 .52517 .15337 .51778 .1436 Mtetra
.665 .733 .901 r
.51778 .1436 .52517 .15337 .53879 .14804 .53144 .13838 Mtetra
.664 .737 .904 r
.53144 .13838 .53879 .14804 .55248 .14278 .54517 .13317 Mtetra
.664 .739 .906 r
.54517 .13317 .55248 .14278 .56623 .13757 .55897 .12795 Mtetra
.664 .74 .907 r
.55897 .12795 .56623 .13757 .58006 .13236 .57284 .12271 Mtetra
.664 .741 .907 r
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25088 .22514 .24229 Mtetra
.22514 .24229 .23345 .25088 .24573 .24625 .23745 .23762 Mtetra
.664 .74 .907 r
.23745 .23762 .24573 .24625 .25807 .24161 .24983 .23292 Mtetra
.24983 .23292 .25807 .24161 .27047 .23699 .26227 .2282 Mtetra
.663 .739 .906 r
.26227 .2282 .27047 .23699 .28292 .23239 .27476 .22348 Mtetra
.662 .736 .905 r
.27476 .22348 .28292 .23239 .29543 .22783 .28731 .21875 Mtetra
.661 .733 .902 r
.28731 .21875 .29543 .22783 .30799 .22333 .29992 .21402 Mtetra
.66 .728 .899 r
.29992 .21402 .30799 .22333 .32061 .21886 .31259 .2093 Mtetra
.659 .722 .896 r
.31259 .2093 .32061 .21886 .33329 .21439 .32532 .20457 Mtetra
.658 .717 .892 r
.32532 .20457 .33329 .21439 .34604 .20987 .33811 .19983 Mtetra
.658 .713 .888 r
.33811 .19983 .34604 .20987 .35885 .20528 .35097 .19506 Mtetra
.658 .71 .886 r
.35097 .19506 .35885 .20528 .37174 .20059 .36389 .19024 Mtetra
.659 .708 .884 r
.36389 .19024 .37174 .20059 .38469 .1958 .37687 .18535 Mtetra
.66 .707 .882 r
.37687 .18535 .38469 .1958 .3977 .19089 .38992 .18039 Mtetra
.662 .708 .882 r
.38992 .18039 .3977 .19089 .41079 .18586 .40304 .17537 Mtetra
.663 .709 .882 r
.40304 .17537 .41079 .18586 .42394 .18073 .41622 .17027 Mtetra
.664 .712 .884 r
.41622 .17027 .42394 .18073 .43716 .17549 .42947 .16513 Mtetra
.664 .715 .886 r
.42947 .16513 .43716 .17549 .45043 .17018 .44278 .15996 Mtetra
.665 .719 .889 r
.44278 .15996 .45043 .17018 .46378 .16482 .45616 .15476 Mtetra
.665 .724 .894 r
.45616 .15476 .46378 .16482 .47718 .15946 .4696 .14957 Mtetra
.665 .729 .898 r
.4696 .14957 .47718 .15946 .49065 .15412 .48311 .14437 Mtetra
.664 .734 .901 r
.48311 .14437 .49065 .15412 .50418 .14884 .49668 .13918 Mtetra
.664 .737 .904 r
.49668 .13918 .50418 .14884 .51778 .1436 .51032 .13397 Mtetra
.664 .739 .906 r
.51032 .13397 .51778 .1436 .53144 .13838 .52403 .12876 Mtetra
.664 .74 .907 r
.52403 .12876 .53144 .13838 .54517 .13317 .5378 .12352 Mtetra
.664 .741 .907 r
.5378 .12352 .54517 .13317 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23762 .2291 .22892 Mtetra
.2291 .22892 .23745 .23762 .24983 .23292 .24152 .22417 Mtetra
.24152 .22417 .24983 .23292 .26227 .2282 .25399 .21941 Mtetra
.664 .74 .907 r
.25399 .21941 .26227 .2282 .27476 .22348 .26652 .21462 Mtetra
.26652 .21462 .27476 .22348 .28731 .21875 .27911 .20982 Mtetra
.663 .739 .906 r
.27911 .20982 .28731 .21875 .29992 .21402 .29176 .205 Mtetra
.663 .738 .905 r
.29176 .205 .29992 .21402 .31259 .2093 .30447 .20016 Mtetra
.663 .736 .904 r
.30447 .20016 .31259 .2093 .32532 .20457 .31724 .1953 Mtetra
.662 .733 .902 r
.31724 .1953 .32532 .20457 .33811 .19983 .33007 .19042 Mtetra
.662 .731 .901 r
.33007 .19042 .33811 .19983 .35097 .19506 .34297 .18552 Mtetra
.662 .729 .899 r
.34297 .18552 .35097 .19506 .36389 .19024 .35593 .18059 Mtetra
.662 .728 .898 r
.35593 .18059 .36389 .19024 .37687 .18535 .36895 .17562 Mtetra
.663 .727 .897 r
.36895 .17562 .37687 .18535 .38992 .18039 .38204 .17062 Mtetra
.38204 .17062 .38992 .18039 .40304 .17537 .3952 .16558 Mtetra
.663 .728 .897 r
.3952 .16558 .40304 .17537 .41622 .17027 .40841 .16051 Mtetra
.664 .729 .899 r
.40841 .16051 .41622 .17027 .42947 .16513 .4217 .15541 Mtetra
.664 .732 .9 r
.4217 .15541 .42947 .16513 .44278 .15996 .43505 .15028 Mtetra
.664 .734 .902 r
.43505 .15028 .44278 .15996 .45616 .15476 .44846 .14513 Mtetra
.664 .736 .904 r
.44846 .14513 .45616 .15476 .4696 .14957 .46194 .13996 Mtetra
.664 .738 .905 r
.46194 .13996 .4696 .14957 .48311 .14437 .47549 .13477 Mtetra
.664 .739 .906 r
.47549 .13477 .48311 .14437 .49668 .13918 .48911 .12956 Mtetra
.664 .74 .907 r
.48911 .12956 .49668 .13918 .51032 .13397 .50279 .12432 Mtetra
.50279 .12432 .51032 .13397 .52403 .12876 .51654 .11907 Mtetra
.664 .741 .907 r
.51654 .11907 .52403 .12876 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26677 Mtetra
.09942 .26677 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .22491 Mtetra
.20829 .22491 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20982 .27082 .20087 Mtetra
.664 .74 .907 r
.27082 .20087 .27911 .20982 .29176 .205 .28351 .19599 Mtetra
.28351 .19599 .29176 .205 .30447 .20016 .29626 .19109 Mtetra
.29626 .19109 .30447 .20016 .31724 .1953 .30907 .18617 Mtetra
.664 .739 .906 r
.30907 .18617 .31724 .1953 .33007 .19042 .32194 .18122 Mtetra
.32194 .18122 .33007 .19042 .34297 .18552 .33488 .17625 Mtetra
.664 .738 .905 r
.33488 .17625 .34297 .18552 .35593 .18059 .34788 .17126 Mtetra
.34788 .17126 .35593 .18059 .36895 .17562 .36094 .16624 Mtetra
.36094 .16624 .36895 .17562 .38204 .17062 .37407 .16119 Mtetra
.37407 .16119 .38204 .17062 .3952 .16558 .38726 .15612 Mtetra
.38726 .15612 .3952 .16558 .40841 .16051 .40052 .15102 Mtetra
.40052 .15102 .40841 .16051 .4217 .15541 .41385 .14589 Mtetra
.664 .739 .906 r
.41385 .14589 .4217 .15541 .43505 .15028 .42723 .14074 Mtetra
.664 .74 .906 r
.42723 .14074 .43505 .15028 .44846 .14513 .44069 .13556 Mtetra
.664 .74 .907 r
.44069 .13556 .44846 .14513 .46194 .13996 .45421 .13036 Mtetra
.45421 .13036 .46194 .13996 .47549 .13477 .46781 .12513 Mtetra
.664 .741 .907 r
.46781 .12513 .47549 .13477 .48911 .12956 .48147 .11988 Mtetra
.48147 .11988 .48911 .12956 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .1093 Mtetra
.50899 .1093 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .09861 Mtetra
.5368 .09861 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .26291 Mtetra
.07875 .26291 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .22491 .19976 .21609 Mtetra
.19976 .21609 .20829 .22491 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20087 .26247 .19184 Mtetra
.26247 .19184 .27082 .20087 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19109 .28798 .18198 Mtetra
.28798 .18198 .29626 .19109 .30907 .18617 .30083 .177 Mtetra
.664 .74 .907 r
.30083 .177 .30907 .18617 .32194 .18122 .31374 .17201 Mtetra
.664 .741 .907 r
.31374 .17201 .32194 .18122 .33488 .17625 .32671 .16699 Mtetra
.664 .74 .907 r
.32671 .16699 .33488 .17625 .34788 .17126 .33975 .16195 Mtetra
.33975 .16195 .34788 .17126 .36094 .16624 .35285 .15688 Mtetra
.35285 .15688 .36094 .16624 .37407 .16119 .36602 .15179 Mtetra
.36602 .15179 .37407 .16119 .38726 .15612 .37925 .14667 Mtetra
.37925 .14667 .38726 .15612 .40052 .15102 .39255 .14152 Mtetra
.39255 .14152 .40052 .15102 .41385 .14589 .40592 .13636 Mtetra
.664 .741 .907 r
.40592 .13636 .41385 .14589 .42723 .14074 .41935 .13116 Mtetra
.664 .74 .907 r
.41935 .13116 .42723 .14074 .44069 .13556 .43285 .12594 Mtetra
.664 .741 .907 r
.43285 .12594 .44069 .13556 .45421 .13036 .44641 .12069 Mtetra
.44641 .12069 .45421 .13036 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .1093 .50137 .09943 Mtetra
.50137 .09943 .50899 .1093 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .09861 .52926 .08864 Mtetra
.52926 .08864 .5368 .09861 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .033 Mtetra
.67312 .033 .68016 .04348 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .26291 .06982 .25443 Mtetra
.06982 .25443 .07875 .26291 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .1926 Mtetra
.2287 .1926 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18198 .27962 .17278 Mtetra
.27962 .17278 .28798 .18198 .30083 .177 .29251 .16777 Mtetra
.29251 .16777 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15179 .3579 .14231 Mtetra
.3579 .14231 .36602 .15179 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13636 .39792 .12674 Mtetra
.39792 .12674 .40592 .13636 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12594 .42493 .11623 Mtetra
.42493 .11623 .43285 .12594 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08948 Mtetra
.49367 .08948 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .033 .66602 .0224 Mtetra
.66602 .0224 .67312 .033 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16777 .28411 .15844 Mtetra
.28411 .15844 .29251 .16777 .30546 .16272 .2971 .15336 Mtetra
.2971 .15336 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13795 Mtetra
.33645 .13795 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12755 Mtetra
.36301 .12755 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08948 .4859 .07942 Mtetra
.4859 .07942 .49367 .08948 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
G02Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000005h0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX
0000002Y_NP0GP2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@0
07Boo`3oool0@@3oool008/0oooo0`00001S0:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000?oo
o`3oool03@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`800000<02Y_NP3
0:Vmi`L0ZKgX0`2Y_NLY0:Vmj0030000002Y_NP0ZKgX01D0ZKgX00<000000?ooo`3oool0D03oool0
08H0oooo0`00000U0:Vmj0H0ZKgW1@2Y_NP60:Vmi`@0ZKgX1P2Y_NL30:Vmj0<0ZKgW8P2Y_NP00`00
0000ZKgX0:Vmj00E0:Vmj0030?ooo`000000oooo0500oooo00240?ooo`<000006`2Y_NP30:Vmi`L0
ZKgX0`2Y_>L60:Vmi`D0ZKcW1@2Y_NL50:Vli``0ZKgW8@2Y_NP00`000000ZKgX0:Vmj00F0:Vmj003
0000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX0:Vmj00E0:Vmj0L0ZKgW
102Y_NP60:Vli`<0ZKgW0`2Y^nH50:Vli`80ZKgW0`2Z^nH50:Vli`<0ZKgW0`2Z_>H50:Vmi`D0ZKcW
702Y_NP00`000000ZKgX0:Vmj00G0:Vmj0030000003oool0oooo04h0oooo001o0?ooo`800000702Y
_NP90:Vmi`X0ZKcW1`2Y^nH40:Vli`H0Z[_V102Y_>L70:ZliP80ZKgW0`2Z^nH50:Vli`<0ZKgX0`2Z
_>LE0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00000L
0:Vmj0T0ZKgW0`2Y^nH70:Vli`<0Z[[U1P2Y^nH50:Zji@D0Z[_V1@2Z^^D60:ZliPH0Z[_V102Y_>L7
0:Zli`80ZKgX0`2Z_>L?0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool0
04/0oooo00D0a5lD000000000000000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP0602Y_NP6
0:Vli`D0ZKgW1P2Y^nH40:Vli`H0Z[[U0`2Y^nH30:Zhh`D0Z[[U0P2Z^nH30:^hh`D0Z[[U0`2Z_>H3
0:^ji0X0Z[_V302Z_>L>0:Vmj0030000002Y_NP0ZKgX01T0ZKgX00<000000?ooo`3oool0C03oool0
04X0oooo00L0ohle000DG`34ool0oooo0?ooa01O53D0Sooo02H0oooo0P00000L0:Vmj0T0ZKcW2P2Y
^nH50:Zii0H0Z[[U1P2Z^><40:Zji@H0ZkSS1@2Z^^D60:^ji080Z[_V0`2[^N@50:ZkiP<0Z[cW0`2Z
^nH50:Zli`D0Z[gW2P2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0030000003oool0oooo04`0oooo001?
0?ooo`0308le000eSol0oooo0280oooo0`00000L0:Vmj0T0ZKcW0`2Y^^H70:VkiP<0Z[SS1@2Z^N@3
0:Zji@<0ZkKR1@2Z^><50:^gh@H0ZkSS1@2[^>850:^ji0H0ZkWT2`2Z^nH20:Zli`<0Z[cV1@2Z_NL2
0:Vmj0<0ZKgW102Y_NP00`000000ZKgX0:Vmj00I0:Vmj0030000003oool0oooo04/0oooo00120?oo
o`030?o4G`0D0000000000<0000000<0000e08ooo`3oool0103oool00`2?=@00=Hoo0?ooo`0P0?oo
o`8000006`2Y_NP;0:Vli`H0ZK[V102Y^nH60:Zhh`D0Z[WT1P2[]^820:Zhh`<0[;KP1@2[]n430:^h
h`<0[KKP1@2[^>820:^ji0<0[;OQ1@2[^N@60:^ji0D0Z[_V1P2Z_>H40:Zmi`H0ZKgW0`2Y_NP00`00
0000ZKgX0:Vmj00J0:Vmj0030000003oool0oooo04X0oooo001:0?ooo`070?o4G`0D01@0GlCo0?oo
o`3ool@0Ga@D05o4o`0N0?ooo`<0000000<0ZKgX0000002Y_NP0602Y_NP90:Vli`D0ZK[U1@2Y^^H5
0:VghPH0Z[SS1@2[]N450:^fhPD0[;KP1@2[]n470:ffh0@0ZkSR1P2/]n420:^ii0<0[KSQ1P2[^^@5
0:bji0D0Z[cV1@2Z_>L50:Vmi`<0ZKgX00<000000:Vmj02Y_NP06P2Y_NP00`000000oooo0?ooo`1:
0?ooo`00BP3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01X0oooo00<0ZKgX0000
00000000702Y_NP90:Vli`P0ZK[U0P2Y^^H30:VfhPD0ZKOR0`2Z^><30:^eh0D0ZkGQ0P2[]^880:bf
h080ZkOQ0`2^^>460:ffh0D0[[OP1@2/]n460:fhh@<0Zk[T0`2^^>450:bji080Z[cV0`2[^nD:0:Zl
i`80ZKgX00<000000:Vmj02Y_NP06`2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0
Ga@D05o4o`0M0?ooo`<000006P2Y_NP;0:Vli`X0ZK[U1P2Y]^840:VghPL0ZkGP102[]N4:0:bfh0H0
[[SQ0`2]]^030:nkh`D0[[OP0P2/]n430:nih@D0[KSQ1`2^^>440:bji0H0Zk_U0P2Z_>L30:^ki@D0
Z[cW00<0ZKgX0000002Y_NP00`2Z_NLJ0:Vmj0030000003oool0oooo04P0oooo001;0?ooo`0308le
000eSol0oooo01X0oooo0P00000K0:Vmj0/0ZKcW202Y^^D50:Veh@D0ZKKR2`2[]N050:fihPD0[;KP
1@2^_>@60:jhh@H0[k_S102^]n060:nih@80[KSQ0`2`^^460:jhh@D0[[WR2`2[^nD40:Zli`030:Zm
i`000000Z[gW00@0Z[gW6@2Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@000000000
00000000000e08oooa<0oooo00@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0:Vmj00F0:Vm
j0/0ZKcW202Y^^D80:Veh@80ZKKR0`2Z]N480:^eh0<0[KkV1@2]^N820:bfh0<0[LK/1@2^_>@30:jh
h@<0[/K/1@2_^n<50;30iPD0[kWQ1P2`^^430:jhh@<0/;[Q1@2^^N820:^ki@<0[K[S1@2[^nD50:^l
iP030000002Z_NL0Z[gW00<0Z[gW6P2Y_NP00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP0
00000000000J0:Vmj0D0ZKgW1P2Y_>L:0:Vji@X0ZKGQ1P2Z]N450:^eh0D0[KkV1@2]^N860:g6k0D0
[[cT1P2^a^`20:nkh`<0Zm3c1@2``>H20:nih@<0/<?X2`2`^^450:jihPH0[K[S0P2[^nD30:fki0@0
ZkcV00<000000:Zmi`2Z_NL0102Z_NLJ0:Vmj0030000003oool0oooo04H0oooo001O0?ooo`@00000
6`2Y_NP70:Vmi`<0ZKcW0`2Y^^H50:Vji@D0Z;CQ1`2Y]N430:ZfhPH0Z[GQ0P2[]N030:c3j`D0[KkV
0P2]^N830:WBmPD0[LK/1P2WdoL50:k6k0H0Zm3c102``>H60;33j0<0/;[Q0`2``nP50;2jh@80[[WR
0`2`^^450:fjh`H0[K_T0P2[_>H00`2/_>D000000:bli@060:Zmi`80ZKgX0`2Z_NLD0:Vmj0030000
003oool0oooo04H0oooo001M0?ooo`040:Vmj00000000000000001/0ZKgX2P2Y_NL60:VjiP80ZK[U
0`2X]N850:Rdh@@0ZKGQ1P2Z]^850:Zeh@H0[<?[102]_^H60:WBmPH0WlSe1@2WdoL509k8m@D0Zm3c
1@2VdOL<0;33j0X0/;[Q0P2]^^<30;2jh@D0[K_T0`2/_>D00`000000[;cU0:bli@0;0:Zmia@0ZKgX
00<000000?ooo`3oool0A@3oool005/0oooo0`00000O0:Vmj0D0ZKgW1@2Y^nH50:VjiPD0Z;GR1@2X
]>450:VfhPH0Z[KR1@2[bNl50:c3j`H0YM3g1@2J^Nh609o8m@D0V;K]1@2Nb?D509Fil0D0Y]7g1@2S
c_H60;33j0D0/L;V2`2`^^420:fki0<0[k_R0P2/_>D00`000000[;cU0:bli@060:^liPD0Z[gW502Y
_NP00`3oool000000?ooo`150?ooo`00F03oool3000002<0ZKgX0P2Y_NL80:VkiPX0Z;GR0P2X]>48
0:VfhP<0Z[KR0`2Yc_<50:_9k`D0Xl_d0`2Ud?L30:Rlj0D0V[W^0`2Ob?D30:Vmj0D0V;K]1@2U^nT5
09Fil0D0TkC^1@2Sc_H30;33j0<0Y<of1@2a`^H20;2jh@<0/[oT1@2`^^460:nkhP030:bli@000000
[K_T0080[K_T1P2[_>H50:Zmia@0ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX0000
000000009P2Y_NP80:VkiP<0Z;KS2@2X]N8;0:VfhPH0ZLkc0P2[bNl30:?6l@D0Xl_d1P2X_>P509Zi
kPH0ZKgX0P2H]^d30:Vmj0D0YK_Y0P2E^O030:Vmj0D0TkC^102Sc_H70:C?mP@0/L;V1P2b_n@20;2j
h@<0/[gR1@2_^n800`2]^n@000000:fki0030:fki0D0ZkcV1P2Z_NLD0:Vmj0030000003oool0oooo
04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y_NP08@2Y_NP50:Vli`D0ZK_V1P2X]^<90:RehPH0
ZKKR1@2Yd?@50:W>l`H0XlKa1@2Y_NP60:Rlj100ZKgX102U^nT60:Vmj080TkC^0`2Y_NP509>dkPD0
Y<of1@2XcO<50;:oi0H0/[gR0P2_^n830;6lhP030000002]^n@0[K_T0080[K_T1P2/_>H50:ZmiaD0
ZKgX00<000000?ooo`3oool0@P3oool00540oooo0P00000S0:Vmj0X0ZKcW1@2X]n@60:Rfh`80Z;GR
0`2W]>840:RehP<0ZKKR202Yd?@50:C2kP<0XlKa202Y_NP30:Rlj280ZKgX1@2C]>h5096ckPD0Z<gc
1@2^an`50;:mhPD0/KcR00<000000:fki02]^n@00`2__><50:bliPH0Z[gW502Y_NP00`000000oooo
0?ooo`120?ooo`00CP3oool3000002<0ZKgX0`2Y_NL80:Vli`80Z;SU1@2X]n@50:Rfh`H0YkCR102X
]N860:W@m0D0Yl3/1@2T`^he0:Vmj0D0TK?^1@2C^?450:k7k080/[gR0`2b`ND40;6lhP030000002_
_><0[kcS00@0[kcS0P2/_>H30:fli@D0Z[gW1P2Z_NP?0:Vmj0030000003oool0oooo0440oooo000I
0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`800000902Y
_NP60:Vmi`D0ZKcW1@2X^>D50:Rgi0D0Yk?R1@2W]>850:W>l`<0ZM3d0`2Z`N/50:O0k3X0ZKgX1@2U
^nT509>hl@@0[/O/1P2b`ND20;6lhP030;>nhP000000/kkR00D0[kcS1P2]_>D20:Zmi`<0ZkgW1P2Z
_NP?0:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0Ga@0
01AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX0280ZKgX1P2Y_NL50:Rj
iPD0Z;SU1@2V/n850:NchP80YkCR0`2YbO050:W>l`H0Z/7[0P2W`>`m0:Vmj0D0YK_Y102C^?4509k8
m@D0//7U0`2c_^800`000000/kkR0;>nhP020:nlh`<0/KgR1@2]_>D60:^mi`D0Z[gX3`2Y_NP00`00
0000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool001T0oooo00/0omnL04P0
M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`030:Vmj0000000000002/0
ZKgX0`2Y_NL30:VkiPD0Z;[V0P2X^>D80:JchP@0Yk?R1P2YbO060:g4j`@0Z/7[@02Y_NP40:Fkj@D0
V;K/1@2Nb?D50:g5k0<0/kkR00<000000;>nhP2a_N801@2a_N820:fli@<0[[gT1@2[_NL60:Zmi`l0
ZKgX00<000000?ooo`3oool0203oool01P3ooml0W4P004RLg`3oool0gia8001d_c40oooo000=0?oo
o`030?oOW0180000000000<0000000<0001d0;ooo`3oool00`3oool02`3ogi`0B01d0;ooo`3oool0
omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo0`00000^0:Vmj0H0ZK_V102X^^H:0:JchPD0
Z<;/0`2YbO030:o9k@H0[LC[B02Y_NP509Rfk0D0Sk;^1@2]aN`20;>nhP030000002b`>@0//3T00D0
/KgR1P2^_N@20:^mi`<0[;gV1@2Z_NL?0:Vmj0030000003oool0oooo00P0oooo00L0oono07@0M02o
ool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Co
o`3oool0oon?03D0501Oa?l07P3oool3000002`0ZKgX1@2Y_>L50:VkiPD0Y[GS1@2V/n850:Nlj0D0
Z<;/1P2_bNd30:g4je00ZKgX1@2?/^h40:g5k080//3T00@000000;;0i02b`>@0//3T0P2a_N830;>n
hPD0[[gT1P2/_NH50:Zmi`l0ZKgX00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3o
ohl0=@0D05o4o`0K0?ooo`<00000;@2Y_NP30:Vmi`D0ZKcW1@2W]n@50:Jeh`80Y[?R0`2V]nD50:Nl
j0<0Z<;/0`2`co050:o9kAX0ZKgX1@2WZ]T50:Vmj0D0Y9c=1@2Y_NP50:Rbh200ZKgX102?/^h509o7
m0030;;0i0000000//3T0080//3T1P2c_^850;2ni0D0[;gV1P2Z_NL?0:Vmj0030000003oool0oooo
00H0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0
W;nL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`800000;P2Y_NP6
0:Vmi`<0ZKcW0P2X^NH50:Ngi0@0Y[GS1P2V]nD50:Nlj0H0/<o`702Y_NP30:>Gb@D0Yj[I0P2Y_NP3
09j7^`D0Y9c=1@2OR[d50:Rbh0D0Yj[I6P2Y_NP509Vfk0D0WlOd00<000000;32i`2``^L00P2``^L3
0;>nhP<0/koS1@2`_^@50:bmiPD0Z[gW3`2Y_NP00`000000oooo0?ooo`060?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`0`0?ooo`00603oool02`3o_g@000000000M02oool0oooo0?oog`1O
5000=Hoo0?ooo`34Ga@003F?01L0oooo0`00000b0:Vmj0D0ZKgW1@2X^NH50:Ngi0@0YK?S1P2V]nD6
0:oClah0ZKgX1@2SUlT50:NZf@D0WXNk102TW<d20;:C]PD0WhZm0P2X/^030:B;^PD0Yj[I1P2X/]lD
0:Vmj0D0VKK/102@]>l00`000000/<;W0;32i`030;32i`H0/koS0P2`_^@30;6ni0D0[;gV1@2Z_NL?
0:Vmj0030000003oool0oooo00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo
000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D0?ooo`<00000
00<0ZKgX0000002Y_NP0<`2Y_NP50:Rki`D0Z;WV2@2U/n<30:Jgi@<0[=?e0`2_do<L0:Vmj0D0X8k1
1@2SUlT20:NZf@<0YhVe1@2NQk/20:BLc@<0/Y>f1@2OR[d60:B;^P<0Yj[I0P2[T[`60:Rbga@0ZKgX
1@2X_>P3092dk`040000002@]>l0/<;W0;32i`<0Z/;[1@2c_n<60;6ni0@0[;gV1P2Z_NL?0:Vmj003
0000003oool0oooo00@0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y
_NP000000000000g0:Vmj0<0ZKcW1@2X^nL20:RiiP<0YKCS2@2U/n<60:cCmA`0ZKgX0`2OR[d40:2>
`@D0XiO91@2WRKD509j7^`030:BLc@2bTkH0/Y>f0080/Y>f1@2OR[d00`31X;L0Y8^j0:B;^P040:B;
^P030:NZf@2[T[`0Zi:l0080Zi:l1@2X/]lE0:Vmj0D0Z;cX0P2@]>l00`000000T;C_0:[2j`050:[2
j`80/koS0`2c`><50;6ni0D0[KkV1@2Z_NL?0:Vmj0030000003oool0oooo00D0oooo00D0oono07@0
0000000004RL0=ooo`0a0?ooo`00<P3oool3000003L0ZKgX1P2Y_>L40:Rki`H0YKCS102U/n<60:W4
k@D0ZkoX6@2Y_NP509n:_@D0X8k10`2SUlT20:f?]`@0YhVe1@2NQk/60;:C]P<0WhZm0P31X;L60:B;
^PH0Zi:l0P2X/]l30:NB_aD0ZKgX0P2X_>P30:Vmj004096ckP000000TK?^096ckPD0Z/;[1P2c`><2
0;6ni0<0/[oT1@2]_^H50:Zmi`l0ZKgX00<000000?ooo`3oool0>P3oool00300oooo0P0000000`2Y
_NP000000:Vmj00i0:Vmj0@0ZKcW1@2V]nD50:Fdh`D0Y[[W0`2Ya>d30;S?j`D0ZkoX502Y_NP909n:
_@D0X8k10P2SUlT30:f?]`D0YhVe0`2NQk/20;VK^PD0/Y>f0P2OR[d40<6P]`D0Y8^j00<0ajJh0:^B
_02[T[`00`2[T[`60:NB_`D0Y9c=502Y_NP2000000<0TK?^1@2S`>h50;?0h`H0/[oT1@2]_^H50:Zm
i`l0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo00@0ZKgX0000000000000000?`2Y_NP40:Ni
iPD0Y[OU0P2U]><30:Bdi0D0Y[[W1P2hcn/40:^oj1<0ZKgX0P2PS/4909n:_@@0X8k11@2]SkL50:N9
]@80WXNk0`2iVkX50;:C]P0309n:_@31X;L0`J2g00<0`J2g102TRkX20<NV^0D0Zi:l00<0c:Zh0:NB
_`2WT[l00`2WT[l00`3:Z[T0Y9c=0:BLc@030:BLcA00ZKgX0`0000000`2Y_NP0UkG]0000000309Ne
k@D0Xl3^0P2c`><30;?1i0D0/[oT1P2]_^H20:Zmi`<0ZkgW3P2Y_NP00`000000oooo0?ooo`0i0?oo
o`00:`3oool200000400ZKgX0`2X^nL40:NiiP@0Y[OU1P2T]>@30:Jji`<0/]Gb1@2hcn/D0:Vmj0@0
X8k12@2OR[d20:2>`@<0ZHnj1@2]SkL40:N9]@D0^I^j1@2bTkH70<6P]`80Y8^j0`37Y[P40:^B_080
c:Zh102WT[l20<ZZ^@@0Y9c=0P2lY<8<0:Vmj0<000001@2Y_NP00`000000UkG]09Nek@0209Nek@@0
Xl3^1P2c`N@20;:oi0<0//3T1@2]_^H50:^mi`l0ZKgX00<000000?ooo`3oool0>03oool002T0oooo
0P0000100:Vmj0H0Z;_W102W^NH50:>ci0D0Y;CT1P2beO8D0:Vmj0D0XiO9102PS/4809n:_@D0ZHnj
1@2]SkL30:N9]@80]j721@2iVkX30;:C]P80`:S11P31X;L00`2TRkX0ajJh0<NV^0030<NV^080Zi:l
103<Z[P20:NB_`@0bZZi0P2TW<d40;bT`PP0ZKgX0`0000090:Vmj0040000002G]Nd0UkG]09Nek@D0
Vkc_1@2c`N@50;;0i0H0[[oV102[_NL@0:Vmj0030000003oool0oooo03L0oooo000M0?ooo`050?oo
_`1d000000000018W03Oool01`3oool2000003`0ZKgX1@2Y_>L50:Rki`D0YKGU1@2S/n@50:_5k@<0
/]Gb4P2Y_NP50:NZf@@0XiO9102PS/4609n:_@<0Y8jm102YSkX50:f?]`80YhVe0`2gXL850;VK^P80
/Y>f1030Z<450<6P]`H0ajJh00<0Zi:l0<bZ^03<Z[P00`3<Z[P00`2WT[l0bZZi0<ZZ^@030<ZZ^@03
0:BLc@2lY<80_:C200<0_:C21@2WZ]T00`2Y_NP000000000000<0:Vmj00309fhj`000000WKS[0080
WKS[1@2K_>l50;;1i@80//3T0`2c`N@50:joiPD0ZkkW3`2Y_NP00`000000oooo0?ooo`0g0?ooo`00
703oool01P3ooml0W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000?02Y_NP50:Vl
i`D0Y[SV1@2U]ND20:>ci0<0YKSW1@2[aNdE0:Vmj0@0Yj[I1@2SUlT40:2>`@<0WhZm1@2TS[d50:V?
^P@0[Hng1P2gXL840;VK^PH0`:S11031X;L20<FaaPD0ajJh1P3<Z[P60<ZZ^@H0_:C200<0d[Bk0:NZ
f@2WZ]T00`00000?0:Vmj00409fhj`000000WKS[09fhj`H0U[O_102b`ND60;?1i080[[oV0`2^_nL5
0:^ni`l0ZKgX00<000000?ooo`3oool0=P3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00D0oooo0P0000020?ooo`030000002Y_NP0ZKgX03X0ZKgX0`2Y_>L20:Rki`D0Y[SV102U
]ND60:Fhi`80ZlG]0`2jcnXD0:Vmj0D0Yj[I102SUlT40:2>`@@0Wh^n1@2TS[d40:V?^P80[Hng0`2c
Y//50;NQ`P<0^I^j0P2m//l60<2X`@80`J2g0`35/LH40<NV^080b[K71@3<Z[P00`3>]l<0bZZi0<ZZ
^@030<ZZ^@030=>f_02lY<80_:C20080_:C200D0d[Bk00000000000000000:NZf@030;J[cPh0ZKgX
00<0Xk[Z0000002S^^X00P2S^^X509Jgk`80//7U0`2a`>D50;?1i0H0[[oW0P2[_^L30:Znj0l0ZKgX
00<000000?ooo`3oool0=@3oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0
oooo00<000000?ooo`3oool00P3oool00`000000ZKgX0:Vmj00j0:Vmj0D0Z;_W102V^>H50::ci0D0
YKSW1P2jcnXD0:Vmj0@0Yj[I102SUlT509V6_@<0Wh^n1@2TS[d40:V?^PH0/jK;1@2gXL800`2iVkX0
_K;?0;fbc`020;fbc`D0`:S11P35/LH20<NV^0<0b[K7103<Z[P20<jg``@0bZZi0P3C][`20;bT`P<0
00000P3B];/50;J[cPl0ZKgX00<0Xk[Z0000002S^^X00P2S^^X409Jgk`H0/L3U0P2c`N@30;?2i@D0
[[oW1P2Z_^P>0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?noM000B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030000003oool0oooo00<0oooo>02Y_NP50:Vli`D0Z;_W102S]>D50::c
i0H0/m;`0`2jcnXE0:Vmj0@0Yj[I1@2AOk/409V6_@@0Wh^n1@2TS[d20:V?^P80[j[B1@2cY//50;NQ
`PD0_K;?1030Z<420;jnf@D0aK7600<0ajJh0<Zfa`3:]/L00`3:]/L20<bZ^0@0c[O30P3:Z[T20=>f
_0<000001@3B];/00`3J_;/0]Z_>0;J[cP020;J[cQ00ZKgX00<0Xk[Z0000002U^nT00P2U^nT409>c
k@D0/L3U1P2c`^D50:foi`D0Z[kX3`2Y_NP00`000000oooo0?ooo`0d0?ooo`00703oool01`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<000000:Vmj02Y_NP0=@2Y_NP5
0:Vli`D0YKOV102S]>D30::ci0<0Z;gY1@2cd_0B0:Vmj080Y9c=102@Ok`408Yh^@@0TGnk102IQ[d4
09n;_PD0Y8jm1@2_Z]850;>Vb`80]j720`2g_Mh50;fbc`80`:S10`2n_]T50<FaaPH0b[K700<0c:Zh
0<jg``3>]l<00`3>]l<0103:Z[T000000000000000020=>f_0D0d[Bk0P3J_;/30;J[cP80bKS:3`2Y
_NP20:Fkj@040000002U^nT0YK_Y0:Fkj@@0Tk?]1@2a`>D60;?2i@D0[KoW1@2Z_^P?0:Vmj0030000
003oool0oooo03<0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000:Vmj02Y_NP0=@2Y_NP50:Nji`D0YKOV102S]>D60:Rmj@D0
[/?Y3`2Y_NP40:BLc@@0T7nl102:N;T4095o^`D0VHJm102ORkh20:B>_@<0Zj_G102_Z]850;>Vb`D0
]kgN1@2m//l60;jnf@80aK760`2o`md50<Zfa`@0c[O30`0000050=>f_0040=>naP3B];/0d[Bk0=:d
^`@0f[bk00<0]Z_>0<VhbP39^<X00P39^<X?0:Vmj0030:Fkj@000000YK_Y0080YK_Y1@2C/N/50;70
i@H0/l;U1@2]_nL50:Znj0h0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00H0oooO09a8001d
_ol0oooo0=nLB000M;l60?ooo`030000003oool0oooo00L0oooo=@2Y_NP20:Rli`D0Yk[W102U]nH5
0::di@<0Z;gY0`2leNd50:k3j@l0ZKgX0`2TW<d4091o_0@0RWRi1@2AOk/409V6_@@0Wh^n1@2[ZmL5
0:nZdP80/jK;0`2`aNT50;NmgP80_K;?0`2bb^`50;jnf@H0_l?M0P3:]/L30<?3fP<0000000<0c[O3
0<[1d@3:`M40103C][`20=>naP<0d[Bk103J_;/50<VhbP030=G2a`2Y_NP0ZKgX00d0ZKgX00<0YK_Y
0000002U^nT00P2U^nT509>aj`80/L3U0`2b`ND50;?2i@H0[KoW102Z_^P?0:Vmj0030000003oool0
oooo0380oooo000M0?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`08
0?oooc80ZKgX1@2X_>L40:Nji`X0X[CU1P2leNd20:k3jA40ZKgX102TW<d4091o_0@0RWRi102AOk/4
09V6_@D0YjWI1@2[ZmL40:nZdPH0/<GY102g_Mh60;;:k080_[kI0`2/cO850;o3g@<0`l?J0P000000
0`33`mX0c[O30<jg``030<[1d@<0dkJl103C_/H00`3B];/0f[bk0=Zl^`030=Zl^`040=_1`039^<X0
bKS:0<VhbP<0eL;73`2Y_NP00`2U^nT000000:Fkj@020:Fkj@@0Tk7[1P2b`ND20;?2i@<0//;V1@2]
_nL50:Znj0h0ZKgX00<000000?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool02P3ooolb
0:Vmj0D0Z;cW102T]nH70::di@@0[<7Y102leNdD0:Vmj0<0Y9c=102@Ok`408Yh^@@0TGnk0P2IQ[d3
0::Te`@0YjWI1@2[ZmL50:_;l0D0/<GY1@2UdOL50;;:k0H0[<gb0P2o`md20:[<l@<000000`33`mX6
0<[1d@030=>f_03C_/H0dkk600<0dkk61@3J_;/20=_1`0<0bKS:0`3E`/L@0:Vmj0040000002U^nT0
YK_Y0:Fkj@D0Uk7Y1@2b`ND60;;2iPD0[;oW102Z_^P?0:Vmj0030000003oool0oooo0340oooo000W
0?ooo`030000003oool0oooo00/0oooo<P2Y_NP50:Nji`@0Y;OV102R]>D70:c1jA40ZKgX0`2X/^03
07mh`@<0Y9c=102@Ok`408Yh^@@0TGnk1@2RY=L50:NYf@80Zj_G0`2XcO<50:_;l0D0W=Kl1@2UdOL5
09SAo0D0[<gb00@0Z/ca00000000000000000P2Zc?420<?3fP<0/LW/1@3:`M450=>naP80c/??0`3J
_;/40=_1`0030<VhbP3E`/L0eL;70080eL;700<0g<W60:Vmj02Y_NP03@2Y_NP00`2S^^X000000:>j
jP020:>jjPD0Uk7Y1@2c`^D30;;2iP<0/L;W102/_nL50:Zmj0l0ZKgX00<000000?ooo`3oool0<03o
ool002L0oooo00<000000?ooo`3oool0303oool_0:Vmj0<0Z;cX1@2W^^L40:BgiPD0X[GV0`2/`NT3
0;kDjPh0ZKgX1@2X/^0407mh`@80Ng:n102@Ok`509:>c0@0Vi_C1@2RY=L40:NYf@H0Z<gc1@2JfOd5
09cFo0H0SM?o102HdO`2093=o0<000001@2Zc?460;79k080b/7A0`2oa^030=>naP<0c/??0`3J_;/4
0=_1`0@0eL;70`3LbLH?0:Vmj0030:>jjP000000Xk[Z0080Xk[Z1@2M/nL50;?2i@D0/L;W0P2/_nL3
0:boj0D0Z[gX3P2Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool2000000h0oooo;02Y_NP60:Rl
j0@0Yk[W1@2Q]>H50::eiPH0_]CZ3P2Y_NP40:Rbh0@0OgS10`1kL[h408J0a@@0TXk<1@2KVm<40::T
e`H0Z<gc1@2Mfod509[Io@H0S=Ko1@23c_l208?<o`<00000102@cO`50978nPD0/LW/1P2oa^000`3C
_/H0c/??0<k3c`030<k3c`030=Zl^`3K`L00fl7000<0fl7000<0flK40=G2a`3E`/L0103LbLH00`3P
dLT0ZKgX0:Vmj00=0:Vmj00309fhj`000000WKS[0080WKS[1@2M/nL20;?2i@<0]<?V102a`^L60:bo
j0@0Z[gX3`2Y_NP00`000000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooobd0
ZKgX1@2X_>P40:Bgi`D0XKCV0P2R]NH30:k2j@<0_]CZ4@2Y_NP40:Rbh0<0OgS1101kL[h308J0a@D0
TXk<102KVm<50:S:l@<0Z<gc0`2RgO`509gKo@H0TMWn1P29d_l208?>o`<00000101la_h407k5oPD0
TLSj1@2Ka_D50;o6h0H0c/??1@3K`L020=_6a0030=G2a`3LbLH0g<W60080g<W60`3PdLT?0:Vmj003
0000002M^>/0WKS[0080WKS[102M/nL50;C3iPD0/<;W1@2/_nP50:Zmj0l0ZKgX00<000000?ooo`3o
ool0;P3oool002L0oooo00<000000?ooo`3oool03`3oool]0:Vmj0D0Yk_W102T]nL40:6diPH0[/;Y
502Y_NP30:Rbh0@0OgS10`1kL[h408J0a@@0TXk<0P2KVm<30:O2k@D0Z<[a1P2RgO`609WLoPH0T]Kn
0`2<c_d3000000@0Pl[n101la_h407k5oPD0P<3l1@2Ka_D20;o6h0<0/<GZ103>`ll20<S5e`<0fl70
0`3Ka/@40=c9aP@0h=79402Y_NP010000000WKS[09fhj`2M^>/50:>fiP80]<?V0`2da>H50;32i`D0
ZkkX1@2Z_NP>0:Vmj0030000003oool0oooo02h0oooo000W0?ooo`8000004@3oool00`000000ZKgX
0:Vmj00U0:Vmj0D0Z;cX1@2W^nL40:Bgi`D0X[GV0`2^`^T30;kDjPh0ZKgX1@2LYM`00`1TIKd0Z;;P
07mh`@0307mh`@@0Ng:n0`26P<D409:>c0H0Yl;]1P2XgOX60:7Oo0H0VmWm102FdO`3000000<0S<km
1@27aO`407k2o@D0NKom1020`?`409_6m@H0/<GZ0P3>`ll40<S5e`030=_1`03Ka/@0flK40080flK4
00<0g<W70=c9aP3LbLH0103PdLT20>7Kd0l0ZKgX00<0UkG]0000002G]Nd00P2G]Nd40:>fiPH0]<CV
0P2``^L30:o1j0D0ZkkX4`2Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool2000001<0oooo00<0
00000:Vmj02Y_NP09@2Y_NP50:Rlj0@0Yk_W1@2P]>H50::eiPH0_]CZ3P2Y_NP409bUg080I6Fm101o
N<4407]b_P<0QX351@2R]^H30:O2k@@0[M[g0`2XgOX40:WPnPH0Y=_k102NdoX300000080U]7l1P2A
bO/408O5o0@0O/;m1@1j^_X407VinP@0Rkkg1@2`aNX60<S5e`@0flK40`3LbLL40>3Ab@@0hM_@3`2Y
_NP0102G]Nd0000009Nek@2G]Nd20:>fiP<0Z[_V1@2da>H60:o1j080ZkkX0`2Z_^PC0:Vmj0030000
003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo
0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0
oooo01<0oooo00<000000:Vmj02Y_NP09@2Y_NP40:Rlj0D0Y;SW1@2P]>H60:g0ia<0ZKgX0`2LYM`3
06AU_@@0MWK61028SM8409RSg@@0X[KV1`2]f_L40:WPnP@0Zmgi1@2Ve_P00`2NdoX0000000000003
0:7>m`@0VLci1@2Da?L408_1n@D0P[gj101j^_X407VinP@0Rkkg1@2S`Nh30<S5e`<0`/GL0`3Ka/@3
0=c9a`030=k>b03PdLT0h=7900@0hM_@0P3KjMh>0:Vmj00409Nek@000000UkG]09Nek@H0Z[_V0P2d
a>H30;?5i`D0[l7X1@2Z_^PC0:Vmj0030000003oool0oooo00X0oooo00D0gia80000000000000018
09cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00<0omnL04P0001d
_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0D
0?ooo`030000002Y_NP0ZKgX02D0ZKgX1@2W^nP40:Bhi`D0XKCW102]`>L20;oAj180ZKgX102LYM`2
06AU_@@0MWK61028SM8509RSg@H0[]Cd1P2`hOP40:_Mn@<0[MSf0P2Ve_P3000000H0XLkg102LaoH5
09C4m`@0Rl7i1@25^OL407ben0@0N;?h1022]oH50:?1kPH0`/GL00@0flK40=c9a`3LbLL0g<W70`3N
c/P40>7Kd0@0fnWN3P2Y_NP0102B/N`0000009:ak02B/N`50:ZkiPH0/lGW1@2]`>P40:Znj1@0ZKgX
00<000000?ooo`3oool0203oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool0703oool000P0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo00<0omnL04P0001d_ol0203oool0
0`2oM000M;oo0?ooo`050?ooo`8000005P3ooolX0:Vmj0D0Yk_X102P]NL50:6di`80[L3W102odNP?
0:Vmj0<0SZSW00<0EUo009bUg02LYM`00`1TIKd407IfaP@0R8gB0P2HXmd30:_8k`<0[]Cd102dgoD6
0;;NmP@0[MSf0`0000050:S@m@D0XlWc102LaoH509O0m0@0Skge1@25^OL407ben0@0N;?h1022]oH5
09Zkk`D0`/GL103LbLL30=k>b0030>;Cb03Qfm00hM_@00D0fnWN3`2Y_NP0102B/N`0000009:ak02B
/N`50:o0iP<0/lGW0`2ba>P40:g0j0D0Z[kX502Y_NP00`000000oooo0?ooo`0<0?ooo`030;md001d
_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo
_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G0?ooobL0ZKgX
1@2T^NP40:2ei`@0XKCW1P2odNP@0:Vmj080SZSW0`1FGl0306AU_@@0MWK61028SM860:_8k`@0]=oe
0`2hgo<30;;NmP<0/mWd0`0000030:kBl`<0Z=3e0`2Ybo450:?9l`@0W/;b1@2G`?@408nmm@D0RKGc
1020/O@407Z_m0@0Ok7d1@2J^nl20<;5g0<0_lGO0P3LbLL30=k>b0<0h]?8103KjMh30<7Mk@h0ZKgX
00<0TjOS0000002CYn<00P2CYn<50:o0iPD0//CX1@2/_nP50:Znj1<0ZKgX00<000000?ooo`3oool0
303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02L
gol01P3oool02`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo
00<000000?ooo`3oool0603ooolU0:Vmj080YkcX1@2T^NP40:2ei`H0Z[cV1@2^`nT>0:Vmj080SZSW
101FGl02075ic0@0MWK61@2P]>H30:_8k`@0]][b1P2hgo<20;?Im0<000000P2de?450:kBl`H0ZL_a
1@2Ta?0409k2lPD0VKc`102A^O8508Vel`@0P;7d101j[o@407nam0@0V[__1P2oaMl30=k>b0@0h]?8
0P3Xf/H50<7Mk@X0ZKgX1@2X_>P00`2CYn<0000009>Wh`0209>Wh`80[l3V0`2ca>L20;;4j0<0/<?X
1@2/_nP50:Zmj1<0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8
B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono
07@0B02Lgol0oono07@000030000000307Boo`3oool0oooo00@0oooo0P00000K0?ooob80ZKgX1@2W
_>P40:Bij0D0WkCW0`2Z_>H30;c8i0D0[/?Y2@2Y_NP509^hk@80SZSW0`1FGl03075ic0@0S9SJ1@2P
]>H40;KJlP<0_=ga0`2hgo<0102ifo4000000000000000060;CDl@H0[/c_1@2Ya^h50:C4l0D0Wkk^
102I_?04096ilP@0RKGc1020/O@407Z_m0@0Ok7d1@2G]nh60;o5g`030=k>b03RdlP0h]?80080h]?8
0`3Xf/H20>oT``h0ZKgX1@2X_>P0102CYn<0000009>Wh`2CYn<50;?4i`H0/<?X0P2/_nP30:^nj0D0
Z[gX4`2Y_NP00`000000oooo0?ooo`050?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3o
ool06`3oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0okmd001d
_`3oool00P3oool01@2oM000M;oo0?oog`2LB4P0W=oo00T0oooo00<000000?ooo`3oool06`3ooolR
0:Vmj0D0YkcX102Q]nP509ndi`H0_<ST0P2^`nT<0:Vmj0@0VkS]00<0@EK108jXi`1FGl000`1FGl03
075ic0@0S9SJ0P2P]>H40;??kPH0_=ga0`0000020;WKl@80^MG^0`2de?430;?>k@<0[/c_0`2^an`5
0:W6kPD0YL3]1@2O_^h309Vll0D0TkG^102;/Nl408>]l0@0OJ_a1020[?4509NgkPD0_lGO103RdlP3
0>SJaP<0knC300<0k_?60:Vmj02Y_NP0302Y_NP509Vfk0040::ci@000000X[?U0::ci@<0/lCW0P2d
a^P50;33j0H0ZkkX102Z_NPC0:Vmj0030000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803o
ool000P0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3o
gi`0B01809cOo`3oool0_g@007Boo`T0oooo00<000000?ooo`3oool0703ooolR0:Vmj0D0YK_X102Q
]nP209ndi`<0Y;SW1@2lb>@?0:Vmj0<0VkS]0P11E/4405IO`0@0LGW<0`2<V=X50;??kP<0_MW^00@0
_=ga00000000000000000`2nfnh50;WEkPH0/lk]1P2^an`20:W6kP<0ZL7[1@2U`>d50:2jj`<0V[S]
1@2C]Nh408^ak`@0Pjg`101mZo44082/l@D0UkC[0`2oaMl20<?7gP80h]?80`3Xf/H30>oT``80k_?6
3`2Y_NP509Vfk0040000002R/nD0X[?U0::ci@D0]<KX1@2^`NP50:^nj1P0ZKgX00<000000?ooo`3o
ool01@3oool00`2oM000M;oo0?ooo`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0
oooo00D0omnL04P000000000000007Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3o
ool00`000000oooo0?ooo`0M0?oooad0ZKgX1@2X_>P50:Fkj0<0XKOX1P2T^>L50;[?jPl0ZKgX00<0
<Ec=09^hk@2K^>d00P11E/4306Mgc`@0LGW<1P2V^nP40;gIkP800000102nfnh30;kFk0<0^MG^0`2h
cn/30;?>k@80/lWZ1@2^an`60:W1j`D0YKcY1@2P^^/309Zhk@D0U;7[102=[N`408FZk@@0P:O]1022
ZNd509Ndj`030;o5g`33amh0`lON0080`lON103Xf/H20>oT``<0k_?6402Y_NP409Vfk0030:bniP00
0000[;kV0080[;kV0P2da^P30;;6j@D0[/7X1@2Z_^PG0:Vmj0030000003oool0oooo00D0oooo00H0
gia800000000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo7@2Y_NP50:Rlj0D0X[WY
102N]NP30:Bhi`<0/L3U102jcnX?0:Vmj004035Lc@2K^>d0@EK1045F`@@0IgO?102<WMh30:Jkj0<0
^<o[0`0000040<7Ik0H0_]K/1P2hcn/50;?9jPD0[/?Y0`2Y`N/30:Vmj0D0YKcY102P^^/409^dj@D0
U;7[102=[N`408FZk@@0P:O]1022ZNd409Ndj`@0`lON0P3;cM`20>SJaP80knC30`3^llH20=;gi@l0
ZKgX1@2CY^80102/_^H000000:bniP2/_^H60;;6j@80[/7X0`2/`>P40:Znj1P0ZKgX00<000000?oo
o`3oool09P3oool002D0oooo00<000000?ooo`3oool07`3ooolM0:Vmj0<0Z;cX0P2W_>P50::ij@@0
W[GX1P2a`>DB0:Vmj080<Ec=0`11E/4406Mgc`@0S9gN0P2hcn/3000000030;S?j`31fN`0`MW/0080
`MW/0`32e^T30;kFk0@0_M3Y1@2hb^P30;?9jP80//CW1@2^`nT60:Vmj0@0YKcY1@2P]^P409^dj@@0
U;7[102=[N`408FZk@@0P:O]1022ZNd509bcj@80`lON103;cM`20>oT``<0k_?6103BmnD?0:Vmj0@0
TjKR00<0[;kV0000002baNP00P2baNP50;;6j@D0[<3X0P2Z_^P30:Zmj1P0ZKgX00<000000?ooo`3o
ool09@3oool002D0oooo00<000000?ooo`3oool0803ooolM0:Vmj0D0YkcX102R^NT509nfj0<0/L3U
0`2nb>8B0:Vmj080<Ec=0P1AJlh406Mgc`<0Yk_W0`0000020;S?j`@0`=GY1P32e^T40;g@j@<0_<_V
1@2hb^P50;;4i`D0[[kV1@2Y_NP50:FhiP@0X;KX102K]>T509F]i`@0SZWX1027Y^T408>Tj@@0QZOZ
102L/nT50<_=g0<0emSI0P3Ti]<00`3BmnD0ZKgX0:Vmj00A0:Vmj0@0TjKR0P2baNP010000000//GX
0;;5j02baNP50;34j@@0[<3X1P2Z_NPG0:Vmj0030000003oool0oooo02D0oooo000T0?ooo`800000
8`3ooolM0:Vmj0D0YkcX102O]nT509nfj0H0_/SR3P2Y_NP305^LlP80<Ec=0`1AJlh308FHgP<00000
0`2W^nL50<3Ej@80a=CV0`32e^T40<;AiPH0_<_V1@2gaND30;;4i`<0//3T102^_^H50:Vii@D0YKSV
102P/^D409^`iPD0UJgW102>ZNP408NVj@@0PjCY1026YnX40:>giP<0blgL0`3Gf=T30>CVd`030>gd
aP3LoKT0ZKgX00d0ZKgX1@2I/^T40::bi080//GX00@000000;?7j@2canT0/lOY102`a>T50:^nj0D0
Z[gX602Y_NP00`000000oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`0S0?oooad0ZKgX
1@2U^nT409ngj@<0WkKX0P2V^NL50;k8hPl0ZKgX0`1KW?80100XD/L0<Ec=055[cP1AJlh300000080
QISN0P2W^nL30;S:j0<0`=GY1034e>H50<;AiP80`LcS0`2lbnH30;_6h`D0]lGU1P2b`>@40:fkh`D0
ZKWU1@2U]><40:2bi@@0Vk3V102E[NL508nVi0@0RJ?U1026X^H408bVi`@0XkOV103Gf=T30>CVd`04
0>gdaP3LoKT0g?fi0=cm^@h0ZKgX1@2I/^T40::bi080/lOY00@000000;?7j@2canT0/lOY102]`NT5
0:^nj1d0ZKgX00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0903ooolI0:Vm
j0D0Z;cX102U^nT409ngj@D0Y[WW1@2jcNT?0:Vmj0030015aP1KW?80:5;700<000000P1AJlh308FH
gPH0^<[X1034e>H30<CAi0<0`]7V1031c><60;_6h`80]lGU0`2f`N830;;0i0<0/KcR102]^n<20:Vi
i@<0ZKKR1@2U]><30:2bi@D0VjcR102EZN<508nVi0@0RJ?U1026X^H308bVi`80XkOV0`2__^D20=OH
f@<0i>KC0P3]m<H30=cm^@l0ZKgX102I/^T50:k1i`030;?7j@000000/lOY00<0/LKY102]`NT50:Zn
j1`0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?oooaT0ZKgX1@2X_>P40::ij@@0
WKKY0`2V^NL30;6oi0@0^/gY3P2Y_NP300000080:5;70`1_RMd50:6ciP<0^<[X0`31cnD60<CAi0D0
`LcS0P2oan450;_6h`H0]/7R1P2a_>830:fkh`H0ZKKR102U]><40:2^h@D0VjcR102EZN<408nVi0@0
RJ?U1026X^H308bVi`H0[kkU0`3Ti]<20>gdaPD0]/k/3P2Y_NP509NWh0D0[/7W00<0/LKY0000002a
a^T00P2aa^T50:^oj0D0Z[kX702Y_NP00`000000oooo0?ooo`0R0?ooo`008`3oool2000002P0oooo
6@2Y_NP20:Rlj0<0YkcX102R^NT409ffj@H0/KoT1@2[_nP:0:Vmj080000000<0ZKgX0015aP00ALH0
0P0XD/L406n9g@D0XK?V1031cnD30<C>hP<0a=7T0`34cN420<7<h`@0_lOQ0P2ka^<30;[2h0<0]/7R
0`2e_Ml50;6lhP@0[KOP1@2Y]^850:F`h0@0X:kQ102K[>8409FYh`D0T:;Q102;X>8408ZQh`<0TjWU
0`2__^D40<3=i080kOC600<0i?[A0=KiZP2fc^`0102fc^`90:Vmj0D0YK_Y1@2GYn050;?7j@030;76
j@000000[/?Y0080[/?Y1@2[_nPQ0:Vmj0030000003oool0oooo0240oooo000=0?ooo`0;0?oo_`1d
000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`07
0?ooo`030000003oool0oooo02P0oooo5`2Y_NP60:Nlj0<0X[WY1@2N]^T30;6oi0<0_LCO1@2[_nP6
0:Vmj0<000000`2Y_NP30015aP0303i[eP0XD/L0KhWM00<0KhWM0P2Q/nH30;?2i@80`LoU1@34c^86
0<C=h@D0_lOQ1P2j`^060;Fmg`80/KcR0`2a^=h40:fgh0D0ZK7N1@2U/>030:2^h@D0VjOO102FYN05
092Rh@@0Rj3R0`2:XN<409>Yi@D0`<gT0P3Ei>40103Tn]40e_VZ0=KiZP3FnJX>0:Vmj0D0YK_Y0P2G
Yn030:Vki`@0/lOY0P2^`nT010000000[/?Y0:k3j@2^`nT20:^oj0<0Z[kX802Y_NP00`000000oooo
0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd0018W03O
ool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3ooolG0:Vmj0D0YkcX1@2O^>X4
09jfj@H0_LCO1`2Y_NP3000000@0ZKgX0`2:/_401000<kX004G603i[eP0nJmH406n9g@H0/l;U1@34
c^820<G<g`<0a<gQ0`33b=h30;o7h@80_/?N0`2j`^030;Vng@D0]KgO1P2a^=h20:fgh080[;?M1@2Y
/Mh40:F`h0@0X:[N1@2KYml409JUh0@0T:;Q102;X>8308ZQh`D0Wk;U0`30cN@20=GTh@80i?[A00@0
e_VZ0<7Mk@31gNd0`Mg]3P2Y_NP40:Fkj@H0ZK_W102banX00`2^`nT000000:k3j@020:k3j@D0Z[kX
8@2Y_NP200000240oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`080?ooo`03
0;md001d_ol0oooo00D0oooo0P00000/0?oooaL0ZKgX1@2U^nT509nhjP@0X[SX0`2ma=l30;g5h@<0
ZKgX0`0000080:Vmj0<0R[;a00@003>j0015aP0nJmH0?V_F102=YND30;?2i@<0_<OS0`34c^840<G<
g`H0`lSN1@2n`mh60;Vng@D0];WL1@2a^=h50:bcg@@0ZK7N1@2T[=`40:2ZgP@0VjOO102FYN05096O
g@@0SYoO0`2@Xn8509nbi@<0eNCQ0P3Tn]460<7Mk@h0ZKgX102EY=l30:Vki`<0/LOZ102banX00`2/
`>P000000:c0j0020:c0j0@0Z[kX8P2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0
oooo02`0oooo4`2Y_NP50:Rmj0@0YK_Y1@2M]n/40::hj0D0_LGQ0`00000<0:Vmj0<0?Hc]00@003>j
03i[eP0nJmH0?V_F102=YND60;c7h`D0aLcO0P35b=`30<?8gP<0`/CK0`2n`mh20;fnf`<0^KkM0`2h
^]X50;Big0D0/;CK102//md50:R]f`D0Y:cL0`2PZ]h509^Tf`@0UZ7L102AWmd508jOg`<0T:?R0P2O
/^D40;73j080i?[A00<0e_oD0;3YT@31gNd00P31gNdA0:Vmj0@0UJCO1@2aanX50:o4j@030:c0j000
0000[<3X0080[<3X102Z_NPQ0:Vmj0030000003oool0oooo01l0oooo000<0?ooo`070?noM000B9`0
gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?oo
o`030000003oool0oooo02d0oooo4`2Y_NP50:Rmj0@0Y;_Y1@2M]n/20::hj080Z;_W00D0_LGQ0000
0000000000000;g5h@0?0:Vmj0<0?Hc]00<003>j05Z6h`1JQ^<01@2R]^H30;c7h`<0`LSP0`35c=l4
0<G8g0H0`/CK1@2m_]/60;RjfP80];WL0`2c]MT50;2df`@0[:oJ1@2X[M/40:B/g0@0WjKJ1@2KY=/4
09JQg0@0TIoM102>Wml3092ShPD0/L?X0P39h^X0103Fom@0/>VA0;3YT@2`jI4C0:Vmj0D0Y[SV0P2a
anX30;;8j`D0[lCY00<000000:Znj02Z_^P00P2Z_^P40:Zmj240ZKgX00<000000?ooo`3oool07P3o
ool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo4`2Y_NP50:Rmj0@0Y;_Y
102M]n/20:Rki`<000000`2maN430;[6h`h0ZKgX00@005oE03f<k@0mS>d003>j0`1JQ^<40::fiPH0
`LSP1@35b=`20<C4fP<0`/CK0`30_mT30;fnf`80_;[H1@2h^]X60;>ef@80/;CK0`2_/=P40:b_fP@0
Z:gK1@2TZ=T409nVfP@0VjCK102FXM`4096Og@D0Tj7N0`2J[><30;73j080bN;Z0P3Fom@40;K>k0l0
ZKgX102GY=l40:JhiPH0//S[1@2/`NT010000000Z[kX0:Znj02Z_^PV0:Vmj0030000003oool0oooo
01d0oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`030?oog`2LB4P0
W=oo00T0oooo0P00000a0?oooa@0ZKgX102X_NP40::jjP80W;O[0`0000040:Rki`H0^/KS3P2Y_NP2
001Oe@03000n`P1JQ^<0FXKS0080FXKS102^_^D30<78h0<0`lKM0`35b=`40<C4fPH0`;oI1@2l^]P3
0;RjfP80]kKH1@2c]MT60:n`f0<0[:oJ1@2WZMP50:BXf@<0WjKJ1@2KX=P409NOfP@0TikK102CXMh4
09Z/h`<0bN;Z0P3Fom@00`2glJ80]/k/0;K>k0030;K>k0l0ZKgX102GY=l40;37j`<0//S[0`2_a>X4
0:c1j@030:Zmj0000000Z[gX0080Z[gX9@2Y_NP00`000000oooo0?ooo`0M0?ooo`00303oool01P3o
oml0W4P007Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3oool0203oool00`000000oooo0?oo
o`0a0?oooa@0ZKgX102W_>T30::jjP8000000`2L]n/50:nni0<0^/KS0`2ea>H>0:Vmj08005oE00<0
03k2076KjP1aVnX00P1aVnX40:jni@H0`lKM1@34a=X20<;0f0@0`;oI0P2o^mH50;bjf0D0]kKH0P2c
]MT30;>aePD0[k3H102[ZmL50:NYf0@0Y:SI102OX]L409^Pf0D0UioJ102CW]/309>QgPH0Zl3Y0P3F
om@30;OaXQ<0ZKgX1@2U^>H40;37j`D0[lCZ0P2/`NT30:Znj0030:Zmj0000000Z[gX0080Z[gX9@2Y
_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0
gia800000000000000000000M02oool50?ooo`030000003oool0oooo0380oooo502Y_NP30:Nlj@<0
00000P2R^^X409bhj`D0[kkT1P2ea>H>0:Vmj0030016`P00GmD003k200@0LI_Z0P2^_^D30;G1h`<0
`lKM0P33a=/30<C4fP@0`/3H0P30_mT40;nkeP80_;[H0`2j]mH40;Nff0H0/k7F0P2_/=P30:n/e@@0
Zj_G102WZMP50:>TeP<0Wj;G1@2KX=P409NOfP@0TikK102KZn830:_0j@<0`nS`00<0]oVo0:Vmj02Y
_NP0402Y_NP509NSg@@0YKSV1@2ab>/40:o4jPH0Z[kX00<000000:Zmj02Y_NP09`2Y_NP00`000000
oooo0?ooo`0K0?ooo`008P3oool2000003@0oooo4`2Y_NP3000000030:Nlj@2P^^/0X;[[00<0X;[[
102L^>/50;G0hP<0]LCV0`2``NH>0:Vmj0030016`P00B<L0LI_Z00<0LI_Z1P2e`N<50<?4f`H0`/3H
1P2o^mH60;ZgeP80]kKH0P2f/]@50;>aePD0[jcE102[ZmL50:NVe@D0XjCF0`2OX]L409^Pf0D0V9oI
102GX]`409^[hP@0`nS`00<0]oVo0=;gi@2Y_NP03@2Y_NP50:Vii0@0Uj?M0P2U^>H30;38k0D0/LS[
102/`NT50:Znj0030:Vmj0000000ZKgX02L0ZKgX00<000000?ooo`3oool06`3oool00280oooo00<0
00000?ooo`3oool0=03oool?0:Vmj0<0000000<0ZKgX0:Jlj@2V_>T00`2V_>T40:2jj`D0WKS[102e
`>860;31iPh0ZKgX00<004K20019a@20ZNh00`20ZNh30;G1h`<0^<;R0`33a=/20<;1f@<0`/3H0`31
_MH30;nkeP<0_KSD1@2j]mH50;Jbe080/k7F0`2b[M<50:n/e@80Zj_G0P2[Ym<50:NVe@@0XjCF0`2O
X]L509^Oe`@0V9oI102GX]`209^[hP@0[<K]0P2gnKl30=;gi@h0ZKgX1@2Y^N@309NSg@H0/<S/1@2^
a>X40:c1j@D0Z[gX00<0ZKgX0000002Y_NP09`2Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool0
0`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX00P0ZKgX0`0000050:Vmj0D0Y[cY102N^N`5
09fhj`@0^L7P0`2``NH30:jniPh0ZKgX00<004K20019a@20ZNh00`20ZNh60;S2hPD0`/7I1P31_MH6
0;fhe080^[OF0`2i/m<40;Jbe0H0/ZgC102_[=D40:^Wd`D0YjKE1@2SX]@309nPe@D0VioG102HWmT3
09NRg0D0[<K]0P2jn>h40=;gi@l0ZKgX102Y^N@40:Rlj0H0/<S/102^a>X50:Znj0D0Z[gX00<0ZKgX
0000002Y_NP09P2Y_NP00`000000oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo0080oooo00D0oono
07@00000000004RL0=ooo`040?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`H0ZKgX0`000009
0:Vmj0D0Y[cY102N^N`509nij`@0^L7P1P2^_^H>0:Vmj003001Oe@00>k8004W500<0Q[7a1P2h`^83
0<;1f@80`;oI1031_MH20;nje@D0_KSD1P2i/m<20;Jbe080]JoB1@2b[M<50:jYdP@0ZjOC0P2WY]D3
0:JSd`@0Xj;D102OX=D409^Oe`@0V9oI102P/N@30:c6k@80^_S^00<000000:Vmj02Y_NP04@2Y_NP5
09VVgP@0Z;cX1P2`b>`40:_0j@D0Z[kX1@2Y_NP00`000000ZKgX0:Vmj00V0:Vmj0800000303oool0
2P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`008@3oool2000003X0
oooo0P2Y_NP3000000d0ZKgX1@2V_>T409jik0D0WkW[0P2i`N030;_1g`@0[[kV3`2Y_NP00`00GmD0
03^b000k/P0308Jal@H0^<;R00<0`/7I0<2of@30_mT00P30_mT20<6meP@0_k[E0P2m^=@30;bed`D0
^K?C1@2e[m820;:]d`<0/J_A102^ZM840:^Wd`D0YZ?C102SX]@409nPe@D0WJ?I102MYmd40:2ai080
^_S^4P2Y_NP50:F^gP@0VJKN1@2`bN`30;38k0<0[L?Z102[`>T50:Zmj0D0ZKgX00<000000:Vmj02Y
_NP09P2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool00`3oool00240oooo00<000000?ooo`3oool0>03oool300000140ZKgX1@2U
_>T409jik0@0WkW[1P2k`Ml40:fli0l0ZKgX0P0mS>d01000>k80PkKf08>fmP23]_H50;S2hPH0`;oI
1@2o^]D60;bed`80^K?C0`2h/M840;F_dPD0/J_A102^ZM850:ZUdPD0YZ?C0`2SX]@50:2Se`D0WJ?I
102MYmd30:oLm`03083R/P31gNd0`Mg]0180ZKgX1@2U[]h40:_2j`D0/<W/1@2]`nX50:Znj0@0Z[gX
1P2Y_NP00`000000ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0
oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0f
0?ooo`8000000`3oool>0:Vmj0D0Z;gX102U_>T309jik0D0Wk[/1P2k`Ml40:fli0l0ZKgX0`0mS>d3
08>fmPD0]L?T0`30_mT30;jnfP<0_k[E0P2n^MD50;bed`H0^;7B0P2e[m820;B]d@D0/J_A0P2^ZM82
0:jWd@D0ZZGB102VXm<40:>Se@D0X:?G102MXmT50:O4kP80P>:b1031gNdB0:Vmj0D0XK;T102[`^/5
0:o7k080[L?Z0`2[_nT50:Znj0T0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`09
0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240
oooo0P00000d0?ooo`<000001P3oool>0:Vmj0D0Z;gX102U_>X409fjk0@0Wk[/1P2k`Ml40;2khPh0
ZKgX102:/_43072fn`D0]L?T1P2n_]X00`2o^]D0_[WE0;jie@020;jie@80_;GC0`2k]=<50;RadPD0
]:gA102aZm450:jWd@@0ZZGB1@2WYM@40:>Se@@0X:?G1@2S]nH30:O4kP0309GaiP2io>D0^OcU0180
ZKgX1@2KY=`40:6bi0D0/<[]102_an`60:^oj@80Z[kX302Y_NP00`000000ZKgX0:Vmj00V0:Vmj003
0000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3oool?0:Vmj0D0Z;gX102U
_>X409fjk0@0Wk_/0`2k`Ml30;W1h0@0/;_R3P2Y_NP408Zbl@<0L;Kk0P2e`n@30:o6j`D0_[kJ1@2n
^MD60;^dd`D0^;7B102d[M450;6Zd@@0[ZOA1@2ZYm<50:NUe0<0Xj?E1@2T/>450:>giP0309GaiP2Y
_NP0ZKgX0100ZKgX1@2Y/=d509^Tg080XK;T0P2^b>d50;3:k@@0[<;Z1@2[_nT?0:Vmj0030000002Y
_NP0ZKgX02D0ZKgX00<000000?ooo`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=oo
o`3oool0omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cO
o`070?ooo`030000003oool0oooo02d0oooo0`00000>0?ooo`h0ZKgX1@2X_NP40:FljP@0WK[]102O
^n`60;W1h0D0/k_O4P2Y_NP00`0mZ?H0[lK[0:o6j`040:o6j`80_[kJ0`2k`Mh30;jie@80_;_I1@2k
]=<60;RadP80]:gA0P2d[]<50;6Zd@80[ZOA0P2^Z]@40:ZWd`D0YjGD102V[mh50:B`h@80XkOV0P2O
j_X@0:Vmj0@0ZK_V1@2Y/=d409^Tg0D0[/S]1@2^aN/40:c2jPD0Z[kX3`2Y_NP00`000000ZKgX0:Vm
j00U0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Bo
o`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P004RLg`3oool0gia8001d_`D0oooo00<0
oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000
oooo0?ooo`0Z0?ooo`<000004P3oool>0:Vmj0D0Z;gX102U_>X409fjk@@0W[_]0`2i`N030;G1h`D0
/k_O4P2Y_NP00`00;Zh0[lK[0:o6j`030:o6j`H0^l7N1@2l^mT20;^dd`<0^KOG1@2h/M840;B^d`D0
/J[A102^Z]@50:ZWd`80YjGD0`2X/=d40:J_gP@0Y;3Q0P2Oj_XC0:Vmj0@0ZK_V102Y/=d50:S0j`80
[/S]0`2_b>d40:k5j`T0Z[kX3`2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003o
ool0203oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool000<0
oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool0
0`2oM000M;oo0?ooo`040?ooo`800000:@3oool3000001H0oooo3@2Y_NP60:Rmj0<0YKcZ1@2M^^d4
09jkk@H0]L7S0P2c^ml30;RlgA80ZKgX00<0Ficb09g<n02Mc?P00`2Mc?P30;_1gP<0/lWZ102l^mT6
0;Vge`80^;7B0`2g]]P40;B^d`80/J[A0`2a[mL40:jZe0@0ZZOC1P2X/=d30:J_gP@0X]ol5P2Y_NP3
0:VkiPD0X[?T102X`>/60:o8k@@0Zl3Y1@2Z_^PC0:Vmj0030000002Y_NP0ZKgX01`0ZKgX0`000005
0?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103oool00`000000oooo0?oo
o`0U0?ooo`<000006P3oool>0:Vmj0@0Z;gX1@2U_>X409fjk@D0WK_^102e`N<60;Rlg@@0ZK_V4@2Y
_NP309g<n0H0/lWZ0P2l^mT20;O4i0D0^KOG1P2g]]P30;B^d`H0/JoG0`2^Z]@50:^cgPD0Z;3M1@2S
fO/D0:Vmj0D0Yj_I0`2MYM`50::ci0D0[/[^1@2/`nX40:_0j@D0Z[gX4`2Y_NP00`000000ZKgX0:Vm
j00H0:Vmj0<00000203oool00`000000oooo0?ooo`0E0?ooo`000`3oool01`3o_g@004RL0=ooo`3o
ool0oono07@0B02Lgol01@3oool00`3ookl0M01809cOo`020?ooo`070?oOW01804P0W=oo0?ooo`3o
oml0W4Q809cOo`050?ooo`030000003oool0oooo0280oooo0`00000N0?ooo`h0ZKgX102X_NP50:Fl
jP@0W[_]1@2M^nh40;31iP<0^;cM0`2k_md40:VkiQ80ZKgX0P1MaO/50;?9jPD0]lCT0P2i]mL30;K3
i0D0]kKH102c^=d50;6_e`@0[[[S1@2[/mh50:?InaH0ZKgX0`2Y[m`40:N[f@@0WJGL1@2]bNh20:k:
kP<0[LG/102/`nX50:Znj0@0Z[gX502Y_NP00`000000ZKgX0:Vmj00C0:Vmj0@00000303oool00`00
0000oooo0?ooo`0D0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01P3oool0
1P3OW4P007Bo0?ooo`3oool0oono07@000<0000000<0M;oo0?ooo`3oool0103oool00`000000oooo
0?ooo`0O0?ooo`<000008P3oool>0:Vmj0@0Z;gX1@2V_>T409jkk@D0W;_^102``NH60;^og@@0Z[;N
4P2Y_NP209^hk@D0TmOn102ga>@60;K3i080]kKH0`2bb>X40;>hg@80/JoG0`2_a^/40:jjh`H0W]km
5`2Y_NP60:V_g0<0Yj_I1@2Za>d40:g9kPH0[LG/102Z_nP50:Znj1L0ZKgX00<000000:Vmj02Y_NP0
3`2Y_NP0103oool0000000000000000@0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oo
_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cO
o`090?ooo`8000007P3oool2000002H0oooo00<000000:Vmj02Y_NP03`2Y_NP50:Jlj@@0X;_/1@2L
^nh40:S0j`<0^koM0`2l`]h40:ZbgQD0ZKgX102Ceoh409oIo0D0]/?T1@2bb>X40;>hg@H0[lK[0P2^
^^<308cTnaP0ZKgX102Y/ml50:V_g0@0YkgY1@2Za>d40:g8k@<0[LG/0`2[`>T40:Zoj1`0ZKgX00<0
00000:Vmj02Y_NP02P2Y_NP20?ooo`<000004`3oool00`000000oooo0?ooo`0D0?ooo`000`3oool0
1P3ooml0W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd0018W03Oool0oooo0;md001d_ol80?oo
o`800000703oool3000002X0oooo4@2Y_NP50:Jlj@@0X;_/1@2K^nl40:S0j`H0_<;N0P2Z/]h20;Jj
g1X0ZKgX0`2OfO`509SNoP@0//SZ1P2VfOT40:o6j`80S>Ck00<0C/gF0:Vmj02Y_NP0502Y_NP50:Vg
h`@0ZK?O1@2U]^D40:Nmj@D0[L[_102]b>d50:_0j@D0Z[gX702Y_NP00`000000ZKgX0:Vmj0070:Vm
j0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0gooo
00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003000000030000M02oool0oooo
00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo4P2Y_NP40:Jlj@D0X[c/102K^nl40::o
kPD0_<;N1@2f^]`50:V`gAT0ZKgX102Hg_h506GGkAd0ZKgX1@2Y^ND40:Vgh`D0Y;3P102U]^D50:c:
k`@0[L[_1P2[`^X40:Znj0D0Z[gX6`2Y_NP00`000000ZKgX0:Vmj0050:Vmj08000006P3oool00`00
0000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3ooolB0:Vmj0@0
YkgY1@2R_>`409blkP@0X[o^1@2b`nL30;Jjg080_L7M1@2Y/=d40:Vii3L0ZKgX2@2Y^ND40:F/g@D0
Y;3P0P2U]^D20:_:l0D0[<[_102/`n/30:_2jPL0Z[kX802Y_NP010000000ZKgX0:Vmj02Y_NP20000
01d0oooo00<000000?ooo`3oool0503oool001l0oooo0P00000C0?ooo`<00000=P3ooolB0:Vmj0@0
YkgY1@2T_>/409blkP@0WKk_1@2b`nL50;g1g@80ZK3M0`2f^M`40:Vii380ZKgX1@2Y]n<40:Vii@D0
YZ_J102U[=d40:B`h0D0Zl[`1@2/aN`40:c3j`L0Z[kX8P2Y_NP300000200oooo00<000000?ooo`3o
ool0503oool001l0oooo00<000000?ooo`3oool03`3oool3000003X0oooo4P2Y_NP40:Rmj0D0Y;c[
102O_>d409fnk`D0Y/;]102m`Md60;Jig0@0[;3J;P2Y_NP40:Vcg`D0ZKOS102X[=X50:J[fP<0YJcM
1@2Zb?050:c7k@@0[<G/1@2Z_nT40:Znj200ZKgX0`0000030?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3000003h0oooo4P2Y
_NP40:Rmj0D0YKcZ102O_>d509bmk`@0Y/;]102ba>L30;Jig0<0^l?P102//=X50:R]fRH0ZKgX0`2Y
[m`40:Vcg`80ZKOS0`2[[m/40:R/fP@0YZ_J102Yanl30:[8l080ZlS^1@2/and90:ZojB00ZKgX0`00
00060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<00000
0?ooo`3oool02@3oool300000480oooo4P2Y_NP40:Rmj0D0YKcZ102R_>`509bmk`@0W[o`102ba>L6
0;_3h080[;3J0P2l`=d90:R]fPD0ZKgX102Y^N@=0:Vmj0D0ZK_V102Y_NP60:V_g0<0ZK?O1@2[[m/4
0:R/fPD0ZLK_102Yanl50:_8kPD0Z/3Z102Z_nTP0:Vmj0@000002P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01<0oooo000N0?ooo`8000002@3oool2000004H0oooo4P2Y_NP40:Rm
j0D0YkgY102R_>`509jmkP@0W[o`102T`^l50;_3h0D0_<3M0P2X[MX30;Zng@@0Z:gJ1@2XZmT40:Vi
i0@0ZK3M1@2Y_NP40:V`g@D0ZK_V102XZmT50:V_g0@0[K?M102[[m/90:W6k`H0Z/S_102Z`NX40:[0
jPD0Z[kX6`2Y_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0oooo5P2Y_NP50:Nm
j@@0YKgZ1@2N_Nh409fnl0@0Y<;_1@2Za>d40;c0g@H0^[kM0P2X[MX20;Zng@@0Z:_I1@2/[]T40:V`
g@D0Z:[H102Y/=d50:V[f0@0Z:_I1@2^^N440:fcg@@0ZLO_1@2Ya^l50:W8l0D0Z/7[102Z`NX90:Zn
j1L0ZKgX00@0oooo00000000000000004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01<0oooo000N0?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`030000002Y_NP0ZKgX
01<0ZKgX1@2X_NP40:FmjPD0X[g/102M__0409g0l0D0Z/C]102]aN/:0;Zng@80Z:_I0P2i`N050:b^
f@80ZK3M0P2f^]`50:RZf0@0];WM102YZmP50:joiP@0[[WQ1@2Xb?040:W7k`D0Z<S`1@2Z`^/40:[1
j`T0Z[kX5`2Y_NP00`3oool0000000000002000001H0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0000000200000540oooo00<000000:Vmj02Y
_NP04`2Y_NP50:Rmj0@0YkgY1@2R_N`40:2mk@@0WL3`1@2O`_440:g5j`D0[/G[102j_]d50;W1h0@0
[:kI1@2f^]`20:RZf0<0/L;W102d^Md20:V[f080[<G/1@2^_nH40:O8l@D0Z<S`102Xao030:S8l080
ZL;[1@2Z`^/40:Vnj0D0Z[kX602Y_NP3000001/0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0C0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP0602Y_NP40:Nmj@D0YKgZ
102P_Nd409nnk`D0Wl;a102P`o450:k5j`@0ZlK]102i`N050;;4j0@0][[L1P2a`^L30;Big@D0[<G/
1@2Vb?840:O8l@D0YlK`102Xao050:W2j`T0ZKkX6P2Y_NP2000001l0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003o
ool0oooo05@0oooo00<000000:Vmj02Y_NP0602Y_NP40:Rmj0D0YKgZ102T_N/409nnk`D0Wko_2@2P
`o440:_6k@@0YlK`1@2ba>P40:[7kPD0/L;W1@2Xao040:C7lPD0Y/Sb102WaNl40:O6l0H0ZL7[202Y
_^PK0:Vmj0030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000EP3ooolJ0:Vmj0@0Z;gX1@2W_NT4
0:Bmj`@0Xkg/1@2O_nl409o0k`T0X<?a102Wa_050:?6lP@0Z/O^1@2Tao850:C5l@@0Y<Ob1@2V`nh4
0:O5k`D0ZL7[2@2Y_^PJ0:Vmj08000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0E03ooolN0:Vm
j0T0YkgY102S_N`50:>nk0@0Wl3_1@2Q`>l40:33l@D0XL?a102Sa_850:;5l@@0Y<?_1@2TaO440:K2
k@@0Y/?^1@2X`>X30:W1j`H0ZKkX6`2Y_NP2000002/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05@0
oooo8`2Y_NP80:Nmj@D0Xkk/1@2T_^`40:Fnj`D0X/3^102T_nd40:?2k`D0YL3]102T`nl50:O0k0@0
Y/;]102X_nX50:S0jPD0ZKkX6P2Y_NP200000300oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0oooo
8`2Y_NP40:Rmj0h0YkgY102U_^/50:JnjP@0Y;o]102V_n/50:G0k@@0YkoZ102W`>`50:Rnj@@0Z;oZ
1@2Y_^PJ0:Vmj0<00000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo
000C0?ooo`030?oOW01807@0_ooo00l0oooo00<000000?ooo`3oool0E03ooolS0:Vmj0h0Z;gX102W
_NT40:Rmj@D0Y[kZ102X_^T40:Joj`D0Z;kY102W_nX40:Vnj@D0Z;kY102Y_NP30:Vnj1P0ZKgX0`00
000g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@0
0000B02L_i`0B01d0;ooo`0@0?ooo`800000E@3oool/0:Vmj0D0Z;gX102Y_NP40:Rmj@D0Z;gX102X
_^T40:Rmj0D0Z;kY102Y_NP40:VnjAl0ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?oo
o`1C0?ooocT0ZKgX102X_NP50:Vmj0@0Z;gX:02Y_NP300000400oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003oool0
oooo05<0ooooJ@2Y_NP4000004<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A
0?ooo`00:P3oool00`000000oooo0?ooo`1C0?ooofD0ZKgX0`0000180?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04@3oool002/0oooo0P00001D0?ooof00ZKgX00@0oooo00000000
00000000C03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000]0?ooo`03
0000003oool0oooo0580ooooG02Y_NP4000004l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?oooeP0ZKgX0`00001D0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool002l0oooo00<000000?ooo`3oool0DP3o
oomC0:Vmj0040?ooo`0000000000000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`00<03oool00`000000oooo0?ooo`1B0?ooodl0ZKgX1000001L0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04@3oool00340oooo0P00001C0?ooodX0ZKgX00@0oooo
0000000000000000H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000c
0?ooo`030000003oool0oooo0540ooooAP2Y_NP4000006@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`00=03oool00`000000oooo0?ooo`1A0?oood80ZKgX0`00001Y0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003D0oooo00<000000?ooo`3o
ool0D@3ooolm0:Vmj0040?ooo`0000000000000006`0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`00=P3oool200000580oooo>@2Y_NP400000700oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`00>03oool00`000000oooo0?ooo`1@0?ooocD0ZKgX
0`00001e0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool003T0oooo00<0
00000?ooo`3oool0D@3oool_0:Vmj0040?ooo`0000000000000007T0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A0?ooob/0ZKgX1000
001l0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool003/0oooo00<00000
0?ooo`3oool0D@3ooolW0:Vmj0<00000P@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00l0oooo000l0?ooo`800000DP3ooolR0:Vmj0040?ooo`0000000000000008D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`00?P3oool00`000000oooo0?ooo`1@0?oo
oah0ZKgX100000290?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool003l0
oooo00<000000?ooo`3oool0D03ooolJ0:Vmj0<00000S@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00l0oooo00100?ooo`030000003oool0oooo0500oooo5P2Y_NP300000940oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00@@3oool200000540oooo4P2Y
_NP3000009D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool0
0`000000oooo0?ooo`1?0?ooo`d0ZKgX0`00002I0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03`3oool004@0oooo00<000000?ooo`3oool0D03oool80:Vmj0<00000W@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo0500
oooo102Y_NP300000:40oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00
AP3oool200000540oooo0P00002V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool004P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool0
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004`0oooo
0P00001;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0>0?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`00C`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=
0?ooo`00D03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool2000004H0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo001C0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0[03oool01@000000oooo0?ooo`3oool0000000l0
oooo001D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0[P3oool010000000oooo
0?ooo`00000?0?ooo`00E@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:h0oooo
00@000000?ooo`3oool000003`3oool005H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0000000l0oooo001G0?ooo`800000?`3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0000000h0oooo001I0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0/@3oool2000000h0oooo001J0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0/@3oool2000000h0oooo001K0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0/@3oool2000000h0oooo001L0?ooo`800000>P3oool00`000000oooo0?ooo`2]0?ooo`@00000
403oool005h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Y0?ooo`@00000503o
ool005l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2U0?ooo`@00000603oool0
0600oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2Q0?ooo`@00000703oool00640
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2N0?ooo`<00000803oool00680oooo
0P00000d0?ooo`030000003oool0oooo09X0oooo1000000S0?ooo`00I03oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09H0oooo1000000W0?ooo`00I@3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0980oooo1000000[0?ooo`00IP3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo08h0oooo1000000_0?ooo`00I`3oool2000002l0oooo00<000000?ooo`3o
ool0RP3oool4000003<0oooo001Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
Q`3oool3000003L0oooo001Z0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0P`3o
ool4000003X0oooo001[0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0O`3oool4
000003h0oooo001/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0N`3oool40000
0480oooo001]0?ooo`800000:@3oool00`000000oooo0?ooo`1g0?ooo`@00000AP3oool006l0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1e0?ooo`<00000BP3oool00700oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`1a0?ooo`@00000C@3oool00740oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000D@3oool00780oooo0P00000S0?oo
o`030000003oool0oooo06T0oooo1000001E0?ooo`00M03oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo06D0oooo1000001I0?ooo`00M@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0680oooo0`00001M0?ooo`00MP3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo05h0oooo1000001P0?ooo`00M`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo05X0oooo1000001T0?ooo`00N03oool2000001d0oooo00<000000?ooo`3oool0EP3oool40000
06P0oooo001j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool4000006`0
oooo001k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool400000700oooo
001l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool3000007@0oooo001m
0?ooo`800000603oool00`000000oooo0?ooo`170?ooo`@00000M`3oool007l0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`130?ooo`@00000N`3oool00800oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0o0?ooo`@00000O`3oool00840oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0k0?ooo`@00000P`3oool00880oooo0P00000C0?ooo`030000003o
ool0oooo03P0oooo0`0000270?ooo`00Q03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo03@0oooo1000002:0?ooo`00Q@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0300oooo1000002>0?ooo`00QP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0
oooo1000002B0?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo
1000002F0?ooo`00R03oool2000000d0oooo00<000000?ooo`3oool09@3oool3000009X0oooo002:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool4000009d0oooo002;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000:40oooo002<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000:D0oooo002=0?ooo`800000
1`3oool00`000000oooo0?ooo`0F0?ooo`@00000Z@3oool008l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0B0?ooo`@00000[@3oool00900oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0?0?ooo`<00000/@3oool00940oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`@00000]03oool00980oooo00D000000?ooo`3oool0oooo000000090?oo
o`@00000^03oool009<0oooo0P0000000`3oool000000?ooo`040?ooo`@00000_03oool009D0oooo
0P0000000`3oool000000000000200000<00oooo002F0?ooo`800000a03oool00?l0ooooG@3oool0
0?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool0
0?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57074 Mtetra
.47319 .57074 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54049 .59388 .53425 Mtetra
.59388 .53425 .59961 .54049 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52402 Mtetra
.62773 .52402 .63336 .53033 .64471 .52692 .63911 .52058 Mtetra
.63911 .52058 .64471 .52692 .6561 .52349 .65053 .51713 Mtetra
.65053 .51713 .6561 .52349 .66754 .52005 .662 .51366 Mtetra
.662 .51366 .66754 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50264 .72005 .49611 Mtetra
.72005 .49611 .72542 .50264 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49557 .7436 .48899 Mtetra
.7436 .48899 .74891 .49557 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47093 Mtetra
.80335 .47093 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .4636 Mtetra
.8276 .4636 .83266 .47036 .84483 .4667 .83981 .4599 Mtetra
.83981 .4599 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44875 Mtetra
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44065 .92668 .43364 Mtetra
.92668 .43364 .93144 .44065 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .58411 Mtetra
.4033 .58411 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .5777 Mtetra
.4244 .5777 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57074 .46711 .56472 Mtetra
.46711 .56472 .47319 .57074 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53138 Mtetra
.5769 .53138 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52455 Mtetra
.59939 .52455 .60512 .53085 .6164 .52744 .6107 .52112 Mtetra
.664 .741 .908 r
.6107 .52112 .6164 .52744 .62773 .52402 .62206 .51767 Mtetra
.62206 .51767 .62773 .52402 .63911 .52058 .63347 .51421 Mtetra
.664 .742 .908 r
.63347 .51421 .63911 .52058 .65053 .51713 .64492 .51073 Mtetra
.664 .741 .908 r
.64492 .51073 .65053 .51713 .662 .51366 .65642 .50725 Mtetra
.664 .742 .908 r
.65642 .50725 .662 .51366 .67351 .51018 .66797 .50374 Mtetra
.66797 .50374 .67351 .51018 .68508 .50668 .67956 .50021 Mtetra
.664 .741 .908 r
.67956 .50021 .68508 .50668 .69669 .50317 .69121 .49668 Mtetra
.664 .742 .908 r
.69121 .49668 .69669 .50317 .70834 .49965 .7029 .49312 Mtetra
.664 .741 .908 r
.7029 .49312 .70834 .49965 .72005 .49611 .71463 .48955 Mtetra
.71463 .48955 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.664 .741 .907 r
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48237 Mtetra
.73826 .48237 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47093 .79818 .46416 Mtetra
.79818 .46416 .80335 .47093 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .4636 .82251 .45677 Mtetra
.82251 .45677 .8276 .4636 .83981 .4599 .83475 .45305 Mtetra
.83475 .45305 .83981 .4599 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44875 .87177 .44181 Mtetra
.87177 .44181 .87672 .44875 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .58411 .39701 .57819 Mtetra
.39701 .57819 .4033 .58411 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .5777 .41817 .57173 Mtetra
.41817 .57173 .4244 .5777 .43501 .57447 .42881 .56849 Mtetra
.42881 .56849 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55867 Mtetra
.46098 .55867 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .5285 Mtetra
.664 .741 .908 r
.55985 .5285 .56572 .53477 .5769 .53138 .57106 .52508 Mtetra
.57106 .52508 .5769 .53138 .58812 .52797 .58231 .52166 Mtetra
.663 .741 .908 r
.58231 .52166 .58812 .52797 .59939 .52455 .59361 .51823 Mtetra
.663 .742 .909 r
.59361 .51823 .59939 .52455 .6107 .52112 .60496 .51479 Mtetra
.60496 .51479 .6107 .52112 .62206 .51767 .61635 .51134 Mtetra
.663 .743 .91 r
.61635 .51134 .62206 .51767 .63347 .51421 .62779 .50787 Mtetra
.663 .744 .91 r
.62779 .50787 .63347 .51421 .64492 .51073 .63927 .50439 Mtetra
.63927 .50439 .64492 .51073 .65642 .50725 .65081 .50088 Mtetra
.664 .745 .91 r
.65081 .50088 .65642 .50725 .66797 .50374 .66239 .49735 Mtetra
.66239 .49735 .66797 .50374 .67956 .50021 .67401 .49379 Mtetra
.67401 .49379 .67956 .50021 .69121 .49668 .68569 .4902 Mtetra
.665 .744 .909 r
.68569 .4902 .69121 .49668 .7029 .49312 .69741 .4866 Mtetra
.69741 .4866 .7029 .49312 .71463 .48955 .70918 .48298 Mtetra
.664 .743 .908 r
.70918 .48298 .71463 .48955 .72642 .48596 .721 .47935 Mtetra
.664 .742 .908 r
.721 .47935 .72642 .48596 .73826 .48237 .73287 .47571 Mtetra
.73287 .47571 .73826 .48237 .75014 .47875 .74479 .47206 Mtetra
.664 .741 .908 r
.74479 .47206 .75014 .47875 .76208 .47513 .75676 .4684 Mtetra
.664 .741 .907 r
.75676 .4684 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83475 .45305 .82964 .44615 Mtetra
.82964 .44615 .83475 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .4156 Mtetra
.92976 .4156 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56849 .42256 .56246 Mtetra
.42256 .56246 .42881 .56849 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55867 .45481 .55256 Mtetra
.45481 .55256 .46098 .55867 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.663 .741 .908 r
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .52562 Mtetra
.54275 .52562 .54869 .5319 .55985 .5285 .55394 .52221 Mtetra
.662 .742 .909 r
.55394 .52221 .55985 .5285 .57106 .52508 .56518 .51881 Mtetra
.662 .742 .91 r
.56518 .51881 .57106 .52508 .58231 .52166 .57646 .51541 Mtetra
.661 .744 .912 r
.57646 .51541 .58231 .52166 .59361 .51823 .58779 .51202 Mtetra
.66 .746 .914 r
.58779 .51202 .59361 .51823 .60496 .51479 .59917 .50864 Mtetra
.66 .749 .916 r
.59917 .50864 .60496 .51479 .61635 .51134 .6106 .50524 Mtetra
.66 .751 .918 r
.6106 .50524 .61635 .51134 .62779 .50787 .62207 .50182 Mtetra
.661 .754 .919 r
.62207 .50182 .62779 .50787 .63927 .50439 .63359 .49836 Mtetra
.662 .756 .92 r
.63359 .49836 .63927 .50439 .65081 .50088 .64516 .49486 Mtetra
.663 .757 .92 r
.64516 .49486 .65081 .50088 .66239 .49735 .65678 .4913 Mtetra
.664 .758 .92 r
.65678 .4913 .66239 .49735 .67401 .49379 .66844 .48768 Mtetra
.666 .757 .919 r
.66844 .48768 .67401 .49379 .68569 .4902 .68014 .48402 Mtetra
.667 .756 .917 r
.68014 .48402 .68569 .4902 .69741 .4866 .6919 .48031 Mtetra
.667 .753 .915 r
.6919 .48031 .69741 .4866 .70918 .48298 .7037 .47659 Mtetra
.667 .751 .913 r
.7037 .47659 .70918 .48298 .721 .47935 .71555 .47285 Mtetra
.666 .748 .911 r
.71555 .47285 .721 .47935 .73287 .47571 .72745 .46911 Mtetra
.666 .746 .91 r
.72745 .46911 .73287 .47571 .74479 .47206 .7394 .46538 Mtetra
.665 .744 .909 r
.7394 .46538 .74479 .47206 .75676 .4684 .7514 .46165 Mtetra
.665 .742 .908 r
.7514 .46165 .75676 .4684 .76878 .46473 .76346 .45793 Mtetra
.664 .742 .908 r
.76346 .45793 .76878 .46473 .78085 .46104 .77556 .45421 Mtetra
.664 .741 .907 r
.77556 .45421 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .4156 .92493 .40839 Mtetra
.92493 .40839 .92976 .4156 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52955 Mtetra
.663 .741 .908 r
.50337 .52955 .50944 .53581 .5205 .53242 .51445 .52614 Mtetra
.51445 .52614 .5205 .53242 .5316 .52902 .52558 .52274 Mtetra
.662 .741 .909 r
.52558 .52274 .5316 .52902 .54275 .52562 .53676 .51936 Mtetra
.66 .743 .911 r
.53676 .51936 .54275 .52562 .55394 .52221 .54798 .51601 Mtetra
.658 .745 .914 r
.54798 .51601 .55394 .52221 .56518 .51881 .55925 .51271 Mtetra
.656 .748 .918 r
.55925 .51271 .56518 .51881 .57646 .51541 .57057 .50945 Mtetra
.654 .753 .923 r
.57057 .50945 .57646 .51541 .58779 .51202 .58194 .50622 Mtetra
.653 .759 .928 r
.58194 .50622 .58779 .51202 .59917 .50864 .59336 .50298 Mtetra
.653 .765 .932 r
.59336 .50298 .59917 .50864 .6106 .50524 .60482 .4997 Mtetra
.654 .771 .935 r
.60482 .4997 .6106 .50524 .62207 .50182 .61633 .49636 Mtetra
.656 .775 .936 r
.61633 .49636 .62207 .50182 .63359 .49836 .62789 .49294 Mtetra
.658 .778 .937 r
.62789 .49294 .63359 .49836 .64516 .49486 .63949 .48944 Mtetra
.661 .78 .937 r
.63949 .48944 .64516 .49486 .65678 .4913 .65114 .48585 Mtetra
.663 .78 .936 r
.65114 .48585 .65678 .4913 .66844 .48768 .66284 .48218 Mtetra
.666 .78 .934 r
.66284 .48218 .66844 .48768 .68014 .48402 .67458 .47843 Mtetra
.668 .779 .932 r
.67458 .47843 .68014 .48402 .6919 .48031 .68637 .47459 Mtetra
.671 .776 .929 r
.68637 .47459 .6919 .48031 .7037 .47659 .6982 .4707 Mtetra
.672 .771 .925 r
.6982 .4707 .7037 .47659 .71555 .47285 .71008 .46675 Mtetra
.672 .765 .921 r
.71008 .46675 .71555 .47285 .72745 .46911 .72201 .46281 Mtetra
.671 .759 .916 r
.72201 .46281 .72745 .46911 .7394 .46538 .73398 .45888 Mtetra
.669 .753 .913 r
.73398 .45888 .7394 .46538 .7514 .46165 .74601 .455 Mtetra
.667 .748 .911 r
.74601 .455 .7514 .46165 .76346 .45793 .7581 .45116 Mtetra
.666 .744 .909 r
.7581 .45116 .76346 .45793 .77556 .45421 .77024 .44735 Mtetra
.665 .742 .908 r
.77024 .44735 .77556 .45421 .78772 .45047 .78243 .44357 Mtetra
.664 .741 .908 r
.78243 .44357 .78772 .45047 .79993 .44673 .79467 .43978 Mtetra
.664 .741 .907 r
.79467 .43978 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53007 Mtetra
.47515 .53007 .48133 .53633 .49232 .53294 .48618 .52666 Mtetra
.663 .741 .908 r
.48618 .52666 .49232 .53294 .50337 .52955 .49725 .52326 Mtetra
.662 .741 .909 r
.49725 .52326 .50337 .52955 .51445 .52614 .50836 .51988 Mtetra
.659 .742 .911 r
.50836 .51988 .51445 .52614 .52558 .52274 .51952 .51655 Mtetra
.656 .744 .915 r
.51952 .51655 .52558 .52274 .53676 .51936 .53073 .51331 Mtetra
.651 .748 .921 r
.53073 .51331 .53676 .51936 .54798 .51601 .54199 .51016 Mtetra
.647 .755 .928 r
.54199 .51016 .54798 .51601 .55925 .51271 .55329 .50709 Mtetra
.645 .763 .935 r
.55329 .50709 .55925 .51271 .57057 .50945 .56464 .50403 Mtetra
.646 .771 .94 r
.56464 .50403 .57057 .50945 .58194 .50622 .57605 .50091 Mtetra
.65 .777 .941 r
.57605 .50091 .58194 .50622 .59336 .50298 .5875 .49765 Mtetra
.654 .779 .94 r
.5875 .49765 .59336 .50298 .60482 .4997 .59899 .49425 Mtetra
.659 .777 .936 r
.59899 .49425 .60482 .4997 .61633 .49636 .61054 .49073 Mtetra
.662 .772 .931 r
.61054 .49073 .61633 .49636 .62789 .49294 .62213 .48713 Mtetra
.663 .767 .927 r
.62213 .48713 .62789 .49294 .63949 .48944 .63376 .48351 Mtetra
.663 .764 .925 r
.63376 .48351 .63949 .48944 .65114 .48585 .64545 .4799 Mtetra
.662 .764 .926 r
.64545 .4799 .65114 .48585 .66284 .48218 .65719 .47629 Mtetra
.662 .767 .928 r
.65719 .47629 .66284 .48218 .67458 .47843 .66897 .47266 Mtetra
.663 .773 .931 r
.66897 .47266 .67458 .47843 .68637 .47459 .6808 .46896 Mtetra
.667 .779 .933 r
.6808 .46896 .68637 .47459 .6982 .4707 .69268 .46513 Mtetra
.671 .784 .934 r
.69268 .46513 .6982 .4707 .71008 .46675 .7046 .46115 Mtetra
.675 .785 .932 r
.7046 .46115 .71008 .46675 .72201 .46281 .71655 .45704 Mtetra
.677 .781 .928 r
.71655 .45704 .72201 .46281 .73398 .45888 .72856 .45286 Mtetra
.677 .773 .923 r
.72856 .45286 .73398 .45888 .74601 .455 .74061 .44869 Mtetra
.674 .763 .918 r
.74061 .44869 .74601 .455 .7581 .45116 .75271 .44459 Mtetra
.671 .754 .913 r
.75271 .44459 .7581 .45116 .77024 .44735 .76488 .44058 Mtetra
.668 .748 .91 r
.76488 .44058 .77024 .44735 .78243 .44357 .7771 .43667 Mtetra
.666 .744 .909 r
.7771 .43667 .78243 .44357 .79467 .43978 .78938 .4328 Mtetra
.665 .742 .908 r
.78938 .4328 .79467 .43978 .80697 .43598 .80171 .42896 Mtetra
.664 .741 .907 r
.80171 .42896 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54745 Mtetra
.39278 .54745 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.663 .741 .908 r
.45792 .52718 .46417 .53347 .47515 .53007 .46893 .52377 Mtetra
.46893 .52377 .47515 .53007 .48618 .52666 .47998 .52036 Mtetra
.66 .741 .91 r
.47998 .52036 .48618 .52666 .49725 .52326 .49108 .51701 Mtetra
.656 .742 .913 r
.49108 .51701 .49725 .52326 .50836 .51988 .50222 .51376 Mtetra
.65 .746 .919 r
.50222 .51376 .50836 .51988 .51952 .51655 .51341 .51065 Mtetra
.644 .752 .928 r
.51341 .51065 .51952 .51655 .53073 .51331 .52465 .50769 Mtetra
.64 .761 .936 r
.52465 .50769 .53073 .51331 .54199 .51016 .53594 .50476 Mtetra
.642 .771 .941 r
.53594 .50476 .54199 .51016 .55329 .50709 .54728 .50172 Mtetra
.653 .776 .939 r
.54728 .50172 .55329 .50709 .56464 .50403 .55866 .49838 Mtetra
.668 .771 .927 r
.55866 .49838 .56464 .50403 .57605 .50091 .57009 .49466 Mtetra
.68 .755 .908 r
.57009 .49466 .57605 .50091 .5875 .49765 .58156 .4906 Mtetra
.685 .733 .887 r
.58156 .4906 .5875 .49765 .59899 .49425 .59307 .48631 Mtetra
.682 .709 .868 r
.59307 .48631 .59899 .49425 .61054 .49073 .60462 .48198 Mtetra
.672 .687 .855 r
.60462 .48198 .61054 .49073 .62213 .48713 .61622 .47792 Mtetra
.66 .672 .851 r
.61622 .47792 .62213 .48713 .63376 .48351 .62789 .47429 Mtetra
.62789 .47429 .63376 .48351 .64545 .4799 .6396 .47064 Mtetra
.6396 .47064 .64545 .4799 .65719 .47629 .65136 .46698 Mtetra
.648 .667 .854 r
.65136 .46698 .65719 .47629 .66897 .47266 .66318 .46376 Mtetra
.642 .674 .866 r
.66318 .46376 .66897 .47266 .6808 .46896 .67508 .46081 Mtetra
.642 .694 .883 r
.67508 .46081 .6808 .46896 .69268 .46513 .68702 .45782 Mtetra
.648 .721 .901 r
.68702 .45782 .69268 .46513 .7046 .46115 .69902 .4546 Mtetra
.658 .749 .917 r
.69902 .4546 .7046 .46115 .71655 .45704 .71104 .45103 Mtetra
.669 .772 .927 r
.71104 .45103 .71655 .45704 .72856 .45286 .7231 .44708 Mtetra
.678 .783 .929 r
.7231 .44708 .72856 .45286 .74061 .44869 .73519 .44283 Mtetra
.682 .783 .927 r
.73519 .44283 .74061 .44869 .75271 .44459 .74732 .43845 Mtetra
.68 .774 .922 r
.74732 .43845 .75271 .44459 .76488 .44058 .7595 .43411 Mtetra
.676 .762 .916 r
.7595 .43411 .76488 .44058 .7771 .43667 .77174 .42991 Mtetra
.671 .752 .912 r
.77174 .42991 .7771 .43667 .78938 .4328 .78405 .42586 Mtetra
.667 .746 .909 r
.78405 .42586 .78938 .4328 .80171 .42896 .79641 .4219 Mtetra
.665 .743 .908 r
.79641 .4219 .80171 .42896 .8141 .42511 .80883 .418 Mtetra
.664 .741 .908 r
.80883 .418 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.664 .741 .907 r
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54745 .38632 .54126 Mtetra
.38632 .54126 .39278 .54745 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.663 .741 .908 r
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52086 Mtetra
.662 .741 .908 r
.45162 .52086 .45792 .52718 .46893 .52377 .46266 .51746 Mtetra
.659 .741 .911 r
.46266 .51746 .46893 .52377 .47998 .52036 .47374 .51414 Mtetra
.653 .743 .916 r
.47374 .51414 .47998 .52036 .49108 .51701 .48486 .51096 Mtetra
.644 .747 .924 r
.48486 .51096 .49108 .51701 .50222 .51376 .49603 .50799 Mtetra
.637 .755 .934 r
.49603 .50799 .50222 .51376 .51341 .51065 .50725 .50516 Mtetra
.638 .766 .94 r
.50725 .50516 .51341 .51065 .52465 .50769 .51852 .50224 Mtetra
.654 .773 .937 r
.51852 .50224 .52465 .50769 .53594 .50476 .52985 .4989 Mtetra
.68 .767 .917 r
.52985 .4989 .53594 .50476 .54728 .50172 .54121 .49485 Mtetra
.701 .742 .883 r
.54121 .49485 .54728 .50172 .55866 .49838 .55261 .49 Mtetra
.681 .697 .858 r
.55261 .49 .55866 .49838 .57009 .49466 .56406 .48568 Mtetra
.66 .676 .854 r
.56406 .48568 .57009 .49466 .58156 .4906 .57556 .48208 Mtetra
.661 .688 .864 r
.57556 .48208 .58156 .4906 .59307 .48631 .58711 .47847 Mtetra
.663 .707 .88 r
.58711 .47847 .59307 .48631 .60462 .48198 .59871 .47485 Mtetra
.664 .727 .897 r
.59871 .47485 .60462 .48198 .61622 .47792 .61035 .47121 Mtetra
.664 .741 .907 r
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66318 .46376 .65742 .45649 Mtetra
.664 .727 .897 r
.65742 .45649 .66318 .46376 .67508 .46081 .66932 .45277 Mtetra
.663 .707 .88 r
.66932 .45277 .67508 .46081 .68702 .45782 .68126 .44903 Mtetra
.661 .688 .864 r
.68126 .44903 .68702 .45782 .69902 .4546 .69325 .44528 Mtetra
.641 .668 .86 r
.69325 .44528 .69902 .4546 .71104 .45103 .70534 .44227 Mtetra
.626 .675 .877 r
.70534 .44227 .71104 .45103 .7231 .44708 .71751 .43978 Mtetra
.648 .725 .905 r
.71751 .43978 .7231 .44708 .73519 .44283 .7297 .4365 Mtetra
.669 .764 .922 r
.7297 .4365 .73519 .44283 .74732 .43845 .7419 .43249 Mtetra
.682 .782 .926 r
.7419 .43249 .74732 .43845 .7595 .43411 .75411 .42805 Mtetra
.685 .781 .923 r
.75411 .42805 .7595 .43411 .77174 .42991 .76637 .42351 Mtetra
.68 .769 .918 r
.76637 .42351 .77174 .42991 .78405 .42586 .77869 .41911 Mtetra
.673 .756 .913 r
.77869 .41911 .78405 .42586 .79641 .4219 .79108 .41492 Mtetra
.668 .748 .91 r
.79108 .41492 .79641 .4219 .80883 .418 .80353 .41087 Mtetra
.665 .743 .908 r
.80353 .41087 .80883 .418 .82131 .4141 .81605 .40691 Mtetra
.664 .742 .908 r
.81605 .40691 .82131 .4141 .83385 .4102 .82862 .40296 Mtetra
.664 .741 .907 r
.82862 .40296 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.663 .741 .908 r
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51794 Mtetra
.662 .741 .909 r
.43425 .51794 .44063 .52428 .45162 .52086 .44527 .51453 Mtetra
.658 .741 .911 r
.44527 .51453 .45162 .52086 .46266 .51746 .45634 .51123 Mtetra
.651 .743 .917 r
.45634 .51123 .46266 .51746 .47374 .51414 .46744 .50811 Mtetra
.64 .747 .927 r
.46744 .50811 .47374 .51414 .48486 .51096 .47859 .50525 Mtetra
.633 .757 .937 r
.47859 .50525 .48486 .51096 .49603 .50799 .48979 .5025 Mtetra
.643 .768 .939 r
.48979 .5025 .49603 .50799 .50725 .50516 .50105 .49944 Mtetra
.676 .77 .922 r
.50105 .49944 .50725 .50516 .51852 .50224 .51235 .49551 Mtetra
.71 .748 .881 r
.51235 .49551 .51852 .50224 .52985 .4989 .5237 .49032 Mtetra
.674 .69 .857 r
.5237 .49032 .52985 .4989 .54121 .49485 .53509 .48623 Mtetra
.661 .685 .862 r
.53509 .48623 .54121 .49485 .55261 .49 .54653 .48264 Mtetra
.664 .719 .89 r
.54653 .48264 .55261 .49 .56406 .48568 .55801 .47903 Mtetra
.664 .741 .907 r
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .70534 .44227 .69965 .43452 Mtetra
.664 .719 .89 r
.69965 .43452 .70534 .44227 .71751 .43978 .71178 .43071 Mtetra
.648 .679 .866 r
.71178 .43071 .71751 .43978 .7297 .4365 .724 .4274 Mtetra
.615 .665 .875 r
.724 .4274 .7297 .4365 .7419 .43249 .73634 .42521 Mtetra
.652 .731 .907 r
.73634 .42521 .7419 .43249 .75411 .42805 .74867 .42174 Mtetra
.679 .772 .921 r
.74867 .42174 .75411 .42805 .76637 .42351 .76098 .41738 Mtetra
.688 .782 .923 r
.76098 .41738 .76637 .42351 .77869 .41911 .77333 .4127 Mtetra
.684 .772 .918 r
.77333 .4127 .77869 .41911 .79108 .41492 .78573 .40813 Mtetra
.676 .758 .913 r
.78573 .40813 .79108 .41492 .80353 .41087 .7982 .40381 Mtetra
.669 .748 .91 r
.7982 .40381 .80353 .41087 .81605 .40691 .81074 .39969 Mtetra
.666 .743 .908 r
.81074 .39969 .81605 .40691 .82862 .40296 .82335 .39567 Mtetra
.664 .742 .908 r
.82335 .39567 .82862 .40296 .84124 .39901 .83601 .39167 Mtetra
.664 .741 .907 r
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51846 Mtetra
.663 .741 .908 r
.40586 .51846 .41234 .52481 .42327 .52137 .41682 .51501 Mtetra
.662 .741 .908 r
.41682 .51501 .42327 .52137 .43425 .51794 .42783 .51159 Mtetra
.658 .741 .911 r
.42783 .51159 .43425 .51794 .44527 .51453 .43887 .50827 Mtetra
.649 .742 .917 r
.43887 .50827 .44527 .51453 .45634 .51123 .44996 .50518 Mtetra
.636 .746 .928 r
.44996 .50518 .45634 .51123 .46744 .50811 .46109 .5024 Mtetra
.63 .757 .938 r
.46109 .5024 .46744 .50811 .47859 .50525 .47227 .49969 Mtetra
.651 .769 .935 r
.47227 .49969 .47859 .50525 .48979 .5025 .48351 .49643 Mtetra
.698 .765 .903 r
.48351 .49643 .48979 .5025 .50105 .49944 .4948 .49179 Mtetra
.701 .721 .865 r
.4948 .49179 .50105 .49944 .51235 .49551 .50614 .48678 Mtetra
.661 .682 .859 r
.50614 .48678 .51235 .49551 .5237 .49032 .51752 .48319 Mtetra
.664 .726 .895 r
.51752 .48319 .5237 .49032 .53509 .48623 .52894 .47959 Mtetra
.664 .741 .907 r
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .724 .4274 .71835 .41977 Mtetra
.664 .726 .895 r
.71835 .41977 .724 .4274 .73634 .42521 .73062 .41589 Mtetra
.622 .665 .871 r
.73062 .41589 .73634 .42521 .74867 .42174 .74305 .41346 Mtetra
.631 .696 .892 r
.74305 .41346 .74867 .42174 .76098 .41738 .75551 .41066 Mtetra
.673 .759 .916 r
.75551 .41066 .76098 .41738 .77333 .4127 .76793 .40644 Mtetra
.69 .781 .921 r
.76793 .40644 .77333 .4127 .78573 .40813 .78036 .40165 Mtetra
.687 .774 .918 r
.78036 .40165 .78573 .40813 .7982 .40381 .79284 .39694 Mtetra
.677 .759 .913 r
.79284 .39694 .7982 .40381 .81074 .39969 .8054 .39254 Mtetra
.669 .748 .91 r
.8054 .39254 .81074 .39969 .82335 .39567 .81804 .38836 Mtetra
.666 .743 .908 r
.81804 .38836 .82335 .39567 .83601 .39167 .83074 .38429 Mtetra
.664 .741 .907 r
.83074 .38429 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92127 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52243 Mtetra
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51846 .39934 .51206 Mtetra
.662 .741 .908 r
.39934 .51206 .40586 .51846 .41682 .51501 .41032 .50862 Mtetra
.658 .74 .91 r
.41032 .50862 .41682 .51501 .42783 .51159 .42135 .50528 Mtetra
.649 .741 .917 r
.42135 .50528 .42783 .51159 .43887 .50827 .43242 .50217 Mtetra
.635 .745 .927 r
.43242 .50217 .43887 .50827 .44996 .50518 .44353 .49941 Mtetra
.628 .755 .938 r
.44353 .49941 .44996 .50518 .46109 .5024 .45468 .49674 Mtetra
.656 .768 .932 r
.45468 .49674 .46109 .5024 .47227 .49969 .46591 .49335 Mtetra
.714 .76 .889 r
.46591 .49335 .47227 .49969 .48351 .49643 .4772 .4881 Mtetra
.682 .699 .86 r
.4772 .4881 .48351 .49643 .4948 .49179 .48852 .48375 Mtetra
.662 .7 .875 r
.48852 .48375 .4948 .49179 .50614 .48678 .49988 .48014 Mtetra
.664 .741 .907 r
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74305 .41346 .73736 .40477 Mtetra
.641 .691 .881 r
.73736 .40477 .74305 .41346 .75551 .41066 .74983 .40162 Mtetra
.614 .671 .881 r
.74983 .40162 .75551 .41066 .76793 .40644 .76243 .39937 Mtetra
.669 .75 .911 r
.76243 .39937 .76793 .40644 .78036 .40165 .77495 .39523 Mtetra
.691 .779 .918 r
.77495 .39523 .78036 .40165 .79284 .39694 .78747 .39034 Mtetra
.688 .773 .916 r
.78747 .39034 .79284 .39694 .8054 .39254 .80004 .38554 Mtetra
.677 .758 .912 r
.80004 .38554 .8054 .39254 .81804 .38836 .81269 .38109 Mtetra
.669 .747 .909 r
.81269 .38109 .81804 .38836 .83074 .38429 .82543 .37688 Mtetra
.665 .742 .908 r
.82543 .37688 .83074 .38429 .8435 .38025 .83822 .37277 Mtetra
.664 .741 .907 r
.83822 .37277 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92127 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .50911 Mtetra
.663 .741 .908 r
.38179 .50911 .38839 .51553 .39934 .51206 .39276 .50564 Mtetra
.66 .74 .91 r
.39276 .50564 .39934 .51206 .41032 .50862 .40377 .50224 Mtetra
.651 .741 .915 r
.40377 .50224 .41032 .50862 .42135 .50528 .41482 .49908 Mtetra
.636 .743 .925 r
.41482 .49908 .42135 .50528 .43242 .50217 .42591 .49629 Mtetra
.626 .751 .937 r
.42591 .49629 .43242 .50217 .44353 .49941 .43704 .49368 Mtetra
.654 .765 .931 r
.43704 .49368 .44353 .49941 .45468 .49674 .44824 .49033 Mtetra
.72 .76 .884 r
.44824 .49033 .45468 .49674 .46591 .49335 .45954 .48481 Mtetra
.674 .692 .859 r
.45954 .48481 .46591 .49335 .4772 .4881 .47084 .4807 Mtetra
.663 .718 .889 r
.47084 .4807 .4772 .4881 .48852 .48375 .48218 .47708 Mtetra
.664 .741 .907 r
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.542 .696 .94 r
.53959 .45877 .54578 .46557 .55738 .46189 .55125 .45809 Mtetra
.264 .673 .967 r
.55125 .45809 .55738 .46189 .56902 .4582 .56299 .45936 Mtetra
.111 0 0 r
.56299 .45936 .56902 .4582 .58072 .45449 .5748 .45921 Mtetra
.262 0 0 r
.5748 .45921 .58072 .45449 .59246 .45076 .58667 .45771 Mtetra
.289 0 0 r
.58667 .45771 .59246 .45076 .60425 .44702 .59857 .45502 Mtetra
.271 0 0 r
.59857 .45502 .60425 .44702 .6161 .44326 .6105 .45125 Mtetra
.211 0 0 r
.6105 .45125 .6161 .44326 .62799 .43948 .62245 .44639 Mtetra
.074 0 0 r
.62245 .44639 .62799 .43948 .63994 .43569 .63441 .44032 Mtetra
0 0 0 r
.63441 .44032 .63994 .43569 .65193 .43188 .64635 .43289 Mtetra
.713 .987 .85 r
.64635 .43289 .65193 .43188 .66398 .42806 .65825 .42401 Mtetra
.758 .869 .929 r
.65825 .42401 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.664 .741 .907 r
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74983 .40162 .74418 .39351 Mtetra
.648 .712 .894 r
.74418 .39351 .74983 .40162 .76243 .39937 .75673 .39005 Mtetra
.606 .663 .879 r
.75673 .39005 .76243 .39937 .77495 .39523 .76944 .38802 Mtetra
.671 .749 .909 r
.76944 .38802 .77495 .39523 .78747 .39034 .78205 .38377 Mtetra
.694 .778 .916 r
.78205 .38377 .78747 .39034 .80004 .38554 .79465 .37875 Mtetra
.687 .77 .915 r
.79465 .37875 .80004 .38554 .81269 .38109 .80732 .37392 Mtetra
.675 .755 .911 r
.80732 .37392 .81269 .38109 .82543 .37688 .82007 .36947 Mtetra
.668 .745 .909 r
.82007 .36947 .82543 .37688 .83822 .37277 .83291 .36525 Mtetra
.665 .742 .908 r
.83291 .36525 .83822 .37277 .85108 .36868 .8458 .3611 Mtetra
.664 .741 .907 r
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.663 .741 .908 r
.36418 .50614 .37086 .51259 .38179 .50911 .37513 .50265 Mtetra
.661 .741 .909 r
.37513 .50265 .38179 .50911 .39276 .50564 .38613 .4992 Mtetra
.654 .74 .913 r
.38613 .4992 .39276 .50564 .40377 .50224 .39716 .49594 Mtetra
.639 .741 .922 r
.39716 .49594 .40377 .50224 .41482 .49908 .40823 .49305 Mtetra
.625 .747 .934 r
.40823 .49305 .41482 .49908 .42591 .49629 .41934 .49048 Mtetra
.645 .761 .933 r
.41934 .49048 .42591 .49629 .43704 .49368 .43052 .48737 Mtetra
.716 .762 .889 r
.43052 .48737 .43704 .49368 .44824 .49033 .4418 .48202 Mtetra
.682 .701 .861 r
.4418 .48202 .44824 .49033 .45954 .48481 .45309 .47764 Mtetra
.664 .726 .895 r
.45309 .47764 .45954 .48481 .47084 .4807 .46442 .47401 Mtetra
.664 .741 .907 r
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.472 .666 .947 r
.51018 .45934 .51648 .46614 .52801 .46246 .52174 .4599 Mtetra
0 .426 .748 r
.52174 .4599 .52801 .46246 .53959 .45877 .53339 .46352 Mtetra
.449 0 0 r
.53339 .46352 .53959 .45877 .55125 .45809 .54512 .46511 Mtetra
.41 0 .037 r
.54512 .46511 .55125 .45809 .56299 .45936 .55693 .4648 Mtetra
.275 0 0 r
.55693 .4648 .56299 .45936 .5748 .45921 .56879 .46303 Mtetra
.094 0 0 r
.56879 .46303 .5748 .45921 .58667 .45771 .5807 .46028 Mtetra
0 0 0 r
.5807 .46028 .58667 .45771 .59857 .45502 .59265 .45692 Mtetra
.59265 .45692 .59857 .45502 .6105 .45125 .60465 .45313 Mtetra
.255 .753 .69 r
.60465 .45313 .6105 .45125 .62245 .44639 .61669 .4489 Mtetra
0 0 0 r
.61669 .4489 .62245 .44639 .63441 .44032 .62876 .44404 Mtetra
.62876 .44404 .63441 .44032 .64635 .43289 .64084 .43821 Mtetra
.64084 .43821 .64635 .43289 .65825 .42401 .6529 .43089 Mtetra
.6529 .43089 .65825 .42401 .67026 .41709 .66491 .42163 Mtetra
.541 .859 .566 r
.66491 .42163 .67026 .41709 .68245 .4132 .67683 .41031 Mtetra
.792 .918 .923 r
.67683 .41031 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.664 .741 .907 r
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75673 .39005 .75109 .38211 Mtetra
.64 .716 .903 r
.75109 .38211 .75673 .39005 .76944 .38802 .76375 .37886 Mtetra
.611 .672 .884 r
.76375 .37886 .76944 .38802 .78205 .38377 .77655 .3766 Mtetra
.678 .756 .909 r
.77655 .3766 .78205 .38377 .79465 .37875 .78923 .37204 Mtetra
.695 .777 .915 r
.78923 .37204 .79465 .37875 .80732 .37392 .80192 .36692 Mtetra
.685 .765 .913 r
.80192 .36692 .80732 .37392 .82007 .36947 .81469 .36212 Mtetra
.672 .751 .91 r
.81469 .36212 .82007 .36947 .83291 .36525 .82755 .3577 Mtetra
.666 .744 .908 r
.82755 .3577 .83291 .36525 .8458 .3611 .84048 .35347 Mtetra
.664 .741 .907 r
.84048 .35347 .8458 .3611 .85876 .35696 .85348 .34929 Mtetra
.85348 .34929 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.663 .741 .908 r
.35745 .49965 .36418 .50614 .37513 .50265 .36843 .49616 Mtetra
.658 .74 .911 r
.36843 .49616 .37513 .50265 .38613 .4992 .37945 .49278 Mtetra
.645 .74 .918 r
.37945 .49278 .38613 .4992 .39716 .49594 .3905 .48974 Mtetra
.626 .742 .93 r
.3905 .48974 .39716 .49594 .40823 .49305 .40158 .48713 Mtetra
.632 .754 .936 r
.40158 .48713 .40823 .49305 .41934 .49048 .41273 .48433 Mtetra
.699 .764 .903 r
.41273 .48433 .41934 .49048 .43052 .48737 .42398 .47963 Mtetra
.701 .721 .865 r
.42398 .47963 .43052 .48737 .4418 .48202 .43528 .47457 Mtetra
.663 .718 .89 r
.43528 .47457 .4418 .48202 .45309 .47764 .44659 .47092 Mtetra
.664 .741 .907 r
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.072 .439 .876 r
.49229 .4562 .49867 .46303 .51018 .45934 .50378 .46173 Mtetra
.512 0 0 r
.50378 .46173 .51018 .45934 .52174 .4599 .51538 .46571 Mtetra
.446 0 .005 r
.51538 .46571 .52174 .4599 .53339 .46352 .52709 .46677 Mtetra
.169 0 0 r
.52709 .46677 .53339 .46352 .54512 .46511 .53887 .46542 Mtetra
.314 .805 .842 r
.53887 .46542 .54512 .46511 .55693 .4648 .55071 .46249 Mtetra
.592 .888 .991 r
.55071 .46249 .55693 .4648 .56879 .46303 .56259 .45876 Mtetra
.657 .835 .969 r
.56259 .45876 .56879 .46303 .5807 .46028 .57452 .45474 Mtetra
.665 .791 .942 r
.57452 .45474 .5807 .46028 .59265 .45692 .58651 .45074 Mtetra
.661 .769 .93 r
.58651 .45074 .59265 .45692 .60465 .45313 .59854 .44692 Mtetra
.654 .767 .932 r
.59854 .44692 .60465 .45313 .61669 .4489 .61064 .44326 Mtetra
.649 .786 .947 r
.61064 .44326 .61669 .4489 .62876 .44404 .62279 .43964 Mtetra
.648 .832 .971 r
.62279 .43964 .62876 .44404 .64084 .43821 .63498 .43572 Mtetra
.644 .904 .983 r
.63498 .43572 .64084 .43821 .6529 .43089 .6472 .43099 Mtetra
.607 .952 .904 r
.6472 .43099 .6529 .43089 .66491 .42163 .6594 .42466 Mtetra
.516 .885 .676 r
.6594 .42466 .66491 .42163 .67683 .41031 .67153 .41588 Mtetra
0 0 0 r
.67153 .41588 .67683 .41031 .6889 .40204 .68352 .40412 Mtetra
.82 .995 .756 r
.68352 .40412 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.664 .741 .907 r
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76375 .37886 .75808 .37056 Mtetra
.619 .7 .902 r
.75808 .37056 .76375 .37886 .77655 .3766 .77089 .36795 Mtetra
.63 .696 .892 r
.77089 .36795 .77655 .3766 .78923 .37204 .78374 .36497 Mtetra
.688 .765 .91 r
.78374 .36497 .78923 .37204 .80192 .36692 .79649 .36002 Mtetra
.694 .774 .913 r
.79649 .36002 .80192 .36692 .81469 .36212 .80928 .35487 Mtetra
.68 .759 .911 r
.80928 .35487 .81469 .36212 .82755 .3577 .82215 .35016 Mtetra
.669 .747 .909 r
.82215 .35016 .82755 .3577 .84048 .35347 .83512 .3458 Mtetra
.665 .742 .908 r
.83512 .3458 .84048 .35347 .85348 .34929 .84815 .34155 Mtetra
.664 .741 .907 r
.84815 .34155 .85348 .34929 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32883 Mtetra
.88763 .32883 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49666 Mtetra
.663 .741 .908 r
.3397 .49666 .34651 .50317 .35745 .49965 .35066 .49312 Mtetra
.661 .74 .909 r
.35066 .49312 .35745 .49965 .36843 .49616 .36167 .48965 Mtetra
.652 .74 .914 r
.36167 .48965 .36843 .49616 .37945 .49278 .37271 .48641 Mtetra
.633 .739 .925 r
.37271 .48641 .37945 .49278 .3905 .48974 .38377 .48365 Mtetra
.622 .746 .935 r
.38377 .48365 .3905 .48974 .40158 .48713 .39489 .48109 Mtetra
.67 .762 .919 r
.39489 .48109 .40158 .48713 .41273 .48433 .4061 .47728 Mtetra
.722 .744 .87 r
.4061 .47728 .41273 .48433 .42398 .47963 .41741 .47149 Mtetra
.662 .7 .875 r
.41741 .47149 .42398 .47963 .43528 .47457 .4287 .46783 Mtetra
.664 .741 .907 r
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.647 .736 .914 r
.46285 .45677 .46934 .46359 .48079 .4599 .47432 .45355 Mtetra
0 .284 .761 r
.47432 .45355 .48079 .4599 .49229 .4562 .48572 .46096 Mtetra
.563 .072 .048 r
.48572 .46096 .49229 .4562 .50378 .46173 .49727 .46522 Mtetra
.329 0 0 r
.49727 .46522 .50378 .46173 .51538 .46571 .50895 .46565 Mtetra
.313 .802 .867 r
.50895 .46565 .51538 .46571 .52709 .46677 .52071 .46314 Mtetra
.659 .857 .976 r
.52071 .46314 .52709 .46677 .53887 .46542 .53252 .45891 Mtetra
.698 .767 .905 r
.53252 .45891 .53887 .46542 .55071 .46249 .54438 .45397 Mtetra
.692 .711 .863 r
.54438 .45397 .55071 .46249 .56259 .45876 .55628 .44893 Mtetra
.68 .679 .842 r
.55628 .44893 .56259 .45876 .57452 .45474 .56823 .44415 Mtetra
.667 .659 .833 r
.56823 .44415 .57452 .45474 .58651 .45074 .58023 .43979 Mtetra
.654 .648 .832 r
.58023 .43979 .58651 .45074 .59854 .44692 .59229 .43593 Mtetra
.642 .643 .835 r
.59229 .43593 .59854 .44692 .61064 .44326 .60441 .43257 Mtetra
.632 .644 .844 r
.60441 .43257 .61064 .44326 .62279 .43964 .6166 .42964 Mtetra
.625 .656 .861 r
.6166 .42964 .62279 .43964 .63498 .43572 .62886 .42698 Mtetra
.627 .687 .887 r
.62886 .42698 .63498 .43572 .6472 .43099 .64118 .42421 Mtetra
.646 .752 .926 r
.64118 .42421 .6472 .43099 .6594 .42466 .65354 .42073 Mtetra
.692 .867 .964 r
.65354 .42073 .6594 .42466 .67153 .41588 .66588 .41551 Mtetra
.733 .982 .909 r
.66588 .41551 .67153 .41588 .68352 .40412 .67812 .4073 Mtetra
.698 .955 .692 r
.67812 .4073 .68352 .40412 .69543 .39075 .69019 .39518 Mtetra
.741 .938 .607 r
.69019 .39518 .69543 .39075 .70785 .38675 .70207 .37982 Mtetra
.679 .762 .913 r
.70207 .37982 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.664 .741 .907 r
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77089 .36795 .76516 .35887 Mtetra
.598 .672 .892 r
.76516 .35887 .77089 .36795 .78374 .36497 .77813 .35694 Mtetra
.658 .727 .901 r
.77813 .35694 .78374 .36497 .79649 .36002 .79101 .35298 Mtetra
.696 .772 .91 r
.79101 .35298 .79649 .36002 .80928 .35487 .80383 .34772 Mtetra
.689 .767 .911 r
.80383 .34772 .80928 .35487 .82215 .35016 .81672 .34266 Mtetra
.674 .752 .909 r
.81672 .34266 .82215 .35016 .83512 .3458 .82971 .33809 Mtetra
.667 .744 .908 r
.82971 .33809 .83512 .3458 .84815 .34155 .84279 .33376 Mtetra
.664 .741 .907 r
.84279 .33376 .84815 .34155 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32883 .88239 .32091 Mtetra
.88239 .32091 .88763 .32883 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49666 .33283 .49009 Mtetra
.663 .741 .908 r
.33283 .49009 .3397 .49666 .35066 .49312 .34382 .48655 Mtetra
.658 .74 .91 r
.34382 .48655 .35066 .49312 .36167 .48965 .35485 .48314 Mtetra
.643 .739 .918 r
.35485 .48314 .36167 .48965 .37271 .48641 .36591 .48011 Mtetra
.623 .74 .931 r
.36591 .48011 .37271 .48641 .38377 .48365 .37699 .47756 Mtetra
.638 .753 .931 r
.37699 .47756 .38377 .48365 .39489 .48109 .38815 .47459 Mtetra
.722 .76 .883 r
.38815 .47459 .39489 .48109 .4061 .47728 .39946 .4689 Mtetra
.675 .7 .865 r
.39946 .4689 .4061 .47728 .41741 .47149 .41075 .46473 Mtetra
.664 .741 .907 r
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
0 .26 .75 r
.45631 .4499 .46285 .45677 .47432 .45355 .46762 .4578 Mtetra
.586 .09 .044 r
.46762 .4578 .47432 .45355 .48572 .46096 .4791 .46283 Mtetra
.213 0 0 r
.4791 .46283 .48572 .46096 .49727 .46522 .49073 .46312 Mtetra
.555 .88 .991 r
.49073 .46312 .49727 .46522 .50895 .46565 .50248 .45982 Mtetra
.709 .79 .915 r
.50248 .45982 .50895 .46565 .52071 .46314 .51428 .45455 Mtetra
.713 .716 .851 r
.51428 .45455 .52071 .46314 .53252 .45891 .52612 .44855 Mtetra
.702 .677 .823 r
.52612 .44855 .53252 .45891 .54438 .45397 .538 .44256 Mtetra
.688 .654 .81 r
.538 .44256 .54438 .45397 .55628 .44893 .54992 .43694 Mtetra
.675 .64 .806 r
.54992 .43694 .55628 .44893 .56823 .44415 .56188 .43184 Mtetra
.662 .629 .806 r
.56188 .43184 .56823 .44415 .58023 .43979 .57389 .42733 Mtetra
.649 .622 .809 r
.57389 .42733 .58023 .43979 .59229 .43593 .58596 .42343 Mtetra
.636 .615 .812 r
.58596 .42343 .59229 .43593 .60441 .43257 .5981 .42015 Mtetra
.623 .611 .818 r
.5981 .42015 .60441 .43257 .6166 .42964 .61032 .41747 Mtetra
.61 .609 .825 r
.61032 .41747 .6166 .42964 .62886 .42698 .62261 .41532 Mtetra
.6 .614 .837 r
.62261 .41532 .62886 .42698 .64118 .42421 .63498 .41354 Mtetra
.599 .633 .856 r
.63498 .41354 .64118 .42421 .65354 .42073 .64743 .41178 Mtetra
.617 .681 .888 r
.64743 .41178 .65354 .42073 .66588 .41551 .65992 .40929 Mtetra
.676 .783 .931 r
.65992 .40929 .66588 .41551 .67812 .4073 .67238 .40481 Mtetra
.778 .936 .933 r
.67238 .40481 .67812 .4073 .69019 .39518 .68472 .39667 Mtetra
.827 .999 .785 r
.68472 .39667 .69019 .39518 .70207 .37982 .69682 .38368 Mtetra
.793 .961 .641 r
.69682 .38368 .70207 .37982 .71455 .37526 .70873 .36773 Mtetra
.664 .741 .907 r
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.648 .734 .912 r
.7595 .35121 .76516 .35887 .77813 .35694 .77237 .34756 Mtetra
.602 .669 .886 r
.77237 .34756 .77813 .35694 .79101 .35298 .78544 .34546 Mtetra
.684 .755 .905 r
.78544 .34546 .79101 .35298 .80383 .34772 .79834 .34056 Mtetra
.697 .772 .909 r
.79834 .34056 .80383 .34772 .81672 .34266 .81125 .33522 Mtetra
.682 .758 .909 r
.81125 .33522 .81672 .34266 .82971 .33809 .82427 .33037 Mtetra
.669 .746 .908 r
.82427 .33037 .82971 .33809 .84279 .33376 .83737 .32591 Mtetra
.665 .742 .908 r
.83737 .32591 .84279 .33376 .85593 .32948 .85055 .32158 Mtetra
.664 .741 .907 r
.85055 .32158 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.663 .741 .908 r
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48348 Mtetra
.661 .74 .909 r
.32592 .48348 .33283 .49009 .34382 .48655 .33693 .47995 Mtetra
.653 .739 .913 r
.33693 .47995 .34382 .48655 .35485 .48314 .34798 .47664 Mtetra
.633 .738 .923 r
.34798 .47664 .35485 .48314 .36591 .48011 .35905 .47384 Mtetra
.62 .742 .934 r
.35905 .47384 .36591 .48011 .37699 .47756 .37016 .47132 Mtetra
.675 .759 .914 r
.37016 .47132 .37699 .47756 .38815 .47459 .38139 .46732 Mtetra
.718 .74 .869 r
.38139 .46732 .38815 .47459 .39946 .4689 .39273 .46161 Mtetra
.664 .726 .896 r
.39273 .46161 .39946 .4689 .41075 .46473 .40403 .45791 Mtetra
.664 .741 .907 r
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.049 .428 .869 r
.43822 .44673 .44485 .45363 .45631 .4499 .4495 .45224 Mtetra
.625 .106 0 r
.4495 .45224 .45631 .4499 .46762 .4578 .46087 .45887 Mtetra
.226 0 0 r
.46087 .45887 .46762 .4578 .4791 .46283 .47246 .45993 Mtetra
.6 .868 .993 r
.47246 .45993 .4791 .46283 .49073 .46312 .48418 .45647 Mtetra
.724 .769 .888 r
.48418 .45647 .49073 .46312 .50248 .45982 .49598 .45053 Mtetra
.725 .705 .832 r
.49598 .45053 .50248 .45982 .51428 .45455 .50782 .44371 Mtetra
.713 .673 .809 r
.50782 .44371 .51428 .45455 .52612 .44855 .51969 .43691 Mtetra
.7 .656 .802 r
.51969 .43691 .52612 .44855 .538 .44256 .53158 .43053 Mtetra
.688 .645 .802 r
.53158 .43053 .538 .44256 .54992 .43694 .54352 .42473 Mtetra
.675 .637 .804 r
.54352 .42473 .54992 .43694 .56188 .43184 .5555 .41955 Mtetra
.663 .631 .808 r
.5555 .41955 .56188 .43184 .57389 .42733 .56753 .415 Mtetra
.65 .625 .812 r
.56753 .415 .57389 .42733 .58596 .42343 .57962 .41107 Mtetra
.636 .618 .815 r
.57962 .41107 .58596 .42343 .5981 .42015 .59177 .40776 Mtetra
.622 .612 .819 r
.59177 .40776 .5981 .42015 .61032 .41747 .604 .40508 Mtetra
.606 .605 .824 r
.604 .40508 .61032 .41747 .62261 .41532 .61631 .40303 Mtetra
.591 .6 .829 r
.61631 .40303 .62261 .41532 .63498 .41354 .62871 .40158 Mtetra
.579 .6 .838 r
.62871 .40158 .63498 .41354 .64743 .41178 .6412 .40056 Mtetra
.576 .613 .852 r
.6412 .40056 .64743 .41178 .65992 .40929 .65377 .39956 Mtetra
.598 .656 .878 r
.65377 .39956 .65992 .40929 .67238 .40481 .66638 .39769 Mtetra
.672 .756 .914 r
.66638 .39769 .67238 .40481 .68472 .39667 .67894 .3933 Mtetra
.805 .91 .913 r
.67894 .3933 .68472 .39667 .69682 .38368 .69132 .3843 Mtetra
.889 .989 .79 r
.69132 .3843 .69682 .38368 .70873 .36773 .7034 .3696 Mtetra
.82 .995 .756 r
.7034 .3696 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.664 .741 .907 r
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77237 .34756 .76666 .33927 Mtetra
.597 .697 .913 r
.76666 .33927 .77237 .34756 .78544 .34546 .77977 .33714 Mtetra
.654 .722 .899 r
.77977 .33714 .78544 .34546 .79834 .34056 .79279 .33323 Mtetra
.698 .769 .906 r
.79279 .33323 .79834 .34056 .81125 .33522 .80575 .3278 Mtetra
.689 .764 .909 r
.80575 .3278 .81125 .33522 .82427 .33037 .81878 .32265 Mtetra
.673 .75 .908 r
.81878 .32265 .82427 .33037 .83737 .32591 .83192 .31802 Mtetra
.666 .743 .908 r
.83192 .31802 .83737 .32591 .85055 .32158 .84514 .31361 Mtetra
.664 .741 .907 r
.84514 .31361 .85055 .32158 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48043 Mtetra
.663 .741 .908 r
.30794 .48043 .31494 .48706 .32592 .48348 .31895 .47683 Mtetra
.66 .74 .909 r
.31895 .47683 .32592 .48348 .33693 .47995 .32999 .47332 Mtetra
.647 .738 .916 r
.32999 .47332 .33693 .47995 .34798 .47664 .34106 .47015 Mtetra
.624 .737 .928 r
.34106 .47015 .34798 .47664 .35905 .47384 .35214 .46755 Mtetra
.63 .746 .931 r
.35214 .46755 .35905 .47384 .37016 .47132 .36329 .46475 Mtetra
.717 .759 .886 r
.36329 .46475 .37016 .47132 .38139 .46732 .37462 .45923 Mtetra
.683 .711 .87 r
.37462 .45923 .38139 .46732 .39273 .46161 .38594 .45477 Mtetra
.664 .741 .907 r
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.465 .666 .95 r
.42007 .44355 .42678 .45047 .43822 .44673 .43142 .44407 Mtetra
.613 .047 0 r
.43142 .44407 .43822 .44673 .4495 .45224 .44264 .453 Mtetra
.388 0 0 r
.44264 .453 .4495 .45224 .46087 .45887 .45413 .45608 Mtetra
.541 .852 .998 r
.45413 .45608 .46087 .45887 .47246 .45993 .46581 .4534 Mtetra
.728 .773 .889 r
.46581 .4534 .47246 .45993 .48418 .45647 .47761 .4473 Mtetra
.736 .711 .828 r
.47761 .4473 .48418 .45647 .49598 .45053 .48945 .4399 Mtetra
.726 .682 .807 r
.48945 .4399 .49598 .45053 .50782 .44371 .50132 .4324 Mtetra
.714 .667 .802 r
.50132 .4324 .50782 .44371 .51969 .43691 .51321 .42533 Mtetra
.702 .658 .803 r
.51321 .42533 .51969 .43691 .53158 .43053 .52514 .41889 Mtetra
.69 .653 .808 r
.52514 .41889 .53158 .43053 .54352 .42473 .53709 .41309 Mtetra
.677 .648 .813 r
.53709 .41309 .54352 .42473 .5555 .41955 .54909 .40794 Mtetra
.665 .644 .819 r
.54909 .40794 .5555 .41955 .56753 .415 .56114 .40338 Mtetra
.653 .639 .823 r
.56114 .40338 .56753 .415 .57962 .41107 .57325 .39941 Mtetra
.639 .632 .828 r
.57325 .39941 .57962 .41107 .59177 .40776 .58542 .39603 Mtetra
.624 .625 .831 r
.58542 .39603 .59177 .40776 .604 .40508 .59766 .39326 Mtetra
.607 .616 .834 r
.59766 .39326 .604 .40508 .61631 .40303 .60999 .39114 Mtetra
.59 .607 .837 r
.60999 .39114 .61631 .40303 .62871 .40158 .6224 .38967 Mtetra
.572 .598 .841 r
.6224 .38967 .62871 .40158 .6412 .40056 .63491 .38885 Mtetra
.558 .596 .847 r
.63491 .38885 .6412 .40056 .65377 .39956 .64752 .38847 Mtetra
.558 .608 .86 r
.64752 .38847 .65377 .39956 .66638 .39769 .66021 .38801 Mtetra
.593 .657 .882 r
.66021 .38801 .66638 .39769 .67894 .3933 .67293 .38624 Mtetra
.696 .769 .908 r
.67293 .38624 .67894 .3933 .69132 .3843 .68555 .38099 Mtetra
.849 .912 .877 r
.68555 .38099 .69132 .3843 .7034 .3696 .6979 .36986 Mtetra
.927 .969 .762 r
.6979 .36986 .7034 .3696 .71551 .35601 .70989 .35271 Mtetra
.792 .918 .923 r
.70989 .35271 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.664 .741 .907 r
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.64 .731 .915 r
.76095 .33145 .76666 .33927 .77977 .33714 .77398 .32795 Mtetra
.608 .681 .893 r
.77398 .32795 .77977 .33714 .79279 .33323 .78717 .32555 Mtetra
.69 .757 .903 r
.78717 .32555 .79279 .33323 .80575 .3278 .8002 .32034 Mtetra
.696 .767 .907 r
.8002 .32034 .80575 .3278 .81878 .32265 .81325 .31492 Mtetra
.678 .754 .908 r
.81325 .31492 .81878 .32265 .83192 .31802 .82642 .31008 Mtetra
.668 .744 .908 r
.82642 .31008 .83192 .31802 .84514 .31361 .83968 .30558 Mtetra
.665 .741 .907 r
.83968 .30558 .84514 .31361 .85843 .30925 .85301 .30118 Mtetra
.664 .741 .907 r
.85301 .30118 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29235 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48043 .30089 .47373 Mtetra
.662 .74 .908 r
.30089 .47373 .30794 .48043 .31895 .47683 .31192 .47013 Mtetra
.657 .74 .911 r
.31192 .47013 .31895 .47683 .32999 .47332 .32299 .46666 Mtetra
.64 .737 .919 r
.32299 .46666 .32999 .47332 .34106 .47015 .33407 .46364 Mtetra
.618 .736 .931 r
.33407 .46364 .34106 .47015 .35214 .46755 .34518 .46115 Mtetra
.653 .75 .921 r
.34518 .46115 .35214 .46755 .36329 .46475 .35639 .45775 Mtetra
.729 .751 .87 r
.35639 .45775 .36329 .46475 .37462 .45923 .36777 .45162 Mtetra
.663 .719 .891 r
.36777 .45162 .37462 .45923 .38594 .45477 .37909 .44788 Mtetra
.664 .741 .907 r
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
0 .248 .739 r
.41331 .43657 .42007 .44355 .43142 .44407 .42446 .44443 Mtetra
.583 .02 0 r
.42446 .44443 .43142 .44407 .44264 .453 .43578 .45081 Mtetra
.293 .752 .952 r
.43578 .45081 .44264 .453 .45413 .45608 .44738 .4503 Mtetra
.714 .794 .914 r
.44738 .4503 .45413 .45608 .46581 .4534 .45916 .44486 Mtetra
.745 .727 .835 r
.45916 .44486 .46581 .4534 .47761 .4473 .47101 .43721 Mtetra
.739 .696 .81 r
.47101 .43721 .47761 .4473 .48945 .4399 .48289 .42912 Mtetra
.729 .681 .804 r
.48289 .42912 .48945 .4399 .50132 .4324 .49479 .42139 Mtetra
.716 .673 .807 r
.49479 .42139 .50132 .4324 .51321 .42533 .50671 .41432 Mtetra
.704 .669 .813 r
.50671 .41432 .51321 .42533 .52514 .41889 .51865 .40793 Mtetra
.692 .666 .82 r
.51865 .40793 .52514 .41889 .53709 .41309 .53063 .40222 Mtetra
.68 .663 .827 r
.53063 .40222 .53709 .41309 .54909 .40794 .54266 .39711 Mtetra
.668 .66 .833 r
.54266 .39711 .54909 .40794 .56114 .40338 .55473 .39257 Mtetra
.656 .656 .838 r
.55473 .39257 .56114 .40338 .57325 .39941 .56686 .38856 Mtetra
.642 .65 .842 r
.56686 .38856 .57325 .39941 .58542 .39603 .57905 .3851 Mtetra
.627 .642 .846 r
.57905 .3851 .58542 .39603 .59766 .39326 .59131 .38221 Mtetra
.611 .633 .848 r
.59131 .38221 .59766 .39326 .60999 .39114 .60365 .37993 Mtetra
.591 .621 .85 r
.60365 .37993 .60999 .39114 .6224 .38967 .61608 .37834 Mtetra
.571 .61 .853 r
.61608 .37834 .6224 .38967 .63491 .38885 .6286 .37744 Mtetra
.55 .599 .855 r
.6286 .37744 .63491 .38885 .64752 .38847 .64124 .37723 Mtetra
.537 .596 .861 r
.64124 .37723 .64752 .38847 .66021 .38801 .65397 .37739 Mtetra
.547 .615 .872 r
.65397 .37739 .66021 .38801 .67293 .38624 .66678 .37712 Mtetra
.612 .682 .892 r
.66678 .37712 .67293 .38624 .68555 .38099 .67957 .37462 Mtetra
.757 .809 .894 r
.67957 .37462 .68555 .38099 .6979 .36986 .69216 .36709 Mtetra
.901 .918 .823 r
.69216 .36709 .6979 .36986 .70989 .35271 .70439 .3525 Mtetra
.917 .971 .783 r
.70439 .3525 .70989 .35271 .72238 .34413 .7165 .33635 Mtetra
.664 .741 .907 r
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77398 .32795 .7682 .31925 Mtetra
.586 .685 .91 r
.7682 .31925 .77398 .32795 .78717 .32555 .78148 .31742 Mtetra
.673 .74 .901 r
.78148 .31742 .78717 .32555 .8002 .32034 .79459 .31276 Mtetra
.7 .767 .904 r
.79459 .31276 .8002 .32034 .81325 .31492 .80768 .30716 Mtetra
.684 .757 .907 r
.80768 .30716 .81325 .31492 .82642 .31008 .82088 .3021 Mtetra
.67 .746 .907 r
.82088 .3021 .82642 .31008 .83968 .30558 .83417 .2975 Mtetra
.665 .742 .907 r
.83417 .2975 .83968 .30558 .85301 .30118 .84754 .29303 Mtetra
.664 .741 .907 r
.84754 .29303 .85301 .30118 .8664 .29677 .86098 .28859 Mtetra
.86098 .28859 .8664 .29677 .87985 .29235 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.663 .741 .907 r
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .467 Mtetra
.662 .741 .908 r
.29379 .467 .30089 .47373 .31192 .47013 .30484 .46338 Mtetra
.654 .739 .912 r
.30484 .46338 .31192 .47013 .32299 .46666 .31593 .45997 Mtetra
.634 .736 .922 r
.31593 .45997 .32299 .46666 .33407 .46364 .32703 .45709 Mtetra
.618 .736 .931 r
.32703 .45709 .33407 .46364 .34518 .46115 .33816 .45458 Mtetra
.68 .754 .907 r
.33816 .45458 .34518 .46115 .35639 .45775 .34944 .45036 Mtetra
.715 .74 .871 r
.34944 .45036 .35639 .45775 .36777 .45162 .36084 .4447 Mtetra
.664 .741 .907 r
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.536 .697 .943 r
.39501 .43335 .40185 .44035 .41331 .43657 .40639 .43258 Mtetra
.624 .072 0 r
.40639 .43258 .41331 .43657 .42446 .44443 .41747 .44274 Mtetra
.24 0 0 r
.41747 .44274 .42446 .44443 .43578 .45081 .42891 .44616 Mtetra
.631 .814 .97 r
.42891 .44616 .43578 .45081 .44738 .4503 .44062 .44277 Mtetra
.745 .752 .857 r
.44062 .44277 .44738 .4503 .45916 .44486 .45247 .43555 Mtetra
.752 .715 .817 r
.45247 .43555 .45916 .44486 .47101 .43721 .46437 .42709 Mtetra
.743 .698 .808 r
.46437 .42709 .47101 .43721 .48289 .42912 .47628 .41873 Mtetra
.731 .69 .81 r
.47628 .41873 .48289 .42912 .49479 .42139 .48821 .411 Mtetra
.719 .686 .817 r
.48821 .411 .49479 .42139 .50671 .41432 .50016 .404 Mtetra
.706 .683 .825 r
.50016 .404 .50671 .41432 .51865 .40793 .51213 .39773 Mtetra
.694 .682 .834 r
.51213 .39773 .51865 .40793 .53063 .40222 .52414 .39209 Mtetra
.682 .68 .841 r
.52414 .39209 .53063 .40222 .54266 .39711 .53618 .38704 Mtetra
.67 .677 .847 r
.53618 .38704 .54266 .39711 .55473 .39257 .54828 .38251 Mtetra
.658 .673 .853 r
.54828 .38251 .55473 .39257 .56686 .38856 .56044 .37847 Mtetra
.645 .668 .857 r
.56044 .37847 .56686 .38856 .57905 .3851 .57265 .37493 Mtetra
.631 .661 .861 r
.57265 .37493 .57905 .3851 .59131 .38221 .58494 .37191 Mtetra
.614 .651 .863 r
.58494 .37191 .59131 .38221 .60365 .37993 .59729 .36948 Mtetra
.594 .64 .866 r
.59729 .36948 .60365 .37993 .61608 .37834 .60974 .36769 Mtetra
.571 .625 .867 r
.60974 .36769 .61608 .37834 .6286 .37744 .62228 .36666 Mtetra
.547 .612 .869 r
.62228 .36666 .6286 .37744 .64124 .37723 .63493 .36637 Mtetra
.525 .6 .871 r
.63493 .36637 .64124 .37723 .65397 .37739 .64769 .36674 Mtetra
.519 .602 .876 r
.64769 .36674 .65397 .37739 .66678 .37712 .66055 .36722 Mtetra
.557 .639 .887 r
.66055 .36722 .66678 .37712 .67957 .37462 .67345 .36646 Mtetra
.675 .735 .895 r
.67345 .36646 .67957 .37462 .69216 .36709 .68623 .3618 Mtetra
.842 .854 .853 r
.68623 .3618 .69216 .36709 .70439 .3525 .6987 .35017 Mtetra
.938 .911 .766 r
.6987 .35017 .70439 .3525 .7165 .33635 .71075 .33162 Mtetra
.758 .869 .929 r
.71075 .33162 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.664 .741 .907 r
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.599 .713 .924 r
.76243 .31126 .7682 .31925 .78148 .31742 .7757 .30887 Mtetra
.649 .72 .901 r
.7757 .30887 .78148 .31742 .79459 .31276 .78893 .305 Mtetra
.7 .763 .901 r
.78893 .305 .79459 .31276 .80768 .30716 .80206 .29935 Mtetra
.689 .759 .905 r
.80206 .29935 .80768 .30716 .82088 .3021 .81529 .29407 Mtetra
.672 .747 .907 r
.81529 .29407 .82088 .3021 .83417 .2975 .82862 .28934 Mtetra
.665 .742 .907 r
.82862 .28934 .83417 .2975 .84754 .29303 .84203 .28483 Mtetra
.664 .741 .907 r
.84203 .28483 .84754 .29303 .86098 .28859 .85551 .28033 Mtetra
.85551 .28033 .86098 .28859 .87448 .28412 .86906 .27584 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.664 .741 .908 r
.27559 .46388 .28278 .47064 .29379 .467 .28663 .4602 Mtetra
.661 .74 .908 r
.28663 .4602 .29379 .467 .30484 .46338 .29771 .45658 Mtetra
.652 .738 .913 r
.29771 .45658 .30484 .46338 .31593 .45997 .30882 .45322 Mtetra
.628 .734 .924 r
.30882 .45322 .31593 .45997 .32703 .45709 .31994 .45047 Mtetra
.622 .737 .929 r
.31994 .45047 .32703 .45709 .33816 .45458 .3311 .44783 Mtetra
.705 .755 .891 r
.3311 .44783 .33816 .45458 .34944 .45036 .34246 .44271 Mtetra
.696 .73 .876 r
.34246 .44271 .34944 .45036 .36084 .4447 .35385 .43773 Mtetra
.664 .741 .907 r
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.158 .5 .908 r
.38811 .42629 .39501 .43335 .40639 .43258 .39932 .43053 Mtetra
.622 .056 0 r
.39932 .43053 .40639 .43258 .41747 .44274 .41048 .4391 Mtetra
.264 .691 .965 r
.41048 .4391 .41747 .44274 .42891 .44616 .42202 .43989 Mtetra
.71 .78 .907 r
.42202 .43989 .42891 .44616 .44062 .44277 .43382 .43448 Mtetra
.758 .738 .834 r
.43382 .43448 .44062 .44277 .45247 .43555 .44573 .42619 Mtetra
.757 .716 .814 r
.44573 .42619 .45247 .43555 .46437 .42709 .45767 .41734 Mtetra
.747 .707 .813 r
.45767 .41734 .46437 .42709 .47628 .41873 .46962 .40892 Mtetra
.735 .703 .82 r
.46962 .40892 .47628 .41873 .48821 .411 .48158 .40124 Mtetra
.722 .7 .829 r
.48158 .40124 .48821 .411 .50016 .404 .49356 .39436 Mtetra
.709 .699 .839 r
.49356 .39436 .50016 .404 .51213 .39773 .50556 .38817 Mtetra
.687 .694 .851 r
.50556 .38817 .51213 .39773 .52414 .39209 .51759 .38304 Mtetra
.661 .697 .872 r
.51759 .38304 .52414 .39209 .53618 .38704 .52968 .379 Mtetra
.663 .724 .894 r
.52968 .379 .53618 .38704 .54828 .38251 .54181 .37495 Mtetra
.664 .738 .905 r
.54181 .37495 .54828 .38251 .56044 .37847 .554 .37088 Mtetra
.554 .37088 .56044 .37847 .57265 .37493 .56624 .36679 Mtetra
.663 .724 .894 r
.56624 .36679 .57265 .37493 .58494 .37191 .57854 .36268 Mtetra
.629 .684 .883 r
.57854 .36268 .58494 .37191 .59729 .36948 .59091 .35968 Mtetra
.596 .657 .88 r
.59091 .35968 .59729 .36948 .60974 .36769 .60338 .35774 Mtetra
.573 .643 .882 r
.60338 .35774 .60974 .36769 .62228 .36666 .61594 .35651 Mtetra
.545 .626 .883 r
.61594 .35651 .62228 .36666 .63493 .36637 .62861 .35611 Mtetra
.518 .611 .884 r
.62861 .35611 .63493 .36637 .64769 .36674 .64139 .35646 Mtetra
.501 .602 .886 r
.64139 .35646 .64769 .36674 .66055 .36722 .65428 .35727 Mtetra
.519 .62 .892 r
.65428 .35727 .66055 .36722 .67345 .36646 .66725 .35752 Mtetra
.614 .692 .899 r
.66725 .35752 .67345 .36646 .68623 .3618 .68017 .35486 Mtetra
.782 .802 .869 r
.68017 .35486 .68623 .3618 .6987 .35017 .69283 .34585 Mtetra
.911 .872 .787 r
.69283 .34585 .6987 .35017 .71075 .33162 .70505 .32886 Mtetra
.873 .934 .858 r
.70505 .32886 .71075 .33162 .72344 .32422 .7175 .31626 Mtetra
.664 .741 .907 r
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.625 .725 .918 r
.75661 .3032 .76243 .31126 .7757 .30887 .76987 .30004 Mtetra
.621 .703 .903 r
.76987 .30004 .7757 .30887 .78893 .305 .78321 .29703 Mtetra
.697 .758 .9 r
.78321 .29703 .78893 .305 .80206 .29935 .7964 .29144 Mtetra
.693 .76 .903 r
.7964 .29144 .80206 .29935 .81529 .29407 .80965 .28597 Mtetra
.675 .748 .906 r
.80965 .28597 .81529 .29407 .82862 .28934 .82302 .28112 Mtetra
.666 .743 .907 r
.82302 .28112 .82862 .28934 .84203 .28483 .83647 .27654 Mtetra
.664 .741 .907 r
.83647 .27654 .84203 .28483 .85551 .28033 .85 .27201 Mtetra
.85 .27201 .85551 .28033 .86906 .27584 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.663 .741 .908 r
.26834 .45706 .27559 .46388 .28663 .4602 .27941 .45336 Mtetra
.661 .74 .909 r
.27941 .45336 .28663 .4602 .29771 .45658 .29052 .44973 Mtetra
.649 .738 .914 r
.29052 .44973 .29771 .45658 .30882 .45322 .30165 .44642 Mtetra
.624 .733 .925 r
.30165 .44642 .30882 .45322 .31994 .45047 .31279 .44374 Mtetra
.629 .737 .926 r
.31279 .44374 .31994 .45047 .3311 .44783 .32399 .44092 Mtetra
.724 .756 .878 r
.32399 .44092 .3311 .44783 .34246 .44271 .33543 .43498 Mtetra
.676 .724 .885 r
.33543 .43498 .34246 .44271 .35385 .43773 .34681 .43071 Mtetra
.664 .741 .907 r
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
0 .241 .732 r
.38116 .41917 .38811 .42629 .39932 .43053 .39223 .42701 Mtetra
.439 0 0 r
.39223 .42701 .39932 .43053 .41048 .4391 .40347 .43395 Mtetra
.513 .758 .985 r
.40347 .43395 .41048 .4391 .42202 .43989 .4151 .43277 Mtetra
.738 .763 .873 r
.4151 .43277 .42202 .43989 .43382 .43448 .42698 .42604 Mtetra
.766 .737 .827 r
.42698 .42604 .43382 .43448 .44573 .42619 .43894 .41716 Mtetra
.763 .725 .818 r
.43894 .41716 .44573 .42619 .45767 .41734 .45092 .40813 Mtetra
.752 .72 .822 r
.45092 .40813 .45767 .41734 .46962 .40892 .46291 .39972 Mtetra
.739 .717 .831 r
.46291 .39972 .46962 .40892 .48158 .40124 .4749 .39212 Mtetra
.725 .716 .841 r
.4749 .39212 .48158 .40124 .49356 .39436 .48691 .38531 Mtetra
.702 .711 .855 r
.48691 .38531 .49356 .39436 .50556 .38817 .49894 .37962 Mtetra
.662 .71 .883 r
.49894 .37962 .50556 .38817 .51759 .38304 .511 .37557 Mtetra
.664 .741 .907 r
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59091 .35968 .58451 .35089 Mtetra
.611 .69 .899 r
.58451 .35089 .59091 .35968 .60338 .35774 .59699 .34838 Mtetra
.574 .66 .896 r
.59699 .34838 .60338 .35774 .61594 .35651 .60957 .34701 Mtetra
.545 .643 .898 r
.60957 .34701 .61594 .35651 .62861 .35611 .62226 .34644 Mtetra
.513 .624 .899 r
.62226 .34644 .62861 .35611 .64139 .35646 .63506 .34672 Mtetra
.487 .61 .9 r
.63506 .34672 .64139 .35646 .65428 .35727 .64798 .34764 Mtetra
.491 .616 .903 r
.64798 .34764 .65428 .35727 .66725 .35752 .661 .34842 Mtetra
.57 .67 .906 r
.661 .34842 .66725 .35752 .68017 .35486 .67401 .34703 Mtetra
.735 .768 .88 r
.67401 .34703 .68017 .35486 .69283 .34585 .68682 .33997 Mtetra
.881 .839 .8 r
.68682 .33997 .69283 .34585 .70505 .32886 .69921 .32459 Mtetra
.907 .879 .796 r
.69921 .32459 .70505 .32886 .7175 .31626 .71151 .30825 Mtetra
.664 .741 .907 r
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.65 .735 .912 r
.75074 .29507 .75661 .3032 .76987 .30004 .76398 .29111 Mtetra
.595 .69 .908 r
.76398 .29111 .76987 .30004 .78321 .29703 .77742 .28888 Mtetra
.692 .753 .899 r
.77742 .28888 .78321 .29703 .7964 .29144 .79067 .28341 Mtetra
.696 .759 .901 r
.79067 .28341 .7964 .29144 .80965 .28597 .80396 .27779 Mtetra
.677 .749 .905 r
.80396 .27779 .80965 .28597 .82302 .28112 .81737 .27282 Mtetra
.667 .743 .907 r
.81737 .27282 .82302 .28112 .83647 .27654 .83087 .26819 Mtetra
.665 .741 .907 r
.83087 .26819 .83647 .27654 .85 .27201 .84444 .26361 Mtetra
.664 .741 .907 r
.84444 .26361 .85 .27201 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45019 Mtetra
.663 .741 .908 r
.26104 .45019 .26834 .45706 .27941 .45336 .27214 .44646 Mtetra
.66 .74 .909 r
.27214 .44646 .27941 .45336 .29052 .44973 .28327 .44282 Mtetra
.647 .737 .915 r
.28327 .44282 .29052 .44973 .30165 .44642 .29443 .43953 Mtetra
.621 .731 .925 r
.29443 .43953 .30165 .44642 .31279 .44374 .30559 .43689 Mtetra
.635 .737 .922 r
.30559 .43689 .31279 .44374 .32399 .44092 .31683 .43389 Mtetra
.734 .756 .87 r
.31683 .43389 .32399 .44092 .33543 .43498 .32833 .42747 Mtetra
.663 .728 .897 r
.32833 .42747 .33543 .43498 .34681 .43071 .33971 .42363 Mtetra
.664 .741 .907 r
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
0 .067 .573 r
.37415 .412 .38116 .41917 .39223 .42701 .38513 .42209 Mtetra
0 .328 .748 r
.38513 .42209 .39223 .42701 .40347 .43395 .39643 .42779 Mtetra
.601 .756 .953 r
.39643 .42779 .40347 .43395 .4151 .43277 .40814 .42532 Mtetra
.751 .758 .859 r
.40814 .42532 .4151 .43277 .42698 .42604 .42008 .41781 Mtetra
.773 .745 .827 r
.42008 .41781 .42698 .42604 .43894 .41716 .43209 .40862 Mtetra
.769 .738 .825 r
.43209 .40862 .43894 .41716 .45092 .40813 .44411 .3995 Mtetra
.757 .734 .832 r
.44411 .3995 .45092 .40813 .46291 .39972 .45613 .39111 Mtetra
.742 .732 .842 r
.45613 .39111 .46291 .39972 .4749 .39212 .46816 .38355 Mtetra
.727 .73 .853 r
.46816 .38355 .4749 .39212 .48691 .38531 .4802 .3768 Mtetra
.679 .718 .878 r
.4802 .3768 .48691 .38531 .49894 .37962 .49225 .37213 Mtetra
.664 .741 .907 r
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.644 .734 .914 r
.57808 .34316 .58451 .35089 .59699 .34838 .59057 .33955 Mtetra
.574 .675 .909 r
.59057 .33955 .59699 .34838 .60957 .34701 .60318 .33805 Mtetra
.542 .658 .912 r
.60318 .33805 .60957 .34701 .62226 .34644 .61589 .33738 Mtetra
.507 .639 .914 r
.61589 .33738 .62226 .34644 .63506 .34672 .62871 .33757 Mtetra
.475 .621 .914 r
.62871 .33757 .63506 .34672 .64798 .34764 .64166 .3385 Mtetra
.47 .62 .915 r
.64166 .3385 .64798 .34764 .661 .34842 .65471 .33953 Mtetra
.539 .663 .917 r
.65471 .33953 .661 .34842 .67401 .34703 .66779 .33886 Mtetra
.703 .751 .889 r
.66779 .33886 .67401 .34703 .68682 .33997 .68071 .33305 Mtetra
.857 .815 .807 r
.68071 .33305 .68682 .33997 .69921 .32459 .69323 .31888 Mtetra
.91 .839 .763 r
.69323 .31888 .69921 .32459 .71151 .30825 .70546 .30016 Mtetra
.664 .741 .907 r
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76398 .29111 .75807 .2824 Mtetra
.577 .69 .918 r
.75807 .2824 .76398 .29111 .77742 .28888 .77158 .28059 Mtetra
.687 .75 .899 r
.77158 .28059 .77742 .28888 .79067 .28341 .78489 .27525 Mtetra
.697 .758 .899 r
.78489 .27525 .79067 .28341 .80396 .27779 .79822 .26952 Mtetra
.678 .749 .904 r
.79822 .26952 .80396 .27779 .81737 .27282 .81167 .26446 Mtetra
.667 .743 .907 r
.81167 .26446 .81737 .27282 .83087 .26819 .82521 .25976 Mtetra
.665 .741 .907 r
.82521 .25976 .83087 .26819 .84444 .26361 .83883 .25514 Mtetra
.664 .741 .907 r
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45019 .25368 .44326 Mtetra
.663 .741 .908 r
.25368 .44326 .26104 .45019 .27214 .44646 .26481 .43951 Mtetra
.66 .74 .909 r
.26481 .43951 .27214 .44646 .28327 .44282 .27597 .43584 Mtetra
.646 .736 .915 r
.27597 .43584 .28327 .44282 .29443 .43953 .28715 .43256 Mtetra
.62 .73 .925 r
.28715 .43256 .29443 .43953 .30559 .43689 .29833 .42992 Mtetra
.638 .736 .919 r
.29833 .42992 .30559 .43689 .31683 .43389 .30961 .4268 Mtetra
.733 .755 .871 r
.30961 .4268 .31683 .43389 .32833 .42747 .32114 .42036 Mtetra
.664 .741 .907 r
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
0 0 .495 r
.36709 .40477 .37415 .412 .38513 .42209 .37801 .41593 Mtetra
0 .429 .857 r
.37801 .41593 .38513 .42209 .39643 .42779 .38935 .42096 Mtetra
.631 .746 .931 r
.38935 .42096 .39643 .42779 .40814 .42532 .40112 .41785 Mtetra
.757 .76 .855 r
.40112 .41785 .40814 .42532 .42008 .41781 .41311 .40998 Mtetra
.778 .755 .832 r
.41311 .40998 .42008 .41781 .43209 .40862 .42516 .40063 Mtetra
.774 .752 .833 r
.42516 .40063 .43209 .40862 .44411 .3995 .43723 .39146 Mtetra
.762 .75 .842 r
.43723 .39146 .44411 .3995 .45613 .39111 .44929 .38305 Mtetra
.746 .747 .853 r
.44929 .38305 .45613 .39111 .46816 .38355 .46136 .37551 Mtetra
.73 .745 .863 r
.46136 .37551 .46816 .38355 .4802 .3768 .47343 .36876 Mtetra
.666 .727 .895 r
.47343 .36876 .4802 .3768 .49225 .37213 .48551 .36458 Mtetra
.664 .741 .907 r
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.661 .74 .908 r
.57159 .33537 .57808 .34316 .59057 .33955 .58411 .33121 Mtetra
.571 .689 .921 r
.58411 .33121 .59057 .33955 .60318 .33805 .59674 .32963 Mtetra
.537 .673 .925 r
.59674 .32963 .60318 .33805 .61589 .33738 .60948 .32887 Mtetra
.499 .653 .928 r
.60948 .32887 .61589 .33738 .62871 .33757 .62233 .329 Mtetra
.462 .633 .929 r
.62233 .329 .62871 .33757 .64166 .3385 .63531 .32991 Mtetra
.452 .629 .929 r
.63531 .32991 .64166 .3385 .65471 .33953 .6484 .33103 Mtetra
.519 .666 .928 r
.6484 .33103 .65471 .33953 .66779 .33886 .66152 .33067 Mtetra
.687 .747 .897 r
.66152 .33067 .66779 .33886 .68071 .33305 .67451 .32544 Mtetra
.842 .799 .809 r
.67451 .32544 .68071 .33305 .69323 .31888 .68712 .31189 Mtetra
.903 .811 .747 r
.68712 .31189 .69323 .31888 .70546 .30016 .69937 .292 Mtetra
.664 .741 .907 r
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.575 .702 .928 r
.75214 .27409 .75807 .2824 .77158 .28059 .7657 .27223 Mtetra
.685 .749 .9 r
.7657 .27223 .77158 .28059 .78489 .27525 .77906 .26694 Mtetra
.698 .756 .897 r
.77906 .26694 .78489 .27525 .79822 .26952 .79243 .26114 Mtetra
.679 .748 .903 r
.79243 .26114 .79822 .26952 .81167 .26446 .80592 .256 Mtetra
.668 .743 .906 r
.80592 .256 .81167 .26446 .82521 .25976 .81951 .25126 Mtetra
.665 .741 .907 r
.81951 .25126 .82521 .25976 .83883 .25514 .83317 .24659 Mtetra
.664 .741 .907 r
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24194 Mtetra
.23517 .44007 .24261 .44702 .25368 .44326 .24627 .43628 Mtetra
.663 .741 .908 r
.24627 .43628 .25368 .44326 .26481 .43951 .25742 .4325 Mtetra
.66 .74 .909 r
.25742 .4325 .26481 .43951 .27597 .43584 .26861 .4288 Mtetra
.646 .736 .915 r
.26861 .4288 .27597 .43584 .28715 .43256 .27981 .42549 Mtetra
.62 .729 .924 r
.27981 .42549 .28715 .43256 .29833 .42992 .29103 .42282 Mtetra
.639 .734 .918 r
.29103 .42282 .29833 .42992 .30961 .4268 .30233 .41967 Mtetra
.733 .756 .871 r
.30233 .41967 .30961 .4268 .32114 .42036 .3139 .4132 Mtetra
.664 .741 .907 r
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
0 0 .495 r
.35996 .39748 .36709 .40477 .37801 .41593 .37089 .40864 Mtetra
.079 .451 .882 r
.37089 .40864 .37801 .41593 .38935 .42096 .38224 .41365 Mtetra
.633 .734 .921 r
.38224 .41365 .38935 .42096 .40112 .41785 .39403 .41051 Mtetra
.759 .765 .858 r
.39403 .41051 .40112 .41785 .41311 .40998 .40606 .4026 Mtetra
.783 .768 .839 r
.40606 .4026 .41311 .40998 .42516 .40063 .41817 .3932 Mtetra
.78 .768 .842 r
.41817 .3932 .42516 .40063 .43723 .39146 .43028 .384 Mtetra
.768 .766 .852 r
.43028 .384 .43723 .39146 .44929 .38305 .44238 .37555 Mtetra
.751 .763 .863 r
.44238 .37555 .44929 .38305 .46136 .37551 .45449 .36797 Mtetra
.734 .76 .873 r
.45449 .36797 .46136 .37551 .47343 .36876 .46661 .36118 Mtetra
.667 .742 .906 r
.46661 .36118 .47343 .36876 .48551 .36458 .47872 .35696 Mtetra
.664 .741 .907 r
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.661 .74 .908 r
.56505 .32751 .57159 .33537 .58411 .33121 .5776 .32331 Mtetra
.567 .703 .933 r
.5776 .32331 .58411 .33121 .59674 .32963 .59027 .3217 Mtetra
.53 .686 .938 r
.59027 .3217 .59674 .32963 .60948 .32887 .60304 .32092 Mtetra
.488 .666 .942 r
.60304 .32092 .60948 .32887 .62233 .329 .61593 .32102 Mtetra
.448 .646 .943 r
.61593 .32102 .62233 .329 .63531 .32991 .62893 .3219 Mtetra
.437 .64 .943 r
.62893 .3219 .63531 .32991 .6484 .33103 .64205 .32299 Mtetra
.511 .678 .94 r
.64205 .32299 .6484 .33103 .66152 .33067 .65521 .3226 Mtetra
.687 .752 .901 r
.65521 .3226 .66152 .33067 .67451 .32544 .66824 .31733 Mtetra
.838 .789 .805 r
.66824 .31733 .67451 .32544 .68712 .31189 .68091 .30373 Mtetra
.891 .79 .742 r
.68091 .30373 .68712 .31189 .69937 .292 .69322 .28378 Mtetra
.664 .741 .907 r
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.575 .702 .928 r
.74616 .26571 .75214 .27409 .7657 .27223 .75976 .26381 Mtetra
.685 .749 .9 r
.75976 .26381 .7657 .27223 .77906 .26694 .77317 .25848 Mtetra
.698 .754 .895 r
.77317 .25848 .77906 .26694 .79243 .26114 .78659 .25264 Mtetra
.679 .747 .902 r
.78659 .25264 .79243 .26114 .80592 .256 .80012 .24747 Mtetra
.668 .742 .906 r
.80012 .24747 .80592 .256 .81951 .25126 .81376 .24268 Mtetra
.665 .741 .907 r
.81376 .24268 .81951 .25126 .83317 .24659 .82746 .23798 Mtetra
.664 .741 .907 r
.82746 .23798 .83317 .24659 .8469 .24194 .84124 .23328 Mtetra
.22766 .43306 .23517 .44007 .24627 .43628 .23879 .42924 Mtetra
.663 .741 .908 r
.23879 .42924 .24627 .43628 .25742 .4325 .24997 .42543 Mtetra
.66 .74 .909 r
.24997 .42543 .25742 .4325 .26861 .4288 .26119 .42169 Mtetra
.647 .736 .914 r
.26119 .42169 .26861 .4288 .27981 .42549 .27243 .41832 Mtetra
.622 .728 .923 r
.27243 .41832 .27981 .42549 .29103 .42282 .28367 .41559 Mtetra
.635 .731 .917 r
.28367 .41559 .29103 .42282 .30233 .41967 .29499 .41251 Mtetra
.734 .757 .871 r
.29499 .41251 .30233 .41967 .3139 .4132 .3066 .40598 Mtetra
.664 .741 .907 r
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
0 .067 .573 r
.35279 .39014 .35996 .39748 .37089 .40864 .36376 .40021 Mtetra
.092 .424 .869 r
.36376 .40021 .37089 .40864 .38224 .41365 .37508 .40585 Mtetra
.611 .715 .919 r
.37508 .40585 .38224 .41365 .39403 .41051 .38688 .4033 Mtetra
.754 .769 .865 r
.38688 .4033 .39403 .41051 .40606 .4026 .39894 .39568 Mtetra
.786 .781 .848 r
.39894 .39568 .40606 .4026 .41817 .3932 .41109 .38636 Mtetra
.786 .784 .851 r
.41109 .38636 .41817 .3932 .43028 .384 .42325 .37712 Mtetra
.774 .783 .861 r
.42325 .37712 .43028 .384 .44238 .37555 .4354 .3686 Mtetra
.757 .78 .872 r
.4354 .3686 .44238 .37555 .45449 .36797 .44755 .36092 Mtetra
.739 .776 .883 r
.44755 .36092 .45449 .36797 .46661 .36118 .45971 .35406 Mtetra
.683 .761 .911 r
.45971 .35406 .46661 .36118 .47872 .35696 .47187 .34928 Mtetra
.664 .741 .907 r
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.644 .734 .914 r
.55845 .31959 .56505 .32751 .5776 .32331 .57105 .31588 Mtetra
.559 .715 .945 r
.57105 .31588 .5776 .32331 .59027 .3217 .58376 .31428 Mtetra
.519 .699 .951 r
.58376 .31428 .59027 .3217 .60304 .32092 .59656 .31351 Mtetra
.473 .679 .955 r
.59656 .31351 .60304 .32092 .61593 .32102 .60948 .31362 Mtetra
.431 .658 .956 r
.60948 .31362 .61593 .32102 .62893 .3219 .62252 .31447 Mtetra
.426 .655 .955 r
.62252 .31447 .62893 .3219 .64205 .32299 .63566 .31542 Mtetra
.518 .698 .951 r
.63566 .31542 .64205 .32299 .65521 .3226 .64884 .31465 Mtetra
.704 .763 .898 r
.64884 .31465 .65521 .3226 .66824 .31733 .66189 .30872 Mtetra
.84 .78 .794 r
.66189 .30872 .66824 .31733 .68091 .30373 .67459 .29439 Mtetra
.872 .769 .746 r
.67459 .29439 .68091 .30373 .69322 .28378 .68702 .27548 Mtetra
.664 .741 .907 r
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.574 .701 .929 r
.74014 .25726 .74616 .26571 .75976 .26381 .75377 .25535 Mtetra
.687 .751 .9 r
.75377 .25535 .75976 .26381 .77317 .25848 .76722 .24988 Mtetra
.697 .752 .894 r
.76722 .24988 .77317 .25848 .78659 .25264 .78069 .24403 Mtetra
.678 .746 .902 r
.78069 .24403 .78659 .25264 .80012 .24747 .79427 .23884 Mtetra
.667 .742 .906 r
.79427 .23884 .80012 .24747 .81376 .24268 .80795 .23402 Mtetra
.665 .741 .907 r
.80795 .23402 .81376 .24268 .82746 .23798 .82171 .22928 Mtetra
.664 .741 .907 r
.82171 .22928 .82746 .23798 .84124 .23328 .83553 .22454 Mtetra
.2201 .426 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.663 .741 .908 r
.23126 .42215 .23879 .42924 .24997 .42543 .24247 .4183 Mtetra
.661 .74 .909 r
.24247 .4183 .24997 .42543 .26119 .42169 .25371 .41452 Mtetra
.649 .736 .913 r
.25371 .41452 .26119 .42169 .27243 .41832 .26498 .41106 Mtetra
.624 .728 .921 r
.26498 .41106 .27243 .41832 .28367 .41559 .27625 .40824 Mtetra
.63 .727 .918 r
.27625 .40824 .28367 .41559 .29499 .41251 .28759 .40528 Mtetra
.724 .755 .877 r
.28759 .40528 .29499 .41251 .3066 .40598 .2992 .39916 Mtetra
.679 .758 .911 r
.2992 .39916 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.664 .741 .907 r
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
0 .241 .732 r
.34555 .38273 .35279 .39014 .36376 .40021 .35663 .39051 Mtetra
.057 .364 .834 r
.35663 .39051 .36376 .40021 .37508 .40585 .3679 .39739 Mtetra
.563 .679 .917 r
.3679 .39739 .37508 .40585 .38688 .4033 .37967 .39607 Mtetra
.739 .768 .876 r
.37967 .39607 .38688 .4033 .39894 .39568 .39174 .38915 Mtetra
.786 .793 .859 r
.39174 .38915 .39894 .39568 .41109 .38636 .40393 .38007 Mtetra
.791 .801 .861 r
.40393 .38007 .41109 .38636 .42325 .37712 .41613 .37083 Mtetra
.78 .802 .87 r
.41613 .37083 .42325 .37712 .4354 .3686 .42834 .36221 Mtetra
.763 .798 .882 r
.42834 .36221 .4354 .3686 .44755 .36092 .44054 .35441 Mtetra
.745 .794 .892 r
.44054 .35441 .44755 .36092 .45971 .35406 .45275 .34741 Mtetra
.715 .785 .907 r
.45275 .34741 .45971 .35406 .47187 .34928 .46497 .34154 Mtetra
.664 .741 .907 r
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.607 .72 .925 r
.5518 .31159 .55845 .31959 .57105 .31588 .56445 .30892 Mtetra
.547 .728 .958 r
.56445 .30892 .57105 .31588 .58376 .31428 .5772 .30739 Mtetra
.503 .712 .965 r
.5772 .30739 .58376 .31428 .59656 .31351 .59004 .30668 Mtetra
.454 .69 .968 r
.59004 .30668 .59656 .31351 .60948 .31362 .60299 .30681 Mtetra
.413 .671 .967 r
.60299 .30681 .60948 .31362 .62252 .31447 .61606 .30759 Mtetra
.424 .676 .967 r
.61606 .30759 .62252 .31447 .63566 .31542 .62923 .30823 Mtetra
.547 .725 .957 r
.62923 .30823 .63566 .31542 .64884 .31465 .64243 .30668 Mtetra
.736 .774 .883 r
.64243 .30668 .64884 .31465 .66189 .30872 .65547 .29941 Mtetra
.846 .768 .776 r
.65547 .29941 .66189 .30872 .67459 .29439 .66816 .28374 Mtetra
.841 .744 .757 r
.66816 .28374 .67459 .29439 .68702 .27548 .68077 .26711 Mtetra
.664 .741 .907 r
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.65 .735 .912 r
.72064 .25336 .72676 .26185 .74014 .25726 .73409 .24921 Mtetra
.587 .722 .936 r
.73409 .24921 .74014 .25726 .75377 .25535 .74773 .2468 Mtetra
.692 .752 .898 r
.74773 .2468 .75377 .25535 .76722 .24988 .76121 .24113 Mtetra
.695 .749 .894 r
.76121 .24113 .76722 .24988 .78069 .24403 .77473 .2353 Mtetra
.677 .744 .902 r
.77473 .2353 .78069 .24403 .79427 .23884 .78837 .23013 Mtetra
.667 .741 .906 r
.78837 .23013 .79427 .23884 .80795 .23402 .8021 .22529 Mtetra
.665 .741 .907 r
.8021 .22529 .80795 .23402 .82171 .22928 .8159 .22051 Mtetra
.664 .741 .907 r
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42215 .22367 .415 Mtetra
.664 .741 .908 r
.22367 .415 .23126 .42215 .24247 .4183 .2349 .41111 Mtetra
.661 .74 .908 r
.2349 .41111 .24247 .4183 .25371 .41452 .24618 .40728 Mtetra
.652 .737 .912 r
.24618 .40728 .25371 .41452 .26498 .41106 .25748 .40372 Mtetra
.629 .728 .919 r
.25748 .40372 .26498 .41106 .27625 .40824 .26879 .40076 Mtetra
.624 .724 .918 r
.26879 .40076 .27625 .40824 .28759 .40528 .28014 .39793 Mtetra
.704 .749 .887 r
.28014 .39793 .28759 .40528 .2992 .39916 .29173 .39257 Mtetra
.702 .771 .905 r
.29173 .39257 .2992 .39916 .31074 .39473 .30335 .38737 Mtetra
.664 .741 .907 r
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.158 .5 .908 r
.33825 .37526 .34555 .38273 .35663 .39051 .34954 .37938 Mtetra
.004 .291 .788 r
.34954 .37938 .35663 .39051 .3679 .39739 .36072 .38788 Mtetra
.482 .617 .907 r
.36072 .38788 .3679 .39739 .37967 .39607 .37241 .38851 Mtetra
.707 .754 .889 r
.37241 .38851 .37967 .39607 .39174 .38915 .38446 .38284 Mtetra
.778 .8 .871 r
.38446 .38284 .39174 .38915 .40393 .38007 .39668 .37428 Mtetra
.793 .817 .871 r
.39668 .37428 .40393 .38007 .41613 .37083 .40893 .36513 Mtetra
.786 .82 .88 r
.40893 .36513 .41613 .37083 .42834 .36221 .42119 .35643 Mtetra
.77 .819 .891 r
.42119 .35643 .42834 .36221 .44054 .35441 .43344 .34846 Mtetra
.751 .813 .902 r
.43344 .34846 .44054 .35441 .45275 .34741 .4457 .34131 Mtetra
.732 .807 .911 r
.4457 .34131 .45275 .34741 .46497 .34154 .45798 .33486 Mtetra
.7 .784 .916 r
.45798 .33486 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.664 .741 .907 r
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.627 .727 .92 r
.53248 .30791 .53922 .31593 .5518 .31159 .5451 .30467 Mtetra
.575 .742 .955 r
.5451 .30467 .5518 .31159 .56445 .30892 .5578 .30251 Mtetra
.531 .741 .972 r
.5578 .30251 .56445 .30892 .5772 .30739 .57058 .30107 Mtetra
.481 .723 .977 r
.57058 .30107 .5772 .30739 .59004 .30668 .58346 .30045 Mtetra
.43 .702 .979 r
.58346 .30045 .59004 .30668 .60299 .30681 .59646 .3006 Mtetra
.399 .687 .977 r
.59646 .3006 .60299 .30681 .61606 .30759 .60956 .30122 Mtetra
.441 .704 .977 r
.60956 .30122 .61606 .30759 .62923 .30823 .62275 .30126 Mtetra
.601 .758 .953 r
.62275 .30126 .62923 .30823 .64243 .30668 .63594 .29836 Mtetra
.774 .777 .855 r
.63594 .29836 .64243 .30668 .65547 .29941 .64895 .28903 Mtetra
.849 .751 .754 r
.64895 .28903 .65547 .29941 .66816 .28374 .66162 .27163 Mtetra
.79 .709 .775 r
.66162 .27163 .66816 .28374 .68077 .26711 .67446 .25868 Mtetra
.664 .741 .907 r
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.625 .725 .918 r
.71446 .2448 .72064 .25336 .73409 .24921 .728 .24138 Mtetra
.616 .743 .937 r
.728 .24138 .73409 .24921 .74773 .2468 .74163 .23812 Mtetra
.696 .752 .895 r
.74163 .23812 .74773 .2468 .76121 .24113 .75515 .23224 Mtetra
.692 .746 .893 r
.75515 .23224 .76121 .24113 .77473 .2353 .76872 .22648 Mtetra
.674 .742 .902 r
.76872 .22648 .77473 .2353 .78837 .23013 .78241 .22134 Mtetra
.666 .741 .906 r
.78241 .22134 .78837 .23013 .8021 .22529 .79619 .21648 Mtetra
.664 .741 .907 r
.79619 .21648 .8021 .22529 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .41171 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.663 .741 .907 r
.21601 .40779 .22367 .415 .2349 .41111 .22728 .40388 Mtetra
.662 .74 .908 r
.22728 .40388 .2349 .41111 .24618 .40728 .23858 .39999 Mtetra
.654 .737 .911 r
.23858 .39999 .24618 .40728 .25748 .40372 .24992 .39631 Mtetra
.634 .73 .917 r
.24992 .39631 .25748 .40372 .26879 .40076 .26127 .39318 Mtetra
.62 .721 .918 r
.26127 .39318 .26879 .40076 .28014 .39793 .27264 .39041 Mtetra
.679 .74 .897 r
.27264 .39041 .28014 .39793 .29173 .39257 .28419 .3859 Mtetra
.722 .774 .894 r
.28419 .3859 .29173 .39257 .30335 .38737 .2959 .37994 Mtetra
.664 .741 .907 r
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.536 .697 .943 r
.3309 .36773 .33825 .37526 .34954 .37938 .34249 .36673 Mtetra
0 .229 .745 r
.34249 .36673 .34954 .37938 .36072 .38788 .35356 .37682 Mtetra
.369 .521 .878 r
.35356 .37682 .36072 .38788 .37241 .38851 .36513 .38007 Mtetra
.647 .715 .898 r
.36513 .38007 .37241 .38851 .38446 .38284 .37712 .3764 Mtetra
.757 .796 .885 r
.37712 .3764 .38446 .38284 .39668 .37428 .38934 .36882 Mtetra
.789 .828 .882 r
.38934 .36882 .39668 .37428 .40893 .36513 .40164 .35999 Mtetra
.79 .839 .889 r
.40164 .35999 .40893 .36513 .42119 .35643 .41395 .35127 Mtetra
.776 .839 .9 r
.41395 .35127 .42119 .35643 .43344 .34846 .42626 .34318 Mtetra
.758 .835 .911 r
.42626 .34318 .43344 .34846 .4457 .34131 .43857 .33582 Mtetra
.737 .828 .921 r
.43857 .33582 .4457 .34131 .45798 .33486 .4509 .32921 Mtetra
.718 .821 .929 r
.4509 .32921 .45798 .33486 .47027 .32948 .46326 .32325 Mtetra
.698 .8 .928 r
.46326 .32325 .47027 .32948 .4826 .32521 .47564 .31787 Mtetra
.681 .763 .914 r
.47564 .31787 .4826 .32521 .49499 .32091 .48807 .31302 Mtetra
.664 .743 .909 r
.48807 .31302 .49499 .32091 .50743 .3166 .50055 .30867 Mtetra
.647 .738 .915 r
.50055 .30867 .50743 .3166 .51992 .31226 .51308 .30482 Mtetra
.627 .745 .933 r
.51308 .30482 .51992 .31226 .53248 .30791 .52568 .3015 Mtetra
.593 .767 .962 r
.52568 .3015 .53248 .30791 .5451 .30467 .53834 .29878 Mtetra
.552 .769 .979 r
.53834 .29878 .5451 .30467 .5578 .30251 .55108 .29671 Mtetra
.506 .754 .985 r
.55108 .29671 .5578 .30251 .57058 .30107 .56391 .2954 Mtetra
.454 .735 .988 r
.56391 .2954 .57058 .30107 .58346 .30045 .57684 .29485 Mtetra
.406 .714 .986 r
.57684 .29485 .58346 .30045 .59646 .3006 .58987 .29495 Mtetra
.399 .709 .985 r
.58987 .29495 .59646 .3006 .60956 .30122 .60301 .29518 Mtetra
.492 .743 .983 r
.60301 .29518 .60956 .30122 .62275 .30126 .61621 .29414 Mtetra
.677 .783 .93 r
.61621 .29414 .62275 .30126 .63594 .29836 .62937 .28914 Mtetra
.807 .765 .814 r
.62937 .28914 .63594 .29836 .64895 .28903 .64233 .27706 Mtetra
.846 .727 .732 r
.64233 .27706 .64895 .28903 .66162 .27163 .65498 .25795 Mtetra
.706 .654 .796 r
.65498 .25795 .66162 .27163 .67446 .25868 .6681 .25016 Mtetra
.664 .741 .907 r
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.599 .713 .924 r
.70823 .23617 .71446 .2448 .728 .24138 .72186 .23346 Mtetra
.648 .756 .928 r
.72186 .23346 .728 .24138 .74163 .23812 .73547 .22924 Mtetra
.698 .75 .892 r
.73547 .22924 .74163 .23812 .75515 .23224 .74903 .22322 Mtetra
.687 .743 .894 r
.74903 .22322 .75515 .23224 .76872 .22648 .76266 .21757 Mtetra
.672 .741 .902 r
.76266 .21757 .76872 .22648 .78241 .22134 .7764 .21247 Mtetra
.665 .741 .906 r
.7764 .21247 .78241 .22134 .79619 .21648 .79023 .20759 Mtetra
.664 .741 .907 r
.79023 .20759 .79619 .21648 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19787 Mtetra
.19705 .40447 .2048 .41171 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40388 .21959 .39657 Mtetra
.662 .74 .908 r
.21959 .39657 .22728 .40388 .23858 .39999 .23093 .39264 Mtetra
.657 .739 .91 r
.23093 .39264 .23858 .39999 .24992 .39631 .2423 .38884 Mtetra
.641 .731 .914 r
.2423 .38884 .24992 .39631 .26127 .39318 .25369 .3855 Mtetra
.621 .72 .918 r
.25369 .3855 .26127 .39318 .27264 .39041 .26508 .3827 Mtetra
.653 .73 .906 r
.26508 .3827 .27264 .39041 .28419 .3859 .27661 .37896 Mtetra
.733 .77 .882 r
.27661 .37896 .28419 .3859 .2959 .37994 .28839 .37245 Mtetra
.664 .741 .907 r
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34249 .36673 .33528 .35601 Mtetra
.026 .32 .807 r
.33528 .35601 .34249 .36673 .35356 .37682 .34647 .36375 Mtetra
.246 .406 .825 r
.34647 .36375 .35356 .37682 .36513 .38007 .35787 .36998 Mtetra
.547 .636 .891 r
.35787 .36998 .36513 .38007 .37712 .3764 .36975 .36917 Mtetra
.711 .769 .897 r
.36975 .36917 .37712 .3764 .38934 .36882 .38193 .36334 Mtetra
.773 .828 .895 r
.38193 .36334 .38934 .36882 .40164 .35999 .39425 .35525 Mtetra
.787 .852 .9 r
.39425 .35525 .40164 .35999 .41395 .35127 .40661 .34672 Mtetra
.78 .86 .909 r
.40661 .34672 .41395 .35127 .42626 .34318 .41898 .33854 Mtetra
.762 .858 .921 r
.41898 .33854 .42626 .34318 .43857 .33582 .43135 .33105 Mtetra
.743 .853 .931 r
.43135 .33105 .43857 .33582 .4509 .32921 .44374 .32423 Mtetra
.721 .845 .94 r
.44374 .32423 .4509 .32921 .46326 .32325 .45614 .31812 Mtetra
.7 .837 .948 r
.45614 .31812 .46326 .32325 .47564 .31787 .46858 .3126 Mtetra
.679 .829 .956 r
.46858 .3126 .47564 .31787 .48807 .31302 .48106 .30767 Mtetra
.656 .822 .963 r
.48106 .30767 .48807 .31302 .50055 .30867 .49359 .30329 Mtetra
.632 .815 .97 r
.49359 .30329 .50055 .30867 .51308 .30482 .50617 .29945 Mtetra
.603 .807 .978 r
.50617 .29945 .51308 .30482 .52568 .3015 .51881 .2962 Mtetra
.569 .798 .985 r
.51881 .2962 .52568 .3015 .53834 .29878 .53152 .29356 Mtetra
.526 .784 .991 r
.53152 .29356 .53834 .29878 .55108 .29671 .5443 .29163 Mtetra
.476 .768 .995 r
.5443 .29163 .55108 .29671 .56391 .2954 .55718 .29039 Mtetra
.424 .746 .993 r
.55718 .29039 .56391 .2954 .57684 .29485 .57015 .28986 Mtetra
.395 .732 .991 r
.57015 .28986 .57684 .29485 .58987 .29495 .58323 .2897 Mtetra
.436 .745 .993 r
.58323 .2897 .58987 .29495 .60301 .29518 .59639 .2891 Mtetra
.586 .784 .974 r
.59639 .2891 .60301 .29518 .61621 .29414 .60959 .28622 Mtetra
.751 .784 .879 r
.60959 .28622 .61621 .29414 .62937 .28914 .6227 .27822 Mtetra
.825 .738 .769 r
.6227 .27822 .62937 .28914 .64233 .27706 .63559 .26302 Mtetra
.809 .692 .735 r
.63559 .26302 .64233 .27706 .65498 .25795 .64838 .24624 Mtetra
.656 .665 .847 r
.64838 .24624 .65498 .25795 .6681 .25016 .66168 .24157 Mtetra
.664 .741 .907 r
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.58 .705 .928 r
.70194 .22746 .70823 .23617 .72186 .23346 .71565 .22524 Mtetra
.674 .759 .915 r
.71565 .22524 .72186 .23346 .73547 .22924 .72925 .22015 Mtetra
.697 .746 .889 r
.72925 .22015 .73547 .22924 .74903 .22322 .74285 .21409 Mtetra
.683 .741 .895 r
.74285 .21409 .74903 .22322 .76266 .21757 .75655 .20858 Mtetra
.67 .74 .903 r
.75655 .20858 .76266 .21757 .7764 .21247 .77034 .20353 Mtetra
.665 .741 .906 r
.77034 .20353 .7764 .21247 .79023 .20759 .78422 .19862 Mtetra
.664 .741 .907 r
.78422 .19862 .79023 .20759 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19787 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38922 Mtetra
.663 .741 .908 r
.21184 .38922 .21959 .39657 .23093 .39264 .22321 .38523 Mtetra
.66 .739 .909 r
.22321 .38523 .23093 .39264 .2423 .38884 .23462 .38134 Mtetra
.647 .734 .912 r
.23462 .38134 .2423 .38884 .25369 .3855 .24605 .37778 Mtetra
.626 .722 .916 r
.24605 .37778 .25369 .3855 .26508 .3827 .25748 .3748 Mtetra
.633 .721 .911 r
.25748 .3748 .26508 .3827 .27661 .37896 .26899 .37162 Mtetra
.717 .758 .885 r
.26899 .37162 .27661 .37896 .28839 .37245 .28076 .36566 Mtetra
.689 .769 .912 r
.28076 .36566 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.664 .741 .907 r
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.465 .666 .95 r
.32784 .34832 .33528 .35601 .34647 .36375 .33946 .34852 Mtetra
.16 .312 .77 r
.33946 .34852 .34647 .36375 .35787 .36998 .35071 .35734 Mtetra
.415 .516 .852 r
.35071 .35734 .35787 .36998 .36975 .36917 .3624 .36015 Mtetra
.625 .697 .897 r
.3624 .36015 .36975 .36917 .38193 .36334 .37449 .35707 Mtetra
.733 .803 .907 r
.37449 .35707 .38193 .36334 .39425 .35525 .38679 .35049 Mtetra
.772 .853 .911 r
.38679 .35049 .39425 .35525 .40661 .34672 .39918 .34258 Mtetra
.776 .874 .919 r
.39918 .34258 .40661 .34672 .41898 .33854 .4116 .33456 Mtetra
.764 .88 .93 r
.4116 .33456 .41898 .33854 .43135 .33105 .42403 .32698 Mtetra
.745 .877 .941 r
.42403 .32698 .43135 .33105 .44374 .32423 .43647 .32004 Mtetra
.723 .872 .951 r
.43647 .32004 .44374 .32423 .45614 .31812 .44894 .31376 Mtetra
.699 .864 .96 r
.44894 .31376 .45614 .31812 .46858 .3126 .46143 .30813 Mtetra
.674 .856 .969 r
.46143 .30813 .46858 .3126 .48106 .30767 .47396 .30311 Mtetra
.648 .848 .977 r
.47396 .30311 .48106 .30767 .49359 .30329 .48654 .29869 Mtetra
.618 .839 .984 r
.48654 .29869 .49359 .30329 .50617 .29945 .49917 .29487 Mtetra
.583 .829 .991 r
.49917 .29487 .50617 .29945 .51881 .2962 .51186 .29167 Mtetra
.542 .816 .997 r
.51186 .29167 .51881 .2962 .53152 .29356 .52462 .28913 Mtetra
.494 .8 .999 r
.52462 .28913 .53152 .29356 .5443 .29163 .53746 .28725 Mtetra
.444 .779 .998 r
.53746 .28725 .5443 .29163 .55718 .29039 .55038 .28604 Mtetra
.407 .762 .995 r
.55038 .28604 .55718 .29039 .57015 .28986 .5634 .28527 Mtetra
.423 .763 .996 r
.5634 .28527 .57015 .28986 .58323 .2897 .57651 .28442 Mtetra
.534 .791 .992 r
.57651 .28442 .58323 .2897 .59639 .2891 .58969 .28222 Mtetra
.699 .799 .927 r
.58969 .28222 .59639 .2891 .60959 .28622 .60286 .27646 Mtetra
.798 .754 .812 r
.60286 .27646 .60959 .28622 .6227 .27822 .61591 .26469 Mtetra
.823 .703 .732 r
.61591 .26469 .6227 .27822 .63559 .26302 .62875 .24678 Mtetra
.709 .626 .762 r
.62875 .24678 .63559 .26302 .64838 .24624 .64187 .23761 Mtetra
.664 .741 .907 r
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.64 .731 .915 r
.68207 .22344 .68846 .23219 .70194 .22746 .69564 .21946 Mtetra
.598 .736 .941 r
.69564 .21946 .70194 .22746 .71565 .22524 .70936 .21659 Mtetra
.69 .756 .902 r
.70936 .21659 .71565 .22524 .72925 .22015 .72297 .21085 Mtetra
.693 .742 .888 r
.72297 .21085 .72925 .22015 .74285 .21409 .73662 .20489 Mtetra
.677 .739 .897 r
.73662 .20489 .74285 .21409 .75655 .20858 .75038 .19953 Mtetra
.668 .74 .904 r
.75038 .19953 .75655 .20858 .77034 .20353 .76423 .19451 Mtetra
.664 .74 .907 r
.76423 .19451 .77034 .20353 .78422 .19862 .77815 .18958 Mtetra
.664 .741 .907 r
.77815 .18958 .78422 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38922 .20403 .3818 Mtetra
.663 .741 .907 r
.20403 .3818 .21184 .38922 .22321 .38523 .21543 .37777 Mtetra
.661 .74 .908 r
.21543 .37777 .22321 .38523 .23462 .38134 .22687 .37379 Mtetra
.653 .736 .91 r
.22687 .37379 .23462 .38134 .24605 .37778 .23834 .37003 Mtetra
.634 .726 .914 r
.23834 .37003 .24605 .37778 .25748 .3748 .24982 .36679 Mtetra
.624 .716 .913 r
.24982 .36679 .25748 .3748 .26899 .37162 .26133 .36384 Mtetra
.674 .738 .899 r
.26133 .36384 .26899 .37162 .28076 .36566 .27302 .35937 Mtetra
.728 .792 .903 r
.27302 .35937 .28076 .36566 .2925 .36078 .28489 .35313 Mtetra
.664 .741 .907 r
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33946 .34852 .33225 .33635 Mtetra
.266 .44 .847 r
.33225 .33635 .33946 .34852 .35071 .35734 .34367 .34162 Mtetra
.298 .393 .792 r
.34367 .34162 .35071 .35734 .3624 .36015 .35516 .34804 Mtetra
.497 .572 .861 r
.35516 .34804 .3624 .36015 .37449 .35707 .36707 .34875 Mtetra
.651 .727 .904 r
.36707 .34875 .37449 .35707 .38679 .35049 .37929 .3448 Mtetra
.732 .823 .921 r
.37929 .3448 .38679 .35049 .39918 .34258 .39167 .3383 Mtetra
.758 .871 .93 r
.39167 .3383 .39918 .34258 .4116 .33456 .40412 .3309 Mtetra
.756 .891 .939 r
.40412 .3309 .4116 .33456 .42403 .32698 .4166 .32352 Mtetra
.741 .898 .949 r
.4166 .32352 .42403 .32698 .43647 .32004 .42911 .31656 Mtetra
.718 .896 .96 r
.42911 .31656 .43647 .32004 .44894 .31376 .44163 .3102 Mtetra
.693 .89 .97 r
.44163 .3102 .44894 .31376 .46143 .30813 .45419 .30448 Mtetra
.664 .882 .979 r
.45419 .30448 .46143 .30813 .47396 .30311 .46678 .29939 Mtetra
.632 .873 .987 r
.46678 .29939 .47396 .30311 .48654 .29869 .47941 .29494 Mtetra
.597 .862 .993 r
.47941 .29494 .48654 .29869 .49917 .29487 .49209 .29112 Mtetra
.556 .848 .998 r
.49209 .29112 .49917 .29487 .51186 .29167 .50483 .28795 Mtetra
.51 .831 1 r
.50483 .28795 .51186 .29167 .52462 .28913 .51765 .28541 Mtetra
.464 .812 .998 r
.51765 .28541 .52462 .28913 .53746 .28725 .53054 .28349 Mtetra
.431 .795 .996 r
.53054 .28349 .53746 .28725 .55038 .28604 .54351 .28201 Mtetra
.44 .791 .997 r
.54351 .28201 .55038 .28604 .5634 .28527 .55657 .28055 Mtetra
.526 .808 .997 r
.55657 .28055 .5634 .28527 .57651 .28442 .56971 .27819 Mtetra
.67 .812 .951 r
.56971 .27819 .57651 .28442 .58969 .28222 .58288 .27324 Mtetra
.774 .765 .845 r
.58288 .27324 .58969 .28222 .60286 .27646 .59601 .26356 Mtetra
.809 .707 .752 r
.59601 .26356 .60286 .27646 .61591 .26469 .60899 .24803 Mtetra
.766 .649 .732 r
.60899 .24803 .61591 .26469 .62875 .24678 .62198 .23364 Mtetra
.65 .64 .827 r
.62198 .23364 .62875 .24678 .64187 .23761 .63529 .22892 Mtetra
.664 .741 .907 r
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.594 .711 .926 r
.67563 .21462 .68207 .22344 .69564 .21946 .68932 .21196 Mtetra
.652 .775 .939 r
.68932 .21196 .69564 .21946 .70936 .21659 .70298 .20747 Mtetra
.696 .748 .892 r
.70298 .20747 .70936 .21659 .72297 .21085 .71662 .20142 Mtetra
.687 .738 .89 r
.71662 .20142 .72297 .21085 .73662 .20489 .73034 .19566 Mtetra
.673 .738 .899 r
.73034 .19566 .73662 .20489 .75038 .19953 .74416 .19042 Mtetra
.666 .74 .905 r
.74416 .19042 .75038 .19953 .76423 .19451 .75806 .18541 Mtetra
.664 .741 .907 r
.75806 .18541 .76423 .19451 .77815 .18958 .77203 .18045 Mtetra
.77203 .18045 .77815 .18958 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37777 .20758 .37026 Mtetra
.663 .74 .908 r
.20758 .37026 .21543 .37777 .22687 .37379 .21906 .3662 Mtetra
.658 .738 .909 r
.21906 .3662 .22687 .37379 .23834 .37003 .23057 .36228 Mtetra
.644 .73 .912 r
.23057 .36228 .23834 .37003 .24982 .36679 .2421 .35874 Mtetra
.625 .718 .913 r
.2421 .35874 .24982 .36679 .26133 .36384 .25364 .35571 Mtetra
.641 .721 .906 r
.25364 .35571 .26133 .36384 .27302 .35937 .26528 .35222 Mtetra
.724 .769 .888 r
.26528 .35222 .27302 .35937 .28489 .35313 .27719 .34595 Mtetra
.681 .76 .911 r
.27719 .34595 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.664 .741 .907 r
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34367 .34162 .33671 .32422 Mtetra
.27 .352 .764 r
.33671 .32422 .34367 .34162 .35516 .34804 .3481 .33192 Mtetra
.376 .437 .796 r
.3481 .33192 .35516 .34804 .36707 .34875 .35979 .33666 Mtetra
.527 .59 .861 r
.35979 .33666 .36707 .34875 .37929 .3448 .37183 .33652 Mtetra
.647 .729 .909 r
.37183 .33652 .37929 .3448 .39167 .3383 .38413 .33266 Mtetra
.712 .824 .934 r
.38413 .33266 .39167 .3383 .40412 .3309 .39658 .32678 Mtetra
.733 .876 .947 r
.39658 .32678 .40412 .3309 .4166 .32352 .40909 .32015 Mtetra
.727 .9 .957 r
.40909 .32015 .4166 .32352 .42911 .31656 .42164 .31351 Mtetra
.707 .908 .966 r
.42164 .31351 .42911 .31656 .44163 .3102 .43423 .30725 Mtetra
.68 .908 .975 r
.43423 .30725 .44163 .3102 .45419 .30448 .44684 .30153 Mtetra
.648 .901 .983 r
.44684 .30153 .45419 .30448 .46678 .29939 .45949 .29642 Mtetra
.612 .891 .989 r
.45949 .29642 .46678 .29939 .47941 .29494 .47218 .29193 Mtetra
.573 .878 .993 r
.47218 .29193 .47941 .29494 .49209 .29112 .48492 .28808 Mtetra
.531 .861 .995 r
.48492 .28808 .49209 .29112 .50483 .28795 .49772 .28483 Mtetra
.493 .844 .995 r
.49772 .28483 .50483 .28795 .51765 .28541 .51059 .28213 Mtetra
.47 .829 .995 r
.51059 .28213 .51765 .28541 .53054 .28349 .52353 .27981 Mtetra
.486 .825 .999 r
.52353 .27981 .53054 .28349 .54351 .28201 .53656 .2775 Mtetra
.56 .83 .996 r
.53656 .2775 .54351 .28201 .55657 .28055 .54966 .27444 Mtetra
.675 .817 .951 r
.54966 .27444 .55657 .28055 .56971 .27819 .56281 .26932 Mtetra
.761 .765 .856 r
.56281 .26932 .56971 .27819 .58288 .27324 .57596 .26044 Mtetra
.793 .703 .765 r
.57596 .26044 .58288 .27324 .59601 .26356 .58903 .24656 Mtetra
.786 .655 .718 r
.58903 .24656 .59601 .26356 .60899 .24803 .60201 .22964 Mtetra
.631 .565 .762 r
.60201 .22964 .60899 .24803 .62198 .23364 .6153 .2249 Mtetra
.664 .741 .907 r
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.648 .734 .912 r
.65557 .21055 .66212 .21941 .67563 .21462 .66915 .20626 Mtetra
.591 .725 .937 r
.66915 .20626 .67563 .21462 .68932 .21196 .68288 .20356 Mtetra
.685 .764 .911 r
.68288 .20356 .68932 .21196 .70298 .20747 .69654 .19798 Mtetra
.693 .74 .887 r
.69654 .19798 .70298 .20747 .71662 .20142 .71023 .19193 Mtetra
.68 .736 .893 r
.71023 .19193 .71662 .20142 .73034 .19566 .72401 .1864 Mtetra
.669 .738 .902 r
.72401 .1864 .73034 .19566 .74416 .19042 .73788 .18126 Mtetra
.665 .74 .906 r
.73788 .18126 .74416 .19042 .75806 .18541 .75183 .17624 Mtetra
.664 .741 .907 r
.75183 .17624 .75806 .18541 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16622 Mtetra
.77994 .16622 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37026 .19967 .36268 Mtetra
.663 .741 .907 r
.19967 .36268 .20758 .37026 .21906 .3662 .21118 .35858 Mtetra
.661 .739 .908 r
.21118 .35858 .21906 .3662 .23057 .36228 .22273 .35453 Mtetra
.652 .734 .91 r
.22273 .35453 .23057 .36228 .2421 .35874 .23431 .35072 Mtetra
.635 .723 .911 r
.23431 .35072 .2421 .35874 .25364 .35571 .2459 .3474 Mtetra
.627 .713 .909 r
.2459 .3474 .25364 .35571 .26528 .35222 .25753 .34429 Mtetra
.67 .737 .901 r
.25753 .34429 .26528 .35222 .27719 .34595 .26932 .33987 Mtetra
.733 .803 .907 r
.26932 .33987 .27719 .34595 .28902 .34122 .28132 .33341 Mtetra
.664 .741 .907 r
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.647 .736 .914 r
.32915 .31626 .33671 .32422 .3481 .33192 .34121 .31244 Mtetra
.326 .364 .748 r
.34121 .31244 .3481 .33192 .35979 .33666 .35273 .3196 Mtetra
.417 .45 .787 r
.35273 .3196 .35979 .33666 .37183 .33652 .36456 .32351 Mtetra
.527 .574 .846 r
.36456 .32351 .37183 .33652 .38413 .33266 .37669 .32345 Mtetra
.62 .699 .901 r
.37669 .32345 .38413 .33266 .39658 .32678 .38905 .32035 Mtetra
.677 .795 .938 r
.38905 .32035 .39658 .32678 .40909 .32015 .40154 .31547 Mtetra
.697 .856 .958 r
.40154 .31547 .40909 .32015 .42164 .31351 .41411 .30985 Mtetra
.691 .888 .97 r
.41411 .30985 .42164 .31351 .43423 .30725 .42673 .30412 Mtetra
.669 .901 .978 r
.42673 .30412 .43423 .30725 .44684 .30153 .4394 .29865 Mtetra
.64 .902 .984 r
.4394 .29865 .44684 .30153 .45949 .29642 .45211 .29361 Mtetra
.606 .895 .988 r
.45211 .29361 .45949 .29642 .47218 .29193 .46486 .28909 Mtetra
.573 .884 .991 r
.46486 .28909 .47218 .29193 .48492 .28808 .47766 .28509 Mtetra
.548 .87 .994 r
.47766 .28509 .48492 .28808 .49772 .28483 .49052 .28152 Mtetra
.54 .859 .997 r
.49052 .28152 .49772 .28483 .51059 .28213 .50345 .27822 Mtetra
.564 .851 .997 r
.50345 .27822 .51059 .28213 .52353 .27981 .51645 .27481 Mtetra
.626 .838 .981 r
.51645 .27481 .52353 .27981 .53656 .2775 .52952 .27066 Mtetra
.703 .803 .927 r
.52952 .27066 .53656 .2775 .54966 .27444 .54265 .26471 Mtetra
.756 .745 .842 r
.54265 .26471 .54966 .27444 .56281 .26932 .5558 .25566 Mtetra
.777 .687 .764 r
.5558 .25566 .56281 .26932 .57596 .26044 .56892 .24258 Mtetra
.775 .643 .716 r
.56892 .24258 .57596 .26044 .58903 .24656 .58197 .22616 Mtetra
.632 .548 .741 r
.58197 .22616 .58903 .24656 .60201 .22964 .59523 .22088 Mtetra
.664 .741 .907 r
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.589 .709 .927 r
.64897 .20161 .65557 .21055 .66915 .20626 .66267 .19902 Mtetra
.656 .788 .945 r
.66267 .19902 .66915 .20626 .68288 .20356 .67635 .19433 Mtetra
.694 .747 .893 r
.67635 .19433 .68288 .20356 .69654 .19798 .69003 .18829 Mtetra
.686 .734 .887 r
.69003 .18829 .69654 .19798 .71023 .19193 .70378 .18246 Mtetra
.673 .735 .897 r
.70378 .18246 .71023 .19193 .72401 .1864 .71763 .17712 Mtetra
.666 .739 .904 r
.71763 .17712 .72401 .1864 .73788 .18126 .73155 .17203 Mtetra
.664 .74 .907 r
.73155 .17203 .73788 .18126 .75183 .17624 .74555 .16699 Mtetra
.664 .741 .907 r
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16622 .77376 .15688 Mtetra
.77376 .15688 .77994 .16622 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36332 Mtetra
.16877 .36332 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35858 .20323 .3509 Mtetra
.662 .74 .908 r
.20323 .3509 .21118 .35858 .22273 .35453 .21482 .34676 Mtetra
.658 .737 .909 r
.21482 .34676 .22273 .35453 .23431 .35072 .22644 .34275 Mtetra
.646 .729 .91 r
.22644 .34275 .23431 .35072 .2459 .3474 .23809 .33908 Mtetra
.629 .716 .909 r
.23809 .33908 .2459 .3474 .25753 .34429 .24975 .33586 Mtetra
.636 .716 .905 r
.24975 .33586 .25753 .34429 .26932 .33987 .26149 .33243 Mtetra
.699 .76 .9 r
.26149 .33243 .26932 .33987 .28132 .33341 .27344 .32702 Mtetra
.712 .793 .915 r
.27344 .32702 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.664 .741 .907 r
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34121 .31244 .33364 .30387 Mtetra
.663 .727 .897 r
.33364 .30387 .34121 .31244 .35273 .3196 .34583 .29948 Mtetra
.4 .405 .749 r
.34583 .29948 .35273 .3196 .36456 .32351 .35755 .30466 Mtetra
.44 .444 .767 r
.35755 .30466 .36456 .32351 .37669 .32345 .36949 .30823 Mtetra
.514 .534 .814 r
.36949 .30823 .37669 .32345 .38905 .32035 .38168 .30877 Mtetra
.584 .632 .866 r
.38168 .30877 .38905 .32035 .40154 .31547 .39407 .3068 Mtetra
.634 .721 .911 r
.39407 .3068 .40154 .31547 .41411 .30985 .4066 .3032 Mtetra
.66 .788 .943 r
.4066 .3032 .41411 .30985 .42673 .30412 .41923 .29875 Mtetra
.664 .83 .963 r
.41923 .29875 .42673 .30412 .4394 .29865 .43192 .29399 Mtetra
.655 .852 .976 r
.43192 .29399 .4394 .29865 .45211 .29361 .44467 .28927 Mtetra
.641 .86 .982 r
.44467 .28927 .45211 .29361 .46486 .28909 .45748 .28471 Mtetra
.632 .857 .985 r
.45748 .28471 .46486 .28909 .47766 .28509 .47034 .28033 Mtetra
.635 .847 .981 r
.47034 .28033 .47766 .28509 .49052 .28152 .48326 .27596 Mtetra
.656 .828 .966 r
.48326 .27596 .49052 .28152 .50345 .27822 .49625 .2713 Mtetra
.69 .797 .931 r
.49625 .2713 .50345 .27822 .51645 .27481 .50931 .26579 Mtetra
.725 .751 .873 r
.50931 .26579 .51645 .27481 .52952 .27066 .52242 .25862 Mtetra
.748 .7 .806 r
.52242 .25862 .52952 .27066 .54265 .26471 .53557 .24889 Mtetra
.757 .654 .748 r
.53557 .24889 .54265 .26471 .5558 .25566 .54871 .23608 Mtetra
.746 .616 .714 r
.54871 .23608 .5558 .25566 .56892 .24258 .56182 .22161 Mtetra
.622 .538 .739 r
.56182 .22161 .56892 .24258 .58197 .22616 .57508 .21683 Mtetra
.663 .727 .897 r
.57508 .21683 .58197 .22616 .59523 .22088 .58839 .21203 Mtetra
.664 .741 .907 r
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.616 .721 .921 r
.62873 .19749 .63544 .20646 .64897 .20161 .64237 .19412 Mtetra
.622 .768 .95 r
.64237 .19412 .64897 .20161 .66267 .19902 .65607 .19037 Mtetra
.689 .761 .907 r
.65607 .19037 .66267 .19902 .67635 .19433 .66975 .18458 Mtetra
.69 .735 .885 r
.66975 .18458 .67635 .19433 .69003 .18829 .68347 .17857 Mtetra
.678 .732 .891 r
.68347 .17857 .69003 .18829 .70378 .18246 .69729 .17302 Mtetra
.669 .737 .901 r
.69729 .17302 .70378 .18246 .71763 .17712 .71119 .16782 Mtetra
.665 .74 .906 r
.71119 .16782 .71763 .17712 .73155 .17203 .72516 .16273 Mtetra
.664 .741 .907 r
.72516 .16273 .73155 .17203 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14746 Mtetra
.76752 .14746 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36332 .16067 .35569 Mtetra
.16067 .35569 .16877 .36332 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .3509 .19522 .34316 Mtetra
.663 .741 .907 r
.19522 .34316 .20323 .3509 .21482 .34676 .20684 .33897 Mtetra
.661 .739 .908 r
.20684 .33897 .21482 .34676 .22644 .34275 .2185 .33482 Mtetra
.654 .735 .908 r
.2185 .33482 .22644 .34275 .23809 .33908 .2302 .33085 Mtetra
.64 .724 .909 r
.2302 .33085 .23809 .33908 .24975 .33586 .24192 .32728 Mtetra
.629 .712 .906 r
.24192 .32728 .24975 .33586 .26149 .33243 .25366 .32403 Mtetra
.647 .723 .904 r
.25366 .32403 .26149 .33243 .27344 .32702 .26552 .32021 Mtetra
.72 .784 .903 r
.26552 .32021 .27344 .32702 .28547 .32124 .27761 .31407 Mtetra
.69 .769 .912 r
.27761 .31407 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.664 .741 .907 r
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35755 .30466 .35047 .28687 Mtetra
.535 .512 .777 r
.35047 .28687 .35755 .30466 .36949 .30823 .36257 .28685 Mtetra
.464 .435 .741 r
.36257 .28685 .36949 .30823 .38168 .30877 .3746 .28999 Mtetra
.509 .488 .769 r
.3746 .28999 .38168 .30877 .39407 .3068 .38685 .29103 Mtetra
.556 .551 .804 r
.38685 .29103 .39407 .3068 .4066 .3032 .39928 .29008 Mtetra
.597 .613 .838 r
.39928 .29008 .4066 .3032 .41923 .29875 .41185 .2876 Mtetra
.627 .664 .866 r
.41185 .2876 .41923 .29875 .43192 .29399 .42453 .28411 Mtetra
.647 .701 .885 r
.42453 .28411 .43192 .29399 .44467 .28927 .43729 .27997 Mtetra
.661 .72 .893 r
.43729 .27997 .44467 .28927 .45748 .28471 .45013 .27537 Mtetra
.673 .725 .888 r
.45013 .27537 .45748 .28471 .47034 .28033 .46304 .27031 Mtetra
.687 .715 .87 r
.46304 .27031 .47034 .28033 .48326 .27596 .47602 .2646 Mtetra
.701 .694 .839 r
.47602 .2646 .48326 .27596 .49625 .2713 .48906 .25787 Mtetra
.715 .665 .8 r
.48906 .25787 .49625 .2713 .50931 .26579 .50216 .24959 Mtetra
.724 .635 .758 r
.50216 .24959 .50931 .26579 .52242 .25862 .5153 .23929 Mtetra
.728 .609 .724 r
.5153 .23929 .52242 .25862 .53557 .24889 .52845 .22684 Mtetra
.678 .562 .717 r
.52845 .22684 .53557 .24889 .54871 .23608 .54161 .21757 Mtetra
.63 .564 .762 r
.54161 .21757 .54871 .23608 .56182 .22161 .55484 .21277 Mtetra
.664 .741 .907 r
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.639 .731 .915 r
.60841 .19335 .61522 .20236 .62873 .19749 .62199 .18925 Mtetra
.6 .738 .941 r
.62199 .18925 .62873 .19749 .64237 .19412 .63568 .18618 Mtetra
.68 .778 .925 r
.63568 .18618 .64237 .19412 .65607 .19037 .64936 .18072 Mtetra
.691 .739 .887 r
.64936 .18072 .65607 .19037 .66975 .18458 .66308 .17467 Mtetra
.682 .73 .887 r
.66308 .17467 .66975 .18458 .68347 .17857 .67687 .16894 Mtetra
.671 .734 .897 r
.67687 .16894 .68347 .17857 .69729 .17302 .69074 .1636 Mtetra
.666 .738 .904 r
.69074 .1636 .69729 .17302 .71119 .16782 .70469 .15846 Mtetra
.664 .74 .907 r
.70469 .15846 .71119 .16782 .72516 .16273 .71872 .15336 Mtetra
.664 .741 .907 r
.71872 .15336 .72516 .16273 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14746 .76122 .13795 Mtetra
.76122 .13795 .76752 .14746 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33897 .19879 .33113 Mtetra
.663 .74 .907 r
.19879 .33113 .20684 .33897 .2185 .33482 .21049 .32689 Mtetra
.66 .738 .908 r
.21049 .32689 .2185 .33482 .2302 .33085 .22223 .32273 Mtetra
.651 .731 .908 r
.22223 .32273 .2302 .33085 .24192 .32728 .23401 .3188 Mtetra
.638 .719 .906 r
.23401 .3188 .24192 .32728 .25366 .32403 .24581 .31526 Mtetra
.63 .71 .904 r
.24581 .31526 .25366 .32403 .26552 .32021 .25764 .31191 Mtetra
.656 .731 .905 r
.25764 .31191 .26552 .32021 .27761 .31407 .26961 .30777 Mtetra
.728 .803 .911 r
.26961 .30777 .27761 .31407 .28967 .30892 .2818 .30137 Mtetra
.681 .76 .911 r
.2818 .30137 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.664 .741 .907 r
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .36257 .28685 .35518 .27409 Mtetra
.649 .641 .828 r
.35518 .27409 .36257 .28685 .3746 .28999 .3676 .26956 Mtetra
.564 .505 .747 r
.3676 .26956 .3746 .28999 .38685 .29103 .37993 .26817 Mtetra
.523 .461 .729 r
.37993 .26817 .38685 .29103 .39928 .29008 .39226 .26882 Mtetra
.553 .492 .742 r
.39226 .26882 .39928 .29008 .41185 .2876 .40475 .26797 Mtetra
.582 .524 .755 r
.40475 .26797 .41185 .2876 .42453 .28411 .41737 .26571 Mtetra
.608 .551 .765 r
.41737 .26571 .42453 .28411 .43729 .27997 .43011 .2622 Mtetra
.631 .57 .768 r
.43011 .2622 .43729 .27997 .45013 .27537 .44295 .25756 Mtetra
.65 .58 .763 r
.44295 .25756 .45013 .27537 .46304 .27031 .45588 .25177 Mtetra
.666 .582 .752 r
.45588 .25177 .46304 .27031 .47602 .2646 .46888 .24473 Mtetra
.679 .578 .735 r
.46888 .24473 .47602 .2646 .48906 .25787 .48195 .23625 Mtetra
.688 .571 .717 r
.48195 .23625 .48906 .25787 .50216 .24959 .49505 .22626 Mtetra
.657 .542 .712 r
.49505 .22626 .50216 .24959 .5153 .23929 .50817 .2183 Mtetra
.621 .538 .739 r
.50817 .2183 .5153 .23929 .52845 .22684 .52132 .21351 Mtetra
.649 .641 .828 r
.52132 .21351 .52845 .22684 .54161 .21757 .53453 .20869 Mtetra
.664 .741 .907 r
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.647 .734 .913 r
.58801 .18919 .59492 .19824 .60841 .19335 .60155 .1848 Mtetra
.594 .727 .937 r
.60155 .1848 .60841 .19335 .62199 .18925 .61522 .18191 Mtetra
.671 .794 .94 r
.61522 .18191 .62199 .18925 .63568 .18618 .62888 .17669 Mtetra
.691 .743 .892 r
.62888 .17669 .63568 .18618 .64936 .18072 .64259 .17067 Mtetra
.683 .728 .884 r
.64259 .17067 .64936 .18072 .66308 .17467 .65636 .16484 Mtetra
.674 .731 .893 r
.65636 .16484 .66308 .17467 .67687 .16894 .67021 .15939 Mtetra
.667 .736 .902 r
.67021 .15939 .67687 .16894 .69074 .1636 .68414 .15418 Mtetra
.665 .739 .906 r
.68414 .15418 .69074 .1636 .70469 .15846 .69814 .14904 Mtetra
.664 .741 .907 r
.69814 .14904 .70469 .15846 .71872 .15336 .71222 .1439 Mtetra
.71222 .1439 .71872 .15336 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13795 .75486 .12835 Mtetra
.75486 .12835 .76122 .13795 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33178 Mtetra
.16737 .33178 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33113 .19067 .32323 Mtetra
.19067 .32323 .19879 .33113 .21049 .32689 .20241 .31893 Mtetra
.662 .74 .907 r
.20241 .31893 .21049 .32689 .22223 .32273 .21419 .31465 Mtetra
.658 .736 .907 r
.21419 .31465 .22223 .32273 .23401 .3188 .22602 .31048 Mtetra
.65 .728 .907 r
.22602 .31048 .23401 .3188 .24581 .31526 .23787 .30655 Mtetra
.637 .715 .904 r
.23787 .30655 .24581 .31526 .25764 .31191 .24975 .30297 Mtetra
.633 .709 .901 r
.24975 .30297 .25764 .31191 .26961 .30777 .26169 .29949 Mtetra
.658 .735 .906 r
.26169 .29949 .26961 .30777 .2818 .30137 .27374 .29525 Mtetra
.721 .81 .92 r
.27374 .29525 .2818 .30137 .29392 .29643 .286 .28905 Mtetra
.69 .769 .912 r
.286 .28905 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.664 .741 .907 r
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .37993 .26817 .37246 .25655 Mtetra
.654 .666 .849 r
.37246 .25655 .37993 .26817 .39226 .26882 .38504 .25194 Mtetra
.634 .58 .776 r
.38504 .25194 .39226 .26882 .40475 .26797 .39767 .24731 Mtetra
.621 .538 .739 r
.39767 .24731 .40475 .26797 .41737 .26571 .41037 .24265 Mtetra
.614 .517 .72 r
.41037 .24265 .41737 .26571 .43011 .2622 .42312 .23797 Mtetra
.611 .508 .712 r
.42312 .23797 .43011 .2622 .44295 .25756 .43594 .23327 Mtetra
.43594 .23327 .44295 .25756 .45588 .25177 .44881 .22855 Mtetra
.614 .517 .72 r
.44881 .22855 .45588 .25177 .46888 .24473 .46175 .22381 Mtetra
.621 .538 .739 r
.46175 .22381 .46888 .24473 .48195 .23625 .47475 .21904 Mtetra
.634 .58 .776 r
.47475 .21904 .48195 .23625 .49505 .22626 .48781 .21425 Mtetra
.654 .666 .849 r
.48781 .21425 .49505 .22626 .50817 .2183 .50094 .20944 Mtetra
.664 .741 .907 r
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.639 .731 .915 r
.56752 .18502 .57454 .1941 .58801 .18919 .58104 .18088 Mtetra
.602 .739 .941 r
.58104 .18088 .58801 .18919 .60155 .1848 .59467 .1777 Mtetra
.669 .801 .946 r
.59467 .1777 .60155 .1848 .61522 .18191 .60832 .17251 Mtetra
.689 .746 .895 r
.60832 .17251 .61522 .18191 .62888 .17669 .62201 .16655 Mtetra
.684 .727 .883 r
.62201 .16655 .62888 .17669 .64259 .17067 .63576 .16067 Mtetra
.674 .728 .89 r
.63576 .16067 .64259 .17067 .65636 .16484 .64959 .15515 Mtetra
.668 .734 .899 r
.64959 .15515 .65636 .16484 .67021 .15939 .6635 .14988 Mtetra
.665 .738 .905 r
.6635 .14988 .67021 .15939 .68414 .15418 .67748 .1447 Mtetra
.664 .74 .907 r
.67748 .1447 .68414 .15418 .69814 .14904 .69153 .13954 Mtetra
.664 .741 .907 r
.69153 .13954 .69814 .14904 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14751 .32817 Mtetra
.14751 .32817 .15579 .33602 .16737 .33178 .15912 .32389 Mtetra
.15912 .32389 .16737 .33178 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31893 .19425 .31093 Mtetra
.663 .74 .907 r
.19425 .31093 .20241 .31893 .21419 .31465 .20607 .30658 Mtetra
.662 .739 .907 r
.20607 .30658 .21419 .31465 .22602 .31048 .21794 .30226 Mtetra
.658 .735 .907 r
.21794 .30226 .22602 .31048 .23787 .30655 .22985 .29805 Mtetra
.649 .726 .905 r
.22985 .29805 .23787 .30655 .24975 .30297 .24179 .29406 Mtetra
.638 .713 .902 r
.24179 .29406 .24975 .30297 .26169 .29949 .25377 .29039 Mtetra
.635 .708 .9 r
.25377 .29039 .26169 .29949 .27374 .29525 .26579 .2868 Mtetra
.654 .732 .907 r
.26579 .2868 .27374 .29525 .286 .28905 .27792 .28262 Mtetra
.702 .801 .926 r
.27792 .28262 .286 .28905 .29823 .28378 .29023 .27699 Mtetra
.712 .793 .915 r
.29023 .27699 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.664 .741 .907 r
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.615 .722 .922 r
.54694 .18083 .55407 .18995 .56752 .18502 .56045 .17738 Mtetra
.623 .768 .949 r
.56045 .17738 .56752 .18502 .58104 .18088 .57403 .17354 Mtetra
.674 .796 .94 r
.57403 .17354 .58104 .18088 .59467 .1777 .58766 .16821 Mtetra
.688 .744 .894 r
.58766 .16821 .59467 .1777 .60832 .17251 .60133 .16227 Mtetra
.682 .725 .882 r
.60133 .16227 .60832 .17251 .62201 .16655 .61507 .15642 Mtetra
.674 .726 .888 r
.61507 .15642 .62201 .16655 .63576 .16067 .62888 .15087 Mtetra
.668 .733 .898 r
.62888 .15087 .63576 .16067 .64959 .15515 .64277 .14555 Mtetra
.665 .737 .904 r
.64277 .14555 .64959 .15515 .6635 .14988 .65673 .14035 Mtetra
.664 .74 .906 r
.65673 .14035 .6635 .14988 .67748 .1447 .67076 .13516 Mtetra
.664 .741 .907 r
.67076 .13516 .67748 .1447 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14751 .32817 .13917 .32025 Mtetra
.13917 .32025 .14751 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30658 .19788 .29847 Mtetra
.663 .74 .907 r
.19788 .29847 .20607 .30658 .21794 .30226 .20978 .29407 Mtetra
.662 .739 .907 r
.20978 .29407 .21794 .30226 .22985 .29805 .22174 .28969 Mtetra
.658 .734 .906 r
.22174 .28969 .22985 .29805 .24179 .29406 .23374 .28541 Mtetra
.651 .726 .904 r
.23374 .28541 .24179 .29406 .25377 .29039 .24577 .28133 Mtetra
.641 .713 .9 r
.24577 .28133 .25377 .29039 .26579 .2868 .25784 .27751 Mtetra
.636 .707 .898 r
.25784 .27751 .26579 .2868 .27792 .28262 .26996 .27381 Mtetra
.647 .723 .904 r
.26996 .27381 .27792 .28262 .29023 .27699 .28217 .26977 Mtetra
.678 .776 .924 r
.28217 .26977 .29023 .27699 .3026 .27096 .29451 .26481 Mtetra
.72 .816 .925 r
.29451 .26481 .3026 .27096 .31492 .26641 .30699 .2585 Mtetra
.681 .76 .911 r
.30699 .2585 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.664 .741 .907 r
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.647 .735 .913 r
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17716 Mtetra
.605 .733 .935 r
.52629 .17716 .53352 .18578 .54694 .18083 .53976 .17391 Mtetra
.647 .8 .956 r
.53976 .17391 .54694 .18083 .56045 .17738 .55331 .1693 Mtetra
.681 .778 .924 r
.55331 .1693 .56045 .17738 .57403 .17354 .56691 .16375 Mtetra
.685 .737 .89 r
.56691 .16375 .57403 .17354 .58766 .16821 .58057 .15785 Mtetra
.68 .722 .882 r
.58057 .15785 .58766 .16821 .60133 .16227 .5943 .15206 Mtetra
.673 .724 .888 r
.5943 .15206 .60133 .16227 .61507 .15642 .60809 .14654 Mtetra
.668 .731 .897 r
.60809 .14654 .61507 .15642 .62888 .15087 .62195 .14121 Mtetra
.665 .737 .903 r
.62195 .14121 .62888 .15087 .64277 .14555 .63589 .13597 Mtetra
.664 .74 .906 r
.63589 .13597 .64277 .14555 .65673 .14035 .6499 .13076 Mtetra
.664 .74 .907 r
.6499 .13076 .65673 .14035 .67076 .13516 .66398 .12553 Mtetra
.664 .741 .907 r
.66398 .12553 .67076 .13516 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20978 .29407 .20156 .28584 Mtetra
.663 .74 .907 r
.20156 .28584 .20978 .29407 .22174 .28969 .21355 .28139 Mtetra
.662 .739 .907 r
.21355 .28139 .22174 .28969 .23374 .28541 .22559 .27694 Mtetra
.659 .735 .906 r
.22559 .27694 .23374 .28541 .24577 .28133 .23768 .27258 Mtetra
.653 .727 .903 r
.23768 .27258 .24577 .28133 .25784 .27751 .24981 .26836 Mtetra
.645 .715 .899 r
.24981 .26836 .25784 .27751 .26996 .27381 .26198 .26436 Mtetra
.64 .707 .896 r
.26198 .26436 .26996 .27381 .28217 .26977 .2742 .2605 Mtetra
.642 .713 .899 r
.2742 .2605 .28217 .26977 .29451 .26481 .28649 .25654 Mtetra
.657 .744 .914 r
.28649 .25654 .29451 .26481 .30699 .2585 .29887 .25212 Mtetra
.682 .805 .941 r
.29887 .25212 .30699 .2585 .31944 .25336 .31137 .24694 Mtetra
.709 .811 .928 r
.31137 .24694 .31944 .25336 .33191 .24874 .32397 .24092 Mtetra
.689 .769 .912 r
.32397 .24092 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.664 .741 .907 r
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.639 .732 .916 r
.47885 .18235 .48628 .19146 .49955 .18654 .49216 .17818 Mtetra
.618 .745 .937 r
.49216 .17818 .49955 .18654 .51289 .18159 .50553 .17456 Mtetra
.643 .794 .955 r
.50553 .17456 .51289 .18159 .52629 .17716 .51898 .17008 Mtetra
.67 .803 .946 r
.51898 .17008 .52629 .17716 .53976 .17391 .5325 .16484 Mtetra
.683 .753 .905 r
.5325 .16484 .53976 .17391 .55331 .1693 .54608 .15912 Mtetra
.681 .727 .884 r
.54608 .15912 .55331 .1693 .56691 .16375 .55972 .1533 Mtetra
.676 .72 .882 r
.55972 .1533 .56691 .16375 .58057 .15785 .57343 .14762 Mtetra
.671 .724 .889 r
.57343 .14762 .58057 .15785 .5943 .15206 .58721 .14215 Mtetra
.667 .731 .898 r
.58721 .14215 .5943 .15206 .60809 .14654 .60105 .13682 Mtetra
.665 .736 .903 r
.60105 .13682 .60809 .14654 .62195 .14121 .61496 .13158 Mtetra
.664 .739 .906 r
.61496 .13158 .62195 .14121 .63589 .13597 .62895 .12634 Mtetra
.664 .74 .907 r
.62895 .12634 .63589 .13597 .6499 .13076 .643 .12109 Mtetra
.664 .741 .907 r
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09447 Mtetra
.71435 .09447 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28139 .20528 .27305 Mtetra
.663 .74 .907 r
.20528 .27305 .21355 .28139 .22559 .27694 .21736 .26853 Mtetra
.663 .739 .907 r
.21736 .26853 .22559 .27694 .23768 .27258 .22949 .26401 Mtetra
.66 .735 .905 r
.22949 .26401 .23768 .27258 .24981 .26836 .24167 .25955 Mtetra
.656 .729 .903 r
.24167 .25955 .24981 .26836 .26198 .26436 .2539 .25518 Mtetra
.65 .719 .899 r
.2539 .25518 .26198 .26436 .2742 .2605 .26618 .25096 Mtetra
.645 .709 .894 r
.26618 .25096 .2742 .2605 .28649 .25654 .2785 .24688 Mtetra
.643 .707 .893 r
.2785 .24688 .28649 .25654 .29887 .25212 .29089 .24283 Mtetra
.647 .718 .9 r
.29089 .24283 .29887 .25212 .31137 .24694 .30334 .23866 Mtetra
.657 .748 .917 r
.30334 .23866 .31137 .24694 .32397 .24092 .31588 .23416 Mtetra
.67 .796 .942 r
.31588 .23416 .32397 .24092 .33659 .23545 .3285 .22926 Mtetra
.681 .816 .948 r
.3285 .22926 .33659 .23545 .34921 .23073 .34121 .22398 Mtetra
.69 .803 .935 r
.34121 .22398 .34921 .23073 .3619 .226 .35398 .21845 Mtetra
.69 .782 .921 r
.35398 .21845 .3619 .226 .37465 .22124 .36681 .21288 Mtetra
.679 .758 .911 r
.36681 .21288 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.664 .741 .907 r
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.649 .736 .913 r
.41859 .19297 .42625 .20199 .4393 .19711 .43167 .18854 Mtetra
.639 .745 .925 r
.43167 .18854 .4393 .19711 .45242 .19222 .44481 .18437 Mtetra
.638 .766 .94 r
.44481 .18437 .45242 .19222 .46561 .1873 .45802 .18017 Mtetra
.644 .79 .952 r
.45802 .18017 .46561 .1873 .47885 .18235 .47131 .17571 Mtetra
.655 .809 .957 r
.47131 .17571 .47885 .18235 .49216 .17818 .48468 .17088 Mtetra
.671 .796 .942 r
.48468 .17088 .49216 .17818 .50553 .17456 .49811 .16563 Mtetra
.679 .755 .909 r
.49811 .16563 .50553 .17456 .51898 .17008 .51161 .16005 Mtetra
.679 .73 .888 r
.51161 .16005 .51898 .17008 .5325 .16484 .52517 .15434 Mtetra
.676 .719 .881 r
.52517 .15434 .5325 .16484 .54608 .15912 .53879 .14866 Mtetra
.672 .719 .884 r
.53879 .14866 .54608 .15912 .55972 .1533 .55248 .14311 Mtetra
.669 .725 .892 r
.55248 .14311 .55972 .1533 .57343 .14762 .56623 .13771 Mtetra
.666 .732 .899 r
.56623 .13771 .57343 .14762 .58721 .14215 .58006 .13241 Mtetra
.665 .737 .904 r
.58006 .13241 .58721 .14215 .60105 .13682 .59395 .12716 Mtetra
.664 .74 .906 r
.59395 .12716 .60105 .13682 .61496 .13158 .60791 .1219 Mtetra
.664 .74 .907 r
.60791 .1219 .61496 .13158 .62895 .12634 .62194 .11663 Mtetra
.664 .741 .907 r
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09447 .70764 .08446 Mtetra
.70764 .08446 .71435 .09447 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30489 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27375 Mtetra
.17289 .27375 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26853 .20905 .26009 Mtetra
.664 .74 .907 r
.20905 .26009 .21736 .26853 .22949 .26401 .22122 .2555 Mtetra
.663 .739 .907 r
.22122 .2555 .22949 .26401 .24167 .25955 .23344 .25091 Mtetra
.662 .737 .906 r
.23344 .25091 .24167 .25955 .2539 .25518 .24572 .24634 Mtetra
.659 .732 .903 r
.24572 .24634 .2539 .25518 .26618 .25096 .25805 .24181 Mtetra
.655 .724 .9 r
.25805 .24181 .26618 .25096 .2785 .24688 .27044 .23737 Mtetra
.651 .715 .895 r
.27044 .23737 .2785 .24688 .29089 .24283 .28287 .23303 Mtetra
.648 .708 .891 r
.28287 .23303 .29089 .24283 .30334 .23866 .29536 .22876 Mtetra
.647 .706 .89 r
.29536 .22876 .30334 .23866 .31588 .23416 .30791 .22449 Mtetra
.649 .713 .895 r
.30791 .22449 .31588 .23416 .3285 .22926 .32052 .22015 Mtetra
.654 .73 .905 r
.32052 .22015 .3285 .22926 .34121 .22398 .33321 .21566 Mtetra
.659 .753 .919 r
.33321 .21566 .34121 .22398 .35398 .21845 .34597 .21101 Mtetra
.663 .779 .935 r
.34597 .21101 .35398 .21845 .36681 .21288 .3588 .20621 Mtetra
.664 .803 .95 r
.3588 .20621 .36681 .21288 .37968 .20758 .3717 .20134 Mtetra
.662 .817 .958 r
.3717 .20134 .37968 .20758 .39259 .20273 .38466 .19643 Mtetra
.661 .816 .958 r
.38466 .19643 .39259 .20273 .40556 .19786 .39768 .19152 Mtetra
.66 .815 .958 r
.39768 .19152 .40556 .19786 .41859 .19297 .41076 .18661 Mtetra
.661 .816 .958 r
.41076 .18661 .41859 .19297 .43167 .18854 .42391 .18166 Mtetra
.665 .804 .949 r
.42391 .18166 .43167 .18854 .44481 .18437 .43712 .17663 Mtetra
.67 .781 .933 r
.43712 .17663 .44481 .18437 .45802 .18017 .4504 .17146 Mtetra
.674 .758 .914 r
.4504 .17146 .45802 .18017 .47131 .17571 .46375 .16612 Mtetra
.675 .737 .897 r
.46375 .16612 .47131 .17571 .48468 .17088 .47716 .16063 Mtetra
.675 .723 .885 r
.47716 .16063 .48468 .17088 .49811 .16563 .49064 .15506 Mtetra
.673 .716 .881 r
.49064 .15506 .49811 .16563 .51161 .16005 .50418 .14949 Mtetra
.671 .716 .883 r
.50418 .14949 .51161 .16005 .52517 .15434 .51778 .14399 Mtetra
.668 .721 .889 r
.51778 .14399 .52517 .15434 .53879 .14866 .53144 .13859 Mtetra
.667 .728 .895 r
.53144 .13859 .53879 .14866 .55248 .14311 .54517 .13326 Mtetra
.665 .734 .901 r
.54517 .13326 .55248 .14311 .56623 .13771 .55897 .12798 Mtetra
.664 .738 .905 r
.55897 .12798 .56623 .13771 .58006 .13241 .57284 .12272 Mtetra
.664 .74 .906 r
.57284 .12272 .58006 .13241 .59395 .12716 .58678 .11745 Mtetra
.664 .74 .907 r
.58678 .11745 .59395 .12716 .60791 .1219 .60079 .11216 Mtetra
.664 .741 .907 r
.60079 .11216 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30489 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27375 .16441 .26536 Mtetra
.16441 .26536 .17289 .27375 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .2555 .21288 .24695 Mtetra
.664 .74 .907 r
.21288 .24695 .22122 .2555 .23344 .25091 .22514 .2423 Mtetra
.663 .74 .907 r
.22514 .2423 .23344 .25091 .24572 .24634 .23745 .23763 Mtetra
.663 .738 .906 r
.23745 .23763 .24572 .24634 .25805 .24181 .24983 .23296 Mtetra
.661 .735 .905 r
.24983 .23296 .25805 .24181 .27044 .23737 .26226 .22831 Mtetra
.659 .73 .902 r
.26226 .22831 .27044 .23737 .28287 .23303 .27474 .22368 Mtetra
.657 .724 .898 r
.27474 .22368 .28287 .23303 .29536 .22876 .28728 .21909 Mtetra
.655 .716 .894 r
.28728 .21909 .29536 .22876 .30791 .22449 .29988 .21455 Mtetra
.653 .71 .89 r
.29988 .21455 .30791 .22449 .32052 .22015 .31254 .21002 Mtetra
.652 .707 .887 r
.31254 .21002 .32052 .22015 .33321 .21566 .32526 .20547 Mtetra
.653 .707 .887 r
.32526 .20547 .33321 .21566 .34597 .21101 .33805 .20088 Mtetra
.655 .71 .888 r
.33805 .20088 .34597 .21101 .3588 .20621 .3509 .19621 Mtetra
.657 .714 .89 r
.3509 .19621 .3588 .20621 .3717 .20134 .36382 .19145 Mtetra
.66 .719 .893 r
.36382 .19145 .3717 .20134 .38466 .19643 .37681 .18659 Mtetra
.662 .722 .894 r
.37681 .18659 .38466 .19643 .39768 .19152 .38987 .18163 Mtetra
.664 .723 .893 r
.38987 .18163 .39768 .19152 .41076 .18661 .40299 .17658 Mtetra
.666 .721 .89 r
.40299 .17658 .41076 .18661 .42391 .18166 .41618 .17143 Mtetra
.667 .718 .887 r
.41618 .17143 .42391 .18166 .43712 .17663 .42944 .16619 Mtetra
.668 .714 .883 r
.42944 .16619 .43712 .17663 .4504 .17146 .44276 .16086 Mtetra
.668 .712 .881 r
.44276 .16086 .4504 .17146 .46375 .16612 .45614 .15549 Mtetra
.45614 .15549 .46375 .16612 .47716 .16063 .46959 .1501 Mtetra
.668 .715 .884 r
.46959 .1501 .47716 .16063 .49064 .15506 .4831 .14472 Mtetra
.667 .721 .889 r
.4831 .14472 .49064 .15506 .50418 .14949 .49668 .13938 Mtetra
.666 .727 .895 r
.49668 .13938 .50418 .14949 .51778 .14399 .51032 .13408 Mtetra
.665 .732 .9 r
.51032 .13408 .51778 .14399 .53144 .13859 .52403 .1288 Mtetra
.664 .736 .903 r
.52403 .1288 .53144 .13859 .54517 .13326 .5378 .12354 Mtetra
.664 .739 .906 r
.5378 .12354 .54517 .13326 .55897 .12798 .55165 .11826 Mtetra
.664 .74 .907 r
.55165 .11826 .55897 .12798 .57284 .12272 .56557 .11297 Mtetra
.664 .741 .907 r
.56557 .11297 .57284 .12272 .58678 .11745 .57955 .10766 Mtetra
.57955 .10766 .58678 .11745 .60079 .11216 .59361 .10232 Mtetra
.59361 .10232 .60079 .11216 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27514 Mtetra
.10817 .27514 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .2423 .21675 .23364 Mtetra
.21675 .23364 .22514 .2423 .23745 .23763 .2291 .22892 Mtetra
.664 .74 .907 r
.2291 .22892 .23745 .23763 .24983 .23296 .24151 .22418 Mtetra
.663 .74 .907 r
.24151 .22418 .24983 .23296 .26226 .22831 .25398 .21943 Mtetra
.663 .738 .906 r
.25398 .21943 .26226 .22831 .27474 .22368 .26651 .21467 Mtetra
.662 .736 .904 r
.26651 .21467 .27474 .22368 .28728 .21909 .2791 .2099 Mtetra
.661 .732 .902 r
.2791 .2099 .28728 .21909 .29988 .21455 .29175 .20514 Mtetra
.66 .727 .899 r
.29175 .20514 .29988 .21455 .31254 .21002 .30445 .20037 Mtetra
.659 .722 .896 r
.30445 .20037 .31254 .21002 .32526 .20547 .31722 .1956 Mtetra
.658 .718 .892 r
.31722 .1956 .32526 .20547 .33805 .20088 .33005 .19081 Mtetra
.658 .714 .889 r
.33005 .19081 .33805 .20088 .3509 .19621 .34294 .18598 Mtetra
.659 .712 .887 r
.34294 .18598 .3509 .19621 .36382 .19145 .3559 .18111 Mtetra
.659 .711 .886 r
.3559 .18111 .36382 .19145 .37681 .18659 .36893 .17618 Mtetra
.661 .71 .885 r
.36893 .17618 .37681 .18659 .38987 .18163 .38202 .17118 Mtetra
.662 .711 .884 r
.38202 .17118 .38987 .18163 .40299 .17658 .39517 .16611 Mtetra
.663 .712 .884 r
.39517 .16611 .40299 .17658 .41618 .17143 .4084 .16098 Mtetra
.664 .714 .885 r
.4084 .16098 .41618 .17143 .42944 .16619 .42168 .1558 Mtetra
.664 .716 .887 r
.42168 .1558 .42944 .16619 .44276 .16086 .43504 .15058 Mtetra
.665 .72 .89 r
.43504 .15058 .44276 .16086 .45614 .15549 .44846 .14534 Mtetra
.665 .724 .893 r
.44846 .14534 .45614 .15549 .46959 .1501 .46194 .1401 Mtetra
.665 .729 .897 r
.46194 .1401 .46959 .1501 .4831 .14472 .47549 .13485 Mtetra
.664 .733 .901 r
.47549 .13485 .4831 .14472 .49668 .13938 .48911 .1296 Mtetra
.664 .736 .903 r
.48911 .1296 .49668 .13938 .51032 .13408 .50279 .12435 Mtetra
.664 .738 .905 r
.50279 .12435 .51032 .13408 .52403 .1288 .51654 .11908 Mtetra
.664 .74 .906 r
.51654 .11908 .52403 .1288 .5378 .12354 .53037 .11379 Mtetra
.664 .74 .907 r
.53037 .11379 .5378 .12354 .55165 .11826 .54426 .10848 Mtetra
.664 .741 .907 r
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27514 .09942 .26676 Mtetra
.09942 .26676 .10817 .27514 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22965 Mtetra
.19597 .22965 .20446 .23834 .21675 .23364 .20829 .22491 Mtetra
.20829 .22491 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24151 .22418 .23313 .21536 Mtetra
.23313 .21536 .24151 .22418 .25398 .21943 .24563 .21055 Mtetra
.664 .74 .907 r
.24563 .21055 .25398 .21943 .26651 .21467 .2582 .20573 Mtetra
.2582 .20573 .26651 .21467 .2791 .2099 .27082 .20088 Mtetra
.663 .739 .906 r
.27082 .20088 .2791 .2099 .29175 .20514 .28351 .19601 Mtetra
.663 .737 .905 r
.28351 .19601 .29175 .20514 .30445 .20037 .29626 .19113 Mtetra
.663 .735 .904 r
.29626 .19113 .30445 .20037 .31722 .1956 .30907 .18623 Mtetra
.662 .733 .902 r
.30907 .18623 .31722 .1956 .33005 .19081 .32194 .18131 Mtetra
.662 .731 .901 r
.32194 .18131 .33005 .19081 .34294 .18598 .33487 .17636 Mtetra
.662 .729 .899 r
.33487 .17636 .34294 .18598 .3559 .18111 .34787 .17139 Mtetra
.662 .728 .898 r
.34787 .17139 .3559 .18111 .36893 .17618 .36094 .16638 Mtetra
.663 .727 .897 r
.36094 .16638 .36893 .17618 .38202 .17118 .37406 .16133 Mtetra
.37406 .16133 .38202 .17118 .39517 .16611 .38726 .15625 Mtetra
.663 .728 .898 r
.38726 .15625 .39517 .16611 .4084 .16098 .40052 .15112 Mtetra
.664 .729 .899 r
.40052 .15112 .4084 .16098 .42168 .1558 .41384 .14598 Mtetra
.664 .732 .9 r
.41384 .14598 .42168 .1558 .43504 .15058 .42723 .1408 Mtetra
.664 .734 .902 r
.42723 .1408 .43504 .15058 .44846 .14534 .44069 .1356 Mtetra
.664 .736 .903 r
.44069 .1356 .44846 .14534 .46194 .1401 .45421 .13038 Mtetra
.664 .737 .905 r
.45421 .13038 .46194 .1401 .47549 .13485 .46781 .12514 Mtetra
.664 .739 .906 r
.46781 .12514 .47549 .13485 .48911 .1296 .48147 .11989 Mtetra
.664 .74 .907 r
.48147 .11989 .48911 .1296 .50279 .12435 .49519 .1146 Mtetra
.49519 .1146 .50279 .12435 .51654 .11908 .50899 .1093 Mtetra
.664 .741 .907 r
.50899 .1093 .51654 .11908 .53037 .11379 .52286 .10396 Mtetra
.52286 .10396 .53037 .11379 .54426 .10848 .5368 .09861 Mtetra
.5368 .09861 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22965 .1874 .22088 Mtetra
.1874 .22088 .19597 .22965 .20829 .22491 .19976 .21609 Mtetra
.19976 .21609 .20829 .22491 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20573 .2498 .19674 Mtetra
.2498 .19674 .2582 .20573 .27082 .20088 .26247 .19184 Mtetra
.664 .74 .907 r
.26247 .19184 .27082 .20088 .28351 .19601 .27519 .18692 Mtetra
.27519 .18692 .28351 .19601 .29626 .19113 .28798 .18198 Mtetra
.663 .74 .907 r
.28798 .18198 .29626 .19113 .30907 .18623 .30082 .17702 Mtetra
.664 .739 .906 r
.30082 .17702 .30907 .18623 .32194 .18131 .31374 .17202 Mtetra
.663 .739 .906 r
.31374 .17202 .32194 .18131 .33487 .17636 .32671 .16701 Mtetra
.664 .738 .905 r
.32671 .16701 .33487 .17636 .34787 .17139 .33975 .16197 Mtetra
.33975 .16197 .34787 .17139 .36094 .16638 .35285 .15691 Mtetra
.664 .737 .905 r
.35285 .15691 .36094 .16638 .37406 .16133 .36602 .15181 Mtetra
.36602 .15181 .37406 .16133 .38726 .15625 .37925 .14669 Mtetra
.664 .738 .905 r
.37925 .14669 .38726 .15625 .40052 .15112 .39255 .14155 Mtetra
.39255 .14155 .40052 .15112 .41384 .14598 .40592 .13637 Mtetra
.664 .739 .906 r
.40592 .13637 .41384 .14598 .42723 .1408 .41935 .13117 Mtetra
.664 .74 .906 r
.41935 .13117 .42723 .1408 .44069 .1356 .43285 .12594 Mtetra
.664 .74 .907 r
.43285 .12594 .44069 .1356 .45421 .13038 .44641 .12069 Mtetra
.44641 .12069 .45421 .13038 .46781 .12514 .46005 .11542 Mtetra
.46005 .11542 .46781 .12514 .48147 .11989 .47375 .11011 Mtetra
.664 .741 .907 r
.47375 .11011 .48147 .11989 .49519 .1146 .48753 .10479 Mtetra
.48753 .10479 .49519 .1146 .50899 .1093 .50137 .09943 Mtetra
.50137 .09943 .50899 .1093 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .09861 .52926 .08864 Mtetra
.52926 .08864 .5368 .09861 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18198 .27962 .17278 Mtetra
.27962 .17278 .28798 .18198 .30082 .17702 .29251 .16776 Mtetra
.664 .74 .907 r
.29251 .16776 .30082 .17702 .31374 .17202 .30545 .16273 Mtetra
.664 .741 .907 r
.30545 .16273 .31374 .17202 .32671 .16701 .31847 .15766 Mtetra
.664 .74 .907 r
.31847 .15766 .32671 .16701 .33975 .16197 .33155 .15257 Mtetra
.33155 .15257 .33975 .16197 .35285 .15691 .34469 .14746 Mtetra
.34469 .14746 .35285 .15691 .36602 .15181 .3579 .14232 Mtetra
.3579 .14232 .36602 .15181 .37925 .14669 .37117 .13715 Mtetra
.37117 .13715 .37925 .14669 .39255 .14155 .38451 .13196 Mtetra
.38451 .13196 .39255 .14155 .40592 .13637 .39792 .12674 Mtetra
.664 .741 .907 r
.39792 .12674 .40592 .13637 .41935 .13117 .41139 .1215 Mtetra
.664 .74 .907 r
.41139 .1215 .41935 .13117 .43285 .12594 .42493 .11623 Mtetra
.664 .741 .907 r
.42493 .11623 .43285 .12594 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11542 .45222 .10561 Mtetra
.45222 .10561 .46005 .11542 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10479 .47978 .09488 Mtetra
.47978 .09488 .48753 .10479 .50137 .09943 .49367 .08948 Mtetra
.49367 .08948 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .0731 Mtetra
.53576 .0731 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10877 .2271 Mtetra
.10877 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25832 .16854 Mtetra
.25832 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15845 Mtetra
.28411 .15845 .29251 .16776 .30545 .16273 .2971 .15335 Mtetra
.2971 .15335 .30545 .16273 .31847 .15766 .31015 .14825 Mtetra
.31015 .14825 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14746 .33645 .13795 Mtetra
.33645 .13795 .34469 .14746 .3579 .14232 .3497 .13276 Mtetra
.3497 .13276 .3579 .14232 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .12231 Mtetra
.37639 .12231 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08948 .4859 .07942 Mtetra
.4859 .07942 .49367 .08948 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .0731 .52814 .06289 Mtetra
.52814 .06289 .53576 .0731 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00001D
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vm
j01D0:Vmj0030000002Y_NP0ZKgX0140ZKgX00<000000?ooo`3oool01`3oool00`3ogi`0B0000000
0003000000030000M02oool0oooo00@0oooo00<0_g@007Boo`3oool0?@3oool007/0oooo00D0oon?
03D00000000001AO0<Coo`0E0?ooo`<00000F@2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0030?ooo`00
0000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`800000
9P2Y_NP50:Vmic40ZKgX00<000000:Vmj02Y_NP04P2Y_NP00`000000oooo0?ooo`0>0?ooo`030?oo
_`1d000000000080000000<0M;oo0?ooo`3oool0?@3oool00900oooo0`00000V0:Vmj0<0ZKcW1@2Y
_NL20:Vmj0<0ZKgW1P2Y_NP50:Vmib00ZKgX00<000000:Vmj02Y_NP04`2Y_NP00`000000oooo0?oo
o`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX0000002Y_NP06@2Y_NP5
0:Vmi`D0ZKgX1`2Y_>L:0:Vmi`<0ZKgX0`2Y_>L50:Vmi`80ZKgX0`2Y_NLJ0:Vmj0030000002Y_NP0
ZKgX01<0ZKgX00<0oooo0000003oool03P3oool00`2oM000M;oo0?ooo`110?ooo`00R`3oool30000
0140ZKgX0`2Y_NL80:Vmj0<0ZKcW1@2Y_NL20:Vmj0h0ZKcW1@2Y_NL70:Vli`X0ZKgW6@2Y_NP00`00
0000ZKgX0:Vmj00D0:Vmj0030000003oool0oooo00d0oooo00H0gia800000000000000000000M02o
ooln0?ooo`00R@3oool200000180ZKgX1P2Y_NL50:Vmj0H0ZKcW102Y_NL90:Vli`<0Z[_V1@2Y_>L2
0:Vmi`<0Z[_V1P2Y_>L50:Zli`/0ZKgW4`2Y_NP00`000000ZKgX0:Vmj00E0:Vmj0030000003oool0
oooo0500oooo00260?ooo`<000004P2Y_NP90:Vmi`X0ZKcW1@2Y^nH60:Vli`H0Z[_V102Y_>L60:Zk
iP<0ZKcW0`2Z^nH50:Zli`80ZKgW0`2Z_>L;0:Vmi`d0ZKgX00<000000:Vmj02Y_NP05@2Y_NP00`3o
ool000000?ooo`1@0?ooo`00Q03oool300000180ZKgX2@2Y_NL30:VkiPL0ZKcW0`2Z^^D50:VkiP<0
ZKcW0`2Z^^D50:ZkiPD0Z[[U302Z^nH:0:Zli`<0ZKgW0`2Z_>L50:Vmi`80ZKgX0`2Y_NL70:Vmj003
0000002Y_NP0ZKgX01H0ZKgX00<000000?ooo`3oool0C`3oool00840oooo0`0000030:Vmj0030000
002Y_NP0ZKgX00/0ZKgX1@2Y_>L50:Vmi`L0ZK_V102Y_>L60:Zji@D0ZK_V1P2Z^^D20:ZkiP<0ZkSS
1@2Z^^D30:ZkiP<0ZkWT1@2Z^nH50:Zki@`0Z[cW2P2Y_NL60:Vmj0030000002Y_NP0ZKgX01L0ZKgX
00<000000?ooo`3oool0CP3oool007l0oooo0P00000B0:Vmj0P0ZKcW0P2Y_NL90:VkiPD0Z[WT1@2Z
^^D60:Zhh`D0Z[[U1P2[^><40:Zji@L0ZkWT0P2Z^nH30:^ih`D0Z[_U0`2Z_>L30:^ki@X0Z[cW1@2Y
_NL60:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`00000B
0:Vmj0X0ZKcW2@2Y^nH30:Zhh`D0Z[WT0P2Z^^D30:^ghPH0Z[SS0P2Z^^D30:^ghPD0ZkSS1@2/^>86
0:^ii0H0ZkWS102Z^nD70:^ki@80Z[cW0`2[^nD50:Zli`80ZKgW0`2Z_>L50:Vmj0030000002Y_NP0
ZKgX01P0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD000000000000000D05o4o`0Y
0?ooo`<0000000<0ZKgX0000002Y_NP03P2Y_NP:0:Vli`D0ZK[V1P2Y^nH60:Zhh`@0Z[WT1P2[]n85
0:Zhh`H0ZkOR0P2[^><30:fhh@D0[;SR0`2[^N@30:fhh@D0ZkWS1@2/^N<<0:^ki@X0Z[cW0`2Y_NP0
0`2Z_NL000000:Zmi`0J0:Vmj0030000003oool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo
0?ooo`3ool@0Ga@e08ooo`0V0?ooo`8000004P2Y_NP:0:Vli`<0ZK[U1@2Y^^H30:VkiP<0ZKOS1@2Z
^><50:^fh@H0ZkOR1@2/]n450:^ghPH0[KSQ1@2/^>860:fhh@80ZkWS0`2^^>450:bih`<0Zk_U0`2/
^N<50:^ki@D0Zk_V1@2Z_>L50:Zmi`030000002Z_NL0ZKgX01P0ZKgX00<000000?ooo`3oool0C03o
ool004l0oooo00<0ScD003F?o`3oool08P3oool300000180ZKgX2P2Y_>L60:Vji@D0ZK[V1P2Y]n<2
0:Zhh`P0ZkKQ0`2[]n830:bihPD0[;OQ0P2[]n830:fjh`H0[KSQ0P2/^>830:jjhPD0[KSQ1P2^^>4;
0:bih`80Zk_U0`2/^^<50:^kiP80Z[cW0`2Z_>H40:Zmi`030000002Z_NL0ZKgX01T0ZKgX00<00000
0?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`040?oo
o`0308le000eSol0oooo0200oooo0P00000A0:Vmj0X0ZKcW2`2Y^^D50:VfhPD0ZKOS2`2[]^450:bi
hPD0[;OQ1P2]^^<50:fhh@H0[[[R0P2]^>430:nlh`D0[[SQ1@2^^N460:bih`H0[;[S102[^nH60:Zl
iP<0Z[gW00<000000:Zli`2Z_>L06P2Y_NP00`000000oooo0?ooo`1:0?ooo`00BP3oool01`3oa5l0
500D05o4o`3oool0ooo405lD501Oa?l07P3oool3000000030:Vmj0000000ZKgX00h0ZKgX2P2Y_>L;
0:Vji@P0ZKKR0P2Y]n<30:^fhPP0ZkKQ0`2/_>D50:bihP80[;OQ0`2]`NP50:fjh`H0[/3W1@2^^^86
0:nlh`80[[SQ0`2`_^@50:jih@<0[;WS0`2_^^850:bjh`D0[;_T1@2Z_>H30:Zli`040000002Z_>L0
Z[cW0:ZliaT0ZKgX00<000000?ooo`3oool0BP3oool004X0oooo00<0oon?03D0000000000P000000
0`0eSol0oooo0?ooo`0J0?ooo`030:Vmj000000000000180ZKgX2P2Y_>L;0:Vji@X0ZKKR1P2[]^85
0:^fh@H0[;cU102/^N860:g1j080[K[S0`2[cO860:k0i`80[[[R0`2^an`50:nlh`D0/;kT1P2^^N46
0:njhP80[;[S0`2^^^850:bki080Z[cV0`2[^nD20:Zli`040000002Z_>L0Z[cW0:Zli`D0Z[gW5@2Y
_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0Ga@D05o4o`0M0?ooo`<00000402Y_NP5
0:Vmi`D0ZKcW2`2Y^^D:0:VfhPD0Z[OS1@2[]^860:c2j@D0[;cU1@2[bo450:g1j0H0Zlgb1@2^`>L6
0:k7k080[kcS0`2/bo050;2ni0<0[[WQ0`2`_^D50:njhPH0[[[R102/^n@60:^ki@030:Zli`000000
Z[cW00<0ZkcV1@2Z_NLE0:Vmj0030000003oool0oooo04P0oooo001;0?ooo`0308le000eSol0oooo
01X0oooo0P00000A0:Vmj0P0ZKgW0P2Y_>L30:VjiPP0ZK[U0`2Y]N870:VfhP<0Z[SS1@2Z]n<20:^f
hP<0ZlO^1P2/`^T20:bli@<0Ylod1@2[bo460:C;m0D0Zlgb1@2Uc?@50:k7k0H0[<_`102`_^@70;2n
i@80[k[R0`2`_^@50:jjhPD0[[[S1@2[^nD00`2[_>H000000:^liP040:^liPD0Z[gW502Y_NP00`00
0000oooo0?ooo`180?ooo`00B`3oool01P34Ga@00000000000000000000e08oooa<0oooo00@0ZKgX
00000000000000000P2Y_NP00`000000ZKgX0:Vmj00<0:Vmj0X0ZKgW1P2Y^^H50:Vji@H0ZKGR102Y
]^860:Zhh`@0Z[OS1P2[anh50:c2j@H0Ylod1@2N_^l60:C;m0D0V[__1@2Uc?@509o4lPD0[<_`1P2[
cO850;2ni@H0/;kT0P2^^^830;2mh`D0[[[S1@2]^n@00`000000ZkcV0:^liP030:^liPH0Z[gW502Y
_NP00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP000000000000E0:Vmj0D0ZKgW1@2Y^nH6
0:VjiPD0Z;KR1@2Y]N850:Vii0D0Z[SS1P2ZcO850:_7kPD0Y<[c0`2Wco@30:>kjPD0W[k_1P2U_>T5
09Zkk`D0WKS/1@2Oa?8509Zml0H0Zlgb1@2[bo050;2ni0H0/;gS0P2^^^<30;2lhP@0[K_T00@00000
0:^liP2[_>H0ZkcV0`2/_>D:0:Zmia00ZKgX00<000000?ooo`3oool0AP3oool005l0oooo1000000H
0:Vmj0<0ZKgW1`2Y^nH30:VjiP<0Z;KS1@2X]^820:VehP<0ZKST1@2Y^N@20:Zhh`@0ZM3e1@2ZcO85
0:?4l0D0Y<[c1P2S^nX209jnk`<0ZKgX1P2U_>T209Zkk`<0ZKgX1@2M^>`50:>kjPD0V[g`1P2H^^l5
0:_;l080/;kT0`2^an`50;2mh`H0/;cR0`2]^n@00`000000[;cU0:bli@050:bli@80Z[gW0`2[_>H5
0:Zmi`l0ZKgX00<000000?ooo`3oool0AP3oool005d0oooo00@0ZKgX00000000000000006`2Y_NP:
0:VkiPH0Z;KS102X]^860:Vhi0@0ZKWT1`2Yd?D50:>nk0D0XlC`1@2Y_NP50:>kjPH0ZKgX1@2U_>T6
0:Vmj080WKS/0`2Y_NP50:>kjP80V[g`0`2U^nT609Rjk`@0Zl_`1P2^an`20;2mh`<0/<;X1@2`_>83
0:nkh`030000002_^n<0[;cU00D0[;cU1P2[_>H40:Zmia00ZKgX00<000000?ooo`3oool0A@3oool0
05/0oooo0`00000J0:Vmj0D0ZKcW1@2Y^nH:0:Rfh`D0Z;ST1@2Y^>@60:S@m@<0ZM3e0`2V_>T50:>n
k080XlC`8`2Y_NP40:>kjPH0YK_Y1@2H^^l509Vll0D0[/O/1P2``^P20;2lhP<0/KoT0P2_^n<00`00
0000[k_S0:nkh`060:jli0D0ZkcV1@2Z_NL?0:Vmj0030?ooo`000000oooo04D0oooo001H0?ooo`<0
00006`2Y_NP80:Vli`80ZK_V0`2X]n@:0:Rfh`D0Z;ST0P2Y^>@40:W@m@D0Z=3e1P2V_>T40:>nk2X0
ZKgX1@2U^nT60:>kjPD0VKc`1@2Oa?<50;32j0H0/KoT00<0[k_S0000002a_N<00P2a_N<60:jli080
ZkcV0`2/_>H50:Zmi`l0ZKgX00<000000?ooo`3oool0A03oool005D0oooo00<0ZKgX000000000000
702Y_NP:0:Vli`H0Z;OT2P2X]^<40:Rhi0L0ZM3e1@2Y_NP50:JljC@0ZKgX1P2S^nX509fhj`D0WlCc
0P2``^P30:O9l@D0/KoT00<0/KgS0000002a_N<00`2a_N<50:jli0H0[;cV0P2Z_NL30:^mi`l0ZKgX
00<000000?ooo`3oool0@`3oool005<0oooo0`0000000`2Y_NP000000:Vmj00G0:Vmj0D0ZKgW1@2Y
_>L50:Rhi@D0Z;OT1@2W]N<60:Rfh`D0ZM7e0`2Yd?D80:Vmj080Y[cY=`2Y_NP30:>kjP<0ZKgX1@2M
^>/409o4l`H0YlWa0P2a_n@30:o3j@030000002a_N<0/KgS0080/KgS1P2__><50:bliPH0ZkgW3`2Y
_NP00`000000oooo0?ooo`120?ooo`00D@3oool2000001h0ZKgX1@2Y_NL20:Vli`<0Z;[V1@2X^>D2
0:Rgi0<0YkCS1@2W]N<30:Rfh`<0ZLgc1@2YdOE:0:Vmj080WKS[0`2Y_NP409Jek@D0YlWa1@2_`nT0
0`000000/KgS0;6mh`030;:oi0D0[kcS1P2]_ND50:^mi`D0Z[gW2P2Y_NP00`000000oooo0?ooo`12
0?ooo`00CP3oool300000240ZKgX102Y_NL60:RjiP@0Z;SU1P2W]><50:Neh`H0ZLgcE02Y_NP409Je
k@D0UkW_102_`nT00`000000/[oT0;:oi0040;:oi080[kcS0`2a_N<50:fmi@H0ZkgW1@2Z_NL:0:Vm
j0030000003oool0oooo0440oooo000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000
000001AO0<Coo`0Y0?ooo`800000902Y_NP60:VkiPD0Z;[V102V]><60:Ndh`D0ZLO_0`2YcO<30:g2
jE<0ZKgX1@2U^nT509Nik`80[l?Y00<0Y/K`0000002Va_001@2b_n@60;6mh`@0[KgU1`2[_NL50:Zm
i`X0ZKgX00<000000?ooo`3oool0@03oool001T0oooo00X0omnL04P0M02oool0oooo0?oog`1O5000
55o40?ooo`34Ga@003F?9P3oool300000080ZKgX00<000000:Vmj02Y_NP07P2Y_NP40:Vli`H0ZK_V
1@2W]N<40:Jdh`<0YkCS0`2X`>/50:W7k`H0[L;Y7`2Y_NP50:NZf@D0ZKgX1@2VY=<U0:Vmj0D0YK_Y
102G^Nl30:K6l0030000002Va_00Y/K`0080/[oT0`2``NH50;6mh`D0[[gU1P2[_NL60:Zmi`T0ZKgX
00<000000?ooo`3oool02P3oool01@3ookl0M00000000000B9`0gooo0340oooo000I0?ooo`0;0?oO
W01807@0_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool08P3oool00`2Y_NP000000000
000T0:Vmj0L0ZKcW0`2Y^nH30:Ngi0D0YkGS102V]><60:S0j`80ZLO_0`2`b>/50:g2jAd0ZKgX0`2R
U<H50:NZf@80ZKgX0`2NRKd50:JTd`D0XI331@2Y_NP50:VjiAH0ZKgX0P2U^nT30:Vmj0@0V;K]0`2V
a_000`000000Y/K`0;31iP050;31iP80/KgS0`2b_^<50:jmi@H0[;gV1@2Z_NL:0:Vmj0030000003o
ool0oooo00P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;la0?ooo`003@3oool00`3ogi`0B000
00000003000000030000M02oool0oooo00<0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo
0?ooo`3oohl0=@0D05o4o`0P0?ooo`<00000902Y_NP:0:Vli`H0YkOT102W]N<50:Nji`D0Z<3[1P2`
b>/O0:Vmj0D0XYC61@2WZ]T509j9_@@0YZCC0P2]SkL50:6@``80ZKgX0`2ORKd50:VjiA/0ZKgX102H
]^d209Vll0030000002I_?00VKc`00D0/<7V1P2b_^<20:jmi@<0[kkT1@2/_NH60:Zmi`T0ZKgX00<0
00000?ooo`3oool0203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo
00/0omnL04P0M02oool0oooo0?noM00055l0a?oo0?ooo`3oohl0=@0D05o4o`0N0?ooo`<000009`2Y
_NP50:Vli`D0Z;WU1@2W]n@50:Jfi@D0Yk[W1P2`cNl30;38ja`0ZKgX1@2NRKd50::DaP80Yj[I0`2X
R[H509j9_@80YZCC0`2]SkL50:6@``H0WhVm0P2Y^^D30:6<_AX0ZKgX1@2S^nX00`2I_?00000009Vl
l00209Vll080/<7V0`2/`^X50;:nh`H0[kkT1@2/_NH50:Zmi`<0ZKgX0`2Z_NP40:Vmj0030000003o
ool0oooo00L0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000I0?ooo`0;0?oO
W01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l06`3oool3000002/0ZKgX0P2Y
_>L30:RjiPD0Z;WU0P2W]n@30:Fdh`D0Y[KU0P2W^^L40:k@lPD0/<g_702Y_NP309f4^0@0WXVm1@2R
U<H50:R:]PD0WXVm1@2]SkL40:6@``80_Yff1@2ORKd60:6<_AX0ZKgX1@2S^nX010000000VKc`09Vl
l02I_?060:c2jP80/[kS0`2b_n@50:nni0H0[;gV102Z_NL60:Zmj0D0ZKgX00<000000?ooo`3oool0
1P3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0<03oool001L0oooo00d0_g@00000B02L
_i`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0P00000^0:Vmj0H0
Z;[V102X^ND60:Fdh`@0Y[KU1`2^d?8N0:Vmj0D0WHBh1@2NRKd30::DaP80/9:g102XR[H409j9_@80
^Y^i1@2]SkL20:6@``<0_Yff1@2ORKd00`36Y;L0XHbm0:6<_@040:6<_@D0XI335@2Y_NP20:>kjP80
ZKgX00<0000009Bdk@2D]>d00P2D]>d50:c2jPH0/[oT0P2__^@30;6ni0D0[;gV1@2Z_NL50:Zmj0D0
ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01P0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<0
0000;@2Y_NP50:Vli`D0Z;[V102U]N@60:Fdh`D0Zl_a0`2^d?8L0:Vmj0D0W8:f102MQ;P509j9_@80
XYC60`2`T[L50:R:]P80WXVm0`2jVkT50:f?]`030:6@``2nWKH0_Yff0080_Yff102ORKd20<JT]`H0
XHbm00<0bJNg0:6@``2QT<<00`2QT<<50:JSda<0ZKgX00<000000:Vmj02D]>d00`2D]>d50:G1k@D0
/[oT1P2a_^@20:bmiP<0[KkV1@2Z_NL50:Zmj0D0ZKgX00<000000?ooo`3oool01@3oool01`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00<0omnL04P0M02oool00P3oool01@3o
ohl0=@000000000055l0a?oo01@0oooo0`0000000`2Y_NP000000:Vmj00Y0:Vmj0X0ZKcW1@2V]nD4
0:Fei0<0YKCS0`2X_nX50:_;lAX0ZKgX2@2LP[H509f4^0@0WXVm1@2`T[L50:R:]P0309j9_@2jVkT0
^Y^i0080^Y^i1@2]SkL60;jM]P80WhVm1036Y;L40:6<_@80bJNg1@2QT<<00`34Y[/0YZ?C0:JSd`03
0:JSda80ZKgX00<000000:Vmj02I]^`0102I]^`50:G1k@80/[oT0`2b`>D50;6ni0H0[KkV1@2Z_NL5
0:Zmj0D0ZKgX00<000000?ooo`3oool0103oool01P3ooml0W4P007Boo`3oool0gia8001d_c40oooo
000d0?ooo`030:Vmj000000000000300ZKgX1`2Y_>L30:NiiPD0Y[OU102U]N@60:RojPD0/<CY5`2Y
_NP309f4^0P0W8:f1@2MQ;P309j9_@80[I>l1@2`T[L40:R:]PH0^Y^i0`2]SkL20<6W_`D0_Yff00<0
WhVm0<JT]`36Y;L00`36Y;L30:6<_@<0bJNg102QT<<20<BV^`@0YZ?C0P2eX<<A0:Vmj0030000002Y
_NP0ZKgX00D0VKK/102U`Nd60;;0i@D0/KoT1@2]_^H60:Zmi`D0Z[gX102Y_NP00`000000oooo0?oo
o`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`00000c0:Vmj0@0ZKcW1P2W
^NH40:Jgi@D0YKOV0`2X_nX30;G?k@D0/<CY502Y_NP509f4^0T0W8:f102MQ;P209j9_@<0[I>l1@2`
T[L30:R:]P80^J;21@2jVkT20:f?]`<0`JNo1@2nWKH70<JT]`030:6<_@39YkL0bJNg00<0bJNg0P2Q
T<<40<BV^`80YZ?C102eX<<@0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0VKK/1@2M_^l30;;0i@<0/L3U
1@2a_n@50:fniPD0Z[gW1P2Z_NP40:Vmj0030000003oool0oooo03X0oooo000`0?ooo`80000000<0
ZKgX0000002Y_NP0<`2Y_NP50:Rki`D0YkWV1@2T]>@50:FgiPH0]Lo]0P2`a>TB0:Vmj0D0WXVm102M
Q;P909b2]P@0WHBh1@2]Tk`50;2B]`80Z8Zf0`2iX/850;ZK^@030:f?]`31Ykl0`JNo0080`JNo102n
WKH20<J_``H0aZBg1P39YkL00`2QT<<0a:Jk0<BV^`030<BV^`H0]J331@2WZ]P:0:Vmj08000000`2Y
_NP509nij`D0WKk_1P2a`>D20;6oi0<0//3T1@2]_^H50:^mi`D0Z[gX1@2Y_NP00`000000oooo0?oo
o`0i0?ooo`00;03oool0102Y_NP0000000000000000e0:Vmj0@0ZKcW1@2X^nL50:Fei0D0Y;CT0P2U
]nH40:k>l0@0]Lo]4`2Y_NP20::DaP@0WXVm102MQ;P909b2]P80WHBh0`2ZU<050:fC_0@0/9:g1@2i
X/850;ZK^@H0`JNo0P2nWKH40<J_``@0aZBg0P3;/l<50<VW]`H0a:Jk00<0d[>k0;FP``2eX<<00`2e
X<<00`3?/K`0Yj[H0:NZf0030:NZf0H0ZKgX0`0000020:Vmj0040000002Y_NP0ZKgX0:Vmj0D0WkW[
1@2F^>l50;70i@H0//3T0P2]_^H30:foiPD0ZkgW1@2Z_NP40:Vmj0030000003oool0oooo03T0oooo
000[0?ooo`800000>@2Y_NP40:Vli`<0Z;_W0P2V^>H50:Fei0@0Y;CT1`2^c_0D0:Vmj0@0XYC6102N
RKd509f4^0P0W8:f1@2ZU<050:fC_0<0/9:g0P2gZ/`50;VR`P<0^Y^i0P2o/lh50<6W_`030;jM]P36
[l<0aZo300<0aZo30`36Y;L30<^c``@0bJNg0P3?]<040<BV^`80d[>k102eX<<20<na_0@0Yj[H0P2d
Yl/20:Vmj0<000001@2Y_NP00`000000ZKgX0:Vmj0020:Vmj0D0Y[cY1@2F^>l20;70i@<0[l3V1@2b
`>@50:foiPD0ZkgW1@2Z_NP50:Vmj0030000003oool0oooo03P0oooo000Y0?ooo`800000?02Y_NP4
0:Vli`D0Y[SV1@2U]N@50:Rnj@<0[/k`0`2^`^T?0:Vmj0D0Yj[I102RU<H409j9_@@0WHBh102LP[H5
0:JD``@0ZYC01@2]Tk`20;2B]`<0]j[<1@2iX/820;ZK^@<0_k?>1@31Ykl70<J_``030<JT]`3;/l<0
bk?300<0bk?30P39YkL30<nd`0<0a:Jk103B/k/20;FP``@0ck6l0P2WZ]P20;BWb`<000002@2Y_NP0
0`000000ZKgX0:Vmj0020:Vmj0@0Y[cY1@2F^>l60:o0iP80//3T0`2b`ND40:foiPH0ZkkW102Z_NP6
0:Vmj0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool2
000003`0ZKgX1@2W^^L50:JhiPD0Y;KV1@2X_^T60:k2j@l0ZKgX102WZ]T40::DaP@0WXVm102MQ;P2
09b2]P<0XI74102VU<<50:ZD`0@0[I>l1P2gZ/`40;VR`PH0_k?>0`31Ykl20<6ne`H0aZo31P3;/l<0
0`39YkL0ckC00<nd`0030<nd`080a:Jk103B/k/00`2eX<<0ck6l0<na_0030<na_080]:O;0P000002
0;BWb`/0ZKgX00@000000:Vmj02Y_NP0ZKgX0P2V_>T30:Vmj0D0T[?]1@2_`>H50;;1i@80[KoV0`2]
_nL50:^ni`D0Z[gX1@2Y_NP00`000000oooo0?ooo`0g0?ooo`00703oool01P3ooml0W4P004RLg`3o
ool0gia8001d_`L0oooo00<000000?ooo`000000=`2Y_NP50:Rli`D0Yk[W1@2S]>D50:BfiP80Z;kY
0`2hd>`50:k2j@l0ZKgX1@2WZ]T40::DaP<0WXVm102MQ;P50:6Aa0D0YYC3102ZU<020:fC_0<0/k7F
1@2gZ/`20;VR`P<0^L3O1@2o/lh20<6W_`@0`KkG1036[l<20<;3f`D0bk?31P3?]<000`34Y[/0d[>k
0=:c^`030=:c^`D0ck6l0`0000030;BWb`80b[G62`2Y_NP00`000000ZKgX0:Vmj0060:Vmj0@0T[?]
1P2__nH40;;1i@H0[KoW0P2[_^L30:Znj0D0Z[gX1@2Y_NP00`000000oooo0?ooo`0f0?ooo`00703o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y
_NP0=@2Y_NP50:Rli`<0Yk[W0P2U]nH50:>di@@0Y;KV1P2hd>`D0:Vmj0@0Yj[I102RU<H309j9_@D0
Vhg3102QTL@50:JD``@0ZYC01@2c/MH50;NZc0H0^L3O102o/lh70<6ne`80aZo30`32`m/40<^c``80
a/?H1@3?]<060=:c^`030=>la03?/K`00000008000000P3H^[/30;BWb`<0b[G62`2Y_NP00`000000
ZKgX0:Vmj0060:Vmj0D0Tk?]1@2__nH50;;1i@D0[KoW1P2Z_^P50:Zmj0D0ZKgX00<000000?ooo`3o
ool0=@3oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?oo
o`3oool00P3oool00`000000ZKgX0:Vmj00e0:Vmj0D0Z;cW1@2U]nH40:>di@H0[LK/0`2hd>`E0:Vm
j0@0Yj[I102RU<H409B6`@@0Vhg31@2QTL@40:JD``D0[kON1@2c/MH20;NZc0<0/<c^1@2i`=l50;?=
k@H0`KkG1P32`m/20<^c``<0a/?H103?]<020<c1c`@0d[>k0`0000020<na_0@0f;Zk00<0]:O;0<Ze
aP3:]LH00P3:]LH00`3G_/40ZKgX0:Vmj0090:Vmj0030000002Y_NP0ZKgX00H0ZKgX1@2C/nd50:no
iPD0//7U1@2]_nL50:Znj0H0Z[gX102Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@0
04RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`030?ooocP0ZKgX1@2W^^L5
0:FgiPD0YKWW1@2]a^`@0:Vmj0@0YZCC102@PKl408Ef^P@0SGfm102DQ/4409^=``@0XI740P2VU<<3
0:bih`D0[kON102c/MH60;3<kP<0^L3O0`2Pe_/40;?=k@<0`KkG0`2/dO<50<;3f`H0a/?H0P3?]<03
0<c1c`040=:c^`0000000000000000<0dkc400<0ck6l0=Rj^`3H^[/00`3H^[/40<ZeaP<0ekk12`2Y
_NP00`000000ZKgX0:Vmj0060:Vmj0@0Tk?]1P2__nH20;;1i@<0//;V1@2]_nL50:Znj0D0Z[gX1@2Y
_NP00`000000oooo0?ooo`0d0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0
1@3oool2000000D0oooo00<000000:Vmj02Y_NP0<02Y_NP50:Rli`D0Yk[W1@2R]>D50:Fii`D0]/_Z
402Y_NP30:JTd`@0T86o1025M[X408em_@@0U8K1102KSL<40:6Aa0H0[;WS102_]mh60:OCm`D0/<c^
1P2Pe_/40;?=k@H0[=7c0P32`m/30:_?l`D0a/?H0`3<`Ll3000000030=:c^`3C_<@0dkc400<0dkc4
1P3H^[/0103I`<40b[G60<ZeaP3:]LH30=Nn`@`0ZKgX00<000000:Vmj02Y_NP01P2Y_NP409>ck@D0
[koV1P2b`^H50:foi`D0Z[kX2P2Y_NP00`000000oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d
0;ooo`3oool0omnL04P0M02oool01@3oool00`000000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX
0300ZKgX1@2X_>L20:Nji`<0Y;KV1@2R]>D20:Fii`<0/lg]1@2fbnX?0:Vmj0<0YZCC102@PKl408Ef
^P@0SGfm1@2DQ/4309^=``D0ZKST1P2/^N<50:;Hn`D0Ym?g1P2@fOl507cCo`D0SmCn102/dO<60:_?
l`80a/?H0P2bc>d3000000<0c<7?1@3C_<@20<k3d0@0f;Zk0`3I`<400`3:]LH0ekk10=Nn`@020=Nn
`@030=o4_P2Y_NP0ZKgX00T0ZKgX00<000000:Vmj02Y_NP01`2Y_NP409>ck@D0[koV1@2b`^H60:fo
i`D0Z[kX2@2Y_NP00`000000oooo0?ooo`0c0?ooo`00703oool01P3ooml0W4P007Boo`3oool0gia8
001d_`H0oooo00<000000?ooo`3oool01`3ooolb0:Vmj0@0Z;cW1P2T]^H40::di@H0/lg]502Y_NP3
0:JTd`@0T86o1025M[X408em_@@0U8K1102U/n850:Vhi0<0[;WS0`2Qfo`50:;Hn`H0R]_o1P1he?h4
07cCo`D0L<[o1026c_l50:_?l`040;;<k@000000000000000080//c]0P3<`Ll30<38h@<0dkc40`3>
`m030=Rj^`@0fL31103G_/430=o4_P/0ZKgX00<000000:Vmj02Y_NP01P2Y_NP509>`j`D0[koV1@2b
`^H50:foi`D0Z[kX2P2Y_NP00`000000oooo0?ooo`0b0?ooo`007@3oool01@3ookl0M00000000000
B9`0gooo00H0oooo00<000000?ooo`3oool0203ooolb0:Vmj0D0Y[WW102T]^H60:Nkj0<0/lg]0P2`
a>TC0:Vmj0<0YZCC102@PKl408Ef^P@0SGfm0P2DQ/430:2Yg@@0YK?R1@2Y^>@60:7Ko0H0S=kn1P1n
f?h607K?o`@0K/_n101`b_l408K>o`<0R<[m0P0000050;;<k@H0`<SQ00<0dkc40<k3d03>`m000`3>
`m000`3H^[/0fL310=W0`@030=W0`@040=S4aP3G_/40ekk10=Nn`@<0glBn00<0i<Zm0:Vmj02Y_NP0
2@2Y_NP00`000000ZKgX0:Vmj0060:Vmj0D0Tk3[0P2__nH30;70iPD0//;V1@2/_nL40:Znj0X0ZKgX
00<000000?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool02P3oool]0:Vmj0D0Z;_W1@2V
^NL40::eiPH0Yk_X1@2`a>T?0:Vmj0@0R8?60P1fKkd40921_`@0QGJj102=OKd50:2Yg@D0YK?R1P2T
g?/609;Ro@H0Qmcn1P22e?l507k<o`D0LLOo101X`oh206c3oP<000000`28b_d509K8n@D0`<SQ1P3>
`m050=W0`@80f<C60P3G_/430=o4_P<0i<Zm2P2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@0Tk3[1P2a
`>H20;;2iP<0/L;W102/_nL50:Zmj0X0ZKgX00<000000?ooo`3oool0<@3oool002L0oooo00<00000
0?ooo`3oool02`3oool]0:Vmj0D0Z;_W0P2V^NL30:>fiP@0X[GV0`2W^nP30;S?j`D0/<CY3P2Y_NP4
08R3aP<0MVnm0`22O<@508j=c@@0V9cF1@2PZMd20:FchP@0Ym[i1P2KiO`609;PoPH0S]Wo1P2:d?l4
07k<o`D0NLCn0P1/__h3000000<0IK_m101___h509K8n@80`<SQ0`2]b>h40<k3d080a/KJ0`3I`<44
0=S4aP030=Nn`@3Oa;h0glBn00@0i<Zm2`2Y_NP00`000000ZKgX0:Vmj0060:Vmj0D0V;3X1@2a`>H5
0;72i`80[;oW0`2/_nP50:Zmj0X0ZKgX00<000000?ooo`3oool0<03oool002L0oooo00<000000?oo
o`3oool0303oool]0:Vmj0@0Z;_W1P2S]^H40::eiPH0^<o[4P2Y_NP408R3aP<0MVnm1022O<@408j=
c@D0V9cF102PZMd40:OJn@@0XnKk1P2Li?d609SLoPH0UMCm1@2Ac?`508K8o@80NLCn0`00000306bn
oP@0IK_m101___h409K8n@H0[LS^0P3>`m040<K6fP030=W0`@3Ha<H0f<C600<0f<C60`3Oa;h40>C:
_@030>O?_`2Y_NP0ZKgX00T0ZKgX00@000000:Vmj02Y_NP0ZKgX1@2V_>T509R`j0D0//;V102a`^L6
0:boj0D0Z[gX2@2Y_NP00`000000oooo0?ooo`0`0?ooo`009`3oool2000000h0oooo;02Y_NP50:Ji
i`D0XkKV1@2X_>L30;S?j`<0[/;Y4P2Y_NP408R3aP<0MVnm0`22O<@508j=c@@0V9cF1P2Ye?H40:?V
n`@0YNKk1P2Qgo`609kFn`D0V/kj1@2Ac?`308g4nP<000000`21`O`507Blo0<0IkKl101V]O`407fn
n`D0[LS^1P36a]X50=S4aP80elO;00<0glBn0>C:_@3Tb[d00P3Tb[d30>O?_`/0ZKgX00@000000:Vm
j02Y_NP0ZKgX1@2V_>T509jci`@0//;V1@2``^L50:boj0H0Z[gX2@2Y_NP00`000000oooo0?ooo`0_
0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooobP0ZKgX1@2X_>P40:Jii`D0X[GV1@2X_>L60:k2
j@`0ZKgX0`2Y^^D00`1VIkl0ZKgX08R3aP0308R3aP<0MVnm1022O<@408j=c@D0Z<Wa0`2Ye?H40:_V
nPD0YNKk102YhOX60:GInPD0XM3h102Jc_X409O4mP<000000`2=a?X40871o0D0NkWj0`1^/oX406Je
o0@0OKkk1@2I`_<30<K6fP<0_<KR0`3Ha<H30=O7b`@0i<Zm103Wckl00`3Xe/<0ZKgX0:Vmj0080:Vm
j0040000002Y_NP0ZKgX0:Vmj0H0WkW[102N/nL20;;2iP<0/l?V1@2``^L50:^nj0D0Z[gX2P2Y_NP0
0`000000oooo0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0?0?ooobP0ZKgX1@2X_>P40:>g
i`D0X[GV0`2X_>L30;[=j@@0[/;Y2P2Y_NP50:Vji@80IVNo1028PlH407I__@<0PWc41@2R^>T50:S9
l@D0ZnKj102^j?T40:WQnP<0[=_h0`2UfOX30:OBmPD0XM3h102P_^h300000080UlCf1@2C_O@408Nm
n0D0NkWj101^/oX306J_nP@0L;Cj1@2I`_<60;c6hP030=S4aP3Gal/0elO;0080elO;00@0e/W>0>C:
_@3Tb[d0i<Zm0`3Wckl30>SF``X0ZKgX00@000000:Vmj02Y_NP0ZKgX1@2O^N/409jci`H0/l?V0P2`
`^L30:o1j0D0ZkkX1@2Z_NP90:Vmj0030000003oool0oooo02h0oooo000W0?ooo`8000004@3oool0
0`000000ZKgX0:Vmj00U0:Vmj080Z;cX0`2V^^P40:>gi`D0X[GV1P2jcNT>0:Vmj0@0ZK[U0`1VIkl3
071aa0@0MVnm102EXMd50::hj@L0/>?h0P2^j?T60;7Sn0H0[=_h1P2Wd_H50:FljP<0000000<0X;k^
0:2jj`2P^^/00`2P^^/509>mm0@0Qkgh1@20]_L407B`m`<0JJ_g101`]?X508bim0D0_<KR103Gal/3
0=K9cP040>C:_@3Wckl0ilno0>O?_`@0j=K32`2Y_NP010000000ZKgX0:Vmj02Y_NP409nij`D0Y[SV
1@2c`nH60:o1j0D0ZkkX102Z_NP:0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3o
ool00`000000ZKgX0:Vmj00T0:Vmj0H0Y[[X102S]nL50:Nki`<0^/gY0`2`a>T>0:Vmj0@0ZK[U0P1V
Ikl4071aa0@0PhS@102EXMd30::hj@@0/]_e102dj?L30;OUm@<0/N?h102bgOD60:gDm0D0ZKkX00D0
YKcZ00000000000000000:FljP040:Vmj0D0X;[[1@2K^>`408bjm@D0P;Kg101d/?L306V[m`@0K:gg
1@2<^O@20;c6hP<0]<?U0`3Gal/30=K9cP@0ilno103Xe/<00`3XhL/0ZKgX0:Vmj0090:Vmj0030000
002Y_NP0ZKgX00D0VKK/1@2V^>H50;?4i`<0[l7X0`2]`NP40:^nj0l0ZKgX00<000000?ooo`3oool0
;03oool000T0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0gia81@000000
0`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool04`3oool0
0`000000ZKgX0:Vmj00P0:Vmj0D0Z;cX102V^^P50:6ei`D0Yk_W1P2`a>T:0:Vmj0@0YKcY00<0Defo
0:Vji@2Y^^D00`1VIkl3071aa0@0PhS@1@2EXMd40;;Km@@0^^Kd1P2giOD40;;Mm@<0/mKb0`2]e?@3
0:k3j@<0ZKkX0P00000>0:Vmj0D0VkS/102<^_D508Bbl`@0NJgd0`1^Z?@406b]m`@0S;Wd1P2d`nD0
0`3Gal/0e/W>0=K9cP020=K9cP030=O<c`3Wckl0ilno00@0j=K30`3XhL/:0:Vmj0040000002Y_NP0
ZKgX0:Vmj0D0VKK/0P2V^>H30:bmiPD0/lCW1@2]`NP20:^nj0<0Z[kX3P2Y_NP00`000000oooo0?oo
o`0:0?ooo`050=nLB000000000000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo
0=nLB000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo00H0oooo00<000000?ooo`3oool0503oool00`000000ZKgX0:Vmj00P0:Vmj0D0Z;cX102S^>L5
0:6ei`D0^<SW0`2`a>T=0:Vmj0<0YKcY0`1CGKl306IW_`@0L7741023R=0209FQg@@0[L_`102ji_@4
0;gUlPH0^Moc1P2ce_850:k3j@<000004@2Y_NP50:Bkj@@0SkOa1@24/_<407V]m0<0KZSd101]Yo@4
08Bbl`D0]<?U103FbLh30=O<c`@0j=K30`3XhL/20=o_f`X0ZKgX00@000000:Vmj02Y_NP0ZKgX102I
]^`60:bmiP80/lCW0`2ba>P40:g1j0H0Z[kX3P2Y_NP00`000000oooo0?ooo`080?ooo`070?noM000
B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool0103oool00`3ogi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?oo
ob<0ZKgX1@2V^nP40:>hi`<0XKGW0P2U^NL50;S8ia00ZKgX0P2U_>T405=M_`80JW?9101`LL@408>8
d0@0[L_`102kh?850;gUlP80_^3`0`2igo<40;SHl0D0//c]00D0[/?Y00000000000000000:k3j@0D
0:Vmj0D0Y;_Y102?]o4408Bbl`@0NJgd101^Z?@406fWm0@0Q;;c1@2_`>H20=K9cP<0elc?0P3Kd<h2
0>SF``<0j>7;0`3Okm/;0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0UZoX1@2/_NH50;;4j0D0[;oX1@2Z
_^P?0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo
0?ooo`050?ooo`030000003oool0oooo01L0oooo7P2Y_NP40:Rlj0D0Y[_X102S^>L50:Fii`<0^<SW
0`2fbnX>0:Vmj0<0YKcY0`1CGKl306Ycb@@0QY;H1@2N/^H50;_PlP80`NC`0`2miO840;kPl0D0^=S`
0P2gd^d20;;<k@<000006@2Y_NP20:Bkj@<0ZKgX102A/nh408N_l0@0O:[a101bYO4406nSl@@0PZg`
1@2_`>H30=O<c`@0fm3>0`3XhL/40=o_f`/0ZKgX00<000000:Vmj02Y_NP00P2Y_NP409J_j0D0/<7W
0P2ba>P30;33j0D0[;oX1@2Z_NP>0:Vmj0030000003oool0oooo00`0oooo00<0_g@007Boo`3oool0
6`3oool000P0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018
W=l0oooo0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo01P0oooo
7P2Y_NP40:Rlj0@0Y[_X1@2Q]^L50:Fii`H0]/_Z3P2Y_NP00`15F/<0YKcY05=M_`0305=M_`<0JW?9
1026T]P209jbiP<0]];_0`2kh?840<7Tl0D0_^3`102nf^h30;OBk@<000008P2Y_NP4096ckP@0Qjo`
101lZ_4407:Ul@@0Kj?a1022[O020:o0iP<0[koU00<0elc?0=_@cP3Kd<h00P3Kd<h30>7Fc0@0gnoK
0P32g^d;0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0VjkT102``NL60;33j080[;oX0`2[_^P50:Zmj0h0
ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool0
00P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono
07@000030000000307Boo`3oool0oooo00@0oooo0P00000K0?oooah0ZKgX102X_>P40:>ij0D0XKKW
1P2b`^HB0:Vmj080AE[3101CGKl406Ycb@<0QY;H1P2fd^l50<7Tl0@0`n7^102nf^h20;cCj`<00000
00<0]m;]0;?8jP2cb>X08P2Y_NP509:`j`@0RJc/101oYnd407JRk@<0Lj7]1022[O050:noi@@0fm3>
103Qe/`20>WOb@D0`]k]2P2Y_NP00`2S^nX000000:>kjP020:>kjP@0VjkT1@2ba>L50;33j0H0ZkkX
0P2Z_NPA0:Vmj0030000003oool0oooo00D0oooo00<0oono07@0000000000P0000000`1d_ol0oooo
0?ooo`0K0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@0
07Bo0?ooo`020?ooo`050;md001d_ol0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?oo
oad0ZKgX1@2W_>P40:>ij0D0X[OW0`2b`^H30;_=j180ZKgX0P15F/<3061_b`@0JW?91@2U^^P30;KB
k`@0`]k^1033hNh40<?Kj`040;cCj`000000000000000080_=?[1@2cb>XR0:Vmj0D0T[3[1029[>`4
07nWk@@0MZ;]0`1cXNd408BZk@<0[koU0P2c`><20=_@cP@0hMK<0`3YglT00`3`jL@0ZKgX0:Vmj00=
0:Vmj0030:>kjP000000Xk_Z0080Xk_Z0P2K[^@20:NhiPD0//CW1@2^`^P50:^nj1<0ZKgX00<00000
0?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Boo`3oool0
gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool0
0`000000oooo0?ooo`0L0?oooad0ZKgX1@2W_>P40:6gj0D0X[OW1P2kcNP?0:Vmj00304A`f02Y_NP0
AE[30080AE[30`1PKl/408JGg0D0YK[X1032g^h40<KOj`@0`m_[0`0000030;cCj`<0^lkY1@2cb>XR
0:Vmj0@0T[3[1029[>`407nWk@@0MZ;]101cXNd408BZk@D0/l3S103Qe/`30>WOb@80l>W400<0j_S8
0:Vmj02Y_NP03@2Y_NP010000000Xk_Z0:>kjP2S^nX50:NhiP80//CW0`2baNP50:k2j0D0Z[kX4`2Y
_NP00`000000oooo0?ooo`050?ooo`030;md001d_ol0oooo01l0oooo00090?ooo`050?oo_`1d0000
00000018W03Oool01@3oool01@3ogi`0B000000000000000M;oo0080oooo00H0gia8000000000000
00000000M02oool50?ooo`030000003oool0oooo01d0oooo7@2Y_NP50:Fjj0@0XKOX0`2R]nL30:^l
iP@0^lgX3`2Y_NP204A`f0<0AE[30`1PKl/508JGg080YK[X102kd^/50<KOj`<0amcX0P0000040<;E
j@H0^lkY8P2Y_NP50:Bkj@@0TZcX102:Z>T4086Sj@@0NIkY101hW^X408VYjP<0/l3S0P2la>420>7F
c0<0jMo90P3`jL@30>[hb0l0ZKgX00@0000009Rbj@2H/^T0V;;Y102W^>H60;;5j0D0[<3X102Z_^PC
0:Vmj0030000003oool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3o
ool2000001l0oooo6`2Y_NP20:Rlj0D0YK[X102Q]nP60:^liPD0[/;Y3P2Y_NP204A`f00304aTbP15
F/<0AE[300<0H6o;1026Um`50;_Bj`80aM[Y0`36gn/01@37g>P00000000000000000a]KV00<0`]GY
0`30d>H30;_>j@<0]lSX8P2Y_NP50:Bkj@@0TZcX102:Z>T4086Sj@<0NIkY101hW^X408VYjP80/l3S
102la>440>WOb@80l>W40`3Zn<P?0:Vmj00409Rbj@000000V;;Y09Rbj@D0[l7W0`2baNP30;34j@@0
[<3X1@2Z_NPC0:Vmj0030000003oool0oooo02H0oooo000U0?ooo`030000003oool0oooo01l0oooo
602Y_NP50:Rlj0@0YK[X1@2P]^P30:^liP<0^LCS1@2^`^T=0:Vmj080A73H0`1<I<X3061_b`D0Y[[W
0`2kd^/40<GJj@<0000000<0amcX0<KFiP36e^H00P36e^H60<3@iPH0]lSX8P2Y_NP40:Bkj@@0TZcX
1@2;Y>D308>OiP<0NIkY101hW^X408VYjPD0_<CQ0P38cMh20>WOb@80l>W40P3Zn<P30<[[k0h0ZKgX
00<0VZ_R0000002JZn800P2JZn850:o1i`D0/<CY0P2/`>P30:^oj0D0Z[gX4`2Y_NP00`000000oooo
0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P0?oooaP0ZKgX1@2X_>P50::ij@@0X;KX1P2i
a><>0:Vmj0@0Mj[c0P14L=P304aTbP<0Oi;L1@2V^^L30<GJj@<000000P39f^H50<KFiP80aM7T0`30
d>H30;k;i0<0]lSX0`2^`^TQ0:Vmj0D0W;3V102BZ>D508^Ti@<0PioV0`1lW>H407fMi`@0TJ_W0`2l
a>440<S=gP80l>W400<0j_S80<[[k03:jn`0103:jn`90:Vmj0D0YK_Y00<0VZ_R0000002JZn800P2J
Zn850;;5j0@0/<CY1P2[_nP20:Zmj1D0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00000S
0?oooaP0ZKgX1@2V^nP50::ij@D0Y;SW0`2ia><20;[:i`h0ZKgX0`1gZ_<00`0XClD0A73H04aTbP02
04aTbP@0Oi;L0P2V^^L20;_=j0<000001039f^H40<[Fh`D0aM7T1P2nbn@60:k2jB40ZKgX1@2L/>H4
09:Xi@@0RjCU0`23WnH407bLiP@0OIgW102AZnL50<S=gP<0em[J00<0i^_B0>gh``3]n<<03P2Y_NP5
0:Fkj@0309Z[hP000000Z;[V0080Z;[V102baNP50:k2j@D0ZkoX602Y_NP00`000000oooo0?ooo`0T
0?ooo`00903oool00`000000oooo0?ooo`0S0?oooaT0ZKgX102V^nP509ngj@D0Y;SW1@2jb^L>0:Vm
j00400IAcP1gZ_<0Mj[c02Q?a@@0C6C:0`1oT]`01@2kcNP00000000000000000^lgX00<0aM?U0P39
f^H40<[Fh`80bM7Q0`35dN@30<?<h@<0_/_T0P2ma^850:k2jB80ZKgX102L/>H509:Th@@0Rj3R0`24
W>83082JhP@0OIgW1@2M/NH30<S=gP<0em[J00<0i^_B0>gh``3]n<<00P3Ao/4>0:Vmj0@0YK_Y0P2X
^^H010000000Z;[V0:RjiP2X^^H20;;5j080/LKY1@2^`^T50:Znj1P0ZKgX00<000000?ooo`3oool0
8`3oool002@0oooo00<000000?ooo`3oool0903ooolI0:Vmj0@0Y;[Y1@2O]nT20:Bhi`<0[;cV102j
b^L?0:Vmj00400IAcP1gZ_<0:4o502Q?a@<0JXCJ00D0Wk;U000000000000000009nbi@020;_=j0D0
aM?U103:e^<40<WAh@H0`lcQ1@2ma^850:Zmiad0ZKgX1@2Q[n8409RXh@@0TZCQ1@2;X>8208BLhP@0
P9[R1024W^@509faiP@0em[J0P3Vjm800`3]n<<0dOk10=7n`@020=7n`@h0ZKgX102I[>@00`2X^^H0
00000:RjiP020:RjiPD0/LKY1@2/`>P50:Znj1L0ZKgX00<000000?ooo`3oool08`3oool002@0oooo
0P00000V0?oooa@0ZKgX1@2X_>P40:Bjj@@0WkOY1P2/_>H50;34j@h0ZKgX00@01U7>02Q?a@0XClD0
JXCJ0`00000509nbi@@0aM?U1039dn450<WAh@80algN0`33c>430<77g`<0_LKR0P2k`]l50:Zmia/0
ZKgX0P2Y^N@50:6_hP@0V:SQ102BY>4408^PhP<0Q9cR1020V^8408BNi080WK7V0`2/_>D20=OJfP80
i^_B00<0kOS30=7n`@3Ao/400`3Ao/4?0:Vmj0@0VJcT00<0/<?X0000002``nP00P2``nP20;76j@<0
[l?Y1@2/`>P50:Zmj1L0ZKgX00<000000?ooo`3oool08P3oool002<0oooo0P00000X0?oooa@0ZKgX
1@2X_>P40:Bjj@@0WkOY0`2/_>H30;O2hPD0/<CY3@2Y_NP200IAcP800000101ZQ=X60;K4i@D0bM?Q
0P3;dMh30<WAh@@0algN1P31aml50;_2g`D0Z[[U602Y_NP50:Vii0@0XJoR102HZ>4409:Th@D0S9cN
0P26VMh4082JhP@0Q9kT1P2/_>D30>K[dP80dOk14`2Y_NP50:6bi0040;33j0000000/<?X0;33j0H0
[l?Y1@2[_^P40:Zmj1P0ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@000000000
04RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo00<0
00000?ooo`3oool0:03ooolC0:Vmj0@0Z;cX1@2R^NT409ngj@H0]l;R3P2Y_NP208Vbl@<000000P0n
Im<508bRi0@0]/CU0P31bn830<WCh@@0bm7N1@37cMh20<K8g0<0`LOO0`30`m`30;_2g`80^[kL1@2Z
^^DC0:Vmj0D0ZKcW102Y^N@509fVg0@0V:?M102BWmd408bLgP<0QYWN1024V^0408jSh`<0[;cU1031
cn@0103IjN00hog:0>?mbP3;mZ@>0:Vmj0D0W[?V102Q/^@20;76jP030000002aa^X0/LKZ00<0[l?Y
0`2/`NT40:^nj1`0ZKgX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo
0=nLB000M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0
oooo02X0oooo4`2Y_NP40:Nlj0D0X[WY1@2R^>T30;O2hP80^lGQ302Y_NP3000000<0RK;a00<01U7>
03iWd`0nIm<01@2<X^@20;K4i@@0`L_R1@3;dMh20<[=g0<0algN1036b=`60<33g0D0^[kL0`2Z^^D2
0:fgh0h0ZKgX2P2Y_>L40:6Yg0@0WJKL1@2HXmd409:Og@<0S9cN1026VMh408BJh0@0SZ?S1@31cn@0
0`3IjN00hog:0>?mbP030<_fY0h0ZKgX1@2N/nH20:6bi080[L7X00<0/LKZ0000002aa^X00P2aa^X5
0:c1j@80ZkkX0`2Z_NPL0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo4`2Y_NP40:Nlj0D0X;SZ1@2R
^>T50;_5h@P0ZKgX0`0000040:Vmj080:7oX00@003Zn03iWd`0nIm<0?VOC102<X^@40<7;hP<0alcN
0`3;dMh40<[=g0D0a/SL0P34a=X40<33g080_[oJ1@2j_]`50:fgh080ZKgX0`2Y]N850:Vmj0@0ZKWT
1@2Y_>L50:F[f`@0XJWL102MY]`409RSg@@0TYoM0`2<W=h408JIgP@0Q9[P1@2L[^@30<7?i080fNWP
00<0hog:0<_fY03;mZ@00`2]`nT>0:Vmj0@0W[?V1@2]`NP00`2_aNX000000:o5jP020:o5jP@0[<7Y
1P2Z_NPL0:Vmj0030000003oool0oooo01l0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`080?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0;03ooolC0:Vmj0D0
YK_Y102P^>X50:Nji`D0^lGQ102Y_NP3000000P0ZKgX0P0XOnP01000>[h0GXGP05j5h01NQN050:Fg
i@H0alcN1@3:cM`20<W8f@<0a/SL1034a=X20<33g0@0_[oJ0P2j_]`30;ZjfP@0[KOP1P2Y]N820:Vm
j0<0ZK;O102Y^N@50:R/fPD0YJ_K0`2QZM`409fVg0D0UikI102BW=X308bIfP@0RISL102<WMl509b^
i0<0fNWP00<0hog:0<_fY02]`nT0102]`nT:0:Vmj0D0XkOW102L[>820:g1j0<0/LOZ00<0[lGZ0000
002_aNX00P2_aNX40:^oj0D0Z[gX702Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3o_g@0
04RL0=ooo`3oool0oono07@0B02Lgol00`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0
1P3oool00`000000oooo0?ooo`0]0?ooo`h0ZKgX1@2X_NP50:Fkj@@0W[S[1@2W^^L50;S6i0<00000
302Y_NP00`0XOnP00D[9000j_P0305j5h0<0YKOU0`2d`N<30<O<gP<0bL_K0P3:cM`40<W8f@H0a<CJ
1P2n_mX60;ZjfP@0/kKJ1@2Y]N860:Vbg`80ZKWT0P2[[MP50:R/fP@0YJ_K102PY=P409bRf@@0UikI
1@2BW=X308bIfP@0RISL102<WMl209b^i0@0//CX00@0hog:0=?ob02ml9/0_O2K0`2]`nT<0:Vmj0@0
XkOW102L[>860;77jP030000002]`^T0[L;Y0080[L;Y102[_nPQ0:Vmj0030000003oool0oooo01h0
oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d00000000
0080000000<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`l0ZKgX102X_NP50:Bk
j@@0W[S[0P2W^^L30:fmi@050;S6i000000000000000002ha^@03`2Y_NP00`0XOnP00D[905j5h003
05j5h0H0]<7S1P39bm/40<W8f@80alCG0`34a=X30<>oe`<0_[oJ0`2m^mL30;ZjfP<0^KOG102c]]X5
0:naf@D0ZK;O1@2[[MP40:R/fPD0Y:KG0`2PY=P509bRf@@0UikI102BW=X308bIfP@0RISL102<WMl5
0;;4j080c^SY102ml9/?0:Vmj0<0XkOW1@2[_nP30;77jP<0/<GZ00@000000:g2j@2]`^T0[L;Y1@2Z
_^PQ0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`030?oog`2LB4P0W=oo00T0oooo0P00000a0?ooo`l0ZKgX102X_NP50:Bkj@<0W[S[
0`2]_ND3000000D0/lGW3P2Y_NP00`00?K/00D[9005:b@0407^Mj0@0]<7S0P2ma>030<W;f`<0bLOI
0P39b=T40<O4e`H0`koG1P2m^mL60;Vge`80/kKJ0P2e/]H50:naf@D0[ZkG102[[MP50:NWeP@0Y:KG
102PY=P409bRf@@0UikI1@2BVML308jHf0@0SY_L102GZ>430;;4j080c^SY00<0_O2K0:Vmj02Y_NP0
4@2Y_NP409^Yh@D0ZkoX1@2`aNX00`2[_nP000000:^oj0020:^oj0D0Z[kX802Y_NP00`000000oooo
0?ooo`0M0?ooo`00303oool01P3ooml0W4P007Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3o
ool0203oool00`000000oooo0?ooo`0a0?ooo`l0ZKgX102X_NP40:Bkj@@0W[S[0P0000020:fmi@<0
];oS102caNL>0:Vmj003000m^`0>GMD00D[900@0NigX0P2d`N<40;g4h0H0bLOI1037a=L20<K0e@@0
`koG0P31^m@40;fke`80_KOD1@2i]mL50;FbeP80[k7I0`2a[]D40:j^e`80ZjgH0`2[Z=D40:NWeP@0
Y:KG102PY=P509^Me@@0Ui_F102BVML308jHf0D0SY_L102GZ>430<kXj@030;;d/@3Ao/40dOk100h0
ZKgX1@2U]^@409^Yh@D0/<O[0P2`aNX30:g2j@030:^oj0000000ZkoX0080ZkoX9@2Y_NP00`000000
oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia800000000
000000000000M02oool50?ooo`030000003oool0oooo0380oooo3`2Y_NP40:Rmj0@0X[[Z0`000002
09jhj`H0];oS102]`^T>0:Vmj003000m^`0>GMD0NigX00<0NigX1@2ma>020<74g@<0bLOI0`38a=H2
0<O4e`@0a/3E0P33_mL40<6ke080_K_G102m]m@20;Vge`<0^;?D102e/]H60;6^e@<0[ZkG1@2[Z=D5
0:NWeP<0Y:KG1@2OWm@409^Me@D0Ui_F0`2BVML408jHf0@0SY_L1P2/`NT00`37knh0dOk10=7n`@02
0=7n`@h0ZKgX102U]^@209^Yh@<0ZkoY102`an/60:g2j@030000002[_nP0Z[kX0080Z[kX9@2Y_NP0
0`000000oooo0?ooo`0K0?ooo`008P3oool2000003@0oooo3P2Y_NP50:Nlj@<0000000<0X[[Z09ni
j`2O^N/00`2O^N/30;Boh`<0^L7P102]`^T>0:Vmj0<03UgE0`2@[NX30;g4h0@0`LCM1P38a=H60<K0
e@D0`K_D1P2m]m@60;Rce080]K;F0P2d[]<50;6^e@@0[ZWC1@2[Z=D40:NWeP@0Xj7C1@2OWm@409^M
e@@0Ui_F0`2BVML408jHf0D0VJOP0`2/`NT20<O_kP030=7n`@2Y_NP0ZKgX0100ZKgX102U]^@60:^o
j@@0[lK[1@2]`^T00`2Z_^P000000:Znj0020:Znj2D0ZKgX00<000000?ooo`3oool06`3oool00280
oooo00<000000?ooo`3oool0=03oool>0:Vmj0050:Nlj@00000000000000002W_>T01@2Q^^/409ni
j`H0^L7P0P2]`^T@0:Vmj0<05fcN0`2@[NX50<74g@80`/?K1038a=H20<O1e0<0a/3E0`34_=<30<6k
e080`;SB0`2m]m@30;bcd@D0^;?D1@2d[]<20;6^e@<0/J[A102^ZM<40:^Xe@D0Yj?B102SXM<409nO
e0@0VigE1@2GVM@309BIeP@0TicJ1@2IYn030<O_kP030000003:jn`0b^_/00h0ZKgX102T/>4409f[
h@<0ZkoY0`2`an/40:o6j`D0ZkoX00@0Z[kX0000002Z_^P0Z[kX9P2Y_NP00`000000oooo0?ooo`0J
0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX00P0ZKgX0`0000050:Jl
j@T0XK[[1@2i`N0C0:Vmj0<05fcN0`2L]n/30<74g@@0`/?K0P38a=H40<O1e0H0a;cC1@30^=860;bc
d@80^;?D0`2h[m440;B^d`D0/J[A102^ZM<50:ZTd@D0Yj?B0`2SXM<509nLd@@0Vi[B102GVM@409BI
eP@0TicJ0P2IYn040:g8kP030;_kj03:jn`0b^_/0080b^_/3P2Y_NP40:B`h@@0WJ_Q1@2`an/50:g2
j@D0ZkoX00<0ZKgX0000002Y_NP09P2Y_NP00`000000oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo
0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3oool00`000000oooo0?ooo`0g0?oo
o`H0ZKgX0`0000050:Vmj0@0Y[cY1@2O^^/40:6jj`80^L7P0`2k`MhC0:Vmj00301Ach@0GK=h05fcN
00<0W;O[1P32`m/50<O1e080aKkC1034_=<20<>id@<0`;SB0P2o]=050;bcd@H0^:oA0P2d[]<20;B[
d0D0/J[A0P2^ZM<20:fUd0D0ZZCA102WXm840::Nd0@0WicA1@2KV]8409NIe0<0U9WF102CW=X40:g8
kP80^o_X1@3:jn`>0:Vmj0@0Y;3Q1@2/`^X30;37j`80[lG[1@2]`^T50:Znj0030000002Y_NP0ZKgX
02H0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo000Q0?ooo`800000>P3oool20:Vmj0<000002@2Y_NP40:Jlj@D0Wk[[0`2Q^^/60;_1gQ<0ZKgX
0P0DLn440::kj`<0`/?K0`31`]X30<O1e0@0aKkC0P34_=<40<>id@030<2hdP2o]=00_kC@0080_kC@
0P2l/m430;^`c`D0^:oA1@2dZm040;6Zd@@0[JG@1@2ZY=450:JOc`<0XYk@1@2OW=4409^JdP@0UiWD
102IX]/509f^h`<0^o_X0P2:fi0B0:Vmj0D0XK;T1@2/`^X50:o5j`D0ZkoX102Z_^P00`2Y_NP00000
0:Vmj00W0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<000003@2Y_NP4
0:Jlj@D0Wk[/0`2R^nX60;_1gQ80ZKgX0`0DLn440::kj`H0`L;J1P35_]<60<>id@D0_kC@1P2k/<l2
0;R_d@<0]jc>102dZm050;2WcP@0[JG@0P2ZY=430:VQcP@0YYo?102RW]0409nLd@D0W9_C102IWMH4
09VRf`80WJkS102agOHB0:Vmj0@0Wj[N1@2Q/^@50;38k080[lG[0`2/`NT40:^oj0H0ZKgX00<00000
0:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL
0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0=P3oool2000000<0
oooo3P2Y_NP50:Flj@@0Wk[/0`2R^nX60;_1gQ80ZKgX0P004I800`00KM/0XKk^0:6nkP030:6nkP<0
`L;J0P30`]/40<Fnd`80a;cC1033^M420<6gd0<0_kC@0P2n//h50;^`c`H0]jc>0P2dZm020;>Xc@D0
/:O>0`2]YM050:VQcPD0YYo?0`2RW]0509nLd@@0W9_C102IWMH409VRf`@0/Mgf0P32g^d>0:Vmj0D0
ZKWU102OZ]h50:g5j`@0/<S/1P2/`NT40:Znj0D0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000
oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0
0`3oool00240oooo0P00000d0?ooo`<000001P3oool:0:Vmj0@0Z;gX1@2U_>T309njk0D0Xk_[1@2k
`MhC0:Vmj003000ATP00Dkl0XKk^00@0XKk^1@30`]/20<Fnd`@0a;cC0P33^M440<6gd0040;ndd02n
//h0_[;>0;jbcP@0^k3?0P2j[/d50;N/cP@0/jS=1@2`Ylh40:bSc@D0ZJ7>102VWll40::Mc`@0WicA
1@2LVm<309VMePH0YL3]00<0Vo?W0<;Nk@32g^d00P32g^d>0:Vmj0@0ZKWU1@2V^nP40:g5j`D0[/C[
0`2/`NT70:Znj0D0ZKgX00<000000:Vmj02Y_NP09P2Y_NP00`000000oooo0?ooo`080?ooo`0;0?oO
W01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<00000
0?ooo`3oool0<03oool3000000T0oooo2`2Y_NP40:Rmj0D0YKcZ0`2N^^`50:>kj`D0^l7N1@2Y^^D>
0:Vmj003000m^`00Dkl0VL7c00@0VL7c1030`]/60<Bld`H0`KO@1@2n//h20;^`c`<0^Zk=102g[<h2
0;JZc@@0/jS=0P2`Ylh30;2Uc@@0[:?=102YXLh50:JOc`<0XYg?1@2OW=4409bKd`@0X:oS0`2U`>d2
09_ci`030;Klf@2Y_NP0ZKgX0140ZKgX102MZ]l50:Jkj0@0[lO/1@2^a>/70:Znj0P0ZKgX00<00000
0:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?ooo`0=0;md000004P0W;nL04P0M02oool0oooo
0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`00103oool03@3ookl0M00000000000B9`0
gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@0B02Lgol0103oool01@3OW4P000000000000004P0
W=oo00L0oooo00<000000?ooo`3oool0;@3oool3000000h0oooo2P2Y_NP40:Rmj0D0YKcZ0`2N^^`5
0:>lj`H0^l7N102Y^^D>0:Vmj080:7oX1@2I`O<20<32f`80_<?O0`34_=<30<:le@@0`KO@0P30]m44
0;jbcPH0^Zk=0P2g[<h30;JZc@@0/jS=1@2`YLd40:bSc@D0ZJ7>102VWll40::Mc`@0WicA1@2OYm`4
0:2_h`80Vo?W4P2Y_NP50:F]g@@0WJ[O0P2V^nP30:k8k@@0[lO/1@2[`>T40:Znj0/0ZKgX00<00000
0:Vmj02Y_NP09@2Y_NP00`000000oooo0?ooo`060?ooo`0;0?noM0000000001d0;ooo`3oool0oooO
09a8001d_ol0oooo0=nLB000M;l0103oool000<0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l5
0?ooo`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo
00<000000?ooo`3oool0:P3oool300000180oooo2@2Y_NP50:Rmj0@0YKcZ102N^^`50:>lj`H0^l7N
102]^N8>0:Vmj080:7oX102I`O<50;c3g`H0`[cE0P31]m040<2gd@80_[;>0P2m//l50;Z^c@H0]Z[=
0P2cZ<d20;>Wc@D0/:G=0P2/Xld20:bScP@0ZJ7>1@2VWll30::Mc`D0XJCH1@2OYm`20:2_h`030:CW
n`2Y_NP0ZKgX00h0ZKgX1@2Y^><40:F]g@@0WJ[O1@2^b>d50:g3jP@0Zl3Y1@2Z_NP:0:Vmj0030000
002Y_NP0ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo
00D0oono07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool01@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?oo
o`<000005P3oool90:Vmj0@0Z;gX1@2U_>X409jjk0D0X[c/0`2k`Mh30;W1h0@0[KWR3P2Y_NP208Vb
l@@0Pl;l0`2l`ml20;G7j0D0`[cE1P30]m450;fbc`80^Zk=0`2i[/h50;JZc@@0/jO=1@2`YLd40:bS
cPD0ZJ7>102VWll40:BTe@D0XJCH102OYm`00`2Tio/0ZKgX0:Vmj00A0:Vmj0D0ZKSS0`2U[Md60:_3
k0@0[/K/1@2]`nX40:Znj0D0Z[gX2P2Y_NP00`000000ZKgX0:Vmj00L0:Vmj0<000001@3oool00`00
0000oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool0
0`3o_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool09@3oool3
000001X0oooo2@2Y_NP50:Rmj0@0YKcZ1@2N^n`40::lk0H0^L7P0P2]^N820;:jh100ZKgX1023`_`5
0;G7j080`[cE0`2n`=/30<2gd@<0_[[E102m//l60;V^cP80]Z[=0`2f[<l40;>Wc@80/:G=0`2`Yll4
0:bScP@0ZJ7>1@2WYM@40:BTe@@0XJCH102Ue?PE0:Vmj0@0ZKSS102U^NL30:_3k0<0[/S]102^a^`5
0:^oj0@0Z[kX3`2Y_NP00`000000ZKgX0:Vmj00H0:Vmj0<00000203oool00`000000oooo0?ooo`0E
0?ooo`000`3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3ookl0M01809cO
o`020?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`050?ooo`030000003oool0oooo0280
oooo0`00000N0?ooo`T0ZKgX1@2X_NP40:FljPD0W[_/102Q_>d50;W1h0D0/[[P4@2Y_NP304>`m`@0
]LOX1P2n`=/60;jje@80_K;?0P2l]]<50;V^cPD0]Zc?102cYld50;2Wc`@0[:?>1@2ZZ=D40:NUe0@0
Y:CE1P2VbO8G0:Vmj0D0X:cP102U^NL50:k8k@D0Zl7Y102[_nPD0:Vmj0030000002Y_NP0ZKgX01<0
ZKgX1000000<0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`060?ooo`060=nLB000M;l0oooo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?oo
o`040?ooo`030000003oool0oooo01l0oooo0`00000R0?ooo`T0ZKgX1@2X_NP40:FljPD0Wk_/102Q
_>d50;C1i0<0/[[P0P2g_MhB0:Vmj080Mj[c1@2Qd?P30;k0f`80]/_Y1@2n^]D50;bfd`80^Jk>0`2i
]=@40;J/c`D0/jgB1@2`Yll20:bScP80[ZgG1@2ZZ=D30:NUe0D0YlC^0`2VbO8D0:Vmj080ZK3M102T
Zm`40:2/h0D0[LS]0`2^b>d20:c3j`D0Zl7Y102Z_NPC0:Vmj0030000002Y_NP0ZKgX00l0ZKgX00@0
oooo0000000000000000403oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ookl0M01d0;oo
o`3oool0omnL04P0M02oool01P3oool01`3ookl0M01809cOo`3oool0oooO09a8B02Lgol02@3oool2
000001h0oooo0P00000V0?ooo`030000002Y_NP0ZKgX00L0ZKgX102X_NP40:Jlj@D0Wk_/102O_>d5
0;C1i0D0]kgN1@2Y^>@@0:Vmj0@0XM3h1@2fbnT20;jje@<0^/GS102l]]<60;Vde080]Zc?0P2f]mT5
0;>]dP@0/:O?1@2^[ML40:ZXe@@0ZLC^1@2Wa>hD0:Vmj0D0ZK3M102TZm`40:_5k@D0[LS]1@2/`n/5
0:Znj0@0Z[gX4`2Y_NP00`000000ZKgX0:Vmj00:0:Vmj080oooo0`00000C0?ooo`030000003oool0
oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo203oool01P3o_g@004RL0=oo
o`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3oool=0:Vmj0@0Y[cY1@2P^n`409nlk@D0
[/7X0`2g_Mh20;[0gPD0ZKST4@2Y_NP304_0l`@0]/_Y1P2jaN<20;bfd`80^LCS1@2i]=@40;Jgf@D0
/jgB1@2a]]`40:j]e`D0Z/[a102Ya>hD0:Vmj0D0ZKCQ102Y/=d50:RojP@0ZlG]1@2]aN`50:Zoj@@0
Z[kX602Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00
103oool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0
oooo0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0
oooo3@2Y_NP50:Jlj@@0X;_/102N_>h50:k1j0D0^/3N0P2Y^>@30:jfgQ@0ZKgX102:f_l50;[5h`D0
^LCS0P2i]=@30;G:jP@0][OI0P2c[M830;;4i`D0/KKL0P2^[ML20:SEn0D0Z/[a4`2Y_NP50:Vji@@0
ZKCQ1@2U^>H40:RojPD0[LO]0`2]aN`20:_0j@D0Z[oY6`2Y_NP00`000000ZKgX0:Vmj0050:Vmj080
00006P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000
<P3oool=0:Vmj0D0Y[cY102R_>`409jlkPD0Yko[102j`=h60:jfgP@0ZKWU4@2Y_NP308[Jo`D0VMkn
102ia><60;G:jP<0][OI1P2ba>L40;6fg0D0Z=Gh602Y_NP50:Vji@@0Y;7R1@2U^>H40:c8kPD0[LO]
1@2[`>T50:Zmj1/0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000003oool0oooo01@0
oooo000O0?ooo`8000004`3oool3000003H0oooo3@2Y_NP50:Nmj@@0X[c/1@2N_>h40:Noj`@0]l;R
0`2^]]h30;NmgP@0ZKWU5@2Y_NP409WNoP@0S^7m1@2eb^X40:SKn@D0//CW1@2GhodM0:Vmj0D0Y:cM
102T/N850:_8k`@0[<S^1@2[`^X20:_0j@<0Z[kX102Z_NPK0:Vmj0<00000803oool00`000000oooo
0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`<00000>P3oool=0:Vmj0D0YkgY102S
_>/509jlkP@0XKk^102g`^860;NmgP80ZKWU0P2//mdJ0:Vmj0<0S^7m1P1@cMd30:SKnB<0ZKgX102U
Z]X40:B/g@80Y;7R0`2Zanh40:_8k`D0[<?[102[`^X60:Znj1X0ZKgX0`0000030?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3
000003h0oooo3@2Y_NP50:Rmj@@0Xkc[1@2O_>d40:6nkPD0[<;Y102g_Mh50:bcg@D0ZK?O?`2Y_NP5
0:R/f@@0YJ[J0`2T[=d60:[7kP@0[<G/1@2/`n/70:Znj1T0ZKgX0`0000060?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3oool30000
0480oooo3P2Y_NP40:Rmj@@0YKcZ1@2O_>d409jmk`D0[<;Y102h`^830:bcg@80^;kN1@2Y/ml40:Vg
hbh0ZKgX102Y^^D40:Vmj0T0Z:cI102UZ]X50:W5kPD0ZlK]102/aN`50:Zoj@@0Z[kX5`2Y_NP40000
00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000000T0
oooo0P0000160?ooo`h0ZKgX102X_NP40:FljPD0X[c/102N_Nl50:?0kP@0^<;R1@2h_]h20:Vcg`<0
/kSM102Y]n<50:ViiBH0ZKgX0`2Y]>440:Vji@`0Z:cI1@2Ya>d30:W5kP80ZlO^102[a^d50:[0j@@0
Z[oY5`2Y_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0oooo3P2Y_NP40:Rmj0@0
YkgY1@2R_>`409nmkPD0Xl3^102[`n/40;RngPH0/kSM0P2Y]n<20:jcg0D0ZKWU102Y]n<O0:Vmj0D0
ZKCQ0P2Y^^D30:b_fPP0Z:cI102Y`nd50:W4k@D0ZlO^102Z`>X50:[0jAL0ZKgX00@0oooo00000000
000000004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000N0?ooo`03
0000003oool0oooo0080oooo0`00001=0?ooo`030000002Y_NP0ZKgX00l0ZKgX102W_NT50:Bmj`@0
Wkg^1@2O_^l40:_3j`@0//?W1@2c^=d50:jcg0D0[;7K102Y]n<40:Vcg`D0ZKgX102Y^ND50:Vmj0@0
ZKSS102Y_NP50:V`g@@0ZKCQ1P2/[mX30:R/f@D0ZL?/102Y`nd50:[7k`D0Z/7Z102Z`>X50:Vnj180
ZKgX00<0oooo0000000000000P00000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool04`3oool001h0oooo00<000000?ooo`0000000P00001A0?ooo`030000002Y_NP0ZKgX00l0ZKgX
102X_NP50:Bmj`@0X[g/1@2O_^l40:71k`@0//?W1@2g`n<30:jcg080^<;R1@2//M/40:jbg0@0ZK?O
1@2Y[]/40:Vii@D0ZJoL102Y^><40:R]fPD0ZK3M102^]Mh50:b_fP@0ZLC]102Y`n`60:W7k`@0Z/7[
1@2Z`NX40:Znj0@0ZKkX402Y_NP3000001/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0C0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP03`2Y_NP40:Rmj0D0Y[gY102R
_N`50:2mkP@0XL7_102U`^h50;O3h`D0^<;R0P2//M/30;K2h`@0[[;L0P2Y/ml20;>hg@D0ZJkK102/
/=/50:V_g0@0[[;K102X[MX50:nkh`@0[[GN1@2YaNh40:W4k@D0ZLO_1@2Y`^/40:[1j`T0Z[kX4@2Y
_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool0
0`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vmj02Y_NP0502Y_NP4
0:Jmj@@0YKg[1@2P_Nh409nok`@0YL;^1@2W`nh40;S2hPH0]/;S0`2^/]`50;>hg@80ZJkK0`2e_n44
0:b`f`80ZJoL0`2c_N840:jbf`@0[/7X1@2_^n<40:S6k`@0ZLG^1@2Xanl30:W7k`80ZL7[102Y`^/5
0:Vnj0@0Z[kX4P2Y_NP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool02P3oool2000005H0oooo5P2Y_NP40:Rm
j@@0YKg[1@2S_N`409nok`@0X<3_1@2W`nh40:O4kPD0]/;S102b`nL40;>hg@H0]KoQ0`2//=/50;>m
hP80[[;K0`2[aNd40:k1j0D0YlO`102Xa^l40:O6k`D0Z<O_1@2Y`N/90:Vnj140ZKgX0P00000W0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02o
ool0303oool00`000000oooo0?ooo`1D0?oooaH0ZKgX102X_NT40:Nmj@D0Xkg/102R_^`40:30k`D0
X<7`102Wa>h50:K4k`@0//?W102]aN`50;Foh@@0[/CZ102c_N860:_5k@@0Y/K`102Wao050:O5k`@0
YlK_1@2Y`N/90:Vnj180ZKgX0P00000[0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`000000oooo0?ooo`1D0?oooaX0ZKgX
102W_NT50:JmjP@0X[k/102R_^d50:31l0@0XL7`102Va>l50:C4l0@0[LG/1@2WaNl40:k4jPD0YlK`
1@2UaO040:K6l0@0Yl?^1@2WaNl50:W1j`T0ZKkX4@2Y_NP200000300oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>0?ooo`030000003o
ool0oooo05@0oooo6P2Y_NP40:Rmj0T0Y[gZ2@2R_^d40:71l0@0X/7_1@2Ta?050:?4l0<0YlG_1P2T
aO040:G3k`@0YLG`1@2W`^d40:O3kPD0Z<3[2@2Y_^PA0:Vmj0<00000<`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00l0oooo00<00000
0?ooo`3oool0E03ooolJ0:Vmj0T0Z;gX202V_NX50::nk@D0Xko]0`2R`Nl60:?1k`@0Y<3]102S`^l5
0:G1k@@0YL?_102W`>`50:O2k@@0Z;oZ0`2X`>/70:Vnj140ZKgX0`00000g0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@
0?ooo`800000E@3ooolN0:Vmj0D0Z;gX102X_NT40:JmjPH0Y[kZ102W_^X40:Bok0D0Y[k[102T`>d4
0:Joj`D0YL7]102W_n/40:O0k0D0Z;kY102X_nX50:Vnj140ZKgX0`00000l0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool0
0`000000oooo0?ooo`1C0?ooob<0ZKgX3P2X_NT40:NnjP@0YkgY102V_^/50:NnjP@0Y[o[1@2X_^T4
0:Noj`@0ZKkY102X_^TG0:Vmj0<00000@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030?oOW01807@0_ooo01<0oooo00<000000?ooo`3oool0D`3oool/0:Vm
j0@0Z;gY1@2X_NP40:Nmj@@0Z;gY1@2W_^X80:Rnj@D0ZKgX102Y_^TF0:Vmj0@00000@`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000003oool0oooo05<0
oooo<02Y_NP50:Rmj0@0ZKgX102X_NT50:Vmj0@0Z;kY7`2Y_NP3000004P0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0ooooH02Y_NP0103oool00000
00000000001<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002d0oooo
00<000000?ooo`3oool0DP3ooomL0:Vmj0@00000C`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0140oooo000^0?ooo`030000003oool0oooo0580ooooF02Y_NP3000005@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00;`3oool00`000000oooo0?ooo`1B
0?oooe<0ZKgX00@0oooo0000000000000000F03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0140oooo000`0?ooo`030000003oool0oooo0580ooooC`2Y_NP4000005`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0ooooBP2Y_NP0103o
ool0000000000000001P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
03<0oooo00<000000?ooo`3oool0D@3ooom60:Vmj0@00000I03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo000d0?ooo`030000003oool0oooo0540oooo@P2Y_NP3000006T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo
0?ooo`1A0?ooocd0ZKgX00@0oooo0000000000000000K03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo000f0?ooo`800000DP3oooli0:Vmj0@00000L03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo000h0?ooo`030000003oool0oooo0500oooo=@2Y
_NP3000007D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`00>@3oool0
0`000000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo0000000000000000N@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo000j0?ooo`030000003oool0oooo0540oooo:`2Y_NP4
000007`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool00`00
0000oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03`3oool003`0oooo0P00001B0?ooob80ZKgX00@0oooo0000000000000000Q@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo000n0?ooo`030000003oool0oooo0500
oooo7P2Y_NP4000008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00
?`3oool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00002=0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool00400oooo00<000000?ooo`3oool0D03ooolF0:Vmj0<00000T@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00110?ooo`800000D@3ooolB
0:Vmj0<00000U@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00130?oo
o`030000003oool0oooo04l0oooo3@2Y_NP3000009T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0?0?ooo`00A03oool00`000000oooo0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0
D03oool40:Vmj0<00000X@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
00160?ooo`800000D@3oool200000:H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`00B03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B@3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`00BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0>0?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00C03o
ool2000004/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00h0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo001?0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo001@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001A0?ooo`800000AP3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool005<0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`2/0?ooo`050000003oool0oooo0?ooo`000000
3`3oool005@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`040000003o
ool0oooo000000l0oooo001E0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0[P3o
ool010000000oooo0?ooo`00000?0?ooo`00EP3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`0000003`3oool005L0oooo0P00000o0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`0000003P3oool005T0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`2a0?ooo`8000003P3oool005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`2a0?ooo`8000003P3oool005`0oooo0P00000j0?ooo`030000003oool0oooo0:d0oooo1000
000@0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:T0oooo1000000D
0?ooo`00G`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0oooo1000000H0?oo
o`00H03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:40oooo1000000L0?ooo`00
H@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo09h0oooo0`00000P0?ooo`00HP3o
ool2000003@0oooo00<000000?ooo`3oool0VP3oool4000002<0oooo001T0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0UP3oool4000002L0oooo001U0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0TP3oool4000002/0oooo001V0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0SP3oool4000002l0oooo001W0?ooo`800000;`3oool00`000000oooo
0?ooo`2:0?ooo`@00000<`3oool006T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`270?ooo`<00000=`3oool006X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`23
0?ooo`@00000>P3oool006/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1o0?oo
o`@00000?P3oool006`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1k0?ooo`@0
0000@P3oool006d0oooo0P00000Y0?ooo`030000003oool0oooo07L0oooo100000160?ooo`00K`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo0`00001:0?ooo`00L03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0740oooo1000001=0?ooo`00L@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001A0?ooo`00LP3oool2000002<0
oooo00<000000?ooo`3oool0J@3oool4000005D0oooo001d0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0I@3oool4000005T0oooo001e0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0HP3oool3000005d0oooo001f0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0GP3oool400000600oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0FP3oool4000006@0oooo001h0?ooo`8000007@3oool00`000000oooo0?ooo`1F0?ooo`@0
0000J03oool007X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`@00000
K03oool007/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000L03o
ool007`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`<00000M03oool0
07d0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000001g0?ooo`00O`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000001k0?ooo`00P03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000001o0?ooo`00P@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03/0oooo100000230?ooo`00PP3oool2000001<0oooo00<00000
0?ooo`3oool0>03oool3000008L0oooo00240?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0=03oool4000008X0oooo00250?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0<03oool4000008h0oooo00260?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
;03oool400000980oooo00270?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03o
ool4000009H0oooo00280?ooo`8000003@3oool00`000000oooo0?ooo`0U0?ooo`<00000VP3oool0
08X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`@00000W@3oool008/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000X@3oool008`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000Y@3oool008d0oooo0P00
00070?ooo`030000003oool0oooo01H0oooo1000002Y0?ooo`00S`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0180oooo1000002]0?ooo`00T03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo0`00002a0?ooo`00T@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo1000002d0?ooo`00TP3oool01@000000oooo0?ooo`3oool0000000T0
oooo1000002h0?ooo`00T`3oool2000000030?ooo`000000oooo00@0oooo1000002l0?ooo`00U@3o
ool2000000030?ooo`000000000000800000`03oool009H0oooo0P0000340?ooo`00o`3ooomM0?oo
o`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?oo
o`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .57671 .47319 .57073 Mtetra
.47319 .57073 .47922 .57671 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54049 .59388 .53425 Mtetra
.59388 .53425 .59961 .54049 .61081 .53712 .60512 .53085 Mtetra
.60512 .53085 .61081 .53712 .62207 .53373 .61641 .52745 Mtetra
.664 .741 .908 r
.61641 .52745 .62207 .53373 .63336 .53034 .62773 .52403 Mtetra
.62773 .52403 .63336 .53034 .64471 .52692 .63911 .5206 Mtetra
.63911 .5206 .64471 .52692 .6561 .5235 .65053 .51715 Mtetra
.65053 .51715 .6561 .5235 .66754 .52005 .662 .51368 Mtetra
.662 .51368 .66754 .52005 .67902 .5166 .67351 .5102 Mtetra
.67351 .5102 .67902 .5166 .69055 .51313 .68508 .5067 Mtetra
.68508 .5067 .69055 .51313 .70212 .50964 .69669 .50319 Mtetra
.664 .742 .908 r
.69669 .50319 .70212 .50964 .71375 .50615 .70834 .49966 Mtetra
.664 .741 .907 r
.70834 .49966 .71375 .50615 .72542 .50263 .72005 .49612 Mtetra
.664 .741 .908 r
.72005 .49612 .72542 .50263 .73714 .49911 .7318 .49256 Mtetra
.664 .741 .907 r
.7318 .49256 .73714 .49911 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .48541 Mtetra
.75545 .48541 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .4782 Mtetra
.7793 .4782 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47092 Mtetra
.80335 .47092 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .45991 Mtetra
.83981 .45991 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44442 .91411 .43744 Mtetra
.91411 .43744 .91891 .44442 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .426 Mtetra
.95198 .426 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54821 Mtetra
.52145 .54821 .52739 .55435 .53837 .55103 .53245 .54487 Mtetra
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53478 Mtetra
.664 .741 .908 r
.56572 .53478 .57154 .541 .58269 .53763 .5769 .53139 Mtetra
.663 .741 .908 r
.5769 .53139 .58269 .53763 .59388 .53425 .58812 .528 Mtetra
.58812 .528 .59388 .53425 .60512 .53085 .59939 .5246 Mtetra
.663 .742 .909 r
.59939 .5246 .60512 .53085 .61641 .52745 .6107 .52118 Mtetra
.6107 .52118 .61641 .52745 .62773 .52403 .62206 .51776 Mtetra
.663 .744 .91 r
.62206 .51776 .62773 .52403 .63911 .5206 .63347 .51432 Mtetra
.63347 .51432 .63911 .5206 .65053 .51715 .64493 .51086 Mtetra
.663 .745 .911 r
.64493 .51086 .65053 .51715 .662 .51368 .65643 .50738 Mtetra
.664 .745 .911 r
.65643 .50738 .662 .51368 .67351 .5102 .66797 .50387 Mtetra
.66797 .50387 .67351 .5102 .68508 .5067 .67957 .50034 Mtetra
.665 .745 .91 r
.67957 .50034 .68508 .5067 .69669 .50319 .69121 .49678 Mtetra
.664 .744 .91 r
.69121 .49678 .69669 .50319 .70834 .49966 .7029 .49321 Mtetra
.665 .744 .909 r
.7029 .49321 .70834 .49966 .72005 .49612 .71464 .48961 Mtetra
.664 .743 .909 r
.71464 .48961 .72005 .49612 .7318 .49256 .72642 .48601 Mtetra
.665 .743 .908 r
.72642 .48601 .7318 .49256 .7436 .48899 .73826 .48239 Mtetra
.664 .742 .908 r
.73826 .48239 .7436 .48899 .75545 .48541 .75014 .47877 Mtetra
.664 .741 .908 r
.75014 .47877 .75545 .48541 .76735 .48181 .76208 .47514 Mtetra
.664 .741 .907 r
.76208 .47514 .76735 .48181 .7793 .4782 .77406 .47149 Mtetra
.77406 .47149 .7793 .4782 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81545 .46727 .81032 .46047 Mtetra
.81032 .46047 .81545 .46727 .8276 .46359 .82251 .45677 Mtetra
.82251 .45677 .8276 .46359 .83981 .45991 .83474 .45305 Mtetra
.83474 .45305 .83981 .45991 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43042 Mtetra
.90928 .43042 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .426 .94727 .41888 Mtetra
.94727 .41888 .95198 .426 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .5353 Mtetra
.663 .741 .908 r
.53757 .5353 .5435 .54152 .55459 .53815 .54869 .53192 Mtetra
.54869 .53192 .55459 .53815 .56572 .53478 .55985 .52854 Mtetra
.662 .742 .909 r
.55985 .52854 .56572 .53478 .5769 .53139 .57106 .52517 Mtetra
.662 .743 .91 r
.57106 .52517 .5769 .53139 .58812 .528 .58231 .5218 Mtetra
.661 .744 .912 r
.58231 .5218 .58812 .528 .59939 .5246 .59362 .51844 Mtetra
.66 .746 .914 r
.59362 .51844 .59939 .5246 .6107 .52118 .60496 .51508 Mtetra
.66 .749 .916 r
.60496 .51508 .6107 .52118 .62206 .51776 .61636 .5117 Mtetra
.66 .751 .917 r
.61636 .5117 .62206 .51776 .63347 .51432 .6278 .50831 Mtetra
.661 .754 .919 r
.6278 .50831 .63347 .51432 .64493 .51086 .63929 .50487 Mtetra
.662 .756 .92 r
.63929 .50487 .64493 .51086 .65643 .50738 .65083 .50139 Mtetra
.663 .757 .92 r
.65083 .50139 .65643 .50738 .66797 .50387 .66241 .49785 Mtetra
.664 .757 .919 r
.66241 .49785 .66797 .50387 .67957 .50034 .67403 .49427 Mtetra
.665 .757 .918 r
.67403 .49427 .67957 .50034 .69121 .49678 .68571 .49064 Mtetra
.666 .756 .917 r
.68571 .49064 .69121 .49678 .7029 .49321 .69743 .48697 Mtetra
.667 .753 .915 r
.69743 .48697 .7029 .49321 .71464 .48961 .7092 .48328 Mtetra
.667 .751 .913 r
.7092 .48328 .71464 .48961 .72642 .48601 .72101 .47956 Mtetra
.666 .748 .911 r
.72101 .47956 .72642 .48601 .73826 .48239 .73288 .47586 Mtetra
.666 .746 .91 r
.73288 .47586 .73826 .48239 .75014 .47877 .7448 .47215 Mtetra
.665 .744 .909 r
.7448 .47215 .75014 .47877 .76208 .47514 .75676 .46845 Mtetra
.665 .743 .908 r
.75676 .46845 .76208 .47514 .77406 .47149 .76878 .46475 Mtetra
.664 .742 .908 r
.76878 .46475 .77406 .47149 .7861 .46783 .78085 .46105 Mtetra
.664 .741 .907 r
.78085 .46105 .7861 .46783 .79818 .46416 .79297 .45735 Mtetra
.79297 .45735 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43042 .90441 .42333 Mtetra
.90441 .42333 .90928 .43042 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53582 Mtetra
.663 .741 .908 r
.50944 .53582 .51547 .54204 .5265 .53867 .5205 .53245 Mtetra
.5205 .53245 .5265 .53867 .53757 .5353 .5316 .52908 Mtetra
.661 .742 .91 r
.5316 .52908 .53757 .5353 .54869 .53192 .54275 .52573 Mtetra
.66 .743 .912 r
.54275 .52573 .54869 .53192 .55985 .52854 .55394 .52242 Mtetra
.658 .746 .915 r
.55394 .52242 .55985 .52854 .57106 .52517 .56518 .51915 Mtetra
.656 .749 .919 r
.56518 .51915 .57106 .52517 .58231 .5218 .57647 .51591 Mtetra
.654 .754 .923 r
.57647 .51591 .58231 .5218 .59362 .51844 .58781 .51269 Mtetra
.654 .759 .927 r
.58781 .51269 .59362 .51844 .60496 .51508 .59919 .50944 Mtetra
.654 .764 .93 r
.59919 .50944 .60496 .51508 .61636 .5117 .61062 .50616 Mtetra
.656 .769 .933 r
.61062 .50616 .61636 .5117 .6278 .50831 .6221 .50281 Mtetra
.657 .772 .934 r
.6221 .50281 .6278 .50831 .63929 .50487 .63363 .49939 Mtetra
.659 .774 .934 r
.63363 .49939 .63929 .50487 .65083 .50139 .6452 .4959 Mtetra
.661 .776 .934 r
.6452 .4959 .65083 .50139 .66241 .49785 .65682 .49234 Mtetra
.663 .776 .933 r
.65682 .49234 .66241 .49785 .67403 .49427 .66848 .48871 Mtetra
.665 .776 .932 r
.66848 .48871 .67403 .49427 .68571 .49064 .68019 .48501 Mtetra
.667 .775 .93 r
.68019 .48501 .68571 .49064 .69743 .48697 .69194 .48124 Mtetra
.669 .773 .928 r
.69194 .48124 .69743 .48697 .7092 .48328 .70374 .4774 Mtetra
.671 .77 .924 r
.70374 .4774 .7092 .48328 .72101 .47956 .71559 .47352 Mtetra
.671 .765 .921 r
.71559 .47352 .72101 .47956 .73288 .47586 .72748 .46962 Mtetra
.671 .759 .917 r
.72748 .46962 .73288 .47586 .7448 .47215 .73942 .46573 Mtetra
.669 .754 .914 r
.73942 .46573 .7448 .47215 .75676 .46845 .75142 .46187 Mtetra
.668 .749 .911 r
.75142 .46187 .75676 .46845 .76878 .46475 .76347 .45805 Mtetra
.666 .745 .909 r
.76347 .45805 .76878 .46475 .78085 .46105 .77557 .45426 Mtetra
.665 .743 .908 r
.77557 .45426 .78085 .46105 .79297 .45735 .78772 .4505 Mtetra
.664 .742 .908 r
.78772 .4505 .79297 .45735 .80514 .45363 .79993 .44674 Mtetra
.664 .741 .907 r
.79993 .44674 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53634 Mtetra
.663 .741 .908 r
.48133 .53634 .48746 .54255 .49843 .53919 .49232 .53296 Mtetra
.49232 .53296 .49843 .53919 .50944 .53582 .50337 .52959 Mtetra
.661 .741 .909 r
.50337 .52959 .50944 .53582 .5205 .53245 .51445 .52625 Mtetra
.659 .743 .912 r
.51445 .52625 .5205 .53245 .5316 .52908 .52558 .52297 Mtetra
.655 .745 .916 r
.52558 .52297 .5316 .52908 .54275 .52573 .53676 .51977 Mtetra
.651 .75 .922 r
.53676 .51977 .54275 .52573 .55394 .52242 .54799 .51665 Mtetra
.648 .756 .928 r
.54799 .51665 .55394 .52242 .56518 .51915 .55926 .51357 Mtetra
.648 .764 .934 r
.55926 .51357 .56518 .51915 .57647 .51591 .57059 .51047 Mtetra
.65 .77 .937 r
.57059 .51047 .57647 .51591 .58781 .51269 .58196 .50727 Mtetra
.654 .773 .936 r
.58196 .50727 .58781 .51269 .59919 .50944 .59337 .50394 Mtetra
.659 .773 .933 r
.59337 .50394 .59919 .50944 .61062 .50616 .60484 .50048 Mtetra
.663 .768 .928 r
.60484 .50048 .61062 .50616 .6221 .50281 .61635 .49691 Mtetra
.665 .762 .923 r
.61635 .49691 .6221 .50281 .63363 .49939 .6279 .4933 Mtetra
.665 .756 .919 r
.6279 .4933 .63363 .49939 .6452 .4959 .6395 .48968 Mtetra
.663 .753 .917 r
.6395 .48968 .6452 .4959 .65682 .49234 .65115 .4861 Mtetra
.662 .752 .917 r
.65115 .4861 .65682 .49234 .66848 .48871 .66286 .48254 Mtetra
.661 .755 .92 r
.66286 .48254 .66848 .48871 .68019 .48501 .67461 .47898 Mtetra
.662 .761 .924 r
.67461 .47898 .68019 .48501 .69194 .48124 .68641 .47537 Mtetra
.664 .769 .928 r
.68641 .47537 .69194 .48124 .70374 .4774 .69825 .47166 Mtetra
.668 .775 .93 r
.69825 .47166 .70374 .4774 .71559 .47352 .71014 .46782 Mtetra
.672 .779 .93 r
.71014 .46782 .71559 .47352 .72748 .46962 .72207 .46383 Mtetra
.675 .778 .927 r
.72207 .46383 .72748 .46962 .73942 .46573 .73404 .45975 Mtetra
.676 .772 .923 r
.73404 .45975 .73942 .46573 .75142 .46187 .74606 .45564 Mtetra
.674 .764 .918 r
.74606 .45564 .75142 .46187 .76347 .45805 .75813 .45158 Mtetra
.671 .756 .914 r
.75813 .45158 .76347 .45805 .77557 .45426 .77025 .44759 Mtetra
.668 .749 .911 r
.77025 .44759 .77557 .45426 .78772 .4505 .78244 .44368 Mtetra
.666 .745 .909 r
.78244 .44368 .78772 .4505 .79993 .44674 .79468 .43982 Mtetra
.665 .743 .908 r
.79468 .43982 .79993 .44674 .81219 .44297 .80697 .436 Mtetra
.664 .741 .908 r
.80697 .436 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.664 .741 .907 r
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42836 Mtetra
.83172 .42836 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54358 Mtetra
.43149 .54358 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.663 .741 .908 r
.46417 .53347 .47037 .53971 .48133 .53634 .47515 .53009 Mtetra
.662 .741 .909 r
.47515 .53009 .48133 .53634 .49232 .53296 .48618 .52673 Mtetra
.659 .742 .911 r
.48618 .52673 .49232 .53296 .50337 .52959 .49725 .52344 Mtetra
.655 .744 .915 r
.49725 .52344 .50337 .52959 .51445 .52625 .50836 .52024 Mtetra
.649 .748 .921 r
.50836 .52024 .51445 .52625 .52558 .52297 .51952 .51718 Mtetra
.645 .754 .929 r
.51952 .51718 .52558 .52297 .53676 .51977 .53073 .51421 Mtetra
.644 .763 .935 r
.53073 .51421 .53676 .51977 .54799 .51665 .54199 .5112 Mtetra
.65 .77 .936 r
.54199 .5112 .54799 .51665 .55926 .51357 .5533 .508 Mtetra
.662 .77 .93 r
.5533 .508 .55926 .51357 .57059 .51047 .56465 .50448 Mtetra
.675 .76 .915 r
.56465 .50448 .57059 .51047 .58196 .50727 .57604 .5006 Mtetra
.683 .741 .895 r
.57604 .5006 .58196 .50727 .59337 .50394 .58747 .49641 Mtetra
.685 .718 .875 r
.58747 .49641 .59337 .50394 .60484 .50048 .59895 .49207 Mtetra
.671 .692 .861 r
.59895 .49207 .60484 .50048 .61635 .49691 .61047 .48816 Mtetra
.661 .681 .858 r
.61047 .48816 .61635 .49691 .6279 .4933 .62205 .48458 Mtetra
.661 .682 .859 r
.62205 .48458 .6279 .4933 .6395 .48968 .63368 .48097 Mtetra
.661 .683 .86 r
.63368 .48097 .6395 .48968 .65115 .4861 .64536 .47736 Mtetra
.64536 .47736 .65115 .4861 .66286 .48254 .65708 .47373 Mtetra
.661 .682 .859 r
.65708 .47373 .66286 .48254 .67461 .47898 .66886 .47008 Mtetra
.652 .677 .861 r
.66886 .47008 .67461 .47898 .68641 .47537 .6807 .46676 Mtetra
.64 .68 .872 r
.6807 .46676 .68641 .47537 .69825 .47166 .69261 .46388 Mtetra
.644 .704 .89 r
.69261 .46388 .69825 .47166 .71014 .46782 .70458 .46084 Mtetra
.652 .731 .907 r
.70458 .46084 .71014 .46782 .72207 .46383 .71658 .45749 Mtetra
.663 .757 .92 r
.71658 .45749 .72207 .46383 .73404 .45975 .72861 .45378 Mtetra
.672 .773 .926 r
.72861 .45378 .73404 .45975 .74606 .45564 .74068 .44974 Mtetra
.678 .779 .926 r
.74068 .44974 .74606 .45564 .75813 .45158 .75278 .4455 Mtetra
.679 .774 .922 r
.75278 .4455 .75813 .45158 .77025 .44759 .76493 .44123 Mtetra
.676 .764 .917 r
.76493 .44123 .77025 .44759 .78244 .44368 .77713 .43704 Mtetra
.672 .755 .913 r
.77713 .43704 .78244 .44368 .79468 .43982 .78939 .43298 Mtetra
.668 .748 .91 r
.78939 .43298 .79468 .43982 .80697 .436 .80172 .42903 Mtetra
.666 .744 .908 r
.80172 .42903 .80697 .436 .81932 .43218 .8141 .42514 Mtetra
.665 .742 .908 r
.8141 .42514 .81932 .43218 .83172 .42836 .82654 .42126 Mtetra
.664 .741 .907 r
.82654 .42126 .83172 .42836 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54358 .42515 .53737 Mtetra
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .5306 Mtetra
.663 .741 .908 r
.44695 .5306 .45323 .53685 .46417 .53347 .45792 .52721 Mtetra
.661 .741 .909 r
.45792 .52721 .46417 .53347 .47515 .53009 .46893 .52386 Mtetra
.657 .742 .912 r
.46893 .52386 .47515 .53009 .48618 .52673 .47998 .52061 Mtetra
.651 .744 .918 r
.47998 .52061 .48618 .52673 .49725 .52344 .49107 .51751 Mtetra
.644 .749 .926 r
.49107 .51751 .49725 .52344 .50836 .52024 .50222 .51458 Mtetra
.64 .758 .934 r
.50222 .51458 .50836 .52024 .51952 .51718 .51341 .51168 Mtetra
.648 .767 .936 r
.51341 .51168 .51952 .51718 .53073 .51421 .52465 .50855 Mtetra
.668 .768 .925 r
.52465 .50855 .53073 .51421 .54199 .5112 .53594 .50489 Mtetra
.691 .753 .9 r
.53594 .50489 .54199 .5112 .5533 .508 .54727 .50051 Mtetra
.694 .721 .87 r
.54727 .50051 .5533 .508 .56465 .50448 .55864 .49584 Mtetra
.661 .682 .859 r
.55864 .49584 .56465 .50448 .57604 .5006 .57006 .49228 Mtetra
.662 .691 .867 r
.57006 .49228 .57604 .5006 .58747 .49641 .58153 .48871 Mtetra
.663 .708 .881 r
.58153 .48871 .58747 .49641 .59895 .49207 .59305 .48513 Mtetra
.664 .73 .899 r
.59305 .48513 .59895 .49207 .61047 .48816 .60461 .48153 Mtetra
.664 .741 .907 r
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .6807 .46676 .67502 .45962 Mtetra
.664 .73 .899 r
.67502 .45962 .6807 .46676 .69261 .46388 .68693 .45591 Mtetra
.663 .708 .881 r
.68693 .45591 .69261 .46388 .70458 .46084 .69889 .45219 Mtetra
.662 .691 .867 r
.69889 .45219 .70458 .46084 .71658 .45749 .7109 .44846 Mtetra
.63 .669 .869 r
.7109 .44846 .71658 .45749 .72861 .45378 .72303 .44585 Mtetra
.638 .701 .892 r
.72303 .44585 .72861 .45378 .74068 .44974 .7352 .44296 Mtetra
.659 .744 .913 r
.7352 .44296 .74068 .44974 .75278 .4455 .74738 .43933 Mtetra
.675 .771 .923 r
.74738 .43933 .75278 .4455 .76493 .44123 .75958 .43516 Mtetra
.682 .778 .923 r
.75958 .43516 .76493 .44123 .77713 .43704 .77181 .43075 Mtetra
.68 .771 .919 r
.77181 .43075 .77713 .43704 .78939 .43298 .78409 .42637 Mtetra
.675 .759 .914 r
.78409 .42637 .78939 .43298 .80172 .42903 .79643 .42216 Mtetra
.67 .75 .911 r
.79643 .42216 .80172 .42903 .8141 .42514 .80884 .41809 Mtetra
.666 .744 .909 r
.80884 .41809 .8141 .42514 .82654 .42126 .82132 .41414 Mtetra
.665 .742 .908 r
.82132 .41414 .82654 .42126 .83903 .41739 .83385 .41021 Mtetra
.664 .741 .907 r
.83385 .41021 .83903 .41739 .85158 .4135 .84643 .40629 Mtetra
.84643 .40629 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .52771 Mtetra
.663 .741 .908 r
.42968 .52771 .43603 .53399 .44695 .5306 .44062 .52432 Mtetra
.661 .741 .909 r
.44062 .52432 .44695 .5306 .45792 .52721 .45162 .52097 Mtetra
.656 .742 .913 r
.45162 .52097 .45792 .52721 .46893 .52386 .46265 .51775 Mtetra
.648 .744 .92 r
.46265 .51775 .46893 .52386 .47998 .52061 .47373 .51474 Mtetra
.639 .751 .929 r
.47373 .51474 .47998 .52061 .49107 .51751 .48485 .51189 Mtetra
.64 .761 .936 r
.48485 .51189 .49107 .51751 .50222 .51458 .49603 .50897 Mtetra
.66 .768 .929 r
.49603 .50897 .50222 .51458 .51341 .51168 .50725 .50552 Mtetra
.693 .758 .902 r
.50725 .50552 .51341 .51168 .52465 .50855 .51853 .50106 Mtetra
.694 .721 .87 r
.51853 .50106 .52465 .50855 .53594 .50489 .52984 .49638 Mtetra
.661 .685 .862 r
.52984 .49638 .53594 .50489 .54727 .50051 .5412 .49283 Mtetra
.663 .708 .881 r
.5412 .49283 .54727 .50051 .55864 .49584 .55261 .48926 Mtetra
.664 .741 .907 r
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72303 .44585 .71739 .43773 Mtetra
.663 .708 .881 r
.71739 .43773 .72303 .44585 .7352 .44296 .72954 .43394 Mtetra
.63 .672 .872 r
.72954 .43394 .7352 .44296 .74738 .43933 .74182 .43128 Mtetra
.635 .7 .893 r
.74182 .43128 .74738 .43933 .75958 .43516 .75414 .42841 Mtetra
.665 .751 .914 r
.75414 .42841 .75958 .43516 .77181 .43075 .76645 .42451 Mtetra
.682 .775 .921 r
.76645 .42451 .77181 .43075 .78409 .42637 .77877 .42006 Mtetra
.684 .774 .92 r
.77877 .42006 .78409 .42637 .79643 .42216 .79113 .41553 Mtetra
.678 .763 .915 r
.79113 .41553 .79643 .42216 .80884 .41809 .80356 .41118 Mtetra
.671 .752 .911 r
.80356 .41118 .80884 .41809 .82132 .41414 .81606 .40702 Mtetra
.667 .745 .909 r
.81606 .40702 .82132 .41414 .83385 .41021 .82862 .40299 Mtetra
.665 .742 .908 r
.82862 .40299 .83385 .41021 .84643 .40629 .84124 .39901 Mtetra
.664 .741 .907 r
.84124 .39901 .84643 .40629 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.663 .741 .908 r
.41234 .52481 .41877 .53111 .42968 .52771 .42327 .52141 Mtetra
.661 .741 .909 r
.42327 .52141 .42968 .52771 .44062 .52432 .43425 .51805 Mtetra
.655 .741 .913 r
.43425 .51805 .44062 .52432 .45162 .52097 .44526 .51485 Mtetra
.645 .744 .921 r
.44526 .51485 .45162 .52097 .46265 .51775 .45632 .51187 Mtetra
.636 .75 .931 r
.45632 .51187 .46265 .51775 .47373 .51474 .46742 .50909 Mtetra
.642 .761 .935 r
.46742 .50909 .47373 .51474 .48485 .51189 .47858 .50611 Mtetra
.675 .766 .919 r
.47858 .50611 .48485 .51189 .49603 .50897 .4898 .50223 Mtetra
.714 .746 .878 r
.4898 .50223 .49603 .50897 .50725 .50552 .50106 .49693 Mtetra
.661 .683 .86 r
.50106 .49693 .50725 .50552 .51853 .50106 .51236 .49338 Mtetra
.663 .708 .881 r
.51236 .49338 .51853 .50106 .52984 .49638 .5237 .48981 Mtetra
.664 .741 .907 r
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74182 .43128 .7362 .42304 Mtetra
.663 .708 .881 r
.7362 .42304 .74182 .43128 .75414 .42841 .74849 .41917 Mtetra
.612 .662 .874 r
.74849 .41917 .75414 .42841 .76645 .42451 .76096 .41711 Mtetra
.653 .729 .905 r
.76096 .41711 .76645 .42451 .77877 .42006 .77339 .41358 Mtetra
.68 .769 .918 r
.77339 .41358 .77877 .42006 .79113 .41553 .78581 .40914 Mtetra
.686 .775 .919 r
.78581 .40914 .79113 .41553 .80356 .41118 .79825 .40448 Mtetra
.68 .764 .915 r
.79825 .40448 .80356 .41118 .81606 .40702 .81077 .40001 Mtetra
.672 .752 .911 r
.81077 .40001 .81606 .40702 .82862 .40299 .82336 .39579 Mtetra
.667 .745 .909 r
.82336 .39579 .82862 .40299 .84124 .39901 .83602 .39171 Mtetra
.665 .742 .908 r
.83602 .39171 .84124 .39901 .85393 .39504 .84873 .38768 Mtetra
.664 .741 .907 r
.84873 .38768 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37963 Mtetra
.87435 .37963 .87946 .38706 .89231 .38304 .88724 .37557 Mtetra
.88724 .37557 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91818 .37495 .91319 .36742 Mtetra
.91319 .36742 .91818 .37495 .9312 .37088 .92625 .36332 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52876 Mtetra
.37325 .52876 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .52191 Mtetra
.663 .741 .908 r
.39495 .52191 .40145 .52823 .41234 .52481 .40586 .51848 Mtetra
.661 .741 .909 r
.40586 .51848 .41234 .52481 .42327 .52141 .41682 .5151 Mtetra
.655 .741 .913 r
.41682 .5151 .42327 .52141 .43425 .51805 .42782 .51188 Mtetra
.645 .743 .921 r
.42782 .51188 .43425 .51805 .44526 .51485 .43886 .50892 Mtetra
.634 .749 .931 r
.43886 .50892 .44526 .51485 .45632 .51187 .44994 .50618 Mtetra
.644 .761 .934 r
.44994 .50618 .45632 .51187 .46742 .50909 .46108 .50315 Mtetra
.687 .764 .911 r
.46108 .50315 .46742 .50909 .47858 .50611 .47228 .49892 Mtetra
.704 .732 .873 r
.47228 .49892 .47858 .50611 .4898 .50223 .48354 .49392 Mtetra
.662 .691 .867 r
.48354 .49392 .4898 .50223 .50106 .49693 .49482 .49036 Mtetra
.664 .741 .907 r
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.661 .74 .908 r
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46142 Mtetra
.58 .714 .934 r
.58676 .46142 .59276 .46811 .60443 .46444 .59852 .45993 Mtetra
.599 .802 .977 r
.59852 .45993 .60443 .46444 .61616 .46076 .61032 .45734 Mtetra
.633 .857 .984 r
.61032 .45734 .61616 .46076 .62794 .45706 .62214 .45361 Mtetra
.687 .871 .968 r
.62214 .45361 .62794 .45706 .63976 .45334 .63398 .44875 Mtetra
.734 .837 .929 r
.63398 .44875 .63976 .45334 .65164 .44961 .64582 .44277 Mtetra
.667 .745 .908 r
.64582 .44277 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.664 .741 .907 r
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76096 .41711 .75533 .40809 Mtetra
.621 .673 .879 r
.75533 .40809 .76096 .41711 .77339 .41358 .76787 .40565 Mtetra
.642 .712 .898 r
.76787 .40565 .77339 .41358 .78581 .40914 .78042 .40243 Mtetra
.679 .764 .915 r
.78042 .40243 .78581 .40914 .79825 .40448 .79293 .39797 Mtetra
.688 .775 .917 r
.79293 .39797 .79825 .40448 .81077 .40001 .80546 .39321 Mtetra
.68 .763 .914 r
.80546 .39321 .81077 .40001 .82336 .39579 .81807 .38867 Mtetra
.672 .751 .91 r
.81807 .38867 .82336 .39579 .83602 .39171 .83075 .38439 Mtetra
.666 .744 .908 r
.83075 .38439 .83602 .39171 .84873 .38768 .8435 .38028 Mtetra
.665 .742 .908 r
.8435 .38028 .84873 .38768 .86151 .38366 .85632 .3762 Mtetra
.664 .741 .907 r
.85632 .3762 .86151 .38366 .87435 .37963 .86919 .37213 Mtetra
.86919 .37213 .87435 .37963 .88724 .37557 .88212 .36805 Mtetra
.88212 .36805 .88724 .37557 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36332 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52876 .36664 .52243 Mtetra
.36664 .52243 .37325 .52876 .38407 .52533 .37749 .51899 Mtetra
.663 .741 .908 r
.37749 .51899 .38407 .52533 .39495 .52191 .38839 .51554 Mtetra
.662 .741 .909 r
.38839 .51554 .39495 .52191 .40586 .51848 .39933 .51213 Mtetra
.656 .741 .912 r
.39933 .51213 .40586 .51848 .41682 .5151 .41031 .50886 Mtetra
.645 .742 .919 r
.41031 .50886 .41682 .5151 .42782 .51188 .42133 .50588 Mtetra
.633 .747 .93 r
.42133 .50588 .42782 .51188 .43886 .50892 .43239 .50315 Mtetra
.642 .758 .933 r
.43239 .50315 .43886 .50892 .44994 .50618 .44351 .50017 Mtetra
.691 .763 .907 r
.44351 .50017 .44994 .50618 .46108 .50315 .4547 .49578 Mtetra
.699 .727 .871 r
.4547 .49578 .46108 .50315 .47228 .49892 .46595 .49091 Mtetra
.662 .699 .874 r
.46595 .49091 .47228 .49892 .48354 .49392 .47721 .48734 Mtetra
.664 .741 .907 r
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.575 .71 .934 r
.53423 .46924 .54041 .47596 .55192 .47233 .5458 .46787 Mtetra
.261 .644 .964 r
.5458 .46787 .55192 .47233 .56349 .46868 .55746 .46974 Mtetra
.179 0 0 r
.55746 .46974 .56349 .46868 .5751 .46501 .56919 .47031 Mtetra
.339 0 0 r
.56919 .47031 .5751 .46501 .58676 .46142 .58097 .46953 Mtetra
.368 0 .062 r
.58097 .46953 .58676 .46142 .59852 .45993 .59281 .46759 Mtetra
.308 0 .01 r
.59281 .46759 .59852 .45993 .61032 .45734 .60468 .4647 Mtetra
.25 0 0 r
.60468 .4647 .61032 .45734 .62214 .45361 .61659 .46095 Mtetra
.2 0 0 r
.61659 .46095 .62214 .45361 .63398 .44875 .62853 .45637 Mtetra
.156 0 0 r
.62853 .45637 .63398 .44875 .64582 .44277 .64047 .4508 Mtetra
.109 0 0 r
.64047 .4508 .64582 .44277 .65777 .4389 .65241 .44408 Mtetra
0 0 0 r
.65241 .44408 .65777 .4389 .66979 .43511 .66432 .43597 Mtetra
.745 .993 .851 r
.66432 .43597 .66979 .43511 .68185 .4313 .67619 .42654 Mtetra
.736 .839 .928 r
.67619 .42654 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.664 .741 .907 r
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76787 .40565 .76225 .39687 Mtetra
.624 .683 .885 r
.76225 .39687 .76787 .40565 .78042 .40243 .77487 .39424 Mtetra
.638 .706 .895 r
.77487 .39424 .78042 .40243 .79293 .39797 .78753 .39112 Mtetra
.681 .763 .913 r
.78753 .39112 .79293 .39797 .80546 .39321 .80013 .38655 Mtetra
.689 .773 .916 r
.80013 .38655 .80546 .39321 .81807 .38867 .81275 .38171 Mtetra
.68 .761 .913 r
.81275 .38171 .81807 .38867 .83075 .38439 .82545 .37713 Mtetra
.671 .749 .91 r
.82545 .37713 .83075 .38439 .8435 .38028 .83823 .37284 Mtetra
.666 .743 .908 r
.83823 .37284 .8435 .38028 .85632 .3762 .85108 .3687 Mtetra
.664 .741 .907 r
.85108 .3687 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51899 .37086 .5126 Mtetra
.662 .741 .908 r
.37086 .5126 .37749 .51899 .38839 .51554 .38179 .50915 Mtetra
.658 .74 .91 r
.38179 .50915 .38839 .51554 .39933 .51213 .39275 .50582 Mtetra
.648 .741 .917 r
.39275 .50582 .39933 .51213 .41031 .50886 .40375 .50275 Mtetra
.634 .744 .928 r
.40375 .50275 .41031 .50886 .42133 .50588 .41479 .50001 Mtetra
.637 .754 .933 r
.41479 .50001 .42133 .50588 .43239 .50315 .42588 .49715 Mtetra
.686 .763 .91 r
.42588 .49715 .43239 .50315 .44351 .50017 .43706 .49291 Mtetra
.704 .731 .872 r
.43706 .49291 .44351 .50017 .4547 .49578 .4483 .48789 Mtetra
.662 .703 .877 r
.4483 .48789 .4547 .49578 .46595 .49091 .45955 .4843 Mtetra
.664 .741 .907 r
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.576 .71 .934 r
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46841 Mtetra
.02 .49 .876 r
.51648 .46841 .52273 .47289 .53423 .46924 .52802 .47245 Mtetra
.443 0 0 r
.52802 .47245 .53423 .46924 .5458 .46787 .53967 .47469 Mtetra
.433 0 .047 r
.53967 .47469 .5458 .46787 .55746 .46974 .55138 .47491 Mtetra
.289 0 0 r
.55138 .47491 .55746 .46974 .56919 .47031 .56316 .47349 Mtetra
.057 0 0 r
.56316 .47349 .56919 .47031 .58097 .46953 .57498 .47094 Mtetra
.211 .729 .712 r
.57498 .47094 .58097 .46953 .59281 .46759 .58685 .46772 Mtetra
.396 .852 .877 r
.58685 .46772 .59281 .46759 .60468 .4647 .59877 .46415 Mtetra
.476 .887 .933 r
.59877 .46415 .60468 .4647 .61659 .46095 .61074 .46039 Mtetra
.493 .895 .935 r
.61074 .46039 .61659 .46095 .62853 .45637 .62275 .45643 Mtetra
.464 .888 .894 r
.62275 .45643 .62853 .45637 .64047 .4508 .6348 .45211 Mtetra
.391 .847 .784 r
.6348 .45211 .64047 .4508 .65241 .44408 .64688 .44712 Mtetra
0 0 0 r
.64688 .44712 .65241 .44408 .66432 .43597 .65895 .44099 Mtetra
.65895 .44099 .66432 .43597 .67619 .42654 .67098 .43318 Mtetra
.67098 .43318 .67619 .42654 .68823 .42036 .68294 .42332 Mtetra
.703 .961 .706 r
.68294 .42332 .68823 .42036 .70043 .41649 .69481 .4116 Mtetra
.735 .838 .928 r
.69481 .4116 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.664 .741 .907 r
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77487 .39424 .76925 .38551 Mtetra
.62 .685 .889 r
.76925 .38551 .77487 .39424 .78753 .39112 .78199 .38299 Mtetra
.643 .712 .897 r
.78199 .38299 .78753 .39112 .80013 .38655 .79473 .37964 Mtetra
.685 .765 .913 r
.79473 .37964 .80013 .38655 .81275 .38171 .80741 .37489 Mtetra
.689 .771 .914 r
.80741 .37489 .81275 .38171 .82545 .37713 .82012 .36999 Mtetra
.678 .757 .911 r
.82012 .36999 .82545 .37713 .83823 .37284 .83292 .36543 Mtetra
.669 .747 .909 r
.83292 .36543 .83823 .37284 .85108 .3687 .84581 .36115 Mtetra
.665 .742 .908 r
.84581 .36115 .85108 .3687 .864 .36458 .85876 .35697 Mtetra
.664 .741 .907 r
.85876 .35697 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.88485 .34864 .89 .35633 .90309 .35217 .89798 .34446 Mtetra
.89798 .34446 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51312 Mtetra
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.663 .741 .908 r
.35327 .50964 .35998 .51606 .37086 .5126 .36418 .50617 Mtetra
.66 .74 .909 r
.36418 .50617 .37086 .5126 .38179 .50915 .37513 .50276 Mtetra
.652 .74 .914 r
.37513 .50276 .38179 .50915 .39275 .50582 .38611 .49957 Mtetra
.637 .741 .924 r
.38611 .49957 .39275 .50582 .40375 .50275 .39713 .49676 Mtetra
.631 .749 .933 r
.39713 .49676 .40375 .50275 .41479 .50001 .4082 .49404 Mtetra
.672 .761 .918 r
.4082 .49404 .41479 .50001 .42588 .49715 .41935 .49021 Mtetra
.713 .743 .875 r
.41935 .49021 .42588 .49715 .43706 .49291 .43059 .48485 Mtetra
.662 .7 .874 r
.43059 .48485 .43706 .49291 .4483 .48789 .44182 .48125 Mtetra
.664 .741 .907 r
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.293 .576 .938 r
.4872 .4667 .49357 .47345 .505 .4698 .49862 .46974 Mtetra
.461 0 0 r
.49862 .46974 .505 .4698 .51648 .46841 .51012 .47435 Mtetra
.484 .006 .043 r
.51012 .47435 .51648 .46841 .52802 .47245 .52173 .47614 Mtetra
.242 0 0 r
.52173 .47614 .52802 .47245 .53967 .47469 .53342 .47524 Mtetra
.277 .781 .811 r
.53342 .47524 .53967 .47469 .55138 .47491 .54517 .47243 Mtetra
.613 .887 .99 r
.54517 .47243 .55138 .47491 .56316 .47349 .55696 .46854 Mtetra
.678 .812 .947 r
.55696 .46854 .56316 .47349 .57498 .47094 .5688 .46421 Mtetra
.68 .754 .907 r
.5688 .46421 .57498 .47094 .58685 .46772 .58069 .45986 Mtetra
.672 .72 .885 r
.58069 .45986 .58685 .46772 .59877 .46415 .59263 .45574 Mtetra
.661 .702 .878 r
.59263 .45574 .59877 .46415 .61074 .46039 .60462 .45195 Mtetra
.651 .699 .881 r
.60462 .45195 .61074 .46039 .62275 .45643 .61668 .44848 Mtetra
.644 .71 .895 r
.61668 .44848 .62275 .45643 .6348 .45211 .6288 .44523 Mtetra
.642 .742 .921 r
.6288 .44523 .6348 .45211 .64688 .44712 .64098 .44197 Mtetra
.648 .804 .958 r
.64098 .44197 .64688 .44712 .65895 .44099 .65319 .43827 Mtetra
.654 .899 .982 r
.65319 .43827 .65895 .44099 .67098 .43318 .66542 .43349 Mtetra
.617 .957 .89 r
.66542 .43349 .67098 .43318 .68294 .42332 .6776 .42675 Mtetra
.516 .873 .638 r
.6776 .42675 .68294 .42332 .69481 .4116 .68967 .41728 Mtetra
0 0 0 r
.68967 .41728 .69481 .4116 .70698 .40538 .7016 .40492 Mtetra
.83 .988 .87 r
.7016 .40492 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.664 .741 .907 r
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78199 .38299 .77635 .37401 Mtetra
.61 .677 .889 r
.77635 .37401 .78199 .38299 .79473 .37964 .78921 .37177 Mtetra
.656 .727 .902 r
.78921 .37177 .79473 .37964 .80741 .37489 .80201 .36794 Mtetra
.69 .769 .912 r
.80201 .36794 .80741 .37489 .82012 .36999 .81477 .36297 Mtetra
.686 .766 .912 r
.81477 .36297 .82012 .36999 .83292 .36543 .82758 .35808 Mtetra
.674 .753 .91 r
.82758 .35808 .83292 .36543 .84581 .36115 .84049 .35359 Mtetra
.667 .744 .908 r
.84049 .35359 .84581 .36115 .85876 .35697 .85348 .34931 Mtetra
.665 .742 .908 r
.85348 .34931 .85876 .35697 .87177 .35281 .86654 .3451 Mtetra
.664 .741 .907 r
.86654 .3451 .87177 .35281 .88485 .34864 .87965 .3409 Mtetra
.87965 .3409 .88485 .34864 .89798 .34446 .89283 .33667 Mtetra
.89283 .33667 .89798 .34446 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50318 Mtetra
.662 .741 .908 r
.34651 .50318 .35327 .50964 .36418 .50617 .35744 .49971 Mtetra
.656 .74 .911 r
.35744 .49971 .36418 .50617 .37513 .50276 .36842 .49639 Mtetra
.643 .74 .919 r
.36842 .49639 .37513 .50276 .38611 .49957 .37942 .49342 Mtetra
.629 .744 .93 r
.37942 .49342 .38611 .49957 .39713 .49676 .39046 .49077 Mtetra
.652 .756 .926 r
.39046 .49077 .39713 .49676 .4082 .49404 .40157 .48749 Mtetra
.723 .756 .879 r
.40157 .48749 .4082 .49404 .41935 .49021 .41281 .48181 Mtetra
.661 .692 .868 r
.41281 .48181 .41935 .49021 .43059 .48485 .42403 .47819 Mtetra
.664 .741 .907 r
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.088 .453 .884 r
.46934 .46359 .47579 .47036 .4872 .4667 .48067 .46882 Mtetra
.562 .02 0 r
.48067 .46882 .4872 .4667 .49862 .46974 .49211 .47385 Mtetra
.412 0 0 r
.49211 .47385 .49862 .46974 .51012 .47435 .50369 .4751 Mtetra
.173 .709 .752 r
.50369 .4751 .51012 .47435 .52173 .47614 .51536 .47301 Mtetra
.653 .873 .981 r
.51536 .47301 .52173 .47614 .53342 .47524 .52709 .46876 Mtetra
.709 .768 .898 r
.52709 .46876 .53342 .47524 .54517 .47243 .53886 .46348 Mtetra
.702 .702 .847 r
.53886 .46348 .54517 .47243 .55696 .46854 .55067 .45794 Mtetra
.689 .665 .822 r
.55067 .45794 .55696 .46854 .5688 .46421 .56252 .45258 Mtetra
.675 .643 .81 r
.56252 .45258 .5688 .46421 .58069 .45986 .57442 .44765 Mtetra
.662 .628 .806 r
.57442 .44765 .58069 .45986 .59263 .45574 .58637 .44325 Mtetra
.649 .619 .806 r
.58637 .44325 .59263 .45574 .60462 .45195 .59837 .43941 Mtetra
.637 .613 .809 r
.59837 .43941 .60462 .45195 .61668 .44848 .61045 .43616 Mtetra
.625 .611 .816 r
.61045 .43616 .61668 .44848 .6288 .44523 .6226 .43343 Mtetra
.616 .616 .828 r
.6226 .43343 .6288 .44523 .64098 .44197 .63483 .43114 Mtetra
.611 .631 .847 r
.63483 .43114 .64098 .44197 .65319 .43827 .64713 .42903 Mtetra
.616 .669 .878 r
.64713 .42903 .65319 .43827 .66542 .43349 .65949 .42668 Mtetra
.644 .749 .925 r
.65949 .42668 .66542 .43349 .6776 .42675 .67186 .42327 Mtetra
.702 .886 .965 r
.67186 .42327 .6776 .42675 .68967 .41728 .68419 .41769 Mtetra
.731 .99 .871 r
.68419 .41769 .68967 .41728 .7016 .40492 .69638 .40869 Mtetra
.679 .933 .639 r
.69638 .40869 .7016 .40492 .71361 .39412 .70837 .39583 Mtetra
.819 .996 .768 r
.70837 .39583 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.664 .741 .907 r
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78921 .37177 .78353 .36236 Mtetra
.601 .664 .883 r
.78353 .36236 .78921 .37177 .80201 .36794 .79652 .36039 Mtetra
.673 .746 .906 r
.79652 .36039 .80201 .36794 .81477 .36297 .80937 .35593 Mtetra
.692 .77 .911 r
.80937 .35593 .81477 .36297 .82758 .35808 .82221 .35082 Mtetra
.682 .76 .911 r
.82221 .35082 .82758 .35808 .84049 .35359 .83514 .34603 Mtetra
.67 .748 .909 r
.83514 .34603 .84049 .35359 .85348 .34931 .84816 .34161 Mtetra
.666 .743 .908 r
.84816 .34161 .85348 .34931 .86654 .3451 .86125 .33733 Mtetra
.664 .741 .907 r
.86125 .33733 .86654 .3451 .87965 .3409 .87441 .33308 Mtetra
.87441 .33308 .87965 .3409 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.663 .741 .908 r
.32878 .50019 .33562 .50668 .34651 .50318 .3397 .49668 Mtetra
.66 .74 .909 r
.3397 .49668 .34651 .50318 .35744 .49971 .35065 .49324 Mtetra
.65 .739 .915 r
.35065 .49324 .35744 .49971 .36842 .49639 .36165 .49006 Mtetra
.633 .74 .925 r
.36165 .49006 .36842 .49639 .37942 .49342 .37267 .48732 Mtetra
.633 .748 .931 r
.37267 .48732 .37942 .49342 .39046 .49077 .38374 .48451 Mtetra
.696 .76 .901 r
.38374 .48451 .39046 .49077 .40157 .48749 .39493 .4799 Mtetra
.695 .723 .871 r
.39493 .4799 .40157 .48749 .41281 .48181 .40617 .47513 Mtetra
.664 .741 .907 r
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.081 .449 .882 r
.45142 .46047 .45794 .46727 .46934 .46359 .46268 .46569 Mtetra
.596 .064 0 r
.46268 .46569 .46934 .46359 .48067 .46882 .47405 .47151 Mtetra
.347 0 0 r
.47405 .47151 .48067 .46882 .49211 .47385 .48558 .47269 Mtetra
.465 .867 .962 r
.48558 .47269 .49211 .47385 .50369 .4751 .49723 .4698 Mtetra
.714 .806 .922 r
.49723 .4698 .50369 .4751 .51536 .47301 .50895 .46443 Mtetra
.723 .717 .844 r
.50895 .46443 .51536 .47301 .52709 .46876 .52071 .458 Mtetra
.71 .671 .81 r
.52071 .458 .52709 .46876 .53886 .46348 .53251 .45144 Mtetra
.696 .645 .795 r
.53251 .45144 .53886 .46348 .55067 .45794 .54433 .44519 Mtetra
.683 .63 .79 r
.54433 .44519 .55067 .45794 .56252 .45258 .55619 .43948 Mtetra
.671 .62 .79 r
.55619 .43948 .56252 .45258 .57442 .44765 .5681 .43436 Mtetra
.658 .612 .791 r
.5681 .43436 .57442 .44765 .58637 .44325 .58006 .42987 Mtetra
.646 .606 .794 r
.58006 .42987 .58637 .44325 .59837 .43941 .59208 .426 Mtetra
.634 .599 .798 r
.59208 .426 .59837 .43941 .61045 .43616 .60417 .42276 Mtetra
.62 .594 .802 r
.60417 .42276 .61045 .43616 .6226 .43343 .61633 .42014 Mtetra
.607 .589 .807 r
.61633 .42014 .6226 .43343 .63483 .43114 .62858 .41813 Mtetra
.594 .587 .814 r
.62858 .41813 .63483 .43114 .64713 .42903 .64091 .41667 Mtetra
.585 .593 .827 r
.64091 .41667 .64713 .42903 .65949 .42668 .65333 .41554 Mtetra
.586 .616 .849 r
.65333 .41554 .65949 .42668 .67186 .42327 .66583 .41427 Mtetra
.613 .677 .887 r
.66583 .41427 .67186 .42327 .68419 .41769 .67834 .41195 Mtetra
.688 .802 .936 r
.67834 .41195 .68419 .41769 .69638 .40869 .6908 .40711 Mtetra
.793 .965 .917 r
.6908 .40711 .69638 .40869 .70837 .39583 .70308 .39812 Mtetra
.81 .99 .736 r
.70308 .39812 .70837 .39583 .72032 .38273 .71509 .38436 Mtetra
.819 .996 .768 r
.71509 .38436 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.664 .741 .907 r
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.626 .725 .918 r
.77795 .35473 .78353 .36236 .79652 .36039 .7909 .35175 Mtetra
.633 .701 .895 r
.7909 .35175 .79652 .36039 .80937 .35593 .80391 .34861 Mtetra
.688 .762 .908 r
.80391 .34861 .80937 .35593 .82221 .35082 .81681 .3436 Mtetra
.69 .766 .91 r
.81681 .3436 .82221 .35082 .83514 .34603 .82975 .33852 Mtetra
.676 .753 .909 r
.82975 .33852 .83514 .34603 .84816 .34161 .8428 .33388 Mtetra
.667 .744 .908 r
.8428 .33388 .84816 .34161 .86125 .33733 .85593 .32951 Mtetra
.665 .742 .907 r
.85593 .32951 .86125 .33733 .87441 .33308 .86913 .32521 Mtetra
.664 .741 .907 r
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32188 .49366 Mtetra
.662 .741 .908 r
.32188 .49366 .32878 .50019 .3397 .49668 .33283 .49014 Mtetra
.657 .74 .911 r
.33283 .49014 .3397 .49668 .35065 .49324 .34381 .48677 Mtetra
.642 .739 .919 r
.34381 .48677 .35065 .49324 .36165 .49006 .35482 .48378 Mtetra
.627 .741 .93 r
.35482 .48378 .36165 .49006 .37267 .48732 .36586 .48115 Mtetra
.658 .754 .921 r
.36586 .48115 .37267 .48732 .38374 .48451 .37699 .47769 Mtetra
.72 .75 .876 r
.37699 .47769 .38374 .48451 .39493 .4799 .38826 .47205 Mtetra
.663 .708 .881 r
.38826 .47205 .39493 .4799 .40617 .47513 .39948 .46839 Mtetra
.664 .741 .907 r
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.282 .572 .937 r
.43343 .45734 .44004 .46416 .45142 .46047 .44468 .46036 Mtetra
.615 .056 0 r
.44468 .46036 .45142 .46047 .46268 .46569 .45594 .46758 Mtetra
.365 0 0 r
.45594 .46758 .46268 .46569 .47405 .47151 .46741 .46954 Mtetra
.531 .873 .99 r
.46741 .46954 .47405 .47151 .48558 .47269 .47904 .46652 Mtetra
.73 .781 .894 r
.47904 .46652 .48558 .47269 .49723 .4698 .49076 .46046 Mtetra
.733 .704 .824 r
.49076 .46046 .49723 .4698 .50895 .46443 .50252 .45318 Mtetra
.72 .667 .797 r
.50252 .45318 .50895 .46443 .52071 .458 .51431 .44578 Mtetra
.707 .648 .788 r
.51431 .44578 .52071 .458 .53251 .45144 .52612 .43879 Mtetra
.694 .637 .787 r
.52612 .43879 .53251 .45144 .54433 .44519 .53796 .4324 Mtetra
.683 .63 .79 r
.53796 .4324 .54433 .44519 .55619 .43948 .54984 .42667 Mtetra
.671 .625 .795 r
.54984 .42667 .55619 .43948 .5681 .43436 .56176 .42158 Mtetra
.66 .621 .799 r
.56176 .42158 .5681 .43436 .58006 .42987 .57374 .41708 Mtetra
.648 .616 .803 r
.57374 .41708 .58006 .42987 .59208 .426 .58577 .41318 Mtetra
.636 .61 .807 r
.58577 .41318 .59208 .426 .60417 .42276 .59787 .40986 Mtetra
.622 .603 .81 r
.59787 .40986 .60417 .42276 .61633 .42014 .61004 .40716 Mtetra
.607 .594 .812 r
.61004 .40716 .61633 .42014 .62858 .41813 .6223 .40509 Mtetra
.592 .586 .815 r
.6223 .40509 .62858 .41813 .64091 .41667 .63465 .40369 Mtetra
.576 .579 .82 r
.63465 .40369 .64091 .41667 .65333 .41554 .64709 .40291 Mtetra
.563 .579 .828 r
.64709 .40291 .65333 .41554 .66583 .41427 .65964 .40256 Mtetra
.563 .596 .844 r
.65964 .40256 .66583 .41427 .67834 .41195 .67226 .40211 Mtetra
.593 .65 .876 r
.67226 .40211 .67834 .41195 .6908 .40711 .68491 .40042 Mtetra
.685 .773 .918 r
.68491 .40042 .6908 .40711 .70308 .39812 .69746 .39565 Mtetra
.824 .94 .903 r
.69746 .39565 .70308 .39812 .71509 .38436 .70977 .38578 Mtetra
.879 .992 .757 r
.70977 .38578 .71509 .38436 .72712 .37119 .72177 .37051 Mtetra
.83 .988 .87 r
.72177 .37051 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.664 .741 .907 r
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7909 .35175 .78522 .34284 Mtetra
.602 .681 .897 r
.78522 .34284 .7909 .35175 .80391 .34861 .79835 .34069 Mtetra
.668 .738 .902 r
.79835 .34069 .80391 .34861 .81681 .3436 .81135 .3363 Mtetra
.694 .767 .908 r
.81135 .3363 .81681 .3436 .82975 .33852 .82433 .33103 Mtetra
.682 .759 .909 r
.82433 .33103 .82975 .33852 .8428 .33388 .8374 .32613 Mtetra
.67 .747 .908 r
.8374 .32613 .8428 .33388 .85593 .32951 .85056 .32163 Mtetra
.665 .742 .908 r
.85056 .32163 .85593 .32951 .86913 .32521 .8638 .31727 Mtetra
.664 .741 .907 r
.8638 .31727 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.663 .741 .908 r
.30401 .49064 .31098 .4972 .32188 .49366 .31494 .48708 Mtetra
.661 .74 .909 r
.31494 .48708 .32188 .49366 .33283 .49014 .32591 .48357 Mtetra
.652 .739 .913 r
.32591 .48357 .33283 .49014 .34381 .48677 .33691 .4803 Mtetra
.634 .738 .923 r
.33691 .4803 .34381 .48677 .35482 .48378 .34794 .47751 Mtetra
.63 .744 .93 r
.34794 .47751 .35482 .48378 .36586 .48115 .35901 .47476 Mtetra
.696 .758 .9 r
.35901 .47476 .36586 .48115 .37699 .47769 .37022 .4701 Mtetra
.695 .725 .873 r
.37022 .4701 .37699 .47769 .38826 .47205 .38148 .46529 Mtetra
.664 .741 .907 r
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.574 .711 .936 r
.41538 .4542 .42207 .46104 .43343 .45734 .42671 .45275 Mtetra
.515 0 0 r
.42671 .45275 .43343 .45734 .44468 .46036 .43782 .46179 Mtetra
.478 0 0 r
.43782 .46179 .44468 .46036 .45594 .46758 .44919 .46564 Mtetra
.455 .842 .983 r
.44919 .46564 .45594 .46758 .46741 .46954 .46078 .46346 Mtetra
.734 .785 .894 r
.46078 .46346 .46741 .46954 .47904 .46652 .4725 .45727 Mtetra
.743 .709 .82 r
.4725 .45727 .47904 .46652 .49076 .46046 .48427 .44939 Mtetra
.732 .675 .794 r
.48427 .44939 .49076 .46046 .50252 .45318 .49606 .44129 Mtetra
.719 .658 .788 r
.49606 .44129 .50252 .45318 .51431 .44578 .50787 .43363 Mtetra
.707 .65 .79 r
.50787 .43363 .51431 .44578 .52612 .43879 .5197 .42665 Mtetra
.696 .646 .796 r
.5197 .42665 .52612 .43879 .53796 .4324 .53156 .42038 Mtetra
.685 .643 .802 r
.53156 .42038 .53796 .4324 .54984 .42667 .54346 .41477 Mtetra
.674 .641 .809 r
.54346 .41477 .54984 .42667 .56176 .42158 .5554 .40976 Mtetra
.663 .638 .814 r
.5554 .40976 .56176 .42158 .57374 .41708 .5674 .40529 Mtetra
.652 .634 .819 r
.5674 .40529 .57374 .41708 .58577 .41318 .57945 .40135 Mtetra
.64 .628 .823 r
.57945 .40135 .58577 .41318 .59787 .40986 .59157 .39794 Mtetra
.627 .621 .825 r
.59157 .39794 .59787 .40986 .61004 .40716 .60375 .39507 Mtetra
.612 .612 .827 r
.60375 .39507 .61004 .40716 .6223 .40509 .61602 .39281 Mtetra
.595 .601 .828 r
.61602 .39281 .6223 .40509 .63465 .40369 .62837 .39123 Mtetra
.576 .589 .829 r
.62837 .39123 .63465 .40369 .64709 .40291 .64083 .39036 Mtetra
.557 .578 .831 r
.64083 .39036 .64709 .40291 .65964 .40256 .65339 .3902 Mtetra
.542 .575 .837 r
.65339 .3902 .65964 .40256 .67226 .40211 .66606 .3905 Mtetra
.545 .59 .851 r
.66606 .3905 .67226 .40211 .68491 .40042 .67881 .3906 Mtetra
.589 .651 .879 r
.67881 .3906 .68491 .40042 .69746 .39565 .69156 .38898 Mtetra
.71 .785 .91 r
.69156 .38898 .69746 .39565 .70977 .38578 .70416 .38329 Mtetra
.864 .937 .867 r
.70416 .38329 .70977 .38578 .72177 .37051 .71644 .37141 Mtetra
.919 .978 .745 r
.71644 .37141 .72177 .37051 .734 .35951 .72837 .35419 Mtetra
.735 .838 .928 r
.72837 .35419 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.664 .741 .907 r
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.626 .725 .918 r
.7796 .33504 .78522 .34284 .79835 .34069 .79269 .33197 Mtetra
.633 .703 .897 r
.79269 .33197 .79835 .34069 .81135 .3363 .80583 .32875 Mtetra
.691 .761 .905 r
.80583 .32875 .81135 .3363 .82433 .33103 .81886 .32354 Mtetra
.689 .763 .908 r
.81886 .32354 .82433 .33103 .8374 .32613 .83195 .31838 Mtetra
.674 .75 .908 r
.83195 .31838 .8374 .32613 .85056 .32163 .84515 .3137 Mtetra
.666 .743 .908 r
.84515 .3137 .85056 .32163 .8638 .31727 .85843 .30927 Mtetra
.664 .741 .907 r
.85843 .30927 .8638 .31727 .8771 .31293 .87177 .30489 Mtetra
.87177 .30489 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48403 Mtetra
.663 .741 .908 r
.29699 .48403 .30401 .49064 .31494 .48708 .30794 .48045 Mtetra
.659 .74 .91 r
.30794 .48045 .31494 .48708 .32591 .48357 .31894 .47697 Mtetra
.647 .738 .916 r
.31894 .47697 .32591 .48357 .33691 .4803 .32996 .47383 Mtetra
.627 .738 .927 r
.32996 .47383 .33691 .4803 .34794 .47751 .341 .47117 Mtetra
.646 .748 .924 r
.341 .47117 .34794 .47751 .35901 .47476 .35212 .468 Mtetra
.724 .754 .876 r
.35212 .468 .35901 .47476 .37022 .4701 .36342 .46218 Mtetra
.662 .709 .882 r
.36342 .46218 .37022 .4701 .38148 .46529 .37465 .45848 Mtetra
.664 .741 .907 r
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
0 .364 .827 r
.40865 .4473 .41538 .4542 .42671 .45275 .41975 .45359 Mtetra
.615 .069 0 r
.41975 .45359 .42671 .45275 .43782 .46179 .43096 .46037 Mtetra
.163 .687 .876 r
.43096 .46037 .43782 .46179 .44919 .46564 .44246 .46033 Mtetra
.717 .807 .921 r
.44246 .46033 .44919 .46564 .46078 .46346 .45415 .45485 Mtetra
.752 .725 .827 r
.45415 .45485 .46078 .46346 .4725 .45727 .46593 .44675 Mtetra
.745 .688 .797 r
.46593 .44675 .4725 .45727 .48427 .44939 .47774 .43805 Mtetra
.733 .672 .79 r
.47774 .43805 .48427 .44939 .49606 .44129 .48956 .42974 Mtetra
.721 .664 .794 r
.48956 .42974 .49606 .44129 .50787 .43363 .5014 .42216 Mtetra
.709 .661 .801 r
.5014 .42216 .50787 .43363 .5197 .42665 .51325 .41538 Mtetra
.697 .661 .81 r
.51325 .41538 .5197 .42665 .53156 .42038 .52513 .40929 Mtetra
.661 .649 .828 r
.52513 .40929 .53156 .42038 .54346 .41477 .53706 .40507 Mtetra
.659 .676 .855 r
.53706 .40507 .54346 .41477 .5554 .40976 .54904 .40113 Mtetra
.662 .703 .878 r
.54904 .40113 .5554 .40976 .5674 .40529 .56107 .39718 Mtetra
.663 .717 .889 r
.56107 .39718 .5674 .40529 .57945 .40135 .57315 .3932 Mtetra
.57315 .3932 .57945 .40135 .59157 .39794 .58529 .38921 Mtetra
.662 .703 .878 r
.58529 .38921 .59157 .39794 .60375 .39507 .59748 .3852 Mtetra
.652 .673 .858 r
.59748 .3852 .60375 .39507 .61602 .39281 .60973 .38147 Mtetra
.6 .621 .844 r
.60973 .38147 .61602 .39281 .62837 .39123 .6221 .37963 Mtetra
.58 .607 .844 r
.6221 .37963 .62837 .39123 .64083 .39036 .63456 .3785 Mtetra
.557 .592 .844 r
.63456 .3785 .64083 .39036 .65339 .3902 .64713 .37819 Mtetra
.535 .578 .845 r
.64713 .37819 .65339 .3902 .66606 .3905 .65982 .37862 Mtetra
.521 .574 .849 r
.65982 .37862 .66606 .3905 .67881 .3906 .67262 .37947 Mtetra
.534 .597 .863 r
.67262 .37947 .67881 .3906 .69156 .38898 .68548 .37974 Mtetra
.611 .677 .889 r
.68548 .37974 .69156 .38898 .70416 .38329 .6983 .37733 Mtetra
.769 .824 .895 r
.6983 .37733 .70416 .38329 .71644 .37141 .71087 .36938 Mtetra
.909 .938 .816 r
.71087 .36938 .71644 .37141 .72837 .35419 .72302 .35441 Mtetra
.886 .989 .797 r
.72302 .35441 .72837 .35419 .74097 .34768 .73518 .33992 Mtetra
.664 .741 .907 r
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79269 .33197 .78695 .3229 Mtetra
.597 .679 .898 r
.78695 .3229 .79269 .33197 .80583 .32875 .80024 .32081 Mtetra
.679 .747 .902 r
.80024 .32081 .80583 .32875 .81886 .32354 .81335 .31598 Mtetra
.694 .764 .906 r
.81335 .31598 .81886 .32354 .83195 .31838 .82647 .31061 Mtetra
.679 .754 .908 r
.82647 .31061 .83195 .31838 .84515 .3137 .83969 .30574 Mtetra
.668 .745 .908 r
.83969 .30574 .84515 .3137 .85843 .30927 .85301 .30121 Mtetra
.665 .742 .907 r
.85301 .30121 .85843 .30927 .87177 .30489 .8664 .29677 Mtetra
.664 .741 .907 r
.8664 .29677 .87177 .30489 .88518 .3005 .87985 .29235 Mtetra
.27897 .48098 .28608 .48761 .29699 .48403 .28991 .47736 Mtetra
.662 .74 .908 r
.28991 .47736 .29699 .48403 .30794 .48045 .30089 .47378 Mtetra
.657 .74 .911 r
.30089 .47378 .30794 .48045 .31894 .47697 .31191 .47034 Mtetra
.64 .737 .919 r
.31191 .47034 .31894 .47697 .32996 .47383 .32294 .46733 Mtetra
.624 .738 .928 r
.32294 .46733 .32996 .47383 .341 .47117 .33401 .46471 Mtetra
.67 .752 .912 r
.33401 .46471 .341 .47117 .35212 .468 .3452 .46084 Mtetra
.713 .742 .875 r
.3452 .46084 .35212 .468 .36342 .46218 .35651 .45534 Mtetra
.664 .741 .907 r
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.572 .711 .936 r
.39045 .44413 .39727 .45105 .40865 .4473 .40177 .44267 Mtetra
.581 .033 0 r
.40177 .44267 .40865 .4473 .41975 .45359 .41276 .45258 Mtetra
.325 0 0 r
.41276 .45258 .41975 .45359 .43096 .46037 .4241 .45622 Mtetra
.627 .829 .978 r
.4241 .45622 .43096 .46037 .44246 .46033 .43572 .45281 Mtetra
.754 .751 .85 r
.43572 .45281 .44246 .46033 .45415 .45485 .4475 .44515 Mtetra
.758 .706 .804 r
.4475 .44515 .45415 .45485 .46593 .44675 .45933 .43606 Mtetra
.747 .687 .793 r
.45933 .43606 .46593 .44675 .47774 .43805 .47118 .4271 Mtetra
.735 .679 .797 r
.47118 .4271 .47774 .43805 .48956 .42974 .48302 .41888 Mtetra
.722 .677 .805 r
.48302 .41888 .48956 .42974 .5014 .42216 .49488 .41151 Mtetra
.697 .672 .822 r
.49488 .41151 .5014 .42216 .51325 .41538 .50676 .40568 Mtetra
.659 .676 .856 r
.50676 .40568 .51325 .41538 .52513 .40929 .51866 .40174 Mtetra
.664 .732 .901 r
.51866 .40174 .52513 .40929 .53706 .40507 .53062 .39779 Mtetra
.664 .741 .907 r
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60973 .38147 .6035 .3737 Mtetra
.664 .732 .901 r
.6035 .3737 .60973 .38147 .6221 .37963 .61583 .36962 Mtetra
.606 .654 .871 r
.61583 .36962 .6221 .37963 .63456 .3785 .62828 .36746 Mtetra
.561 .611 .86 r
.62828 .36746 .63456 .3785 .64713 .37819 .64086 .36686 Mtetra
.534 .592 .859 r
.64086 .36686 .64713 .37819 .65982 .37862 .65356 .36714 Mtetra
.509 .577 .859 r
.65356 .36714 .65982 .37862 .67262 .37947 .66638 .36818 Mtetra
.502 .578 .864 r
.66638 .36818 .67262 .37947 .68548 .37974 .67931 .36937 Mtetra
.544 .62 .879 r
.67931 .36937 .68548 .37974 .6983 .37733 .69227 .36913 Mtetra
.673 .732 .894 r
.69227 .36913 .6983 .37733 .71087 .36938 .70507 .36454 Mtetra
.849 .869 .855 r
.70507 .36454 .71087 .36938 .72302 .35441 .71749 .35274 Mtetra
.94 .929 .766 r
.71749 .35274 .72302 .35441 .73518 .33992 .72949 .33448 Mtetra
.736 .839 .928 r
.72949 .33448 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.664 .741 .907 r
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.604 .715 .923 r
.78127 .31493 .78695 .3229 .80024 .32081 .79456 .31244 Mtetra
.658 .728 .901 r
.79456 .31244 .80024 .32081 .81335 .31598 .80778 .30827 Mtetra
.695 .762 .904 r
.80778 .30827 .81335 .31598 .82647 .31061 .82094 .3028 Mtetra
.684 .756 .906 r
.82094 .3028 .82647 .31061 .83969 .30574 .83419 .29772 Mtetra
.67 .746 .907 r
.83419 .29772 .83969 .30574 .85301 .30121 .84755 .29308 Mtetra
.665 .742 .907 r
.84755 .29308 .85301 .30121 .8664 .29677 .86098 .28859 Mtetra
.664 .741 .907 r
.86098 .28859 .8664 .29677 .87985 .29235 .87448 .28413 Mtetra
.663 .741 .907 r
.27181 .47429 .27897 .48098 .28991 .47736 .28278 .47066 Mtetra
.662 .741 .908 r
.28278 .47066 .28991 .47736 .30089 .47378 .29378 .46706 Mtetra
.654 .739 .912 r
.29378 .46706 .30089 .47378 .31191 .47034 .30482 .46367 Mtetra
.635 .736 .921 r
.30482 .46367 .31191 .47034 .32294 .46733 .31588 .46078 Mtetra
.627 .738 .927 r
.31588 .46078 .32294 .46733 .33401 .46471 .32697 .45807 Mtetra
.695 .754 .897 r
.32697 .45807 .33401 .46471 .3452 .46084 .33824 .45333 Mtetra
.696 .731 .878 r
.33824 .45333 .3452 .46084 .35651 .45534 .34955 .44846 Mtetra
.664 .741 .907 r
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.168 .508 .912 r
.38357 .43715 .39045 .44413 .40177 .44267 .3947 .44125 Mtetra
.632 .07 0 r
.3947 .44125 .40177 .44267 .41276 .45258 .40577 .44952 Mtetra
.243 .696 .953 r
.40577 .44952 .41276 .45258 .4241 .45622 .41723 .4501 Mtetra
.725 .785 .9 r
.41723 .4501 .4241 .45622 .43572 .45281 .42896 .44421 Mtetra
.765 .73 .82 r
.42896 .44421 .43572 .45281 .4475 .44515 .44081 .43526 Mtetra
.762 .705 .799 r
.44081 .43526 .4475 .44515 .45933 .43606 .45268 .42575 Mtetra
.75 .695 .799 r
.45268 .42575 .45933 .43606 .47118 .4271 .46456 .4168 Mtetra
.737 .692 .808 r
.46456 .4168 .47118 .4271 .48302 .41888 .47643 .40876 Mtetra
.711 .687 .825 r
.47643 .40876 .48302 .41888 .49488 .41151 .48831 .40235 Mtetra
.66 .69 .867 r
.48831 .40235 .49488 .41151 .50676 .40568 .5002 .3984 Mtetra
.664 .741 .907 r
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62828 .36746 .62201 .35792 Mtetra
.586 .658 .887 r
.62201 .35792 .62828 .36746 .64086 .36686 .63458 .35628 Mtetra
.535 .61 .874 r
.63458 .35628 .64086 .36686 .65356 .36714 .64729 .3563 Mtetra
.504 .589 .873 r
.64729 .3563 .65356 .36714 .66638 .36818 .66013 .35726 Mtetra
.482 .576 .873 r
.66013 .35726 .66638 .36818 .67931 .36937 .67309 .35881 Mtetra
.499 .594 .88 r
.67309 .35881 .67931 .36937 .69227 .36913 .68613 .35981 Mtetra
.599 .674 .893 r
.68613 .35981 .69227 .36913 .70507 .36454 .69911 .3577 Mtetra
.778 .804 .874 r
.69911 .3577 .70507 .36454 .71749 .35274 .71177 .34896 Mtetra
.914 .888 .792 r
.71177 .34896 .71749 .35274 .72949 .33448 .72395 .33232 Mtetra
.87 .954 .861 r
.72395 .33232 .72949 .33448 .74223 .32784 .73638 .31992 Mtetra
.664 .741 .907 r
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.627 .725 .918 r
.77555 .3069 .78127 .31493 .79456 .31244 .78882 .3037 Mtetra
.632 .709 .902 r
.78882 .3037 .79456 .31244 .80778 .30827 .80215 .30036 Mtetra
.693 .758 .902 r
.80215 .30036 .80778 .30827 .82094 .3028 .81537 .29491 Mtetra
.688 .758 .905 r
.81537 .29491 .82094 .3028 .83419 .29772 .82865 .28965 Mtetra
.673 .748 .907 r
.82865 .28965 .83419 .29772 .84755 .29308 .84204 .28489 Mtetra
.666 .742 .907 r
.84204 .28489 .84755 .29308 .86098 .28859 .85551 .28035 Mtetra
.664 .741 .907 r
.85551 .28035 .86098 .28859 .87448 .28413 .86906 .27583 Mtetra
.664 .741 .908 r
.26459 .46756 .27181 .47429 .28278 .47066 .27559 .46389 Mtetra
.661 .74 .909 r
.27559 .46389 .28278 .47066 .29378 .46706 .28662 .4603 Mtetra
.652 .739 .913 r
.28662 .4603 .29378 .46706 .30482 .46367 .29768 .45695 Mtetra
.63 .735 .923 r
.29768 .45695 .30482 .46367 .31588 .46078 .30875 .45415 Mtetra
.633 .739 .925 r
.30875 .45415 .31588 .46078 .32697 .45807 .31989 .45125 Mtetra
.718 .755 .882 r
.31989 .45125 .32697 .45807 .33824 .45333 .33123 .44563 Mtetra
.673 .721 .885 r
.33123 .44563 .33824 .45333 .34955 .44846 .34253 .44152 Mtetra
.664 .741 .907 r
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
0 .191 .689 r
.37664 .43012 .38357 .43715 .3947 .44125 .3876 .4385 Mtetra
.442 0 0 r
.3876 .4385 .3947 .44125 .40577 .44952 .39877 .44476 Mtetra
.552 .785 .986 r
.39877 .44476 .40577 .44952 .41723 .4501 .41035 .44286 Mtetra
.754 .76 .857 r
.41035 .44286 .41723 .4501 .42896 .44421 .42217 .43531 Mtetra
.773 .727 .81 r
.42217 .43531 .42896 .44421 .44081 .43526 .43407 .42565 Mtetra
.766 .712 .802 r
.43407 .42565 .44081 .43526 .45268 .42575 .44598 .416 Mtetra
.754 .707 .808 r
.44598 .416 .45268 .42575 .46456 .4168 .45788 .40716 Mtetra
.74 .706 .82 r
.45788 .40716 .46456 .4168 .47643 .40876 .46979 .3993 Mtetra
.667 .686 .859 r
.46979 .3993 .47643 .40876 .48831 .40235 .48166 .39504 Mtetra
.664 .741 .907 r
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.655 .737 .911 r
.61576 .35025 .62201 .35792 .63458 .35628 .62829 .34637 Mtetra
.538 .628 .889 r
.62829 .34637 .63458 .35628 .64729 .3563 .64101 .34613 Mtetra
.501 .604 .888 r
.64101 .34613 .64729 .3563 .66013 .35726 .65386 .3469 Mtetra
.47 .584 .887 r
.65386 .3469 .66013 .35726 .67309 .35881 .66685 .34853 Mtetra
.467 .585 .889 r
.66685 .34853 .67309 .35881 .68613 .35981 .67994 .35018 Mtetra
.543 .641 .898 r
.67994 .35018 .68613 .35981 .69911 .3577 .69303 .34969 Mtetra
.716 .757 .885 r
.69303 .34969 .69911 .3577 .71177 .34896 .70589 .34344 Mtetra
.878 .85 .812 r
.70589 .34344 .71177 .34896 .72395 .33232 .71827 .32879 Mtetra
.919 .897 .79 r
.71827 .32879 .72395 .33232 .73638 .31992 .73048 .31193 Mtetra
.664 .741 .907 r
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.653 .736 .911 r
.76977 .2988 .77555 .3069 .78882 .3037 .78302 .29474 Mtetra
.605 .692 .905 r
.78302 .29474 .78882 .3037 .80215 .30036 .79647 .29226 Mtetra
.688 .753 .901 r
.79647 .29226 .80215 .30036 .81537 .29491 .80974 .28693 Mtetra
.691 .758 .903 r
.80974 .28693 .81537 .29491 .82865 .28965 .82305 .2815 Mtetra
.675 .748 .906 r
.82305 .2815 .82865 .28965 .84204 .28489 .83648 .27663 Mtetra
.667 .743 .907 r
.83648 .27663 .84204 .28489 .85551 .28035 .85 .27202 Mtetra
.664 .741 .907 r
.85 .27202 .85551 .28035 .86906 .27583 .86359 .26747 Mtetra
.663 .74 .907 r
.25732 .46076 .26459 .46756 .27559 .46389 .26834 .45708 Mtetra
.66 .74 .909 r
.26834 .45708 .27559 .46389 .28662 .4603 .2794 .45347 Mtetra
.649 .738 .914 r
.2794 .45347 .28662 .4603 .29768 .45695 .29048 .45017 Mtetra
.627 .734 .924 r
.29048 .45017 .29768 .45695 .30875 .45415 .30158 .44741 Mtetra
.641 .74 .921 r
.30158 .44741 .30875 .45415 .31989 .45125 .31275 .4443 Mtetra
.725 .754 .875 r
.31275 .4443 .31989 .45125 .33123 .44563 .32415 .43832 Mtetra
.664 .731 .9 r
.32415 .43832 .33123 .44563 .34253 .44152 .33546 .43452 Mtetra
.664 .741 .907 r
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.661 .74 .909 r
.35821 .42688 .36522 .43394 .37664 .43012 .36965 .42313 Mtetra
.526 .025 0 r
.36965 .42313 .37664 .43012 .3876 .4385 .38049 .43435 Mtetra
0 .4 .782 r
.38049 .43435 .3876 .4385 .39877 .44476 .39175 .43883 Mtetra
.654 .777 .939 r
.39175 .43883 .39877 .44476 .41035 .44286 .40342 .43514 Mtetra
.768 .752 .838 r
.40342 .43514 .41035 .44286 .42217 .43531 .41531 .42655 Mtetra
.779 .732 .809 r
.41531 .42655 .42217 .43531 .43407 .42565 .42727 .41653 Mtetra
.771 .724 .809 r
.42727 .41653 .43407 .42565 .44598 .416 .43921 .40685 Mtetra
.757 .721 .819 r
.43921 .40685 .44598 .416 .45788 .40716 .45115 .39813 Mtetra
.719 .714 .845 r
.45115 .39813 .45788 .40716 .46979 .3993 .46306 .39167 Mtetra
.664 .732 .901 r
.46306 .39167 .46979 .3993 .48166 .39504 .47497 .38767 Mtetra
.664 .741 .907 r
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62829 .34637 .62201 .3383 Mtetra
.577 .698 .924 r
.62201 .3383 .62829 .34637 .64101 .34613 .63471 .33658 Mtetra
.499 .62 .903 r
.63471 .33658 .64101 .34613 .65386 .3469 .64758 .33716 Mtetra
.459 .596 .901 r
.64758 .33716 .65386 .3469 .66685 .34853 .66058 .33873 Mtetra
.443 .587 .901 r
.66058 .33873 .66685 .34853 .67994 .35018 .67372 .34069 Mtetra
.501 .626 .906 r
.67372 .34069 .67994 .35018 .69303 .34969 .68689 .34119 Mtetra
.667 .728 .895 r
.68689 .34119 .69303 .34969 .70589 .34344 .69988 .3367 Mtetra
.845 .82 .825 r
.69988 .3367 .70589 .34344 .71827 .32879 .71243 .32381 Mtetra
.925 .853 .752 r
.71243 .32381 .71827 .32879 .73048 .31193 .72453 .30397 Mtetra
.667 .745 .908 r
.72453 .30397 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.664 .741 .907 r
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78302 .29474 .7772 .28618 Mtetra
.591 .699 .918 r
.7772 .28618 .78302 .29474 .79647 .29226 .79072 .28399 Mtetra
.683 .748 .901 r
.79072 .28399 .79647 .29226 .80974 .28693 .80406 .27883 Mtetra
.693 .757 .901 r
.80406 .27883 .80974 .28693 .82305 .2815 .81741 .27328 Mtetra
.677 .749 .905 r
.81741 .27328 .82305 .2815 .83648 .27663 .83088 .2683 Mtetra
.667 .743 .907 r
.83088 .2683 .83648 .27663 .85 .27202 .84444 .26363 Mtetra
.664 .741 .907 r
.84444 .26363 .85 .27202 .86359 .26747 .85807 .25903 Mtetra
.663 .741 .908 r
.24999 .45392 .25732 .46076 .26834 .45708 .26104 .45021 Mtetra
.66 .74 .909 r
.26104 .45021 .26834 .45708 .2794 .45347 .27213 .44659 Mtetra
.647 .737 .915 r
.27213 .44659 .2794 .45347 .29048 .45017 .28323 .4433 Mtetra
.626 .732 .924 r
.28323 .4433 .29048 .45017 .30158 .44741 .29435 .44057 Mtetra
.647 .74 .917 r
.29435 .44057 .30158 .44741 .31275 .4443 .30556 .43725 Mtetra
.723 .753 .876 r
.30556 .43725 .31275 .4443 .32415 .43832 .31699 .4313 Mtetra
.664 .741 .907 r
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.572 .711 .936 r
.35114 .41977 .35821 .42688 .36965 .42313 .3625 .41822 Mtetra
.63 .089 0 r
.3625 .41822 .36965 .42313 .38049 .43435 .37336 .42901 Mtetra
.126 .548 .92 r
.37336 .42901 .38049 .43435 .39175 .43883 .38469 .43219 Mtetra
.692 .766 .908 r
.38469 .43219 .39175 .43883 .40342 .43514 .39644 .42736 Mtetra
.776 .753 .832 r
.39644 .42736 .40342 .43514 .41531 .42655 .4084 .41818 Mtetra
.785 .742 .813 r
.4084 .41818 .41531 .42655 .42727 .41653 .4204 .40796 Mtetra
.776 .737 .817 r
.4204 .40796 .42727 .41653 .43921 .40685 .43238 .3983 Mtetra
.761 .736 .829 r
.43238 .3983 .43921 .40685 .45115 .39813 .44436 .38966 Mtetra
.698 .722 .868 r
.44436 .38966 .45115 .39813 .46306 .39167 .45628 .38428 Mtetra
.664 .741 .907 r
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.618 .723 .921 r
.61569 .33046 .62201 .3383 .63471 .33658 .62838 .32758 Mtetra
.495 .635 .916 r
.62838 .32758 .63471 .33658 .64758 .33716 .64127 .32801 Mtetra
.449 .608 .915 r
.64127 .32801 .64758 .33716 .66058 .33873 .6543 .3295 Mtetra
.423 .592 .914 r
.6543 .3295 .66058 .33873 .67372 .34069 .66746 .33158 Mtetra
.469 .621 .917 r
.66746 .33158 .67372 .34069 .68689 .34119 .68069 .33262 Mtetra
.633 .715 .906 r
.68069 .33262 .68689 .34119 .69988 .3367 .69378 .32922 Mtetra
.82 .8 .833 r
.69378 .32922 .69988 .3367 .71243 .32381 .70647 .3176 Mtetra
.91 .829 .754 r
.70647 .3176 .71243 .32381 .72453 .30397 .71867 .29814 Mtetra
.736 .835 .925 r
.71867 .29814 .72453 .30397 .7376 .29948 .73164 .29132 Mtetra
.664 .741 .907 r
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.591 .709 .925 r
.77137 .27791 .7772 .28618 .79072 .28399 .78492 .27562 Mtetra
.678 .745 .902 r
.78492 .27562 .79072 .28399 .80406 .27883 .79832 .2706 Mtetra
.694 .756 .899 r
.79832 .2706 .80406 .27883 .81741 .27328 .81172 .26496 Mtetra
.678 .749 .904 r
.81172 .26496 .81741 .27328 .83088 .2683 .82523 .25989 Mtetra
.668 .743 .907 r
.82523 .25989 .83088 .2683 .84444 .26363 .83883 .25516 Mtetra
.664 .741 .907 r
.83883 .25516 .84444 .26363 .85807 .25903 .85251 .25053 Mtetra
.663 .741 .908 r
.24261 .44702 .24999 .45392 .26104 .45021 .25368 .44328 Mtetra
.659 .74 .909 r
.25368 .44328 .26104 .45021 .27213 .44659 .26479 .43964 Mtetra
.646 .737 .915 r
.26479 .43964 .27213 .44659 .28323 .4433 .27593 .43636 Mtetra
.625 .731 .923 r
.27593 .43636 .28323 .4433 .29435 .44057 .28707 .43361 Mtetra
.651 .739 .914 r
.28707 .43361 .29435 .44057 .30556 .43725 .29832 .43016 Mtetra
.722 .753 .876 r
.29832 .43016 .30556 .43725 .31699 .4313 .30978 .42422 Mtetra
.664 .741 .907 r
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.513 .688 .946 r
.34401 .4126 .35114 .41977 .3625 .41822 .35534 .41216 Mtetra
.548 .022 0 r
.35534 .41216 .3625 .41822 .37336 .42901 .36621 .42264 Mtetra
.262 .594 .949 r
.36621 .42264 .37336 .42901 .38469 .43219 .37759 .42516 Mtetra
.706 .759 .894 r
.37759 .42516 .38469 .43219 .39644 .42736 .3894 .41976 Mtetra
.782 .759 .832 r
.3894 .41976 .39644 .42736 .4084 .41818 .40141 .41029 Mtetra
.791 .755 .819 r
.40141 .41029 .4084 .41818 .4204 .40796 .41345 .39998 Mtetra
.782 .752 .826 r
.41345 .39998 .4204 .40796 .43238 .3983 .42548 .39031 Mtetra
.766 .75 .839 r
.42548 .39031 .43238 .3983 .44436 .38966 .4375 .3817 Mtetra
.687 .733 .886 r
.4375 .3817 .44436 .38966 .45628 .38428 .44944 .37682 Mtetra
.664 .741 .907 r
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.637 .731 .916 r
.60931 .32256 .61569 .33046 .62838 .32758 .62203 .3191 Mtetra
.489 .649 .929 r
.62203 .3191 .62838 .32758 .64127 .32801 .63494 .31943 Mtetra
.437 .62 .929 r
.63494 .31943 .64127 .32801 .6543 .3295 .648 .32086 Mtetra
.403 .601 .927 r
.648 .32086 .6543 .3295 .66746 .33158 .66119 .32296 Mtetra
.446 .625 .929 r
.66119 .32296 .66746 .33158 .68069 .33262 .67445 .32422 Mtetra
.615 .714 .916 r
.67445 .32422 .68069 .33262 .69378 .32922 .68761 .32133 Mtetra
.807 .79 .837 r
.68761 .32133 .69378 .32922 .70647 .3176 .70039 .31033 Mtetra
.897 .809 .753 r
.70039 .31033 .70647 .3176 .71867 .29814 .71268 .29111 Mtetra
.76 .805 .889 r
.71268 .29111 .71867 .29814 .73164 .29132 .72563 .28309 Mtetra
.664 .741 .907 r
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.593 .71 .925 r
.76549 .26956 .77137 .27791 .78492 .27562 .77908 .26719 Mtetra
.675 .744 .903 r
.77908 .26719 .78492 .27562 .79832 .2706 .79253 .26223 Mtetra
.695 .755 .898 r
.79253 .26223 .79832 .2706 .81172 .26496 .80597 .25654 Mtetra
.679 .748 .903 r
.80597 .25654 .81172 .26496 .82523 .25989 .81952 .2514 Mtetra
.668 .743 .906 r
.81952 .2514 .82523 .25989 .83883 .25516 .83317 .24662 Mtetra
.664 .741 .907 r
.83317 .24662 .83883 .25516 .85251 .25053 .8469 .24194 Mtetra
.663 .741 .908 r
.23516 .44007 .24261 .44702 .25368 .44328 .24627 .4363 Mtetra
.659 .74 .909 r
.24627 .4363 .25368 .44328 .26479 .43964 .25741 .43263 Mtetra
.646 .736 .915 r
.25741 .43263 .26479 .43964 .27593 .43636 .26857 .42932 Mtetra
.625 .73 .922 r
.26857 .42932 .27593 .43636 .28707 .43361 .27973 .42654 Mtetra
.651 .738 .913 r
.27973 .42654 .28707 .43361 .29832 .43016 .29101 .42307 Mtetra
.723 .754 .877 r
.29101 .42307 .29832 .43016 .30978 .42422 .3025 .41709 Mtetra
.664 .741 .907 r
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.513 .688 .946 r
.33683 .40538 .34401 .4126 .35534 .41216 .34818 .40491 Mtetra
0 .029 .533 r
.34818 .40491 .35534 .41216 .36621 .42264 .35905 .41538 Mtetra
.307 .589 .943 r
.35905 .41538 .36621 .42264 .37759 .42516 .37045 .41788 Mtetra
.705 .754 .89 r
.37045 .41788 .37759 .42516 .3894 .41976 .38229 .41245 Mtetra
.785 .768 .837 r
.38229 .41245 .3894 .41976 .40141 .41029 .39434 .40294 Mtetra
.797 .769 .827 r
.39434 .40294 .40141 .41029 .41345 .39998 .40643 .39258 Mtetra
.788 .768 .835 r
.40643 .39258 .41345 .39998 .42548 .39031 .41851 .38287 Mtetra
.771 .766 .848 r
.41851 .38287 .42548 .39031 .4375 .3817 .43057 .37422 Mtetra
.689 .748 .897 r
.43057 .37422 .4375 .3817 .44944 .37682 .44254 .36931 Mtetra
.664 .741 .907 r
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.637 .731 .916 r
.60289 .3146 .60931 .32256 .62203 .3191 .61564 .3111 Mtetra
.478 .66 .941 r
.61564 .3111 .62203 .3191 .63494 .31943 .62858 .31141 Mtetra
.421 .631 .941 r
.62858 .31141 .63494 .31943 .648 .32086 .64167 .3128 Mtetra
.384 .61 .939 r
.64167 .3128 .648 .32086 .66119 .32296 .65489 .31487 Mtetra
.431 .636 .942 r
.65489 .31487 .66119 .32296 .67445 .32422 .66818 .31611 Mtetra
.613 .724 .924 r
.66818 .31611 .67445 .32422 .68761 .32133 .68138 .31319 Mtetra
.805 .785 .834 r
.68138 .31319 .68761 .32133 .70039 .31033 .69421 .30213 Mtetra
.888 .791 .748 r
.69421 .30213 .70039 .31033 .71268 .29111 .70657 .28285 Mtetra
.752 .771 .869 r
.70657 .28285 .71268 .29111 .72563 .28309 .71957 .27479 Mtetra
.664 .741 .907 r
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.593 .71 .925 r
.75956 .26114 .76549 .26956 .77908 .26719 .77319 .25874 Mtetra
.675 .745 .904 r
.77319 .25874 .77908 .26719 .79253 .26223 .78668 .25374 Mtetra
.694 .753 .897 r
.78668 .25374 .79253 .26223 .80597 .25654 .80017 .248 Mtetra
.679 .747 .903 r
.80017 .248 .80597 .25654 .81952 .2514 .81377 .24282 Mtetra
.668 .743 .906 r
.81377 .24282 .81952 .2514 .83317 .24662 .82747 .238 Mtetra
.664 .741 .907 r
.82747 .238 .83317 .24662 .8469 .24194 .84124 .23328 Mtetra
.663 .741 .908 r
.22766 .43307 .23516 .44007 .24627 .4363 .23879 .42926 Mtetra
.66 .74 .909 r
.23879 .42926 .24627 .4363 .25741 .43263 .24996 .42556 Mtetra
.647 .736 .914 r
.24996 .42556 .25741 .43263 .26857 .42932 .26115 .42218 Mtetra
.626 .729 .921 r
.26115 .42218 .26857 .42932 .27973 .42654 .27235 .41936 Mtetra
.648 .735 .913 r
.27235 .41936 .27973 .42654 .29101 .42307 .28364 .41596 Mtetra
.724 .755 .878 r
.28364 .41596 .29101 .42307 .3025 .41709 .29517 .4099 Mtetra
.664 .741 .907 r
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.572 .711 .936 r
.32959 .39809 .33683 .40538 .34818 .40491 .34103 .39646 Mtetra
0 .057 .586 r
.34103 .39646 .34818 .40491 .35905 .41538 .35187 .40723 Mtetra
.292 .553 .924 r
.35187 .40723 .35905 .41538 .37045 .41788 .36325 .41036 Mtetra
.69 .746 .894 r
.36325 .41036 .37045 .41788 .38229 .41245 .3751 .40543 Mtetra
.785 .776 .845 r
.3751 .40543 .38229 .41245 .39434 .40294 .38719 .39612 Mtetra
.802 .783 .835 r
.38719 .39612 .39434 .40294 .40643 .39258 .39933 .38577 Mtetra
.795 .784 .843 r
.39933 .38577 .40643 .39258 .41851 .38287 .41146 .37598 Mtetra
.778 .782 .856 r
.41146 .37598 .41851 .38287 .43057 .37422 .42356 .36722 Mtetra
.706 .768 .9 r
.42356 .36722 .43057 .37422 .44254 .36931 .43559 .36173 Mtetra
.664 .741 .907 r
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.618 .723 .921 r
.5964 .30657 .60289 .3146 .61564 .3111 .60921 .30358 Mtetra
.463 .67 .953 r
.60921 .30358 .61564 .3111 .62858 .31141 .62219 .30393 Mtetra
.401 .64 .953 r
.62219 .30393 .62858 .31141 .64167 .3128 .6353 .30533 Mtetra
.365 .621 .95 r
.6353 .30533 .64167 .3128 .65489 .31487 .64855 .30733 Mtetra
.428 .654 .954 r
.64855 .30733 .65489 .31487 .66818 .31611 .66187 .30829 Mtetra
.631 .741 .927 r
.66187 .30829 .66818 .31611 .68138 .31319 .67509 .30478 Mtetra
.812 .782 .824 r
.67509 .30478 .68138 .31319 .69421 .30213 .68794 .29301 Mtetra
.88 .775 .741 r
.68794 .29301 .69421 .30213 .70657 .28285 .70034 .27336 Mtetra
.72 .732 .861 r
.70034 .27336 .70657 .28285 .71957 .27479 .71345 .26641 Mtetra
.664 .741 .907 r
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.591 .709 .925 r
.75357 .25265 .75956 .26114 .77319 .25874 .76725 .25026 Mtetra
.678 .748 .904 r
.76725 .25026 .77319 .25874 .78668 .25374 .78078 .24511 Mtetra
.694 .751 .896 r
.78078 .24511 .78668 .25374 .80017 .248 .79432 .23935 Mtetra
.678 .746 .902 r
.79432 .23935 .80017 .248 .81377 .24282 .80796 .23416 Mtetra
.668 .742 .906 r
.80796 .23416 .81377 .24282 .82747 .238 .82171 .2293 Mtetra
.664 .741 .907 r
.82171 .2293 .82747 .238 .84124 .23328 .83553 .22455 Mtetra
.663 .74 .907 r
.2201 .426 .22766 .43307 .23879 .42926 .23126 .42217 Mtetra
.66 .74 .909 r
.23126 .42217 .23879 .42926 .24996 .42556 .24246 .41841 Mtetra
.649 .736 .913 r
.24246 .41841 .24996 .42556 .26115 .42218 .25368 .41496 Mtetra
.628 .729 .92 r
.25368 .41496 .26115 .42218 .27235 .41936 .2649 .41207 Mtetra
.641 .732 .914 r
.2649 .41207 .27235 .41936 .28364 .41596 .27621 .4088 Mtetra
.725 .756 .877 r
.27621 .4088 .28364 .41596 .29517 .4099 .28778 .40265 Mtetra
.664 .741 .907 r
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.661 .74 .909 r
.32229 .39075 .32959 .39809 .34103 .39646 .33389 .38685 Mtetra
0 .071 .615 r
.33389 .38685 .34103 .39646 .35187 .40723 .34469 .39804 Mtetra
.233 .489 .894 r
.34469 .39804 .35187 .40723 .36325 .41036 .35601 .40244 Mtetra
.656 .727 .901 r
.35601 .40244 .36325 .41036 .3751 .40543 .36784 .39859 Mtetra
.778 .782 .856 r
.36784 .39859 .3751 .40543 .38719 .39612 .37995 .3898 Mtetra
.806 .797 .844 r
.37995 .3898 .38719 .39612 .39933 .38577 .39214 .37955 Mtetra
.802 .801 .851 r
.39214 .37955 .39933 .38577 .41146 .37598 .40432 .36966 Mtetra
.785 .799 .864 r
.40432 .36966 .41146 .37598 .42356 .36722 .41648 .36074 Mtetra
.737 .791 .895 r
.41648 .36074 .42356 .36722 .43559 .36173 .42858 .35409 Mtetra
.664 .741 .907 r
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.575 .705 .931 r
.58987 .29847 .5964 .30657 .60921 .30358 .60274 .29658 Mtetra
.44 .678 .964 r
.60274 .29658 .60921 .30358 .62219 .30393 .61575 .29703 Mtetra
.375 .648 .963 r
.61575 .29703 .62219 .30393 .6353 .30533 .62891 .29846 Mtetra
.349 .635 .96 r
.62891 .29846 .6353 .30533 .64855 .30733 .64218 .30028 Mtetra
.445 .682 .965 r
.64218 .30028 .64855 .30733 .66187 .30829 .65552 .30064 Mtetra
.668 .762 .921 r
.65552 .30064 .66187 .30829 .67509 .30478 .66872 .29596 Mtetra
.825 .776 .806 r
.66872 .29596 .67509 .30478 .68794 .29301 .68156 .28281 Mtetra
.873 .758 .733 r
.68156 .28281 .68794 .29301 .70034 .27336 .694 .26265 Mtetra
.661 .684 .861 r
.694 .26265 .70034 .27336 .71345 .26641 .70729 .25797 Mtetra
.664 .741 .907 r
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.589 .708 .926 r
.74753 .24409 .75357 .25265 .76725 .25026 .76125 .24172 Mtetra
.683 .75 .902 r
.76125 .24172 .76725 .25026 .78078 .24511 .77482 .23635 Mtetra
.692 .749 .895 r
.77482 .23635 .78078 .24511 .79432 .23935 .78841 .23059 Mtetra
.677 .744 .902 r
.78841 .23059 .79432 .23935 .80796 .23416 .80211 .2254 Mtetra
.667 .741 .906 r
.80211 .2254 .80796 .23416 .82171 .2293 .8159 .22053 Mtetra
.664 .741 .907 r
.8159 .22053 .82171 .2293 .83553 .22455 .82977 .21573 Mtetra
.21248 .41888 .2201 .426 .23126 .42217 .22367 .41501 Mtetra
.661 .74 .908 r
.22367 .41501 .23126 .42217 .24246 .41841 .23489 .41121 Mtetra
.652 .737 .912 r
.23489 .41121 .24246 .41841 .25368 .41496 .24615 .40766 Mtetra
.631 .729 .918 r
.24615 .40766 .25368 .41496 .2649 .41207 .2574 .40466 Mtetra
.634 .728 .915 r
.2574 .40466 .2649 .41207 .27621 .4088 .26872 .40156 Mtetra
.718 .754 .881 r
.26872 .40156 .27621 .4088 .28778 .40265 .28031 .39569 Mtetra
.675 .754 .91 r
.28031 .39569 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.664 .741 .907 r
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38685 .32657 .37931 Mtetra
0 .195 .694 r
.32657 .37931 .33389 .38685 .34469 .39804 .33753 .38762 Mtetra
.147 .404 .85 r
.33753 .38762 .34469 .39804 .35601 .40244 .34875 .39379 Mtetra
.595 .688 .907 r
.34875 .39379 .35601 .40244 .36784 .39859 .36052 .39169 Mtetra
.76 .78 .87 r
.36052 .39169 .36784 .39859 .37995 .3898 .37263 .38387 Mtetra
.805 .809 .855 r
.37263 .38387 .37995 .3898 .39214 .37955 .38485 .3739 Mtetra
.808 .818 .859 r
.38485 .3739 .39214 .37955 .40432 .36966 .39709 .36395 Mtetra
.794 .818 .871 r
.39709 .36395 .40432 .36966 .41648 .36074 .40931 .35482 Mtetra
.773 .813 .884 r
.40931 .35482 .41648 .36074 .42858 .35409 .4215 .34669 Mtetra
.674 .752 .91 r
.4215 .34669 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.664 .741 .907 r
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.655 .737 .911 r
.57049 .29473 .57712 .30286 .58987 .29847 .58328 .2906 Mtetra
.505 .683 .946 r
.58328 .2906 .58987 .29847 .60274 .29658 .59622 .29015 Mtetra
.41 .684 .974 r
.59622 .29015 .60274 .29658 .61575 .29703 .60928 .29073 Mtetra
.347 .656 .97 r
.60928 .29073 .61575 .29703 .62891 .29846 .62247 .29216 Mtetra
.345 .655 .97 r
.62247 .29216 .62891 .29846 .64218 .30028 .63577 .29363 Mtetra
.49 .72 .973 r
.63577 .29363 .64218 .30028 .65552 .30064 .6491 .29292 Mtetra
.719 .779 .9 r
.6491 .29292 .65552 .30064 .66872 .29596 .66227 .28638 Mtetra
.838 .765 .781 r
.66227 .28638 .66872 .29596 .68156 .28281 .67507 .27134 Mtetra
.839 .734 .748 r
.67507 .27134 .68156 .28281 .694 .26265 .68773 .25407 Mtetra
.664 .738 .905 r
.68773 .25407 .694 .26265 .70729 .25797 .70106 .24945 Mtetra
.664 .741 .907 r
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.653 .736 .911 r
.72792 .24014 .73405 .24874 .74753 .24409 .74147 .23581 Mtetra
.599 .723 .932 r
.74147 .23581 .74753 .24409 .76125 .24172 .75521 .23306 Mtetra
.688 .751 .9 r
.75521 .23306 .76125 .24172 .77482 .23635 .7688 .22745 Mtetra
.69 .747 .895 r
.7688 .22745 .77482 .23635 .78841 .23059 .78244 .22173 Mtetra
.674 .742 .902 r
.78244 .22173 .78841 .23059 .80211 .2254 .7962 .21658 Mtetra
.667 .741 .906 r
.7962 .21658 .80211 .2254 .8159 .22053 .81004 .21167 Mtetra
.664 .741 .907 r
.81004 .21167 .8159 .22053 .82977 .21573 .82395 .20684 Mtetra
.663 .74 .907 r
.2048 .4117 .21248 .41888 .22367 .41501 .21601 .40781 Mtetra
.662 .74 .908 r
.21601 .40781 .22367 .41501 .23489 .41121 .22727 .40394 Mtetra
.654 .737 .911 r
.22727 .40394 .23489 .41121 .24615 .40766 .23856 .40029 Mtetra
.635 .73 .917 r
.23856 .40029 .24615 .40766 .2574 .40466 .24985 .39714 Mtetra
.628 .725 .916 r
.24985 .39714 .2574 .40466 .26872 .40156 .26118 .39417 Mtetra
.695 .747 .892 r
.26118 .39417 .26872 .40156 .28031 .39569 .27273 .38914 Mtetra
.701 .772 .907 r
.27273 .38914 .28031 .39569 .29182 .39136 .28434 .38397 Mtetra
.664 .741 .907 r
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.168 .508 .912 r
.31918 .37182 .32657 .37931 .33753 .38762 .33041 .37576 Mtetra
.06 .312 .796 r
.33041 .37576 .33753 .38762 .34875 .39379 .3415 .38394 Mtetra
.497 .616 .9 r
.3415 .38394 .34875 .39379 .36052 .39169 .35316 .3843 Mtetra
.721 .762 .885 r
.35316 .3843 .36052 .39169 .37263 .38387 .36523 .37809 Mtetra
.796 .815 .867 r
.36523 .37809 .37263 .38387 .38485 .3739 .37748 .36877 Mtetra
.811 .834 .868 r
.37748 .36877 .38485 .3739 .39709 .36395 .38976 .35887 Mtetra
.802 .838 .879 r
.38976 .35887 .39709 .36395 .40931 .35482 .40204 .34954 Mtetra
.782 .834 .892 r
.40204 .34954 .40931 .35482 .4215 .34669 .4143 .34114 Mtetra
.742 .824 .915 r
.4143 .34114 .4215 .34669 .43362 .34219 .42653 .33439 Mtetra
.664 .741 .907 r
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.574 .705 .931 r
.5638 .28653 .57049 .29473 .58328 .2906 .57667 .2846 Mtetra
.445 .719 .983 r
.57667 .2846 .58328 .2906 .59622 .29015 .58965 .28436 Mtetra
.372 .689 .981 r
.58965 .28436 .59622 .29015 .60928 .29073 .60276 .28506 Mtetra
.321 .666 .974 r
.60276 .28506 .60928 .29073 .62247 .29216 .61599 .28638 Mtetra
.368 .689 .981 r
.61599 .28638 .62247 .29216 .63577 .29363 .62931 .28712 Mtetra
.571 .764 .969 r
.62931 .28712 .63577 .29363 .6491 .29292 .64262 .2847 Mtetra
.772 .782 .861 r
.64262 .2847 .6491 .29292 .66227 .28638 .65572 .27555 Mtetra
.844 .745 .754 r
.65572 .27555 .66227 .28638 .67507 .27134 .66848 .25839 Mtetra
.782 .696 .77 r
.66848 .25839 .67507 .27134 .68773 .25407 .68141 .24552 Mtetra
.664 .741 .907 r
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.627 .725 .918 r
.72173 .23146 .72792 .24014 .74147 .23581 .73538 .22793 Mtetra
.629 .75 .935 r
.73538 .22793 .74147 .23581 .75521 .23306 .7491 .22424 Mtetra
.692 .751 .896 r
.7491 .22424 .75521 .23306 .7688 .22745 .76273 .21842 Mtetra
.687 .744 .895 r
.76273 .21842 .7688 .22745 .78244 .22173 .77643 .21278 Mtetra
.672 .742 .902 r
.77643 .21278 .78244 .22173 .7962 .21658 .79023 .20766 Mtetra
.666 .741 .906 r
.79023 .20766 .7962 .21658 .81004 .21167 .80413 .20275 Mtetra
.664 .741 .907 r
.80413 .20275 .81004 .21167 .82395 .20684 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40781 .2083 .40053 Mtetra
.662 .74 .908 r
.2083 .40053 .21601 .40781 .22727 .40394 .21958 .39662 Mtetra
.657 .738 .91 r
.21958 .39662 .22727 .40394 .23856 .40029 .23091 .39285 Mtetra
.641 .732 .914 r
.23091 .39285 .23856 .40029 .24985 .39714 .24224 .38953 Mtetra
.626 .723 .917 r
.24224 .38953 .24985 .39714 .26118 .39417 .25359 .38659 Mtetra
.669 .737 .901 r
.25359 .38659 .26118 .39417 .27273 .38914 .26511 .38238 Mtetra
.719 .771 .894 r
.26511 .38238 .27273 .38914 .28434 .38397 .2768 .37651 Mtetra
.664 .741 .907 r
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.572 .711 .936 r
.31173 .36426 .31918 .37182 .33041 .37576 .32333 .3625 Mtetra
.003 .244 .752 r
.32333 .3625 .33041 .37576 .3415 .38394 .33431 .37233 Mtetra
.366 .508 .868 r
.33431 .37233 .3415 .38394 .35316 .3843 .34579 .37577 Mtetra
.649 .714 .896 r
.34579 .37577 .35316 .3843 .36523 .37809 .35777 .37201 Mtetra
.77 .808 .883 r
.35777 .37201 .36523 .37809 .37748 .36877 .37001 .36392 Mtetra
.807 .845 .879 r
.37001 .36392 .37748 .36877 .38976 .35887 .38234 .35437 Mtetra
.807 .857 .887 r
.38234 .35437 .38976 .35887 .40204 .34954 .39467 .34495 Mtetra
.791 .856 .899 r
.39467 .34495 .40204 .34954 .4143 .34114 .407 .33627 Mtetra
.77 .849 .91 r
.407 .33627 .4143 .34114 .42653 .33439 .41931 .32848 Mtetra
.726 .813 .919 r
.41931 .32848 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.664 .741 .907 r
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.596 .715 .927 r
.54425 .28274 .55103 .29098 .5638 .28653 .55707 .28023 Mtetra
.494 .733 .979 r
.55707 .28023 .5638 .28653 .57667 .2846 .57 .27929 Mtetra
.401 .723 .989 r
.57 .27929 .57667 .2846 .58965 .28436 .58303 .27925 Mtetra
.332 .694 .981 r
.58303 .27925 .58965 .28436 .60276 .28506 .59618 .27999 Mtetra
.318 .688 .979 r
.59618 .27999 .60276 .28506 .61599 .28638 .60944 .28088 Mtetra
.443 .74 .991 r
.60944 .28088 .61599 .28638 .62931 .28712 .62277 .28029 Mtetra
.674 .794 .938 r
.62277 .28029 .62931 .28712 .64262 .2847 .63603 .27529 Mtetra
.81 .765 .811 r
.63603 .27529 .64262 .2847 .65572 .27555 .64906 .26293 Mtetra
.84 .72 .731 r
.64906 .26293 .65572 .27555 .66848 .25839 .66179 .24399 Mtetra
.69 .639 .793 r
.66179 .24399 .66848 .25839 .68141 .24552 .67504 .23689 Mtetra
.664 .741 .907 r
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.604 .715 .923 r
.71549 .22271 .72173 .23146 .73538 .22793 .72923 .21982 Mtetra
.658 .758 .923 r
.72923 .21982 .73538 .22793 .7491 .22424 .74293 .21521 Mtetra
.694 .748 .893 r
.74293 .21521 .7491 .22424 .76273 .21842 .7566 .20929 Mtetra
.683 .742 .896 r
.7566 .20929 .76273 .21842 .77643 .21278 .77036 .20375 Mtetra
.67 .74 .903 r
.77036 .20375 .77643 .21278 .79023 .20766 .78422 .19867 Mtetra
.665 .741 .906 r
.78422 .19867 .79023 .20766 .80413 .20275 .79816 .19373 Mtetra
.664 .74 .907 r
.79816 .19373 .80413 .20275 .81809 .19786 .81217 .18882 Mtetra
.664 .741 .907 r
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .39321 Mtetra
.663 .741 .908 r
.20052 .39321 .2083 .40053 .21958 .39662 .21184 .38925 Mtetra
.659 .739 .909 r
.21184 .38925 .21958 .39662 .23091 .39285 .22319 .38538 Mtetra
.647 .734 .913 r
.22319 .38538 .23091 .39285 .24224 .38953 .23457 .38186 Mtetra
.628 .724 .916 r
.23457 .38186 .24224 .38953 .25359 .38659 .24595 .37882 Mtetra
.647 .728 .908 r
.24595 .37882 .25359 .38659 .26511 .38238 .25744 .37527 Mtetra
.726 .765 .883 r
.25744 .37527 .26511 .38238 .2768 .37651 .2692 .36899 Mtetra
.664 .741 .907 r
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32333 .3625 .316 .35249 Mtetra
.111 .398 .851 r
.316 .35249 .32333 .3625 .33431 .37233 .3272 .35859 Mtetra
.237 .388 .812 r
.3272 .35859 .33431 .37233 .34579 .37577 .33849 .36521 Mtetra
.531 .619 .885 r
.33849 .36521 .34579 .37577 .35777 .37201 .3503 .36483 Mtetra
.714 .771 .897 r
.3503 .36483 .35777 .37201 .37001 .36392 .36247 .3589 Mtetra
.787 .842 .893 r
.36247 .3589 .37001 .36392 .38234 .35437 .37481 .35026 Mtetra
.805 .87 .896 r
.37481 .35026 .38234 .35437 .39467 .34495 .3872 .34102 Mtetra
.797 .878 .906 r
.3872 .34102 .39467 .34495 .407 .33627 .39959 .33218 Mtetra
.779 .875 .918 r
.39959 .33218 .407 .33627 .41931 .32848 .41197 .32409 Mtetra
.757 .866 .929 r
.41197 .32409 .41931 .32848 .43161 .32223 .42435 .3168 Mtetra
.735 .832 .925 r
.42435 .3168 .43161 .32223 .4439 .31793 .43675 .31022 Mtetra
.674 .752 .91 r
.43675 .31022 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.664 .741 .907 r
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.654 .738 .911 r
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27925 Mtetra
.583 .719 .936 r
.52462 .27925 .5315 .28721 .54425 .28274 .53742 .27699 Mtetra
.512 .762 .987 r
.53742 .27699 .54425 .28274 .55707 .28023 .5503 .27546 Mtetra
.423 .755 .995 r
.5503 .27546 .55707 .28023 .57 .27929 .56327 .27476 Mtetra
.351 .726 .986 r
.56327 .27476 .57 .27929 .58303 .27925 .57635 .27482 Mtetra
.31 .707 .978 r
.57635 .27482 .58303 .27925 .59618 .27999 .58955 .27531 Mtetra
.371 .733 .99 r
.58955 .27531 .59618 .27999 .60944 .28088 .60283 .27519 Mtetra
.575 .796 .983 r
.60283 .27519 .60944 .28088 .62277 .28029 .61613 .27234 Mtetra
.761 .788 .875 r
.61613 .27234 .62277 .28029 .63603 .27529 .62932 .26381 Mtetra
.825 .732 .763 r
.62932 .26381 .63603 .27529 .64906 .26293 .64227 .24812 Mtetra
.789 .678 .741 r
.64227 .24812 .64906 .26293 .66179 .24399 .6552 .23291 Mtetra
.658 .681 .861 r
.6552 .23291 .66179 .24399 .67504 .23689 .66861 .22819 Mtetra
.664 .741 .907 r
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.59 .709 .926 r
.70919 .21388 .71549 .22271 .72923 .21982 .723 .21133 Mtetra
.679 .758 .91 r
.723 .21133 .72923 .21982 .74293 .21521 .7367 .20597 Mtetra
.692 .744 .891 r
.7367 .20597 .74293 .21521 .7566 .20929 .75042 .20007 Mtetra
.678 .74 .897 r
.75042 .20007 .7566 .20929 .77036 .20375 .76424 .19466 Mtetra
.668 .74 .904 r
.76424 .19466 .77036 .20375 .78422 .19867 .77815 .18961 Mtetra
.665 .741 .907 r
.77815 .18961 .78422 .19867 .79816 .19373 .79214 .18464 Mtetra
.664 .741 .907 r
.79214 .18464 .79816 .19373 .81217 .18882 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .39321 .19268 .38582 Mtetra
.663 .741 .908 r
.19268 .38582 .20052 .39321 .21184 .38925 .20403 .38182 Mtetra
.661 .74 .908 r
.20403 .38182 .21184 .38925 .22319 .38538 .21542 .37786 Mtetra
.652 .736 .911 r
.21542 .37786 .22319 .38538 .23457 .38186 .22684 .37415 Mtetra
.635 .726 .914 r
.22684 .37415 .23457 .38186 .24595 .37882 .23826 .37092 Mtetra
.632 .721 .911 r
.23826 .37092 .24595 .37882 .25744 .37527 .24974 .36774 Mtetra
.695 .749 .893 r
.24974 .36774 .25744 .37527 .2692 .36899 .26144 .36259 Mtetra
.702 .783 .914 r
.26144 .36259 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.664 .741 .907 r
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.574 .711 .936 r
.30846 .34478 .316 .35249 .3272 .35859 .32018 .34291 Mtetra
.16 .306 .764 r
.32018 .34291 .3272 .35859 .33849 .36521 .3313 .35182 Mtetra
.387 .487 .839 r
.3313 .35182 .33849 .36521 .3503 .36483 .34288 .35539 Mtetra
.609 .682 .893 r
.34288 .35539 .3503 .36483 .36247 .3589 .35491 .35276 Mtetra
.738 .807 .907 r
.35491 .35276 .36247 .3589 .37481 .35026 .36721 .34601 Mtetra
.787 .868 .909 r
.36721 .34601 .37481 .35026 .3872 .34102 .37962 .33753 Mtetra
.794 .893 .915 r
.37962 .33753 .3872 .34102 .39959 .33218 .39207 .32881 Mtetra
.782 .899 .925 r
.39207 .32881 .39959 .33218 .41197 .32409 .40452 .32055 Mtetra
.762 .895 .936 r
.40452 .32055 .41197 .32409 .42435 .3168 .41697 .31299 Mtetra
.74 .886 .947 r
.41697 .31299 .42435 .3168 .43675 .31022 .42943 .30615 Mtetra
.717 .876 .956 r
.42943 .30615 .43675 .31022 .44914 .30556 .44191 .29998 Mtetra
.7 .826 .942 r
.44191 .29998 .44914 .30556 .46157 .30117 .45441 .29443 Mtetra
.682 .786 .929 r
.45441 .29443 .46157 .30117 .47407 .29677 .46696 .28943 Mtetra
.664 .765 .925 r
.46696 .28943 .47407 .29677 .48662 .29234 .47955 .28497 Mtetra
.645 .759 .932 r
.47955 .28497 .48662 .29234 .49923 .2879 .4922 .28104 Mtetra
.62 .767 .95 r
.4922 .28104 .49923 .2879 .5119 .28343 .5049 .27768 Mtetra
.579 .789 .979 r
.5049 .27768 .5119 .28343 .52462 .27925 .51767 .27493 Mtetra
.5 .807 1 r
.51767 .27493 .52462 .27925 .53742 .27699 .53052 .27288 Mtetra
.437 .786 .997 r
.53052 .27288 .53742 .27699 .5503 .27546 .54345 .27155 Mtetra
.368 .757 .988 r
.54345 .27155 .5503 .27546 .56327 .27476 .55648 .27095 Mtetra
.321 .735 .978 r
.55648 .27095 .56327 .27476 .57635 .27482 .56961 .27081 Mtetra
.35 .745 .985 r
.56961 .27081 .57635 .27482 .58955 .27531 .58283 .27046 Mtetra
.512 .799 .998 r
.58283 .27046 .58955 .27531 .60283 .27519 .59612 .26835 Mtetra
.713 .808 .924 r
.59612 .26835 .60283 .27519 .61613 .27234 .60937 .26206 Mtetra
.804 .748 .801 r
.60937 .26206 .61613 .27234 .62932 .26381 .62248 .24943 Mtetra
.818 .693 .727 r
.62248 .24943 .62932 .26381 .64227 .24812 .63538 .23131 Mtetra
.676 .605 .768 r
.63538 .23131 .64227 .24812 .6552 .23291 .64867 .22417 Mtetra
.664 .741 .907 r
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.626 .725 .918 r
.6892 .20981 .6956 .21867 .70919 .21388 .70291 .20618 Mtetra
.627 .76 .942 r
.70291 .20618 .70919 .21388 .723 .21133 .71669 .2024 Mtetra
.69 .752 .899 r
.71669 .2024 .723 .21133 .7367 .20597 .7304 .19657 Mtetra
.687 .74 .891 r
.7304 .19657 .7367 .20597 .75042 .20007 .74418 .19079 Mtetra
.673 .739 .899 r
.74418 .19079 .75042 .20007 .76424 .19466 .75806 .18551 Mtetra
.666 .74 .905 r
.75806 .18551 .76424 .19466 .77815 .18961 .77203 .18046 Mtetra
.664 .741 .907 r
.77203 .18046 .77815 .18961 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .38182 .19615 .37433 Mtetra
.662 .74 .908 r
.19615 .37433 .20403 .38182 .21542 .37786 .20757 .37031 Mtetra
.657 .738 .909 r
.20757 .37031 .21542 .37786 .22684 .37415 .21903 .36643 Mtetra
.643 .73 .912 r
.21903 .36643 .22684 .37415 .23826 .37092 .23051 .36294 Mtetra
.629 .72 .912 r
.23051 .36294 .23826 .37092 .24974 .36774 .242 .35982 Mtetra
.658 .731 .903 r
.242 .35982 .24974 .36774 .26144 .36259 .25363 .35583 Mtetra
.726 .778 .895 r
.25363 .35583 .26144 .36259 .27319 .35728 .26549 .34961 Mtetra
.664 .741 .907 r
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32018 .34291 .31276 .33276 Mtetra
.364 .547 .9 r
.31276 .33276 .32018 .34291 .3313 .35182 .32427 .33543 Mtetra
.278 .371 .78 r
.32427 .33543 .3313 .35182 .34288 .35539 .33563 .34243 Mtetra
.467 .541 .849 r
.33563 .34243 .34288 .35539 .35491 .35276 .34742 .34402 Mtetra
.638 .713 .901 r
.34742 .34402 .35491 .35276 .36721 .34601 .35959 .34047 Mtetra
.737 .828 .921 r
.35959 .34047 .36721 .34601 .37962 .33753 .37197 .33377 Mtetra
.773 .887 .927 r
.37197 .33377 .37962 .33753 .39207 .32881 .38444 .32582 Mtetra
.775 .911 .933 r
.38444 .32582 .39207 .32881 .40452 .32055 .39694 .31774 Mtetra
.76 .918 .942 r
.39694 .31774 .40452 .32055 .41697 .31299 .40946 .31008 Mtetra
.738 .915 .953 r
.40946 .31008 .41697 .31299 .42943 .30615 .42199 .30305 Mtetra
.713 .908 .963 r
.42199 .30305 .42943 .30615 .44191 .29998 .43453 .29668 Mtetra
.687 .898 .973 r
.43453 .29668 .44191 .29998 .45441 .29443 .4471 .29097 Mtetra
.66 .888 .981 r
.4471 .29097 .45441 .29443 .46696 .28943 .45971 .28587 Mtetra
.629 .878 .988 r
.45971 .28587 .46696 .28943 .47955 .28497 .47236 .28137 Mtetra
.595 .867 .994 r
.47236 .28137 .47955 .28497 .4922 .28104 .48505 .27748 Mtetra
.553 .854 .998 r
.48505 .27748 .4922 .28104 .5049 .27768 .49781 .27421 Mtetra
.503 .837 .998 r
.49781 .27421 .5049 .27768 .51767 .27493 .51064 .2716 Mtetra
.444 .815 .993 r
.51064 .2716 .51767 .27493 .53052 .27288 .52354 .26967 Mtetra
.383 .788 .983 r
.52354 .26967 .53052 .27288 .54345 .27155 .53652 .26837 Mtetra
.342 .766 .974 r
.53652 .26837 .54345 .27155 .55648 .27095 .5496 .26751 Mtetra
.365 .773 .982 r
.5496 .26751 .55648 .27095 .56961 .27081 .56278 .26654 Mtetra
.499 .814 1 r
.56278 .26654 .56961 .27081 .58283 .27046 .57602 .2643 Mtetra
.684 .821 .949 r
.57602 .2643 .58283 .27046 .59612 .26835 .58929 .25887 Mtetra
.785 .76 .83 r
.58929 .25887 .59612 .26835 .60937 .26206 .60248 .2482 Mtetra
.807 .696 .743 r
.60248 .2482 .60937 .26206 .62248 .24943 .61551 .23198 Mtetra
.734 .628 .74 r
.61551 .23198 .62248 .24943 .63538 .23131 .62866 .22014 Mtetra
.658 .682 .862 r
.62866 .22014 .63538 .23131 .64867 .22417 .64209 .21536 Mtetra
.664 .741 .907 r
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.595 .712 .925 r
.68274 .20086 .6892 .20981 .70291 .20618 .69655 .19811 Mtetra
.669 .768 .924 r
.69655 .19811 .70291 .20618 .71669 .2024 .7103 .19305 Mtetra
.691 .744 .891 r
.7103 .19305 .71669 .2024 .7304 .19657 .72405 .18708 Mtetra
.681 .737 .893 r
.72405 .18708 .7304 .19657 .74418 .19079 .7379 .18149 Mtetra
.67 .738 .902 r
.7379 .18149 .74418 .19079 .75806 .18551 .75183 .17629 Mtetra
.665 .74 .906 r
.75183 .17629 .75806 .18551 .77203 .18046 .76585 .17125 Mtetra
.664 .741 .907 r
.76585 .17125 .77203 .18046 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37433 .18821 .36679 Mtetra
.663 .74 .908 r
.18821 .36679 .19615 .37433 .20757 .37031 .19967 .36271 Mtetra
.66 .739 .908 r
.19967 .36271 .20757 .37031 .21903 .36643 .21116 .3587 Mtetra
.65 .734 .91 r
.21116 .3587 .21903 .36643 .23051 .36294 .22269 .35495 Mtetra
.634 .723 .912 r
.22269 .35495 .23051 .36294 .242 .35982 .23422 .35166 Mtetra
.636 .72 .908 r
.23422 .35166 .242 .35982 .25363 .35583 .24582 .34829 Mtetra
.695 .753 .896 r
.24582 .34829 .25363 .35583 .26549 .34961 .25763 .34305 Mtetra
.703 .783 .914 r
.25763 .34305 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.664 .741 .907 r
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32427 .33543 .31711 .32058 Mtetra
.342 .436 .813 r
.31711 .32058 .32427 .33543 .33563 .34243 .32857 .32549 Mtetra
.351 .411 .783 r
.32857 .32549 .33563 .34243 .34742 .34402 .34012 .33101 Mtetra
.498 .559 .848 r
.34012 .33101 .34742 .34402 .35959 .34047 .35206 .33174 Mtetra
.634 .714 .905 r
.35206 .33174 .35959 .34047 .37197 .33377 .36432 .32825 Mtetra
.717 .829 .934 r
.36432 .32825 .37197 .33377 .38444 .32582 .37675 .32219 Mtetra
.747 .892 .944 r
.37675 .32219 .38444 .32582 .39694 .31774 .38928 .31504 Mtetra
.745 .921 .95 r
.38928 .31504 .39694 .31774 .40946 .31008 .40184 .30774 Mtetra
.726 .931 .957 r
.40184 .30774 .40946 .31008 .42199 .30305 .41443 .30076 Mtetra
.7 .929 .966 r
.41443 .30076 .42199 .30305 .43453 .29668 .42704 .29434 Mtetra
.67 .923 .974 r
.42704 .29434 .43453 .29668 .4471 .29097 .43968 .28853 Mtetra
.636 .913 .981 r
.43968 .28853 .4471 .29097 .45971 .28587 .45234 .28336 Mtetra
.598 .9 .986 r
.45234 .28336 .45971 .28587 .47236 .28137 .46505 .27883 Mtetra
.555 .885 .989 r
.46505 .27883 .47236 .28137 .48505 .27748 .47781 .27494 Mtetra
.506 .865 .987 r
.47781 .27494 .48505 .27748 .49781 .27421 .49063 .2717 Mtetra
.453 .843 .982 r
.49063 .2717 .49781 .27421 .51064 .2716 .50351 .26908 Mtetra
.405 .818 .975 r
.50351 .26908 .51064 .2716 .52354 .26967 .51647 .26702 Mtetra
.381 .803 .972 r
.51647 .26702 .52354 .26967 .53652 .26837 .52952 .2653 Mtetra
.416 .811 .986 r
.52952 .2653 .53652 .26837 .5496 .26751 .54265 .26343 Mtetra
.537 .837 .999 r
.54265 .26343 .5496 .26751 .56278 .26654 .55585 .26046 Mtetra
.688 .825 .949 r
.55585 .26046 .56278 .26654 .57602 .2643 .5691 .2549 Mtetra
.773 .759 .84 r
.5691 .2549 .57602 .2643 .58929 .25887 .58232 .24504 Mtetra
.794 .692 .753 r
.58232 .24504 .58929 .25887 .60248 .2482 .59545 .23027 Mtetra
.755 .634 .726 r
.59545 .23027 .60248 .2482 .61551 .23198 .60857 .21609 Mtetra
.64 .599 .792 r
.60857 .21609 .61551 .23198 .62866 .22014 .62197 .21129 Mtetra
.664 .741 .907 r
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.626 .725 .918 r
.66257 .19674 .66913 .20572 .68274 .20086 .67629 .19306 Mtetra
.627 .761 .942 r
.67629 .19306 .68274 .20086 .69655 .19811 .69008 .18921 Mtetra
.688 .755 .903 r
.69008 .18921 .69655 .19811 .7103 .19305 .70384 .18343 Mtetra
.687 .737 .889 r
.70384 .18343 .7103 .19305 .72405 .18708 .71765 .17756 Mtetra
.675 .736 .896 r
.71765 .17756 .72405 .18708 .7379 .18149 .73156 .17216 Mtetra
.667 .739 .904 r
.73156 .17216 .7379 .18149 .75183 .17629 .74555 .16702 Mtetra
.665 .74 .907 r
.74555 .16702 .75183 .17629 .76585 .17125 .75962 .16195 Mtetra
.664 .741 .907 r
.75962 .16195 .76585 .17125 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36271 .19169 .35506 Mtetra
.662 .74 .908 r
.19169 .35506 .19967 .36271 .21116 .3587 .20322 .35096 Mtetra
.656 .737 .909 r
.20322 .35096 .21116 .3587 .22269 .35495 .21479 .347 Mtetra
.643 .728 .91 r
.21479 .347 .22269 .35495 .23422 .35166 .22638 .34341 Mtetra
.631 .718 .909 r
.22638 .34341 .23422 .35166 .24582 .34829 .23799 .34015 Mtetra
.653 .728 .904 r
.23799 .34015 .24582 .34829 .25763 .34305 .24972 .33623 Mtetra
.728 .781 .895 r
.24972 .33623 .25763 .34305 .2695 .33765 .26171 .32981 Mtetra
.664 .741 .907 r
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32857 .32549 .32152 .30825 Mtetra
.378 .423 .782 r
.32152 .30825 .32857 .32549 .34012 .33101 .33308 .31312 Mtetra
.394 .426 .775 r
.33308 .31312 .34012 .33101 .35206 .33174 .34478 .31779 Mtetra
.501 .546 .834 r
.34478 .31779 .35206 .33174 .36432 .32825 .35681 .31854 Mtetra
.607 .682 .895 r
.35681 .31854 .36432 .32825 .37675 .32219 .36911 .31581 Mtetra
.68 .798 .938 r
.36911 .31581 .37675 .32219 .38928 .31504 .38158 .31084 Mtetra
.71 .873 .958 r
.38158 .31084 .38928 .31504 .40184 .30774 .39415 .30479 Mtetra
.706 .912 .966 r
.39415 .30479 .40184 .30774 .41443 .30076 .40678 .29847 Mtetra
.684 .927 .97 r
.40678 .29847 .41443 .30076 .42704 .29434 .41944 .29234 Mtetra
.651 .928 .973 r
.41944 .29234 .42704 .29434 .43968 .28853 .43214 .28664 Mtetra
.613 .92 .975 r
.43214 .28664 .43968 .28853 .45234 .28336 .44487 .28149 Mtetra
.571 .907 .976 r
.44487 .28149 .45234 .28336 .46505 .27883 .45765 .27693 Mtetra
.528 .89 .976 r
.45765 .27693 .46505 .27883 .47781 .27494 .47047 .27296 Mtetra
.488 .871 .974 r
.47047 .27296 .47781 .27494 .49063 .2717 .48335 .26953 Mtetra
.46 .855 .975 r
.48335 .26953 .49063 .2717 .50351 .26908 .4963 .26655 Mtetra
.461 .847 .982 r
.4963 .26655 .50351 .26908 .51647 .26702 .50932 .26376 Mtetra
.514 .852 .996 r
.50932 .26376 .51647 .26702 .52952 .2653 .52242 .2607 Mtetra
.615 .85 .988 r
.52242 .2607 .52952 .2653 .54265 .26343 .5356 .25656 Mtetra
.715 .809 .923 r
.5356 .25656 .54265 .26343 .55585 .26046 .54882 .25014 Mtetra
.766 .739 .827 r
.54882 .25014 .55585 .26046 .5691 .2549 .56205 .24019 Mtetra
.778 .676 .751 r
.56205 .24019 .5691 .2549 .58232 .24504 .57523 .22623 Mtetra
.749 .624 .721 r
.57523 .22623 .58232 .24504 .59545 .23027 .58839 .21203 Mtetra
.631 .568 .765 r
.58839 .21203 .59545 .23027 .60857 .21609 .60178 .20721 Mtetra
.664 .741 .907 r
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.591 .71 .926 r
.65595 .18768 .66257 .19674 .67629 .19306 .66976 .18496 Mtetra
.674 .772 .924 r
.66976 .18496 .67629 .19306 .69008 .18921 .68353 .17967 Mtetra
.69 .741 .891 r
.68353 .17967 .69008 .18921 .70384 .18343 .69733 .1737 Mtetra
.68 .734 .891 r
.69733 .1737 .70384 .18343 .71765 .17756 .7112 .16806 Mtetra
.67 .737 .9 r
.7112 .16806 .71765 .17756 .73156 .17216 .72517 .16279 Mtetra
.665 .739 .905 r
.72517 .16279 .73156 .17216 .74555 .16702 .73921 .15767 Mtetra
.664 .74 .907 r
.73921 .15767 .74555 .16702 .75962 .16195 .75333 .15257 Mtetra
.664 .741 .907 r
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.14925 .35983 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35506 .18365 .34736 Mtetra
.663 .74 .907 r
.18365 .34736 .19169 .35506 .20322 .35096 .19522 .34319 Mtetra
.66 .739 .908 r
.19522 .34319 .20322 .35096 .21479 .347 .20683 .33908 Mtetra
.652 .733 .909 r
.20683 .33908 .21479 .347 .22638 .34341 .21847 .3352 Mtetra
.638 .723 .909 r
.21847 .3352 .22638 .34341 .23799 .34015 .23012 .33171 Mtetra
.634 .716 .906 r
.23012 .33171 .23799 .34015 .24972 .33623 .24183 .32831 Mtetra
.672 .742 .903 r
.24183 .32831 .24972 .33623 .26171 .32981 .25369 .32375 Mtetra
.724 .805 .915 r
.25369 .32375 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.664 .741 .907 r
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33308 .31312 .32598 .29575 Mtetra
.459 .472 .785 r
.32598 .29575 .33308 .31312 .34478 .31779 .33778 .29831 Mtetra
.422 .427 .759 r
.33778 .29831 .34478 .31779 .35681 .31854 .34959 .3025 Mtetra
.493 .511 .804 r
.34959 .3025 .35681 .31854 .36911 .31581 .36169 .30375 Mtetra
.57 .617 .861 r
.36169 .30375 .36911 .31581 .38158 .31084 .37402 .3022 Mtetra
.632 .722 .913 r
.37402 .3022 .38158 .31084 .39415 .30479 .38651 .29865 Mtetra
.666 .806 .95 r
.38651 .29865 .39415 .30479 .40678 .29847 .39912 .29397 Mtetra
.672 .86 .971 r
.39912 .29397 .40678 .29847 .41944 .29234 .4118 .28883 Mtetra
.657 .889 .981 r
.4118 .28883 .41944 .29234 .43214 .28664 .42454 .28367 Mtetra
.632 .899 .985 r
.42454 .28367 .43214 .28664 .44487 .28149 .43733 .27874 Mtetra
.604 .897 .988 r
.43733 .27874 .44487 .28149 .45765 .27693 .45016 .27414 Mtetra
.582 .89 .99 r
.45016 .27414 .45765 .27693 .47047 .27296 .46305 .26988 Mtetra
.575 .88 .993 r
.46305 .26988 .47047 .27296 .48335 .26953 .476 .26584 Mtetra
.593 .869 .994 r
.476 .26584 .48335 .26953 .4963 .26655 .48902 .26179 Mtetra
.637 .851 .982 r
.48902 .26179 .4963 .26655 .50932 .26376 .50211 .25727 Mtetra
.692 .813 .94 r
.50211 .25727 .50932 .26376 .52242 .2607 .51526 .25162 Mtetra
.735 .756 .869 r
.51526 .25162 .52242 .2607 .5356 .25656 .52847 .24393 Mtetra
.755 .695 .795 r
.52847 .24393 .5356 .25656 .54882 .25014 .5417 .2334 Mtetra
.758 .646 .738 r
.5417 .2334 .54882 .25014 .56205 .24019 .55491 .21986 Mtetra
.717 .596 .721 r
.55491 .21986 .56205 .24019 .57523 .22623 .56814 .20795 Mtetra
.631 .568 .766 r
.56814 .20795 .57523 .22623 .58839 .21203 .5815 .20311 Mtetra
.664 .741 .907 r
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.603 .716 .924 r
.63558 .1835 .64231 .19259 .65595 .18768 .64935 .18043 Mtetra
.653 .791 .948 r
.64935 .18043 .65595 .18768 .66976 .18496 .66313 .17572 Mtetra
.689 .749 .898 r
.66313 .17572 .66976 .18496 .68353 .17967 .67691 .16982 Mtetra
.684 .733 .888 r
.67691 .16982 .68353 .17967 .69733 .1737 .69076 .164 Mtetra
.673 .734 .896 r
.69076 .164 .69733 .1737 .7112 .16806 .7047 .15858 Mtetra
.667 .738 .903 r
.7047 .15858 .7112 .16806 .72517 .16279 .71872 .15338 Mtetra
.665 .74 .906 r
.71872 .15338 .72517 .16279 .73921 .15767 .73282 .14825 Mtetra
.664 .741 .907 r
.73282 .14825 .73921 .15767 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.76122 .13794 .76752 .14745 .78177 .14231 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34319 .18714 .33538 Mtetra
.662 .74 .908 r
.18714 .33538 .19522 .34319 .20683 .33908 .19879 .33117 Mtetra
.658 .737 .908 r
.19879 .33117 .20683 .33908 .21847 .3352 .21047 .32708 Mtetra
.648 .73 .908 r
.21047 .32708 .21847 .3352 .23012 .33171 .22218 .32325 Mtetra
.636 .718 .907 r
.22218 .32325 .23012 .33171 .24183 .32831 .23392 .31978 Mtetra
.64 .718 .904 r
.23392 .31978 .24183 .32831 .25369 .32375 .24573 .31616 Mtetra
.686 .757 .905 r
.24573 .31616 .25369 .32375 .26573 .31759 .25771 .31111 Mtetra
.713 .794 .915 r
.25771 .31111 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.664 .741 .907 r
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .33778 .29831 .33051 .28309 Mtetra
.586 .572 .805 r
.33051 .28309 .33778 .29831 .34959 .3025 .34267 .28098 Mtetra
.451 .426 .74 r
.34267 .28098 .34959 .3025 .36169 .30375 .35461 .28453 Mtetra
.492 .474 .765 r
.35461 .28453 .36169 .30375 .37402 .3022 .36676 .28619 Mtetra
.541 .54 .803 r
.36676 .28619 .37402 .3022 .38651 .29865 .37911 .28574 Mtetra
.587 .613 .845 r
.37911 .28574 .38651 .29865 .39912 .29397 .39163 .28357 Mtetra
.623 .68 .883 r
.39163 .28357 .39912 .29397 .4118 .28883 .40427 .28022 Mtetra
.645 .732 .913 r
.40427 .28022 .4118 .28883 .42454 .28367 .41701 .27617 Mtetra
.656 .768 .932 r
.41701 .27617 .42454 .28367 .43733 .27874 .42982 .27174 Mtetra
.662 .785 .94 r
.42982 .27174 .43733 .27874 .45016 .27414 .4427 .2671 Mtetra
.668 .787 .938 r
.4427 .2671 .45016 .27414 .46305 .26988 .45564 .26225 Mtetra
.68 .775 .922 r
.45564 .26225 .46305 .26988 .476 .26584 .46866 .25703 Mtetra
.696 .749 .893 r
.46866 .25703 .476 .26584 .48902 .26179 .48174 .2511 Mtetra
.713 .713 .849 r
.48174 .2511 .48902 .26179 .50211 .25727 .49488 .24397 Mtetra
.725 .673 .799 r
.49488 .24397 .50211 .25727 .51526 .25162 .50808 .23508 Mtetra
.731 .636 .753 r
.50808 .23508 .51526 .25162 .52847 .24393 .5213 .22406 Mtetra
.73 .607 .72 r
.5213 .22406 .52847 .24393 .5417 .2334 .53453 .2111 Mtetra
.651 .546 .723 r
.53453 .2111 .5417 .2334 .55491 .21986 .5478 .20385 Mtetra
.639 .599 .792 r
.5478 .20385 .55491 .21986 .56814 .20795 .56114 .19899 Mtetra
.664 .741 .907 r
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.615 .721 .921 r
.61514 .1793 .62196 .18843 .63558 .1835 .62886 .17587 Mtetra
.639 .775 .946 r
.62886 .17587 .63558 .1835 .64935 .18043 .64262 .17159 Mtetra
.685 .759 .908 r
.64262 .17159 .64935 .18043 .66313 .17572 .6564 .16584 Mtetra
.685 .734 .888 r
.6564 .16584 .66313 .17572 .67691 .16982 .67024 .15993 Mtetra
.676 .731 .892 r
.67024 .15993 .67691 .16982 .69076 .164 .68415 .15437 Mtetra
.668 .736 .9 r
.68415 .15437 .69076 .164 .7047 .15858 .69815 .14909 Mtetra
.665 .739 .905 r
.69815 .14909 .7047 .15858 .71872 .15338 .71222 .14391 Mtetra
.664 .74 .907 r
.71222 .14391 .71872 .15338 .73282 .14825 .72636 .13874 Mtetra
.664 .741 .907 r
.72636 .13874 .73282 .14825 .74698 .14311 .74058 .13356 Mtetra
.74058 .13356 .74698 .14311 .76122 .13794 .75486 .12835 Mtetra
.75486 .12835 .76122 .13794 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33178 Mtetra
.16737 .33178 .17554 .3396 .18714 .33538 .17899 .32751 Mtetra
.663 .741 .907 r
.17899 .32751 .18714 .33538 .19879 .33117 .19067 .32324 Mtetra
.662 .739 .908 r
.19067 .32324 .19879 .33117 .21047 .32708 .2024 .31901 Mtetra
.656 .735 .908 r
.2024 .31901 .21047 .32708 .22218 .32325 .21416 .31491 Mtetra
.646 .726 .907 r
.21416 .31491 .22218 .32325 .23392 .31978 .22596 .31111 Mtetra
.636 .715 .905 r
.22596 .31111 .23392 .31978 .24573 .31616 .23778 .30758 Mtetra
.645 .721 .904 r
.23778 .30758 .24573 .31616 .25771 .31111 .24968 .30377 Mtetra
.692 .768 .91 r
.24968 .30377 .25771 .31111 .26981 .30522 .26177 .29848 Mtetra
.708 .789 .914 r
.26177 .29848 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.664 .741 .907 r
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34267 .28098 .33509 .27026 Mtetra
.657 .683 .863 r
.33509 .27026 .34267 .28098 .35461 .28453 .34749 .26571 Mtetra
.581 .529 .762 r
.34749 .26571 .35461 .28453 .36676 .28619 .35982 .26355 Mtetra
.509 .454 .731 r
.35982 .26355 .36676 .28619 .37911 .28574 .37206 .26477 Mtetra
.537 .485 .746 r
.37206 .26477 .37911 .28574 .39163 .28357 .38446 .26463 Mtetra
.567 .523 .765 r
.38446 .26463 .39163 .28357 .40427 .28022 .39702 .26306 Mtetra
.595 .558 .783 r
.39702 .26306 .40427 .28022 .41701 .27617 .40971 .26029 Mtetra
.62 .587 .795 r
.40971 .26029 .41701 .27617 .42982 .27174 .42251 .25649 Mtetra
.64 .606 .799 r
.42251 .25649 .42982 .27174 .4427 .2671 .4354 .25181 Mtetra
.657 .614 .795 r
.4354 .25181 .4427 .2671 .45564 .26225 .44837 .24623 Mtetra
.671 .613 .781 r
.44837 .24623 .45564 .26225 .46866 .25703 .46142 .23963 Mtetra
.683 .604 .761 r
.46142 .23963 .46866 .25703 .48174 .2511 .47454 .2318 Mtetra
.692 .591 .738 r
.47454 .2318 .48174 .2511 .49488 .24397 .48771 .22253 Mtetra
.697 .578 .718 r
.48771 .22253 .49488 .24397 .50808 .23508 .50092 .21187 Mtetra
.648 .538 .716 r
.50092 .21187 .50808 .23508 .5213 .22406 .51413 .2046 Mtetra
.626 .555 .754 r
.51413 .2046 .5213 .22406 .53453 .2111 .52738 .19974 Mtetra
.657 .683 .863 r
.52738 .19974 .53453 .2111 .5478 .20385 .54069 .19486 Mtetra
.664 .741 .907 r
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.62 .723 .92 r
.5946 .17508 .60154 .18426 .61514 .1793 .60829 .17149 Mtetra
.633 .768 .944 r
.60829 .17149 .61514 .1793 .62886 .17587 .62203 .16736 Mtetra
.682 .768 .916 r
.62203 .16736 .62886 .17587 .64262 .17159 .6358 .16173 Mtetra
.685 .735 .889 r
.6358 .16173 .64262 .17159 .6564 .16584 .64962 .1558 Mtetra
.677 .729 .889 r
.64962 .1558 .6564 .16584 .67024 .15993 .66351 .15014 Mtetra
.67 .734 .898 r
.66351 .15014 .67024 .15993 .68415 .15437 .67748 .14478 Mtetra
.666 .738 .904 r
.67748 .14478 .68415 .15437 .69815 .14909 .69153 .13955 Mtetra
.664 .74 .906 r
.69153 .13955 .69815 .14909 .71222 .14391 .70565 .13436 Mtetra
.664 .741 .907 r
.70565 .13436 .71222 .14391 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16737 .33178 .15912 .32389 Mtetra
.15912 .32389 .16737 .33178 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32324 .18249 .31527 Mtetra
.663 .74 .907 r
.18249 .31527 .19067 .32324 .2024 .31901 .19425 .31095 Mtetra
.661 .739 .907 r
.19425 .31095 .2024 .31901 .21416 .31491 .20606 .30668 Mtetra
.655 .733 .907 r
.20606 .30668 .21416 .31491 .22596 .31111 .21791 .30257 Mtetra
.645 .723 .905 r
.21791 .30257 .22596 .31111 .23778 .30758 .22978 .29873 Mtetra
.637 .713 .903 r
.22978 .29873 .23778 .30758 .24968 .30377 .2417 .29511 Mtetra
.647 .723 .904 r
.2417 .29511 .24968 .30377 .26177 .29848 .2537 .29119 Mtetra
.688 .771 .915 r
.2537 .29119 .26177 .29848 .27395 .29269 .26586 .28599 Mtetra
.713 .794 .915 r
.26586 .28599 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.664 .741 .907 r
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35982 .26355 .35223 .25265 Mtetra
.657 .682 .862 r
.35223 .25265 .35982 .26355 .37206 .26477 .36478 .24802 Mtetra
.634 .582 .779 r
.36478 .24802 .37206 .26477 .38446 .26463 .37739 .24337 Mtetra
.617 .531 .735 r
.37739 .24337 .38446 .26463 .39702 .26306 .39006 .2388 Mtetra
.575 .485 .716 r
.39006 .2388 .39702 .26306 .40971 .26029 .4027 .23642 Mtetra
.594 .5 .718 r
.4027 .23642 .40971 .26029 .42251 .25649 .41546 .23287 Mtetra
.612 .513 .718 r
.41546 .23287 .42251 .25649 .4354 .25181 .42833 .22814 Mtetra
.629 .523 .715 r
.42833 .22814 .4354 .25181 .44837 .24623 .44129 .2222 Mtetra
.643 .53 .71 r
.44129 .2222 .44837 .24623 .46142 .23963 .45433 .21509 Mtetra
.612 .508 .712 r
.45433 .21509 .46142 .23963 .47454 .2318 .46737 .21018 Mtetra
.619 .532 .735 r
.46737 .21018 .47454 .2318 .48771 .22253 .48048 .20535 Mtetra
.634 .582 .779 r
.48048 .20535 .48771 .22253 .50092 .21187 .49364 .20049 Mtetra
.657 .682 .862 r
.49364 .20049 .50092 .21187 .51413 .2046 .50687 .19561 Mtetra
.664 .741 .907 r
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.614 .721 .922 r
.57399 .17085 .58103 .18006 .5946 .17508 .58764 .16739 Mtetra
.638 .774 .946 r
.58764 .16739 .5946 .17508 .60829 .17149 .60135 .16309 Mtetra
.681 .771 .919 r
.60135 .16309 .60829 .17149 .62203 .16736 .61511 .15749 Mtetra
.685 .736 .89 r
.61511 .15749 .62203 .16736 .6358 .16173 .62891 .15157 Mtetra
.677 .728 .888 r
.62891 .15157 .6358 .16173 .64962 .1558 .64278 .14588 Mtetra
.671 .732 .896 r
.64278 .14588 .64962 .1558 .66351 .15014 .65673 .14045 Mtetra
.666 .737 .903 r
.65673 .14045 .66351 .15014 .67748 .14478 .67076 .13518 Mtetra
.664 .74 .906 r
.67076 .13518 .67748 .14478 .69153 .13955 .68486 .12996 Mtetra
.664 .741 .907 r
.68486 .12996 .69153 .13955 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32883 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .3116 Mtetra
.16249 .3116 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31095 .18603 .30287 Mtetra
.663 .74 .907 r
.18603 .30287 .19425 .31095 .20606 .30668 .19788 .2985 Mtetra
.661 .738 .907 r
.19788 .2985 .20606 .30668 .21791 .30257 .20977 .29419 Mtetra
.655 .732 .906 r
.20977 .29419 .21791 .30257 .22978 .29873 .22171 .29002 Mtetra
.646 .722 .904 r
.22171 .29002 .22978 .29873 .2417 .29511 .23367 .2861 Mtetra
.639 .713 .901 r
.23367 .2861 .2417 .29511 .2537 .29119 .24568 .28237 Mtetra
.645 .721 .903 r
.24568 .28237 .2537 .29119 .26586 .28599 .25776 .27842 Mtetra
.677 .764 .916 r
.25776 .27842 .26586 .28599 .27813 .27998 .26998 .27352 Mtetra
.724 .805 .915 r
.26998 .27352 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.664 .741 .907 r
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39006 .2388 .38239 .23001 Mtetra
.664 .738 .905 r
.38239 .23001 .39006 .2388 .4027 .23642 .39516 .22527 Mtetra
.657 .683 .863 r
.39516 .22527 .4027 .23642 .41546 .23287 .40799 .22051 Mtetra
.652 .658 .843 r
.40799 .22051 .41546 .23287 .42833 .22814 .42088 .21573 Mtetra
.42088 .21573 .42833 .22814 .44129 .2222 .43384 .21092 Mtetra
.657 .683 .863 r
.43384 .21092 .44129 .2222 .45433 .21509 .44685 .20609 Mtetra
.664 .738 .905 r
.44685 .20609 .45433 .21509 .46737 .21018 .45993 .20124 Mtetra
.664 .741 .907 r
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.602 .716 .925 r
.55328 .1666 .56043 .17585 .57399 .17085 .56691 .16346 Mtetra
.65 .789 .948 r
.56691 .16346 .57399 .17085 .58764 .16739 .58059 .15878 Mtetra
.681 .766 .915 r
.58059 .15878 .58764 .16739 .60135 .16309 .59432 .15312 Mtetra
.683 .734 .889 r
.59432 .15312 .60135 .16309 .61511 .15749 .60811 .14724 Mtetra
.677 .726 .887 r
.60811 .14724 .61511 .15749 .62891 .15157 .62196 .14154 Mtetra
.67 .73 .894 r
.62196 .14154 .62891 .15157 .64278 .14588 .63589 .13609 Mtetra
.666 .735 .902 r
.63589 .13609 .64278 .14588 .65673 .14045 .6499 .13079 Mtetra
.665 .739 .905 r
.6499 .13079 .65673 .14045 .67076 .13518 .66398 .12554 Mtetra
.664 .74 .907 r
.66398 .12554 .67076 .13518 .68486 .12996 .67813 .12028 Mtetra
.664 .741 .907 r
.67813 .12028 .68486 .12996 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.70664 .1097 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09364 Mtetra
.10759 .32091 .11606 .32883 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .3116 .15414 .30354 Mtetra
.15414 .30354 .16249 .3116 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30287 .17774 .29473 Mtetra
.17774 .29473 .18603 .30287 .19788 .2985 .18962 .2903 Mtetra
.663 .74 .907 r
.18962 .2903 .19788 .2985 .20977 .29419 .20155 .28588 Mtetra
.661 .737 .907 r
.20155 .28588 .20977 .29419 .22171 .29002 .21353 .2815 Mtetra
.655 .731 .905 r
.21353 .2815 .22171 .29002 .23367 .2861 .22556 .27726 Mtetra
.648 .722 .902 r
.22556 .27726 .23367 .2861 .24568 .28237 .23762 .27321 Mtetra
.641 .713 .899 r
.23762 .27321 .24568 .28237 .25776 .27842 .24972 .26935 Mtetra
.643 .717 .901 r
.24972 .26935 .25776 .27842 .26998 .27352 .26189 .2654 Mtetra
.663 .748 .914 r
.26189 .2654 .26998 .27352 .28238 .26711 .27417 .26087 Mtetra
.698 .81 .935 r
.27417 .26087 .28238 .26711 .29467 .26255 .28658 .25528 Mtetra
.703 .783 .914 r
.28658 .25528 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.664 .741 .907 r
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.625 .726 .919 r
.51898 .16738 .52629 .17662 .53975 .17162 .5325 .16356 Mtetra
.63 .761 .942 r
.5325 .16356 .53975 .17162 .55328 .1666 .54609 .1595 Mtetra
.665 .803 .949 r
.54609 .1595 .55328 .1666 .56691 .16346 .55974 .15436 Mtetra
.682 .755 .906 r
.55974 .15436 .56691 .16346 .58059 .15878 .57345 .14863 Mtetra
.681 .73 .887 r
.57345 .14863 .58059 .15878 .59432 .15312 .58722 .1428 Mtetra
.675 .725 .887 r
.58722 .1428 .59432 .15312 .60811 .14724 .60106 .13715 Mtetra
.67 .729 .894 r
.60106 .13715 .60811 .14724 .62196 .14154 .61497 .1317 Mtetra
.666 .735 .901 r
.61497 .1317 .62196 .14154 .63589 .13609 .62895 .12638 Mtetra
.665 .739 .905 r
.62895 .12638 .63589 .13609 .6499 .13079 .643 .1211 Mtetra
.664 .74 .907 r
.643 .1211 .6499 .13079 .66398 .12554 .65713 .11582 Mtetra
.664 .741 .907 r
.65713 .11582 .66398 .12554 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .1097 .69994 .09984 Mtetra
.69994 .09984 .70664 .1097 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09364 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20155 .28588 .19326 .27757 Mtetra
.663 .74 .907 r
.19326 .27757 .20155 .28588 .21353 .2815 .20528 .27309 Mtetra
.661 .737 .906 r
.20528 .27309 .21353 .2815 .22556 .27726 .21735 .26863 Mtetra
.657 .732 .905 r
.21735 .26863 .22556 .27726 .23762 .27321 .22947 .26428 Mtetra
.651 .723 .902 r
.22947 .26428 .23762 .27321 .24972 .26935 .24162 .26008 Mtetra
.645 .714 .898 r
.24162 .26008 .24972 .26935 .26189 .2654 .25383 .25605 Mtetra
.643 .712 .898 r
.25383 .25605 .26189 .2654 .27417 .26087 .26609 .25204 Mtetra
.651 .729 .906 r
.26609 .25204 .27417 .26087 .28658 .25528 .27843 .24779 Mtetra
.67 .771 .926 r
.27843 .24779 .28658 .25528 .29907 .24945 .29088 .24297 Mtetra
.695 .807 .934 r
.29088 .24297 .29907 .24945 .31152 .2448 .30343 .23737 Mtetra
.702 .783 .914 r
.30343 .23737 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.664 .741 .907 r
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.625 .726 .919 r
.48471 .16815 .49217 .17739 .50554 .17239 .49812 .16433 Mtetra
.633 .762 .941 r
.49812 .16433 .50554 .17239 .51898 .16738 .51161 .16019 Mtetra
.657 .798 .95 r
.51161 .16019 .51898 .16738 .5325 .16356 .52517 .15527 Mtetra
.677 .774 .924 r
.52517 .15527 .5325 .16356 .54609 .1595 .5388 .14976 Mtetra
.68 .739 .895 r
.5388 .14976 .54609 .1595 .55974 .15436 .55249 .144 Mtetra
.677 .724 .885 r
.55249 .144 .55974 .15436 .57345 .14863 .56624 .13826 Mtetra
.672 .723 .888 r
.56624 .13826 .57345 .14863 .58722 .1428 .58006 .13268 Mtetra
.668 .729 .895 r
.58006 .13268 .58722 .1428 .60106 .13715 .59395 .12726 Mtetra
.666 .735 .901 r
.59395 .12726 .60106 .13715 .61497 .1317 .60791 .12194 Mtetra
.665 .739 .905 r
.60791 .12194 .61497 .1317 .62895 .12638 .62194 .11664 Mtetra
.664 .74 .907 r
.62194 .11664 .62895 .12638 .643 .1211 .63605 .11134 Mtetra
.664 .741 .907 r
.63605 .11134 .643 .1211 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27757 .18489 .26922 Mtetra
.18489 .26922 .19326 .27757 .20528 .27309 .19694 .26467 Mtetra
.663 .74 .907 r
.19694 .26467 .20528 .27309 .21735 .26863 .20905 .26012 Mtetra
.662 .738 .906 r
.20905 .26012 .21735 .26863 .22947 .26428 .22121 .25558 Mtetra
.659 .734 .905 r
.22121 .25558 .22947 .26428 .24162 .26008 .23343 .2511 Mtetra
.655 .726 .902 r
.23343 .2511 .24162 .26008 .25383 .25605 .24569 .24673 Mtetra
.649 .717 .898 r
.24569 .24673 .25383 .25605 .26609 .25204 .258 .24249 Mtetra
.646 .711 .895 r
.258 .24249 .26609 .25204 .27843 .24779 .27036 .23833 Mtetra
.647 .715 .898 r
.27036 .23833 .27843 .24779 .29088 .24297 .28278 .23414 Mtetra
.653 .734 .908 r
.28278 .23414 .29088 .24297 .30343 .23737 .29528 .22973 Mtetra
.665 .77 .928 r
.29528 .22973 .30343 .23737 .31606 .23146 .30787 .22497 Mtetra
.677 .807 .945 r
.30787 .22497 .31606 .23146 .32866 .22673 .32054 .21982 Mtetra
.687 .798 .934 r
.32054 .21982 .32866 .22673 .34133 .22198 .33329 .21434 Mtetra
.692 .78 .919 r
.33329 .21434 .34133 .22198 .35405 .2172 .34611 .20868 Mtetra
.675 .754 .91 r
.34611 .20868 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.664 .741 .907 r
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.653 .737 .911 r
.424 .17892 .43169 .18806 .44485 .18312 .43719 .17429 Mtetra
.637 .741 .923 r
.43719 .17429 .44485 .18312 .45807 .17815 .45044 .17013 Mtetra
.641 .765 .938 r
.45044 .17013 .45807 .17815 .47136 .17316 .46376 .16578 Mtetra
.65 .788 .948 r
.46376 .16578 .47136 .17316 .48471 .16815 .47716 .16112 Mtetra
.663 .803 .95 r
.47716 .16112 .48471 .16815 .49812 .16433 .49063 .15604 Mtetra
.675 .773 .924 r
.49063 .15604 .49812 .16433 .51161 .16019 .50417 .15061 Mtetra
.678 .742 .899 r
.50417 .15061 .51161 .16019 .52517 .15527 .51778 .14497 Mtetra
.676 .725 .887 r
.51778 .14497 .52517 .15527 .5388 .14976 .53144 .13927 Mtetra
.673 .721 .885 r
.53144 .13927 .5388 .14976 .55249 .144 .54518 .13366 Mtetra
.669 .724 .89 r
.54518 .13366 .55249 .144 .56624 .13826 .55898 .12818 Mtetra
.667 .73 .897 r
.55898 .12818 .56624 .13826 .58006 .13268 .57285 .1228 Mtetra
.665 .735 .902 r
.57285 .1228 .58006 .13268 .59395 .12726 .58678 .11747 Mtetra
.664 .739 .905 r
.58678 .11747 .59395 .12726 .60791 .12194 .60079 .11216 Mtetra
.664 .74 .907 r
.60079 .11216 .60791 .12194 .62194 .11664 .61487 .10684 Mtetra
.664 .741 .907 r
.61487 .10684 .62194 .11664 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.16441 .26536 .17289 .27374 .18489 .26922 .17644 .26079 Mtetra
.17644 .26079 .18489 .26922 .19694 .26467 .18853 .2562 Mtetra
.18853 .2562 .19694 .26467 .20905 .26012 .20067 .25159 Mtetra
.663 .74 .907 r
.20067 .25159 .20905 .26012 .22121 .25558 .21287 .24697 Mtetra
.663 .739 .906 r
.21287 .24697 .22121 .25558 .23343 .2511 .22513 .24235 Mtetra
.661 .736 .905 r
.22513 .24235 .23343 .2511 .24569 .24673 .23744 .23775 Mtetra
.658 .73 .903 r
.23744 .23775 .24569 .24673 .258 .24249 .2498 .23321 Mtetra
.655 .723 .899 r
.2498 .23321 .258 .24249 .27036 .23833 .26222 .22874 Mtetra
.651 .715 .895 r
.26222 .22874 .27036 .23833 .28278 .23414 .27469 .22436 Mtetra
.649 .711 .893 r
.27469 .22436 .28278 .23414 .29528 .22973 .28721 .22001 Mtetra
.649 .713 .894 r
.28721 .22001 .29528 .22973 .30787 .22497 .2998 .21563 Mtetra
.653 .725 .901 r
.2998 .21563 .30787 .22497 .32054 .21982 .31246 .21114 Mtetra
.658 .744 .914 r
.31246 .21114 .32054 .21982 .33329 .21434 .32519 .2065 Mtetra
.663 .769 .929 r
.32519 .2065 .33329 .21434 .34611 .20868 .338 .20171 Mtetra
.665 .795 .944 r
.338 .20171 .34611 .20868 .35895 .20348 .35087 .1968 Mtetra
.665 .805 .95 r
.35087 .1968 .35895 .20348 .37184 .19862 .3638 .19183 Mtetra
.665 .803 .949 r
.3638 .19183 .37184 .19862 .38478 .19373 .3768 .18685 Mtetra
.663 .801 .949 r
.3768 .18685 .38478 .19373 .39779 .18881 .38986 .18189 Mtetra
.662 .801 .949 r
.38986 .18189 .39779 .18881 .41086 .18388 .40298 .17696 Mtetra
.661 .802 .95 r
.40298 .17696 .41086 .18388 .424 .17892 .41616 .17202 Mtetra
.662 .804 .951 r
.41616 .17202 .424 .17892 .43719 .17429 .42941 .16702 Mtetra
.666 .796 .944 r
.42941 .16702 .43719 .17429 .45044 .17013 .44273 .1619 Mtetra
.671 .772 .925 r
.44273 .1619 .45044 .17013 .46376 .16578 .45612 .15662 Mtetra
.674 .749 .908 r
.45612 .15662 .46376 .16578 .47716 .16112 .46957 .15119 Mtetra
.674 .732 .894 r
.46957 .15119 .47716 .16112 .49063 .15604 .48309 .14565 Mtetra
.673 .722 .886 r
.48309 .14565 .49063 .15604 .50417 .15061 .49667 .14007 Mtetra
.671 .719 .885 r
.49667 .14007 .50417 .15061 .51778 .14497 .51032 .13452 Mtetra
.669 .721 .888 r
.51032 .13452 .51778 .14497 .53144 .13927 .52403 .12905 Mtetra
.667 .727 .894 r
.52403 .12905 .53144 .13927 .54518 .13366 .53781 .12365 Mtetra
.665 .733 .9 r
.53781 .12365 .54518 .13366 .55898 .12818 .55165 .11831 Mtetra
.665 .737 .904 r
.55165 .11831 .55898 .12818 .57285 .1228 .56557 .11299 Mtetra
.664 .739 .906 r
.56557 .11299 .57285 .1228 .58678 .11747 .57955 .10766 Mtetra
.664 .74 .907 r
.57955 .10766 .58678 .11747 .60079 .11216 .59361 .10232 Mtetra
.664 .741 .907 r
.59361 .10232 .60079 .11216 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.16792 .2523 .17644 .26079 .18853 .2562 .18004 .24767 Mtetra
.18004 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21287 .24697 .20446 .23834 Mtetra
.664 .74 .907 r
.20446 .23834 .21287 .24697 .22513 .24235 .21675 .23365 Mtetra
.663 .739 .907 r
.21675 .23365 .22513 .24235 .23744 .23775 .2291 .22894 Mtetra
.662 .738 .906 r
.2291 .22894 .23744 .23775 .2498 .23321 .24151 .22424 Mtetra
.661 .734 .904 r
.24151 .22424 .2498 .23321 .26222 .22874 .25397 .21955 Mtetra
.659 .729 .901 r
.25397 .21955 .26222 .22874 .27469 .22436 .26649 .2149 Mtetra
.657 .723 .898 r
.26649 .2149 .27469 .22436 .28721 .22001 .27907 .21027 Mtetra
.655 .717 .894 r
.27907 .21027 .28721 .22001 .2998 .21563 .2917 .20567 Mtetra
.653 .712 .891 r
.2917 .20567 .2998 .21563 .31246 .21114 .3044 .20108 Mtetra
.654 .711 .89 r
.3044 .20108 .31246 .21114 .32519 .2065 .31716 .19646 Mtetra
.654 .713 .891 r
.31716 .19646 .32519 .2065 .338 .20171 .32998 .19179 Mtetra
.657 .717 .893 r
.32998 .19179 .338 .20171 .35087 .1968 .34288 .18704 Mtetra
.659 .723 .896 r
.34288 .18704 .35087 .1968 .3638 .19183 .35584 .18221 Mtetra
.661 .728 .899 r
.35584 .18221 .3638 .19183 .3768 .18685 .36887 .17729 Mtetra
.663 .731 .9 r
.36887 .17729 .3768 .18685 .38986 .18189 .38196 .17229 Mtetra
.665 .732 .9 r
.38196 .17229 .38986 .18189 .40298 .17696 .39513 .16721 Mtetra
.666 .73 .897 r
.39513 .16721 .40298 .17696 .41616 .17202 .40836 .16204 Mtetra
.667 .726 .893 r
.40836 .16204 .41616 .17202 .42941 .16702 .42165 .15678 Mtetra
.668 .721 .889 r
.42165 .15678 .42941 .16702 .44273 .1619 .43501 .15145 Mtetra
.668 .718 .886 r
.43501 .15145 .44273 .1619 .45612 .15662 .44844 .14606 Mtetra
.668 .716 .884 r
.44844 .14606 .45612 .15662 .46957 .15119 .46193 .14064 Mtetra
.668 .717 .886 r
.46193 .14064 .46957 .15119 .48309 .14565 .47548 .13522 Mtetra
.667 .721 .889 r
.47548 .13522 .48309 .14565 .49667 .14007 .4891 .12983 Mtetra
.666 .726 .894 r
.4891 .12983 .49667 .14007 .51032 .13452 .50279 .12447 Mtetra
.665 .731 .899 r
.50279 .12447 .51032 .13452 .52403 .12905 .51654 .11914 Mtetra
.665 .735 .903 r
.51654 .11914 .52403 .12905 .53781 .12365 .53037 .11381 Mtetra
.664 .738 .905 r
.53037 .11381 .53781 .12365 .55165 .11831 .54426 .10849 Mtetra
.664 .74 .906 r
.54426 .10849 .55165 .11831 .56557 .11299 .55822 .10314 Mtetra
.664 .74 .907 r
.55822 .10314 .56557 .11299 .57955 .10766 .57225 .09778 Mtetra
.664 .741 .907 r
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04262 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26677 Mtetra
.09942 .26677 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18004 .24767 .17149 .23906 Mtetra
.17149 .23906 .18004 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23365 .20829 .22491 Mtetra
.20829 .22491 .21675 .23365 .2291 .22894 .22068 .22015 Mtetra
.664 .74 .907 r
.22068 .22015 .2291 .22894 .24151 .22424 .23313 .21537 Mtetra
.663 .739 .906 r
.23313 .21537 .24151 .22424 .25397 .21955 .24563 .21058 Mtetra
.663 .738 .905 r
.24563 .21058 .25397 .21955 .26649 .2149 .25819 .20578 Mtetra
.662 .735 .904 r
.25819 .20578 .26649 .2149 .27907 .21027 .27081 .20097 Mtetra
.661 .731 .902 r
.27081 .20097 .27907 .21027 .2917 .20567 .2835 .19617 Mtetra
.66 .727 .899 r
.2835 .19617 .2917 .20567 .3044 .20108 .29624 .19136 Mtetra
.659 .722 .896 r
.29624 .19136 .3044 .20108 .31716 .19646 .30904 .18654 Mtetra
.659 .719 .893 r
.30904 .18654 .31716 .19646 .32998 .19179 .32191 .1817 Mtetra
.658 .716 .891 r
.32191 .1817 .32998 .19179 .34288 .18704 .33484 .17683 Mtetra
.659 .714 .889 r
.33484 .17683 .34288 .18704 .35584 .18221 .34784 .1719 Mtetra
.66 .713 .888 r
.34784 .1719 .35584 .18221 .36887 .17729 .36091 .16692 Mtetra
.661 .713 .887 r
.36091 .16692 .36887 .17729 .38196 .17229 .37404 .16187 Mtetra
.662 .714 .887 r
.37404 .16187 .38196 .17229 .39513 .16721 .38723 .15676 Mtetra
.663 .714 .887 r
.38723 .15676 .39513 .16721 .40836 .16204 .4005 .15159 Mtetra
.664 .716 .887 r
.4005 .15159 .40836 .16204 .42165 .15678 .41383 .14637 Mtetra
.664 .718 .888 r
.41383 .14637 .42165 .15678 .43501 .15145 .42722 .14112 Mtetra
.665 .721 .891 r
.42722 .14112 .43501 .15145 .44844 .14606 .44068 .13583 Mtetra
.665 .724 .894 r
.44068 .13583 .44844 .14606 .46193 .14064 .45421 .13054 Mtetra
.665 .728 .897 r
.45421 .13054 .46193 .14064 .47548 .13522 .4678 .12524 Mtetra
.665 .732 .9 r
.4678 .12524 .47548 .13522 .4891 .12983 .48146 .11994 Mtetra
.664 .736 .903 r
.48146 .11994 .4891 .12983 .50279 .12447 .49519 .11463 Mtetra
.664 .738 .905 r
.49519 .11463 .50279 .12447 .51654 .11914 .50899 .10931 Mtetra
.664 .739 .906 r
.50899 .10931 .51654 .11914 .53037 .11381 .52286 .10397 Mtetra
.664 .74 .907 r
.52286 .10397 .53037 .11381 .54426 .10849 .5368 .09861 Mtetra
.664 .741 .907 r
.5368 .09861 .54426 .10849 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.57904 .08236 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04262 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .26291 Mtetra
.07875 .26291 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.1874 .22088 .19597 .22964 .20829 .22491 .19976 .21609 Mtetra
.19976 .21609 .20829 .22491 .22068 .22015 .21218 .21129 Mtetra
.21218 .21129 .22068 .22015 .23313 .21537 .22466 .20646 Mtetra
.22466 .20646 .23313 .21537 .24563 .21058 .2372 .20162 Mtetra
.664 .74 .907 r
.2372 .20162 .24563 .21058 .25819 .20578 .2498 .19675 Mtetra
.2498 .19675 .25819 .20578 .27081 .20097 .26247 .19186 Mtetra
.663 .738 .906 r
.26247 .19186 .27081 .20097 .2835 .19617 .27519 .18695 Mtetra
.663 .737 .905 r
.27519 .18695 .2835 .19617 .29624 .19136 .28797 .18203 Mtetra
.663 .735 .904 r
.28797 .18203 .29624 .19136 .30904 .18654 .30082 .17708 Mtetra
.662 .733 .902 r
.30082 .17708 .30904 .18654 .32191 .1817 .31373 .17212 Mtetra
.662 .731 .901 r
.31373 .17212 .32191 .1817 .33484 .17683 .3267 .16712 Mtetra
.662 .729 .899 r
.3267 .16712 .33484 .17683 .34784 .1719 .33974 .16211 Mtetra
.662 .728 .898 r
.33974 .16211 .34784 .1719 .36091 .16692 .35284 .15705 Mtetra
.663 .728 .898 r
.35284 .15705 .36091 .16692 .37404 .16187 .36601 .15196 Mtetra
.663 .728 .897 r
.36601 .15196 .37404 .16187 .38723 .15676 .37925 .14683 Mtetra
.663 .729 .898 r
.37925 .14683 .38723 .15676 .4005 .15159 .39255 .14166 Mtetra
.663 .73 .899 r
.39255 .14166 .4005 .15159 .41383 .14637 .40591 .13647 Mtetra
.664 .732 .9 r
.40591 .13647 .41383 .14637 .42722 .14112 .41935 .13124 Mtetra
.664 .733 .901 r
.41935 .13124 .42722 .14112 .44068 .13583 .43285 .12599 Mtetra
.664 .736 .903 r
.43285 .12599 .44068 .13583 .45421 .13054 .44641 .12072 Mtetra
.664 .737 .904 r
.44641 .12072 .45421 .13054 .4678 .12524 .46005 .11543 Mtetra
.664 .739 .906 r
.46005 .11543 .4678 .12524 .48146 .11994 .47375 .11012 Mtetra
.664 .74 .906 r
.47375 .11012 .48146 .11994 .49519 .11463 .48753 .10479 Mtetra
.664 .74 .907 r
.48753 .10479 .49519 .11463 .50899 .10931 .50137 .09943 Mtetra
.664 .741 .907 r
.50137 .09943 .50899 .10931 .52286 .10397 .51528 .09405 Mtetra
.51528 .09405 .52286 .10397 .5368 .09861 .52926 .08864 Mtetra
.52926 .08864 .5368 .09861 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08236 .57165 .07225 Mtetra
.57165 .07225 .57904 .08236 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .033 Mtetra
.67312 .033 .68016 .04348 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .26291 .06982 .25443 Mtetra
.06982 .25443 .07875 .26291 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21684 Mtetra
.16642 .21684 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21609 .19115 .20721 Mtetra
.19115 .20721 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20162 .2287 .1926 Mtetra
.2287 .1926 .2372 .20162 .2498 .19675 .24134 .18768 Mtetra
.24134 .18768 .2498 .19675 .26247 .19186 .25404 .18274 Mtetra
.664 .74 .907 r
.25404 .18274 .26247 .19186 .27519 .18695 .2668 .17777 Mtetra
.2668 .17777 .27519 .18695 .28797 .18203 .27962 .17278 Mtetra
.663 .739 .906 r
.27962 .17278 .28797 .18203 .30082 .17708 .2925 .16778 Mtetra
.664 .739 .906 r
.2925 .16778 .30082 .17708 .31373 .17212 .30545 .16274 Mtetra
.663 .738 .906 r
.30545 .16274 .31373 .17212 .3267 .16712 .31847 .15768 Mtetra
.664 .738 .905 r
.31847 .15768 .3267 .16712 .33974 .16211 .33154 .15259 Mtetra
.663 .737 .905 r
.33154 .15259 .33974 .16211 .35284 .15705 .34469 .14748 Mtetra
.664 .737 .905 r
.34469 .14748 .35284 .15705 .36601 .15196 .35789 .14234 Mtetra
.35789 .14234 .36601 .15196 .37925 .14683 .37117 .13717 Mtetra
.37117 .13717 .37925 .14683 .39255 .14166 .38451 .13198 Mtetra
.664 .738 .905 r
.38451 .13198 .39255 .14166 .40591 .13647 .39792 .12675 Mtetra
.39792 .12675 .40591 .13647 .41935 .13124 .41139 .12151 Mtetra
.664 .739 .906 r
.41139 .12151 .41935 .13124 .43285 .12599 .42493 .11623 Mtetra
.42493 .11623 .43285 .12599 .44641 .12072 .43854 .11093 Mtetra
.664 .74 .907 r
.43854 .11093 .44641 .12072 .46005 .11543 .45222 .10561 Mtetra
.45222 .10561 .46005 .11543 .47375 .11012 .46597 .10026 Mtetra
.664 .741 .907 r
.46597 .10026 .47375 .11012 .48753 .10479 .47978 .09488 Mtetra
.47978 .09488 .48753 .10479 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .07309 Mtetra
.53576 .07309 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .033 .66602 .0224 Mtetra
.66602 .0224 .67312 .033 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21684 .15767 .20795 Mtetra
.15767 .20795 .16642 .21684 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.20751 .18843 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18768 .23279 .17854 Mtetra
.23279 .17854 .24134 .18768 .25404 .18274 .24553 .17355 Mtetra
.24553 .17355 .25404 .18274 .2668 .17777 .25832 .16854 Mtetra
.25832 .16854 .2668 .17777 .27962 .17278 .27119 .16351 Mtetra
.27119 .16351 .27962 .17278 .2925 .16778 .28411 .15844 Mtetra
.664 .74 .907 r
.28411 .15844 .2925 .16778 .30545 .16274 .2971 .15336 Mtetra
.664 .741 .907 r
.2971 .15336 .30545 .16274 .31847 .15768 .31015 .14825 Mtetra
.664 .74 .907 r
.31015 .14825 .31847 .15768 .33154 .15259 .32327 .14312 Mtetra
.32327 .14312 .33154 .15259 .34469 .14748 .33645 .13795 Mtetra
.33645 .13795 .34469 .14748 .35789 .14234 .3497 .13277 Mtetra
.3497 .13277 .35789 .14234 .37117 .13717 .36301 .12755 Mtetra
.664 .741 .907 r
.36301 .12755 .37117 .13717 .38451 .13198 .37639 .12231 Mtetra
.664 .74 .907 r
.37639 .12231 .38451 .13198 .39792 .12675 .38984 .11705 Mtetra
.664 .741 .907 r
.38984 .11705 .39792 .12675 .41139 .12151 .40336 .11175 Mtetra
.664 .74 .907 r
.40336 .11175 .41139 .12151 .42493 .11623 .41694 .10643 Mtetra
.664 .741 .907 r
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000004/0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?oo
o`00NP3oool01`3oScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000004l0ZKgX00<00000
0:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3o
ool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`00001A0:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`00000C
0:Vmj0<0ZKgW1@2Y_NP50:Vmi`H0ZKgX1@2Y_NLY0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<00000
0?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0
a5lD000eSaP0oooo0P0000000`2Y_NP000000:Vmj00A0:Vmj0H0ZKgW0P2Y_NP30:Vli`D0ZKgW0`2Y
_NP30:Vli`D0ZKgW0`2Y_NP30:Vmib80ZKgX00<000000:Vmj02Y_NP04@2Y_NP00`000000oooo0?oo
o`070?ooo`030?oOW0180000000000<0000000<0001d0;ooo`3oool0103oool00`2oM000M;oo0?oo
o`0m0?ooo`00N`3oool01@3oohl0=@000000000055l0a?oo01D0oooo0`0000070:Vmj0D0ZKgW1@2Y
_NP;0:Vmi`H0ZKcW1@2Y_NL60:Vli`/0ZKgW0P2Y_NP30:Vmia`0ZKgX00<000000:Vmj02Y_NP04@2Y
_NP00`3oool000000?ooo`0?0?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0n0?ooo`00
T`3oool2000000P0ZKgX202Y_NL20:Vmj0<0ZKcW202Y_NL90:Vli`D0Z[cW1@2Y_>L60:Zli`/0ZKgW
6`2Y_NP00`000000ZKgX0:Vmj00B0:Vmj0030000003oool0oooo00h0oooo00<0oono07@000000000
0P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool3000000P0ZKgX2P2Y_NL60:Vli`D0ZKgW2@2Y
_>L30:ZkiPD0Z[cW0P2Y_>L30:ZkiPH0Z[cW1@2Z_>H50:Vmi`H0Z[gW5@2Y_NP00`000000ZKgX0:Vm
j00C0:Vmj0030000003oool0oooo00d0oooo00<0oooO09a8B02Lgol0@P3oool008h0oooo0P000000
0`2Y_NP000000:Vmj0060:Vmj0<0ZKcW1@2Y_NL;0:Vli`D0Z[_V1@2Y_>L70:ZkiP@0Z[cW1P2Z^nH3
0:Zli`<0Z[[U1@2Z_>H20:Vmi`<0Z[cV1P2Z_NL20:Vmj0<0Z[gW3`2Y_NP00`000000ZKgX0:Vmj00C
0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@007Boo`3oool0@@3oool008/0oooo0`0000090:Vm
j0H0ZKcW0P2Y_NL30:VkiPP0ZKcW0`2Z^^D50:ZkiP80ZKcW0`2Z^N@60:ZkiPD0Z[[T1@2Z^nH70:Zj
i@X0Z[cV2`2Z_NL20:Vmj0<0Z[gW2@2Y_NP00`000000ZKgX0:Vmj00D0:Vmj0030000003oool0oooo
00d0oooo00H0gia800000000000000000000M02oooln0?ooo`00R@3oool2000000L0ZKgX2`2Y_>L6
0:VkiPD0ZKcW1P2Z^^D40:ZkiPH0Z[WT0`2Z^nH30:^hh`D0Z[[T0P2Z^nH30:^ih`H0Z[[U1@2[^^D;
0:ZliP/0Z[gW202Y_NP00`000000ZKgX0:Vmj00E0:Vmj0030000003oool0oooo0500oooo00260?oo
o`<000001`2Y_NP;0:Vli`T0ZK_V1@2Z^N@50:Zji@D0Z[SS1P2Z^N@60:^hh`@0Z[[T1P2[^N<30:Zj
i@<0[;WS1@2[^^D20:ZliP<0Zk[T1P2Z_>H20:Zmi`<0Z[cV1@2Z_NL60:Vmi`80ZKgX00<000000:Vm
j02Y_NP05@2Y_NP00`3oool000000?ooo`1@0?ooo`00Q03oool3000000L0ZKgX2`2Y_>L90:VkiP<0
Z[ST1@2Z^N@20:Zji@<0ZkOR1@2Z^><30:Zii0<0ZkSR1@2[^><50:bhhPH0ZkWS1@2/^N<50:^ji@H0
Zk[T2`2Z_>H20:Zmi`<0Z[cW1P2Y_NL00`2Y_NP000000:Vmi`020:VmiaD0ZKgX00<000000?ooo`3o
ool0C`3oool00840oooo0`0000030:Vmj0030000002Y_NP0ZKgX00/0ZKcW1@2Y^^H50:VkiPH0Z[ST
1@2Z^N@60:^ghPD0Z[SS1P2[^>820:^hh`<0[KWS1@2/^>830:^ih`<0[KWR1@2/^N<20:^ji@<0[;WS
2`2[^^@50:ZliPH0Z[cW1P2Y_NL00`000000ZKgW0:Vmi`020:VmiaD0ZKgX00<000000?ooo`3oool0
CP3oool007l0oooo0P0000070:Vmj0/0ZKcW0`2Y^^D50:VjiP80ZK_V0`2Y]n<60:Zhi080Z[WT202[
]n860:bhhPD0ZkSR1@2]^N<50:bhhPL0[KWR2P2/^N<30:^ji0<0[KWS1@2[^^@20:ZliP<0Zk_U2`2Z
_>L00`000000ZKgW0:Vmi`020:VmiaH0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`000007
0:Vmj0/0ZKcW1P2Y^^D40:VjiPH0ZKOS1@2Z^>@80:^ghP<0[;_T1P2/^>820:^hhP<0[KgV1@2]^N<2
0:bhhP<0[[gU1P2]^N850:jjh`D0[;WS1`2]^N<40:^ji0H0Zk_U0P2Z_>L30:^ki@D0Z[cW00<00000
0:Zmi`2Z_NL00`2Z_NLE0:Vmj0030000003oool0oooo04d0oooo001;0?ooo`050<AO500000000000
0000501Oa?l0:@3oool3000000030:Vmj0000000ZKgX00D0ZKgX2@2Y_>L:0:Vji@/0ZKOS2P2[]n86
0:bki0D0[;SR1P2]_NH40:fih`H0[[gU0`2]^N830:k1i`D0[[[S0P2/^N<30:jkh`H0[KWS1@2]^^<;
0:^ki@<0Z[cW00<0ZkcV0000002[_>H01@2Z_NL20:Vmj0<0Z[gW402Y_NP00`000000oooo0?ooo`1<
0?ooo`00BP3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09P3oool2000000T0ZKgX2@2Y
_>L:0:Vji@<0ZKKS202Y]n<30:^hh`L0ZkOR0`2/_nP60:bki080[;SR0`2/aN`50:fmiPD0[LK/1P2^
_ND60:k1i`@0[[[S1P2^^n<30:fih`<0[kcS1@2]^^<20:^ki@<0[K[S1@2[^nD50:^liP030000002[
_>H0Z[gW00T0Z[gW3`2Y_NP00`000000oooo0?ooo`1<0?ooo`00C`3oool00`2?=@00=Hoo0?ooo`0R
0?ooo`<000001`2Y_NP;0:Vli`X0ZK[U1P2Y]^<50:Vgh`H0ZkSS102[]n860:boj0D0[;_T1P2/aN`2
0:fmiP<0Z<cc1@2]a^`30:jmi@<0Z/gb1@2^`NL50:k4jPD0[[_S1`2__><:0:fjh`80Zk_U0`2]^n@4
0:^liP030000002[_>H0Z[cW00@0Z[cW1@2Z_NL@0:Vmj0030000003oool0oooo04/0oooo00120?oo
o`030?o4G`0D0000000000<0000000<0000e08ooo`3oool0103oool00`2?=@00=Hoo0?ooo`0P0?oo
o`800000202Y_NP90:Vli`X0ZK[U2`2Y]^<50:Zii0D0ZkSS1@2[aN`60:boj0D0ZLgc1@2/aN`60:S<
l`D0[LK/1P2ZcO820:k1i`<0Y/Wb1@2^a>X20:jkh`<0[/G[2`2__><50:fjh`H0[K_T0`2[_>H00`00
0000[;_U0:bki@050:Zli`D0Z[gW402Y_NP00`000000oooo0?ooo`1:0?ooo`00BP3oool01`3oa5l0
500D05o4o`3oool0ooo405lD501Oa?l07P3oool3000000030:Vmj0000000ZKgX00D0ZKgX2@2Y_>L3
0:VjiPL0ZK[U2`2Y]^<30:Zji@D0Z[WT0P2[^><30:[;l@D0ZlG/0`2/_nP30:K9lPD0ZLgc1@2R`o05
0:S<l`H0XL;a1@2ZcO860:K9lP@0[/CZ1P2^aN/30:nlh`<0[/CZ1@2__><20:fjh`<0[k_S1@2]^n@3
0:bki@040000002/^nD0[;_U0:bki@@0Z[cW1P2Z_NL20:Vmj0<0Z[gX2P2Y_NP00`000000oooo0?oo
o`1:0?ooo`00BP3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01X0oooo00<0ZKgX
0000000000001`2Y_NP60:Vmi`D0ZKcW1P2Y^^H40:Vji@/0ZKKS1P2Z^^D40:Zii0H0Z/_a1@2[aN`6
0:K9lPD0WkW[1@2R`o0609nij`D0XL;a1@2J]n`50:K9lPD0XlKb1P2^aN/60:k4jP@0[kcS1P2_^n<2
0:fki0<0[k_S0P2/^nD010000000[;_U0:bki@2/^nD50:^liPD0Z[gW1P2Z_NP:0:Vmj0030000003o
ool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`0000080:Vmj0P0ZKgW1@2Y^nH5
0:VjiPD0Z;KS202Y]^<30:ZkiPD0Z[[U1@2YcO<50:[;l@H0Y<?`0`2VbO830:Vmj0D0WkW[0P2R`o03
0:Vmj0H0WkW[1@2Y_NP509Zgk0D0WKS/1@2Sa_860:;4l@D0[/CZ1@2_`^P;0:nkh`030:bki@000000
[;_U00<0[[_T1@2[_>H50:Zmi`D0Z[gX2`2Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool00`2?
=@00=Hoo0?ooo`0J0?ooo`8000002@2Y_NP80:Vmi`P0ZK_V0P2Y^^H80:Rfh`D0ZKKS1P2Z^nH20:Zj
i@P0ZLgc1P2S_N`50:C3l0H0ZKgX102O^N/60:Vmj0<0WkW[202Y_NP209Zgk0<0ZKgX1@2M^>`509ji
j`H0X/Ca0P2^a>X30:?6lPD0[l;X0P2_^n<30;2oi@D0[k_S00<0[[_T0000002^^n@0102^^n@20:^l
iP<0[;cU1@2Z_NL20:Zmj0<0Z[gW2P2Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@0
0000000000000000000e08oooa<0oooo00@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0:Vm
j0070:Vmj0D0ZKgW2P2Y^nH;0:Rfh`D0ZK_V1@2Z^nH80:W=l`<0YkcY1P2S_N`U0:Vmj080WKS/0`2Y
_NP509jij`D0X/Ca1P2Sa_840:o2j0H0/;oU0P2_^n<30;2mi0030000002^^n@0[[_T00<0[[_T1P2/
_>D:0:Zmi`X0ZKgX00<000000?ooo`3oool0A`3oool00680oooo00<0ZKgX000000000000402Y_NP5
0:Vli`D0ZK_V1@2X]n@80:Rfh`<0ZK[V1@2Y^nH50:W=lPD0ZLgc1P2W_>T30:>mk2d0ZKgX1@2N^N/5
09fhj`D0XlKb1@2Wb_850;2oi@D0/;gT00@000000:jki02^^n@0[[_T0`2__><50:bli@D0ZkcV1@2Z
_NL;0:Vmj0030000003oool0oooo04H0oooo001O0?ooo`@00000402Y_NP80:Vli`<0ZK_V0P2X^>@5
0:Rgi0D0Z;KS1P2Y^^H20:VkiPP0ZLgb1P2Y_NP50:NljCD0ZKgX1@2M^>/509Zgk0D0Yl[b1@2/aN`4
0;2mi0030000002__><0[kcS00D0[kcS0P2/_>D30:jli0D0ZkcV1@2Z_NL:0:Vmj0030000003oool0
oooo04H0oooo001M0?ooo`040:Vmj0000000000000000100ZKgX2`2Y_>L50:Rhi0D0Z;OT1@2X^ND5
0:VjiPP0ZLgbB02Y_NP509Zgk0D0UkG]1@2/aN`20;2mi0030;31i`000000/<7W00H0[kcS1P2^_>@4
0:^liPH0Z[gW0P2Y_NP30:Zmj0D0ZKgX00<000000?ooo`3oool0A@3oool005/0oooo0`00000?0:Vm
j0/0ZKcW1@2X^>D50:Rhi0D0Z;OT1@2X^ND60:[=lP@0ZLgbB`2Y_NP209Zgk0<0ZKgX1@2G]Nd40:c5
k0<0/<7W00<000000;31i`2``NL00`2__><30;2ni0D0[[cT1@2/_NH50:Zmi`H0Z[gX102Y_NP00`3o
ool000000?ooo`150?ooo`00F03oool3000001<0ZKgX202Y_>L30:RjiPD0Z;SU0P2X^>@30:Nfi0D0
Z;OT0P2X^ND30:[>l`H0Z/gbE02Y_NP409Nek@D0X<;a0P2``NL00`000000/<7W0;31i`070;2ni080
[[cT0`2__N@50:bmiPD0ZkgW1@2Z_NP50:Vmj0030000003oool0oooo04@0oooo001E0?ooo`030:Vm
j0000000000001L0ZKgX1@2Y_>L60:RjiP@0Z;SU1P2W]^@40:Rgi0H0Z/kc0`2ZcO8_0:Vmj0<0Z:kL
902Y_NP50:2ij`D0X<;a00<0ZlC/0000002[a>`00P2[a>`60;2ni0H0[kgT0P2/_NH30:fmi@D0ZkgW
0P2Z_NP30:Zmi`D0ZKgX00<000000?ooo`3oool0@`3oool005<0oooo0`0000000`2Y_NP000000:Vm
j00G0:Vmj0D0ZK_V1@2X^^H50:Nfh`D0YkKT1P2Zbo450:[>lbD0ZKgX1@2X[]`50:Vmj0H0Z:kL902Y
_NP50:2ij`D0V;K/00<000000:_4k02[a>`00P2[a>`30;2ni0<0/<3V1@2__N@60:fmi@@0ZkgW1P2Z
_NL50:Vmj0030000003oool0oooo0480oooo001A0?ooo`8000006`2Y_NP30:Vli`D0ZK_V0P2X^^H3
0:Nfi0D0YkKS0P2W]^@30:W4k@H0Z/_a702Y_NP30:Vli`P0ZKgX0`2RU<L50:R^g0D0X8k11@2X[]`5
0:>IbR00ZKgX0P2P^N/30:Vmj0@0V;K/00<000000:_4k02[a>`00P2[a>`60;30iP<0[kgT0`2a_^@5
0:fmi@D0ZkgW1@2Z_NL50:Vmj0030000003oool0oooo0480oooo001>0?ooo`<000006`2Y_NP60:Vl
i`@0ZK_V1P2W]^@40:Nfh`H0ZLC]0`2Zbo430:c1j1T0ZKgX1P2Y_>L50:Vmj0D0XYC7102X[]`20:F9
]`D0X8k10P2X[]`30:J;^@D0XiW:1@2QTL@P0:Vmj0<0V;K/00<000000:32l@2P`_400`2P`_450;30
iPH0/KkT0`2]_ND30:jmi@D0ZkgW1@2Z_NL50:Vmj0030000003oool0oooo0440oooo000I0?ooo`03
0?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?ooo`8000006P2Y_NP:0:Vl
i`D0YkOT1P2W]^@50:Rnj@D0ZLC]1P2/`NPD0:Vmj0D0Z:kL1P2Y_>L509j8_0D0XYC70P2X[]`30:F9
]`D0X8k11@2VRkT40:>IbP80]iRh1@2QTL@20:Vmj0<0XI736P2Y_NP30:2ij`030000002P^N/0X<;a
00@0X<;a1@2]`^P50;6ni0L0[[gU0P2[_NL30:bmiPD0Z[gW1@2Y_NP00`000000oooo0?ooo`100?oo
o`006@3oool02P3ogi`0B01d0;ooo`3oool0oooO05lD000DGl@0oooo0<AO5000=HlV0?ooo`<00000
0P2Y_NP00`000000ZKgX0:Vmj00E0:Vmj0<0ZKgW1P2Y_>L40:Rii@D0YkOT0`2W]^@30:NiiPD0Z;kY
1@2aan/50:c1j180ZKgX0`2VZ=L50:R^g0<0ZKcW0`2LP[H409j8_0D0XYC71@2URKL40:2>`@80^Y^h
1@2VRkT20:>IbP<0]iRh1@2QTL@60:6A``<0ZKgX0`2SVLXD0:Vmj080X;W[00<000000:2ij`2P^N/0
1@2G]Nd50:g2j080/KkT0`2a_n@60:jmi@H0[;gV1@2Z_NL40:Vmj0030000003oool0oooo00X0oooo
00D0oono07@00000000004RL0=ooo`0a0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0oono03D0
=@2?ool0oooo0?o4G`0D03D0Sooo0280oooo00<0ZKgX0000000000006`2Y_NP60:Vmi`<0ZKcW0`2X
^^H40:Rii@D0YkOT1P2W^NH20:Rnj@<0[lc_1@2aan/D0:Vmj0H0YZSG1@2X[]`509b2]PD0WXRl0`2R
U<L20;:C]`D0YHVg0P2PS/430;ZK^0D0YX^i00<0XiW:0;NH^02gV;P00P2gV;P40:6Aa080_inh1P2Q
TL<60:>IbQ@0ZKgX0P2P^N/00`000000ZKgX0:Vmj00509Nek@@0[L;X1P2a_n@30:jmi@<0[kkU1@2/
_NH60:Zmi`@0ZKgX00<000000?ooo`3oool0203oool01P3ooml0W4P004RLg`3oool0gia8001d_c40
oooo000=0?ooo`030?oOW0180000000000<0000000<0001d0;ooo`3oool00`3oool02`3ogi`0B01d
0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo0200oooo0`00000O0:Vmj0D0ZKgW1P2X
^^H40:Rii@D0Y[KT1@2W^NH60:o<k`80/LO[4`2Y_NP:0:JXe`80Z:kL0`2TQkD409b2]PD0WXRl0P2R
U<L30;:C]`D0YHVg00<0X8k10;ZK^02jVkP00P2jVkP50:J;^@H0]iRh0P2QTL@40;nO^0@0XI730P31
X[T50:>IbPD0Z:kL4@2Y_NP010000000ZKgX0:Vmj02Y_NP409Nek@D0Z<;/1@2a_n@60:nni@H0[;gV
1@2Z_NL40:Vmj0030000003oool0oooo00P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo
0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Coo`3oool0oon?03D0501Oa?l0
7P3oool300000280ZKgX1@2Y^nL50:RjiPX0Y[KT0P2W^NH30:g>l@D0[lc_4`2Y_NP30:R^g0T0YZSG
1@2TQkD509b2]P@0WXRl1@2bTkL50:F9]`H0^Y^h0`2VRkT20<:U_0D0]iRh00<0XI740;nO^02oWkP0
0`2oWkP30:6A``<0`J:i102SVLX20;^P_@D0Z:kL402Y_NP010000000ZKgX0:Vmj02Y_NP509Zgk0D0
Z<;/1@2a`>D50:nni@H0[;gV1P2Z_NL40:Vmj0030000003oool0oooo00L0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Co
o`3oool0oon?03D0501Oa?l06`3oool3000002<0ZKgX0`2Y_>L50:Vki`80Z;[V0`2V]nD90:Jfi0H0
[Lka5@2Y_NP50:R^g0D0YZSG1@2QQKL40:B7]@D0W8:f0`2NR;`20;6G_0D0/Y>g0`2URKL20;^R`0D0
^Y^h0P2VRkT30<:U_0D0]iRh1`2oWkP00`2QTL<0`J:i0<6R^@030<6R^@80XiW:102kX;d20:R^g0<0
[I[43`2Y_NP00`000000ZKgX0:Vmj0020:Vmj0D0V[O/1@2Q_nl50;70i@D0/;oU1@2/_NH60:Zmi`D0
ZKgX00<000000?ooo`3oool01P3oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0<03oool0
01L0oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo
01T0oooo0P00000T0:Vmj0H0ZKcW102Y^nL60:Jgi@@0Y[KT1P2ZaNd30:g>lA80ZKgX1@2Y_>L50:R^
g080YZSG0`2LPkL40:65]`D0Y8Ne102LP[H209j8_0<0/INl1@2bTkL20:F9]`<0^j;01@2jVkP00`2V
RkT0`ZFl0<:U_0020<:U_0@0]iRh0P37[L060;nO^0H0`J:i00<0XiW:0;^P_@2kX;d00`2kX;d60:fJ
a0h0ZKgX00<000000:Vmj02Y_NP00`2Y_NP209Zgk0<0X;W[1@2Q_nl20;70i@<0/<3V1@2`_nD50:fn
iPD0Z[gW1@2Y_NP00`000000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`0`0?ooo`00603oool02`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo0?ooo`34Ga@003F?
01L0oooo0`00000X0:Vmj0D0ZKcW102W^NH60:Jgi@D0Yk_X1@2ZaNdE0:Vmj0D0ZKcW102X[]`509b3
]`@0XHFg1@2TQkD409b2]PD0/INl1@2bTkL00`2URKL0^j;00;^R`0020;^R`0D0^Y^h1P32YK`20;NH
^0<0ajg01P2oWkP00`3;/L00`J:i0<6R^@030<6R^@H0^j2m00<0dK6j0:fJa02]V/@00`2]V/@50:R^
g0T0ZKgX00<000000:Vmj02Y_NP00`2Y_NP60:2ij`@0XKo_1P2``>H20;2oi@<0/KoU1@2]_^H50:^m
i`D0ZKgX00<000000?ooo`3oool01@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0<03o
ool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo01@0oooo0`00
00000`2Y_NP000000:Vmj00Y0:Vmj0D0Z;[W102W^NH30:Jgi@<0YKOU1@2W^nP50;?8jAD0ZKgX102Y
_>L509Qo]`@0W8>g1@2QQKL40:B7]@80W8:f0`2^V/850;6G_0@0/Y>g1P2kX/030;ZK^080`K7;1@32
YK`00`2gV;P0ajg00<N]`0030<N]`0@0_inh0P3;/L050<6R^@030<jb_P2kX;d0^j2m0080^j2m0P3A
/KX50:fJa0030<V]_@2X[]`0Z:kL00<0Z:kL202Y_NP00`000000ZKgX0:Vmj0040:Vmj0D0X;W[1@2I
^Nh50;30iPH0/KoU1@2]_^H50:^mi`D0ZKgX00<000000?ooo`3oool0103oool01P3ooml0W4P007Bo
o`3oool0gia8001d_c40oooo000d0?ooo`030:Vmj0000000000002d0ZKgX0`2Y_>L50:Rji`@0YkWV
1P2U]nD20:Nkj0<0/Lk_1@2cb>TD0:Vmj0D0Tgbg102HOkL409b3]`D0XHFg102TQkD50:jJ`PD0/INl
0P2bTkL30;V/c0D0^j;00P2jVkP30<6ab`D0`ZFl1P37[L030;nO^0<0bk701031X[T20<jb_P<0^j2m
0`3A/KX40:fJa0<0bJfm0P2X[]`30;2Sb`L0ZKgX00<000000:Vmj02Y_NP01@2Y_NP50:Nlj@D0VKW^
0P2``>H30:joiPD0/KoU1P2]_^H20:^mi`<0ZkkW102Y_NP00`000000oooo0?ooo`050?ooo`050?oo
_`1d000000000018W03Oool0<@3oool00380oooo0`00000]0:Vmj0H0ZKcW102X^^L50:Ffi@D0YKOU
1P2ac^l20;?8jA80ZKgX1@2MQk`409=l]`@0V7ng1@2LPkL40:65]`80Y8Ne0`2[W<L50:jJ`P@0/INl
1@2i[<`50;^R`0H0`K7;0`32YK`20<Bmd`H0ajg000<0_inh0<^a`03;/L000`3;/L020<6R^@@0c[:n
0P2kX;d40=6a^P80[I[41039[Kd60;2Sb`H0ZKgX00<000000:Vmj02Y_NP01P2Y_NP50:Nlj@@0VKW^
1P2^_nH20;6oi@<0/L3U1@2]_^H60:^ni`@0ZKgX00<000000?ooo`3oool0>P3oool00300oooo0P00
00000`2Y_NP000000:Vmj00Y0:Vmj0H0ZKgW102Y_>L50:Jgi@D0YKKU1@2[aNd50;7>ka80ZKgX0`2R
U<L409f7_0@0Tgbg1@2HOkL409b3]`@0XHFg1@2[W<L50:jJ`P80/INl0`2f]]T50;V/c0<0^j;00P2l
`Mh50<6ab`80`ZFl1034_M<50<N]`0H0bk7000<0`J:i0<jb_P3>/[h00`3>/[h00`2kX;d0dK6j0=6a
^P030=6a^P030:fJa039[Kd0bJfm00<0bJfm00<0ekRk0;2Sb`2`Xl/00`2`Xl/50:Vmj08000002@2Y
_NP20:Nlj@<0ZKgX102F]Nd50:joiPH0/L3U0P2]_^H30:foi`D0ZkkW1@2Y_NP00`000000oooo0?oo
o`0i0?ooo`00;03oool0102Y_NP0000000000000000_0:Vmj0H0ZKgW102W^NH50:Jgi@80YKKU0`2V
^^L50:_5kA@0ZKgX1@2RU<L409f7_0D0Tgbg102HOkL409b3]`80XHFg0`2XWL/50:^La`@0[Y[21@2f
]]T50;V/c080^j;00`2l`Mh50<6ab`H0a;gC1037[L020<G2e`D0bk701P3>/[h60=6a^PD0bJfm0P3G
^;/40;2Sb`80b;;500@0ZKgX00000000000000000P2Y_NP00`000000ZKgX0:Vmj00<0:Vmj0@0U[G]
1@2]_nL50;70i@H0[KoW1@2[_^L40:Vmj0030000003oool0oooo03T0oooo000[0?ooo`800000<`2Y
_NP30:Vmi`<0Z;_W102W^NH40:Jgi@H0Y[[W0`2[aNd20;?8jA00ZKgX102X[]`40::Da`D0WHNl102C
O;L409Qo]`@0W8>g1@2XWL/50:^La`80[Y[20`2b_n@50;Jff@@0^Jc<1P2l`Mh20<6ab`<0]lo/1P34
_M<20<N]`0<0aL;G103;/L020<S2e0@0c[:n0P3=_ld40=6a^P80dk_30`39[Kd40=Nh^`80/:?;00@0
b;;500000000000000001@2Y_>L00`000000ZKgX0:Vmj00<0:Vmj0D0UkG/1@2]_nL50;70i@D0[KoW
1@2[_^L50:Vmj0030000003oool0oooo03P0oooo000Y0?ooo`800000=P2Y_NP60:Rki`@0YkWV1@2T
]^D50:Jji`D0/lSY402Y_NP40:R^g0@0XYC7102MQk`409=l]`@0V7ng1@2SVl`50:RMb`@0Zic71@2b
_n@50;Jff@D0/M3`1@2l`Mh60;O?k0D0a;gC1P35`]L20<^a`0<0b<;D0`3>/[h30<foc@<0dK6j0`3C
^l<30<V]_@@0ekRk0`0000030<Rba@030=Jk_`2Y_>L0ZKcW00<0ZKcW00<000000:Vmj02Y_NP0302Y
_NP509Nek080[KoW0`2/_^L40;70i@H0[KoW102[_^L60:Vmj0030000003oool0oooo03L0oooo000M
0?ooo`050?oo_`1d000000000018W03Oool01`3oool200000380ZKgX1@2Y_>L50:Rki`D0YKKU1@2T
]^D50;;?k`D0/lSY402Y_NP30:R^g0@0XYC7102MQk`409=l]`D0WYK;102SVl`50:RMb`80Zic70`2^
a^`50;:oi080][KI0`2SfO/50;7@l0D0WMWl1@2gcn`60;3ClPD0aL;G1P38`]@00`3>/[h0cKo=0<fo
c@030<foc@030=6a^P3C^l<0dk_300<0dk_300@0bJfm0=Nh^`3G^;/0ekRk0P0000050<Rba@80e[^o
1@2Y_>L00`2Y_NP000000:Vmj00<0:Vmj0D0UkG/1@2/_^L20;70i@<0/L7U1@2]_nL50:^nj0D0ZKgX
00<000000?ooo`3oool0=`3oool001`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l70?ooo`03
0000003oool000000380ZKgX1@2Y_>L50:JiiPD0YKKU0P2T]^D30:Voj@D0//o_502Y_NP40:R^g0<0
XYC7102MQk`509R>b0@0WYK;1@2SVl`40:RMb`H0[/K/102b_n@60:?In`D0Pm[n1@2MfO`608WFo`D0
/=?b1@2_d_850<S2e0H0cKo=1P3C^l<0103G^;/000000000000000020=Nh^`040=Rn`@38//D0b;;5
0<Rba@<0e[^o1P2Y[m`00`2Y_NP000000:Vmj00;0:Vmj0H0UkG/102/_^L60;71i@D0[KoW1@2[_^P5
0:Vmj0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`050?ooo`8000000P3oool00`000000ZKgX0:Vmj00`0:Vmj0<0ZKcW0P2X^nL50:JiiP@0YKKU1P2Y
_nTD0:Vmj0D0U8O30`22M;/30::Da`D0THG3102HS/P509jFb`@0Xi_<1@2[bO050:k6k0H0Umkn1`1f
f?/308?JoPL0J/ol1029e_l507o@o`D0[m;b0P38`]@30;K>k0@0cKo=0P32bMl30=>k``<00000103G
^;/20=Rn`@<0b;;50`3F^kl00`3O`[/0ZJoL0:V_g0030:V_g0030:Vmj0000000ZKgX00`0ZKgX1@2G
]N`50:bni`D0/L7U1P2]_nL20:^nj0<0Z[kX1@2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool0
1`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`020?ooo`030000
002Y_NP0ZKgX0300ZKgX1@2X^nL40:JiiPH0Y;OV0`2Y_nT20;W>jPl0ZKgX1@2X[]`409B7``@0PWBk
0`29O;h40965``D0V8k8102NU//20:>Kc0<0ZLS`1@2[bO0609?QoPL0MM[i1P1WdOT4067=n0D0ElCi
1@1MaO/407o@o`@0[m;b1P2fc^`20<foc@<0`/WO0`0000030<o3c`<0ekRk103H_/401038//D0e[^o
0=Jk_`3F^kl30=o2^`80ZJoL0`2h^m`00`2Y_NP000000:Vmj00<0:Vmj0D0UkG/1@2/_^L50;71iPD0
[KoW1P2Z_^P40:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?noM000B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030000003oool0oooo00<0oooo;P2Y_NP50:Vli`D0Z;_W102T]^H60:Bg
iPD0^LkZ3`2Y_NP40:R^g0@0U8O31022M;/408Ul_P@0THG3102HS/P409jFb`H0ZLS`1`2Dhod607cN
n@H0LmOk1P1ad?h406;9n`@0ElCi1@1B_?X405Vno0@0Plco1@2fc^`20<;9g`<0000000<0`/WO0=>k
``3?`ll0103?`ll00`3G^;/0f;k10=Rn`@030=Rn`@@0e[^o0`3O`[/60;Rkg0030:Vmj0000000ZKgX
00`0ZKgX1@2G]N`20:bni`<0[KkV1@2a`NH50:foi`D0Z[kX1@2Y_NP00`000000oooo0?ooo`0d0?oo
o`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool2000000D0oooo00<00000
0:Vmj02Y_NP0:`2Y_NP50:Vli`D0YKSV102T]^H30:BgiP<0[L?Z1@2ic^X?0:Vmj0<0Z:kL1@2DQl<3
089d^`@0RGbn102AQL<409R>b0D0YlC^0`2Yb?0509[Uo0H0Qn?i0P21gO`508gJo`D0P=Ko1P1oc_l4
06o9o`@0G/7l101B_?X405Vno0@0Plco0`2Cbo/3000000@0`/WO1P3?`ll50=Rn`@80e/?70P3F^kl4
0=o2^`030>76_@2h^m`0^;_L00<0^;_L0P2Y_NP00`000000ZKgX0:Vmj00;0:Vmj0@0UkG/1P2]_^H5
0;71iPD0[KoW1@2Z_^P50:Vmj0030000003oool0oooo03<0oooo000L0?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0oooo00D0oooo00<000000:Vmj02Y_NP0:`2Y
_NP20:Vli`<0Yk_W1@2U^>H40:BfiPH0[L?Z502Y_NP30:R^g0@0U8O31022M;/408Ul_P<0THG31P2U
^nT40:O4kPD0V^Gl102Bj?T408kRo@<0V=gn1@2=f_l609C9nPD0UKS_1@23`o`406c1oP@0FKWl101?
]?X205jko@<000000`2Cbo/50:c;l0@0cl??0P35b=`30=Rn`@@0e/?700@0e[^o0=o2^`3O`[/0gl:k
0`3Qa[d20;Rkg0<0`<GN00<0ZKgX0000002Y_NP0302Y_NP509Nek0D0[KkV1P2a`NH20:foi`<0[;oW
1@2Z_^P40:Vmj0030000003oool0oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P0
07Bo1P3oool00`000000oooo0?ooo`070?ooob`0ZKgX1P2W^nL40:FhiPD0YKSW0`2]`nX30;K;jQ<0
ZKgX0`2X[]`409B7``@0PWBk1029O;h409n^hPH0YK_Y1P2Qi_`209;Xn@H0VNKl1P2HgOh609k4l`D0
YkcY1@2E^>l509Rgk@@0O[_j101V^Od205Ban`<000000P1A/?X5076mo@D0[<_`0P3?`ll40<G8g003
0=Rn`@3F`lL0e/?700<0e/?7103O`[/30>76_@H0`<GN00<0ZKgX0000002Y_NP0302Y_NP509Nek0D0
[[oV1@2a`NH50:boi`<0Z[kX0`2Z_NP40:Vmj0030000003oool0oooo0380oooo000M0?ooo`050?oo
_`1d000000000018W03Oool01P3oool00`000000oooo0?ooo`080?ooobP0ZKgX1@2Y_>P50:Nki`@0
XkKV1@2U^>L60;K;jPl0ZKgX102FT/h207=]_@@0U8O31022M;/509JLf0@0WjkR0`2U^nT40:SSn`@0
W>_i102RjO/60:7Po0D0YL;^0`2Na?<30:Vmj0D0YkcY1@2Y_NP509Rgk@@0O[_j0`1V^Od2000000<0
E;7k101A/?X4076mo@@0[<_`1P35b=`50=K3a`80dlK>0P3O`[/40>76_@030>?:_`30aMh0`<GN0080
`<GN0P32c^<00`2Y_NP000000:Vmj00<0:Vmj0D0Uk;[1@2^_nH50;32i`@0[;oW1P2Z_NP40:Vmj003
0000003oool0oooo0380oooo000W0?ooo`030000003oool0oooo00X0oooo:02Y_NP50:Vlj0D0YKSW
102S]^H30:Fhi`<0/<GZ1@2fbnX>0:Vmj0@0UY;>0`1cKKd407ei``@0RX[=1@2FW=P409n^hP@0Z>?k
102VkOT40:;Yn`@0Z>?k1@2Y`n`50:G2kPH0ZKgX0P2W_>T80:Vmj080V;O]0`2Y_NP309:dkP<00000
0`1a^?/305n`n`@0DZ[i101N/?/409;3n0<0aLSL0`2hanH30=K3a`@0dlK>00@0gl:k0>76_@3Qa[d0
hLJm0`3Sb[l20<35gP@0`/kS00<000000:Vmj02Y_NP0302Y_NP509Nbj`80[[oV0`2``>H40;32i`D0
[;oX1@2Z_NP50:Vmj0030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0oooo
:02Y_NP20:Vlj0<0Yk_W1@2U^>L40:>fiPH0/<GZ4`2Y_NP309JBcP@0Lffm0`1mNL<408Z:c@D0UYcH
1P2/g?P40:K]n@@0Znci1@2Xho/30:k9k@@0ZL?/6@2Y_NP3000000<0YkcY1021[_8306R_n@@0DZ[i
101N/?/409;3n0H0^<OV00<0e/?70=?6cP3Ca/h00`3Ca/h40>76_@<0hlZo1P32c^<00`2Y_NP00000
0:Vmj00=0:Vmj0@0Uk;[1@2``>H50;32i`D0[;oX1@2Z_NP50:Vmj0030000003oool0oooo0300oooo
000W0?ooo`030000003oool0oooo00`0oooo9`2Y_NP60:Nki`@0YKSW1@2U^NL30;35jP<0]LWY4P2Y
_NP409JBcP<0Lffm101mNL<408Z:c@80UYcH0`2Zc_<30:cLn0@0[ngh0`2[k?T60:oUn@H0[/W]6@2Y
_NP3000000030:Vmj02W_>T0YkcY00@0YkcY1021[_8406R_n@L0F:Oh101m^?T50;S7iPD0dlK>0P3?
b=820>76_@@0hlZo00@0iLo00<;>h`32c^<0`/kS0`2leN`00`2Y_NP000000:Vmj00<0:Vmj0D0V[7W
102``>H60;32i`80[;oX0`2[_^P50:Zmj0@0ZKgX00<000000?ooo`3oool0<03oool002L0oooo0P00
000>0?ooob<0ZKgX1@2Y_>P40:Nki`D0XkKW1@2U^NL60;G9j@l0ZKgX0P1eN<P409JBcP@0Lffm0`1m
NL<408Z:c@H0Z/kc1@2_kOP20;?]m`@0]^Sf1@2cdo430:k9kAP0ZKgX0`0000050:Vmj0D0YkcY1@2C
]>h4072]mP<0GjGf101HYoP407fhn@80^<OV0`2[`n/30=?6cP@0clSB00@0hLJm0>?:_`3Sb[l0hlZo
0`3Ucl060;cEk0030:Vmj0000000ZKgX00H0ZKgX1P2W_>T409Zai`D0/L;V1@2``^L60:^nj0D0Z[gX
102Y_NP00`000000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooob<0ZKgX1@2Y
_>P40:Fii`D0XkKW1P2aa>P40;G9j@l0ZKgX0`1eN<P306a]`P@0Lffm0`1mNL<50:6hj@<0Z/kc1@2d
jOL20;?]m`@0]^Sf0`2gh?@50;?ClAL0ZKgX0`00000>0:Vmj0D0TkC^101`[OH305nUmP@0FJ;e0`1a
[_L60:_3j`030=?6cP3?b=80clSB00<0clSB0`3Sb[l40>G?`0040>SD`@2leN`0_=G/0;cEk0<0Z[kX
00<000000:Vmj02Y_NP01P2Y_NP50:Nlj@D0XKGV1@2a`^H50:o1i`D0ZkkX1@2Z_NP50:Vmj0030000
003oool0oooo02h0oooo000W0?ooo`030000003oool0oooo00l0oooo8`2Y_NP50:Nkj0@0YKWW0`2S
]^L20:Fhi`H0/LCX4`2Y_NP207Ehb0@0K6g2101nP/d3096Mg0D0XKSY1@2djOL20;W^m0@0_>[c1P2g
h?@H0:Vmj0<000004P2Y_NP509jij`<0MZ_c101OYOH405VRm@<0LJkg1@2[`n/50<o8dP80c/SE00<0
hlZo0>G?`03Ucl000P3Ucl030>SD`@H0Z[kX00<000000:Vmj02Y_NP01P2Y_NP50:2ij`D0XKGV0P2a
`^H30;73i`D0[l7W1@2[_^P40:Zmj0D0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo0P00000A
0?ooo`030000002Y_NP0ZKgX0200ZKgX1@2W^nP40:Fii`D0YKSW0`2aa>P30;K;jQ80ZKgX0P1eN<P4
06a]`P@0OX;=102AWM`30:6hj@@0]Moe0P2ik_@40;cZl`@0_N;b1@2/`>PD0:Vmj0<000005P2Y_NP5
09jij`<0MZ_c101VXo<305fNl`@0LJkg1@2Q_Nd30<o8dP<0c/SE103Ucl040>SD`@030>cJ`02Z_^P0
Z[kX00<0Z[kX00<0ZKgX0000002Y_NP01`2Y_NP50:2ij`@0XKGV1P2a`nL20:o1i`<0[L7X102[_^P:
0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000ZKgX0:Vmj00P0:Vm
j0@0Yk_X1@2R]nL50:Fhi`H0]/_Z3P2Y_NP3061/b0<0MGS8101/KL8407j2c@@0TIgL102egoD30;k[
l`<0`^_a1@2mh_820;cDk0D0[<3X402Y_NP3000001X0ZKgX102N^N/407J[l`@0IZ?c0`1MW_<406fW
m0D0XKg]1@3>b=D0103>b]H0iLo00>G?`03Ucl030>SD`@<0k=[01P2Y_NP00`000000ZKgX0:Vmj006
0:Vmj0@0X;W[1@2X^^H50;73i`D0[L7X1@2Z_^P:0:Vmj0030000003oool0oooo02`0oooo00090?oo
o`0:0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3O
W4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000:Vmj02Y
_NP0802Y_NP50:Fij0@0X[OW1@2_`NL30;K;jQ00ZKgX101PK<P00`1TKLH0MGS806a]`P0306a]`P@0
OX;=1P2^c?040;k[l`<0`^_a1033iNl50;cDk080[<3X402Y_NP2000001d0ZKgX1@2S^nX407ZXl0@0
Jj7`0`1RW?0406fWm0D0W;W/0`3>b=D30<k:eP040>G?`03Xe<40j=C10>SD`@@0k=[000<0jnG:0:Vm
j02Y_NP00`2Y_NP00`000000ZKgX0:Vmj0060:Vmj0D0V[O/1@2X^^H50;73i`80[L7X0`2/_nP50:Zn
j0T0ZKgX00<000000?ooo`3oool02P3oool01@3OW4P000000000000004P0W=oo01d0oooo00080?oo
o`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00`3ogi`0B00007Boo`040?ooo`070?noM000
B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo01@0oooo00<000000:Vmj02Y
_NP06`2Y_NP50:Nlj0D0YKWX102S]nL50:o1ia<0ZKgX0`1PK<P206A]aP@0K6g21@2K[^D30:k<l0@0
_nCa1032jo440<?Uk`80`Mg]102le>`?0:Vmj0<00000802Y_NP50:>kjP@0NZS`0`1[XO0406:Ll0@0
KZ;a1@2L^N`00`3>b=D0c/[F0<k:eP020<k:eP@0j=C10`3/f/020>_UbPH0ZKgX00<000000:Vmj02Y
_NP01P2Y_NP509Zgk080Z;[V0`2]_nH40;73i`H0[;oX102Z_^P:0:Vmj0030000003oool0oooo00P0
oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3oool01@3o
ool2000001H0oooo7P2Y_NP50:Nlj0D0X[OX102S]nL30:o1i`<0^LkZ4@2Y_NP3061/b0<0I6g61020
RmD509^^i@@0_nCa1@36jNh40<?Uk`@0`Mg]3`2Y_NP3000002@0ZKgX1@2S^nX407fVk@80Kik]101R
W?0506jRl@@0W;W/103>b]H20=7<e@80j=C10`3/f/030>_UbP030=kdg02Y_NP0ZKgX00@0ZKgX00<0
00000:Vmj02Y_NP01P2Y_NP409Zgk0D0[KoV1@2``nP50:boj0D0Z[gX2P2Y_NP00`000000oooo0?oo
o`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo
0?ooo`0G0?oooad0ZKgX0`2W_>P20:Fjj0D0X[OX102S]nL60;W>jPh0ZKgX0P1GKm04061/b0<0I6g6
1020RmD209^^i@@0]mC_1@36jNh40<SVk0@0`Mg]0`2id>/;0:Vmj0<00000:02Y_NP50:>kjP<0OJK]
0`1_W^d406NIk@@0LYo]1@2M]^X20<k:eP@0dLcE0`3/f/030>_UbP<0g_CL1@2Y_NP00`000000ZKgX
0:Vmj0070:Vmj0@0V:gU0P2]_nH30;32i`D0/<?X1@2[_nP50:Zmj0T0ZKgX00<000000?ooo`3oool0
303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02L
gol01P3oool02`3ooml0W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo
00<000000?ooo`3oool0603ooolM0:Vmj0D0YK[X102R]nP60:bmia80ZKgX0`1GKm000`1IJLP0H6c8
061/b00406A]aP<0P8_E1@2ge>l40<GSk@@0b>K/1037gn/60;W@j`L0ZKgX0`00000/0:Vmj0@0Xk_Z
0`1mY^d406nNk@@0IiW]101bWnd409ffjPD0dLcE0`3HdM<30>_UbP@0g_CL1P2Y_NP00`000000ZKgX
0:Vmj0060:Vmj0@0V:gU1P2``^L20;33j0<0[/;X1@2[_nP50:Zmj0T0ZKgX00<000000?ooo`3oool0
1P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3o
ool0oooo00@0oooo0P00000K0?oooaP0ZKgX1@2X_>P50:Fjj0@0X[OW0`2/_NL30;[7iA80ZKgX0`1G
Km0205UYb0@0I6g61@2R]^L20;ODk`@0aN?]0`3;i>X40<OOj`<0aMWX0`2id>/60:Vmj0<00000;`2Y
_NP509jij`<0OZ;Z101bVnX306bGj@@0LYo]1@2R]nL30=7<e@@0f=7C0P3PfLl30=kdg0<0_=K]1P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0D0X[?U1@2``^L60:k2j080ZkoX0`2Z_^P40:Zmj0X0ZKgX00<0
00000?ooo`3oool01@3oool00`3ookl0M000000000020000000307Boo`3oool0oooo01/0oooo0008
0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`030?noM000M;l0oooo0080oooo
00D0_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo01/0oooo602Y_NP50:Rlj0D0
XkWX102R]nL60;[7i@l0ZKgX0P1MS>H305M_d0<0FFW8101oSmT50::fi`@0aN?]0`3;i>X30<cPi`H0
aMWX1@2Y_NP3000003<0ZKgX102N^N/407jRjP@0LY_Z0`1/UnT407RNjPD0X[OW1@3HdM<30>3Ic`03
0>WSbP2le^d0_=K]00@0_=K]1P2Y_NP00`000000ZKgX0:Vmj0050:2ij`D0X[?U1@2aa>P50:k2j0D0
Z[kX0P2Z_NP<0:Vmj0030000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool000P0oooo
00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0B01809cO
o`3oool0_g@007Boo`T0oooo00<000000?ooo`3oool0703ooolH0:Vmj0D0Y[_X1@2S^NP20::gi`<0
Yk[W102janD@0:Vmj080GHcV00<0Aek705M_d01GKm000P1IJLP507n?f@80X[KW102ldn/40<_TjP<0
c>3W0P3:fnH30<GIj0<0_M;Z00@0ZKgX0000000000000000=`2Y_NP409>bk0<0OikW101bVnX406bG
j@@0N9kZ0P2R]nL30:Zji@<0f=7C0`3PfLl20>WSbP80l>g42P2Y_NP010000000ZKgX0:Vmj02Y_NP5
0:2ij`80X[?U0`2[_>H50;74j0D0[L3X102Z_^P?0:Vmj0030000003oool0oooo00D0oooo00<0_g@0
07Boo`3oool07`3oool000T0oooo00D0oono07@00000000004RL0=ooo`050?ooo`050?oOW0180000
00000000001d_ol00P3oool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3o
ool07@3ooolD0:Vmj0@0Z;gX1@2V^nP40:>ij0H0Yk[W1@2cb>T>0:Vmj080GHcV0`17G/L305UYb0@0
OhoI102ldn/40<WNj0@0c>3W103:fnH40;gBjP800000>`2Y_NP409>bk0<0OikW101eV>H3076FiP@0
N9kZ1P2Z^^D0103HdM<0h=W?0>3Ic`3PfLl20>WSbP<0l>g400<0h_g<0:Vmj02Y_NP0202Y_NP01000
0000ZKgX0:Vmj02Y_NP40:2ij`H0ZkcV0P2aa>P30;34j0@0[L3X1@2Z_^P>0:Vmj0030000003oool0
oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo502Y
_NP40:Rmj0@0Y[_X1@2Q]nP30:Nji`<0/L3U1@2cb>T90:Vmj0D0T[K_0P1MS>H304MNa`80Mh[I1P2S
]^H50<WNj0@0c]kU103:fnH20<SEi0<0000000<0_M;Z0:c0j02/`>P0>`2Y_NP309>bk0@0OikW101e
V>H3076FiP@0P:3W1@2Z^^D30>3Ic`<0jN?:0P3`kL@30>;mc0X0ZKgX00@000000:Vmj02Y_NP0ZKgX
102J[^D50:^liPD0/<CX1@2[_nP50:Znj0h0ZKgX00<000000?ooo`3oool09P3oool002D0oooo00<0
00000?ooo`3oool07`3ooolD0:Vmj0@0Z;gX1@2T^^P40:6gj0H0/L3U3`2Y_NP309:fk`0302Q>``1M
S>H0Aek70080Aek70`1gR]T30:>fiP<0_<kX0`39g^P40<kNi@<0c]_S00@0b=GT0000000000000000
0P38eN@50:c0j3P0ZKgX0`2W_>T308VPh`<0P9[S101eV>H4076FiP@0P:3W1P2g`N830>WSbP80l>g4
103RoL`:0:Vmj0030000002Y_NP0ZKgX0080ZKgX102J[^D50;33j080/<CX0`2^`^T50:^oj0D0Z[gX
3P2Y_NP00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P0?oooa<0ZKgX1@2W
_>P50:Bjj0D0X[SX0`2a`>D20;W7i@l0ZKgX0`2B]^l00`0XC/<0Aek704MNa`0204MNa`<0Mh[I1P2l
c^P50<kNi@80c]_S0`0000030<SEi0<0aM3R0`2/`>Pg0:Vmj0D0YkcY1029X><3082Jh`@0N9GS0`1g
UN<508^Ti@@0]l7R0`37cMl20?3]a0<0h_g<0`2le^d:0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0X[?U
102``nP60:k2j@80ZkoX0`2Z_^P40:Zmj0h0ZKgX00<000000?ooo`3oool09@3oool002@0oooo0P00
000S0?oooa@0ZKgX102W_>P50::ij@D0X[SX1@2ianD?0:Vmj00401aUf@2B]^l0:4k302Q>``<0HgcF
1@2K[^@30;c>j0@0bMOT00@0c]_S0000000000000000103=e^460<G@hSX0ZKgX102W_>T408VPh`@0
P9[S101hUN<307NEh`D0RjCU0P2g`N830<O=g`80fMkJ0P3RoL`50;cFk@X0ZKgX00<0X;W[0000002P
^N/00P2P^N/50::ci@@0/LGY1@2^`^T60:Znj080Z[gX402Y_NP00`000000oooo0?ooo`0T0?ooo`00
903oool00`000000oooo0?ooo`0S0?oooa@0ZKgX1@2V^nP40::ij@80X[SX0`2X^nL50;W7i@l0ZKgX
00<076GI02Q>``0XC/<0101SO=H509^^i0@0bMOT0`0000000`3>f>40cMKQ0<gFh@030<gFh@80bm7N
0`35d>830;c:iCX0ZKgX102FZ><408RLg`<0PIKO101hUN<407NEh`@0RjCU1037cMl30=WNfP80j?3@
0P3[n[h>0:Vmj0030:2ij`000000X;W[0080X;W[0P2R/nD30:bni`@0/LGY1@2/`>P50:Znj1<0ZKgX
00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0903oool?0:Vmj0D0Z;gX1@2V
^nP30::ij@H0Z;_W1@2cb>T>0:Vmj08076GI00<0?6??02Q>``1SO=H00`1SO=H209^^i0<0]/GU0`00
00030<kHh@80cmGN0`3=e^440<_AgPH0_<[U>P2Y_NP309JXh`@0R9cO1021U]l407^Cg`@0OiSQ102I
[>@20<O=g`<0fMkJ0P3Xl=020>_j_P80e?cN3P2Y_NP010000000X;W[0:2ij`2P^N/50:bni`D0[lCY
1@2/`>P50:Zmj180ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?ooo`l0ZKgX1@2X
_NP20:Jkj0<0Y;[Y0`2Q^>T30:Rki`<0/KoT1@2cb>T90:Vmj0D0T[K_00<076GI03aSc`0lHll0101S
O=H20;K5i@<0000000<0]/GU0<kHh@3>f>400P3>f>440<oEgP@0bm7N0`38c=d30;c:i@<0]<CV>@2Y
_NP409JXh`@0R9cO1021U]l407^Cg`@0OiSQ102I[>@30=WNfP80j?3@0P3[n[h30=ClgPl0ZKgX00@0
000009VYhP2IZN80VJWR0P2/_^L30;34j@D0[lCY1@2[_nP40:Zmj1<0ZKgX00<000000?ooo`3oool0
8P3oool002<0oooo0P00000X0?ooo`l0ZKgX102X_NP60:Bjj@<0XKSY1P2a_n@?0:Vmj0<0T[K_00@0
03k001aUf@0lHll0?6??0`27W^8200000080]/GU1035c^850<oEgP<0c]7K1P38c=d60;C4iSP0ZKgX
102FZ><408RLg`@0PIKO101kTml407nHh@H0[;_T0P3Xl=020>_j_P@0e?cN3`2Y_NP0102IZN800000
09VYhP2IZN860;34j@80[lCY0`2]`NT40:^oj1P0ZKgX00<000000?ooo`3oool08@3oool000d0oooo
00/0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02L
gol0oooo00L0oooo00<000000?ooo`3oool0:03oool>0:Vmj0D0Z;cX102T^^T50:6hj@<0/KoT0P2i
`n8?0:Vmj0<0T[K_00<003k003aSc`0lHll00`00000208NNhPD0aLkR0`3;d=d20<oEgP<0c]7K0`3=
cMT30<S<g@80alSK0`2da>H30;2oiC80ZKgX0`2Y^nH309^WgP@0SicL1028Um/408:Cf`@0P9?M102;
W^440:bki080a=;U0P3[n[h20=ClgQ80ZKgX0P2W^^H00`000000Yk[V0:NjiP050;34j@D0[L7Y1@2Z
_^PG0:Vmj0030000003oool0oooo0240oooo000<0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo
103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z0?oo
o`h0ZKgX1@2X_>P40::ij@D0XKSY1@2i`n8?0:Vmj080:h;Y0`00000205f2gPD0Y[KU0P35c^850<_@
g@<0c]7K1@3=cMT50<O8f`H0/;oU;`2Y_NP50:VkiP@0VjON102?W=`408RGf`@0PY?K0`20Tmd508^N
h@80[;_T0`34d^D00`3Mkmd0hOg10>7m`@020=7na0d0ZKgX1@2L[N<00`2W^^H000000:NjiP020:Nj
iPD0/<GY0P2]`NT30:^oj0D0Z[kX5`2Y_NP200000240oooo000<0?ooo`070?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000/0?ooo`h0ZKgX1@2V_>T4
0::ij@D0YK[X1@2i`n8=0:Vmj0<0000000<0:h;Y000n`01MP]h00`1MP]h50:Jfi@D0bm3M0`3>cmX5
0<g=f@80blSG0`37b=/30<G4f@@0/;oU<02Y_NP50:VkiP<0VjON102?W=`408RGf`@0PY?K1020Tmd4
08^Nh@@0a=;U00<0gNoM0>7m`@3QoL400`3Ao/@>0:Vmj0D0W:gS00<0Yk[V0000002_`nT00P2_`nT4
0;35j@H0ZkoX0P2Z_^P30:Zmj1L0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?oo
o`0/0?ooo`h0ZKgX1@2V_>T40:2ijPD0YK[X1@2haN@90:Vmj0<000000`2Y_NP00`0[P^T03do;000n
`00405f2gP80Y[KU0`2h`n830<_@g@<0c/oJ0P3>c=P30<g=f@@0blSG00<0alSK0<G4f@35a=T00`35
a=T40:nkhS00ZKgX102Y^nH409BKf0@0SYOH1028TmP408FBf@<0R9SL1@2L[N<20<CBi@030=g_g@3Q
oL40hOg101<0ZKgX102L[N<20:o3j@040000002_`nT0[l?Y0:o3j@@0[/;Y1@2[_nP50:Zmj1L0ZKgX
00<000000?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0
oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3oool>
0:Vmj0D0YK_Y102P^NX30:Fjj080ZkcV1@2haN@50:Vmj0<000001`2Y_NP00`0[P^T03do;05f2gP03
05f2gPH0^<?R103>cmX40<k<f0H0blSG1@35a=T20<BoeP@0[k_R:`2Y_NP50:J/f`@0VIkH0`2DVmP4
08jGf0@0R9?H1025T]T408RHg0D0W:gS00D0gNoM0>7m`@3QoL40cofl0=7na00B0:Vmj0D0Y;KU00<0
[l?Y0000002_`nT00`2`aNX40:k2j@D0Z[kX102Z_NPH0:Vmj0030000003oool0oooo01h0oooo000<
0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d0000000000800000
00<0M;oo0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`X0ZKgX102X_NP50:Fkj@@0X;WZ
1@2[_>H50;?5j0040:Vmj00000000000000000X0ZKgX00<0036a00m?b`0?Cl/0101oWNH30;S3hP<0
`/ON0P3>cmX40<k<f080cLSE0`3;b=L30<W4e@<0aLCI1034_mH20:nkhP80/[SN9P2Y_NP50:Vch0@0
YZcK1@2IW]P309BKf0@0SYOH1028TmP408FBf@@0R9SL102eb>P20=;`i`040<om_03Ao/@0dOk40=7n
a0h0ZKgX102N[n<50:Bfi@030;35jP000000/<GZ0080/<GZ1@2/`>P40:Znj1d0ZKgX00<000000?oo
o`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO
09a8B02Lgol02@3oool200000340oooo2P2Y_NP40:Rmj0@0YK_Y1@2P^NX30:^liP<0/KoT00@0/lGX
00000000000000003P2Y_NP00`00<K409FOI00m?b`0407nMiPH0`/ON103>c=P40<g8e@H0bLCE1P34
_mH50;:hgPD0ZK_V7`2Y_NP20:Vgh`D0ZK?P102V[=/409VNf0<0U9_H102>UmP408RCf0@0QI;I1@2F
Y^420;G8j080d_3W00<0cofl0=7na03Ao/@00P3Ao/@?0:Vmj0@0WZoS1@2^`nT00`2`aNX000000:k3
j@020:k3j@D0[<3X102Z_NPL0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`060?oog`2LB000
M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo0340oooo
2P2Y_NP40:Rmj0D0Y;_Y102P^NX40;6oi08000001@2/`NP=0:Vmj003000a/@0UImT09FOI00@0V;3X
0`32amh30<O8f`80c/cH103=b=D20<c4d`@0bLCE0P38`=<30<BoeP<0`[cD0`2b^=h20;Rff0D0ZK_V
702Y_NP50:Vgh`@0ZK?P102V[=/509RId`<0TiKD102>Tm@408ZCeP@0RiOI1@2FY^420=;`i`030<om
_03Ao/@0ZKgX0180ZKgX1@2S]>D60:k3j@040000002^`nT0[/?Y0:k3j@D0Z[kX102Z_NPL0:Vmj003
0000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d000000000018W03Oool01@3oool01P3OW4P0
0000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool0<P3oool90:Vmj0D0Z;cX1@2T^nT4
0:2ijP<000000`2g`N450:c1j0`0ZKgX00@001:M02EWf@0UImT09FOI102H/>P60<O8f`@0cLSE103<
a=<20<W4e@@0b<3C1P32_=@50;Rff0D0ZZoK5`2Y_NP90:Vgh`D0X9kC102LW=<409RId`<0TiKD1@2>
Tm@408ZCeP@0RiOI0P2FY^430:o5j`040<_gjP2]kZ<0e?cN0=ClgPh0ZKgX1@2O[^850:>di@@0/<KZ
00<0[/?Y0000002^`nT00`2/`>T40:Znj240ZKgX00<000000?ooo`3oool06`3oool00280oooo0P00
000d0?ooo`X0ZKgX102X_>P50::jjP<0000000<0X;WZ0;O1h@2g`N40102g`N420:c1j0`0ZKgX0`2B
]^l010003YH0>ggT03]mi00kON@50:NjiP<0alSK0P38a]P20<g8e@D0c<CC1@38`=<20<Jld@@0`[cD
0P31^=430;Rff080_KCA1@2Z[m/50:R`g@@0ZKgX1@2Y^nH40:Vmj0D0ZK?P1@2Y]n<40:>PdP@0X9kC
1@2LW=<309RId`@0TiKD102>Tm@408ZCeP@0RiOI102_aN/00`3;mnX0[NjS0=ClgP030=ClgPh0ZKgX
1@2O[^850:g3jP@0/<KZ00<0[<3Y0000002/`>T00P2/`>T20:Znj0<0Z[gX802Y_NP00`000000oooo
0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`X0ZKgX102W_>T0102R^^X000000000
000000060::jjP@0]l7Q3`2Y_NP309:fk`04000>UP0kON@0>ggT03]mi0D0Yk[V1@38a]P50<c4d`80
b/7A0`38`=<40<Jld@80`[cD1031^=400`2h]]P0_KCA0;fdd@020;fdd@80ZZoK0`2f[m<50:R`g@@0
Z:gK1@2Y^nH40:R]fPD0ZK?P1@2VX]430:>PdPD0X9kC102LW=<309RId`@0TiKD1@2@U=<4092Hf0@0
UjKP0P2_aN/00`3;mnX0[NjS0=ClgP0C0:Vmj0D0Y;KU102]`nX50:k3jP040:c0j@000000[<3Y0:c0
j@H0Z[gX802Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`03
0000002Y_NP0ZKgX00L0ZKgX00@0YkcY00000000000000001@2Q^^/50::jjP@0^L7P3`2Y_NP408>`
lP<0>ggT0P2W^^H30;2ni0<0b<KH0`38a=H20<c4d`@0b/7A1P36_=460<6hd@D0_KCA1P2f[m<20:R`
g@<0/ZcB102X[M/20:VkiP<0ZJKC102X[MX20:Vch0<0ZJ?@102VX]440:>PdP@0X9kC1@2KV<l309NF
d0@0TiCA102@U=<5092Hf0<0UjKP0P3;mnX0102koMh000000;cFk@2le^d>0:Vmj0D0WZcQ102T]^D5
0:o6j`D0[/?Z00@0Z[kX0000002Z_^P0Z[kX1@2Z_NPP0:Vmj0030000003oool0oooo00`0oooo00<0
omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00@0oooo000R0?ooo`030000003o
ool0oooo03L0oooo1P2Y_NP3000000D0Y[cY102Q^^/50:Bkj@@0^L7P3`2Y_NP408>`lP80BXg/1P2`
_^@60<S4eP@0b/7A0P38_M040<Jld@80aKW?1031^=420<6dcP<0_KCA0P2l/Lh50;J_d`H0/ZcB0`2X
[M/60:VVd`<0Z:gJ1@2YXm050:JRd@<0Xj3B1@2OV/l409^Hc`<0UiK@1@2CU=44092Dd`@0T9SH102`
cNl00`2koMh0_=K]0;cFk@030;cFk@h0ZKgX1@2N[>420:Bfi@80[/C[1@2_a^/50:_0j@040000002Z
_^P0Z[kX0:Znj2D0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0
gia8001d_`@0oooo000Q0?ooo`800000>P3oool20:Vmj0<00000102Y_NP50:Jlj@@0X;[[1@2T^nT5
0;W1h0d0ZKgX1@23/?8204Z=k0<0/;kT0`2d`N<40<S4eP80b<;D0P3:`M440<Rmd080a[cA1035^Ll2
0<6hd@@0`KC>00<0_KCA0;bacP2l/Lh00P2l/Lh20;J_d`<0^:g>1@2b[=840;:Yc`D0ZJKC102/Y<l5
0:VSd0@0YZ;A102RW<h409nJc`D0ViS?0`2GU]0409>Dd@@0T9CC1@2L[N<20;3=k`030;_mgP2cm[@0
/oJd00@0_=K]3`2Y_NP409j/h@D0[/C[1@2]`nX40:_0j@030:Zmj0000000Z[gX0080Z[gX9@2Y_NP0
0`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool00240oooo00<000000?ooo`3oool0>03oool3000000P0ZKgX1@2V_>T40:2jj`@0
Y;_Y1P2i`N0=0:Vmj0D0Pk3b0P1>U_460;C1h`80b<CF1038`]@50<Rmd0H0aKW?1P31]<h50;bacPH0
^:g>0P2b[=830;FYc@@0/ZW?0P2YY]<30:nTc@@0[:C?102YXm050:FMc@<0XYc>1@2OV/l409^Hc`<0
UiK@1@2EUm<409JMf@@0W:gS0P2koMh30;?f]1<0ZKgX1@2W^^L20:k4j`<0[lK[102]`nX50:Znj003
0:Zmj0000000Z[gX0080Z[gX902Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?oo
o`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0=P3o
ool2000000<0oooo1@2Y_NP50:Rmj0@0Y[cY0`2P^^/50:Flj@H0^L7P3@2Y_NP509:fk`80CYKa1@2d
`N<50<S2e080a/3D0`38_M020<Nkc`@0aKW?0P34]/d40<6dcP80_k7<0`2l/Lh20;b]c0D0^:g>1@2e
ZLd40;:Yc`D0[jC=102/Y<l50:RNc0@0YIg=102RW<h409nJc`D0ViK>0`2HU]0409FGd`D0UYgI0P2L
[N<20;?Rm`030;?f]02Y_NP0ZKgX0100ZKgX1@2LZMl40:Nji`H0[lK[102[_nT50:Znj0030000002Y
_NP0ZKgX02H0ZKgX00<000000?ooo`3oool02@3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`800000=03oool3000000H0oooo1@2Y_NP50:Rm
j0@0YKcY102P^^/40:Flj@H0^L7P3@2Y_NP409:fk`<0CYKa1@2d`^@30<S2e0@0a/3D00<0b;g@0<Nk
c`37^ll00P37^ll20<Fic`@0a;K=0P31]<h40;nac0040;bacP2l[L`0_:g<0;b]c0@0^:g>0P2hZL/5
0;FYc@80/ZW?0P2bYL/50:nTc@80[:C?0P2[Wl/40:RNc0D0YIg=0`2RW<h509jHc@@0ViK>0`2HU]05
09FGd`@0UYgI0`2ch_L30;cFk@d0ZKgX1@2Y]N4409bYg`D0[/K[0`2_a^/30:c2j@@0ZkoY1@2Z_NP0
0`000000ZKgX0:Vmj00V0:Vmj0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oO
W018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<0
00002@3oool60:Vmj0D0Z;gX102U_>T40:2jj`@0Y[cY0`2i`N030;S0h140ZKgX0`13V?850;C2i0H0
a/3D1@37^ll60<Bfc@H0_k7<1@2l[L`20;R]cP<0^:W;1@2eZLd40;:Ub`D0[jC=102[Wl/50:RNc0@0
YIg=102RVL`409jHc@@0ViK>102HU]0409FGd`D0Y;o/00<0WOCS0;cFk@2le^d00P2le^d>0:Vmj0D0
ZKGQ102Z`>T50:k6j`D0[<;Y0P2[_nT30:Znj0@0Z[gX00<0ZKgX0000002Y_NP09P2Y_NP00`000000
oooo0?ooo`060?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`030?ooo`00103oool03@3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3o
ool0oono07@0B02Lgol0103oool01@3OW4P000000000000004P0W=oo00L0oooo00<000000?ooo`3o
ool0;@3oool3000000h0oooo102Y_NP60:Rmj0<0YKcY1@2O^^`40:Jlj@H0^<3P4@2Y_NP304>HlPD0
/LCX0`36`=@30<C0eP<0ak_?0`35^/l30<Bfc@80`kC<102o/L`20;n_b`@0_:g<1P2hZL/20;FYc@<0
]:K:102bYL/20:nTc@<0[Z7:102[Wl/40:RNc0D0YI_;0`2RVL`509jHc@<0ViK>102HU]0509f[h0<0
Y;o/00<0WOCS0;knf@2no]T04P2Y_NP50::ci0@0Z/3Y1@2^aN/40:c2j@H0Z[kX1@2Y_NP00`000000
ZKgX0:Vmj00U0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0
W4P007Boo`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P004RLg`3oool0gia8001d_`D0
oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool0
0`000000oooo0?ooo`0Z0?ooo`<000004P3oool40:Vmj0D0Z;gX102U_>X509njk0@0Y[gY0`2h`>03
0;W0h180ZKgX0P0PS>/50;74j0H0a<3F1P35^/l50<>dc080_k7<102o[l/20;b]c080^jc:1@2hZL/5
0;BVbP@0/ZG;1@2^XLX40:^Ob`D0Z9c:102UVl/40::Ic0@0WYS=102MWM<409bQf0D0WJ_P00<0WOCS
0:Vmj02Y_NP0402Y_NP50:6/g`@0X[?T1@2^an`40:k5j`D0ZkoX0`2Z_^P70:Vmj0030000002Y_NP0
ZKgX0240ZKgX0`0000000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo00D0oono
07@00000000004RL0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
1@3oool00`2oM000B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<00000
5P3oool40:Vmj0D0Z;gX102U_>X509nkk0@0Y[gY1P2i`>050:VkiPd0ZKgX00<0032`022<j`2aa>P0
0P2aa>P20:O6l0@0a<3F0P31`]/40<Fjc`80`k[A1033]<`60;n_b`D0^jc:0P2hZL/30;RXb@@0]:K:
1@2aXlT50:jQbP80Zio;0P2[W/X40:RLbP@0YI_;102RVL`509nLd0@0WIgC102LXMP40:OVna00ZKgX
102Y]N450:6/g`80X[?T0P2/aN`50:k7k0@0[<7Y1@2[_nP:0:Vmj0030000002Y_NP0ZKgX01`0ZKgX
0`0000050?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103oool00`000000
oooo0?ooo`0U0?ooo`<000006P3oool50:Vmj0@0Z;gX1@2U_>X409nkk0D0YKgZ0`2i`>020;W1g`D0
ZK_V3@2Y_NP202^2j@D0YlK`0P34`=H40<72f`80aK[?1033^]420<>dc080`[C=102o[l/20;j`c0@0
^jc:1@2hZ<T30;BVbP80]:G91@2aXlT40:jQbP@0Zik:1@2XW<X30:FKb`D0Xic?1@2OW=0309fMd`H0
YLge4`2Y_NP40:Veh@@0XJcO1@2/aN`50:g3jP@0[<7Y1@2Z_^P:0:Vmj0030000002Y_NP0ZKgX01P0
ZKgX0`0000080?ooo`030000003oool0oooo01D0oooo00030?ooo`070?noM000B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2L
B4P0W=oo00D0oooo00<000000?ooo`3oool08P3oool3000001h0oooo1@2Y_NP40:Rmj0D0YKcZ102P
^n`50:FmjPD0^L7O0P2Y^nH30:bhhPd0ZKgX0`0[P^T30:O6l0H0`L;K1P33^]450<:dc@80_jo;0`2n
/<`30;^/bP80^jc;1@2hZ<T0102dY/X0]:G90;BUb@2dYLT50;6Sb@D0[Z7:102[W/X40:RLbP@0YYk>
1@2SW<l409nLd0@0Y;g[0`2UcOD20:Znj1<0ZKgX102Y]N450:Rnj@80[<G/0`2]a^`40:g3jPT0Z[kX
2`2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0@00000303oool00`000000oooo0?ooo`0D0?ooo`000`3o
ool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono
07@000<0000000<0M;oo0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000008P3oool5
0:Vmj0@0Z;gX1@2U_>X40:2kk0D0Y;g[102i`Ml60:bhhPd0ZKgX0`2B]^l308g8o0<0`L;K0`2ib>H4
0<>jd@80`L3I1032]<d60;j`c0040;^/bP2k[</0^jc;0;^/b`D0^:S91@2dYLT20;6Sb@<0/ZG;102^
XLX40:^NbPD0ZJ3>102VW/h40:>Lc`D0Y;GU102T_N/00`2ke^d0Z[kX0:Znj0020:Znj180ZKgX1@2S
/n@40:Rnj@H0[LK/102[_nT50:Znj0h0ZKgX00<000000:Vmj02Y_NP03`2Y_NP0103oool000000000
0000000@0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2
000002H0oooo00<000000:Vmj02Y_NP00P2Y_NP50:Rmj0@0YKcZ102P^n`50:Bmj`@0]l7Q0`2/^>83
0;:kh100ZKgX0`2=b?`60;W8iP80`k[A1031`=T20<:dc@80`;WC1@2n/<`50;^/b`80^:S90`2hZ/`4
0;BUb@D0/ZG;1@2^XLX20:^NbP80[:C?102YX<h40:JNcPD0Y[;Q102T]ND20:Bmj`@0^mK]402Y_NP3
0:V`g@<0XJ_N1@2S/n@50:g7k@D0Zl7Y102[_nTC0:Vmj0030000002Y_NP0ZKgX00X0ZKgX0P3oool3
000001<0oooo00<000000?ooo`3oool0503oool000<0oooo00H0oooO09a8001d_ol0oooo0=nLB000
M;l80?ooo`060?noM000B9`0gooo0?ooo`2oM000M;oo203oool2000001`0oooo0`00000Z0?ooo`@0
ZKgX1@2X_NP40:Jlj@@0X;_/1@2R_N`40;O1h@H0/[_P4@2Y_NP203jbl`D0^LSV1P31`=T50<2id`80
_[3<0`2n]M440;^/b`H0^:[<0P2dYLT20;F[c`D0/ZG;102^XLX40:bTc`D0ZJ3>0P2VW/h20:Vch0D0
Y[;Q0`2T]ND00`1fhn@0[mkg0:Vmj00A0:Vmj0D0ZK3M102QZmh50:c5k@80[LO]0`2/`n/40:_1j@D0
Z[kX4`2Y_NP00`000000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00
103oool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0
oooo0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0
oooo102Y_NP50:Rmj0@0Y[cY1@2Q_>`40::mk0@0/L7U1@2b^n0C0:Vmj00309:fk`2Pe?X0X=Cj00<0
X=Cj0`31`=T30;O>j`@0`;WC1P2n]M420;^/b`80^kCB1@2hZ/`40;F[c`D0/ZG;1@2`Z]840:bTc`@0
ZJ3>1@2Y/n040:Jbh@80M^?T4@2Y_NP50:Veh@@0ZK3M1@2Y`N/40:c5k@H0[<?[2@2Z_^PB0:Vmj003
0000002Y_NP0ZKgX00D0ZKgX0P00000J0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000
003oool0oooo01D0oooo0`00000b0?ooo`@0ZKgX1@2X_NP40:Jmj@D0XKc/102P_>d40;71i@D0][gO
0`2Y_NP20:VehA40ZKgX0`2Pe?X60;O>j`80`;WC0P2kb>@50;jed@D0^kCB0P2hZ/`30;Vgf0@0]J_?
0P2bYL/30;>cf0@0/:[B102/Y<l50:bhhP@0ZK?P0P1niNlB0:Vmj0@0ZK[V1@2Y]N440:Jkj0D0ZL7[
102]aN`30:c3j`<0ZkoY102Z_^PG0:Vmj0040000002Y_NP0ZKgX0:Vmj08000007@3oool00`000000
oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo0`00000f0?ooo`T0ZKgX102V_NT50::lj`@0X;c]
1@2[`>T40;Jmg`D0ZKGQ502Y_NP50;O>j`D0^lST0P2n]M430;[7i0@0^kCB1@2i]mP40;F[c`D0/k?H
102`Z]850:k1j0D0[;SR00<0NN?^0:Vmj02Y_NP05@2Y_NP40:VjiPD0Y;CS102V^nP50:c7k@@0[LG/
1@2[_nTK0:Vmj0<00000803oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?oo
o`0?0?ooo`<00000>P3oool90:Vmj0@0YkgY1@2R_>/409nlk@D0Zl3Y102i`N050:VehA@0ZKgX1@1d
eo/40;_8i0H0^/OT0P2k]=820;K>k0D0^KOH0P2eZll20;G4i@D0/k?H0P2`Z]820:g?lPD0[/7X0P1U
f^0J0:Vmj0D0XjkO102T]><50:c7kP@0[<O]1@2[`NT30:^oj@80Z[kX5P2Y_NP3000000<0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0<
0?ooo`<00000?P3oool90:Vmj0@0YkgY1@2S_>/409nlk@D0YKo/102i`N050;6ig`<0ZKgX0P2Y]N4D
0:Vmj0@0Qmom1@2jan@50;K>k0@0^KOH1@2ea>D40;>cf0D0[Lob0P0f^[HK0:Vmj0@0YZgL1@2S[]l4
0:_6kPD0[<O^102[`^X50:_1j@D0Z[kX4P2Y_NP3000000H0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`<00000@P3oool90:Vm
j0D0Z;gY102S_>/40:2lk@D0YKo/102b`^H50;6ig`D0ZKGQ602Y_NP507OMmP@0]/k/1@2Wgo/40;G4
i@H0W>?m702Y_NP50:V^f`@0YZgL0P2S[]l30:W4k@@0ZlK^1@2[`n/40:_2jPL0Z[kX402Y_NP40000
00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2000000T0
oooo0P0000160?ooo`T0ZKgX1@2X_NT40:FljP@0X;c]1@2Q_^h40;;2iPD0^;oP102Y]N4S0:Vmj0@0
Ymok8P2Y_NP40:V^g0D0ZJkK0`2V[M`50:W4k@D0ZlG/102[`n/90:Znj0h0ZKgX00@0oooo00000000
000000003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo000N0?ooo`03
0000003oool0oooo00D0oooo0`0000190?ooo`T0ZKgX1@2X_NP40:FljP@0X[c/1@2Q_^h40:S1j`D0
^;oP102a^Mh30:Vmj080ZK7N?`2Y_NP90:V^g0@0ZJkK1@2Y`^`40:_5k@D0ZlG/102Z_nT50:Znj0h0
ZKgX00@0oooo00000000000000004`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01<0oooo000N0?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`030000002Y_NP0ZKgX00H0
ZKgX1@2X_NP40:Jmj@@0X[c/1@2P_Nh40:S1j`D0//;V102a^Mh50:VagPD0ZK?O;`2Y_NP20:VjiPD0
ZKgX102Y[]/80:V^g0D0ZL7[0P2Y`^`30:[6kP@0ZlG]1@2Z`>T40:Zoj@h0ZKgX00<0oooo00000000
00000P00000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo
00<000000?ooo`0000000P00001A0?ooo`030000002Y_NP0ZKgX00/0ZKgX102V_NT40:Bmj`D0X;g^
102R_nh50;;2iP@0^L7Q0`2Y/Mh20;Jng`D0ZK?O102Y/n0X0:Vmj0D0ZK[V2@2Y[]/30:V^g0D0ZL3Z
102Y`N/60:[6kP@0Z/3Z102Z`>T50:Znj0/0ZKgX0`00000K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool04`3oool001h0oooo0P00001E0?ooo`030000002Y_NP0ZKgX00/0ZKgX102X
_NT40:Bmj`D0X[g/102R_nh50:K1k@@0^L7Q1@2f_]l20:Vcg`<0];_O102Y/n050:Vbgah0ZKgX1@2Y
]N430:VjiP80Zk7L202Y[]/90:W0jPD0Z/K^1@2Z`NX40:[0jP@0ZKkX1@2Z_^P80:Vmj08000007`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo000C0?ooo`030?oOW01807@0
_ooo00T0oooo00<000000?ooo`3oool0E03oool00`000000ZKgX0:Vmj00;0:Vmj0@0Z;gY1@2V_NX4
0::mk0@0XKk^1@2V`Nd40:c2j`@0][kO1P2d^ml20:Vch080/[[N1@2Y/]l40:V`g@@0ZKgX1@2Y]N44
0:Vmj0D0ZKGQ102Y_NP40:V`g@D0ZKGQ1@2[/M`30:V^f`D0Z/7[102Y`>X50:W6kPD0Z/7[102Z`NX5
0:Znj0@0ZKkX2@2Y_NP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool02P3oool2000005H0oooo3@2Y_NP40:Rm
j0D0Y[gZ102T_N/40:6nkPD0XKo^102/`^/40:o3j0D0];_O1@2b^]h20:Vbg`<0];_O102Y/=d40:V^
g0D0ZKGQ102Y[m`40:Veh@D0ZJkK102Y/=d50:ngg`@0Zk7L102Z`n`50:[1j`D0ZLK_102Y`N/50:[1
j`@0ZKkX102Z_^P90:Vmj08000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0180oooo000C0?ooo`030?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0E03oool=0:Vmj0@0
Z;gX1@2W_NT40:Bmj`@0Xkg/1@2Q_nh40:?1kP@0[l?X1@2``nP40;:jgPD0];_O0P2Y/=d30;Jnh0@0
ZJkL1@2a^=h40:V_g0@0/KSN1@2Y[]/40:jmi@@0[kOO1@2Ya>d40:[3k0D0Z<K_0P2Ya^l70:W1j`D0
Z[kX102Y_^P90:Vmj0800000:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180
oooo000C0?ooo`030?oOW01807@0_ooo00d0oooo00<000000?ooo`3oool0E03ooolA0:Vmj0D0YkgY
102V_NT40:>mk0D0X[k]102S`Nh40:C2kPD0/<?X102_`nT40;Bkg`H0][kP0P2Y[]`20;72iP@0/KSN
0P2Y[m`30;30iP@0/KSN1@2/`^X40:jmi@@0Z<G^1@2Ya>d40:S5k`@0Z<K_1P2Y`N/40:Vnj@@0Z[kX
2@2Y_NP200000300oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3o
ool00`3ogi`0B01d0;ooo`0>0?ooo`030000003oool0oooo05@0oooo4@2Y_NP50:Rmj0@0Y[gY102U
_NX50::nk@@0X[o^102T`^h50:C2k`@0[l?Y102/a>/50;Jnh0D0/L;V0`2a^=h60;30iP80/KSN0P2Y
aNh40:c2jPD0YlG_102XaNh50:O4kP@0Z<G_1@2Y`N/90:Vnj@P0ZKgX0`00000c0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03`3oool0
0`000000oooo0?ooo`1D0?oooa40ZKgX2@2X_NP40:FmjPD0YKg[202R_nh90:C2k`@0[<C[1@2Xa>d4
0;72iPD0ZlC/102``>H50:W5kP@0Y/G_1@2WaNl40:O3kP@0YlC^1P2Y`N/80:Vnj@T0ZKgX0`00000g
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000
B02L_i`0B01d0;ooo`0@0?ooo`800000E@3ooolF0:Vmj0@0Z;gX102W_NT50:Fmj`@0YKk[2@2R_nh4
0:C2k`@0Xl;_1@2Xa>d50:G4k`@0Y<?_1@2VaNl40:G3k`@0Y/G_1@2W`^d40:O3kPD0Z<3Z1@2Y_^P4
0:Vnj@P0ZKgX0`00000l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3oool0
0180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?ooo`1C0?oooaX0ZKgX2@2W_NT9
0:Fnj`@0X[o^1@2S`>d80:?2k`D0YL7]102T`nl50:G1k@@0YL?_102W`N`40:O2k@H0Z;oZ202Y_^P9
0:Vmj0<00000@03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo000C0?oo
o`030?oOW01807@0_ooo01<0oooo00<000000?ooo`3oool0D`3ooolN0:Vmj0h0YkgY102U_^/50:Jn
j`@0Y;o]102V_n/50:G1k@@0Y[o/102U`Nd50:Noj`@0Yl7/102X_^T30:RojP<0ZKgX102Y_^P80:Vm
j0@00000@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`03
0000003oool0oooo05<0oooo:02Y_NP40:Nmj@@0Z;gY1@2V_^/40:NnjP@0Y[o[1@2W_^X40:Jok0@0
Z;kZ1@2W_n/40:Vnj@@0Z;kY3P2Y_NP3000004P0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo;02Y_NP90:Rmj@@0YkkZ102X_^T50:NnjP@0Z;kY
102X_^X50:Vnj0@0ZKkY3@2Y_NP0103oool0000000000000001<0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool0DP3oool`0:Vmj0D0Z;gY
102Y_NP40:Rnj@D0ZKgX102X_^T40:Vmj0@0ZKkX3P2Y_NP4000004l0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?oooeP0ZKgX0`00
001D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool002l0oooo00<00000
0?ooo`3oool0DP3ooomC0:Vmj0040?ooo`0000000000000005P0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0A0?ooo`00<03oool00`000000oooo0?ooo`1B0?ooodl0ZKgX1000001L
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00340oooo0P00001C0?oo
odX0ZKgX00@0oooo0000000000000000H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo000c0?ooo`030000003oool0oooo0540ooooAP2Y_NP4000006@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`00=03oool00`000000oooo0?ooo`1A0?oood80
ZKgX0`00001Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003D0oooo
00<000000?ooo`3oool0D@3ooolm0:Vmj0040?ooo`0000000000000006`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0@0?ooo`00=P3oool200000580oooo>@2Y_NP400000700oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`00>03oool00`000000oooo0?oo
o`1@0?ooocD0ZKgX0`00001e0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403o
ool003T0oooo00<000000?ooo`3oool0D@3oool_0:Vmj0040?ooo`0000000000000007T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A
0?ooob/0ZKgX1000001l0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
03/0oooo00<000000?ooo`3oool0D@3ooolW0:Vmj0<00000P@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00l0oooo000l0?ooo`800000DP3ooolR0:Vmj0040?ooo`00000000000000
08D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`00?P3oool00`000000
oooo0?ooo`1@0?oooah0ZKgX100000290?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03`3oool003l0oooo00<000000?ooo`3oool0D03ooolJ0:Vmj0<00000S@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00100?ooo`030000003oool0oooo0500oooo5P2Y
_NP300000940oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00@@3oool2
00000540oooo4P2Y_NP3000009D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?
0?ooo`00@`3oool00`000000oooo0?ooo`1?0?ooo`d0ZKgX0`00002I0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03`3oool004@0oooo00<000000?ooo`3oool0D03oool80:Vmj0<0
0000W@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00150?ooo`030000
003oool0oooo0500oooo102Y_NP300000:40oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0>0?ooo`00AP3oool200000540oooo0P00002V0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool004P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03P3oool004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool004`0oooo0P00001;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0>0?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`00C`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`00D03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool2000004H0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
001C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0[03oool01@000000oooo0?oo
o`3oool0000000l0oooo001D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0[P3o
ool010000000oooo0?ooo`00000?0?ooo`00E@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005H0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0000000l0oooo001G0?ooo`800000?`3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0000000h0oooo001I0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001J0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001K0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0/@3oool2000000h0oooo001L0?ooo`800000>P3oool00`000000oooo0?oo
o`2]0?ooo`@00000403oool005h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Y
0?ooo`@00000503oool005l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2U0?oo
o`@00000603oool00600oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2Q0?ooo`@0
0000703oool00640oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2N0?ooo`<00000
803oool00680oooo0P00000d0?ooo`030000003oool0oooo09X0oooo1000000S0?ooo`00I03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09H0oooo1000000W0?ooo`00I@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0980oooo1000000[0?ooo`00IP3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo08h0oooo1000000_0?ooo`00I`3oool2000002l0oooo
00<000000?ooo`3oool0RP3oool4000003<0oooo001Y0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0Q`3oool3000003L0oooo001Z0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0P`3oool4000003X0oooo001[0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0O`3oool4000003h0oooo001/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0N`3oool400000480oooo001]0?ooo`800000:@3oool00`000000oooo0?ooo`1g0?ooo`@00000
AP3oool006l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1e0?ooo`<00000BP3o
ool00700oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1a0?ooo`@00000C@3oool0
0740oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000D@3oool00780
oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000001E0?ooo`00M03oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo06D0oooo1000001I0?ooo`00M@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0680oooo0`00001M0?ooo`00MP3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo05h0oooo1000001P0?ooo`00M`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo05X0oooo1000001T0?ooo`00N03oool2000001d0oooo00<000000?ooo`3o
ool0EP3oool4000006P0oooo001j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
DP3oool4000006`0oooo001k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3o
ool400000700oooo001l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool3
000007@0oooo001m0?ooo`800000603oool00`000000oooo0?ooo`170?ooo`@00000M`3oool007l0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`130?ooo`@00000N`3oool00800oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`@00000O`3oool00840oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`@00000P`3oool00880oooo0P00000C
0?ooo`030000003oool0oooo03P0oooo0`0000270?ooo`00Q03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo03@0oooo1000002:0?ooo`00Q@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0300oooo1000002>0?ooo`00QP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo02`0oooo1000002B0?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02P0oooo1000002F0?ooo`00R03oool2000000d0oooo00<000000?ooo`3oool09@3oool3
000009X0oooo002:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool40000
09d0oooo002;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000:40
oooo002<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000:D0oooo
002=0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?ooo`@00000Z@3oool008l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000[@3oool00900oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000/@3oool00940oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000]03oool00980oooo00D000000?ooo`3oool0
oooo000000090?ooo`@00000^03oool009<0oooo0P0000000`3oool000000?ooo`040?ooo`@00000
_03oool009D0oooo0P0000000`3oool000000000000200000<00oooo002F0?ooo`800000a03oool0
0?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool0
0?l0ooooG@3oool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55714 .53837 .55103 Mtetra
.53837 .55103 .54423 .55714 .55522 .55384 .54938 .5477 Mtetra
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .54101 Mtetra
.664 .741 .908 r
.57154 .54101 .57732 .54719 .58844 .54385 .58269 .53765 Mtetra
.663 .741 .908 r
.58269 .53765 .58844 .54385 .59961 .54049 .59388 .53428 Mtetra
.59388 .53428 .59961 .54049 .61081 .53713 .60512 .53091 Mtetra
.663 .742 .909 r
.60512 .53091 .61081 .53713 .62207 .53376 .61641 .52752 Mtetra
.61641 .52752 .62207 .53376 .63337 .53036 .62774 .52413 Mtetra
.663 .743 .91 r
.62774 .52413 .63337 .53036 .64471 .52696 .63911 .52071 Mtetra
.63911 .52071 .64471 .52696 .6561 .52354 .65054 .51728 Mtetra
.663 .744 .91 r
.65054 .51728 .6561 .52354 .66754 .52011 .66201 .51382 Mtetra
.664 .744 .91 r
.66201 .51382 .66754 .52011 .67902 .51665 .67352 .51034 Mtetra
.67352 .51034 .67902 .51665 .69055 .51318 .68508 .50684 Mtetra
.665 .744 .91 r
.68508 .50684 .69055 .51318 .70213 .50969 .69669 .50331 Mtetra
.664 .744 .909 r
.69669 .50331 .70213 .50969 .71375 .50618 .70835 .49976 Mtetra
.665 .744 .909 r
.70835 .49976 .71375 .50618 .72542 .50266 .72005 .49619 Mtetra
.665 .743 .908 r
.72005 .49619 .72542 .50266 .73714 .49912 .7318 .49261 Mtetra
.665 .742 .908 r
.7318 .49261 .73714 .49912 .74891 .49557 .74361 .48902 Mtetra
.664 .742 .908 r
.74361 .48902 .74891 .49557 .76073 .49202 .75546 .48542 Mtetra
.664 .741 .907 r
.75546 .48542 .76073 .49202 .77259 .48844 .76735 .48182 Mtetra
.76735 .48182 .77259 .48844 .78451 .48486 .7793 .4782 Mtetra
.7793 .4782 .78451 .48486 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80848 .47764 .80335 .47093 Mtetra
.80335 .47093 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .4636 Mtetra
.8276 .4636 .83266 .47036 .84483 .4667 .83981 .45991 Mtetra
.83981 .45991 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44874 Mtetra
.87672 .44874 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55154 Mtetra
.5105 .55154 .51647 .55765 .52739 .55435 .52145 .54822 Mtetra
.52145 .54822 .52739 .55435 .53837 .55103 .53245 .54488 Mtetra
.664 .741 .908 r
.53245 .54488 .53837 .55103 .54938 .5477 .5435 .54153 Mtetra
.663 .741 .908 r
.5435 .54153 .54938 .5477 .56044 .54436 .55459 .53819 Mtetra
.663 .741 .909 r
.55459 .53819 .56044 .54436 .57154 .54101 .56572 .53484 Mtetra
.662 .742 .909 r
.56572 .53484 .57154 .54101 .58269 .53765 .5769 .53149 Mtetra
.661 .743 .911 r
.5769 .53149 .58269 .53765 .59388 .53428 .58812 .52815 Mtetra
.661 .745 .912 r
.58812 .52815 .59388 .53428 .60512 .53091 .59939 .52482 Mtetra
.66 .747 .914 r
.59939 .52482 .60512 .53091 .61641 .52752 .61071 .52148 Mtetra
.66 .749 .916 r
.61071 .52148 .61641 .52752 .62774 .52413 .62208 .51812 Mtetra
.66 .751 .918 r
.62208 .51812 .62774 .52413 .63911 .52071 .63349 .51474 Mtetra
.661 .754 .919 r
.63349 .51474 .63911 .52071 .65054 .51728 .64494 .51132 Mtetra
.662 .755 .919 r
.64494 .51132 .65054 .51728 .66201 .51382 .65645 .50787 Mtetra
.663 .757 .92 r
.65645 .50787 .66201 .51382 .67352 .51034 .668 .50436 Mtetra
.664 .757 .919 r
.668 .50436 .67352 .51034 .68508 .50684 .67959 .5008 Mtetra
.665 .756 .918 r
.67959 .5008 .68508 .50684 .69669 .50331 .69123 .49721 Mtetra
.666 .755 .917 r
.69123 .49721 .69669 .50331 .70835 .49976 .70292 .49357 Mtetra
.666 .753 .915 r
.70292 .49357 .70835 .49976 .72005 .49619 .71465 .48991 Mtetra
.667 .752 .914 r
.71465 .48991 .72005 .49619 .7318 .49261 .72644 .48623 Mtetra
.666 .749 .912 r
.72644 .48623 .7318 .49261 .74361 .48902 .73827 .48255 Mtetra
.666 .746 .91 r
.73827 .48255 .74361 .48902 .75546 .48542 .75015 .47887 Mtetra
.665 .745 .909 r
.75015 .47887 .75546 .48542 .76735 .48182 .76208 .47519 Mtetra
.665 .743 .908 r
.76208 .47519 .76735 .48182 .7793 .4782 .77406 .47152 Mtetra
.664 .742 .908 r
.77406 .47152 .7793 .4782 .7913 .47457 .7861 .46785 Mtetra
.664 .741 .908 r
.7861 .46785 .7913 .47457 .80335 .47093 .79818 .46417 Mtetra
.664 .741 .907 r
.79818 .46417 .80335 .47093 .81545 .46727 .81032 .46048 Mtetra
.81032 .46048 .81545 .46727 .8276 .4636 .82251 .45677 Mtetra
.82251 .45677 .8276 .4636 .83981 .45991 .83474 .45305 Mtetra
.83474 .45305 .83981 .45991 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44874 .87177 .44181 Mtetra
.87177 .44181 .87672 .44874 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55866 Mtetra
.46098 .55866 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55205 Mtetra
.48265 .55205 .48872 .55816 .49959 .55486 .49354 .54873 Mtetra
.49354 .54873 .49959 .55486 .5105 .55154 .50449 .54539 Mtetra
.664 .741 .908 r
.50449 .54539 .5105 .55154 .52145 .54822 .51547 .54205 Mtetra
.663 .741 .908 r
.51547 .54205 .52145 .54822 .53245 .54488 .5265 .53871 Mtetra
.662 .741 .909 r
.5265 .53871 .53245 .54488 .5435 .54153 .53757 .53537 Mtetra
.661 .742 .91 r
.53757 .53537 .5435 .54153 .55459 .53819 .54869 .53206 Mtetra
.659 .744 .912 r
.54869 .53206 .55459 .53819 .56572 .53484 .55985 .52878 Mtetra
.658 .746 .915 r
.55985 .52878 .56572 .53484 .5769 .53149 .57106 .52554 Mtetra
.656 .75 .919 r
.57106 .52554 .5769 .53149 .58812 .52815 .58232 .52231 Mtetra
.655 .754 .923 r
.58232 .52231 .58812 .52815 .59939 .52482 .59363 .51909 Mtetra
.655 .759 .926 r
.59363 .51909 .59939 .52482 .61071 .52148 .60498 .51584 Mtetra
.656 .763 .929 r
.60498 .51584 .61071 .52148 .62208 .51812 .61638 .51254 Mtetra
.657 .767 .931 r
.61638 .51254 .62208 .51812 .63349 .51474 .62783 .50919 Mtetra
.658 .769 .931 r
.62783 .50919 .63349 .51474 .64494 .51132 .63932 .50577 Mtetra
.66 .771 .931 r
.63932 .50577 .64494 .51132 .65645 .50787 .65086 .5023 Mtetra
.662 .771 .931 r
.65086 .5023 .65645 .50787 .668 .50436 .66244 .49876 Mtetra
.663 .772 .93 r
.66244 .49876 .668 .50436 .67959 .5008 .67408 .49518 Mtetra
.665 .772 .93 r
.67408 .49518 .67959 .5008 .69123 .49721 .68575 .49152 Mtetra
.667 .772 .928 r
.68575 .49152 .69123 .49721 .70292 .49357 .69747 .48781 Mtetra
.668 .77 .926 r
.69747 .48781 .70292 .49357 .71465 .48991 .70924 .48404 Mtetra
.67 .768 .924 r
.70924 .48404 .71465 .48991 .72644 .48623 .72105 .48022 Mtetra
.67 .764 .921 r
.72105 .48022 .72644 .48623 .73827 .48255 .73291 .47637 Mtetra
.67 .759 .917 r
.73291 .47637 .73827 .48255 .75015 .47887 .74482 .47252 Mtetra
.669 .754 .914 r
.74482 .47252 .75015 .47887 .76208 .47519 .75678 .46869 Mtetra
.668 .75 .912 r
.75678 .46869 .76208 .47519 .77406 .47152 .76879 .46489 Mtetra
.666 .746 .91 r
.76879 .46489 .77406 .47152 .7861 .46785 .78086 .46112 Mtetra
.665 .743 .908 r
.78086 .46112 .7861 .46785 .79818 .46417 .79297 .45738 Mtetra
.665 .742 .908 r
.79297 .45738 .79818 .46417 .81032 .46048 .80514 .45364 Mtetra
.664 .741 .907 r
.80514 .45364 .81032 .46048 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83474 .45305 .82964 .44615 Mtetra
.82964 .44615 .83474 .45305 .84704 .44932 .84197 .44239 Mtetra
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55866 .45481 .55256 Mtetra
.45481 .55256 .46098 .55866 .47179 .55537 .46565 .54924 Mtetra
.46565 .54924 .47179 .55537 .48265 .55205 .47653 .5459 Mtetra
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54256 Mtetra
.663 .741 .908 r
.48746 .54256 .49354 .54873 .50449 .54539 .49843 .53921 Mtetra
.662 .741 .908 r
.49843 .53921 .50449 .54539 .51547 .54205 .50944 .53588 Mtetra
.661 .742 .91 r
.50944 .53588 .51547 .54205 .5265 .53871 .5205 .53258 Mtetra
.658 .743 .913 r
.5205 .53258 .5265 .53871 .53757 .53537 .5316 .52935 Mtetra
.655 .746 .917 r
.5316 .52935 .53757 .53537 .54869 .53206 .54275 .52618 Mtetra
.652 .751 .922 r
.54275 .52618 .54869 .53206 .55985 .52878 .55395 .52307 Mtetra
.65 .757 .928 r
.55395 .52307 .55985 .52878 .57106 .52554 .56519 .51997 Mtetra
.651 .763 .932 r
.56519 .51997 .57106 .52554 .58232 .52231 .57648 .51682 Mtetra
.654 .768 .933 r
.57648 .51682 .58232 .52231 .59363 .51909 .58782 .51356 Mtetra
.658 .769 .931 r
.58782 .51356 .59363 .51909 .60498 .51584 .59921 .51016 Mtetra
.663 .766 .926 r
.59921 .51016 .60498 .51584 .61638 .51254 .61064 .50665 Mtetra
.666 .76 .92 r
.61064 .50665 .61638 .51254 .62783 .50919 .62211 .50305 Mtetra
.667 .753 .915 r
.62211 .50305 .62783 .50919 .63932 .50577 .63363 .49942 Mtetra
.666 .747 .911 r
.63363 .49942 .63932 .50577 .65086 .5023 .6452 .49582 Mtetra
.664 .743 .909 r
.6452 .49582 .65086 .5023 .66244 .49876 .65681 .49226 Mtetra
.662 .742 .91 r
.65681 .49226 .66244 .49876 .67408 .49518 .66848 .48874 Mtetra
.66 .745 .913 r
.66848 .48874 .67408 .49518 .68575 .49152 .6802 .48525 Mtetra
.661 .751 .917 r
.6802 .48525 .68575 .49152 .69747 .48781 .69197 .48173 Mtetra
.662 .759 .922 r
.69197 .48173 .69747 .48781 .70924 .48404 .70378 .47813 Mtetra
.666 .767 .925 r
.70378 .47813 .70924 .48404 .72105 .48022 .71564 .4744 Mtetra
.669 .772 .927 r
.71564 .4744 .72105 .48022 .73291 .47637 .72754 .47053 Mtetra
.673 .774 .926 r
.72754 .47053 .73291 .47637 .74482 .47252 .73948 .46656 Mtetra
.674 .771 .923 r
.73948 .46656 .74482 .47252 .75678 .46869 .75146 .46253 Mtetra
.674 .765 .919 r
.75146 .46253 .75678 .46869 .76879 .46489 .7635 .4585 Mtetra
.672 .757 .915 r
.7635 .4585 .76879 .46489 .78086 .46112 .77559 .45454 Mtetra
.669 .751 .912 r
.77559 .45454 .78086 .46112 .79297 .45738 .78773 .45064 Mtetra
.667 .746 .91 r
.78773 .45064 .79297 .45738 .80514 .45364 .79993 .4468 Mtetra
.665 .743 .908 r
.79993 .4468 .80514 .45364 .81737 .4499 .81219 .44299 Mtetra
.664 .742 .908 r
.81219 .44299 .81737 .4499 .82964 .44615 .8245 .4392 Mtetra
.664 .741 .907 r
.8245 .4392 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .85435 .43861 .84929 .43159 Mtetra
.84929 .43159 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.4486 .54642 .45481 .55256 .46565 .54924 .45947 .54307 Mtetra
.664 .741 .908 r
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53972 Mtetra
.663 .741 .908 r
.47037 .53972 .47653 .5459 .48746 .54256 .48133 .53637 Mtetra
.661 .741 .909 r
.48133 .53637 .48746 .54256 .49843 .53921 .49232 .53306 Mtetra
.658 .742 .912 r
.49232 .53306 .49843 .53921 .50944 .53588 .50336 .52982 Mtetra
.654 .745 .916 r
.50336 .52982 .50944 .53588 .5205 .53258 .51445 .52668 Mtetra
.649 .749 .923 r
.51445 .52668 .5205 .53258 .5316 .52935 .52558 .52364 Mtetra
.647 .756 .929 r
.52558 .52364 .5316 .52935 .54275 .52618 .53677 .52063 Mtetra
.649 .763 .933 r
.53677 .52063 .54275 .52618 .55395 .52307 .54799 .51752 Mtetra
.658 .767 .93 r
.54799 .51752 .55395 .52307 .56519 .51997 .55927 .51418 Mtetra
.67 .763 .92 r
.55927 .51418 .56519 .51997 .57648 .51682 .57059 .51049 Mtetra
.68 .749 .903 r
.57059 .51049 .57648 .51682 .58782 .51356 .58194 .50648 Mtetra
.685 .729 .883 r
.58194 .50648 .58782 .51356 .59921 .51016 .59334 .50222 Mtetra
.674 .702 .869 r
.59334 .50222 .59921 .51016 .61064 .50665 .60478 .49829 Mtetra
.662 .688 .864 r
.60478 .49829 .61064 .50665 .62211 .50305 .61629 .49474 Mtetra
.662 .69 .866 r
.61629 .49474 .62211 .50305 .63363 .49942 .62783 .49118 Mtetra
.662 .693 .868 r
.62783 .49118 .63363 .49942 .6452 .49582 .63943 .48761 Mtetra
.662 .694 .87 r
.63943 .48761 .6452 .49582 .65681 .49226 .65108 .48402 Mtetra
.65108 .48402 .65681 .49226 .66848 .48874 .66277 .48042 Mtetra
.662 .693 .868 r
.66277 .48042 .66848 .48874 .6802 .48525 .67451 .4768 Mtetra
.662 .69 .866 r
.67451 .4768 .6802 .48525 .69197 .48173 .6863 .47317 Mtetra
.651 .684 .868 r
.6863 .47317 .69197 .48173 .70378 .47813 .69816 .46993 Mtetra
.641 .69 .88 r
.69816 .46993 .70378 .47813 .71564 .4744 .71009 .46701 Mtetra
.648 .716 .898 r
.71009 .46701 .71564 .4744 .72754 .47053 .72207 .46386 Mtetra
.657 .742 .912 r
.72207 .46386 .72754 .47053 .73948 .46656 .73408 .46037 Mtetra
.667 .762 .921 r
.73408 .46037 .73948 .46656 .75146 .46253 .74612 .45653 Mtetra
.674 .772 .924 r
.74612 .45653 .75146 .46253 .7635 .4585 .75819 .45245 Mtetra
.677 .772 .922 r
.75819 .45245 .7635 .4585 .77559 .45454 .7703 .44827 Mtetra
.676 .765 .918 r
.7703 .44827 .77559 .45454 .78773 .45064 .78247 .44411 Mtetra
.672 .757 .914 r
.78247 .44411 .78773 .45064 .79993 .4468 .7947 .44005 Mtetra
.669 .749 .911 r
.7947 .44005 .79993 .4468 .81219 .44299 .80698 .4361 Mtetra
.666 .745 .909 r
.80698 .4361 .81219 .44299 .8245 .4392 .81932 .43222 Mtetra
.665 .742 .908 r
.81932 .43222 .8245 .4392 .83687 .4354 .83172 .42837 Mtetra
.664 .741 .907 r
.83172 .42837 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86176 .42777 .85669 .42066 Mtetra
.85669 .42066 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54359 Mtetra
.43149 .54359 .43778 .54975 .4486 .54642 .44234 .54023 Mtetra
.663 .741 .908 r
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53687 Mtetra
.662 .741 .908 r
.45323 .53687 .45947 .54307 .47037 .53972 .46417 .53352 Mtetra
.66 .741 .91 r
.46417 .53352 .47037 .53972 .48133 .53637 .47515 .53023 Mtetra
.656 .742 .914 r
.47515 .53023 .48133 .53637 .49232 .53306 .48617 .52705 Mtetra
.65 .746 .92 r
.48617 .52705 .49232 .53306 .50336 .52982 .49724 .52401 Mtetra
.645 .752 .927 r
.49724 .52401 .50336 .52982 .51445 .52668 .50836 .52107 Mtetra
.646 .76 .932 r
.50836 .52107 .51445 .52668 .52558 .52364 .51952 .51805 Mtetra
.659 .765 .929 r
.51952 .51805 .52558 .52364 .53677 .52063 .53073 .51468 Mtetra
.679 .76 .912 r
.53073 .51468 .53677 .52063 .54799 .51752 .54199 .51072 Mtetra
.697 .739 .884 r
.54199 .51072 .54799 .51752 .55927 .51418 .55328 .50609 Mtetra
.668 .696 .867 r
.55328 .50609 .55927 .51418 .57059 .51049 .56462 .50236 Mtetra
.662 .693 .869 r
.56462 .50236 .57059 .51049 .58194 .50648 .57601 .49883 Mtetra
.663 .707 .88 r
.57601 .49883 .58194 .50648 .59334 .50222 .58745 .49529 Mtetra
.664 .728 .897 r
.58745 .49529 .59334 .50222 .60478 .49829 .59894 .49173 Mtetra
.664 .741 .907 r
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69816 .46993 .69256 .46274 Mtetra
.664 .728 .897 r
.69256 .46274 .69816 .46993 .71009 .46701 .70448 .45905 Mtetra
.663 .707 .88 r
.70448 .45905 .71009 .46701 .72207 .46386 .71645 .45534 Mtetra
.656 .691 .871 r
.71645 .45534 .72207 .46386 .73408 .46037 .72849 .45184 Mtetra
.63 .681 .879 r
.72849 .45184 .73408 .46037 .74612 .45653 .74065 .44926 Mtetra
.649 .724 .903 r
.74065 .44926 .74612 .45653 .75819 .45245 .75281 .44598 Mtetra
.667 .756 .917 r
.75281 .44598 .75819 .45245 .7703 .44827 .76499 .44211 Mtetra
.677 .772 .922 r
.76499 .44211 .7703 .44827 .78247 .44411 .77719 .43788 Mtetra
.679 .771 .92 r
.77719 .43788 .78247 .44411 .7947 .44005 .78944 .43357 Mtetra
.676 .762 .916 r
.78944 .43357 .7947 .44005 .80698 .4361 .80174 .42935 Mtetra
.671 .753 .912 r
.80174 .42935 .80698 .4361 .81932 .43222 .81411 .42528 Mtetra
.667 .746 .909 r
.81411 .42528 .81932 .43222 .83172 .42837 .82654 .42132 Mtetra
.665 .743 .908 r
.82654 .42132 .83172 .42837 .84418 .42452 .83904 .4174 Mtetra
.664 .741 .908 r
.83904 .4174 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.664 .741 .907 r
.85158 .4135 .85669 .42066 .86925 .41679 .86419 .4096 Mtetra
.86419 .4096 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54744 Mtetra
.39278 .54744 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54074 Mtetra
.41432 .54074 .42068 .54693 .43149 .54359 .42515 .53738 Mtetra
.663 .741 .908 r
.42515 .53738 .43149 .54359 .44234 .54023 .43603 .534 Mtetra
.662 .741 .908 r
.43603 .534 .44234 .54023 .45323 .53687 .44695 .53065 Mtetra
.659 .741 .91 r
.44695 .53065 .45323 .53687 .46417 .53352 .45791 .52738 Mtetra
.653 .743 .915 r
.45791 .52738 .46417 .53352 .47515 .53023 .46892 .52425 Mtetra
.646 .747 .923 r
.46892 .52425 .47515 .53023 .48617 .52705 .47997 .52129 Mtetra
.642 .754 .93 r
.47997 .52129 .48617 .52705 .49724 .52401 .49107 .51839 Mtetra
.651 .762 .931 r
.49107 .51839 .49724 .52401 .50836 .52107 .50221 .51523 Mtetra
.677 .762 .915 r
.50221 .51523 .50836 .52107 .51952 .51805 .51341 .51135 Mtetra
.704 .743 .882 r
.51341 .51135 .51952 .51805 .53073 .51468 .52465 .50645 Mtetra
.663 .691 .866 r
.52465 .50645 .53073 .51468 .54199 .51072 .53593 .5029 Mtetra
.663 .702 .876 r
.53593 .5029 .54199 .51072 .55328 .50609 .54726 .49938 Mtetra
.664 .734 .902 r
.54726 .49938 .55328 .50609 .56462 .50236 .55864 .49584 Mtetra
.664 .741 .907 r
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72849 .45184 .72296 .4447 Mtetra
.664 .734 .902 r
.72296 .4447 .72849 .45184 .74065 .44926 .73507 .44094 Mtetra
.662 .701 .876 r
.73507 .44094 .74065 .44926 .75281 .44598 .74724 .43719 Mtetra
.622 .673 .878 r
.74724 .43719 .75281 .44598 .76499 .44211 .75955 .43482 Mtetra
.651 .727 .905 r
.75955 .43482 .76499 .44211 .77719 .43788 .77186 .43141 Mtetra
.673 .762 .918 r
.77186 .43141 .77719 .43788 .78944 .43357 .78416 .42727 Mtetra
.681 .772 .92 r
.78416 .42727 .78944 .43357 .80174 .42935 .79649 .42285 Mtetra
.679 .765 .916 r
.79649 .42285 .80174 .42935 .81411 .42528 .80888 .41849 Mtetra
.673 .755 .912 r
.80888 .41849 .81411 .42528 .82654 .42132 .82133 .41431 Mtetra
.668 .747 .909 r
.82133 .41431 .82654 .42132 .83904 .4174 .83385 .41027 Mtetra
.665 .743 .908 r
.83385 .41027 .83904 .4174 .85158 .4135 .84644 .4063 Mtetra
.664 .741 .908 r
.84644 .4063 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.664 .741 .907 r
.85908 .40235 .86419 .4096 .87684 .40568 .87177 .3984 Mtetra
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54744 .38632 .54126 Mtetra
.38632 .54126 .39278 .54744 .40353 .5441 .39709 .53789 Mtetra
.39709 .53789 .40353 .5441 .41432 .54074 .40791 .53451 Mtetra
.663 .741 .908 r
.40791 .53451 .41432 .54074 .42515 .53738 .41877 .53113 Mtetra
.662 .741 .908 r
.41877 .53113 .42515 .53738 .43603 .534 .42967 .52777 Mtetra
.659 .741 .911 r
.42967 .52777 .43603 .534 .44695 .53065 .44062 .5245 Mtetra
.652 .742 .916 r
.44062 .5245 .44695 .53065 .45791 .52738 .45161 .5214 Mtetra
.643 .747 .924 r
.45161 .5214 .45791 .52738 .46892 .52425 .46264 .51849 Mtetra
.641 .755 .931 r
.46264 .51849 .46892 .52425 .47997 .52129 .47371 .5156 Mtetra
.659 .763 .926 r
.47371 .5156 .47997 .52129 .49107 .51839 .48485 .51221 Mtetra
.696 .757 .899 r
.48485 .51221 .49107 .51839 .50221 .51523 .49604 .5077 Mtetra
.684 .716 .873 r
.49604 .5077 .50221 .51523 .51341 .51135 .50726 .50344 Mtetra
.662 .699 .874 r
.50726 .50344 .51341 .51135 .52465 .50645 .51853 .49992 Mtetra
.664 .74 .906 r
.51853 .49992 .52465 .50645 .53593 .5029 .52984 .49638 Mtetra
.664 .741 .907 r
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74724 .43719 .74174 .43012 Mtetra
.664 .74 .906 r
.74174 .43012 .74724 .43719 .75955 .43482 .75399 .42629 Mtetra
.641 .69 .88 r
.75399 .42629 .75955 .43482 .77186 .43141 .76635 .42321 Mtetra
.633 .696 .891 r
.76635 .42321 .77186 .43141 .78416 .42727 .77879 .42039 Mtetra
.666 .749 .912 r
.77879 .42039 .78416 .42727 .79649 .42285 .7912 .41642 Mtetra
.682 .77 .918 r
.7912 .41642 .79649 .42285 .80888 .41849 .80362 .41194 Mtetra
.681 .767 .916 r
.80362 .41194 .80888 .41849 .82133 .41431 .8161 .40746 Mtetra
.674 .756 .912 r
.8161 .40746 .82133 .41431 .83385 .41027 .82864 .40318 Mtetra
.669 .747 .909 r
.82864 .40318 .83385 .41027 .84644 .4063 .84125 .39907 Mtetra
.665 .743 .908 r
.84125 .39907 .84644 .4063 .85908 .40235 .85393 .39506 Mtetra
.664 .741 .907 r
.85393 .39506 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91817 .37495 Mtetra
.91817 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.37981 .53503 .38632 .54126 .39709 .53789 .39061 .53164 Mtetra
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52824 Mtetra
.662 .741 .908 r
.40145 .52824 .40791 .53451 .41877 .53113 .41234 .52486 Mtetra
.659 .741 .91 r
.41234 .52486 .41877 .53113 .42967 .52777 .42327 .52157 Mtetra
.651 .742 .916 r
.42327 .52157 .42967 .52777 .44062 .5245 .43424 .51848 Mtetra
.642 .746 .924 r
.43424 .51848 .44062 .5245 .45161 .5214 .44525 .5156 Mtetra
.641 .754 .931 r
.44525 .5156 .45161 .5214 .46264 .51849 .4563 .51272 Mtetra
.666 .762 .922 r
.4563 .51272 .46264 .51849 .47371 .5156 .46742 .50913 Mtetra
.71 .752 .884 r
.46742 .50913 .47371 .5156 .48485 .51221 .47861 .50405 Mtetra
.664 .693 .867 r
.47861 .50405 .48485 .51221 .49604 .5077 .48981 .50046 Mtetra
.664 .718 .889 r
.48981 .50046 .49604 .5077 .50726 .50344 .50106 .49693 Mtetra
.664 .741 .907 r
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.629 .729 .919 r
.56955 .47541 .57556 .48208 .58711 .47847 .58114 .47276 Mtetra
.526 .724 .964 r
.58114 .47276 .58711 .47847 .59871 .47485 .59284 .47206 Mtetra
.474 .82 .998 r
.59284 .47206 .59871 .47485 .61035 .47121 .60458 .47038 Mtetra
.409 .848 .935 r
.60458 .47038 .61035 .47121 .62205 .46755 .61636 .4677 Mtetra
.408 .859 .878 r
.61636 .4677 .62205 .46755 .63379 .46388 .62816 .464 Mtetra
.504 .908 .899 r
.62816 .464 .63379 .46388 .64558 .46019 .63997 .4593 Mtetra
.653 .949 .952 r
.63997 .4593 .64558 .46019 .65742 .45649 .65179 .45358 Mtetra
.752 .904 .945 r
.65179 .45358 .65742 .45649 .66932 .45277 .66361 .44686 Mtetra
.695 .783 .919 r
.66361 .44686 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.664 .741 .907 r
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76635 .42321 .76083 .4153 Mtetra
.662 .718 .89 r
.76083 .4153 .76635 .42321 .77879 .42039 .77323 .41147 Mtetra
.617 .673 .881 r
.77323 .41147 .77879 .42039 .7912 .41642 .78581 .40918 Mtetra
.661 .739 .908 r
.78581 .40918 .7912 .41642 .80362 .41194 .79833 .40535 Mtetra
.682 .768 .916 r
.79833 .40535 .80362 .41194 .8161 .40746 .81084 .40079 Mtetra
.682 .767 .915 r
.81084 .40079 .8161 .40746 .82864 .40318 .8234 .39622 Mtetra
.675 .756 .912 r
.8234 .39622 .82864 .40318 .84125 .39907 .83603 .39188 Mtetra
.668 .747 .909 r
.83603 .39188 .84125 .39907 .85393 .39506 .84874 .38773 Mtetra
.665 .743 .908 r
.84874 .38773 .85393 .39506 .86666 .39106 .86151 .38367 Mtetra
.664 .741 .907 r
.86151 .38367 .86666 .39106 .87946 .38706 .87435 .37963 Mtetra
.87435 .37963 .87946 .38706 .89231 .38304 .88724 .37558 Mtetra
.88724 .37558 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91817 .37495 .91319 .36742 Mtetra
.91319 .36742 .91817 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52875 Mtetra
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52534 Mtetra
.663 .741 .908 r
.38407 .52534 .39061 .53164 .40145 .52824 .39495 .52194 Mtetra
.66 .741 .91 r
.39495 .52194 .40145 .52824 .41234 .52486 .40586 .51862 Mtetra
.652 .741 .915 r
.40586 .51862 .41234 .52486 .42327 .52157 .41681 .51549 Mtetra
.641 .744 .923 r
.41681 .51549 .42327 .52157 .43424 .51848 .4278 .51262 Mtetra
.639 .752 .93 r
.4278 .51262 .43424 .51848 .44525 .5156 .43883 .50976 Mtetra
.668 .761 .92 r
.43883 .50976 .44525 .5156 .4563 .51272 .44994 .50612 Mtetra
.71 .748 .882 r
.44994 .50612 .4563 .51272 .46742 .50913 .46112 .501 Mtetra
.662 .694 .87 r
.46112 .501 .46742 .50913 .47861 .50405 .4723 .49747 Mtetra
.664 .739 .906 r
.4723 .49747 .47861 .50405 .48981 .50046 .48354 .49392 Mtetra
.664 .741 .907 r
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.628 .729 .92 r
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47698 Mtetra
.308 .62 .958 r
.54041 .47698 .54653 .48264 .55801 .47903 .55198 .47928 Mtetra
.162 0 0 r
.55198 .47928 .55801 .47903 .56955 .47541 .56362 .48042 Mtetra
.368 0 0 r
.56362 .48042 .56955 .47541 .58114 .47276 .57533 .48024 Mtetra
.38 0 .048 r
.57533 .48024 .58114 .47276 .59284 .47206 .58709 .47885 Mtetra
.309 0 0 r
.58709 .47885 .59284 .47206 .60458 .47038 .5989 .47652 Mtetra
.235 0 0 r
.5989 .47652 .60458 .47038 .61636 .4677 .61074 .47343 Mtetra
.17 0 0 r
.61074 .47343 .61636 .4677 .62816 .464 .62262 .46972 Mtetra
.125 0 0 r
.62262 .46972 .62816 .464 .63997 .4593 .63453 .46538 Mtetra
.097 0 0 r
.63453 .46538 .63997 .4593 .65179 .45358 .64646 .46029 Mtetra
.075 0 0 r
.64646 .46029 .65179 .45358 .66361 .44686 .6584 .45424 Mtetra
.039 0 0 r
.6584 .45424 .66361 .44686 .67554 .4421 .67031 .44695 Mtetra
0 0 0 r
.67031 .44695 .67554 .4421 .68757 .43832 .68219 .43832 Mtetra
.798 .993 .876 r
.68219 .43832 .68757 .43832 .69965 .43452 .69402 .4285 Mtetra
.696 .784 .919 r
.69402 .4285 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.664 .741 .907 r
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .41147 .76776 .40417 Mtetra
.664 .739 .906 r
.76776 .40417 .77323 .41147 .78581 .40918 .78024 .40022 Mtetra
.616 .674 .882 r
.78024 .40022 .78581 .40918 .79833 .40535 .79292 .39791 Mtetra
.659 .735 .906 r
.79292 .39791 .79833 .40535 .81084 .40079 .80554 .39408 Mtetra
.683 .767 .915 r
.80554 .39408 .81084 .40079 .8234 .39622 .81814 .38943 Mtetra
.683 .766 .914 r
.81814 .38943 .8234 .39622 .83603 .39188 .83079 .38479 Mtetra
.674 .754 .911 r
.83079 .38479 .83603 .39188 .84874 .38773 .84352 .38042 Mtetra
.668 .746 .909 r
.84352 .38042 .84874 .38773 .86151 .38367 .85632 .37624 Mtetra
.665 .742 .908 r
.85632 .37624 .86151 .38367 .87435 .37963 .86919 .37214 Mtetra
.664 .741 .907 r
.86919 .37214 .87435 .37963 .88724 .37558 .88212 .36805 Mtetra
.88212 .36805 .88724 .37558 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52586 Mtetra
.35583 .52586 .36246 .53216 .37325 .52875 .36664 .52244 Mtetra
.663 .741 .908 r
.36664 .52244 .37325 .52875 .38407 .52534 .37749 .51901 Mtetra
.661 .741 .909 r
.37749 .51901 .38407 .52534 .39495 .52194 .38839 .51564 Mtetra
.654 .741 .913 r
.38839 .51564 .39495 .52194 .40586 .51862 .39932 .51245 Mtetra
.642 .742 .922 r
.39932 .51245 .40586 .51862 .41681 .51549 .41029 .50955 Mtetra
.637 .749 .93 r
.41029 .50955 .41681 .51549 .4278 .51262 .42131 .50675 Mtetra
.664 .76 .921 r
.42131 .50675 .4278 .51262 .43883 .50976 .43239 .5032 Mtetra
.712 .75 .882 r
.43239 .5032 .43883 .50976 .44994 .50612 .44356 .49802 Mtetra
.662 .696 .871 r
.44356 .49802 .44994 .50612 .46112 .501 .45473 .49447 Mtetra
.664 .741 .907 r
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.662 .74 .908 r
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47657 Mtetra
.193 .518 .917 r
.51128 .47657 .51752 .48319 .52894 .47959 .52273 .4808 Mtetra
.398 0 0 r
.52273 .4808 .52894 .47959 .54041 .47698 .53427 .4836 Mtetra
.458 0 .06 r
.53427 .4836 .54041 .47698 .55198 .47928 .5459 .4844 Mtetra
.314 0 0 r
.5459 .4844 .55198 .47928 .56362 .48042 .55759 .48335 Mtetra
.05 0 0 r
.55759 .48335 .56362 .48042 .57533 .48024 .56933 .48096 Mtetra
.298 .794 .805 r
.56933 .48096 .57533 .48024 .58709 .47885 .58111 .47775 Mtetra
.517 .894 .964 r
.58111 .47775 .58709 .47885 .5989 .47652 .59294 .47414 Mtetra
.597 .887 .991 r
.59294 .47414 .5989 .47652 .61074 .47343 .60482 .47041 Mtetra
.619 .87 .99 r
.60482 .47041 .61074 .47343 .62262 .46972 .61675 .46667 Mtetra
.618 .87 .99 r
.61675 .46667 .62262 .46972 .63453 .46538 .62873 .46294 Mtetra
.602 .888 .99 r
.62873 .46294 .63453 .46538 .64646 .46029 .64076 .45907 Mtetra
.563 .913 .966 r
.64076 .45907 .64646 .46029 .6584 .45424 .65283 .4548 Mtetra
.478 .897 .86 r
.65283 .4548 .6584 .45424 .67031 .44695 .66491 .44971 Mtetra
.35 .795 .641 r
.66491 .44971 .67031 .44695 .68219 .43832 .67696 .44325 Mtetra
0 0 0 r
.67696 .44325 .68219 .43832 .69402 .4285 .68896 .43491 Mtetra
.68896 .43491 .69402 .4285 .70613 .42363 .70087 .42452 Mtetra
.826 1 .818 r
.70087 .42452 .70613 .42363 .71835 .41977 .71269 .41265 Mtetra
.665 .743 .908 r
.71269 .41265 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.664 .741 .907 r
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79292 .39791 .78735 .38891 Mtetra
.614 .675 .884 r
.78735 .38891 .79292 .39791 .80554 .39408 .80013 .3866 Mtetra
.663 .738 .906 r
.80013 .3866 .80554 .39408 .81814 .38943 .81283 .38261 Mtetra
.686 .768 .914 r
.81283 .38261 .81814 .38943 .83079 .38479 .82552 .37784 Mtetra
.682 .763 .913 r
.82552 .37784 .83079 .38479 .84352 .38042 .83826 .37317 Mtetra
.673 .752 .91 r
.83826 .37317 .84352 .38042 .85632 .37624 .85109 .3688 Mtetra
.667 .744 .908 r
.85109 .3688 .85632 .37624 .86919 .37214 .864 .36461 Mtetra
.665 .742 .908 r
.864 .36461 .86919 .37214 .88212 .36805 .87697 .36047 Mtetra
.664 .741 .907 r
.87697 .36047 .88212 .36805 .89511 .36395 .89 .35633 Mtetra
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.33835 .52296 .34506 .52928 .35583 .52586 .34914 .51952 Mtetra
.664 .741 .908 r
.34914 .51952 .35583 .52586 .36664 .52244 .35998 .51607 Mtetra
.662 .741 .908 r
.35998 .51607 .36664 .52244 .37749 .51901 .37086 .51266 Mtetra
.657 .74 .911 r
.37086 .51266 .37749 .51901 .38839 .51564 .38178 .50938 Mtetra
.645 .741 .919 r
.38178 .50938 .38839 .51564 .39932 .51245 .39273 .50639 Mtetra
.635 .745 .928 r
.39273 .50639 .39932 .51245 .41029 .50955 .40372 .50363 Mtetra
.655 .756 .925 r
.40372 .50363 .41029 .50955 .42131 .50675 .41478 .50034 Mtetra
.714 .756 .885 r
.41478 .50034 .42131 .50675 .43239 .5032 .42594 .49508 Mtetra
.664 .697 .871 r
.42594 .49508 .43239 .5032 .44356 .49802 .4371 .49146 Mtetra
.664 .741 .907 r
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.487 .674 .947 r
.48218 .47708 .48852 .48375 .49988 .48014 .49353 .47739 Mtetra
.29 0 0 r
.49353 .47739 .49988 .48014 .51128 .47657 .50492 .48241 Mtetra
.517 .042 .068 r
.50492 .48241 .51128 .47657 .52273 .4808 .51644 .48495 Mtetra
.317 0 0 r
.51644 .48495 .52273 .4808 .53427 .4836 .52804 .48465 Mtetra
.192 .72 .737 r
.52804 .48465 .53427 .4836 .5459 .4844 .5397 .48208 Mtetra
.616 .892 .989 r
.5397 .48208 .5459 .4844 .55759 .48335 .55141 .47811 Mtetra
.691 .802 .934 r
.55141 .47811 .55759 .48335 .56933 .48096 .56316 .47349 Mtetra
.692 .733 .883 r
.56316 .47349 .56933 .48096 .58111 .47775 .57495 .46873 Mtetra
.68 .692 .854 r
.57495 .46873 .58111 .47775 .59294 .47414 .58679 .46416 Mtetra
.668 .667 .84 r
.58679 .46416 .59294 .47414 .60482 .47041 .59868 .45995 Mtetra
.656 .654 .836 r
.59868 .45995 .60482 .47041 .61675 .46667 .61063 .45618 Mtetra
.645 .649 .84 r
.61063 .45618 .61675 .46667 .62873 .46294 .62264 .45285 Mtetra
.636 .654 .851 r
.62264 .45285 .62873 .46294 .64076 .45907 .63473 .44989 Mtetra
.631 .672 .871 r
.63473 .44989 .64076 .45907 .65283 .4548 .64688 .44712 Mtetra
.633 .713 .904 r
.64688 .44712 .65283 .4548 .66491 .44971 .65908 .44422 Mtetra
.646 .79 .951 r
.65908 .44422 .66491 .44971 .67696 .44325 .67132 .44066 Mtetra
.661 .906 .979 r
.67132 .44066 .67696 .44325 .68896 .43491 .68354 .43567 Mtetra
.616 .958 .858 r
.68354 .43567 .68896 .43491 .70087 .42452 .69569 .42839 Mtetra
.512 .857 .594 r
.69569 .42839 .70087 .42452 .71269 .41265 .7077 .4182 Mtetra
0 0 0 r
.7077 .4182 .71269 .41265 .725 .40869 .71957 .40545 Mtetra
.783 .909 .927 r
.71957 .40545 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.664 .741 .907 r
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.662 .74 .908 r
.78187 .38149 .78735 .38891 .80013 .3866 .79455 .37751 Mtetra
.613 .674 .885 r
.79455 .37751 .80013 .3866 .81283 .38261 .80744 .37522 Mtetra
.671 .747 .907 r
.80744 .37522 .81283 .38261 .82552 .37784 .82021 .3709 Mtetra
.687 .768 .913 r
.82021 .3709 .82552 .37784 .83826 .37317 .83298 .36603 Mtetra
.68 .759 .911 r
.83298 .36603 .83826 .37317 .85109 .3688 .84583 .36138 Mtetra
.67 .748 .909 r
.84583 .36138 .85109 .3688 .864 .36461 .85877 .35704 Mtetra
.666 .743 .908 r
.85877 .35704 .864 .36461 .87697 .36047 .87178 .35283 Mtetra
.664 .741 .907 r
.87178 .35283 .87697 .36047 .89 .35633 .88485 .34865 Mtetra
.88485 .34865 .89 .35633 .90309 .35217 .89798 .34445 Mtetra
.89798 .34445 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .51659 Mtetra
.33158 .51659 .33835 .52296 .34914 .51952 .3424 .51313 Mtetra
.663 .741 .908 r
.3424 .51313 .34914 .51952 .35998 .51607 .35327 .50967 Mtetra
.659 .74 .91 r
.35327 .50967 .35998 .51607 .37086 .51266 .36417 .50631 Mtetra
.65 .74 .915 r
.36417 .50631 .37086 .51266 .38178 .50938 .37511 .50319 Mtetra
.636 .742 .925 r
.37511 .50319 .38178 .50938 .39273 .50639 .38608 .5004 Mtetra
.643 .751 .928 r
.38608 .5004 .39273 .50639 .40372 .50363 .39711 .49741 Mtetra
.698 .758 .898 r
.39711 .49741 .40372 .50363 .41478 .50034 .40824 .49276 Mtetra
.684 .718 .874 r
.40824 .49276 .41478 .50034 .42594 .49508 .41941 .48844 Mtetra
.664 .739 .906 r
.41941 .48844 .42594 .49508 .4371 .49146 .43059 .48485 Mtetra
.664 .741 .907 r
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.35 .608 .946 r
.46442 .47401 .47084 .4807 .48218 .47708 .4757 .47628 Mtetra
.499 0 0 r
.4757 .47628 .48218 .47708 .49353 .47739 .48703 .48189 Mtetra
.476 0 0 r
.48703 .48189 .49353 .47739 .50492 .48241 .4985 .48405 Mtetra
.007 0 0 r
.4985 .48405 .50492 .48241 .51644 .48495 .51008 .48259 Mtetra
.626 .892 .987 r
.51008 .48259 .51644 .48495 .52804 .48465 .52173 .47851 Mtetra
.717 .778 .9 r
.52173 .47851 .52804 .48465 .5397 .48208 .53341 .47302 Mtetra
.711 .701 .838 r
.53341 .47302 .5397 .48208 .55141 .47811 .54514 .46704 Mtetra
.697 .659 .808 r
.54514 .46704 .55141 .47811 .56316 .47349 .55689 .46114 Mtetra
.682 .633 .794 r
.55689 .46114 .56316 .47349 .57495 .46873 .56869 .45562 Mtetra
.669 .617 .788 r
.56869 .45562 .57495 .46873 .58679 .46416 .58053 .45063 Mtetra
.657 .606 .786 r
.58053 .45063 .58679 .46416 .59868 .45995 .59243 .44622 Mtetra
.645 .598 .787 r
.59243 .44622 .59868 .45995 .61063 .45618 .60439 .44241 Mtetra
.633 .592 .791 r
.60439 .44241 .61063 .45618 .62264 .45285 .61642 .43921 Mtetra
.621 .589 .796 r
.61642 .43921 .62264 .45285 .63473 .44989 .62853 .4366 Mtetra
.61 .588 .804 r
.62853 .4366 .63473 .44989 .64688 .44712 .64071 .43452 Mtetra
.601 .595 .817 r
.64071 .43452 .64688 .44712 .65908 .44422 .65298 .43284 Mtetra
.598 .614 .839 r
.65298 .43284 .65908 .44422 .67132 .44066 .66532 .43124 Mtetra
.609 .661 .875 r
.66532 .43124 .67132 .44066 .68354 .43567 .67771 .42916 Mtetra
.648 .759 .93 r
.67771 .42916 .68354 .43567 .69569 .42839 .6901 .42564 Mtetra
.715 .916 .963 r
.6901 .42564 .69569 .42839 .7077 .4182 .7024 .41947 Mtetra
.719 .987 .816 r
.7024 .41947 .7077 .4182 .71957 .40545 .71452 .40959 Mtetra
.666 .916 .602 r
.71452 .40959 .71957 .40545 .73173 .39748 .72643 .39617 Mtetra
.821 .973 .894 r
.72643 .39617 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.664 .741 .907 r
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79455 .37751 .78906 .36994 Mtetra
.64 .729 .913 r
.78906 .36994 .79455 .37751 .80744 .37522 .8019 .36662 Mtetra
.631 .697 .893 r
.8019 .36662 .80744 .37522 .82021 .3709 .81483 .36364 Mtetra
.681 .757 .909 r
.81483 .36364 .82021 .3709 .83298 .36603 .82767 .35894 Mtetra
.687 .766 .912 r
.82767 .35894 .83298 .36603 .84583 .36138 .84054 .35403 Mtetra
.676 .754 .91 r
.84054 .35403 .84583 .36138 .85877 .35704 .8535 .34946 Mtetra
.668 .745 .908 r
.8535 .34946 .85877 .35704 .87178 .35283 .86654 .34514 Mtetra
.665 .742 .908 r
.86654 .34514 .87178 .35283 .88485 .34865 .87965 .3409 Mtetra
.664 .741 .907 r
.87965 .3409 .88485 .34865 .89798 .34445 .89283 .33667 Mtetra
.89283 .33667 .89798 .34445 .91117 .34025 .90606 .33243 Mtetra
.31396 .51366 .3208 .52005 .33158 .51659 .32477 .51018 Mtetra
.663 .741 .908 r
.32477 .51018 .33158 .51659 .3424 .51313 .33561 .5067 Mtetra
.662 .741 .909 r
.33561 .5067 .3424 .51313 .35327 .50967 .3465 .50325 Mtetra
.655 .74 .912 r
.3465 .50325 .35327 .50967 .36417 .50631 .35743 .49998 Mtetra
.641 .74 .92 r
.35743 .49998 .36417 .50631 .37511 .50319 .36838 .49706 Mtetra
.634 .745 .928 r
.36838 .49706 .37511 .50319 .38608 .5004 .37938 .49429 Mtetra
.673 .757 .914 r
.37938 .49429 .38608 .5004 .39711 .49741 .39047 .49044 Mtetra
.705 .74 .878 r
.39047 .49044 .39711 .49741 .40824 .49276 .40165 .4854 Mtetra
.663 .719 .89 r
.40165 .4854 .40824 .49276 .41941 .48844 .41281 .48181 Mtetra
.664 .741 .907 r
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.347 .608 .946 r
.44659 .47092 .45309 .47764 .46442 .47401 .45782 .47319 Mtetra
.552 0 0 r
.45782 .47319 .46442 .47401 .4757 .47628 .46907 .47959 Mtetra
.445 0 0 r
.46907 .47959 .4757 .47628 .48703 .48189 .4805 .48178 Mtetra
.294 .789 .865 r
.4805 .48178 .48703 .48189 .4985 .48405 .49206 .47956 Mtetra
.712 .831 .939 r
.49206 .47956 .4985 .48405 .51008 .48259 .5037 .47431 Mtetra
.731 .724 .844 r
.5037 .47431 .51008 .48259 .52173 .47851 .51538 .46761 Mtetra
.718 .669 .801 r
.51538 .46761 .52173 .47851 .53341 .47302 .52708 .46054 Mtetra
.703 .64 .784 r
.52708 .46054 .53341 .47302 .54514 .46704 .53882 .45373 Mtetra
.69 .624 .778 r
.53882 .45373 .54514 .46704 .55689 .46114 .55059 .44743 Mtetra
.678 .614 .777 r
.55059 .44743 .55689 .46114 .56869 .45562 .5624 .44175 Mtetra
.667 .607 .779 r
.5624 .44175 .56869 .45562 .58053 .45063 .57425 .4367 Mtetra
.656 .602 .782 r
.57425 .4367 .58053 .45063 .59243 .44622 .58616 .43226 Mtetra
.644 .596 .785 r
.58616 .43226 .59243 .44622 .60439 .44241 .59813 .42841 Mtetra
.633 .59 .788 r
.59813 .42841 .60439 .44241 .61642 .43921 .61016 .42517 Mtetra
.62 .584 .791 r
.61016 .42517 .61642 .43921 .62853 .4366 .62228 .42255 Mtetra
.607 .577 .794 r
.62228 .42255 .62853 .4366 .64071 .43452 .63447 .42056 Mtetra
.593 .571 .799 r
.63447 .42056 .64071 .43452 .65298 .43284 .64676 .4192 Mtetra
.58 .57 .806 r
.64676 .4192 .65298 .43284 .66532 .43124 .65914 .41837 Mtetra
.572 .578 .82 r
.65914 .41837 .66532 .43124 .67771 .42916 .67161 .4178 Mtetra
.578 .607 .846 r
.67161 .4178 .67771 .42916 .6901 .42564 .68415 .41689 Mtetra
.615 .683 .891 r
.68415 .41689 .6901 .42564 .7024 .41947 .69669 .4145 Mtetra
.707 .835 .943 r
.69669 .4145 .7024 .41947 .71452 .40959 .70912 .40904 Mtetra
.802 .988 .886 r
.70912 .40904 .71452 .40959 .72643 .39617 .72132 .39906 Mtetra
.79 .976 .692 r
.72132 .39906 .72643 .39617 .73854 .38613 .73325 .38475 Mtetra
.821 .973 .894 r
.73325 .38475 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.664 .741 .907 r
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .8019 .36662 .79634 .35824 Mtetra
.619 .699 .902 r
.79634 .35824 .8019 .36662 .81483 .36364 .80934 .35559 Mtetra
.655 .725 .901 r
.80934 .35559 .81483 .36364 .82767 .35894 .8223 .35172 Mtetra
.688 .764 .909 r
.8223 .35172 .82767 .35894 .84054 .35403 .83521 .34673 Mtetra
.683 .761 .91 r
.83521 .34673 .84054 .35403 .8535 .34946 .84819 .34189 Mtetra
.672 .749 .909 r
.84819 .34189 .8535 .34946 .86654 .34514 .86126 .33741 Mtetra
.666 .743 .908 r
.86126 .33741 .86654 .34514 .87965 .3409 .87441 .3331 Mtetra
.664 .741 .907 r
.87441 .3331 .87965 .3409 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90606 .33243 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50372 Mtetra
.663 .741 .908 r
.3179 .50372 .32477 .51018 .33561 .5067 .32877 .50022 Mtetra
.659 .74 .91 r
.32877 .50022 .33561 .5067 .3465 .50325 .33969 .49682 Mtetra
.649 .739 .916 r
.33969 .49682 .3465 .50325 .35743 .49998 .35063 .49369 Mtetra
.634 .741 .925 r
.35063 .49369 .35743 .49998 .36838 .49706 .3616 .49093 Mtetra
.647 .75 .925 r
.3616 .49093 .36838 .49706 .37938 .49429 .37264 .48779 Mtetra
.716 .756 .883 r
.37264 .48779 .37938 .49429 .39047 .49044 .38383 .4824 Mtetra
.663 .701 .875 r
.38383 .4824 .39047 .49044 .40165 .4854 .39498 .47875 Mtetra
.664 .741 .907 r
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.484 .674 .949 r
.4287 .46783 .43528 .47457 .44659 .47092 .43994 .46811 Mtetra
.529 0 0 r
.43994 .46811 .44659 .47092 .45782 .47319 .45108 .47569 Mtetra
.465 0 0 r
.45108 .47569 .45782 .47319 .46907 .47959 .46244 .47867 Mtetra
.387 .833 .938 r
.46244 .47867 .46907 .47959 .4805 .48178 .47397 .47638 Mtetra
.731 .803 .908 r
.47397 .47638 .4805 .48178 .49206 .47956 .48561 .47045 Mtetra
.74 .709 .822 r
.48561 .47045 .49206 .47956 .5037 .47431 .49729 .46284 Mtetra
.726 .664 .788 r
.49729 .46284 .5037 .47431 .51538 .46761 .509 .45493 Mtetra
.712 .642 .777 r
.509 .45493 .51538 .46761 .52708 .46054 .52073 .44738 Mtetra
.7 .631 .776 r
.52073 .44738 .52708 .46054 .53882 .45373 .53248 .44048 Mtetra
.689 .625 .78 r
.53248 .44048 .53882 .45373 .55059 .44743 .54426 .43426 Mtetra
.678 .622 .785 r
.54426 .43426 .55059 .44743 .5624 .44175 .55609 .42871 Mtetra
.668 .619 .791 r
.55609 .42871 .5624 .44175 .57425 .4367 .56796 .42375 Mtetra
.658 .616 .796 r
.56796 .42375 .57425 .4367 .58616 .43226 .57988 .41934 Mtetra
.648 .612 .8 r
.57988 .41934 .58616 .43226 .59813 .42841 .59186 .41546 Mtetra
.637 .607 .803 r
.59186 .41546 .59813 .42841 .61016 .42517 .60391 .41211 Mtetra
.625 .6 .805 r
.60391 .41211 .61016 .42517 .62228 .42255 .61603 .40932 Mtetra
.611 .591 .806 r
.61603 .40932 .62228 .42255 .63447 .42056 .62823 .40713 Mtetra
.596 .581 .807 r
.62823 .40713 .63447 .42056 .64676 .4192 .64052 .40561 Mtetra
.579 .571 .808 r
.64052 .40561 .64676 .4192 .65914 .41837 .65291 .4048 Mtetra
.562 .563 .812 r
.65291 .4048 .65914 .41837 .67161 .4178 .66541 .40465 Mtetra
.551 .563 .82 r
.66541 .40465 .67161 .4178 .68415 .41689 .67801 .40489 Mtetra
.554 .585 .839 r
.67801 .40489 .68415 .41689 .69669 .4145 .69068 .40482 Mtetra
.596 .654 .877 r
.69068 .40482 .69669 .4145 .70912 .40904 .70335 .40307 Mtetra
.706 .803 .925 r
.70335 .40307 .70912 .40904 .72132 .39906 .71588 .39761 Mtetra
.841 .969 .882 r
.71588 .39761 .72132 .39906 .73325 .38475 .72811 .38675 Mtetra
.863 .989 .726 r
.72811 .38675 .73325 .38475 .74544 .37464 .74002 .37115 Mtetra
.783 .909 .927 r
.74002 .37115 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.664 .741 .907 r
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.663 .74 .908 r
.7908 .35057 .79634 .35824 .80934 .35559 .80371 .34643 Mtetra
.609 .677 .889 r
.80371 .34643 .80934 .35559 .8223 .35172 .81685 .34409 Mtetra
.677 .749 .905 r
.81685 .34409 .8223 .35172 .83521 .34673 .82984 .33942 Mtetra
.689 .764 .909 r
.82984 .33942 .83521 .34673 .84819 .34189 .84285 .33435 Mtetra
.677 .754 .909 r
.84285 .33435 .84819 .34189 .86126 .33741 .85594 .32965 Mtetra
.668 .745 .908 r
.85594 .32965 .86126 .33741 .87441 .3331 .86913 .32524 Mtetra
.665 .742 .907 r
.86913 .32524 .87441 .3331 .88763 .32882 .88239 .32091 Mtetra
.664 .741 .907 r
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50074 .30707 .50722 .3179 .50372 .31098 .49721 Mtetra
.662 .741 .908 r
.31098 .49721 .3179 .50372 .32877 .50022 .32188 .49372 Mtetra
.656 .74 .911 r
.32188 .49372 .32877 .50022 .33969 .49682 .33282 .49038 Mtetra
.642 .739 .919 r
.33282 .49038 .33969 .49682 .35063 .49369 .34378 .48742 Mtetra
.632 .742 .927 r
.34378 .48742 .35063 .49369 .3616 .49093 .35477 .48466 Mtetra
.677 .755 .91 r
.35477 .48466 .3616 .49093 .37264 .48779 .36588 .48067 Mtetra
.702 .737 .878 r
.36588 .48067 .37264 .48779 .38383 .4824 .37708 .47568 Mtetra
.664 .74 .906 r
.37708 .47568 .38383 .4824 .39498 .47875 .38826 .47205 Mtetra
.664 .741 .907 r
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.662 .74 .908 r
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46109 Mtetra
0 .158 .659 r
.42207 .46109 .4287 .46783 .43994 .46811 .43308 .47 Mtetra
.544 0 0 r
.43308 .47 .43994 .46811 .45108 .47569 .44433 .47471 Mtetra
.291 .777 .91 r
.44433 .47471 .45108 .47569 .46244 .47867 .45582 .4733 Mtetra
.733 .805 .908 r
.45582 .4733 .46244 .47867 .47397 .47638 .46745 .46729 Mtetra
.75 .712 .817 r
.46745 .46729 .47397 .47638 .48561 .47045 .47915 .45911 Mtetra
.737 .671 .785 r
.47915 .45911 .48561 .47045 .49729 .46284 .49087 .45048 Mtetra
.724 .651 .777 r
.49087 .45048 .49729 .46284 .509 .45493 .5026 .4423 Mtetra
.711 .643 .779 r
.5026 .4423 .509 .45493 .52073 .44738 .51434 .43485 Mtetra
.7 .64 .786 r
.51434 .43485 .52073 .44738 .53248 .44048 .52611 .42819 Mtetra
.67 .631 .801 r
.52611 .42819 .53248 .44048 .54426 .43426 .53792 .42333 Mtetra
.655 .647 .83 r
.53792 .42333 .54426 .43426 .55609 .42871 .54978 .41947 Mtetra
.66 .684 .862 r
.54978 .41947 .55609 .42871 .56796 .42375 .56169 .41559 Mtetra
.663 .712 .885 r
.56169 .41559 .56796 .42375 .57988 .41934 .57366 .4117 Mtetra
.664 .727 .897 r
.57366 .4117 .57988 .41934 .59186 .41546 .58567 .40779 Mtetra
.58567 .40779 .59186 .41546 .60391 .41211 .59774 .40386 Mtetra
.663 .712 .885 r
.59774 .40386 .60391 .41211 .61603 .40932 .60985 .39992 Mtetra
.66 .684 .862 r
.60985 .39992 .61603 .40932 .62823 .40713 .62203 .39596 Mtetra
.631 .636 .837 r
.62203 .39596 .62823 .40713 .64052 .40561 .63428 .393 Mtetra
.584 .589 .823 r
.63428 .393 .64052 .40561 .65291 .4048 .64668 .39187 Mtetra
.564 .574 .822 r
.64668 .39187 .65291 .4048 .66541 .40465 .65918 .39155 Mtetra
.544 .561 .823 r
.65918 .39155 .66541 .40465 .67801 .40489 .6718 .39198 Mtetra
.529 .558 .828 r
.6718 .39198 .67801 .40489 .69068 .40482 .68453 .39288 Mtetra
.536 .579 .845 r
.68453 .39288 .69068 .40482 .70335 .40307 .69734 .39335 Mtetra
.594 .654 .879 r
.69734 .39335 .70335 .40307 .71588 .39761 .71011 .39161 Mtetra
.733 .812 .913 r
.71011 .39161 .71588 .39761 .72811 .38675 .72267 .38518 Mtetra
.878 .961 .851 r
.72267 .38518 .72811 .38675 .74002 .37115 .73486 .37247 Mtetra
.907 .983 .732 r
.73486 .37247 .74002 .37115 .75242 .363 .74673 .35542 Mtetra
.665 .743 .908 r
.74673 .35542 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.664 .741 .907 r
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34643 .79817 .33862 Mtetra
.619 .721 .919 r
.79817 .33862 .80371 .34643 .81685 .34409 .81131 .3358 Mtetra
.652 .722 .9 r
.81131 .3358 .81685 .34409 .82984 .33942 .82442 .33195 Mtetra
.689 .762 .907 r
.82442 .33195 .82984 .33942 .84285 .33435 .83746 .32681 Mtetra
.683 .758 .909 r
.83746 .32681 .84285 .33435 .85594 .32965 .85059 .32188 Mtetra
.671 .748 .908 r
.85059 .32188 .85594 .32965 .86913 .32524 .86381 .31733 Mtetra
.666 .743 .908 r
.86381 .31733 .86913 .32524 .88239 .32091 .8771 .31294 Mtetra
.664 .741 .907 r
.8771 .31294 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.664 .741 .908 r
.29313 .4942 .30013 .50074 .31098 .49721 .30401 .49065 Mtetra
.66 .74 .909 r
.30401 .49065 .31098 .49721 .32188 .49372 .31493 .48718 Mtetra
.652 .739 .914 r
.31493 .48718 .32188 .49372 .33282 .49038 .32589 .48394 Mtetra
.635 .738 .923 r
.32589 .48394 .33282 .49038 .34378 .48742 .33687 .48113 Mtetra
.641 .746 .925 r
.33687 .48113 .34378 .48742 .35477 .48466 .3479 .47812 Mtetra
.713 .756 .886 r
.3479 .47812 .35477 .48466 .36588 .48067 .3591 .47283 Mtetra
.669 .71 .879 r
.3591 .47283 .36588 .48067 .37708 .47568 .37028 .46896 Mtetra
.664 .741 .907 r
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.159 .502 .909 r
.40403 .45791 .41075 .46473 .42207 .46109 .41512 .46215 Mtetra
.64 .106 0 r
.41512 .46215 .42207 .46109 .43308 .47 .42621 .46937 Mtetra
0 .56 .734 r
.42621 .46937 .43308 .47 .44433 .47471 .4376 .47006 Mtetra
.71 .826 .937 r
.4376 .47006 .44433 .47471 .45582 .4733 .44921 .46486 Mtetra
.758 .728 .825 r
.44921 .46486 .45582 .4733 .46745 .46729 .46092 .45649 Mtetra
.75 .683 .787 r
.46092 .45649 .46745 .46729 .47915 .45911 .47266 .44728 Mtetra
.736 .664 .779 r
.47266 .44728 .47915 .45911 .49087 .45048 .4844 .43846 Mtetra
.724 .657 .783 r
.4844 .43846 .49087 .45048 .5026 .4423 .49616 .43045 Mtetra
.702 .651 .796 r
.49616 .43045 .5026 .4423 .51434 .43485 .50792 .42392 Mtetra
.655 .647 .83 r
.50792 .42392 .51434 .43485 .52611 .42819 .51971 .42007 Mtetra
.663 .712 .885 r
.51971 .42007 .52611 .42819 .53792 .42333 .53155 .41619 Mtetra
.664 .741 .907 r
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63428 .393 .62816 .38459 Mtetra
.663 .712 .885 r
.62816 .38459 .63428 .393 .64668 .39187 .64047 .38056 Mtetra
.586 .615 .847 r
.64047 .38056 .64668 .39187 .65918 .39155 .65295 .37923 Mtetra
.546 .577 .837 r
.65295 .37923 .65918 .39155 .6718 .39198 .66557 .37941 Mtetra
.522 .56 .835 r
.66557 .37941 .6718 .39198 .68453 .39288 .67832 .38044 Mtetra
.508 .556 .84 r
.67832 .38044 .68453 .39288 .69734 .39335 .69119 .38188 Mtetra
.527 .585 .856 r
.69119 .38188 .69734 .39335 .71011 .39161 .70412 .38248 Mtetra
.618 .682 .888 r
.70412 .38248 .71011 .39161 .72267 .38518 .71694 .37986 Mtetra
.789 .848 .895 r
.71694 .37986 .72267 .38518 .73486 .37247 .72946 .37121 Mtetra
.914 .956 .804 r
.72946 .37121 .73486 .37247 .74673 .35542 .74153 .35584 Mtetra
.83 1 .819 r
.74153 .35584 .74673 .35542 .7595 .35121 .75379 .34348 Mtetra
.664 .741 .907 r
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.657 .738 .91 r
.79259 .33079 .79817 .33862 .81131 .3358 .80566 .32675 Mtetra
.613 .686 .895 r
.80566 .32675 .81131 .3358 .82442 .33195 .81892 .32418 Mtetra
.682 .752 .904 r
.81892 .32418 .82442 .33195 .83746 .32681 .83204 .31924 Mtetra
.688 .761 .907 r
.83204 .31924 .83746 .32681 .85059 .32188 .84519 .31409 Mtetra
.675 .751 .908 r
.84519 .31409 .85059 .32188 .86381 .31733 .85844 .30938 Mtetra
.667 .744 .908 r
.85844 .30938 .86381 .31733 .8771 .31294 .87178 .3049 Mtetra
.664 .741 .907 r
.87178 .3049 .8771 .31294 .89047 .30858 .88519 .30051 Mtetra
.663 .741 .908 r
.28608 .48762 .29313 .4942 .30401 .49065 .29699 .48406 Mtetra
.659 .74 .91 r
.29699 .48406 .30401 .49065 .31493 .48718 .30793 .48061 Mtetra
.646 .738 .916 r
.30793 .48061 .31493 .48718 .32589 .48394 .3189 .47749 Mtetra
.631 .738 .925 r
.3189 .47749 .32589 .48394 .33687 .48113 .3299 .47474 Mtetra
.66 .749 .916 r
.3299 .47474 .33687 .48113 .3479 .47812 .341 .4712 Mtetra
.712 .746 .879 r
.341 .4712 .3479 .47812 .3591 .47283 .35223 .46586 Mtetra
.664 .734 .902 r
.35223 .46586 .3591 .47283 .37028 .46896 .36342 .46218 Mtetra
.664 .741 .907 r
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.627 .73 .921 r
.38594 .45477 .39273 .46161 .40403 .45791 .39723 .45207 Mtetra
.486 0 0 r
.39723 .45207 .40403 .45791 .41512 .46215 .40813 .46175 Mtetra
.413 0 0 r
.40813 .46175 .41512 .46215 .42621 .46937 .41936 .46584 Mtetra
.6 .843 .99 r
.41936 .46584 .42621 .46937 .4376 .47006 .43089 .46275 Mtetra
.759 .755 .848 r
.43089 .46275 .4376 .47006 .44921 .46486 .4426 .45491 Mtetra
.762 .701 .794 r
.4426 .45491 .44921 .46486 .46092 .45649 .45436 .44533 Mtetra
.75 .679 .782 r
.45436 .44533 .46092 .45649 .47266 .44728 .46613 .43585 Mtetra
.737 .671 .786 r
.46613 .43585 .47266 .44728 .4844 .43846 .4779 .42721 Mtetra
.706 .662 .804 r
.4779 .42721 .4844 .43846 .49616 .43045 .48966 .42066 Mtetra
.658 .671 .851 r
.48966 .42066 .49616 .43045 .50792 .42392 .50144 .41679 Mtetra
.664 .741 .907 r
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65295 .37923 .64678 .36899 Mtetra
.583 .637 .871 r
.64678 .36899 .65295 .37923 .66557 .37941 .65935 .36762 Mtetra
.523 .576 .85 r
.65935 .36762 .66557 .37941 .67832 .38044 .67211 .3684 Mtetra
.496 .558 .848 r
.67211 .3684 .67832 .38044 .69119 .38188 .685 .37004 Mtetra
.49 .559 .853 r
.685 .37004 .69119 .38188 .70412 .38248 .698 .3718 Mtetra
.539 .61 .872 r
.698 .3718 .70412 .38248 .71694 .37986 .71101 .37181 Mtetra
.681 .739 .894 r
.71101 .37181 .71694 .37986 .72946 .37121 .7238 .36697 Mtetra
.861 .887 .854 r
.7238 .36697 .72946 .37121 .74153 .35584 .73616 .35475 Mtetra
.939 .944 .763 r
.73616 .35475 .74153 .35584 .75379 .34348 .74811 .33674 Mtetra
.696 .784 .919 r
.74811 .33674 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.664 .741 .907 r
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80566 .32675 .80004 .31859 Mtetra
.609 .711 .917 r
.80004 .31859 .80566 .32675 .81892 .32418 .81335 .31601 Mtetra
.667 .736 .902 r
.81335 .31601 .81892 .32418 .83204 .31924 .82656 .31156 Mtetra
.691 .761 .905 r
.82656 .31156 .83204 .31924 .84519 .31409 .83975 .30627 Mtetra
.679 .753 .907 r
.83975 .30627 .84519 .31409 .85844 .30938 .85303 .30137 Mtetra
.669 .745 .907 r
.85303 .30137 .85844 .30938 .87178 .3049 .8664 .29681 Mtetra
.665 .742 .907 r
.8664 .29681 .87178 .3049 .88519 .30051 .87986 .29236 Mtetra
.662 .741 .908 r
.27897 .48099 .28608 .48762 .29699 .48406 .28991 .47742 Mtetra
.656 .74 .911 r
.28991 .47742 .29699 .48406 .30793 .48061 .30087 .47401 Mtetra
.641 .738 .919 r
.30087 .47401 .30793 .48061 .3189 .47749 .31186 .471 Mtetra
.631 .739 .926 r
.31186 .471 .3189 .47749 .3299 .47474 .32289 .46821 Mtetra
.684 .752 .903 r
.32289 .46821 .3299 .47474 .341 .4712 .33406 .4639 Mtetra
.697 .734 .88 r
.33406 .4639 .341 .4712 .35223 .46586 .34529 .45905 Mtetra
.664 .741 .907 r
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.247 .555 .932 r
.37909 .44788 .38594 .45477 .39723 .45207 .39016 .45113 Mtetra
.645 .09 0 r
.39016 .45113 .39723 .45207 .40813 .46175 .40114 .4593 Mtetra
.172 .669 .915 r
.40114 .4593 .40813 .46175 .41936 .46584 .41251 .46002 Mtetra
.731 .792 .901 r
.41251 .46002 .41936 .46584 .43089 .46275 .42417 .45398 Mtetra
.77 .725 .811 r
.42417 .45398 .43089 .46275 .4426 .45491 .43595 .44456 Mtetra
.764 .696 .787 r
.43595 .44456 .4426 .45491 .45436 .44533 .44775 .43449 Mtetra
.752 .685 .787 r
.44775 .43449 .45436 .44533 .46613 .43585 .45955 .42511 Mtetra
.729 .68 .802 r
.45955 .42511 .46613 .43585 .4779 .42721 .47134 .41739 Mtetra
.658 .671 .851 r
.47134 .41739 .4779 .42721 .48966 .42066 .48309 .4135 Mtetra
.664 .741 .907 r
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65935 .36762 .65316 .35728 Mtetra
.544 .618 .877 r
.65316 .35728 .65935 .36762 .67211 .3684 .66589 .35705 Mtetra
.493 .571 .863 r
.66589 .35705 .67211 .3684 .685 .37004 .67879 .35852 Mtetra
.469 .555 .861 r
.67879 .35852 .685 .37004 .698 .3718 .69183 .3607 Mtetra
.487 .575 .869 r
.69183 .3607 .698 .3718 .71101 .37181 .70494 .36226 Mtetra
.593 .665 .888 r
.70494 .36226 .71101 .37181 .7238 .36697 .71795 .36037 Mtetra
.782 .812 .876 r
.71795 .36037 .7238 .36697 .73616 .35475 .73059 .35154 Mtetra
.918 .905 .794 r
.73059 .35154 .73616 .35475 .74811 .33674 .74273 .33503 Mtetra
.849 .97 .875 r
.74273 .33503 .74811 .33674 .76095 .33145 .75519 .32356 Mtetra
.664 .741 .907 r
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.626 .725 .918 r
.79441 .31059 .80004 .31859 .81335 .31601 .80771 .30743 Mtetra
.644 .718 .901 r
.80771 .30743 .81335 .31601 .82656 .31156 .82103 .30371 Mtetra
.69 .758 .903 r
.82103 .30371 .82656 .31156 .83975 .30627 .83426 .2984 Mtetra
.683 .756 .906 r
.83426 .2984 .83975 .30627 .85303 .30137 .84757 .29332 Mtetra
.671 .746 .907 r
.84757 .29332 .85303 .30137 .8664 .29681 .86099 .28865 Mtetra
.665 .742 .907 r
.86099 .28865 .8664 .29681 .87986 .29236 .87448 .28414 Mtetra
.662 .741 .908 r
.27181 .47432 .27897 .48099 .28991 .47742 .28277 .47072 Mtetra
.654 .739 .912 r
.28277 .47072 .28991 .47742 .30087 .47401 .29376 .46736 Mtetra
.637 .737 .921 r
.29376 .46736 .30087 .47401 .31186 .471 .30477 .46444 Mtetra
.636 .74 .923 r
.30477 .46444 .31186 .471 .32289 .46821 .31583 .46151 Mtetra
.708 .754 .888 r
.31583 .46151 .32289 .46821 .33406 .4639 .32708 .45632 Mtetra
.675 .723 .885 r
.32708 .45632 .33406 .4639 .34529 .45905 .3383 .45219 Mtetra
.664 .741 .907 r
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
0 .211 .705 r
.37218 .44094 .37909 .44788 .39016 .45113 .38306 .44899 Mtetra
.465 0 0 r
.38306 .44899 .39016 .45113 .40114 .4593 .39415 .45497 Mtetra
.565 .803 .989 r
.39415 .45497 .40114 .4593 .41251 .46002 .40565 .45274 Mtetra
.763 .757 .848 r
.40565 .45274 .41251 .46002 .42417 .45398 .41741 .44468 Mtetra
.777 .718 .797 r
.41741 .44468 .42417 .45398 .43595 .44456 .42925 .43441 Mtetra
.768 .701 .789 r
.42925 .43441 .43595 .44456 .44775 .43449 .4411 .42426 Mtetra
.754 .697 .797 r
.4411 .42426 .44775 .43449 .45955 .42511 .45292 .41511 Mtetra
.681 .677 .84 r
.45292 .41511 .45955 .42511 .47134 .41739 .46468 .4102 Mtetra
.664 .741 .907 r
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.63 .728 .918 r
.64703 .34961 .65316 .35728 .66589 .35705 .65967 .34645 Mtetra
.494 .589 .878 r
.65967 .34645 .66589 .35705 .67879 .35852 .67257 .34761 Mtetra
.457 .563 .874 r
.67257 .34761 .67879 .35852 .69183 .3607 .68563 .34981 Mtetra
.452 .561 .875 r
.68563 .34981 .69183 .3607 .70494 .36226 .6988 .35216 Mtetra
.527 .621 .888 r
.6988 .35216 .70494 .36226 .71795 .36037 .71196 .35226 Mtetra
.706 .751 .887 r
.71196 .35226 .71795 .36037 .73059 .35154 .72484 .3464 Mtetra
.879 .861 .819 r
.72484 .3464 .73059 .35154 .74273 .33503 .7372 .33208 Mtetra
.92 .915 .795 r
.7372 .33208 .74273 .33503 .75519 .32356 .74937 .3156 Mtetra
.664 .741 .907 r
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.651 .736 .911 r
.78872 .30252 .79441 .31059 .80771 .30743 .80199 .29855 Mtetra
.618 .699 .903 r
.80199 .29855 .80771 .30743 .82103 .30371 .81544 .29567 Mtetra
.686 .753 .902 r
.81544 .29567 .82103 .30371 .83426 .2984 .82873 .29044 Mtetra
.686 .756 .905 r
.82873 .29044 .83426 .2984 .84757 .29332 .84207 .28521 Mtetra
.673 .748 .907 r
.84207 .28521 .84757 .29332 .86099 .28865 .85552 .28041 Mtetra
.665 .742 .907 r
.85552 .28041 .86099 .28865 .87448 .28414 .86906 .27586 Mtetra
.661 .74 .909 r
.26459 .46758 .27181 .47432 .28277 .47072 .27558 .46399 Mtetra
.651 .739 .913 r
.27558 .46399 .28277 .47072 .29376 .46736 .28659 .46066 Mtetra
.633 .735 .922 r
.28659 .46066 .29376 .46736 .30477 .46444 .29762 .4578 Mtetra
.644 .741 .92 r
.29762 .4578 .30477 .46444 .31583 .46151 .30872 .45465 Mtetra
.717 .752 .88 r
.30872 .45465 .31583 .46151 .32708 .45632 .32003 .44903 Mtetra
.664 .729 .898 r
.32003 .44903 .32708 .45632 .3383 .45219 .33125 .44528 Mtetra
.664 .741 .907 r
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.628 .73 .921 r
.35385 .43773 .36084 .4447 .37218 .44094 .36517 .43494 Mtetra
.556 .032 0 r
.36517 .43494 .37218 .44094 .38306 .44899 .37594 .4455 Mtetra
0 .435 .785 r
.37594 .4455 .38306 .44899 .39415 .45497 .38715 .44924 Mtetra
.684 .788 .929 r
.38715 .44924 .39415 .45497 .40565 .45274 .39877 .44477 Mtetra
.777 .745 .824 r
.39877 .44477 .40565 .45274 .41741 .44468 .41061 .43541 Mtetra
.782 .72 .795 r
.41061 .43541 .41741 .44468 .42925 .43441 .4225 .42474 Mtetra
.771 .712 .796 r
.4225 .42474 .42925 .43441 .4411 .42426 .43438 .41467 Mtetra
.739 .705 .819 r
.43438 .41467 .4411 .42426 .45292 .41511 .4462 .40689 Mtetra
.663 .713 .885 r
.4462 .40689 .45292 .41511 .46468 .4102 .45797 .40295 Mtetra
.664 .741 .907 r
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65967 .34645 .65348 .33765 Mtetra
.528 .653 .915 r
.65348 .33765 .65967 .34645 .67257 .34761 .66635 .33735 Mtetra
.45 .576 .889 r
.66635 .33735 .67257 .34761 .68563 .34981 .67942 .3394 Mtetra
.426 .56 .886 r
.67942 .3394 .68563 .34981 .6988 .35216 .69263 .34208 Mtetra
.476 .596 .894 r
.69263 .34208 .6988 .35216 .71196 .35226 .70589 .34344 Mtetra
.642 .709 .896 r
.70589 .34344 .71196 .35226 .72484 .3464 .71894 .33981 Mtetra
.836 .824 .837 r
.71894 .33981 .72484 .3464 .7372 .33208 .73151 .32773 Mtetra
.928 .871 .76 r
.73151 .32773 .7372 .33208 .74937 .3156 .74359 .30861 Mtetra
.695 .783 .919 r
.74359 .30861 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.664 .741 .907 r
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80199 .29855 .79627 .28995 Mtetra
.603 .702 .914 r
.79627 .28995 .80199 .29855 .81544 .29567 .80978 .28745 Mtetra
.68 .747 .902 r
.80978 .28745 .81544 .29567 .82873 .29044 .82314 .28239 Mtetra
.689 .756 .903 r
.82314 .28239 .82873 .29044 .84207 .28521 .83652 .27702 Mtetra
.675 .748 .906 r
.83652 .27702 .84207 .28521 .85552 .28041 .85001 .27212 Mtetra
.666 .743 .907 r
.85001 .27212 .85552 .28041 .86906 .27586 .86359 .2675 Mtetra
.661 .741 .909 r
.25732 .46081 .26459 .46758 .27558 .46399 .26833 .45719 Mtetra
.649 .738 .914 r
.26833 .45719 .27558 .46399 .28659 .46066 .27937 .4539 Mtetra
.631 .735 .922 r
.27937 .4539 .28659 .46066 .29762 .4578 .29042 .45106 Mtetra
.652 .742 .916 r
.29042 .45106 .29762 .4578 .30872 .45465 .30156 .44766 Mtetra
.715 .75 .88 r
.30156 .44766 .30872 .45465 .32003 .44903 .31289 .4421 Mtetra
.664 .741 .907 r
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.48 .674 .95 r
.34681 .43071 .35385 .43773 .36517 .43494 .358 .43087 Mtetra
.626 .073 0 r
.358 .43087 .36517 .43494 .37594 .4455 .36881 .44074 Mtetra
.222 .627 .955 r
.36881 .44074 .37594 .4455 .38715 .44924 .38012 .44265 Mtetra
.726 .772 .889 r
.38012 .44265 .38715 .44924 .39877 .44477 .39184 .43661 Mtetra
.786 .743 .814 r
.39184 .43661 .39877 .44477 .41061 .43541 .40374 .42649 Mtetra
.787 .729 .798 r
.40374 .42649 .41061 .43541 .4225 .42474 .41568 .41565 Mtetra
.775 .724 .805 r
.41568 .41565 .4225 .42474 .43438 .41467 .42759 .40569 Mtetra
.712 .711 .848 r
.42759 .40569 .43438 .41467 .4462 .40689 .43941 .39961 Mtetra
.664 .741 .907 r
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.589 .711 .928 r
.64729 .32981 .65348 .33765 .66635 .33735 .66011 .32771 Mtetra
.445 .59 .903 r
.66011 .32771 .66635 .33735 .67942 .3394 .67319 .32957 Mtetra
.407 .565 .899 r
.67319 .32957 .67942 .3394 .69263 .34208 .68643 .33235 Mtetra
.437 .586 .903 r
.68643 .33235 .69263 .34208 .70589 .34344 .69975 .33442 Mtetra
.592 .684 .905 r
.69975 .33442 .70589 .34344 .71894 .33981 .71294 .33233 Mtetra
.8 .797 .85 r
.71294 .33233 .71894 .33981 .73151 .32773 .72569 .32206 Mtetra
.911 .844 .766 r
.72569 .32206 .73151 .32773 .74359 .30861 .73788 .30359 Mtetra
.783 .871 .913 r
.73788 .30359 .74359 .30861 .75661 .3032 .75074 .29507 Mtetra
.664 .741 .907 r
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.604 .715 .923 r
.79053 .28171 .79627 .28995 .80978 .28745 .80408 .27909 Mtetra
.674 .743 .902 r
.80408 .27909 .80978 .28745 .82314 .28239 .8175 .27421 Mtetra
.69 .755 .902 r
.8175 .27421 .82314 .28239 .83652 .27702 .83092 .26875 Mtetra
.677 .749 .905 r
.83092 .26875 .83652 .27702 .85001 .27212 .84445 .26375 Mtetra
.666 .743 .907 r
.84445 .26375 .85001 .27212 .86359 .2675 .85808 .25908 Mtetra
.66 .74 .909 r
.24999 .45397 .25732 .46081 .26833 .45719 .26103 .45034 Mtetra
.648 .737 .915 r
.26103 .45034 .26833 .45719 .27937 .4539 .27209 .44706 Mtetra
.63 .734 .922 r
.27209 .44706 .27937 .4539 .29042 .45106 .28317 .44422 Mtetra
.658 .742 .912 r
.28317 .44422 .29042 .45106 .30156 .44766 .29435 .44061 Mtetra
.713 .749 .881 r
.29435 .44061 .30156 .44766 .31289 .4421 .30571 .43511 Mtetra
.664 .741 .907 r
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.334 .604 .947 r
.33971 .42363 .34681 .43071 .358 .43087 .35082 .42578 Mtetra
.529 0 0 r
.35082 .42578 .358 .43087 .36881 .44074 .36166 .43499 Mtetra
.4 .687 .977 r
.36166 .43499 .36881 .44074 .38012 .44265 .37305 .43562 Mtetra
.745 .764 .869 r
.37305 .43562 .38012 .44265 .39184 .43661 .38485 .4286 Mtetra
.793 .749 .812 r
.38485 .4286 .39184 .43661 .40374 .42649 .39681 .41805 Mtetra
.793 .74 .804 r
.39681 .41805 .40374 .42649 .41568 .41565 .40879 .40715 Mtetra
.78 .738 .814 r
.40879 .40715 .41568 .41565 .42759 .40569 .42074 .39728 Mtetra
.69 .719 .872 r
.42074 .39728 .42759 .40569 .43941 .39961 .43256 .39228 Mtetra
.664 .741 .907 r
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.631 .728 .918 r
.64105 .3219 .64729 .32981 .66011 .32771 .65385 .31863 Mtetra
.438 .604 .916 r
.65385 .31863 .66011 .32771 .67319 .32957 .66696 .32032 Mtetra
.389 .573 .912 r
.66696 .32032 .67319 .32957 .68643 .33235 .68022 .3231 Mtetra
.406 .583 .913 r
.68022 .3231 .68643 .33235 .69975 .33442 .69359 .32554 Mtetra
.556 .673 .916 r
.69359 .32554 .69975 .33442 .71294 .33233 .70686 .32438 Mtetra
.773 .781 .859 r
.70686 .32438 .71294 .33233 .72569 .32206 .71974 .31537 Mtetra
.895 .823 .769 r
.71974 .31537 .72569 .32206 .73788 .30359 .73205 .29751 Mtetra
.819 .843 .867 r
.73205 .29751 .73788 .30359 .75074 .29507 .74482 .28687 Mtetra
.664 .741 .907 r
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.607 .716 .922 r
.78474 .2734 .79053 .28171 .80408 .27909 .79832 .27064 Mtetra
.668 .74 .904 r
.79832 .27064 .80408 .27909 .8175 .27421 .81181 .26592 Mtetra
.691 .754 .9 r
.81181 .26592 .8175 .27421 .83092 .26875 .82527 .26038 Mtetra
.678 .748 .904 r
.82527 .26038 .83092 .26875 .84445 .26375 .83885 .2553 Mtetra
.667 .743 .907 r
.83885 .2553 .84445 .26375 .85808 .25908 .85252 .25058 Mtetra
.66 .74 .909 r
.2426 .44708 .24999 .45397 .26103 .45034 .25367 .44343 Mtetra
.647 .737 .915 r
.25367 .44343 .26103 .45034 .27209 .44706 .26476 .44014 Mtetra
.63 .733 .922 r
.26476 .44014 .27209 .44706 .28317 .44422 .27586 .43728 Mtetra
.662 .742 .909 r
.27586 .43728 .28317 .44422 .29435 .44061 .28708 .43353 Mtetra
.711 .75 .882 r
.28708 .43353 .29435 .44061 .30571 .43511 .29846 .42806 Mtetra
.664 .741 .907 r
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.245 .556 .932 r
.33255 .41649 .33971 .42363 .35082 .42578 .34362 .41963 Mtetra
0 .1 .574 r
.34362 .41963 .35082 .42578 .36166 .43499 .35449 .42844 Mtetra
.472 .693 .964 r
.35449 .42844 .36166 .43499 .37305 .43562 .36593 .42842 Mtetra
.753 .763 .861 r
.36593 .42842 .37305 .43562 .38485 .4286 .37779 .42092 Mtetra
.799 .757 .815 r
.37779 .42092 .38485 .4286 .39681 .41805 .3898 .41015 Mtetra
.799 .754 .811 r
.3898 .41015 .39681 .41805 .40879 .40715 .40183 .39921 Mtetra
.785 .752 .823 r
.40183 .39921 .40879 .40715 .42074 .39728 .41382 .38937 Mtetra
.677 .73 .89 r
.41382 .38937 .42074 .39728 .43256 .39228 .42565 .3849 Mtetra
.664 .741 .907 r
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.649 .735 .912 r
.63475 .31393 .64105 .3219 .65385 .31863 .64757 .31006 Mtetra
.428 .616 .929 r
.64757 .31006 .65385 .31863 .66696 .32032 .6607 .31166 Mtetra
.37 .582 .924 r
.6607 .31166 .66696 .32032 .68022 .3231 .67399 .3144 Mtetra
.38 .587 .924 r
.67399 .3144 .68022 .3231 .69359 .32554 .68739 .31699 Mtetra
.534 .673 .927 r
.68739 .31699 .69359 .32554 .70686 .32438 .70073 .31625 Mtetra
.76 .775 .865 r
.70073 .31625 .70686 .32438 .71974 .31537 .71369 .30784 Mtetra
.883 .807 .769 r
.71369 .30784 .71974 .31537 .73205 .29751 .7261 .29032 Mtetra
.826 .815 .839 r
.7261 .29032 .73205 .29751 .74482 .28687 .73886 .2786 Mtetra
.664 .741 .907 r
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.61 .717 .922 r
.7789 .26501 .78474 .2734 .79832 .27064 .79252 .26215 Mtetra
.665 .74 .906 r
.79252 .26215 .79832 .27064 .81181 .26592 .80606 .2575 Mtetra
.691 .753 .899 r
.80606 .2575 .81181 .26592 .82527 .26038 .81957 .25192 Mtetra
.678 .748 .903 r
.81957 .25192 .82527 .26038 .83885 .2553 .83319 .24677 Mtetra
.667 .742 .907 r
.83319 .24677 .83885 .2553 .85252 .25058 .84691 .242 Mtetra
.66 .74 .909 r
.23516 .44013 .2426 .44708 .25367 .44343 .24625 .43644 Mtetra
.647 .736 .914 r
.24625 .43644 .25367 .44343 .26476 .44014 .25737 .43313 Mtetra
.63 .732 .921 r
.25737 .43313 .26476 .44014 .27586 .43728 .26849 .43024 Mtetra
.662 .741 .908 r
.26849 .43024 .27586 .43728 .28708 .43353 .27974 .42646 Mtetra
.712 .752 .884 r
.27974 .42646 .28708 .43353 .29846 .42806 .29116 .42096 Mtetra
.664 .741 .907 r
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.245 .556 .932 r
.32534 .4093 .33255 .41649 .34362 .41963 .33642 .41241 Mtetra
0 .148 .647 r
.33642 .41241 .34362 .41963 .35449 .42844 .34729 .42121 Mtetra
.487 .679 .95 r
.34729 .42121 .35449 .42844 .36593 .42842 .35875 .42117 Mtetra
.753 .763 .861 r
.35875 .42117 .36593 .42842 .37779 .42092 .37065 .41363 Mtetra
.803 .768 .821 r
.37065 .41363 .37779 .42092 .3898 .41015 .38271 .40282 Mtetra
.805 .768 .819 r
.38271 .40282 .3898 .41015 .40183 .39921 .39479 .39184 Mtetra
.791 .767 .832 r
.39479 .39184 .40183 .39921 .41382 .38937 .40682 .38196 Mtetra
.678 .745 .901 r
.40682 .38196 .41382 .38937 .42565 .3849 .41869 .37745 Mtetra
.664 .741 .907 r
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.649 .735 .912 r
.6284 .30589 .63475 .31393 .64757 .31006 .64126 .30199 Mtetra
.414 .625 .94 r
.64126 .30199 .64757 .31006 .6607 .31166 .65442 .30356 Mtetra
.349 .589 .934 r
.65442 .30356 .6607 .31166 .67399 .3144 .66773 .30627 Mtetra
.36 .595 .936 r
.66773 .30627 .67399 .3144 .68739 .31699 .68116 .30884 Mtetra
.528 .684 .938 r
.68116 .30884 .68739 .31699 .70073 .31625 .69454 .30807 Mtetra
.76 .775 .866 r
.69454 .30807 .70073 .31625 .71369 .30784 .70755 .29961 Mtetra
.876 .793 .765 r
.70755 .29961 .71369 .30784 .7261 .29032 .72002 .28203 Mtetra
.815 .787 .827 r
.72002 .28203 .7261 .29032 .73886 .2786 .73284 .27026 Mtetra
.664 .741 .907 r
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.61 .717 .922 r
.77301 .25655 .7789 .26501 .79252 .26215 .78667 .25365 Mtetra
.665 .742 .907 r
.78667 .25365 .79252 .26215 .80606 .2575 .80026 .24897 Mtetra
.691 .752 .898 r
.80026 .24897 .80606 .2575 .81957 .25192 .81382 .24334 Mtetra
.678 .747 .903 r
.81382 .24334 .81957 .25192 .83319 .24677 .82748 .23815 Mtetra
.667 .742 .906 r
.82748 .23815 .83319 .24677 .84691 .242 .84124 .23334 Mtetra
.66 .74 .909 r
.22766 .43311 .23516 .44013 .24625 .43644 .23878 .4294 Mtetra
.648 .736 .914 r
.23878 .4294 .24625 .43644 .25737 .43313 .24992 .42603 Mtetra
.631 .731 .92 r
.24992 .42603 .25737 .43313 .26849 .43024 .26107 .42311 Mtetra
.658 .738 .909 r
.26107 .42311 .26849 .43024 .27974 .42646 .27234 .4194 Mtetra
.713 .754 .884 r
.27234 .4194 .27974 .42646 .29116 .42096 .2838 .4138 Mtetra
.664 .741 .907 r
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.334 .604 .947 r
.31807 .40204 .32534 .4093 .33642 .41241 .32922 .40413 Mtetra
0 .159 .677 r
.32922 .40413 .33642 .41241 .34729 .42121 .34007 .41332 Mtetra
.462 .648 .939 r
.34007 .41332 .34729 .42121 .35875 .42117 .35151 .41388 Mtetra
.744 .762 .867 r
.35151 .41388 .35875 .42117 .37065 .41363 .36343 .40675 Mtetra
.806 .779 .828 r
.36343 .40675 .37065 .41363 .38271 .40282 .37554 .39606 Mtetra
.812 .783 .826 r
.37554 .39606 .38271 .40282 .39479 .39184 .38766 .38503 Mtetra
.798 .783 .839 r
.38766 .38503 .39479 .39184 .40682 .38196 .39975 .37503 Mtetra
.696 .765 .905 r
.39975 .37503 .40682 .38196 .41869 .37745 .41167 .36994 Mtetra
.664 .741 .907 r
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.631 .728 .918 r
.622 .29779 .6284 .30589 .64126 .30199 .63492 .29441 Mtetra
.393 .632 .95 r
.63492 .29441 .64126 .30199 .65442 .30356 .64811 .29602 Mtetra
.325 .596 .944 r
.64811 .29602 .65442 .30356 .66773 .30627 .66145 .29872 Mtetra
.347 .609 .947 r
.66145 .29872 .66773 .30627 .68116 .30884 .67491 .30108 Mtetra
.542 .705 .946 r
.67491 .30108 .68116 .30884 .69454 .30807 .68829 .29983 Mtetra
.772 .779 .858 r
.68829 .29983 .69454 .30807 .70755 .29961 .70132 .29067 Mtetra
.872 .781 .757 r
.70132 .29067 .70755 .29961 .72002 .28203 .71383 .27263 Mtetra
.789 .758 .825 r
.71383 .27263 .72002 .28203 .73284 .27026 .72676 .26185 Mtetra
.664 .741 .907 r
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.607 .716 .922 r
.76707 .24802 .77301 .25655 .78667 .25365 .78078 .24515 Mtetra
.669 .745 .907 r
.78078 .24515 .78667 .25365 .80026 .24897 .7944 .24031 Mtetra
.69 .751 .897 r
.7944 .24031 .80026 .24897 .81382 .24334 .80801 .23465 Mtetra
.678 .746 .902 r
.80801 .23465 .81382 .24334 .82748 .23815 .82172 .22945 Mtetra
.667 .742 .906 r
.82172 .22945 .82748 .23815 .84124 .23334 .83553 .2246 Mtetra
.661 .74 .908 r
.2201 .42605 .22766 .43311 .23878 .4294 .23125 .42228 Mtetra
.649 .736 .913 r
.23125 .42228 .23878 .4294 .24992 .42603 .24242 .41885 Mtetra
.632 .73 .919 r
.24242 .41885 .24992 .42603 .26107 .42311 .2536 .41586 Mtetra
.652 .735 .91 r
.2536 .41586 .26107 .42311 .27234 .4194 .26488 .41232 Mtetra
.716 .755 .883 r
.26488 .41232 .27234 .4194 .2838 .4138 .27638 .40658 Mtetra
.664 .741 .907 r
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.48 .674 .95 r
.31074 .39473 .31807 .40204 .32922 .40413 .32204 .39478 Mtetra
0 .148 .68 r
.32204 .39478 .32922 .40413 .34007 .41332 .33283 .40461 Mtetra
.401 .596 .924 r
.33283 .40461 .34007 .41332 .35151 .41388 .34422 .40642 Mtetra
.723 .755 .878 r
.34422 .40642 .35151 .41388 .36343 .40675 .35613 .40019 Mtetra
.804 .788 .838 r
.35613 .40019 .36343 .40675 .37554 .39606 .36827 .38986 Mtetra
.817 .798 .834 r
.36827 .38986 .37554 .39606 .38766 .38503 .38045 .3788 Mtetra
.806 .799 .846 r
.38045 .3788 .38766 .38503 .39975 .37503 .39259 .36862 Mtetra
.729 .789 .9 r
.39259 .36862 .39975 .37503 .41167 .36994 .40459 .36236 Mtetra
.664 .741 .907 r
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.589 .711 .928 r
.61554 .28961 .622 .29779 .63492 .29441 .62854 .28734 Mtetra
.363 .635 .958 r
.62854 .28734 .63492 .29441 .64811 .29602 .64176 .28907 Mtetra
.298 .602 .951 r
.64176 .28907 .64811 .29602 .66145 .29872 .65514 .29172 Mtetra
.348 .63 .958 r
.65514 .29172 .66145 .29872 .67491 .30108 .66861 .29366 Mtetra
.578 .734 .949 r
.66861 .29366 .67491 .30108 .68829 .29983 .68199 .2914 Mtetra
.794 .781 .841 r
.68199 .2914 .68829 .29983 .70132 .29067 .695 .28089 Mtetra
.869 .766 .747 r
.695 .28089 .70132 .29067 .71383 .27263 .70753 .26211 Mtetra
.746 .723 .83 r
.70753 .26211 .71383 .27263 .72676 .26185 .72064 .25336 Mtetra
.664 .741 .907 r
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.604 .715 .923 r
.76108 .23942 .76707 .24802 .78078 .24515 .77484 .23661 Mtetra
.674 .748 .906 r
.77484 .23661 .78078 .24515 .7944 .24031 .78849 .23153 Mtetra
.689 .749 .897 r
.78849 .23153 .7944 .24031 .80801 .23465 .80215 .22586 Mtetra
.676 .744 .902 r
.80215 .22586 .80801 .23465 .82172 .22945 .81591 .22065 Mtetra
.666 .741 .906 r
.81591 .22065 .82172 .22945 .83553 .2246 .82977 .21578 Mtetra
.661 .74 .908 r
.21248 .41891 .2201 .42605 .23125 .42228 .22366 .41511 Mtetra
.651 .737 .912 r
.22366 .41511 .23125 .42228 .24242 .41885 .23486 .41158 Mtetra
.634 .73 .917 r
.23486 .41158 .24242 .41885 .2536 .41586 .24607 .40852 Mtetra
.644 .732 .913 r
.24607 .40852 .2536 .41586 .26488 .41232 .25736 .40516 Mtetra
.718 .755 .882 r
.25736 .40516 .26488 .41232 .27638 .40658 .2689 .39931 Mtetra
.664 .741 .907 r
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.628 .73 .921 r
.30335 .38737 .31074 .39473 .32204 .39478 .31487 .38437 Mtetra
0 .134 .676 r
.31487 .38437 .32204 .39478 .33283 .40461 .3256 .39488 Mtetra
.307 .518 .897 r
.3256 .39488 .33283 .40461 .34422 .40642 .3369 .3985 Mtetra
.681 .735 .891 r
.3369 .3985 .34422 .40642 .35613 .40019 .34875 .39379 Mtetra
.796 .794 .85 r
.34875 .39379 .35613 .40019 .36827 .38986 .36091 .38415 Mtetra
.821 .812 .842 r
.36091 .38415 .36827 .38986 .38045 .3788 .37314 .37317 Mtetra
.814 .816 .852 r
.37314 .37317 .38045 .3788 .39259 .36862 .38534 .36279 Mtetra
.773 .812 .884 r
.38534 .36279 .39259 .36862 .40459 .36236 .39746 .35473 Mtetra
.664 .741 .907 r
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.514 .677 .939 r
.60903 .28137 .61554 .28961 .62854 .28734 .62212 .28085 Mtetra
.326 .637 .964 r
.62212 .28085 .62854 .28734 .64176 .28907 .63538 .28272 Mtetra
.275 .612 .956 r
.63538 .28272 .64176 .28907 .65514 .29172 .6488 .28522 Mtetra
.374 .665 .971 r
.6488 .28522 .65514 .29172 .66861 .29366 .66227 .28638 Mtetra
.638 .766 .94 r
.66227 .28638 .66861 .29366 .68199 .2914 .67562 .28249 Mtetra
.816 .776 .815 r
.67562 .28249 .68199 .2914 .695 .28089 .68858 .27006 Mtetra
.863 .749 .735 r
.68858 .27006 .695 .28089 .70753 .26211 .70112 .2505 Mtetra
.679 .677 .84 r
.70112 .2505 .70753 .26211 .72064 .25336 .71446 .2448 Mtetra
.664 .741 .907 r
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.601 .714 .923 r
.75503 .23073 .76108 .23942 .77484 .23661 .76884 .22797 Mtetra
.681 .75 .904 r
.76884 .22797 .77484 .23661 .78849 .23153 .78252 .22263 Mtetra
.688 .747 .896 r
.78252 .22263 .78849 .23153 .80215 .22586 .79623 .21696 Mtetra
.674 .743 .902 r
.79623 .21696 .80215 .22586 .81591 .22065 .81005 .21178 Mtetra
.666 .741 .906 r
.81005 .21178 .81591 .22065 .82977 .21578 .82396 .20687 Mtetra
.662 .74 .908 r
.20479 .41173 .21248 .41891 .22366 .41511 .216 .40787 Mtetra
.654 .737 .911 r
.216 .40787 .22366 .41511 .23486 .41158 .22724 .40425 Mtetra
.637 .731 .916 r
.22724 .40425 .23486 .41158 .24607 .40852 .23849 .40107 Mtetra
.637 .728 .914 r
.23849 .40107 .24607 .40852 .25736 .40516 .24979 .39788 Mtetra
.708 .751 .886 r
.24979 .39788 .25736 .40516 .2689 .39931 .26133 .39239 Mtetra
.678 .756 .91 r
.26133 .39239 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.664 .741 .907 r
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31487 .38437 .30751 .37589 Mtetra
0 .247 .75 r
.30751 .37589 .31487 .38437 .3256 .39488 .3184 .38385 Mtetra
.192 .417 .851 r
.3184 .38385 .3256 .39488 .3369 .3985 .32956 .3897 Mtetra
.609 .69 .901 r
.32956 .3897 .3369 .3985 .34875 .39379 .34132 .38721 Mtetra
.773 .79 .866 r
.34132 .38721 .34875 .39379 .36091 .38415 .35345 .3788 Mtetra
.82 .824 .852 r
.35345 .3788 .36091 .38415 .37314 .37317 .36572 .36813 Mtetra
.822 .834 .858 r
.36572 .36813 .37314 .37317 .38534 .36279 .37799 .35758 Mtetra
.804 .832 .872 r
.37799 .35758 .38534 .36279 .39746 .35473 .39022 .34806 Mtetra
.697 .779 .915 r
.39022 .34806 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.664 .741 .907 r
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.63 .728 .918 r
.58951 .27756 .59612 .28584 .60903 .28137 .60248 .2741 Mtetra
.414 .66 .961 r
.60248 .2741 .60903 .28137 .62212 .28085 .61565 .275 Mtetra
.282 .636 .965 r
.61565 .275 .62212 .28085 .63538 .28272 .62897 .27697 Mtetra
.267 .631 .962 r
.62897 .27697 .63538 .28272 .6488 .28522 .6424 .27908 Mtetra
.441 .716 .982 r
.6424 .27908 .6488 .28522 .66227 .28638 .65586 .27891 Mtetra
.711 .787 .911 r
.65586 .27891 .66227 .28638 .67562 .28249 .66915 .27268 Mtetra
.834 .762 .783 r
.66915 .27268 .67562 .28249 .68858 .27006 .68204 .25787 Mtetra
.831 .724 .747 r
.68204 .25787 .68858 .27006 .70112 .2505 .69479 .24086 Mtetra
.662 .713 .886 r
.69479 .24086 .70112 .2505 .71446 .2448 .70823 .23617 Mtetra
.664 .741 .907 r
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.651 .736 .911 r
.7353 .22673 .74144 .23545 .75503 .23073 .74897 .22241 Mtetra
.613 .731 .93 r
.74897 .22241 .75503 .23073 .76884 .22797 .76279 .2192 Mtetra
.686 .75 .9 r
.76279 .2192 .76884 .22797 .78252 .22263 .7765 .21359 Mtetra
.685 .745 .896 r
.7765 .21359 .78252 .22263 .79623 .21696 .79026 .20798 Mtetra
.673 .742 .903 r
.79026 .20798 .79623 .21696 .81005 .21178 .80413 .20282 Mtetra
.665 .741 .906 r
.80413 .20282 .81005 .21178 .82396 .20687 .81809 .1979 Mtetra
.662 .74 .908 r
.19705 .40449 .20479 .41173 .216 .40787 .20829 .40059 Mtetra
.656 .738 .91 r
.20829 .40059 .216 .40787 .22724 .40425 .21956 .39685 Mtetra
.641 .732 .914 r
.21956 .39685 .22724 .40425 .23849 .40107 .23085 .39352 Mtetra
.632 .726 .915 r
.23085 .39352 .23849 .40107 .24979 .39788 .24216 .39043 Mtetra
.684 .743 .896 r
.24216 .39043 .24979 .39788 .26133 .39239 .25366 .38577 Mtetra
.702 .771 .906 r
.25366 .38577 .26133 .39239 .27283 .38798 .26526 .38056 Mtetra
.664 .741 .907 r
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.247 .555 .932 r
.30004 .36836 .30751 .37589 .3184 .38385 .31125 .3714 Mtetra
.086 .318 .796 r
.31125 .3714 .3184 .38385 .32956 .3897 .32226 .37947 Mtetra
.495 .607 .893 r
.32226 .37947 .32956 .3897 .34132 .38721 .33385 .37992 Mtetra
.727 .766 .884 r
.33385 .37992 .34132 .38721 .35345 .3788 .34592 .37349 Mtetra
.809 .828 .865 r
.34592 .37349 .35345 .3788 .36572 .36813 .35821 .3636 Mtetra
.825 .85 .866 r
.35821 .3636 .36572 .36813 .37799 .35758 .37053 .35305 Mtetra
.815 .853 .877 r
.37053 .35305 .37799 .35758 .39022 .34806 .38284 .3432 Mtetra
.78 .846 .902 r
.38284 .3432 .39022 .34806 .4023 .34284 .39508 .33504 Mtetra
.664 .741 .907 r
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.513 .677 .939 r
.58284 .26921 .58951 .27756 .60248 .2741 .59592 .26865 Mtetra
.317 .673 .976 r
.59592 .26865 .60248 .2741 .61565 .275 .60914 .26982 Mtetra
.245 .639 .961 r
.60914 .26982 .61565 .275 .62897 .27697 .6225 .27171 Mtetra
.3 .671 .974 r
.6225 .27171 .62897 .27697 .6424 .27908 .63595 .27296 Mtetra
.554 .772 .98 r
.63595 .27296 .6424 .27908 .65586 .27891 .64937 .2707 Mtetra
.775 .786 .862 r
.64937 .2707 .65586 .27891 .66915 .27268 .66256 .26137 Mtetra
.84 .74 .753 r
.66256 .26137 .66915 .27268 .68204 .25787 .6754 .24422 Mtetra
.766 .683 .771 r
.6754 .24422 .68204 .25787 .69479 .24086 .68846 .23219 Mtetra
.664 .741 .907 r
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.626 .725 .918 r
.7291 .21794 .7353 .22673 .74897 .22241 .74287 .21437 Mtetra
.642 .754 .93 r
.74287 .21437 .74897 .22241 .76279 .2192 .75667 .21022 Mtetra
.689 .749 .897 r
.75667 .21022 .76279 .2192 .7765 .21359 .77042 .20445 Mtetra
.682 .742 .897 r
.77042 .20445 .7765 .21359 .79026 .20798 .78424 .19891 Mtetra
.67 .741 .903 r
.78424 .19891 .79026 .20798 .80413 .20282 .79817 .19379 Mtetra
.665 .741 .906 r
.79817 .19379 .80413 .20282 .81809 .1979 .81217 .18883 Mtetra
.663 .74 .908 r
.18925 .39719 .19705 .40449 .20829 .40059 .20051 .39324 Mtetra
.659 .739 .909 r
.20051 .39324 .20829 .40059 .21956 .39685 .21182 .38941 Mtetra
.647 .734 .913 r
.21182 .38941 .21956 .39685 .23085 .39352 .22314 .38591 Mtetra
.632 .726 .915 r
.22314 .38591 .23085 .39352 .24216 .39043 .23448 .38279 Mtetra
.66 .734 .904 r
.23448 .38279 .24216 .39043 .25366 .38577 .24595 .37885 Mtetra
.715 .767 .893 r
.24595 .37885 .25366 .38577 .26526 .38056 .25762 .37307 Mtetra
.664 .741 .907 r
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.627 .73 .921 r
.2925 .36078 .30004 .36836 .31125 .3714 .30415 .35769 Mtetra
.031 .255 .755 r
.30415 .35769 .31125 .3714 .32226 .37947 .31503 .36728 Mtetra
.351 .488 .857 r
.31503 .36728 .32226 .37947 .33385 .37992 .32642 .37114 Mtetra
.64 .706 .894 r
.32642 .37114 .33385 .37992 .34592 .37349 .33835 .36765 Mtetra
.777 .815 .883 r
.33835 .36765 .34592 .37349 .35821 .3636 .3506 .35929 Mtetra
.82 .859 .876 r
.3506 .35929 .35821 .3636 .37053 .35305 .36297 .34915 Mtetra
.821 .872 .883 r
.36297 .34915 .37053 .35305 .38284 .3432 .37534 .33912 Mtetra
.804 .871 .896 r
.37534 .33912 .38284 .3432 .39508 .33504 .38768 .32993 Mtetra
.75 .84 .919 r
.38768 .32993 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.664 .741 .907 r
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.565 .701 .933 r
.56316 .26536 .56992 .27374 .58284 .26921 .57617 .26358 Mtetra
.379 .702 .984 r
.57617 .26358 .58284 .26921 .59592 .26865 .58931 .26399 Mtetra
.258 .667 .966 r
.58931 .26399 .59592 .26865 .60914 .26982 .60258 .26527 Mtetra
.24 .66 .961 r
.60258 .26527 .60914 .26982 .6225 .27171 .61597 .26668 Mtetra
.406 .74 .993 r
.61597 .26668 .6225 .27171 .63595 .27296 .62941 .2663 Mtetra
.683 .805 .94 r
.62941 .2663 .63595 .27296 .64937 .2707 .64276 .26095 Mtetra
.813 .761 .804 r
.64276 .26095 .64937 .2707 .66256 .26137 .65585 .24806 Mtetra
.834 .712 .729 r
.65585 .24806 .66256 .26137 .6754 .24422 .66866 .22926 Mtetra
.664 .62 .796 r
.66866 .22926 .6754 .24422 .68846 .23219 .68207 .22344 Mtetra
.664 .741 .907 r
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.608 .717 .922 r
.72285 .20907 .7291 .21794 .74287 .21437 .7367 .20601 Mtetra
.667 .758 .918 r
.7367 .20601 .74287 .21437 .75667 .21022 .75049 .20104 Mtetra
.689 .745 .894 r
.75049 .20104 .75667 .21022 .77042 .20445 .76428 .19521 Mtetra
.678 .74 .898 r
.76428 .19521 .77042 .20445 .78424 .19891 .77817 .18977 Mtetra
.668 .74 .904 r
.77817 .18977 .78424 .19891 .79817 .19379 .79214 .18468 Mtetra
.665 .741 .907 r
.79214 .18468 .79817 .19379 .81217 .18883 .8062 .17969 Mtetra
.664 .741 .907 r
.18138 .38984 .18925 .39719 .20051 .39324 .19268 .38584 Mtetra
.66 .739 .908 r
.19268 .38584 .20051 .39324 .21182 .38941 .20401 .38192 Mtetra
.652 .736 .911 r
.20401 .38192 .21182 .38941 .22314 .38591 .21538 .37824 Mtetra
.636 .727 .914 r
.21538 .37824 .22314 .38591 .23448 .38279 .22676 .375 Mtetra
.642 .726 .909 r
.22676 .375 .23448 .38279 .24595 .37885 .2382 .37155 Mtetra
.713 .758 .887 r
.2382 .37155 .24595 .37885 .25762 .37307 .24991 .36576 Mtetra
.672 .749 .909 r
.24991 .36576 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.664 .741 .907 r
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30415 .35769 .29665 .34896 Mtetra
.216 .503 .906 r
.29665 .34896 .30415 .35769 .31503 .36728 .30791 .35294 Mtetra
.222 .369 .8 r
.30791 .35294 .31503 .36728 .32642 .37114 .31907 .35997 Mtetra
.505 .594 .877 r
.31907 .35997 .32642 .37114 .33835 .36765 .33079 .36031 Mtetra
.707 .766 .898 r
.33079 .36031 .33835 .36765 .3506 .35929 .34293 .35458 Mtetra
.796 .851 .892 r
.34293 .35458 .3506 .35929 .36297 .34915 .35529 .3456 Mtetra
.819 .885 .892 r
.35529 .3456 .36297 .34915 .37534 .33912 .36772 .33576 Mtetra
.812 .893 .901 r
.36772 .33576 .37534 .33912 .38768 .32993 .38014 .3263 Mtetra
.792 .888 .914 r
.38014 .3263 .38768 .32993 .39996 .3229 .39253 .31769 Mtetra
.75 .84 .919 r
.39253 .31769 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.664 .741 .907 r
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.564 .701 .933 r
.54339 .2615 .55025 .26991 .56316 .26536 .55636 .2597 Mtetra
.424 .726 .988 r
.55636 .2597 .56316 .26536 .57617 .26358 .56944 .25944 Mtetra
.278 .698 .969 r
.56944 .25944 .57617 .26358 .58931 .26399 .58264 .26005 Mtetra
.228 .674 .953 r
.58264 .26005 .58931 .26399 .60258 .26527 .59595 .26107 Mtetra
.318 .721 .979 r
.59595 .26107 .60258 .26527 .61597 .26668 .60935 .26124 Mtetra
.581 .81 .986 r
.60935 .26124 .61597 .26668 .62941 .2663 .62275 .25809 Mtetra
.775 .788 .864 r
.62275 .25809 .62941 .2663 .64276 .26095 .63601 .24876 Mtetra
.823 .724 .755 r
.63601 .24876 .64276 .26095 .65585 .24806 .64901 .23254 Mtetra
.763 .661 .749 r
.64901 .23254 .65585 .24806 .66866 .22926 .66212 .21941 Mtetra
.662 .713 .886 r
.66212 .21941 .66866 .22926 .68207 .22344 .67563 .21462 Mtetra
.664 .741 .907 r
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.657 .738 .91 r
.70284 .20497 .70919 .21388 .72285 .20907 .71656 .20035 Mtetra
.608 .723 .927 r
.71656 .20035 .72285 .20907 .7367 .20601 .73045 .19723 Mtetra
.683 .754 .906 r
.73045 .19723 .7367 .20601 .75049 .20104 .74425 .19167 Mtetra
.686 .741 .893 r
.74425 .19167 .75049 .20104 .76428 .19521 .75809 .1859 Mtetra
.674 .739 .899 r
.75809 .1859 .76428 .19521 .77817 .18977 .77204 .18057 Mtetra
.667 .74 .905 r
.77204 .18057 .77817 .18977 .79214 .18468 .78607 .17549 Mtetra
.664 .74 .907 r
.78607 .17549 .79214 .18468 .8062 .17969 .80018 .17047 Mtetra
.664 .741 .907 r
.17344 .38242 .18138 .38984 .19268 .38584 .18477 .37839 Mtetra
.662 .74 .908 r
.18477 .37839 .19268 .38584 .20401 .38192 .19614 .37439 Mtetra
.656 .737 .91 r
.19614 .37439 .20401 .38192 .21538 .37824 .20755 .37055 Mtetra
.642 .73 .912 r
.20755 .37055 .21538 .37824 .22676 .375 .21897 .3671 Mtetra
.634 .723 .912 r
.21897 .3671 .22676 .375 .2382 .37155 .23042 .36385 Mtetra
.676 .741 .899 r
.23042 .36385 .2382 .37155 .24991 .36576 .24205 .35932 Mtetra
.709 .784 .91 r
.24205 .35932 .24991 .36576 .26153 .36141 .25381 .35377 Mtetra
.664 .741 .907 r
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.662 .74 .908 r
.28902 .34122 .29665 .34896 .30791 .35294 .30086 .33705 Mtetra
.166 .307 .763 r
.30086 .33705 .30791 .35294 .31907 .35997 .31188 .34579 Mtetra
.356 .455 .824 r
.31188 .34579 .31907 .35997 .33079 .36031 .32333 .35022 Mtetra
.583 .657 .888 r
.32333 .35022 .33079 .36031 .34293 .35458 .33527 .34833 Mtetra
.734 .804 .907 r
.33527 .34833 .34293 .35458 .35529 .3456 .34755 .3417 Mtetra
.797 .878 .906 r
.34755 .3417 .35529 .3456 .36772 .33576 .35999 .33282 Mtetra
.809 .908 .909 r
.35999 .33282 .36772 .33576 .38014 .3263 .37247 .32349 Mtetra
.797 .914 .919 r
.37247 .32349 .38014 .3263 .39253 .31769 .38494 .31461 Mtetra
.777 .908 .931 r
.38494 .31461 .39253 .31769 .4049 .31059 .3974 .30648 Mtetra
.755 .878 .935 r
.3974 .30648 .4049 .31059 .4172 .30623 .40986 .29917 Mtetra
.697 .779 .915 r
.40986 .29917 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.664 .741 .907 r
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.63 .729 .918 r
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25867 Mtetra
.545 .725 .957 r
.52354 .25867 .5305 .26606 .54339 .2615 .53648 .25701 Mtetra
.413 .763 .995 r
.53648 .25701 .54339 .2615 .55636 .2597 .54951 .25618 Mtetra
.292 .728 .967 r
.54951 .25618 .55636 .2597 .56944 .25944 .56265 .25612 Mtetra
.235 .698 .947 r
.56265 .25612 .56944 .25944 .58264 .26005 .57589 .25654 Mtetra
.287 .726 .965 r
.57589 .25654 .58264 .26005 .59595 .26107 .58924 .25651 Mtetra
.51 .811 .999 r
.58924 .25651 .59595 .26107 .60935 .26124 .60263 .25421 Mtetra
.734 .811 .912 r
.60263 .25421 .60935 .26124 .62275 .25809 .61596 .24707 Mtetra
.809 .739 .787 r
.61596 .24707 .62275 .25809 .63601 .24876 .62912 .23347 Mtetra
.811 .683 .723 r
.62912 .23347 .63601 .24876 .64901 .23254 .64209 .21541 Mtetra
.637 .582 .776 r
.64209 .21541 .64901 .23254 .66212 .21941 .65557 .21055 Mtetra
.664 .741 .907 r
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.619 .722 .92 r
.69643 .19599 .70284 .20497 .71656 .20035 .71027 .19254 Mtetra
.65 .77 .936 r
.71027 .19254 .71656 .20035 .73045 .19723 .72412 .18802 Mtetra
.688 .747 .896 r
.72412 .18802 .73045 .19723 .74425 .19167 .73795 .18218 Mtetra
.681 .738 .894 r
.73795 .18218 .74425 .19167 .75809 .1859 .75185 .17655 Mtetra
.67 .739 .901 r
.75185 .17655 .75809 .1859 .77204 .18057 .76586 .17131 Mtetra
.666 .74 .906 r
.76586 .17131 .77204 .18057 .78607 .17549 .77994 .16623 Mtetra
.664 .741 .907 r
.77994 .16623 .78607 .17549 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37839 .1768 .37088 Mtetra
.663 .74 .908 r
.1768 .37088 .18477 .37839 .19614 .37439 .18821 .36682 Mtetra
.659 .739 .909 r
.18821 .36682 .19614 .37439 .20755 .37055 .19965 .36285 Mtetra
.649 .733 .911 r
.19965 .36285 .20755 .37055 .21897 .3671 .21112 .35916 Mtetra
.635 .724 .912 r
.21112 .35916 .21897 .3671 .23042 .36385 .2226 .35585 Mtetra
.648 .727 .906 r
.2226 .35585 .23042 .36385 .24205 .35932 .23418 .35215 Mtetra
.718 .766 .89 r
.23418 .35215 .24205 .35932 .25381 .35377 .24601 .34611 Mtetra
.665 .742 .908 r
.24601 .34611 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.664 .741 .907 r
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .33705 .2932 .32915 Mtetra
.485 .673 .948 r
.2932 .32915 .30086 .33705 .31188 .34579 .30484 .32896 Mtetra
.263 .356 .771 r
.30484 .32896 .31188 .34579 .32333 .35022 .31607 .33631 Mtetra
.432 .505 .834 r
.31607 .33631 .32333 .35022 .33527 .34833 .32774 .33891 Mtetra
.614 .688 .895 r
.32774 .33891 .33527 .34833 .34755 .3417 .33983 .33605 Mtetra
.735 .824 .92 r
.33983 .33605 .34755 .3417 .35999 .33282 .35219 .32942 Mtetra
.784 .897 .923 r
.35219 .32942 .35999 .33282 .37247 .32349 .36468 .32105 Mtetra
.79 .926 .926 r
.36468 .32105 .37247 .32349 .38494 .31461 .37721 .31236 Mtetra
.776 .933 .934 r
.37721 .31236 .38494 .31461 .3974 .30648 .38975 .30406 Mtetra
.755 .929 .945 r
.38975 .30406 .3974 .30648 .40986 .29917 .40229 .29641 Mtetra
.732 .919 .956 r
.40229 .29641 .40986 .29917 .4223 .29371 .41483 .28947 Mtetra
.718 .874 .954 r
.41483 .28947 .4223 .29371 .43475 .28927 .42739 .28321 Mtetra
.701 .815 .935 r
.42739 .28321 .43475 .28927 .44726 .28481 .43998 .27756 Mtetra
.682 .775 .921 r
.43998 .27756 .44726 .28481 .45982 .28033 .4526 .27249 Mtetra
.664 .754 .917 r
.4526 .27249 .45982 .28033 .47245 .27583 .46526 .26795 Mtetra
.646 .748 .924 r
.46526 .26795 .47245 .27583 .48513 .27131 .47798 .26395 Mtetra
.622 .756 .942 r
.47798 .26395 .48513 .27131 .49788 .26676 .49075 .26052 Mtetra
.584 .779 .972 r
.49075 .26052 .49788 .26676 .51068 .2622 .50359 .25772 Mtetra
.503 .806 .999 r
.50359 .25772 .51068 .2622 .52354 .25867 .5165 .2556 Mtetra
.38 .791 .98 r
.5165 .2556 .52354 .25867 .53648 .25701 .5295 .25421 Mtetra
.3 .753 .956 r
.5295 .25421 .53648 .25701 .54951 .25618 .54259 .25349 Mtetra
.254 .728 .939 r
.54259 .25349 .54951 .25618 .56265 .25612 .55578 .25317 Mtetra
.3 .75 .959 r
.55578 .25317 .56265 .25612 .57589 .25654 .56906 .25254 Mtetra
.493 .822 1 r
.56906 .25254 .57589 .25654 .58924 .25651 .58242 .25016 Mtetra
.708 .825 .937 r
.58242 .25016 .58924 .25651 .60263 .25421 .59576 .24394 Mtetra
.794 .749 .812 r
.59576 .24394 .60263 .25421 .61596 .24707 .60901 .23214 Mtetra
.802 .684 .734 r
.60901 .23214 .61596 .24707 .62912 .23347 .6221 .21546 Mtetra
.696 .605 .751 r
.6221 .21546 .62912 .23347 .64209 .21541 .63544 .20646 Mtetra
.664 .739 .906 r
.63544 .20646 .64209 .21541 .65557 .21055 .64897 .20161 Mtetra
.664 .741 .907 r
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.663 .74 .908 r
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18696 Mtetra
.603 .716 .924 r
.68996 .18696 .69643 .19599 .71027 .19254 .70387 .18393 Mtetra
.678 .76 .913 r
.70387 .18393 .71027 .19254 .72412 .18802 .71771 .17849 Mtetra
.686 .74 .892 r
.71771 .17849 .72412 .18802 .73795 .18218 .73159 .17264 Mtetra
.676 .737 .896 r
.73159 .17264 .73795 .18218 .75185 .17655 .74556 .16716 Mtetra
.668 .739 .903 r
.74556 .16716 .75185 .17655 .76586 .17131 .75962 .16198 Mtetra
.665 .74 .906 r
.75962 .16198 .76586 .17131 .77994 .16623 .77376 .15688 Mtetra
.664 .741 .907 r
.77376 .15688 .77994 .16623 .7941 .16117 .78796 .15179 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36332 Mtetra
.663 .741 .907 r
.16877 .36332 .1768 .37088 .18821 .36682 .1802 .35921 Mtetra
.662 .74 .908 r
.1802 .35921 .18821 .36682 .19965 .36285 .19168 .35513 Mtetra
.655 .736 .909 r
.19168 .35513 .19965 .36285 .21112 .35916 .2032 .35124 Mtetra
.642 .728 .911 r
.2032 .35124 .21112 .35916 .2226 .35585 .21473 .3477 Mtetra
.636 .721 .909 r
.21473 .3477 .2226 .35585 .23418 .35215 .22629 .34431 Mtetra
.673 .741 .901 r
.22629 .34431 .23418 .35215 .24601 .34611 .23802 .3398 Mtetra
.713 .792 .914 r
.23802 .3398 .24601 .34611 .25773 .34187 .24991 .33406 Mtetra
.664 .741 .907 r
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30484 .32896 .29743 .31693 Mtetra
.44 .547 .868 r
.29743 .31693 .30484 .32896 .31607 .33631 .30902 .31874 Mtetra
.331 .391 .773 r
.30902 .31874 .31607 .33631 .32774 .33891 .32044 .32484 Mtetra
.466 .523 .833 r
.32044 .32484 .32774 .33891 .33983 .33605 .33226 .32658 Mtetra
.612 .689 .897 r
.33226 .32658 .33983 .33605 .35219 .32942 .34444 .32372 Mtetra
.715 .823 .932 r
.34444 .32372 .35219 .32942 .36468 .32105 .35685 .31772 Mtetra
.757 .902 .941 r
.35685 .31772 .36468 .32105 .37721 .31236 .36939 .3102 Mtetra
.76 .936 .942 r
.36939 .3102 .37721 .31236 .38975 .30406 .38197 .30231 Mtetra
.743 .947 .947 r
.38197 .30231 .38975 .30406 .40229 .29641 .39458 .29467 Mtetra
.719 .946 .955 r
.39458 .29467 .40229 .29641 .41483 .28947 .40719 .28757 Mtetra
.692 .938 .964 r
.40719 .28757 .41483 .28947 .42739 .28321 .41982 .28111 Mtetra
.662 .928 .972 r
.41982 .28111 .42739 .28321 .43998 .27756 .43248 .27529 Mtetra
.63 .916 .98 r
.43248 .27529 .43998 .27756 .4526 .27249 .44517 .2701 Mtetra
.594 .903 .985 r
.44517 .2701 .4526 .27249 .46526 .26795 .45789 .26552 Mtetra
.552 .887 .986 r
.45789 .26552 .46526 .26795 .47798 .26395 .47067 .26157 Mtetra
.501 .868 .984 r
.47067 .26157 .47798 .26395 .49075 .26052 .4835 .25825 Mtetra
.441 .843 .975 r
.4835 .25825 .49075 .26052 .50359 .25772 .4964 .25558 Mtetra
.374 .811 .958 r
.4964 .25558 .50359 .25772 .5165 .2556 .50937 .25356 Mtetra
.315 .78 .94 r
.50937 .25356 .5165 .2556 .5295 .25421 .52243 .25209 Mtetra
.293 .765 .936 r
.52243 .25209 .5295 .25421 .54259 .25349 .53558 .25089 Mtetra
.358 .793 .965 r
.53558 .25089 .54259 .25349 .55578 .25317 .54881 .24932 Mtetra
.534 .845 .999 r
.54881 .24932 .55578 .25317 .56906 .25254 .56212 .24621 Mtetra
.71 .827 .937 r
.56212 .24621 .56906 .25254 .58242 .25016 .57546 .23991 Mtetra
.783 .747 .82 r
.57546 .23991 .58242 .25016 .59576 .24394 .58875 .22893 Mtetra
.791 .679 .741 r
.58875 .22893 .59576 .24394 .60901 .23214 .60193 .21347 Mtetra
.718 .611 .736 r
.60193 .21347 .60901 .23214 .6221 .21546 .61522 .20236 Mtetra
.651 .647 .833 r
.61522 .20236 .6221 .21546 .63544 .20646 .62873 .19749 Mtetra
.664 .741 .907 r
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.615 .721 .921 r
.66966 .18273 .67623 .19184 .68996 .18696 .68351 .17932 Mtetra
.653 .779 .941 r
.68351 .17932 .68996 .18696 .70387 .18393 .69738 .17463 Mtetra
.687 .747 .897 r
.69738 .17463 .70387 .18393 .71771 .17849 .71125 .16878 Mtetra
.681 .736 .892 r
.71125 .16878 .71771 .17849 .73159 .17264 .72519 .16308 Mtetra
.671 .737 .9 r
.72519 .16308 .73159 .17264 .74556 .16716 .73922 .15775 Mtetra
.666 .739 .905 r
.73922 .15775 .74556 .16716 .75962 .16198 .75333 .15259 Mtetra
.664 .74 .907 r
.75333 .15259 .75962 .16198 .77376 .15688 .76752 .14746 Mtetra
.664 .741 .907 r
.76752 .14746 .77376 .15688 .78796 .15179 .78177 .14232 Mtetra
.14925 .35983 .15738 .36742 .16877 .36332 .16067 .35569 Mtetra
.16067 .35569 .16877 .36332 .1802 .35921 .17213 .35154 Mtetra
.663 .74 .908 r
.17213 .35154 .1802 .35921 .19168 .35513 .18365 .34739 Mtetra
.659 .738 .908 r
.18365 .34739 .19168 .35513 .2032 .35124 .1952 .34333 Mtetra
.65 .732 .909 r
.1952 .34333 .2032 .35124 .21473 .3477 .20678 .33953 Mtetra
.638 .723 .909 r
.20678 .33953 .21473 .3477 .22629 .34431 .21838 .33606 Mtetra
.644 .723 .906 r
.21838 .33606 .22629 .34431 .23802 .3398 .23006 .33239 Mtetra
.699 .761 .9 r
.23006 .33239 .23802 .3398 .24991 .33406 .24195 .32698 Mtetra
.69 .769 .912 r
.24195 .32698 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.664 .741 .907 r
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30902 .31874 .30172 .30455 Mtetra
.463 .519 .831 r
.30172 .30455 .30902 .31874 .32044 .32484 .31341 .30632 Mtetra
.375 .408 .767 r
.31341 .30632 .32044 .32484 .33226 .32658 .32497 .31156 Mtetra
.473 .514 .819 r
.32497 .31156 .33226 .32658 .34444 .32372 .33689 .31321 Mtetra
.587 .656 .885 r
.33689 .31321 .34444 .32372 .35685 .31772 .34911 .31108 Mtetra
.676 .79 .935 r
.34911 .31108 .35685 .31772 .36939 .3102 .36156 .30622 Mtetra
.719 .881 .956 r
.36156 .30622 .36939 .3102 .38197 .30231 .37413 .29988 Mtetra
.72 .928 .96 r
.37413 .29988 .38197 .30231 .39458 .29467 .38676 .29304 Mtetra
.7 .945 .959 r
.38676 .29304 .39458 .29467 .40719 .28757 .39943 .28626 Mtetra
.667 .946 .959 r
.39943 .28626 .40719 .28757 .41982 .28111 .41213 .27989 Mtetra
.63 .939 .96 r
.41213 .27989 .41982 .28111 .43248 .27529 .42485 .27405 Mtetra
.589 .926 .961 r
.42485 .27405 .43248 .27529 .44517 .2701 .43761 .26882 Mtetra
.544 .909 .96 r
.43761 .26882 .44517 .2701 .45789 .26552 .4504 .26422 Mtetra
.494 .887 .956 r
.4504 .26422 .45789 .26552 .47067 .26157 .46324 .26023 Mtetra
.442 .862 .948 r
.46324 .26023 .47067 .26157 .4835 .25825 .47614 .25686 Mtetra
.395 .837 .939 r
.47614 .25686 .4835 .25825 .4964 .25558 .48911 .25404 Mtetra
.366 .819 .937 r
.48911 .25404 .4964 .25558 .50937 .25356 .50215 .25162 Mtetra
.383 .821 .953 r
.50215 .25162 .50937 .25356 .52243 .25209 .51527 .24928 Mtetra
.472 .847 .987 r
.51527 .24928 .52243 .25209 .53558 .25089 .52847 .24644 Mtetra
.618 .859 .988 r
.52847 .24644 .53558 .25089 .54881 .24932 .54175 .2421 Mtetra
.731 .806 .911 r
.54175 .2421 .54881 .24932 .56212 .24621 .55506 .23499 Mtetra
.773 .726 .809 r
.55506 .23499 .56212 .24621 .57546 .23991 .56837 .22402 Mtetra
.776 .664 .74 r
.56837 .22402 .57546 .23991 .58875 .22893 .58161 .20938 Mtetra
.713 .601 .73 r
.58161 .20938 .58875 .22893 .60193 .21347 .59492 .19824 Mtetra
.643 .611 .803 r
.59492 .19824 .60193 .21347 .61522 .20236 .60841 .19335 Mtetra
.664 .741 .907 r
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.639 .731 .915 r
.64927 .17853 .65595 .18768 .66966 .18273 .66306 .17436 Mtetra
.626 .748 .934 r
.66306 .17436 .66966 .18273 .68351 .17932 .67695 .17052 Mtetra
.681 .759 .91 r
.67695 .17052 .68351 .17932 .69738 .17463 .69081 .16489 Mtetra
.684 .737 .891 r
.69081 .16489 .69738 .17463 .71125 .16878 .70473 .15904 Mtetra
.675 .735 .895 r
.70473 .15904 .71125 .16878 .72519 .16308 .71873 .15353 Mtetra
.668 .738 .903 r
.71873 .15353 .72519 .16308 .73922 .15775 .73282 .14828 Mtetra
.665 .74 .906 r
.73282 .14828 .73922 .15775 .75333 .15259 .74698 .14311 Mtetra
.664 .741 .907 r
.74698 .14311 .75333 .15259 .76752 .14746 .76122 .13795 Mtetra
.76122 .13795 .76752 .14746 .78177 .14232 .77553 .13276 Mtetra
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.1525 .348 .16067 .35569 .17213 .35154 .164 .34381 Mtetra
.164 .34381 .17213 .35154 .18365 .34739 .17554 .33961 Mtetra
.662 .74 .908 r
.17554 .33961 .18365 .34739 .1952 .34333 .18713 .33544 Mtetra
.657 .736 .908 r
.18713 .33544 .1952 .34333 .20678 .33953 .19876 .33141 Mtetra
.646 .728 .909 r
.19876 .33141 .20678 .33953 .21838 .33606 .21041 .32768 Mtetra
.637 .719 .907 r
.21041 .32768 .21838 .33606 .23006 .33239 .2221 .32418 Mtetra
.656 .73 .904 r
.2221 .32418 .23006 .33239 .24195 .32698 .23389 .32011 Mtetra
.719 .782 .902 r
.23389 .32011 .24195 .32698 .25385 .3219 .24592 .314 Mtetra
.666 .743 .908 r
.24592 .314 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.664 .741 .907 r
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31341 .30632 .30606 .292 Mtetra
.535 .558 .825 r
.30606 .292 .31341 .30632 .32497 .31156 .31798 .29167 Mtetra
.409 .414 .754 r
.31798 .29167 .32497 .31156 .33689 .31321 .32968 .29626 Mtetra
.472 .487 .793 r
.32968 .29626 .33689 .31321 .34911 .31108 .34166 .29826 Mtetra
.551 .595 .851 r
.34166 .29826 .34911 .31108 .36156 .30622 .35391 .29727 Mtetra
.624 .712 .909 r
.35391 .29727 .36156 .30622 .37413 .29988 .36636 .29392 Mtetra
.67 .813 .952 r
.36636 .29392 .37413 .29988 .38676 .29304 .37895 .28909 Mtetra
.681 .88 .972 r
.37895 .28909 .38676 .29304 .39943 .28626 .39163 .28358 Mtetra
.665 .914 .977 r
.39163 .28358 .39943 .28626 .41213 .27989 .40436 .27791 Mtetra
.633 .924 .975 r
.40436 .27791 .41213 .27989 .42485 .27405 .41714 .27245 Mtetra
.593 .921 .97 r
.41714 .27245 .42485 .27405 .43761 .26882 .42995 .26735 Mtetra
.553 .909 .966 r
.42995 .26735 .43761 .26882 .4504 .26422 .44282 .26271 Mtetra
.518 .894 .964 r
.44282 .26271 .4504 .26422 .46324 .26023 .45573 .25852 Mtetra
.497 .882 .967 r
.45573 .25852 .46324 .26023 .47614 .25686 .4687 .25471 Mtetra
.502 .876 .977 r
.4687 .25471 .47614 .25686 .48911 .25404 .48174 .2511 Mtetra
.545 .875 .992 r
.48174 .2511 .48911 .25404 .50215 .25162 .49485 .24734 Mtetra
.622 .864 .988 r
.49485 .24734 .50215 .25162 .51527 .24928 .50803 .24289 Mtetra
.699 .821 .94 r
.50803 .24289 .51527 .24928 .52847 .24644 .52129 .23695 Mtetra
.745 .752 .858 r
.52129 .23695 .52847 .24644 .54175 .2421 .53459 .2286 Mtetra
.759 .686 .781 r
.53459 .2286 .54175 .2421 .55506 .23499 .5479 .21722 Mtetra
.756 .637 .73 r
.5479 .21722 .55506 .23499 .56837 .22402 .56119 .20317 Mtetra
.681 .574 .729 r
.56119 .20317 .56837 .22402 .58161 .20938 .57454 .1941 Mtetra
.642 .611 .803 r
.57454 .1941 .58161 .20938 .59492 .19824 .58801 .18919 Mtetra
.664 .741 .907 r
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.662 .74 .908 r
.6288 .17432 .63558 .1835 .64927 .17853 .64254 .16938 Mtetra
.605 .718 .925 r
.64254 .16938 .64927 .17853 .66306 .17436 .65642 .16618 Mtetra
.672 .774 .926 r
.65642 .16618 .66306 .17436 .67695 .17052 .67028 .16088 Mtetra
.685 .741 .894 r
.67028 .16088 .67695 .17052 .69081 .16489 .68418 .15499 Mtetra
.678 .733 .892 r
.68418 .15499 .69081 .16489 .70473 .15904 .69816 .14933 Mtetra
.67 .736 .9 r
.69816 .14933 .70473 .15904 .71873 .15353 .71222 .14398 Mtetra
.665 .739 .905 r
.71222 .14398 .71873 .15353 .73282 .14828 .72636 .13876 Mtetra
.664 .74 .907 r
.72636 .13876 .73282 .14828 .74698 .14311 .74058 .13356 Mtetra
.664 .741 .907 r
.74058 .13356 .74698 .14311 .76122 .13795 .75486 .12835 Mtetra
.75486 .12835 .76122 .13795 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .164 .34381 .15579 .33602 Mtetra
.15579 .33602 .164 .34381 .17554 .33961 .16736 .33178 Mtetra
.663 .74 .907 r
.16736 .33178 .17554 .33961 .18713 .33544 .17899 .32754 Mtetra
.661 .739 .908 r
.17899 .32754 .18713 .33544 .19876 .33141 .19066 .32335 Mtetra
.654 .734 .908 r
.19066 .32335 .19876 .33141 .21041 .32768 .20237 .31934 Mtetra
.643 .724 .907 r
.20237 .31934 .21041 .32768 .2221 .32418 .21409 .31563 Mtetra
.639 .718 .905 r
.21409 .31563 .2221 .32418 .23389 .32011 .22587 .31202 Mtetra
.665 .739 .905 r
.22587 .31202 .23389 .32011 .24592 .314 .23777 .30762 Mtetra
.72 .799 .913 r
.23777 .30762 .24592 .314 .25784 .30959 .24988 .30151 Mtetra
.664 .741 .907 r
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31798 .29167 .31046 .27929 Mtetra
.649 .647 .834 r
.31046 .27929 .31798 .29167 .32968 .29626 .32274 .27484 Mtetra
.443 .422 .741 r
.32274 .27484 .32968 .29626 .34166 .29826 .33458 .27855 Mtetra
.476 .46 .76 r
.33458 .27855 .34166 .29826 .35391 .29727 .34663 .28077 Mtetra
.525 .526 .799 r
.34663 .28077 .35391 .29727 .36636 .29392 .35889 .28087 Mtetra
.576 .606 .846 r
.35889 .28087 .36636 .29392 .37895 .28909 .37135 .27904 Mtetra
.619 .687 .892 r
.37135 .27904 .37895 .28909 .39163 .28358 .38396 .27579 Mtetra
.645 .756 .93 r
.38396 .27579 .39163 .28358 .40436 .27791 .39666 .27169 Mtetra
.656 .806 .955 r
.39666 .27169 .40436 .27791 .41714 .27245 .40945 .26715 Mtetra
.653 .836 .97 r
.40945 .26715 .41714 .27245 .42995 .26735 .42231 .26248 Mtetra
.648 .849 .977 r
.42231 .26248 .42995 .26735 .44282 .26271 .43522 .2578 Mtetra
.647 .849 .977 r
.43522 .2578 .44282 .26271 .45573 .25852 .4482 .25311 Mtetra
.657 .837 .969 r
.4482 .25311 .45573 .25852 .4687 .25471 .46124 .24829 Mtetra
.678 .813 .947 r
.46124 .24829 .4687 .25471 .48174 .2511 .47436 .24303 Mtetra
.703 .774 .907 r
.47436 .24303 .48174 .2511 .49485 .24734 .48754 .23691 Mtetra
.723 .725 .852 r
.48754 .23691 .49485 .24734 .50803 .24289 .50078 .22935 Mtetra
.733 .675 .794 r
.50078 .22935 .50803 .24289 .52129 .23695 .51407 .21982 Mtetra
.735 .634 .747 r
.51407 .21982 .52129 .23695 .53459 .2286 .52738 .20814 Mtetra
.729 .603 .716 r
.52738 .20814 .53459 .2286 .5479 .21722 .54069 .19491 Mtetra
.619 .528 .73 r
.54069 .19491 .5479 .21722 .56119 .20317 .55407 .18995 Mtetra
.651 .647 .833 r
.55407 .18995 .56119 .20317 .57454 .1941 .56752 .18502 Mtetra
.664 .741 .907 r
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.607 .718 .923 r
.62196 .16505 .6288 .17432 .64254 .16938 .6358 .16177 Mtetra
.662 .787 .941 r
.6358 .16177 .64254 .16938 .65642 .16618 .64966 .15674 Mtetra
.685 .747 .898 r
.64966 .15674 .65642 .16618 .67028 .16088 .66354 .15088 Mtetra
.68 .732 .89 r
.66354 .15088 .67028 .16088 .68418 .15499 .6775 .14512 Mtetra
.671 .733 .897 r
.6775 .14512 .68418 .15499 .69816 .14933 .69154 .13966 Mtetra
.666 .737 .903 r
.69154 .13966 .69816 .14933 .71222 .14398 .70566 .13438 Mtetra
.664 .74 .906 r
.70566 .13438 .71222 .14398 .72636 .13876 .71985 .12916 Mtetra
.664 .741 .907 r
.71985 .12916 .72636 .13876 .74058 .13356 .73411 .12392 Mtetra
.73411 .12392 .74058 .13356 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33602 .14752 .32817 Mtetra
.14752 .32817 .15579 .33602 .16736 .33178 .15912 .32389 Mtetra
.15912 .32389 .16736 .33178 .17899 .32754 .17078 .31959 Mtetra
.663 .74 .907 r
.17078 .31959 .17899 .32754 .19066 .32335 .18249 .31531 Mtetra
.66 .738 .908 r
.18249 .31531 .19066 .32335 .20237 .31934 .19424 .3111 Mtetra
.652 .731 .907 r
.19424 .3111 .20237 .31934 .21409 .31563 .20602 .30709 Mtetra
.642 .721 .906 r
.20602 .30709 .21409 .31563 .22587 .31202 .21783 .30335 Mtetra
.641 .719 .904 r
.21783 .30335 .22587 .31202 .23777 .30762 .2297 .29962 Mtetra
.669 .745 .907 r
.2297 .29962 .23777 .30762 .24988 .30151 .2417 .29505 Mtetra
.718 .799 .915 r
.2417 .29505 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.664 .741 .907 r
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32274 .27484 .31492 .26641 Mtetra
.664 .739 .906 r
.31492 .26641 .32274 .27484 .33458 .27855 .3273 .26185 Mtetra
.612 .57 .782 r
.3273 .26185 .33458 .27855 .34663 .28077 .33967 .25833 Mtetra
.497 .449 .733 r
.33967 .25833 .34663 .28077 .35889 .28087 .35182 .25996 Mtetra
.522 .478 .748 r
.35182 .25996 .35889 .28087 .37135 .27904 .36414 .26036 Mtetra
.553 .518 .77 r
.36414 .26036 .37135 .27904 .38396 .27579 .37662 .25938 Mtetra
.584 .562 .795 r
.37662 .25938 .38396 .27579 .39666 .27169 .38925 .25712 Mtetra
.611 .601 .817 r
.38925 .25712 .39666 .27169 .40945 .26715 .402 .25385 Mtetra
.633 .632 .832 r
.402 .25385 .40945 .26715 .42231 .26248 .41486 .24979 Mtetra
.65 .651 .838 r
.41486 .24979 .42231 .26248 .43522 .2578 .42779 .24506 Mtetra
.665 .657 .833 r
.42779 .24506 .43522 .2578 .4482 .25311 .44081 .23968 Mtetra
.677 .652 .818 r
.44081 .23968 .4482 .25311 .46124 .24829 .45391 .23349 Mtetra
.688 .638 .794 r
.45391 .23349 .46124 .24829 .47436 .24303 .46707 .22629 Mtetra
.696 .619 .766 r
.46707 .22629 .47436 .24303 .48754 .23691 .48029 .21778 Mtetra
.701 .598 .738 r
.48029 .21778 .48754 .23691 .50078 .22935 .49357 .20786 Mtetra
.702 .581 .717 r
.49357 .20786 .50078 .22935 .51407 .21982 .50686 .19669 Mtetra
.63 .529 .721 r
.50686 .19669 .51407 .21982 .52738 .20814 .52016 .19071 Mtetra
.634 .581 .777 r
.52016 .19071 .52738 .20814 .54069 .19491 .53352 .18578 Mtetra
.664 .739 .906 r
.53352 .18578 .54069 .19491 .55407 .18995 .54694 .18083 Mtetra
.664 .741 .907 r
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.609 .718 .923 r
.6013 .16078 .60825 .17008 .62196 .16505 .6151 .15743 Mtetra
.659 .786 .942 r
.6151 .15743 .62196 .16505 .6358 .16177 .62894 .15248 Mtetra
.683 .751 .903 r
.62894 .15248 .6358 .16177 .64966 .15674 .64281 .14668 Mtetra
.68 .732 .89 r
.64281 .14668 .64966 .15674 .66354 .15088 .65675 .14087 Mtetra
.673 .731 .894 r
.65675 .14087 .66354 .15088 .6775 .14512 .67077 .13533 Mtetra
.667 .736 .901 r
.67077 .13533 .6775 .14512 .69154 .13966 .68486 .13 Mtetra
.665 .739 .905 r
.68486 .13 .69154 .13966 .70566 .13438 .69903 .12473 Mtetra
.664 .74 .907 r
.69903 .12473 .70566 .13438 .71985 .12916 .71327 .11947 Mtetra
.664 .741 .907 r
.71327 .11947 .71985 .12916 .73411 .12392 .72759 .11419 Mtetra
.72759 .11419 .73411 .12392 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14752 .32817 .13917 .32025 Mtetra
.13917 .32025 .14752 .32817 .15912 .32389 .15081 .31593 Mtetra
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .3116 Mtetra
.663 .741 .907 r
.16249 .3116 .17078 .31959 .18249 .31531 .17424 .30725 Mtetra
.662 .74 .907 r
.17424 .30725 .18249 .31531 .19424 .3111 .18603 .30292 Mtetra
.659 .736 .907 r
.18603 .30292 .19424 .3111 .20602 .30709 .19786 .29868 Mtetra
.651 .729 .906 r
.19786 .29868 .20602 .30709 .21783 .30335 .20973 .29463 Mtetra
.643 .72 .904 r
.20973 .29463 .21783 .30335 .2297 .29962 .22163 .29082 Mtetra
.643 .719 .903 r
.22163 .29082 .2297 .29962 .2417 .29505 .23359 .28699 Mtetra
.667 .746 .909 r
.23359 .28699 .2417 .29505 .25389 .28893 .24567 .28241 Mtetra
.718 .8 .916 r
.24567 .28241 .25389 .28893 .26599 .28447 .25795 .27625 Mtetra
.666 .743 .908 r
.25795 .27625 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.664 .741 .907 r
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33967 .25833 .33191 .24874 Mtetra
.661 .714 .887 r
.33191 .24874 .33967 .25833 .35182 .25996 .34444 .24409 Mtetra
.637 .595 .79 r
.34444 .24409 .35182 .25996 .36414 .26036 .35703 .23942 Mtetra
.602 .525 .741 r
.35703 .23942 .36414 .26036 .37662 .25938 .36963 .23577 Mtetra
.561 .482 .723 r
.36963 .23577 .37662 .25938 .38925 .25712 .3822 .23417 Mtetra
.58 .498 .727 r
.3822 .23417 .38925 .25712 .402 .25385 .39489 .23153 Mtetra
.599 .515 .731 r
.39489 .23153 .402 .25385 .41486 .24979 .40771 .22782 Mtetra
.617 .528 .731 r
.40771 .22782 .41486 .24979 .42779 .24506 .42063 .22305 Mtetra
.633 .537 .729 r
.42063 .22305 .42779 .24506 .44081 .23968 .43365 .2172 Mtetra
.646 .542 .722 r
.43365 .2172 .44081 .23968 .45391 .23349 .44674 .21027 Mtetra
.656 .543 .715 r
.44674 .21027 .45391 .23349 .46707 .22629 .45991 .20229 Mtetra
.627 .521 .715 r
.45991 .20229 .46707 .22629 .48029 .21778 .47307 .19636 Mtetra
.619 .535 .738 r
.47307 .19636 .48029 .21778 .49357 .20786 .48628 .19146 Mtetra
.637 .595 .79 r
.48628 .19146 .49357 .20786 .50686 .19669 .49955 .18654 Mtetra
.661 .714 .887 r
.49955 .18654 .50686 .19669 .52016 .19071 .51289 .18159 Mtetra
.664 .741 .907 r
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.662 .74 .908 r
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15656 Mtetra
.609 .721 .924 r
.58055 .15656 .58761 .16583 .6013 .16078 .59432 .15317 Mtetra
.66 .788 .943 r
.59432 .15317 .6013 .16078 .6151 .15743 .60813 .14815 Mtetra
.682 .752 .904 r
.60813 .14815 .6151 .15743 .62894 .15248 .62199 .14236 Mtetra
.68 .731 .889 r
.62199 .14236 .62894 .15248 .64281 .14668 .63591 .13656 Mtetra
.673 .73 .893 r
.63591 .13656 .64281 .14668 .65675 .14087 .64991 .13097 Mtetra
.668 .734 .9 r
.64991 .13097 .65675 .14087 .67077 .13533 .66398 .1256 Mtetra
.665 .738 .905 r
.66398 .1256 .67077 .13533 .68486 .13 .67813 .1203 Mtetra
.664 .74 .907 r
.67813 .1203 .68486 .13 .69903 .12473 .69235 .11501 Mtetra
.664 .741 .907 r
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .10971 Mtetra
.70664 .10971 .71327 .11947 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11915 .3166 Mtetra
.11915 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31593 .14242 .30791 Mtetra
.14242 .30791 .15081 .31593 .16249 .3116 .15414 .30354 Mtetra
.15414 .30354 .16249 .3116 .17424 .30725 .16591 .29915 Mtetra
.663 .74 .907 r
.16591 .29915 .17424 .30725 .18603 .30292 .17774 .29475 Mtetra
.662 .739 .907 r
.17774 .29475 .18603 .30292 .19786 .29868 .18961 .29037 Mtetra
.659 .736 .907 r
.18961 .29037 .19786 .29868 .20973 .29463 .20153 .28607 Mtetra
.652 .728 .905 r
.20153 .28607 .20973 .29463 .22163 .29082 .21349 .28195 Mtetra
.644 .719 .903 r
.21349 .28195 .22163 .29082 .23359 .28699 .22548 .27804 Mtetra
.643 .718 .902 r
.22548 .27804 .23359 .28699 .24567 .28241 .23753 .27413 Mtetra
.661 .741 .909 r
.23753 .27413 .24567 .28241 .25795 .27625 .24969 .26969 Mtetra
.7 .799 .926 r
.24969 .26969 .25795 .27625 .27014 .27166 .26201 .26405 Mtetra
.69 .769 .912 r
.26201 .26405 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.664 .741 .907 r
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36963 .23577 .3619 .226 Mtetra
.661 .714 .887 r
.3619 .226 .36963 .23577 .3822 .23417 .37465 .22124 Mtetra
.65 .647 .834 r
.37465 .22124 .3822 .23417 .39489 .23153 .38745 .21646 Mtetra
.641 .611 .804 r
.38745 .21646 .39489 .23153 .40771 .22782 .40032 .21166 Mtetra
.637 .595 .791 r
.40032 .21166 .40771 .22782 .42063 .22305 .41325 .20683 Mtetra
.41325 .20683 .42063 .22305 .43365 .2172 .42625 .20199 Mtetra
.641 .611 .804 r
.42625 .20199 .43365 .2172 .44674 .21027 .4393 .19711 Mtetra
.65 .647 .834 r
.4393 .19711 .44674 .21027 .45991 .20229 .45242 .19222 Mtetra
.661 .714 .887 r
.45242 .19222 .45991 .20229 .47307 .19636 .46561 .1873 Mtetra
.664 .741 .907 r
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.639 .731 .915 r
.54607 .15727 .55328 .1666 .56688 .16156 .55972 .15299 Mtetra
.628 .749 .934 r
.55972 .15299 .56688 .16156 .58055 .15656 .57345 .14897 Mtetra
.667 .792 .941 r
.57345 .14897 .58055 .15656 .59432 .15317 .58724 .14374 Mtetra
.681 .749 .902 r
.58724 .14374 .59432 .15317 .60813 .14815 .60108 .13795 Mtetra
.678 .73 .889 r
.60108 .13795 .60813 .14815 .62199 .14236 .61498 .13216 Mtetra
.672 .729 .892 r
.61498 .13216 .62199 .14236 .63591 .13656 .62896 .12657 Mtetra
.668 .733 .899 r
.62896 .12657 .63591 .13656 .64991 .13097 .64301 .12116 Mtetra
.665 .738 .904 r
.64301 .12116 .64991 .13097 .66398 .1256 .65713 .11584 Mtetra
.664 .74 .906 r
.65713 .11584 .66398 .1256 .67813 .1203 .67133 .11052 Mtetra
.664 .741 .907 r
.67133 .11052 .67813 .1203 .69235 .11501 .6856 .1052 Mtetra
.6856 .1052 .69235 .11501 .70664 .10971 .69994 .09984 Mtetra
.69994 .09984 .70664 .10971 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29915 .15752 .29098 Mtetra
.15752 .29098 .16591 .29915 .17774 .29475 .16938 .28653 Mtetra
.663 .74 .907 r
.16938 .28653 .17774 .29475 .18961 .29037 .18129 .28207 Mtetra
.662 .739 .907 r
.18129 .28207 .18961 .29037 .20153 .28607 .19325 .27763 Mtetra
.659 .735 .906 r
.19325 .27763 .20153 .28607 .21349 .28195 .20526 .27326 Mtetra
.653 .728 .904 r
.20526 .27326 .21349 .28195 .22548 .27804 .21731 .26904 Mtetra
.646 .719 .901 r
.21731 .26904 .22548 .27804 .23753 .27413 .2294 .265 Mtetra
.644 .716 .9 r
.2294 .265 .23753 .27413 .24969 .26969 .24154 .26101 Mtetra
.653 .732 .907 r
.24154 .26101 .24969 .26969 .26201 .26405 .25377 .25673 Mtetra
.679 .776 .924 r
.25377 .25673 .26201 .26405 .27435 .25868 .26612 .25169 Mtetra
.712 .793 .915 r
.26612 .25169 .27435 .25868 .28668 .25407 .27861 .24556 Mtetra
.665 .742 .908 r
.27861 .24556 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.664 .741 .907 r
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.663 .74 .908 r
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .153 Mtetra
.615 .723 .923 r
.52517 .153 .53249 .16233 .54607 .15727 .5388 .14941 Mtetra
.65 .778 .942 r
.5388 .14941 .54607 .15727 .55972 .15299 .55249 .1447 Mtetra
.675 .776 .926 r
.55249 .1447 .55972 .15299 .57345 .14897 .56625 .13921 Mtetra
.68 .741 .897 r
.56625 .13921 .57345 .14897 .58724 .14374 .58008 .13342 Mtetra
.676 .727 .888 r
.58008 .13342 .58724 .14374 .60108 .13795 .59396 .12768 Mtetra
.671 .728 .892 r
.59396 .12768 .60108 .13795 .61498 .13216 .60792 .12212 Mtetra
.667 .733 .899 r
.60792 .12212 .61498 .13216 .62896 .12657 .62195 .1167 Mtetra
.665 .737 .904 r
.62195 .1167 .62896 .12657 .64301 .12116 .63605 .11136 Mtetra
.664 .74 .906 r
.63605 .11136 .64301 .12116 .65713 .11584 .65022 .10602 Mtetra
.664 .741 .907 r
.65022 .10602 .65713 .11584 .67133 .11052 .66447 .10067 Mtetra
.66447 .10067 .67133 .11052 .6856 .1052 .67879 .09529 Mtetra
.67879 .09529 .6856 .1052 .69994 .09984 .69318 .08989 Mtetra
.69318 .08989 .69994 .09984 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29098 .14905 .28274 Mtetra
.14905 .28274 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.16094 .27826 .16938 .28653 .18129 .28207 .17289 .27375 Mtetra
.663 .74 .907 r
.17289 .27375 .18129 .28207 .19325 .27763 .18488 .26923 Mtetra
.662 .739 .907 r
.18488 .26923 .19325 .27763 .20526 .27326 .19693 .26472 Mtetra
.66 .736 .906 r
.19693 .26472 .20526 .27326 .21731 .26904 .20904 .26026 Mtetra
.655 .729 .904 r
.20904 .26026 .21731 .26904 .2294 .265 .22118 .25592 Mtetra
.65 .721 .901 r
.22118 .25592 .2294 .265 .24154 .26101 .23337 .25171 Mtetra
.646 .715 .899 r
.23337 .25171 .24154 .26101 .25377 .25673 .24561 .24761 Mtetra
.648 .722 .902 r
.24561 .24761 .25377 .25673 .26612 .25169 .25791 .24341 Mtetra
.661 .748 .915 r
.25791 .24341 .26612 .25169 .27861 .24556 .27031 .23884 Mtetra
.682 .798 .936 r
.27031 .23884 .27861 .24556 .29104 .24086 .28282 .23363 Mtetra
.703 .789 .918 r
.28282 .23363 .29104 .24086 .30352 .23617 .29544 .2277 Mtetra
.672 .749 .909 r
.29544 .2277 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.664 .741 .907 r
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.657 .738 .91 r
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15398 Mtetra
.625 .732 .924 r
.49065 .15398 .49813 .16311 .51162 .15805 .50417 .1501 Mtetra
.647 .774 .941 r
.50417 .1501 .51162 .15805 .52517 .153 .51777 .14548 Mtetra
.668 .794 .942 r
.51777 .14548 .52517 .153 .5388 .14941 .53145 .14021 Mtetra
.678 .754 .908 r
.53145 .14021 .5388 .14941 .55249 .1447 .54518 .13455 Mtetra
.677 .732 .891 r
.54518 .13455 .55249 .1447 .56625 .13921 .55898 .1288 Mtetra
.673 .725 .888 r
.55898 .1288 .56625 .13921 .58008 .13342 .57285 .12314 Mtetra
.669 .728 .893 r
.57285 .12314 .58008 .13342 .59396 .12768 .58679 .11762 Mtetra
.666 .733 .9 r
.58679 .11762 .59396 .12768 .60792 .12212 .60079 .11222 Mtetra
.665 .737 .904 r
.60079 .11222 .60792 .12212 .62195 .1167 .61487 .10685 Mtetra
.664 .74 .906 r
.61487 .10685 .62195 .1167 .63605 .11136 .62902 .1015 Mtetra
.664 .74 .907 r
.62902 .1015 .63605 .11136 .65022 .10602 .64325 .09612 Mtetra
.664 .741 .907 r
.64325 .09612 .65022 .10602 .66447 .10067 .65754 .09072 Mtetra
.65754 .09072 .66447 .10067 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28274 .14051 .27444 Mtetra
.14051 .27444 .14905 .28274 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17289 .27375 .16441 .26536 Mtetra
.16441 .26536 .17289 .27375 .18488 .26923 .17644 .2608 Mtetra
.664 .74 .907 r
.17644 .2608 .18488 .26923 .19693 .26472 .18853 .25621 Mtetra
.663 .739 .907 r
.18853 .25621 .19693 .26472 .20904 .26026 .20067 .25163 Mtetra
.661 .737 .906 r
.20067 .25163 .20904 .26026 .22118 .25592 .21286 .24708 Mtetra
.658 .732 .904 r
.21286 .24708 .22118 .25592 .23337 .25171 .22511 .24259 Mtetra
.654 .724 .901 r
.22511 .24259 .23337 .25171 .24561 .24761 .2374 .2382 Mtetra
.649 .717 .898 r
.2374 .2382 .24561 .24761 .25791 .24341 .24974 .23392 Mtetra
.648 .715 .897 r
.24974 .23392 .25791 .24341 .27031 .23884 .26214 .22966 Mtetra
.651 .725 .903 r
.26214 .22966 .27031 .23884 .28282 .23363 .27461 .22529 Mtetra
.66 .75 .917 r
.27461 .22529 .28282 .23363 .29544 .2277 .28716 .22066 Mtetra
.672 .79 .938 r
.28716 .22066 .29544 .2277 .30803 .22271 .2998 .21566 Mtetra
.683 .794 .933 r
.2998 .21566 .30803 .22271 .32067 .21794 .31252 .21029 Mtetra
.69 .78 .92 r
.31252 .21029 .32067 .21794 .33337 .21314 .32531 .20466 Mtetra
.678 .756 .91 r
.32531 .20466 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.664 .741 .907 r
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.651 .736 .912 r
.42949 .16466 .4372 .17393 .45047 .16892 .44278 .16004 Mtetra
.639 .743 .924 r
.44278 .16004 .45047 .16892 .4638 .16389 .45614 .15577 Mtetra
.646 .767 .937 r
.45614 .15577 .4638 .16389 .47719 .15883 .46957 .15122 Mtetra
.657 .787 .943 r
.46957 .15122 .47719 .15883 .49065 .15398 .48308 .1463 Mtetra
.669 .79 .939 r
.48308 .1463 .49065 .15398 .50417 .1501 .49666 .14101 Mtetra
.676 .756 .911 r
.49666 .14101 .50417 .1501 .51777 .14548 .51031 .13545 Mtetra
.676 .734 .894 r
.51031 .13545 .51777 .14548 .53145 .14021 .52403 .12977 Mtetra
.673 .724 .888 r
.52403 .12977 .53145 .14021 .54518 .13455 .53781 .12412 Mtetra
.67 .724 .89 r
.53781 .12412 .54518 .13455 .55898 .1288 .55165 .11856 Mtetra
.667 .729 .895 r
.55165 .11856 .55898 .1288 .57285 .12314 .56557 .1131 Mtetra
.666 .734 .901 r
.56557 .1131 .57285 .12314 .58679 .11762 .57955 .1077 Mtetra
.665 .738 .905 r
.57955 .1077 .58679 .11762 .60079 .11222 .59361 .10233 Mtetra
.664 .74 .906 r
.59361 .10233 .60079 .11222 .61487 .10685 .60774 .09695 Mtetra
.664 .74 .907 r
.60774 .09695 .61487 .10685 .62902 .1015 .62194 .09156 Mtetra
.664 .741 .907 r
.62194 .09156 .62902 .1015 .64325 .09612 .63621 .08613 Mtetra
.63621 .08613 .64325 .09612 .65754 .09072 .65055 .08068 Mtetra
.65055 .08068 .65754 .09072 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27514 Mtetra
.10817 .27514 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26536 .15586 .25691 Mtetra
.15586 .25691 .16441 .26536 .17644 .2608 .16792 .2523 Mtetra
.16792 .2523 .17644 .2608 .18853 .25621 .18004 .24767 Mtetra
.664 .74 .907 r
.18004 .24767 .18853 .25621 .20067 .25163 .19222 .24302 Mtetra
.663 .74 .907 r
.19222 .24302 .20067 .25163 .21286 .24708 .20446 .23836 Mtetra
.662 .738 .906 r
.20446 .23836 .21286 .24708 .22511 .24259 .21674 .23371 Mtetra
.66 .734 .904 r
.21674 .23371 .22511 .24259 .2374 .2382 .22909 .22909 Mtetra
.657 .729 .902 r
.22909 .22909 .2374 .2382 .24974 .23392 .24148 .22453 Mtetra
.654 .722 .898 r
.24148 .22453 .24974 .23392 .26214 .22966 .25393 .22003 Mtetra
.652 .716 .895 r
.25393 .22003 .26214 .22966 .27461 .22529 .26643 .21559 Mtetra
.651 .715 .895 r
.26643 .21559 .27461 .22529 .28716 .22066 .279 .21115 Mtetra
.652 .721 .899 r
.279 .21115 .28716 .22066 .2998 .21566 .29163 .20664 Mtetra
.657 .736 .908 r
.29163 .20664 .2998 .21566 .31252 .21029 .30433 .20201 Mtetra
.661 .758 .921 r
.30433 .20201 .31252 .21029 .32531 .20466 .31711 .19724 Mtetra
.665 .783 .937 r
.31711 .19724 .32531 .20466 .33814 .19937 .32995 .19231 Mtetra
.667 .796 .943 r
.32995 .19231 .33814 .19937 .351 .19448 .34286 .1873 Mtetra
.668 .793 .941 r
.34286 .1873 .351 .19448 .36392 .18957 .35584 .18224 Mtetra
.667 .79 .94 r
.35584 .18224 .36392 .18957 .37691 .18464 .36887 .1772 Mtetra
.665 .788 .94 r
.36887 .1772 .37691 .18464 .38996 .17968 .38197 .1722 Mtetra
.662 .787 .941 r
.38197 .1722 .38996 .17968 .40307 .1747 .39512 .16724 Mtetra
.661 .788 .942 r
.39512 .16724 .40307 .1747 .41625 .16969 .40834 .1623 Mtetra
.661 .791 .944 r
.40834 .1623 .41625 .16969 .42949 .16466 .42163 .15731 Mtetra
.664 .795 .945 r
.42163 .15731 .42949 .16466 .44278 .16004 .43499 .15223 Mtetra
.668 .784 .936 r
.43499 .15223 .44278 .16004 .45614 .15577 .44841 .147 Mtetra
.672 .761 .918 r
.44841 .147 .45614 .15577 .46957 .15122 .46191 .14162 Mtetra
.673 .742 .902 r
.46191 .14162 .46957 .15122 .48308 .1463 .47547 .13611 Mtetra
.673 .728 .892 r
.47547 .13611 .48308 .1463 .49666 .14101 .4891 .13053 Mtetra
.671 .722 .888 r
.4891 .13053 .49666 .14101 .51031 .13545 .50279 .12496 Mtetra
.669 .722 .889 r
.50279 .12496 .51031 .13545 .52403 .12977 .51654 .11943 Mtetra
.667 .726 .893 r
.51654 .11943 .52403 .12977 .53781 .12412 .53037 .11396 Mtetra
.666 .731 .899 r
.53037 .11396 .53781 .12412 .55165 .11856 .54426 .10855 Mtetra
.665 .736 .903 r
.54426 .10855 .55165 .11856 .56557 .1131 .55822 .10317 Mtetra
.664 .738 .905 r
.55822 .10317 .56557 .1131 .57955 .1077 .57225 .09779 Mtetra
.664 .74 .907 r
.57225 .09779 .57955 .1077 .59361 .10233 .58636 .09239 Mtetra
.664 .741 .907 r
.58636 .09239 .59361 .10233 .60774 .09695 .60053 .08697 Mtetra
.60053 .08697 .60774 .09695 .62194 .09156 .61478 .08152 Mtetra
.61478 .08152 .62194 .09156 .63621 .08613 .6291 .07605 Mtetra
.6291 .07605 .63621 .08613 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27514 .09942 .26676 Mtetra
.09942 .26676 .10817 .27514 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18004 .24767 .17149 .23906 Mtetra
.17149 .23906 .18004 .24767 .19222 .24302 .1837 .23436 Mtetra
.1837 .23436 .19222 .24302 .20446 .23836 .19597 .22965 Mtetra
.664 .74 .907 r
.19597 .22965 .20446 .23836 .21674 .23371 .20829 .22492 Mtetra
.663 .739 .906 r
.20829 .22492 .21674 .23371 .22909 .22909 .22068 .22018 Mtetra
.662 .737 .905 r
.22068 .22018 .22909 .22909 .24148 .22453 .23312 .21544 Mtetra
.661 .733 .903 r
.23312 .21544 .24148 .22453 .25393 .22003 .24562 .21072 Mtetra
.659 .728 .901 r
.24562 .21072 .25393 .22003 .26643 .21559 .25817 .20603 Mtetra
.657 .723 .897 r
.25817 .20603 .26643 .21559 .279 .21115 .27078 .20136 Mtetra
.655 .718 .894 r
.27078 .20136 .279 .21115 .29163 .20664 .28345 .19671 Mtetra
.654 .715 .893 r
.28345 .19671 .29163 .20664 .30433 .20201 .29619 .19205 Mtetra
.655 .716 .893 r
.29619 .19205 .30433 .20201 .31711 .19724 .30899 .18736 Mtetra
.656 .719 .895 r
.30899 .18736 .31711 .19724 .32995 .19231 .32185 .1826 Mtetra
.658 .725 .898 r
.32185 .1826 .32995 .19231 .34286 .1873 .33478 .17777 Mtetra
.66 .731 .902 r
.33478 .17777 .34286 .1873 .35584 .18224 .34778 .17287 Mtetra
.662 .736 .905 r
.34778 .17287 .35584 .18224 .36887 .1772 .36085 .1679 Mtetra
.664 .74 .906 r
.36085 .1679 .36887 .1772 .38197 .1722 .37399 .16285 Mtetra
.665 .74 .906 r
.37399 .16285 .38197 .1722 .39512 .16724 .38719 .15773 Mtetra
.666 .738 .903 r
.38719 .15773 .39512 .16724 .40834 .1623 .40046 .15254 Mtetra
.667 .733 .899 r
.40046 .15254 .40834 .1623 .42163 .15731 .41379 .14728 Mtetra
.668 .728 .894 r
.41379 .14728 .42163 .15731 .43499 .15223 .4272 .14193 Mtetra
.668 .723 .89 r
.4272 .14193 .43499 .15223 .44841 .147 .44066 .13653 Mtetra
.668 .72 .888 r
.44066 .13653 .44841 .147 .46191 .14162 .4542 .13109 Mtetra
.4542 .13109 .46191 .14162 .47547 .13611 .4678 .12564 Mtetra
.667 .722 .89 r
.4678 .12564 .47547 .13611 .4891 .13053 .48146 .12019 Mtetra
.666 .726 .894 r
.48146 .12019 .4891 .13053 .50279 .12496 .49519 .11478 Mtetra
.665 .73 .898 r
.49519 .11478 .50279 .12496 .51654 .11943 .50899 .10938 Mtetra
.665 .735 .902 r
.50899 .10938 .51654 .11943 .53037 .11396 .52286 .104 Mtetra
.664 .738 .905 r
.52286 .104 .53037 .11396 .54426 .10855 .5368 .09862 Mtetra
.664 .739 .906 r
.5368 .09862 .54426 .10855 .55822 .10317 .5508 .09322 Mtetra
.664 .74 .907 r
.5508 .09322 .55822 .10317 .57225 .09779 .56488 .08781 Mtetra
.664 .741 .907 r
.56488 .08781 .57225 .09779 .58636 .09239 .57904 .08237 Mtetra
.57904 .08237 .58636 .09239 .60053 .08697 .59326 .0769 Mtetra
.59326 .0769 .60053 .08697 .61478 .08152 .60756 .0714 Mtetra
.60756 .0714 .61478 .08152 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23436 .1751 .22564 Mtetra
.1751 .22564 .1837 .23436 .19597 .22965 .1874 .22088 Mtetra
.1874 .22088 .19597 .22965 .20829 .22492 .19976 .2161 Mtetra
.664 .74 .907 r
.19976 .2161 .20829 .22492 .22068 .22018 .21218 .2113 Mtetra
.663 .74 .907 r
.21218 .2113 .22068 .22018 .23312 .21544 .22466 .20648 Mtetra
.663 .739 .906 r
.22466 .20648 .23312 .21544 .24562 .21072 .2372 .20165 Mtetra
.663 .737 .905 r
.2372 .20165 .24562 .21072 .25817 .20603 .2498 .19681 Mtetra
.662 .734 .904 r
.2498 .19681 .25817 .20603 .27078 .20136 .26246 .19197 Mtetra
.661 .731 .901 r
.26246 .19197 .27078 .20136 .28345 .19671 .27517 .18712 Mtetra
.66 .727 .899 r
.27517 .18712 .28345 .19671 .29619 .19205 .28795 .18227 Mtetra
.659 .723 .896 r
.28795 .18227 .29619 .19205 .30899 .18736 .3008 .17741 Mtetra
.659 .72 .894 r
.3008 .17741 .30899 .18736 .32185 .1826 .3137 .17251 Mtetra
.659 .718 .892 r
.3137 .17251 .32185 .1826 .33478 .17777 .32667 .16759 Mtetra
.66 .717 .891 r
.32667 .16759 .33478 .17777 .34778 .17287 .33971 .16261 Mtetra
.66 .716 .89 r
.33971 .16261 .34778 .17287 .36085 .1679 .35281 .15757 Mtetra
.661 .717 .889 r
.35281 .15757 .36085 .1679 .37399 .16285 .36598 .15248 Mtetra
.662 .717 .889 r
.36598 .15248 .37399 .16285 .38719 .15773 .37922 .14733 Mtetra
.663 .717 .889 r
.37922 .14733 .38719 .15773 .40046 .15254 .39253 .14212 Mtetra
.664 .719 .889 r
.39253 .14212 .40046 .15254 .41379 .14728 .4059 .13686 Mtetra
.664 .72 .89 r
.4059 .13686 .41379 .14728 .4272 .14193 .41933 .13156 Mtetra
.665 .722 .892 r
.41933 .13156 .4272 .14193 .44066 .13653 .43284 .12623 Mtetra
.665 .725 .894 r
.43284 .12623 .44066 .13653 .4542 .13109 .44641 .12089 Mtetra
.665 .728 .897 r
.44641 .12089 .4542 .13109 .4678 .12564 .46005 .11554 Mtetra
.665 .732 .9 r
.46005 .11554 .4678 .12564 .48146 .12019 .47375 .11018 Mtetra
.664 .735 .902 r
.47375 .11018 .48146 .12019 .49519 .11478 .48752 .10482 Mtetra
.664 .738 .905 r
.48752 .10482 .49519 .11478 .50899 .10938 .50137 .09945 Mtetra
.664 .739 .906 r
.50137 .09945 .50899 .10938 .52286 .104 .51528 .09406 Mtetra
.664 .74 .907 r
.51528 .09406 .52286 .104 .5368 .09862 .52926 .08864 Mtetra
.664 .741 .907 r
.52926 .08864 .5368 .09862 .5508 .09322 .54332 .0832 Mtetra
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07774 Mtetra
.55745 .07774 .56488 .08781 .57904 .08237 .57165 .07225 Mtetra
.57165 .07225 .57904 .08237 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .2161 .19115 .20721 Mtetra
.19115 .20721 .19976 .2161 .21218 .2113 .20361 .20236 Mtetra
.20361 .20236 .21218 .2113 .22466 .20648 .21612 .19749 Mtetra
.664 .74 .907 r
.21612 .19749 .22466 .20648 .2372 .20165 .2287 .1926 Mtetra
.2287 .1926 .2372 .20165 .2498 .19681 .24134 .18769 Mtetra
.663 .739 .906 r
.24134 .18769 .2498 .19681 .26246 .19197 .25403 .18275 Mtetra
.663 .738 .906 r
.25403 .18275 .26246 .19197 .27517 .18712 .26679 .17781 Mtetra
.663 .736 .905 r
.26679 .17781 .27517 .18712 .28795 .18227 .27961 .17284 Mtetra
.663 .735 .903 r
.27961 .17284 .28795 .18227 .3008 .17741 .2925 .16785 Mtetra
.662 .732 .902 r
.2925 .16785 .3008 .17741 .3137 .17251 .30545 .16284 Mtetra
.662 .731 .901 r
.30545 .16284 .3137 .17251 .32667 .16759 .31846 .1578 Mtetra
.662 .729 .899 r
.31846 .1578 .32667 .16759 .33971 .16261 .33154 .15274 Mtetra
.662 .728 .899 r
.33154 .15274 .33971 .16261 .35281 .15757 .34468 .14763 Mtetra
.663 .728 .898 r
.34468 .14763 .35281 .15757 .36598 .15248 .35789 .14249 Mtetra
.35789 .14249 .36598 .15248 .37922 .14733 .37116 .13732 Mtetra
.663 .729 .898 r
.37116 .13732 .37922 .14733 .39253 .14212 .3845 .1321 Mtetra
.663 .73 .899 r
.3845 .1321 .39253 .14212 .4059 .13686 .39791 .12686 Mtetra
.664 .732 .9 r
.39791 .12686 .4059 .13686 .41933 .13156 .41139 .12158 Mtetra
.664 .733 .901 r
.41139 .12158 .41933 .13156 .43284 .12623 .42493 .11629 Mtetra
.664 .735 .903 r
.42493 .11629 .43284 .12623 .44641 .12089 .43854 .11097 Mtetra
.664 .737 .904 r
.43854 .11097 .44641 .12089 .46005 .11554 .45222 .10563 Mtetra
.664 .738 .905 r
.45222 .10563 .46005 .11554 .47375 .11018 .46597 .10027 Mtetra
.664 .739 .906 r
.46597 .10027 .47375 .11018 .48752 .10482 .47978 .09488 Mtetra
.664 .74 .907 r
.47978 .09488 .48752 .10482 .50137 .09945 .49367 .08947 Mtetra
.49367 .08947 .50137 .09945 .51528 .09406 .50763 .08404 Mtetra
.664 .741 .907 r
.50763 .08404 .51528 .09406 .52926 .08864 .52166 .07858 Mtetra
.52166 .07858 .52926 .08864 .54332 .0832 .53576 .0731 Mtetra
.53576 .0731 .54332 .0832 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10877 .2271 Mtetra
.10877 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20236 .19496 .19335 Mtetra
.19496 .19335 .20361 .20236 .21612 .19749 .20751 .18844 Mtetra
.20751 .18844 .21612 .19749 .2287 .1926 .22012 .1835 Mtetra
.22012 .1835 .2287 .1926 .24134 .18769 .23279 .17854 Mtetra
.23279 .17854 .24134 .18769 .25403 .18275 .24553 .17356 Mtetra
.664 .74 .907 r
.24553 .17356 .25403 .18275 .26679 .17781 .25832 .16855 Mtetra
.25832 .16855 .26679 .17781 .27961 .17284 .27118 .16352 Mtetra
.663 .74 .907 r
.27118 .16352 .27961 .17284 .2925 .16785 .28411 .15847 Mtetra
.664 .739 .906 r
.28411 .15847 .2925 .16785 .30545 .16284 .29709 .15339 Mtetra
.663 .739 .906 r
.29709 .15339 .30545 .16284 .31846 .1578 .31015 .1483 Mtetra
.664 .739 .906 r
.31015 .1483 .31846 .1578 .33154 .15274 .32326 .14317 Mtetra
.663 .738 .905 r
.32326 .14317 .33154 .15274 .34468 .14763 .33644 .13801 Mtetra
.664 .738 .905 r
.33644 .13801 .34468 .14763 .35789 .14249 .34969 .13282 Mtetra
.34969 .13282 .35789 .14249 .37116 .13732 .36301 .1276 Mtetra
.36301 .1276 .37116 .13732 .3845 .1321 .37639 .12236 Mtetra
.664 .739 .905 r
.37639 .12236 .3845 .1321 .39791 .12686 .38984 .11708 Mtetra
.664 .739 .906 r
.38984 .11708 .39791 .12686 .41139 .12158 .40335 .11178 Mtetra
.664 .74 .906 r
.40335 .11178 .41139 .12158 .42493 .11629 .41694 .10645 Mtetra
.41694 .10645 .42493 .11629 .43854 .11097 .43059 .10109 Mtetra
.664 .74 .907 r
.43059 .10109 .43854 .11097 .45222 .10563 .44432 .09572 Mtetra
.664 .741 .907 r
.44432 .09572 .45222 .10563 .46597 .10027 .45811 .09031 Mtetra
.45811 .09031 .46597 .10027 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.4859 .07942 .49367 .08947 .50763 .08404 .49991 .07394 Mtetra
.49991 .07394 .50763 .08404 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .0731 .52814 .06289 Mtetra
.52814 .06289 .53576 .0731 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`00000o0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0
FP3oool00:`0oooo100000100:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<0oooo0000003oool0FP3o
ool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000A02Y_NP00`000000ZKgX0:Vm
j00=0:Vmj0030?ooo`000000oooo05T0oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?
9`3oool3000004H0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1H0?ooo`00NP3o
ool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2000004X0ZKgX00<000000:Vmj02Y
_NP03@2Y_NP00`3oool000000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0
501Oa?l08@3oool4000000L0ZKgX0`2Y_NL60:Vmj0D0ZKgW1P2Y_NP50:Vmib/0ZKgX00<000000:Vm
j02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?ooo`00NP3oool01`3oScD001AO0<Coo`3oool0oon?
03D0501Oa?l07`3oool2000000T0ZKgX1P2Y_NL30:Vmj0<0ZKcW1@2Y_NL30:Vmj0<0ZKcW1@2Y_NL2
0:Vmj0<0ZKcW1P2Y_NP50:VmiaX0ZKgX00<000000:Vmj02Y_NP03`2Y_NP00`000000oooo0?ooo`0B
0?ooo`050=nLB000000000000000B02Lgol0?`3oool007X0oooo00L0olAO01@DG`34ool0oooo0?oo
S`0e01@0GlCo01`0oooo0`0000000`2Y_NL0ZKgX0:Vmj0040:Vmj0D0ZKcW1P2Y_NL60:Vli`@0ZKgW
1`2Y_>L40:Vmi`H0ZKcW0`2Y_NP30:Zli`D0ZKgW0`2Y_NP30:Vmia<0ZKgX00<000000:Vmj02Y_NP0
3`2Y_NP00`3oool000000?ooo`0A0?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0n0?oo
o`00NP3oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool3000000D0ZKgW0`2Y_NP8
0:Vli`<0ZKgW0`2Y_>H50:Vli`D0Z[cV1P2Y_>L50:Zli`H0ZKcW1P2Z_>L;0:Vmi`80ZKgX0`2Y_NL=
0:Vmj0030000002Y_NP0ZKgX0100ZKgX00<000000?ooo`3oool05@3oool00`2oM000M;oo0?ooo`0m
0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0oooo0P0000000`2Y_NL000000:Vm
i`060:Vmi`/0ZKcW1P2Y_>H20:Vli`<0Z[[U1@2Z_>H30:Vli`<0Z[_V1@2Z_>L30:Vli`<0Z[_V2P2Z
_>L<0:Vmi``0ZKgX00<000000:Vmj02Y_NP04@2Y_NP00`000000oooo0?ooo`070?ooo`030?oOW018
0000000000<0000000<0001d0;ooo`3oool0103oool00`2oM000M;oo0?ooo`0m0?ooo`00N`3oool0
1@3oohl0=@000000000055l0a?oo01D0oooo0`0000090:Vmi`P0ZKcW1P2Z^nH50:VliPH0Z[[U1@2Z
_>H60:ZkiP@0Z[cW1`2Z^nH20:Zli`<0Z[_V1@2Z_>L30:Vmi`<0Z[cW2`2Y_NL60:Vmj0030000002Y
_NP0ZKgX0140ZKgX00<0oooo0000003oool03`3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02L
gol0?P3oool009<0oooo0P00000:0:Vmi`P0ZKcW0`2Z^^D60:ZkiP80ZKcV0`2Z^N@60:Zji@D0Z[WT
1@2Z^nH50:Zji@`0Z[_V2`2Z_>L20:Vmi`<0Z[cW1P2Y_NL50:Vmj0030000002Y_NP0ZKgX0180ZKgX
00<000000?ooo`3oool03P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo03d0oooo
002@0?ooo`<00000202Y_NL50:VkiPD0ZKcW1P2Z^^D50:ZkiPH0Z[WT0`2Z^^D30:^hh`D0Z[WT0P2Z
^nH30:^ih`D0Z[[U0`2Z^nH30:^ji0/0Z[_V2`2Z_>L50:Vmi`D0ZKgX00<000000:Vmj02Y_NP04`2Y
_NP00`000000oooo0?ooo`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKcW
0000002Y_NL01P2Y_NL80:VkiP80ZKcW0`2Z^N@60:Zji@D0Z[SS1@2Z^N@60:^hh`D0Z[WT1P2[^N<5
0:Zji@H0Zk[T0P2Z^nH30:^ji0H0Z[_V0P2Z_>L30:^kiP/0Z[cW102Y_NP00`000000ZKgX0:Vmj00C
0:Vmj0030?ooo`000000oooo00h0oooo00<0_g@007Boo`3oool0@@3oool008/0oooo0`0000040:Vl
i`D0ZKgW2P2Y^nH60:Zii0<0Z[[U0`2[^><50:Zhh`80Z[WT2@2[^><20:Zii0<0[;WS1@2[^N<60:bi
h`/0Zk[T1@2Z^nH60:^kiP80Z[cW0`2[^nH60:Zli`80ZKgX00<0Z[gW0000002Z_NL05@2Y_NP00`00
0000oooo0?ooo`0=0?ooo`060=nLB000000000000000000007@0_ooo?P3oool008T0oooo0P000007
0:Vli`H0ZK[V1@2Y^nH50:Zhi0H0Z[WT1@2[^><50:Zhh`/0ZkSS1P2/^N<20:^ih`<0[K_T1P2/^N<2
0:^ji0<0[K[S1@2[^^@60:bji0/0Zk_V1@2Z_>L30:Zmi`030000002Z_NL0Z[gW0080ZKgX0`2Y_NL@
0:Vmj0030000003oool0oooo0500oooo00260?ooo`<000001`2Y_>L30:Vji@H0ZK[V0P2Y^nH30:Vh
h`D0Z[ST0`2Z^N@80:^hh`80Z[SS0`2/^^@60:^hh`D0[K_T1@2/^N<60:fki0D0[;WS1P2]^^<20:^j
i0<0[K[S1P2/^^@20:^kiP<0[;[T1@2[^nH60:ZliP80Z[gW00<000000:Zmi`2Z_NL01P2Y_NL?0:Vm
j0030?ooo`000000oooo0500oooo00240?ooo`<000001`2Y_>L60:Vji@D0ZK[V1P2Y^><40:Zhi0/0
ZkSS1P2/^^@30:^hh`<0[L7Y1@2]^n@20:bih`<0[L7X1P2]^n@50:jmi@/0[K[S2`2/^^@20:^kiP<0
[;_T1P2Z_>H00`2Z_NL000000:Zli`020:Zli`D0ZKgW402Y_NP00`000000oooo0?ooo`1?0?ooo`00
P@3oool3000000<0ZKcW00<000000:Vli`2Y_>L02`2Y^^D:0:Vhh`D0ZkWS1P2[^><50:bmiPH0[;[T
1P2]`NT40:fki0H0[L7X0`2]^n@30:c6k@D0[[gU0P2]^^<30:joiPH0[K[S1@2^^n<50:bji0H0[;_T
1@2Z_>H00`2Z_>L000000:Zli`030:Zli`80ZKgW0`2Z_NL@0:Vmj0030000003oool0oooo04h0oooo
001o0?ooo`8000001`2Y_>L;0:Vji@<0ZKOS1`2Y^><30:^ji0D0ZkWS0`2[^><30:c2j`D0[;gV0`2/
^^@30:_:l0D0[L7Y1@2[bo450:g1j0L0[<K]102^_ND60:joiP<0[K[S0`2^`>L50:jkh`80[;[T0`2^
^n<50:bki0H0Zk_U00<000000:Zli`2Z_>L00P2Z_>L60:Zmia00ZKgX00<000000?ooo`3oool0C@3o
ool007`0oooo0`0000020:Vmi`D0ZKcW2`2Y^^D50:Vgh`D0ZKSS1P2[^^@50:^ih`H0[<;[102/_NH7
0:_:l080[L7Y0`2Ua_050:_;l@80[L7X0`2Vao460:c6k@D0Z/[`1@2^_nH60:k0i`/0[[_S0P2/^n@3
0:jkh`D0Zk_U00<000000:Zli`2Z_>L00`2[_>H;0:Zmi`X0ZKgX00<000000?ooo`3oool0C@3oool0
04/0oooo00D0a5lD000000000000000D05o4o`0Y0?ooo`<0000000<0ZKgW0000002Y_NL00`2Y_NL2
0:Vli`<0ZK[V202Y^^D80:Vgh`80ZKSS0`2Z^nH60:^ji0D0ZlS_1@2/`^/60:S9l@D0Zl[`1P2Ua_04
0:_;l@H0Y/Oa0`2/a^d30:2ok`D0Z/[`0P2^_nH30:S9l@H0[/3W0P2^^n<30:k0i`/0[[_S102[^nD0
0`000000ZkcV0:^liP040:^liP80Z[gW0`2[_>L50:Zmi`/0ZKgX00<000000?ooo`3oool0C03oool0
04X0oooo00L0ohle000DG`34ool0oooo0?ooa01O53D0Sooo02H0oooo0P0000090:Vmi`H0ZK[V1@2Y
^^D:0:Vgh`H0Z[_V0`2[^^@30:W;l@D0ZlS_0P2/`^/40:G4k`D0Z<Wa1@2O^n`50:G6l0H0WKW/1@2V
ao460:2ok`@0Z/[`1P2XbO4;0:k0i`80[[_S0`2__nD50:jkh`D0[K_T00<000000:^liP2[_>H00`2[
_>H60:^li`@0Z[gW2`2Y_NP00`000000oooo0?ooo`1<0?ooo`00C`3oool00`2?=@00=Hoo0?ooo`0R
0?ooo`<000001`2Y_NL;0:VjiPX0ZKOS1P2Z_>L50:ZkiPH0ZL_a102[b>l70:G4k`D0Z;cX1@2O^n`5
0:Vmj0H0WKW/1@2S^nX50:2ok`D0VkS/2`2XbO450:k0i`H0[koU0P2^^n<30:nmi0@0[K_T00@00000
0:fki02[_>H0ZkcV0`2/_>D50:^li`D0Z[gW2`2Y_NP00`000000oooo0?ooo`1;0?ooo`00@P3oool0
0`3oa5l0500000000003000000030000=@2?ool0oooo00@0oooo00<0ScD003F?o`3oool0803oool2
000000030:Vmj02Y_NL0ZKgW00D0ZKgW0`2Y^nH80:VjiP<0Z;OS1`2Y]n<30:Zmi`H0Z[cW1@2Yb_45
0:W;l@H0Xkk/0`2Ua>l30:Vmj0D0Z;cX0P2O^n`80:Vmj0<0WKW/0`2Y_NP50:>kjPD0ZKgX1@2K^>`6
09^gk0D0Z<Wa1@2YbO050:noi@H0[kgT0`2]^n@00`000000[K_T0:bli@050:bli@80ZkcW0`2[_>H;
0:Zmi`D0ZKgX00<000000?ooo`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O
51@0GlCo01h0oooo0`000000102Y_NP000000:Vmj02Y_NP40:Vmi`H0ZK_V1@2Y^^H60:Rgh`@0ZKOS
1P2Z_NL30:Zli`<0ZLWa1@2Yb_450:Jlj@H0Xkk/1P2Y_NP40:Rlj140ZKgX0P2S^nX80:Vmj080VkS/
0`2Y_NP;09^gk0D0ZLW`0P2__nD30:c6k@D0[kgT0`2__>@00`000000[kcT0:nli0050:bli@H0ZkcV
0P2Z_NL30:^mi`H0Z[gW102Y_NP00`000000oooo0?ooo`1:0?ooo`00BP3oool00`3oohl0=@000000
00020000000303F?o`3oool0oooo01X0oooo00<0ZKgX0000000000001`2Y_NP;0:VkiPD0Z;OT1@2X
]n<60:Vmi`D0Z[gW1P2YbO420:W:l@<0ZKgX1@2V_>T30:>nk2d0ZKgX0`2K]n`30:Vmj0D0VkO/102Y
bO060:c6k@80[kgT0`2^`^P20:nli0040000002__>@0[kcT0:nli0D0[[cT1@2[_>H60:^mi`D0Z[gW
1@2Y_NP00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0Ga@D05o4o`0M0?ooo`<00000202Y
_NP20:Vli`P0ZK_V202X]n@20:Rgh`<0ZKcW1P2Y_NL50:W9l0D0ZLWa1P2Y_NP40:JljCL0ZKgX102K
]n`509Zgk0D0[<K]1P2^`^P00`2__>@000000:nli0030:noi@D0[[cT0P2[_>H30:fli@D0ZkgW1P2Z
_NL50:Vmj0030000003oool0oooo04P0oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P000009
0:Vmj0D0ZKcW1@2Y^nH:0:Rgi0H0ZKcW0`2Y_NL30:[9l0D0ZLW`BP2Y_NP509Zgk0D0X;o_1@2^`^P0
0`2__nD000000:noi@040:noi@@0[[cT1P2]_>D20:^mi`<0ZkgV1@2Z_NL50:Vmj0030000003oool0
oooo04P0oooo001;0?ooo`060<AO5000000000000000000003D0Sooo4`3oool0102Y_NP000000000
000000020:Vmj0030000002Y_NP0ZKgX0080ZKgX2P2Y_>L50:Rhi0D0Z;OT1@2X^nH60:Vli`H0Z/W`
0P2YbO1=0:Vmj0D0Xk_Z1@2P_nl20:k2j0<0YlO`00<000000:noi@2__nD00`2__nD50:nmi0D0[KcU
1P2[_NH50:Zmi`D0ZKgX00<000000?ooo`3oool0A`3oool00680oooo00<0ZKgX000000000000202Y
_NP:0:Vli`<0Z;WU1@2X^>@20:Rgi0<0Z;WU1@2X^nH30:Vli`<0Z/[`1@2ZbO1@0:Vmj0D0Xk_Z102P
_nl50:O7l0040000002__nD0[koU0:noi@<0[L;Y1@2__N@20:fli@<0[[cT1@2[_NH60:Zmi`D0ZKgX
00<000000?ooo`3oool0AP3oool005l0oooo100000080:Vmj0X0ZKcW1P2X^ND40:Rhi0H0Z;WU1@2X
^nH60:[:l2L0ZKgX0`2Y]^<80:Vmj0<0ZKgW802Y_NP40:>kjPD0WKS[102Wao000`000000[L;Y0:g2
j@050:g2j@@0[kgT1P2^_>@20:^miP<0[;gV1@2Z_NL50:Zmj0030000003oool0oooo04H0oooo001M
0?ooo`040:Vmj00000000000000000H0ZKgX1@2Y_NL50:Vli`D0Z;[V1@2X^ND50:Nhi@H0Z;WU1@2[
bo030:[:l2L0ZKgX1P2Y]^<50:Vmj0H0ZKgW0P2Y_NP30:JUeAl0ZKgX1@2M^>/309Zgk0030000002J
]n`0[L;Y00D0[L;Y1@2`_nD50:jli0H0[;gV0P2Z_NL30:^mi`D0Z[gX00<000000?ooo`3oool0A@3o
ool005/0oooo0`00000:0:Vmj0D0ZKgW0P2Y_>L30:VkiPD0Z;[V0`2X^ND20:Ngi0D0YkSU0`2X^ND3
0:[;l@D0Zl_`7@2Y_NP30:Vfh`D0ZKgX1@2SV<X60:Vfh`D0XYC61@2Y_NL60:JUeB@0ZKgX0P2J]n`0
0`000000V[O/09Zgk0030:g2j@<0Y/G_1@2`_nD50:nmi0D0[;gV1P2[_NL40:Zmj0030?ooo`000000
oooo04D0oooo001H0?ooo`<000003P2Y_NP40:Vmi`H0ZK_V1@2X^^H50:Ngi0D0YkSU1P2Zbo4O0:Vm
j0H0ZKKS0P2Y_NP309j8_0D0XiS:0`2Y]^<30:67^0D0XYC61@2NQkX50:JUe@D0Y9c=802Y_NP0102J
]n`0000009Zgk02J]n`70:K5k`80/;oU0`2^`NL50:nmi0D0[KgU1@2[_NL50:Zmi`030000003oool0
oooo04@0oooo001E0?ooo`030:Vmj000000000000180ZKgX1@2Y^nL50:VkiPX0YkOT1@2Zb>l30:[;
lAd0ZKgX1@2VYMD50:Vfh`H0WXRl1@2SV<X50:67^0@0XYC60P2jV[L409j7^P@0YZGE0P2^T[X:0:BL
cAX0ZKgX00<0W[S[0000002N^>/00P2N^>/60:K5k`H0[/7W0P2__N@30;2ni0D0[KgU1@2[_NL50:Zm
i`030000003oool0oooo04<0oooo001C0?ooo`<0000000<0ZKgX0000002Y_NP03@2Y_NP50:Vli`D0
ZK_W302W]n@30:W2j`D0Z/S_7@2Y_NP30:BLc@D0YZGE0P2Y]^<30:25]`D0WXRl102SV<X20;>D]`D0
XHNh0P2RU<H30;ZJ]`D0WXNj0P2VYMD30:jB^P@0Y9c=0P2fVKX50:BLc@<0ZKgX0`2VYMDD0:Vmj003
0000002N^>/0W[S[0080W[S[1P2K^Nd50:k1i`H0/;kT102]_ND60:^mi`D0Z[gW00<000000?ooo`3o
ool0@P3oool00540oooo0P00000A0:Vmj0<0ZKgW1@2Y_>L20:Vki`<0Z;WU2@2W]n@60:W2j`H0[L7X
6@2Y_NP50:BLc@D0YZGE1@2PQKL609j8_080XiS:0`2cU;L50:67^0030::DaP2jV[L0^YZg0080^YZg
1@2NQkX60:jB^P80Y9c=0`2fVKX60:BLc@H0YZGE0P2Y_NP30:Vmi`h0ZKgX00<000000:Rlj02X_>P0
0`2X_>P509^ik@<0[/7W0`2Z`^/50;2ni0D0[[gU1@2[_NL50:Zmi`030000003oool0oooo0480oooo
001>0?ooo`<000004@2Y_NP60:Vmi`@0ZKcW1P2X^ND40:Ngi0H0Z;cX0`2Y`^/20;37j`H0[L7X502Y
_NP50:>HbPD0Y9c=0P2VYMD30:N;]`D0X8Fg1@2NR;`50;>D]`D0XHNh1P2jV[L309j7^P80`J>j1@2^
T[X00`2TW<d0]YVj0;JI^P030;JI^P@0Y9c=0P2gW;`50:JUe@H0ZKgW3@2Y_NP00`000000ZKgX0:Rl
j0040:Rlj0@0VkW]1`2Z`^/20;2ni0<0/;oU1@2^_ND50:bmi`D0Z[gW00<000000?ooo`3oool0@@3o
ool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo02T0oooo0P00
000E0:Vmj0D0ZKgW1@2X^^H50:Rii@D0Y[SV1P2X_>P50;37j`<0[L7X4P2Y_NP90:>HbPD0Y9c=1@2W
RkL50:25]`@0WXRl0P2cVK`50;>D]`<0XHNh0P2lX[l50;ZJ]`80WXNj0`31XkX50:jB^PH0]YVj0P2T
W<d40;NL_0@0YZGE0P2bV/050:Vmi`d0ZKgX00<000000:Vmj02Y_NP0102X_>P509^gk0H0Z/;[1P2`
_nD20:jmi@<0[kkU1@2/_NL50:Zmi`030000003oool0oooo0400oooo000I0?ooo`0:0?oOW01807@0
_ooo0?ooo`3ooml0Ga@001AOa03oool0a5lD000eSbH0oooo0`0000020:Vmj0030000002Y_NP0ZKgX
01<0ZKgX0P2Y_NL30:Vki`D0Z;[V0`2X^ND20:Jgi@D0Y[SV0`2X_>P30:k;kPD0/<O[4P2Y_NP30:BL
c@T0XiS:0P2TW<d30:F:^0D0Yh^g1@2PQKL209j8_0<0/iVl1@2cU;L20:67^0<0_::o1@2jV[L00`2N
QkX0`J>j0<6S^P020<6S^P@0[Y:j0P36ZKd50;JI^PL0]ibl0P2VYMD40;:J`080ZKgW0`2SU<H<0:Vm
j0030000002Y_NP0ZKgX00D0ZKgX1@2K]n`60:C1kPD0/;oU1P2__^D40:bmi`D0Z[gW00<000000?oo
o`3oool02P3oool01@3ookl0M00000000000B9`0gooo0340oooo000I0?ooo`0;0?oOW01807@0_ooo
0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool08P3oool00`2Y_NP000000000000K0:Vmj0H0
ZK_W1@2X^^H50:Jgi@D0Y[SV1P2^bnhD0:Vmj0D0Y9c=2@2SV<X50:F:^0D0Yh^g1@2PQKL50;>I_0D0
/iBg00<0XHNh0;bR_`2lX[l00P2lX[l50;ZJ]`H0`J>j0P2^T[X30<JY_@D0]YVj00<0bZfm0;NL_02g
W;`0102gW;`60;:J`0H0XiC60P2Y_NP30:VfhPL0ZKgX00<000000:Vmj02Y_NP01@2Y_NP50:2ij`D0
Y<7^0`2`_nD30:noiPD0[kkU1@2/_^H50:Zmi`030000003oool0oooo00P0oooo00H0oooO09a80018
W=l0oooo0=nLB000M;la0?ooo`003@3oool00`3ogi`0B00000000003000000030000M02oool0oooo
00<0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0P0?ooo`<0
00006P2Y_NP50:Vli`D0ZK_W2P2V]nD50:c:l0<0[/_^4P2Y_NP50:JUe@D0Y9c=1P2SV<X30::9^PD0
YHZh1@2WRkL30:25]`80/Yk41@2cVK`40;>D]`H0_::o0`2jV[L20<:_a`D0`J>j00<0[Y:j0<JY_@36
ZKd00P36ZKd40;JI^P80bZfm1P2gW;`00`3=[k/0/Y[00;:J`0030;:J`0030<n^^@2SU<H0XiC600<0
XiC61P2Y]^860:Vmj0030000002Y_NP0ZKgX00H0ZKgX1@2P^N/40:C1kPH0[koV0`2__^D30;2oi@D0
[;kV102Z_NL00`000000oooo0?ooo`080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`
0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0okmd000DG`34ool0oooo0?ooS`0e01@0GlCo01h0
oooo0`00000J0:Vmj0<0ZKgW1@2Y_>L50:Nhi@L0Y[OU0`2X_nX50:c:l1<0ZKgX0P2Y]^<50:JUe@@0
Y9c=102SV<X50::9^PD0YHZh1@2WRkL20:25]`<0/Yk41@2cVK`30;>D]`80^jc;1@2lX[l20;ZJ]`<0
`Zo71@31XkX60<JY_@80]YVj103:[Kd40;NL_080cJnk102bV/020<n^^@@0XiC60P33ZKl50:VfhPH0
ZKgX00<000000:Vmj02Y_NP01`2Y_NP40:2ij`D0W;_^1@2__nH60;2oi@<0[;kV0`2]_^H40:Zmi`03
0000003oool0oooo00L0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000I0?oo
o`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l06`3oool3000001/0
ZKgX1P2Y_NL20:Vli`<0Z;[V1@2W^>D40:Jgi@H0Z;oZ1@2/_nP@0:Vmj0D0ZKKS102VYMD40:BLc@D0
WHNk1@2RRKX50:F:^0@0Yh^g1@2bW/@50;>I_080/iBg0`2k[</50;bR_`030;ZJ]`32[lL0`Zo70080
`Zo71031XkX20<Fic`D0aZVm00<0]YVj0<Z]_@3:[Kd00`3:[Kd30;NL_0@0cJnk0P2bV/040<n^^@80
XiC61033ZKl20:VfhP<0ZIk;1@2Y_NP00`000000ZKgX0:Vmj0070:Vmj0D0Y[cY1@2L^nh50:joi`D0
/;oU1P2]_^H50:Zmi`030000003oool0oooo00H0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0
W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3o
a5l0500e08ooo`0I0?ooo`8000007`2Y_NP50:Vmi`H0Z;[V102W^>D60:Jii`<0Z;oZ0P2cbN/50:bo
j100ZKgX1@2Y]^<40:JUe@80Y9c=0P2IPk/409f7^`D0XXVj1@2UR[P20:N;]`<0/:?;1@2bW/@40;>I
_0H0^jc;102lX[l60<:_a`80`J>j0`35^Ll50<JY_@L0bZfm00<0]ibl0<f_^`3=[k/00`3=[k/00`2b
V/00cjji0<n^^@030<n^^@030:>DaP33ZKl0`jVo00<0`jVo1P2YW//40:Vmj0030000002Y_NP0ZKgX
00P0ZKgX1@2V_>T509Vfk0D0[[oW1@2`_nD50:fniPD0Z[gW00<000000?ooo`3oool01P3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol0<03oool001P0oooo00/0okmd0000000007@0_ooo0?oo
o`3ooml0Ga@003F?o`3oool0a5lD000eS`0G0?ooo`<000008P2Y_NP50:Rki`D0Z;[V1@2U]nD60:Ji
i`D0/lW[1@2/_nP@0:Vmj0@0ZKKS102VYMD409V3^`D0WHNk1@2RRKX40:F:^0D0/:?;1@2bW/@20;>I
_0<0^KWJ1@2k[</20;bR_`<0_/3K1@32[lL00`31XkX0aKW?0<Fic`030<Fic`<0aZVm0P38_m460<Z]
_@H0cJnk1P3?[[T60<>Y_`030=Ff^P2YW//0ZIk;00<0ZIk;102Y_NP00`000000ZKgX0:Vmj0090:Vm
j080Y[cY0`2Y_NP509Vfk0@0[[oW1P2`_nD50:fniPD0Z[gW00<000000?ooo`3oool01@3oool01`3o
okl0M01d0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00<0omnL04P0M02oool00P3oool0
1@3oohl0=@000000000055l0a?oo01@0oooo0`0000000`2Y_NP000000:Vmj00Q0:Vmj080ZKcW1@2X
^nL30:RjiP80Y[OU1@2U]nD30:Jii`<0[/c_1@2cbN/D0:Vmj0D0Sg^i102DOkX409V3^`@0WHNk1@2R
RKX20:F:^0<0[JKA1@2`Xl/40;:Na0D0^KWJ1@2k[</50;k0f`D0`Zo71P35^Ll20<JY_@@0b;oA103:
[Kd20<^oc`@0cJnk0P3?_LT50<n^^@030=:i`@33ZKl0`jVo0080`jVo0P3E][X40:VNb`80a:k50`2Y
_NP00`000000ZKgX0:Vmj00?0:Vmj0@0VKK/1@2/_nL30;2oi@<0/<3U1@2]_^H50:Zmi`030000003o
ool0oooo00@0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y_NP00000
0000000U0:Vmj0D0ZKcW1@2X^nL50:Jgi@D0YKOU1P2^c>lD0:Vmj0D0VXJm102?NkT409Ao^P@0VH>k
1@2MQk/40::9^PD0[JKA1@2`Xl/20;:Na0<0/lKX1@2i^MX20;^/b`<0/];`1@2n`=/20<:_a`<0^lkY
1@35^Ll70<Rod@80bZfm0`3;_ll30<f_^`<0ckg9103?[[T20=:i`@<0`jVo103E][X20:VNb`@0a:k5
0P2Y]^800`000000ZKKR0:VfhP0?0:Vmj0D0V[O/1@2/_nL60;30i@@0[KkV1@2Z_NL00`000000oooo
0?ooo`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`00000X0:Vmj0D0ZKcW
1@2W^NH50:Jgi@D0ZKoZ0`2^c>l30:Zmj0l0ZKgX1@2SV<X409Z6_@@0Sg^i102DOkX509V3^`@0WHNk
0P2RRKX30:ZXe@D0[JKA102`Xl/60;?6j0@0^KWJ1P2bd_040;k0f`H0^lkY0P35^Ll30;GCk`H0b;oA
1P3;_ll00`3=[k/0ckg90<nmb@030<nmb@80cjji103B^L420<>Y_`@0eKJj1P34[/D00`3D^Kl0ZKKR
000000030:VfhPl0ZKgX1@2J]n`20:boi`<0ZkkX1@2``>D50:foi`D0Z[gW00<000000?ooo`3oool0
>P3oool00300oooo0P0000000`2Y_NP000000:Vmj00Y0:Vmj0D0Z;_W1@2W^NH50:FhiPD0ZKoZ1P2Z
_NP<0:Vmj0<0ZKKS102SV<X409Z6_@D0Sg^i102DOkX409V3^`@0WHNk1@2ZZ=D50:fVd@80/:?;0`2]
d?850;?6j0D0Wmgl1@2bd_0509kKo0D0^lkY1P2ednl30<Rod@<0]M?_1@3;_ll60<nmb@030<n^^@3B
^L40d[W100<0d[W100<0`jVo0=Ff^P3E][X00`3E][X00`3G_L00a:k50<B^a@020<B^a@80e;Vo0P00
00030:VfhQ00ZKgX102J]n`60:^nj0D0/<3U1@2]_nL50:Zmj0030000003oool0oooo03T0oooo000/
0?ooo`040:Vmj00000000000000002d0ZKgX0P2Y_>L50:Rki`<0YkWV0P2U]nH50:FhiP80ZKoZ102f
bnX40:Zmj0X0ZKgX1P2Y]^<30:>HbPD0VXJm102?NkT409Ao^P@0VH>k1@2VY]H50:ZXe@@0[JKA1P2]
d?8508_Oo@D0Wmgl1P1hf?`409kKo0H0R=So2`2ednl20<^oc`<0^loY1@3?_LT60=:i`@D0eKJj0P3G
_L030<B^a@<0000000<0e;Vo0:f]e`0000000`2][ML?0:Vmj0D0VkO/1@2[_^P60;30i@D0[KoW102Z
_NP00`000000oooo0?ooo`0i0?ooo`00:`3oool2000002h0ZKgX1@2Y_>L50:Rki`D0YKOV102U^>H7
0;K;jPh0ZKgX1@2Y]^<40:>HbP@0VXJm102?NkT409Ao^PD0XZ7D102VY]H50:ZXe@D0Z=Kh0`2]d?84
083PnP@0Rmom1P1Rd_<604_3k`@0Fl_g1@28f?l507kBo`D0]M?_1@2kcnT40<nmb@80a/WM103B^L42
0=32c@<0eKJj0`3G_L03000000@0e;Vo00<0g;nl0000002][ML00`2][ML?0:Vmj0D0VkO/1@2Z_NP5
0;30i@D0[KoW0`2Z_NP20:Znj0030000003oool0oooo03P0oooo000Y0?ooo`800000<@2Y_NP50:Vl
i`D0Y[SV1@2U]nH50:g6k0<0]/_Z4@2Y_NP50:Vfh`<0XiS:102JQ[d408mk^@D0W9WA102RXM@50:JV
eP80ZZSE0`2UfOX50:SFn080P>3j1P1Ue_0705o?m@H0HL[j101<`?@4046jl0@0C;oe101nd_l508;?
o`D0^loY0P3?_LT40<K9g@80d[W10`3@`/d30=Ff^P<0000000<0ekg00<B^a@3D^Kl00`3D^Kl20=bo
_0040:f]e`000000[JgG0:f]e`80_[WD3P2Y_NP609bgk0D0Z[gX1@2``>H40:foi`H0Z[kX00<00000
0?ooo`3oool0=`3oool001d0oooo00D0oono07@00000000004RL0=ooo`070?ooo`800000<P2Y_NP5
0:Nji`D0Y[SV1@2W^nP50:g6k1@0ZKgX102Y]^<30:>HbP@0VXJm1@2ESl/409bId@D0XZ7D102VY]H6
0:GInP80On7g1`1ag?82073Gn@D0ULOh1@20c_l508^im0D0JL?n101:^_L403bblP@0BKWg1022col4
0;_?j@H0a/WM1P3@`/d2000000@0ekg0103D^Kl40=bo_0030:f]e`000000_[WD0080_[WD3`2Y_NP5
09bgk0<0Z[gX0`2Z_NL40;30iPD0[KoW1@2Z_^P00`000000oooo0?ooo`0g0?ooo`00703oool01P3o
oml0W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000;`2Y_NP30:Rli`D0Yk[W0P2V
^>H30:BgiPD0Yk_X1@2`a>T?0:Vmj0D0W978101oL[/308Ej_`@0SHC5102ESl/509bId@@0XZ7D1P2U
fOX208CTmPL0O^?d0P20g_/509o1l@D0ULOh1@2Q^^/508^im0D0T;?^1@1/^O`404Nbn0<0>Zcc0`1A
^?X509C?o0<0a/WM0`2^c_020=32c@<000001@3G_L020=G3b0<0e;Vo103L_k`20;jie0030000002n
^M@0_[WD0100ZKgX102L]n`60:Zmi`80/<3V0`2``NH50:foi`D0Z[kX00<000000?ooo`3oool0=P3o
ool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo0P0000020?ooo`030000
002Y_NP0ZKgX02X0ZKgX1P2X_>L40:Nji`H0Y;OV0P2W^nP30;?<k@D0/<CY2P2Y_NP50:Vmi`@0W978
101oL[/308Ej_`@0SHC51@2ESl/409bId@H0YmKh1@2=j?L408_Xm@@0SN?l0`2U_n`509o1l@D0ZKgX
1@2Q^^/50:Vmj0X0T;?^101Q/o/304:Zm`@0DKSj102Dco`40:k>l0<0000000@0d<;=0<K9g036bM`0
a/WL0`3G_L040=G3b0030=Bi_`3L_k`0g;nl00<0g;nl00@0g/Bo0;jie0000000_[WD0P39`]<?0:Vm
j0D0W;O/1@2Z_NL60;31iPD0[KoW1@2Z_^P00`000000oooo0?ooo`0e0?ooo`00703oool01`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0
ZKgX02/0ZKgX1@2X_>L50:FhiP@0Y;OV1P2cc>d30;34j@`0ZKgX102Y_NL409bAb0@0Og:k0`25N[l5
08f4a@@0UHo;0P2LVM430:O>m0<0YmKh1@2GjoP208_Xm@H0V>Ol1P2U_n`209o1lAL0ZKgX1@2@/nh4
066cn`@0@Z[g0`0mZ?H406NmoP<000000P2^c_060<K9g0030=Nm`03E`lP0eL?800<0eL?81@3L_k`2
0=k4_`80_[WD00@000000<W2d`39`]<0bL;C3`2Y_NP509bgk0D0ZkgW1@2``NH60:foi`@0Z[kX00<0
00000?ooo`3oool0=@3oool001`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo
00<000000?ooo`3oool00`3oool^0:Vmj0D0Yk[W1@2U^>H50:Vmj0D0/lc]3`2Y_NP40:Vmi`@0W978
101oL[/308Ej_`@0SHC5102ESl/60:O>m0<0Un_h102FkOH40:7ZnPD0ZL7Z1@2U_n`O0:Vmj0D0Pjg`
0`1A[?T303jSmP<0000000<0Ikgn08g5nP2=aOX00`2=aOX50<K9g0D0eL?80P3@a]030=bo_0<0g/Bo
0`39`]<010000000bL;C0=39d`3@bM<?0:Vmj0D0VkO/1@2[_NL50;31iPD0[KoW1@2Z_^P00`000000
oooo0?ooo`0d0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool20000
00D0oooo00<000000:Vmj02Y_NP0:02Y_NP30:Rli`D0Yk[W0P2U^>H30:BgiPD0ZKgX1@2Z_^P?0:Vm
j0<0ZKgW102LTLP407mb^`<0QGZo102=Q<D50:G1kP<0Ylkd0`2Rk?T40:7`m@@0XN[j0`2^a^/50:W1
jR@0ZKgX0P23[O030:6jj`80JJSf0`00000203jSmP<0C:_i1@2=aOX20<K9g0<0]/WY0`3E`lP30=36
d0<0g;nl0`3Na;l01@3Oal40bL;C0<W2d`39`]<0000000<0d<WC3`2Y_NP509^gk080ZkgW0`2/_^H5
0;31iPD0[;oW1@2Z_^P00`000000oooo0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0
omnL04P0M02oool01@3oool00`000000oooo0?ooo`050?ooo`030000002Y_NP0ZKgX02D0ZKgX1P2X
_>L40:Nji`H0Y;OV0P2Y_NP30;O<jPD0Z[kX2P2Y_NP50:JUe@80LFbm102LTLP407mb^`<0QGZo1P2N
[n@40:G1kP<0X^ci102Ql?D40:W]n0H0[/K[:02Y_NP40:6jj`<000000P1YZ?H404RRm`<0A:7f102=
aOX60;K9j@030=G3b03@a]00d<K@00<0d<K@00@0g;nl0=k4_`3Na;l0g/Bo0`3Oal400`39`]<0d<WC
000000030=39da00ZKgX102K]n`60:bniP80/<7V0`2``NL50:boi`@0Z[gX00<000000?ooo`3oool0
<`3oool001`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l60?ooo`030000003oool0oooo00L0
oooo:02Y_NP40:Rli`H0Y;SW102T]nH60;O<jP80Z[kX3@2Y_NP40:JUe@<0LFbm101iML8308J6c0@0
Ti_H1P2N[n@40:[YnP@0Z_;e0P2YkOP60;?@k`<0[/K[:P2Y_NP300000080XK[[101YZ?H404RRm`<0
A:7f101`]o/50;K9j@H0d<K@103Na;l30=o7`@<0d<WC00@000000=39d`3Cd=H0dm3F3`2Y_NP509Zg
k0D0[;kV1@2``NL30:boi`<0[;oX102Z_NP00`000000oooo0?ooo`0b0?ooo`007@3oool01@3ookl0
M00000000000B9`0gooo00H0oooo00<000000?ooo`3oool0203ooolX0:Vmj0@0Y[[W1P2T^>L50:Zn
j0@0]lcZ3`2Y_NP40:JUe@<0LFbm101iML8408J6c0@0Ti_H0`2N[n@40:kQn0@0Z_;e0`2al?H30;OO
m0D0/m3_:P2Y_NP2000000H0ZKgX1@23[O0305>SmP<0AYcd101`]o/50:?4l0@0d<K@0P3;amL20=k4
_`@0glO100D0h<_30=39d`3@bM<0d<WC000000030=?@ePl0ZKgX1@2J]n`20:bniP<0[[oV102``NL6
0:boj0@0Z[gX00<000000?ooo`3oool0<P3oool002L0oooo00<000000?ooo`3oool02P3ooolS0:Vm
j0D0Z;cX102V^^L60:Bhi`D0Z[kX4`2Y_NP40:JUe@80LFbm1@1iML8408J6c0@0Ti_H102^hOP40;?a
m@<0/O3f1P2ggo@[0:Vmj0<000002@2Y_NP509Jfk@<0G:;e0`16W?@405nZn0D0XlC`0P3@a]040<_7
e`@0glO10`3Pbl<20=?@eP030000003Cd=H0dm3F0080dMOM3`2Y_NP409Zgk0D0[[oV1@2_`NL50:bo
j0D0Z[gX00<000000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool02`3ooolS0:Vmj0D0
Z;cX102V^^L60:Bhi`80Z[kX0`2gc>XB0:Vmj0@0YZGE0`1aK;d407Ue`P@0QXK<1P2[d?<40;?am@<0
^?;d102kjo@/0:Vmj0<000003@2Y_NP509Jfk@<0G:;e0`1<V_<405nZn0@0XlC`1@3;amL20<G7f`<0
glO10`3Pbl<0103Rc/@0dm3F0=?@eP0000040=7Gg@l0ZKgX102J/nT20:joiP<0[l3V1@2_`NL50:^n
j0D0Z[gX00<000000?ooo`3oool0<03oool002L0oooo00<000000?ooo`3oool0303ooolS0:Vmj0@0
Z;cX2P2T^>L60;O<jPl0ZKgX0`28S]<306QY`@<0LFbm101iML8509nfj0<0Zm3c102hkOD30;Sbm0@0
^n_d0`2banXX0:Vmj0<000004@2Y_NP409Jfk@@0G:;e0`1<V_<405VQm@@0Tk_b0`3;amL40<G7f`04
0=o7`@3Pbl<0h<_30>3;``<0h/k400<0dm3F0=7Gg@0000000`3Aemd?0:Vmj0@0V[?Y1P2_`>H20:o1
i`<0[/7W1@2[_^P40:Zmj0030000003oool0oooo0300oooo000W0?ooo`8000003P3ooolS0:Vmj0D0
Y[[W102T^>L60:^nj0<0]lcZ402Y_NP308R>d`@0J6W10P1hO</508fHf@D0WkKX1@2hkOD30;kblP<0
`Nga1P2banXT0:Vmj0<00000502Y_NP50:6jj`@0I:7c0`1CV?4405VQm@@0Tk_b1P35am/30>3;``@0
h/k40`3Aemd010000000b=kY0<SNj@38g^T>0:Vmj0D0W[;W1@2_`>H60:k1i`D0ZkkX102Z_NP00`00
0000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?oooah0ZKgX1@2X_>P50:Jji`@0
Y;SW1P2[_^PC0:Vmj080R8kC101XJL4307Qlb`D0SISI0P2O]^P50;SQm0@0__;b0P31kO430<7Pk`D0
//OZ8@2Y_NP3000001P0ZKgX102Q^^/406BQl`@0DiSa0`1HVo8508ZdlP@0aLOK0P32a]d20>3;``@0
h/k40P3Ud/@00`38g^T000000<SNj@020<SNj@X0ZKgX1@2V_>T509jbi`D0/<;W1@2^`NL50:^nj0<0
Z[gX0P2Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0?0?oooah0ZKgX
1@2X_>P90:Bhi`<0ZkkX0`2hc>TB0:Vmj0<0R8kC101XJL4307Qlb`@0SISI1@2hhO@40<;_l@80`Nga
1P31h>lR0:Vmj0<00000702Y_NP40:Jlj@@0JIo`0`1IU^l405RKlPD0R[Cb0P35am/30<;6g@030>3;
``3Rc/@0h/k40080h/k40`3Ud/@0103Yf<@0b=kY00000038g^T20;78j`X0ZKgX1@2V_>T209jbi`<0
Y;OV1@2``^L50:g0j0@0ZkkX1@2Y_NP00`000000oooo0?ooo`0^0?ooo`009`3oool200000140oooo
00<000000:Vmj02Y_NP06`2Y_NP30:Rlj080Y[_X2@2T^>L60;S<j@h0ZKgX101fQ=@00`1OJ<@0R8kC
06QY`@0306QY`@@0N7c;0P2=V=T40:g:k`@0`^oa0`36k^l30<KXkP<0`N3_802Y_NP300000200ZKgX
102V_>T406VOl0<0FIK_101LV>l408ZdlPD0`/KM103Rc/@30>GBa0<0jMS400<0/LS[0000002ab>/0
0P2ab>/:0:Vmj0@0Y[cY1P2T]nH50;32i`@0[L3X1@2Z_^P50:Vmj0030000003oool0oooo02d0oooo
000V0?ooo`8000004`3oool00`000000ZKgX0:Vmj00K0:Vmj0D0Y[_X102T^>L50:Zmi`<0^<cY0`2Z
_^P>0:Vmj0<0MXCD0P1OJ<@406QY`@@0N7c;1@2]b^l30<7Vl0@0a^k_1@36j>hO0:Vmj0<000008`2Y
_NP50:Jlj@<0KIg]101IU^l405bHk`@0Qjo`1@32a]d20>;>a0<0iM;4103Yf<@00`3]g/80/LS[0000
00020;78j`X0ZKgX1@2P^N/50:BgiPD0/<;W0P2]`>P30:c0j0D0Z[kX1@2Y_NP00`000000oooo0?oo
o`0/0?ooo`002@3oool02P3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3OW4P50000
000307Boo`3oool0gia80080000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`0C0?oo
o`030000002Y_NP0ZKgX01H0ZKgX1@2X_>P50:Jkj0D0XkOW102Z_NL60:Znj0h0ZKgX0P1fQ=@305mX
a0@0NH?A102FYn830:g:k`<0`NK`103:kNd40<KXkP<0_mO[702Y_NP2000002H0ZKgX1P2V_>T306fM
k@<0GYC/101LV>l508N_l0D0`/KM103Ud/@30>WHa080kMk200<0ZKgX0000002Y_NP0302Y_NP50:2i
j`D0Z[cV102``^L60:c0j0D0Z[kX102Y_NP00`000000oooo0?ooo`0:0?ooo`050=nLB00000000000
0000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW018
0000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3o
ool0503oool00`000000ZKgX0:Vmj00G0:Vmj0@0Z;cX1@2T^NP50:>gi`D0^<SV102Z_^P;0:Vmj0<0
L8cN0`1fQ=@305mXa0<0NH?A1@2FYn840<7Vl0<0b^g]103<jN/60;oGjaP0ZKgX0`00000Y0:Vmj0D0
Y[cY101]WNd305jDk0@0HIK/1@28[>d30<;6g@80aLOK0P3Ud/@30>WHa0<0kMk200<0jn[;0:Vmj000
00003@2Y_NP509^fjP@0Z[cV1@2``^P50:c0j0H0Z[kX102Y_NP00`000000oooo0?ooo`080?ooo`07
0?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0
omnL04P0M02oool0103oool00`3ogi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00
000F0?oooaX0ZKgX102W^nP50:Bij080XkOW0`2W^^L50;S8iPh0ZKgX101`S=h00`1DI<D0MXCD05mX
a00305mXa0<0NH?A0P2FYn840;OBkP<0b^g]103<jN/40<[SjAT0ZKgX0`00000]0:Vmj0D0XK[[0`1`
V^X405jDk0@0HIK/1028[>d20<;6g@@0aLOK103Yf<@20>gN`P<0jn[;00<0ZKgX0000002Y_NP0302Y
_NP409^fjP80Z[cV0`2^`>L50;32j0D0ZkoX1@2Z_^P50:Vmj0030000003oool0oooo00`0oooo00<0
_g@007Boo`3oool06`3oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo
00<0oono07@00018W=l01`3oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo01L0oooo
6@2Y_NP40:Nkj0@0Y;WX1P2W^^L20;S8iP<0/<CY3P2Y_NP3072<gP80E6C5101OJ<@307V3d@D0]m;^
0`38iN`30<oXj0@0b^?Y0`2oen/E0:Vmj0<00000<@2Y_NP50:6jj`<0L9[Z101ST^T306NEj@@0R:c]
1@35am/20<c<f@80jMS40`3]g/820>_Zb`80fOSO00<000000:Vmj02Y_NP02`2Y_NP409^fjPH0[/3W
1@2^`^P50:^oj0D0Z[gX102Y_NP00`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo
00080?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`0;0?oog`2LB000B9cO0?oo
o`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01P3oool00`000000oooo0?ooo`0H0?oooaT0ZKgX
102W^nP50:>hj0@0Yk[W1P2`a>T=0:Vmj0@0L8cN0P1DI<D407N5e@D0W;3U1038iN`30<oXj0<0cnCV
1P2oen/A0:Vmj0<00000=@2Y_NP40:6jj`@0L9[Z101ST^T306NEj@@0SZcZ0`35am/40<c<f@<0kMk2
0P3[j//40=Whg`030000002Y_NP0ZKgX00P0ZKgX0`2X_>P409b_i@<0[/3W0`2``nP50:k2j0D0ZkkX
102Z_NP50:Vmj0030000003oool0oooo00H0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo
01`0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`070?ooo`050?oo_`1d04P0
W=oo0?oo_`1d00000`0000000`1d_ol0oooo0?ooo`040?ooo`8000006`3ooolH0:Vmj0D0YK[X1@2S
^>P50;;2iP<0/<CY302Y_NP307b/lP0304=Ka@1`S=h0L8cN0080E6C51@1gQMD209b`i@@0_=;[103?
j>P30<oTiP<0cMkU102oen/>0:Vmj0<00000>@2Y_NP409Jfk@@0LIOW0`1XT>H406NEj@@0SZcZ1@3<
c=T30=KBeP80jn[;1@3In=l00`2Y_NP000000:Vmj0060:Vmj0H0Z;cX102L[nD60;33j080[/;X0`2]
`NP40:^nj0X0ZKgX00<000000?ooo`3oool01@3oool00`3ookl0M000000000020000000307Boo`3o
ool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`030?no
M000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo01/0
oooo4`2Y_NP50:Rlj0D0YK[X1@2T^NL50;;2iPl0ZKgX0P1l[?8304=Ka@<0E6C5101gQMD50;cBj`<0
c>3W103?i>H50<gNi@h0ZKgX0`00000m0:Vmj0@0U[K]101aUnL306R@iP<0KiKW1@2G[nL30<c<f@<0
e];F0P3Qg=420=Whg`D0//S[00<0ZKgX0000002Y_NP01P2Y_NP50:Rlj0D0Y[SV1@2``nP50:g1j080
ZkkX0`2Z_^P90:Vmj0030000003oool0oooo00D0oooo00<0oooO09a8B02Lgol0803oool000P0oooo
00H0oooO09a8001d_ol0oooo0=nLB000M;l40?ooo`0:0?oo_`1d04P0W=oo0?ooo`3ogi`0B01809cO
o`3oool0_g@007Boo`T0oooo00<000000?ooo`3oool0703ooolD0:Vmj0@0Z;cX1@2S^NP50:Bii`D0
]/[Y3P2Y_NP307b/lP<0@e_50P1^PMD509f`i@<0_=;[0`3<h>L40=7Ri0@0cMkU0`37f>H:0:Vmj0<0
0000@02Y_NP409Jfk@@0LIOW101XT>H306nFi`D0UjoW103Fd]H30>7Ld@80jnO;00<0l?730;;8j`2b
b>/00`2bb>/00`000000ZKgX0:Vmj0060:Vmj0D0W[S[1@2V^>H50;33j0@0[L7X1P2Z_^P90:Vmj003
0000003oool0oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0oono07@000000000
04RL0=ooo`050?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P00000000000000000
001d0;ooo`D0oooo00<000000?ooo`3oool07@3ooolD0:Vmj0@0Y[_X1@2S^NP20:Bii`<0[;gV1@2f
b^T>0:Vmj00302Y>``1l[?80@e_50080@e_50`1^PMD509f`i@@0c>3W103Ah^@30=;OhPH0amSV1`2Y
_NP2000004@0ZKgX1027YnX407>Ch`<0KHoR101_U^L209N_i`<0Y;GU0P3Fd]H30>7Ld@80jnO;0`3`
lL<20;;8j`<0ZKgX00<000000:Vmj02Y_NP01P2Y_NP509jhj`80Y[SV0`2]_nL40;33j0D0[;oX1@2Z
_^P90:Vmj0030000003oool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`00
9@3oool2000001l0oooo4@2Y_NP30:Rlj0@0Y[_X102S^NP60:bmiPD0Z[gX3@2Y_NP202Y>``@0@e_5
0`1^PMD209f`i@D0^lgX103Ah^@30=;OhP80d=[P0`37f>H30;;7jP<0ZKgX0`0000170:Vmj0@0QjOZ
101cTn<306f?hP<0NIST1P2T]ND40>7Ld@030>_Wb`3`lL<0l?730080l?731P2Y_NP00`000000ZKgX
0:Vmj0060:Vmj0@0W[S[1@2]_nL20;33j0<0[/;X1@2/_nP50:Zmj0T0ZKgX00<000000?ooo`3oool0
9P3oool002D0oooo00<000000?ooo`3oool07`3oool>0:Vmj0H0Z;cX102V^nP50::hj0<0[;gV0P2g
a><50:Zmj0d0ZKgX0P0ZC/<00`1KM=80@e_504=Ka@0306j1e@H0^lgX0`3;fN@40=;OhP@0d=[P1@2b
anX3000004H0ZKgX1@2Q^^/307jFh0@0Li?S101]Sn8307VHi0<0Y;GU0`2d`><20>7Ld@80jnO;0`3`
lL<20=Cod@D0ZKgX00<000000:Vmj02Y_NP01`2Y_NP409^]h`@0[KoW1P2^`^P50:^nj0@0Z[gX2P2Y
_NP00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P0?ooo`l0ZKgX102X_>P5
0:Bjj@D0X[SX1@2ga><30:Zmj0`0ZKgX0P0gP>L302Y>``80FgCB1@2EZ><30;_=j0<0bmWT0`3Afn05
0=3Jh080cMCO00D0//OZ00000000000000000;;7jP190:Vmj0@0XK[[101nU^0407B@g`<0LhoO101i
V>@60;C0h`80jnO;0`3`lL<30=Cod@H0ZKgX00<000000:Vmj02Y_NP01`2Y_NP309^]h`D0/<?X0`2^
`^P30:g1j0@0ZkkX3P2Y_NP00`000000oooo0?ooo`0U0?ooo`00903oool2000002<0oooo3`2Y_NP5
0:Nlj0@0Y;[Y1@2U^^L50;O4h`l0ZKgX0P0gP>L00`0hG/`0:Tk305]ddP0205]ddPD0UJSS103;fN@3
0=7Kh080dmWM0`3@f^00103=e=l0000000000000001>0:Vmj0@0XK[[101nU^0307B@g`@0LhoO1026
W^<40;C0h`80b<oP0P3`lL<00`3Dom40Z[kX0:Znj0030:Znj0H0ZKgX00<000000:Vmj02Y_NP01P2Y
_NP40:NiiPD0/<?X1P2]`NP20:^nj080Z[kX3P2Y_NP00`000000oooo0?ooo`0T0?ooo`00903oool0
0`000000oooo0?ooo`0S0?ooo`l0ZKgX1@2W_>P40::ij@D0YK[W1@2eb>P>0:Vmj080=h3W0P0hG/`0
100ZC/<0FgCB05]ddP1KM=8209FXh`@0]<CU103Afn040=?Ig@<000000P3=e=l30<G?hT`0ZKgX102Q
^^/407jFh0@0M93O101cSml408JNh`80]<3S0`38cn020=cSfP030>Wdc@3Xnk/0Z[kX00@0Z[kX1P2Y
_NP010000000ZKgX0:Vmj02Y_NP509jbiP@0YkWV1@2_a>T50:g1j0D0Z[kX3P2Y_NP00`000000oooo
0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`l0ZKgX1@2V^nT40::ij@<0YK[W0`2]
_NH40;G8j0T0ZKgX1@2P^^/203N0i`80>5k<0`1KM=850;C4i@80a]3R0P3Afn020=?Ig@<000000`3B
eM/60<G?hT`0ZKgX102;W^0407jBg0<0N8kL101cSml408JNh`@0b<oP0P3LhmX0103Ym<d0j?^k0>Sk
^`3Xnk/:0:Vmj0030000002Y_NP0ZKgX0080ZKgX102N/^H20:NiiP<0[/7X1@2_a>T50:^oj0@0Z[kX
3P2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool2000002H0oooo3@2Y_NP20:Rmj0D0Y[_Y102R
^NT60:fmiP@0[;oX2P2Y_NP30:2jj`0300M1`@0gP>L0>5k<0080>5k<0`21V>030;C4i@@0a]3R0`00
00000`3CfMd0d]GK0=;Ef`020=;Ef`80d=3J0`35cn830;[9iT`0ZKgX102;W^0307jBg0@0N8kL101l
Tmh409NZh`80b<oP0P3LhmX20>Wdc@80j?^k0P38j>d:0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0W[;V
1P2^`NP50:k2j@@0ZkoX1@2Z_NP>0:Vmj0030000003oool0oooo0280oooo000S0?ooo`800000:03o
ool:0:Vmj0D0Z;gX102V^nT50::ij@<0[KgV0`2f`^<40:boj0X0ZKgX0`2P^^/00`07@L40>5k<03QN
c00203QNc0<0PISP1036d>82000000<0cm?M103BeM/40=3@fPH0^/WVB`2Y_NP408^Nh0@0OY;L101h
S]`407bCgP@0Uj[S0P3LhmX20>Wdc@80j?^k1038j>d:0:Vmj0030000002Y_NP0ZKgX00D0XK;T0`2^
`NP30:o4j@@0[/;Y1@2Z_^P50:Zmj0h0ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono
07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo
00L0oooo00<000000?ooo`3oool0:03oool90:Vmj0D0Z;gX1@2T^^T40::ij@H0]/;S0P2/_nP<0:Vm
j080?hk^0P07@L4305Ulf`@0XkCT0`0000040<oCg@80dM;J0P3BeM/40=3@fP80c/cH1@2jbNI80:Vm
j0@0UJ?N1025TmT307j>f@@0N8kL101lTmh50:jmi080jOC=00<0j?^k0<SXk@38j>d01038j>d90:Vm
j080Xk[Y00<000000:>jj@2S^^T01@2Q/^@50:o4j@80[/;Y0`2/`>P50:Znj180ZKgX00<000000?oo
o`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`070?noM000B9`0
gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo2@2Y_NP50:Nlj0D0Y;[Y
102T^NP50;K2h`l0ZKgX0P0oS^h00`0FDL/01d7105Ulf`0205Ulf`<000000P2S]>@40<oCg@@0dM;J
103@d=X40<k<f0D0//?WB02Y_NP409FSgP<0QI?I101nS]T407f?fP@0RIcO0`2^_N@20<WIi@80h?KI
0P3LoKT>0:Vmj0030:>jj@000000Xk[Y0080Xk[Y1@2[_nP40:o4j@H0[<3X1@2Z_NPB0:Vmj0800000
8@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3o
ool01@3oool2000002`0oooo2P2Y_NP40:Nlj0D0X[[Y102T^NP50;O4i0l0ZKgX00<0?hk^01IAb`0F
DL/00`0000000`1IO=/0XkCT0:>di0040;[4hPD0dM;J0`3BcmL50<k<f080c<SF1@2b`nM70:Vmj0@0
UJ?N1025TmT407j>f@@0OHoJ0`29W=l20:jmi080bMWU0P3Pm]T20=cm^@80d_WT3P2Y_NP00`2L[>80
000009b/hP0209b/hP@0ZkoX1@2^`nT30:c0j0<0ZkkX102Z_NPC0:Vmj0030000003oool0oooo01l0
oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`080?ooo`030;md001d_ol0oooo
00D0oooo00<000000?ooo`3oool0;03oool:0:Vmj0@0Y[cY1@2R^^T50:Rki`@0]lCT3P2Y_NP30000
00805U7;0P1nVn@50;[4hP80aL[M0`3Ad]X40=;?e`040=7<e@3>c=P0c/cH0<k<f0@0c<SF1@2]_^I2
0:Vmj0D0UYgH102;TmH308F?e@@0OXkI101mSmX308VLg`<0bMWU0`3Pm]T00`3LoKT0d_WT0=;ii002
0=;ii0h0ZKgX00<0W:cR0000002L[>800P2L[>840:o4j@D0[/?Y1@2[_^P40:Zmj1<0ZKgX00<00000
0?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00L0
omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3oool50:Vmj0D0
Z;gX102V_>T50:6ijPD0Z;_W1@2caNL90:Vmj0<0000000<0ZKgX000o_`0FDL/00P0FDL/307jKi0<0
^/CR1035b]d50=;?e`<0dLcE1@3<b=H20<[4e0D0[KkV?@2Y_NP50:VfhP@0UYgH102;TmH408F?e@@0
PXkG1026UM/409j^h`<0h?KI0P3BnN@C0:Vmj0030000002L[>80ZKcW0080ZKcW102_a>T50:c1j@@0
ZkkX602Y_NP00`000000oooo0?ooo`0N0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol00`3oool00`3ookl0M000000000020000000307Boo`3oool0oooo00D0oooo00<000000?oo
o`3oool0;P3oool50:Vmj0D0Z;gX102U^nT50:6ijP80Z;_W0`2__^D50;?5i`D0ZKgX0`0000000`2Y
_NP0X;[[0:2jj`020:2jj`04000R[@0aJ]T05U7;01IAb`<0OY_T1@35b]d30<_;f@80d/oG103Ac=D2
0<o8d`80c<SF103:a=@50:fjhcd0ZKgX1@2Y]^8409JMf0@0Ri?F0`25SmD408:>e`@0QYGK0P2N[^<4
0;_?j@040=Ohh@3:nK40d_WT0=;ii180ZKgX00<0ZKcW0000002Y_>L00P2Y_>L50:k4j@@0[<7Y1@2Z
_^PH0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`030?ooo`030?oog`2LB4P0W=oo00T0oooo0P00000a0?ooo`D0ZKgX1@2X_NP40:Fkj@@0XKWZ
1P2__^D50:g1j0040:Vmj00000000000000000D0ZKgX102P^^/00`008Zd0<F[I035Zf@0509^`iP80
aL[M1@3;bmT40=7<e@@0clSC103:a=@20<S0dPD0[K[S?@2Y_NP40:VfhP@0UYgH102;TmH408F?e@<0
PXkG1026UM/50;_?j@030=Ohh@3:nK40d_WT00<0d_WT3P2Y_NP409f/hP030:Vli`000000[/CZ0080
[/CZ1@2^a>T40:^oj0D0Z[kX5`2Y_NP00`000000oooo0?ooo`0M0?ooo`00303oool01P3ooml0W4P0
07Boo`3oool0gia8001d_`D0oooo00<0_g@007Boo`3oool0203oool00`000000oooo0?ooo`0a0?oo
o`D0ZKgX1@2X_NP40:Fkj@D0XKWZ0`2__^D20;G0hP<0[L7X0P0000090:Vmj0<0X;[[0P008Zd2035Z
f@D0Vk3V1@3;bmT20<g9eP80dLcE103?b=<20<k4d@80b/CD1038`=820:fjh`<0/;SO?02Y_NP509FF
dP@0T9;B102;Sm8308N>d`<0PXkG1@2HYn430;_?j@030=Ohh@3:nK40d_WT00@0d_WT3`2Y_NP309f/
hP80[/CZ00@000000:k4jP2^a>X0[/CZ0P2^a>T30:c1j@@0ZkoX702Y_NP00`000000oooo0?ooo`0L
0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia800000000000000000000
M02oool50?ooo`030000003oool0oooo0380oooo1@2Y_NP40:Rmj0D0Y;_Y1@2Q^NX40;G0hP<00000
302Y_NP307Z/l`04000U[P008Zd0CXCU04j4i@D0[[cT0`3;bmT40<g9eP@0clSC103>a=450<S0dPH0
/;SO=P2Y_NP30:R_g0<0XJ;F102EU]84092BdP@0RhoB1027S]<308VDf0D0V:OQ0P3Gn>400`3:nK40
d_WT0=;ii00C0:Vmj0@0Z;cW00<0[/CZ0000002^a>X00P2^a>X50:c1j@D0Z[kX702Y_NP00`000000
oooo0?ooo`0K0?ooo`008P3oool2000003@0oooo1@2Y_NP50:Nlj0@0Y;_Y1@2S^^T300000080]l7Q
3P2Y_NP307Z/l`04000U[P008Zd0CXCU04j4i@D0[[cT1@3=bMH20<k7d`80clSC103>a=420<c1c`<0
b<3B0`37_=040;2hgc@0ZKgX1@2X[m`40:6ReP@0UIKB102@T]8408^?dP<0QhkC1029U=P209RWh@<0
]<g/0P3=o>830<SXk@h0ZKgX1@2M[>440:Rli`030:k4jP000000[/CZ0080[/CZ0P2/`NT30:^oj0D0
Z[kX6`2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`D0ZKgX
1@2W_>P40:>kjP050:>jj@00000000000000002S^^T01@2g`N4>0:Vmj0<0EI[b00@002F^04j4i@1>
Q>D0CXCU0P2^_>@30;W1h0<0cLWF103>am<40<k4d@@0c<7?00<0b<3B0<Nld037_=000`37_=040;Jf
fBl0ZKgX1@2Y]^840:R_g0@0XJ;F102EU]84092BdP@0RhoB0`27S]<408VDf0@0]<g/0P3=o>850<SX
k@T0ZKgX1@2Y_NL409f/h@H0[/CZ00<000000:k4jP2^a>X01P2[_nP20:Znj1h0ZKgX00<000000?oo
o`3oool06P3oool00280oooo00<000000?ooo`3oool0=@3oool00`000000ZKgX0:Vmj0020:Vmj0D0
YkcY00@0Xk_Z00000000000000001@2T^nT50;O1h@h0ZKgX0`1EV_800`009Jh0IYS/06JHk0060;W1
h0D0c/OC0P3=a=820<k4d@D0c<7?1@37_=020<JicP@0][KI1@2Y]^8V0:Vmj0@0ZK[U1@2Y]^830:R_
g0D0V9C>102DT/h408n@c`@0SI3A0`2=UMH509RWh0<0cOcR0P00000>0:Vmj0@0ZKgW1@2Y_NP50:k4
jP040:c1j@000000[<7Y0:c1j@D0ZkoX802Y_NP00`000000oooo0?ooo`0<0?ooo`030?oOW01807@0
_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?ooo`008P3oool00`000000oooo0?ooo`0g
0?ooo`D0ZKgX00@0YkcY0000000000000000102R^^X50:Bkj@D0]l7R3@2Y_NP405FJlP03000U[P1V
V>`0IYS/00<0^L7P0`2n`md30<k7d`@0cLCB1@3<`Ll20<^mc@<0akc@1036^Lh20;Jff@80_KCA1@2Y
]^8Q0:Vmj0T0ZK[U102Y]^8409bGcP@0V9C>102DT/h408n@c`@0SI3A102=UMH209RWh0@0]=Ga00@0
00000:Znj02Z_^P0Z[kX3P2Y_NP409f/h@D0ZKgX1@2^a>X010000000[<7Y0:c1j@2/`NT50:Znj200
ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0oooo
000Q0?ooo`800000>P3oool20:Vmj0<00000102V_>T40::jjP<0Y;_Y0P2V_>P50;O1hPh0ZKgX0`0n
S^h306JHk0H0_/?M1@3=a=820<c1d0<0c<7?103;_Ld60<JicPD0_KCA1@2^[MLL0:Vmj0D0ZKKR102Y
^^D50:>Kc@@0WiW>0`2LUlh509RDcP@0U9;>102?T<l308f@d@@0SIGF1@2deO460:Znj0T0ZKgX1@2Y
]n<409f/h@80ZKgX0`2^aN/40:k4jP030:^oj0000000ZkoX0080ZkoX102Z_^PQ0:Vmj0030000003o
ool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`03
0?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<00000102Y_NP40:Jlj@@0X[[Z1@2V_>P20;O1
hP<0]/7R3P2Y_NP303j>kP@0MZG`0`2n`md20<33g0<0cLCB103<`M050<^mc@80bK[<1036^Lh20<Ff
b`<0_KCA0P31//`50:j]e`@0Z:_I5P2Y_NP20:R_g0D0ZKKR0P2Y^^D20:FLc0@0Xi_=102OVLh409bG
cP@0V9C>102DT/h408n@c`<0SI3A1@2M[^@30;CEl@80dooA1@2Z_^P:0:Vmj0@0ZKOS102M[>450:k5
j`D0[<7Y00<0ZkoX0000002[_nP00P2[_nPT0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0
M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo
0?ooo`0f0?ooo`8000000`3oool50:Vmj0@0Y[cY102Q^^/40:Jlj0H0]/7R3P2Y_NP203j>kP03000U
Y@1fYO00MZG`0080MZG`1@30`m`50<c1d080bko?0`3;_Ld40<Vjc080a[W>1035]//00`2m]=40`K;<
0<6bc0020<6bc080[ZgG0`2j[/d90:R[f@D0ZKgX102Y]^850:Vmj0D0Z:oL102Y]^840:FLc0D0Xi_=
102OVLh309bGcP@0V9C>1@2DTLh409:Cd@<0Ti_H1@2M[^@00`2gj_H0dooA0=?od@020=?od@h0ZKgX
102Y]n<50:Zoj@<0[/G[0P2]`nX50:c1j@030000002Z_^P0Z[kX0080Z[kX902Y_NP00`000000oooo
0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol00`3o
ool00240oooo0P00000d0?ooo`<000001P3oool50:Vmj0@0Y[cY102Q^^/50:Rlj0<0]/7R0P2f`>8>
0:Vmj080?Xk^00<001VB07b]l`1l[O<00P1l[O<60<33g080c<7@103;_ll00`3;_Ld0bK[<0<Vjc003
0<Vjc0H0aKK;1@31//`60;Z^c@80Z:_I0P2dZLd50:R[f@D0YjGD102Y]^850:NUe0@0Z:oL1@2XWL/4
0:FLc0@0Xi_=102OVLh409^Cb`@0Ui;<102DTLh409:Cd@@0Ti_H102gj_H00`3Com40ZKgX0:Vmj00@
0:Vmj0D0X[;T1@2Z_nT50:g3jPD0Z[kX00@000000:Znj02Z_^P0Z[kX9@2Y_NP00`000000oooo0?oo
o`080?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool0
0240oooo00<000000?ooo`3oool0<03oool3000000T0oooo1P2Y_NP40:Jlj@@0XK_[1@2X_>P50;K0
hPh0ZKgX0P1EV_800`006I80O:gc07b]l`0207b]l`H0`<?L1@3;_ll50<Vjc080b;S;1035]//20<Bc
b@<0`K;<0P30[lT50;Z^c@D0]:W=0P2XZmT30;>Vb`@0YjGD1@2[XLd50:NUe0@0Zik:102XWL/40:FL
c0D0XYO9102NULX309^Cb`@0Ui;<1@2DTLh409:Cd@80Ti_H0`2U`^h0102MmM/0//S[0;;8j`2bb>/>
0:Vmj0@0Y;3Q1@2R/^@50:k5j`80[L?Z0`2[`>T40:Znj0030:Vmj0000000ZKgX02H0ZKgX00<00000
0?ooo`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0
oooo0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0
oooo02d0oooo0`00000>0?ooo`@0ZKgX1@2U_>T40:6kj`D0ZKgX0`2f`>820;Joh@h0ZKgX0`1EV_84
07RamP@0`<?L0P2n`mh30<^oc`80bKk@0`39^/`40<Rhb`80aKK;1034/lT01031//`0`:o90<2_b@30
[lT40;Z^c@80_:_9102dZLd60;>Vb`80YjGD0P2cXlT50:^Qc@80YjGD0`2]WlP30:^NbPD0Z9g;0P2U
W<`20:BHb0@0XYO9102NULX409^Cb`@0Ui;<102DTLh409:Cd@@0YL;^00<0WOGK0;;8j`2bb>/00`2b
b>/90:Vmj0D0ZKgW102T/>450:c3j`@0[/G[1P2[`>T40:Zmj0030:Vmj0000000ZKgX02H0ZKgX00<0
00000?ooo`3oool01P3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P0
07Bo00@0oooo00030?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cO
o`030?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0
oooo0`00000B0?ooo`@0Z;gX1@2U_>T40:6kj`D0ZKgX1@2f_n4>0:Vmj0<0NZcc101h/OH20<33g0@0
_/?N00<0bko?0<Vnd039_]000P39_]060<Rhb`H0a;?91@30[lT20;Z^c@@0_:_90P2dZLd20;VXb0D0
/jK;102cXlT50:^Qc@D0[Io8102[W/X40:RMb`@0Y9S81@2RUlT409jEbP<0Vi?;102GT/`509VMeP@0
VjWO0P2U`^h30<cnh0h0ZKgX102Y_NL50:Jji`@0[<?[1@2]`nX30:_0j@<0Z[kX102Z_NP00`000000
ZKgX0:Vmj00Q0:Vmj0<0000000<0oooo0000003oool0203oool00`3ogi`0B01d0;ooo`020?ooo`05
0?oo_`1d000000000018W03Oool0103oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`800000:@3oool3
000001H0oooo102X_NP50:Flj@@0XK_[1@2Y_NP60;Joh@d0ZKgX102P^^/206J_nPH0_/?N1039_]02
0<JndP@0b;S;0P36]l`40<Bcb@80`k;91030[lT60;b[b@@0^JS8102cY//20;JTa`@0/j?90P2[XLd3
0;2Oa`@0[Io8102[W/X50:NJb0@0Y9S8102RUlT409jEbP@0W9K=102IV=4509VMeP<0VjWO00<0ZNOj
0<cnh02Y_NP04@2Y_NP409n/h0D0Y[[W102]aN/50:g3jPD0Z[kX0P2Z_NP30:Vmj0030000002Y_NP0
ZKgX01`0ZKgX0`0000050?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo
0?ooo`3ookl0M01809cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103o
ool00`000000oooo0?ooo`0U0?ooo`<000006P3oool50:Rmj0@0YKcY1@2Q^n`40:Vmj0H0][oQ3@2Y
_NP40:2jj`80IZoj0`2n`mh30;W5h`80bKk@1036_]820<Rhb`@0a[O<0P34/lT40<>bb@80`:o90P2o
[LP40;b[b@80_:W7102iZ<P20;>Vb`<0]ZC7102cXlT50;2Oa`@0[Io81@2ZVlL40:NJb0@0Y9S8102R
UlT509jFb`<0W9K=1@2IV=4409VMeP<0ZNOj402Y_NP50:Vch0@0WjcP0P2V^^L30:g5k0@0[LG[1@2[
_nT40:Znj0H0ZKgX00<000000:Vmj02Y_NP0602Y_NP3000000P0oooo00<000000?ooo`3oool05@3o
ool000<0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02Lgol0
0P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R0?oo
o`<000007P3oool50:Rmj0@0YKcZ1@2Q^n`40:Rmj@<0][oQ0`2g_n4A0:Vmj080>:3d1P2iaN<50<Jn
dPH0a[O<1P33//T50;n]b080_:_90`2lZLL40;VXb0H0]ZC70P2cXlT20;>QaPD0/9o70P2]WlP20:fM
aP@0ZY_71@2WV/P30:BHb0D0XYO:102NU//409bFc@@0VISA1@2Ub_<00`2ab>/0ZKgX0:Vmj00;0:Vm
j0D0ZK_V102Y/n0409n/h0D0[LG/1@2/`NT40:^oj@/0ZKgX00<000000:Vmj02Y_NP04`2Y_NP40000
00`0oooo00<000000?ooo`3oool0503oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00H0oooo00H0gia8001d_`3oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo
00<000000?ooo`3oool07`3oool300000280oooo1@2X_NP40:FljPD0XK_/102X_NT60;Noh@80ZKgX
0P2Y^^D=0:Vmj080>:3d0`2iaN<30:o9k@<0a[kB0P33`MT40<Jgc080aKW?1033//T20<>cb`@0_jg8
1P2lZLL20;VXb080^JK61@2fY<L40;>QaPD0/9o7102]WLH50:ZKa`@0Yi[8102UVLT40::GbP@0WYK;
102LU/d50::fi`<0YL[c0`2ab>/=0:Vmj0D0ZK_V0`2Y/n060:[1jP@0[L?[1@2/`NT40:Znj0X0ZKgX
00<000000:Vmj02Y_NP03`2Y_NP0103oool0000000000000000@0?ooo`030000003oool0oooo01@0
oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo
0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2000002H0oooo00<000000:Rmj02X_NP00P2X
_NP40:FljPD0XK_/102V_NX50;Noh@D0ZK[U3P2Y_NP00`00KlP0[lW]0:o9k@040:o9k@030<JndP33
`MT0`l7I0080`l7I0P36]l`40<Fic`80`k;90`33/l/30;n]b080_jk91@2lZLL50;VVaP80]ZC70`2f
Y<H40;>QaPD0/9o7102]WLH40:ZKa`D0Z9_90`2UVLT50::GbP<0WYK;1@2Q[=h50::fi`D0/LS[3P2Y
_NP40:VkiP@0Y[WW0`2Z`NX30:g5k0@0[L?[2@2Z_^P:0:Vmj0030000002Y_NP0ZKgX00X0ZKgX0P3o
ool3000001<0oooo00<000000?ooo`3oool0503oool000<0oooo00H0oooO09a8001d_ol0oooo0=nL
B000M;l80?ooo`060?noM000B9`0gooo0?ooo`2oM000M;oo203oool2000001`0oooo0`00000Z0?oo
o`@0Z;gX102U_>X50:6lk0@0Y[gZ1@2g`>440:Vji@l0ZKgX0P0oS^h40:o9k@D0`l7I1P35^Ll60<>c
b`040;n]b02o[/T0_jk90;n^b@@0_:W70P2lZlP40;VVaPD0]ZC6102cXLH50;2Oa`@0[Ig60P2ZVlL3
0:^Mb@@0Z9_9102UVLT40::GbP@0XZOI1@2Q[=h207[Ug0<0`>Oa402Y_NP30:N`gP@0XJkQ102V^NL5
0:g5k0D0Zl3Y102Z_^P?0:Vmj0030000002Y_NP0ZKgX00L0ZKgX1000000F0?ooo`030000003oool0
oooo01@0oooo00040?ooo`050?oo_`1d000000000018W03Oool0103oool00`3OW4P0000000000003
0000000307Boo`3oool0gia800<0000000<0001d0;ooo`3oool0103oool00`000000oooo0?ooo`0G
0?ooo`<00000;P3oool40:Rmj0D0Y[cY102Q_>`50:Bmj`@0]l3Q1@2/^N8>0:Vmj080X;[[102@cOd3
0<?1f@80^l[V1035^Ll20<;1f@D0`k?;1@2o[/T20;bYa`<0_:_80`2iY/H20;VYb@D0]ZC60P2cXLH2
0;>Sb0D0/9o70`2]WLH50:^Mb@D0Z9_90`2UVLT50:FVe`@0XZOI0P2Q[=h2093Ym`030:Obl`2Y_NP0
ZKgX0100ZKgX1P2W/=h30:6^h@H0[<G/102/`NX50:_0j@@0Z[gX3P2Y_NP00`000000ZKgX0:Vmj005
0:Vmj08000006P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?oo
o`<00000<P3oool40:Vmj0D0Y[cY102R_>`50:Bmj`@0]L7S1@2/^N8@0:Vmj0@0T<gm1@2kb^H20<Fi
c`@0`/7I0P33/l/30<:jd`@0_jk91P2lZlP0102iY/H0^JW90;VYb@2iZLT50;JTaP@0/j?81@2`WlL4
0:jRb`D0Zig9102XVlT40:NWePD0YJKG0`2RYmT2093Yma80ZKgX102Y]>450:N`gP@0Z/?[0`2/aN`3
0:c3j`@0[<7Z1@2Z_^P40:Zmj0h0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000003o
ool0oooo01@0oooo000O0?ooo`8000004`3oool3000003H0oooo102Y_NP50:Jmj@@0X[c/1@2R_N`4
0;G1h`D0/[_Q502Y_NP50;_:iPD0`/7I1P32^]<20;n^b@80_kKA1@2lZlP50;VYb@80]ZC60`2gZld4
0;>Sb080/9o70`2bZ<h30:jRb`D0Zig91@2[Z]L40:NWeP@0YJKG0`2Jhod@0:Vmj0D0ZK[U102Y]>45
0:Rmj@@0Z/?[1@2/`n/90:Znj180ZKgX0`00000P0?ooo`030000003oool0oooo01@0oooo000O0?oo
o`030000003oool0oooo00l0oooo0`00000j0?ooo`D0ZKgX102V_NT40:>lj`D0X[g/102_`>L50;:k
h@@0ZK_V402Y_NP509WGo@<0`/7I0P2ednl50<:jd`D0_kKA0P2lZlP30;fedP@0^JW91@2gZld40;>S
b0D0/ZS>102^X//20:^Mb@<0[[7J102[Z]L40:NWePD0W]km4`2Y_NP40:Vji@D0YKOU102X_NT50:c5
k0<0[<?[0P2[_nT40:Znj180ZKgX0`0000030?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3000003h0oooo1@2Y_NP40:Nmj@@0
Xkc[1@2Q_Nd40:o0i`D0][kQ102Y^nHA0:Vmj0@0VMOm1@2ednl20<:jd`<0^lkX102o]]460;fedP80
^JW90P2k^MP50;N[c@80/j?80P2f/mH50;:XcP<0[Z;;1P2^/MX30:^Ze`H0W]km5`2Y_NP40:B`h@D0
YKOU102/a^d50:c5k0D0ZkoY4P2Y_NP3000000H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0C0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`<00000@P3oool50:Vmj0@0YkgY
1@2T_>/40:6mk@@0Z;oZ1@2f_^440:^ehAH0ZKgX0`2ednl60;_>j080_kKA0P2kcNP50;fedP@0^kWH
1@2gZld50;JceP@0/ZS>102a^n850:jafPD0V>?m5`2Y_NP50:J_gP@0Y;3Q1@2[aNd40:c6k@D0Zl7Y
0P2[_nT30:Znj0d0ZKgX1000000:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
4`3oool001h0oooo0P0000090?ooo`800000AP3oool50:Vmj0@0YkgY1@2T_>/40:6lk0@0Z;oZ1@2f
`N840:^eh@D0ZKgW4P2Y_NP204[6j0D0^lkX1@2kcNP20;fedP<0]]C`102k^MP20;N[c@<0]lOV102f
/mH50;3=k`@0/K_R1P24i?HG0:Vmj0@0ZK3M102V[mh50:[4k0@0ZlG]1@2[`^X40:_1j@D0Z[kX2@2Y
_NP0103oool0000000000000000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
4`3oool001h0oooo00<000000?ooo`3oool01@3oool3000004T0oooo1@2Y_NP40:Nmj@D0YKcZ102Q
_>`40:Bnk0D0]/7R102c_>050:Vmia@0ZKgX1@1SeO040;_=j0H0]]C`0`2k^MP60;O7iP80][?F0P2M
i?d50;3=k`D0C<_>5`2Y_NP50:VagP@0ZK3M0P2V[mh20:W2k0D0Z/C/102[`n/50:_2jPL0Z[kX1`2Y
_NP0103oool0000000000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
4`3oool001h0oooo00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP00P2Y
_NP40:Rmj0D0YKcZ102R_>`40:Bnk0D0[L7X102c_>050:VcgaT0ZKgX1@1;bMd40;KDl0D0X>Cl102g
anH509gToA`0ZKgX2@2Y/Mh40:V`g@D0ZL;/1@2[a>`40:_3j`T0Z[kX1@2Y_NP00`3oool000000000
0002000001H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`007P3oool0
0`000000oooo0000000200000540oooo00<000000:Vmj02Y_NP00P2Y_NP40:Rmj0D0Y[gY102R_>`4
0:6mk@D0[L7X102g`N850:Vcg`@0ZKSS0`2Y_NP20:Vmicl0ZKgX302Y/Mh60:W0jP@0ZlG]102[a>`5
0:Zoj@@0Z[kX1`2Y_NP3000001/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C
0?ooo`007P3oool2000005D0oooo00<000000:Vmj02Y_NP00P2Y_NP40:Rmj0D0Y[gY102T_N/40:6m
k@D0YKo/102g`N850;Bmh0@0ZKSS1@2Y_NLj0:Vmj0d0ZK7N102X_^T30:W0jP<0Z/G]102[aNd40:[0
j@D0Z[oY202Y_NP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?oo
o`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vmj02Y
_NP00P2Y_NP40:Rmj0D0YkgY102T_N/50::mk0@0YKo/102/`NT50;Bmh0@0[kOO0`2Y_NL20:VbgSH0
ZKgX102Y/=d80:VagPD0ZKgX102X_^T50:[5k@D0Z/3Z102Z`>T50:Zmj0@0ZKgX00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oO
W01807@0_ooo00X0oooo0P00001F0?ooo`T0ZKgX102W_NT40:JmjPD0X[g/102R_^d40:c1j@D0//;U
102_]ml:0:VbgP@0ZKgX1@2Y_NLN0:Vmj0D0ZK[U0P2Y_NP70:V`g@@0ZK7N102Y_^P40:Vmj0H0Z/G^
102Z`NX40:[0jPD0Z[kX102Z_NP2000002L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05@0oooo2@2Y
_NP40:Rmj0@0Y[gZ1@2T_N/40::nk@@0Y<3]1@2b`^D40;K1hP<0ZK;N0P2f_n450:VbgP@0ZK7N102Y
_NL50:Vgh`@0ZKgX1@2Y_NL40:Vmj0@0ZK_V1@2Y_NP40:Vdh@@0ZK[U2@2Y/=d50:Zoj@@0ZKkX1@2Y
aNh50:[1j`@0Z/7Z2@2Z_^P2000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05@0oooo2@2Y_NP4
0:Rmj0@0YkgY1@2T_N/40::mk0@0Y<3]1@2W`N`40;K1hPD0][oQ0P2Y/]h30;Foh@@0ZK7N102Y/Md5
0:Vgh`@0ZK;O102Y_NL50:Vch0@0ZK_V1@2Y/Mh40:Vdh@@0[;?N1@2Y/=d40:[0jP@0Z[oY1P2YaNh4
0:W1j`@0Z/7[1@2Y_^P40:Znj0800000<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0oooo00<000000?ooo`3oool0E03oool=0:Vm
j0@0YkgY1@2V_NX40::mk0@0X[k]1@2W`N`40:W2j`@0][oQ1P2e_n420:VagP80]L3R102Y/Md50:ng
g`@0ZK;O102Y/=d50:Vch0@0Zk;M102Y/Mh50:njhP@0[;?N1@2Z`^/40:[0jPD0Z<G^2@2Y`N/40:Zn
j0@0ZKkX0`00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0
oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?ooo`d0ZKgX102X_NP50:JmjP@0
YKg[102R_^d50:>okP@0ZL;[102[`^/50;Foh@D0]L3R0P2Y/Md20;;1iPD0[kOO0P2Y/]l20;Bnh@@0
ZK3M1@2b_N840:^bg@@0[[oW1@2_^^840:W4k@@0Z/;[1@2Xa>h30:S5kPH0ZL7[1@2Y_^P40:Znj0<0
0000=`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo000A0?ooo`050;md
000004P0W;nL04P0M02oool0403oool2000005D0oooo3@2Y_NP40:Rmj0D0Z;gY102U_N/40:Bmk0D0
Xko^102S`>h40:_2j`D0Z/?/102e`>850;;1iP@0[kOO1@2d_^420:V`g@80[L;Y1@2b_N840:_3j`@0
[[oW1@2Xa>h40:W4k@T0Z<C^1@2Y`N/80:Vnj0<00000?03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oooa80oooo00<000000?ooo`3o
ool0D`3ooolA0:Vmj0D0Z;gY102W_NT40:Bmk0D0Y;k/102S`>h40:C1kPD0Z/?/102X`nd40;;1iPD0
[L?Z102d_^450:g2j@D0Z<C^102[`n/40:O4kP@0Z<C^1@2W`nd40:S4kPD0ZL7[2@2Y_^P300000400
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d
0;ooo`0C0?ooo`030000003oool0oooo05<0oooo5P2Y_NP40:Nmj@@0Y[gZ2@2T_^`90:C1kP@0Z<?]
1@2V`nh30:g3jPH0Z<?]102V`nh40:S4kPD0Y/?^102Wa>h40:O2k@D0Yl?]1@2X`>/80:Vnj0@00000
@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000003o
ool0oooo05<0oooo5P2Y_NP40:Rmj0T0Y[gZ102T_^`50:Bok0T0Y<7^102U`>d40:G2kPD0YL7]102V
`nh40:K1k@D0Y/?^102W`N`40:O2k@D0Z;oZ2@2Y_^P3000004P0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo5P2Y_NP80:Rmj0X0Y[gZ102W_^X4
0:Fok0D0Y[k[102U`>d40:Jok0D0YL7]102V`>`40:K1k@D0Yko[102W`N`50:Roj@@0ZKgX102Y_^P0
103oool0000000000000001<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3o
ool002d0oooo00<000000?ooo`3oool0DP3ooolJ0:Vmj0@0Z;gX1@2X_NT50:Rmj0@0YkkZ102W_NT5
0:Jnj`@0YkkZ102V_n`50:NnjP@0Y/3/102X_^X40:Noj`D0ZKkY2@2Y_NP4000004l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?oo
ob<0ZKgX2@2X_NP40:Nmj@D0Z;gY102W_^X40:Rnj@@0YkkZ1@2X_^T40:RnjPL0ZKkY1`2Y_NP30000
05@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00;`3oool00`000000
oooo0?ooo`1B0?ooobP0ZKgX102X_NP40:Vmj0@0Z;gY1@2Y_NP40:Rnj@@0ZKgX102X_^T50:Vmj0@0
ZKkY1@2Y_NP0103oool0000000000000001H0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00300oooo00<000000?ooo`3oool0DP3ooom?0:Vmj0@00000G03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000a0?ooo`800000D`3ooom:0:Vmj0040?oo
o`000000000000000600oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00
<`3oool00`000000oooo0?ooo`1A0?ooodH0ZKgX1000001T0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0403oool003@0oooo00<000000?ooo`3oool0D@3ooom20:Vmj0<00000J@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000e0?ooo`030000003oool0
oooo0540oooo?@2Y_NP0103oool0000000000000001/0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool003H0oooo0P00001B0?ooocT0ZKgX1000001`0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0403oool003P0oooo00<000000?ooo`3oool0D03ooole0:Vm
j0<00000M@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000i0?ooo`03
0000003oool0oooo0540oooo;`2Y_NP0103oool0000000000000001i0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0403oool003X0oooo00<000000?ooo`3oool0D@3oool[0:Vmj0@0
0000O03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000k0?ooo`030000
003oool0oooo0540oooo9`2Y_NP300000840oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0?0?ooo`00?03oool200000580oooo8P2Y_NP0103oool000000000000000250?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0D03o
oolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo000o
0?ooo`030000003oool0oooo0500oooo6P2Y_NP3000008d0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0?0?ooo`00@03oool00`000000oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00440oooo0P00001A0?oooa80
ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004<0oooo
00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00l0oooo00140?ooo`030000003oool0oooo0500oooo202Y_NP3000009d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1@
0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool0
04H0oooo0P00001A0?ooo`800000YP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00180?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0Y@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00190?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo001;0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001<0?oo
o`800000B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool004h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool004l0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00500oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool00540oooo0P0000160?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`00D`3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo0:`0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:h0oooo00@000000?oo
o`3oool000003`3oool005D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2^0?oo
o`040000003oool0oooo000000l0oooo001F0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0[`3oool00`000000oooo0000000?0?ooo`00E`3oool2000003l0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0000000>0?ooo`00F@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0oooo00<000000?ooo`3oool0[@3oool40000
0100oooo001N0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0Z@3oool4000001@0
oooo001O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0Y@3oool4000001P0oooo
001P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X@3oool4000001`0oooo001Q
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0WP3oool300000200oooo001R0?oo
o`800000=03oool00`000000oooo0?ooo`2J0?ooo`@000008`3oool006@0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`2F0?ooo`@000009`3oool006D0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3oool006H0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool006L0oooo0P00000_0?ooo`030000003oool0
oooo08X0oooo1000000c0?ooo`00J@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08<0
oooo1000000j0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo
1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07/0oooo1000
00120?ooo`00K@3oool2000002T0oooo00<000000?ooo`3oool0M`3oool4000004H0oooo001_0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0M@3oool3000004X0oooo001`0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0L@3oool4000004d0oooo001a0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool400000540oooo001b0?ooo`8000008`3o
ool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool007@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M0?ooo`030000003oool0oooo05H0oooo1000
001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000001/
0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04h0oooo1000001`0?oo
o`00O03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo0`00001d0?ooo`00
O@3oool2000001P0oooo00<000000?ooo`3oool0A`3oool4000007L0oooo001o0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4000007/0oooo00200?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0?`3oool4000007l0oooo00210?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0>`3oool4000008<0oooo00220?ooo`8000004`3oool00`000000
oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0`0?ooo`@00000SP3oool008H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/
0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?oo
o`@00000UP3oool008P0oooo0P00000=0?ooo`030000003oool0oooo02D0oooo0`00002J0?ooo`00
RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo1000002M0?ooo`00R`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000002Q0?ooo`00S03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000002U0?ooo`00S@3oool20000
00L0oooo00<000000?ooo`3oool05P3oool400000:T0oooo002?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04P3oool400000:d0oooo002@0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool300000;40oooo002A0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool400000;@0oooo002B0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool400000;P0oooo002C0?ooo`80000000<0oooo0000003oool0103oool400000;`0oooo002E0?oo
o`80000000<0oooo0000000000000P0000300?ooo`00UP3oool200000<@0oooo003o0?oooed0oooo
003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo
003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57074 Mtetra
.47319 .57074 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56094 Mtetra
.50558 .56094 .51154 .56698 .52239 .56372 .51647 .55765 Mtetra
.51647 .55765 .52239 .56372 .53329 .56044 .52739 .55435 Mtetra
.52739 .55435 .53329 .56044 .54423 .55715 .53837 .55104 Mtetra
.663 .741 .908 r
.53837 .55104 .54423 .55715 .55522 .55384 .54938 .54772 Mtetra
.54938 .54772 .55522 .55384 .56625 .55053 .56044 .5444 Mtetra
.56044 .5444 .56625 .55053 .57732 .54722 .57154 .54108 Mtetra
.662 .742 .909 r
.57154 .54108 .57732 .54722 .58844 .54389 .58269 .53777 Mtetra
.661 .743 .91 r
.58269 .53777 .58844 .54389 .59961 .54057 .59389 .53445 Mtetra
.661 .744 .912 r
.59389 .53445 .59961 .54057 .61082 .53724 .60513 .53115 Mtetra
.66 .745 .913 r
.60513 .53115 .61082 .53724 .62207 .53391 .61642 .52783 Mtetra
.66 .747 .914 r
.61642 .52783 .62207 .53391 .63337 .53056 .62775 .5245 Mtetra
.661 .748 .915 r
.62775 .5245 .63337 .53056 .64472 .5272 .63913 .52115 Mtetra
.661 .75 .915 r
.63913 .52115 .64472 .5272 .65611 .52381 .65055 .51775 Mtetra
.662 .75 .916 r
.65055 .51775 .65611 .52381 .66755 .52039 .66203 .51432 Mtetra
.663 .751 .915 r
.66203 .51432 .66755 .52039 .67903 .51694 .67354 .51084 Mtetra
.664 .752 .915 r
.67354 .51084 .67903 .51694 .69056 .51345 .68511 .50731 Mtetra
.665 .751 .914 r
.68511 .50731 .69056 .51345 .70214 .50992 .69671 .50374 Mtetra
.666 .751 .914 r
.69671 .50374 .70214 .50992 .71376 .50638 .70837 .50014 Mtetra
.667 .75 .913 r
.70837 .50014 .71376 .50638 .72543 .50281 .72007 .49651 Mtetra
.667 .749 .912 r
.72007 .49651 .72543 .50281 .73715 .49923 .73182 .49286 Mtetra
.667 .747 .911 r
.73182 .49286 .73715 .49923 .74891 .49565 .74362 .4892 Mtetra
.666 .745 .91 r
.74362 .4892 .74891 .49565 .76073 .49206 .75546 .48554 Mtetra
.666 .744 .909 r
.75546 .48554 .76073 .49206 .77259 .48847 .76736 .48189 Mtetra
.665 .743 .908 r
.76736 .48189 .77259 .48847 .78451 .48487 .77931 .47824 Mtetra
.665 .742 .908 r
.77931 .47824 .78451 .48487 .79647 .48126 .79131 .47459 Mtetra
.664 .741 .908 r
.79131 .47459 .79647 .48126 .80848 .47764 .80335 .47093 Mtetra
.664 .741 .907 r
.80335 .47093 .80848 .47764 .82055 .47401 .81545 .46727 Mtetra
.81545 .46727 .82055 .47401 .83266 .47036 .8276 .46359 Mtetra
.8276 .46359 .83266 .47036 .84483 .4667 .83981 .45991 Mtetra
.83981 .45991 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44875 Mtetra
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44065 .92668 .43364 Mtetra
.92668 .43364 .93144 .44065 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .58411 Mtetra
.4033 .58411 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57074 .46711 .56472 Mtetra
.46711 .56472 .47319 .57074 .48394 .56748 .47789 .56145 Mtetra
.47789 .56145 .48394 .56748 .49474 .56422 .48872 .55816 Mtetra
.48872 .55816 .49474 .56422 .50558 .56094 .49959 .55486 Mtetra
.49959 .55486 .50558 .56094 .51647 .55765 .5105 .55155 Mtetra
.663 .741 .908 r
.5105 .55155 .51647 .55765 .52739 .55435 .52145 .54823 Mtetra
.52145 .54823 .52739 .55435 .53837 .55104 .53245 .54492 Mtetra
.662 .742 .909 r
.53245 .54492 .53837 .55104 .54938 .54772 .5435 .54162 Mtetra
.661 .743 .911 r
.5435 .54162 .54938 .54772 .56044 .5444 .55459 .53834 Mtetra
.659 .744 .913 r
.55459 .53834 .56044 .5444 .57154 .54108 .56572 .53509 Mtetra
.658 .747 .916 r
.56572 .53509 .57154 .54108 .58269 .53777 .5769 .53187 Mtetra
.656 .751 .919 r
.5769 .53187 .58269 .53777 .59389 .53445 .58813 .52866 Mtetra
.656 .755 .923 r
.58813 .52866 .59389 .53445 .60513 .53115 .59941 .52543 Mtetra
.656 .759 .925 r
.59941 .52543 .60513 .53115 .61642 .52783 .61073 .52218 Mtetra
.657 .762 .927 r
.61073 .52218 .61642 .52783 .62775 .5245 .6221 .51888 Mtetra
.658 .764 .928 r
.6221 .51888 .62775 .5245 .63913 .52115 .63351 .51552 Mtetra
.66 .765 .928 r
.63351 .51552 .63913 .52115 .65055 .51775 .64497 .51211 Mtetra
.661 .766 .928 r
.64497 .51211 .65055 .51775 .66203 .51432 .65648 .50865 Mtetra
.662 .766 .927 r
.65648 .50865 .66203 .51432 .67354 .51084 .66803 .50514 Mtetra
.663 .767 .927 r
.66803 .50514 .67354 .51084 .68511 .50731 .67963 .50159 Mtetra
.665 .767 .926 r
.67963 .50159 .68511 .50731 .69671 .50374 .69127 .49799 Mtetra
.666 .767 .926 r
.69127 .49799 .69671 .50374 .70837 .50014 .70296 .49433 Mtetra
.667 .767 .924 r
.70296 .49433 .70837 .50014 .72007 .49651 .7147 .49062 Mtetra
.669 .765 .923 r
.7147 .49062 .72007 .49651 .73182 .49286 .72648 .48686 Mtetra
.669 .763 .92 r
.72648 .48686 .73182 .49286 .74362 .4892 .7383 .48307 Mtetra
.67 .759 .918 r
.7383 .48307 .74362 .4892 .75546 .48554 .75018 .47925 Mtetra
.669 .755 .915 r
.75018 .47925 .75546 .48554 .76736 .48189 .7621 .47546 Mtetra
.668 .75 .912 r
.7621 .47546 .76736 .48189 .77931 .47824 .77408 .47168 Mtetra
.667 .747 .91 r
.77408 .47168 .77931 .47824 .79131 .47459 .7861 .46793 Mtetra
.665 .744 .909 r
.7861 .46793 .79131 .47459 .80335 .47093 .79819 .46421 Mtetra
.665 .743 .908 r
.79819 .46421 .80335 .47093 .81545 .46727 .81032 .46049 Mtetra
.664 .741 .908 r
.81032 .46049 .81545 .46727 .8276 .46359 .82251 .45678 Mtetra
.664 .741 .907 r
.82251 .45678 .8276 .46359 .83981 .45991 .83475 .45306 Mtetra
.83475 .45306 .83981 .45991 .85206 .4562 .84704 .44932 Mtetra
.84704 .44932 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44875 .87177 .44181 Mtetra
.87177 .44181 .87672 .44875 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .58411 .39701 .57819 Mtetra
.39701 .57819 .4033 .58411 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55867 Mtetra
.46098 .55867 .46711 .56472 .47789 .56145 .47179 .55537 Mtetra
.47179 .55537 .47789 .56145 .48872 .55816 .48265 .55206 Mtetra
.664 .741 .908 r
.48265 .55206 .48872 .55816 .49959 .55486 .49354 .54874 Mtetra
.663 .741 .908 r
.49354 .54874 .49959 .55486 .5105 .55155 .50449 .54543 Mtetra
.662 .741 .909 r
.50449 .54543 .5105 .55155 .52145 .54823 .51547 .54213 Mtetra
.66 .742 .911 r
.51547 .54213 .52145 .54823 .53245 .54492 .5265 .53887 Mtetra
.658 .744 .914 r
.5265 .53887 .53245 .54492 .5435 .54162 .53757 .53567 Mtetra
.655 .747 .918 r
.53757 .53567 .5435 .54162 .55459 .53834 .54869 .53253 Mtetra
.653 .752 .923 r
.54869 .53253 .55459 .53834 .56572 .53509 .55986 .52942 Mtetra
.652 .758 .927 r
.55986 .52942 .56572 .53509 .5769 .53187 .57107 .52629 Mtetra
.654 .762 .929 r
.57107 .52629 .5769 .53187 .58813 .52866 .58234 .52308 Mtetra
.658 .765 .929 r
.58234 .52308 .58813 .52866 .59941 .52543 .59364 .51976 Mtetra
.662 .763 .925 r
.59364 .51976 .59941 .52543 .61073 .52218 .60499 .51631 Mtetra
.666 .759 .919 r
.60499 .51631 .61073 .52218 .6221 .51888 .61639 .51276 Mtetra
.668 .751 .913 r
.61639 .51276 .6221 .51888 .63351 .51552 .62783 .50914 Mtetra
.668 .744 .907 r
.62783 .50914 .63351 .51552 .64497 .51211 .63931 .50551 Mtetra
.666 .737 .903 r
.63931 .50551 .64497 .51211 .65648 .50865 .65085 .50192 Mtetra
.664 .733 .901 r
.65085 .50192 .65648 .50865 .66803 .50514 .66243 .49839 Mtetra
.662 .733 .902 r
.66243 .49839 .66803 .50514 .67963 .50159 .67406 .49491 Mtetra
.66 .735 .905 r
.67406 .49491 .67963 .50159 .69127 .49799 .68575 .49148 Mtetra
.66 .741 .91 r
.68575 .49148 .69127 .49799 .70296 .49433 .69748 .48803 Mtetra
.661 .749 .916 r
.69748 .48803 .70296 .49433 .7147 .49062 .70927 .48452 Mtetra
.663 .758 .92 r
.70927 .48452 .7147 .49062 .72648 .48686 .72109 .4809 Mtetra
.667 .765 .923 r
.72109 .4809 .72648 .48686 .7383 .48307 .73296 .47715 Mtetra
.67 .769 .924 r
.73296 .47715 .7383 .48307 .75018 .47925 .74487 .47328 Mtetra
.672 .768 .922 r
.74487 .47328 .75018 .47925 .7621 .47546 .75683 .46934 Mtetra
.673 .764 .919 r
.75683 .46934 .7621 .47546 .77408 .47168 .76883 .46537 Mtetra
.671 .758 .916 r
.76883 .46537 .77408 .47168 .7861 .46793 .78088 .46143 Mtetra
.669 .752 .912 r
.78088 .46143 .7861 .46793 .79819 .46421 .79299 .45755 Mtetra
.667 .747 .91 r
.79299 .45755 .79819 .46421 .81032 .46049 .80515 .45372 Mtetra
.666 .744 .909 r
.80515 .45372 .81032 .46049 .82251 .45678 .81737 .44993 Mtetra
.665 .742 .908 r
.81737 .44993 .82251 .45678 .83475 .45306 .82964 .44616 Mtetra
.664 .741 .908 r
.82964 .44616 .83475 .45306 .84704 .44932 .84197 .44239 Mtetra
.664 .741 .907 r
.84197 .44239 .84704 .44932 .85938 .44557 .85435 .43861 Mtetra
.85435 .43861 .85938 .44557 .87177 .44181 .86679 .43481 Mtetra
.86679 .43481 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .4156 Mtetra
.92976 .4156 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55587 Mtetra
.44402 .55587 .45022 .56195 .46098 .55867 .45481 .55256 Mtetra
.45481 .55256 .46098 .55867 .47179 .55537 .46565 .54925 Mtetra
.663 .741 .908 r
.46565 .54925 .47179 .55537 .48265 .55206 .47653 .54592 Mtetra
.662 .741 .908 r
.47653 .54592 .48265 .55206 .49354 .54874 .48746 .54261 Mtetra
.661 .741 .91 r
.48746 .54261 .49354 .54874 .50449 .54543 .49843 .53935 Mtetra
.657 .743 .913 r
.49843 .53935 .50449 .54543 .51547 .54213 .50944 .53615 Mtetra
.653 .746 .918 r
.50944 .53615 .51547 .54213 .5265 .53887 .5205 .53305 Mtetra
.65 .751 .924 r
.5205 .53305 .5265 .53887 .53757 .53567 .5316 .53002 Mtetra
.65 .757 .928 r
.5316 .53002 .53757 .53567 .54869 .53253 .54275 .52695 Mtetra
.654 .763 .929 r
.54275 .52695 .54869 .53253 .55986 .52942 .55395 .52374 Mtetra
.664 .763 .923 r
.55395 .52374 .55986 .52942 .57107 .52629 .56519 .52025 Mtetra
.675 .754 .91 r
.56519 .52025 .57107 .52629 .58234 .52308 .57648 .51643 Mtetra
.683 .738 .892 r
.57648 .51643 .58234 .52308 .59364 .51976 .5878 .51232 Mtetra
.679 .715 .876 r
.5878 .51232 .59364 .51976 .60499 .51631 .59916 .5083 Mtetra
.662 .695 .87 r
.59916 .5083 .60499 .51631 .61639 .51276 .61059 .50479 Mtetra
.663 .697 .872 r
.61059 .50479 .61639 .51276 .62783 .50914 .62206 .50127 Mtetra
.663 .7 .874 r
.62206 .50127 .62783 .50914 .63931 .50551 .63357 .49774 Mtetra
.663 .704 .877 r
.63357 .49774 .63931 .50551 .65085 .50192 .64514 .4942 Mtetra
.663 .706 .879 r
.64514 .4942 .65085 .50192 .66243 .49839 .65675 .49064 Mtetra
.65675 .49064 .66243 .49839 .67406 .49491 .66841 .48706 Mtetra
.663 .704 .877 r
.66841 .48706 .67406 .49491 .68575 .49148 .68012 .48347 Mtetra
.663 .7 .874 r
.68012 .48347 .68575 .49148 .69748 .48803 .69187 .47986 Mtetra
.663 .697 .872 r
.69187 .47986 .69748 .48803 .70927 .48452 .70368 .47624 Mtetra
.648 .689 .875 r
.70368 .47624 .70927 .48452 .72109 .4809 .71557 .47315 Mtetra
.645 .703 .889 r
.71557 .47315 .72109 .4809 .73296 .47715 .72751 .47015 Mtetra
.653 .728 .904 r
.72751 .47015 .73296 .47715 .74487 .47328 .7395 .46684 Mtetra
.662 .75 .916 r
.7395 .46684 .74487 .47328 .75683 .46934 .75151 .46321 Mtetra
.67 .765 .921 r
.75151 .46321 .75683 .46934 .76883 .46537 .76356 .45929 Mtetra
.675 .769 .922 r
.76356 .45929 .76883 .46537 .78088 .46143 .77564 .45522 Mtetra
.675 .766 .919 r
.77564 .45522 .78088 .46143 .79299 .45755 .78777 .45112 Mtetra
.673 .758 .915 r
.78777 .45112 .79299 .45755 .80515 .45372 .79996 .44708 Mtetra
.67 .751 .912 r
.79996 .44708 .80515 .45372 .81737 .44993 .8122 .44313 Mtetra
.667 .746 .909 r
.8122 .44313 .81737 .44993 .82964 .44616 .82451 .43925 Mtetra
.665 .743 .908 r
.82451 .43925 .82964 .44616 .84197 .44239 .83687 .43542 Mtetra
.664 .741 .908 r
.83687 .43542 .84197 .44239 .85435 .43861 .84929 .4316 Mtetra
.664 .741 .907 r
.84929 .4316 .85435 .43861 .86679 .43481 .86176 .42777 Mtetra
.86176 .42777 .86679 .43481 .87927 .431 .87428 .42392 Mtetra
.87428 .42392 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .4156 .92493 .40839 Mtetra
.92493 .40839 .92976 .4156 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55307 Mtetra
.427 .55307 .43327 .55917 .44402 .55587 .43778 .54975 Mtetra
.43778 .54975 .44402 .55587 .45481 .55256 .4486 .54642 Mtetra
.663 .741 .908 r
.4486 .54642 .45481 .55256 .46565 .54925 .45946 .5431 Mtetra
.662 .741 .909 r
.45946 .5431 .46565 .54925 .47653 .54592 .47037 .5398 Mtetra
.659 .742 .911 r
.47037 .5398 .47653 .54592 .48746 .54261 .48132 .53656 Mtetra
.654 .744 .915 r
.48132 .53656 .48746 .54261 .49843 .53935 .49232 .53344 Mtetra
.649 .748 .922 r
.49232 .53344 .49843 .53935 .50944 .53615 .50336 .53043 Mtetra
.647 .754 .927 r
.50336 .53043 .50944 .53615 .5205 .53305 .51445 .52744 Mtetra
.653 .761 .929 r
.51445 .52744 .5205 .53305 .5316 .53002 .52558 .52427 Mtetra
.669 .761 .92 r
.52558 .52427 .5316 .53002 .54275 .52695 .53677 .52066 Mtetra
.687 .749 .899 r
.53677 .52066 .54275 .52695 .55395 .52374 .54799 .51645 Mtetra
.682 .72 .877 r
.54799 .51645 .55395 .52374 .56519 .52025 .55925 .51232 Mtetra
.663 .697 .871 r
.55925 .51232 .56519 .52025 .57648 .51643 .57056 .50883 Mtetra
.663 .706 .879 r
.57056 .50883 .57648 .51643 .5878 .51232 .58192 .50533 Mtetra
.664 .724 .894 r
.58192 .50533 .5878 .51232 .59916 .5083 .59333 .50182 Mtetra
.664 .741 .907 r
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71557 .47315 .71003 .46586 Mtetra
.664 .724 .894 r
.71003 .46586 .71557 .47315 .72751 .47015 .72197 .46218 Mtetra
.663 .706 .879 r
.72197 .46218 .72751 .47015 .7395 .46684 .73396 .45848 Mtetra
.644 .689 .877 r
.73396 .45848 .7395 .46684 .75151 .46321 .74604 .45544 Mtetra
.641 .705 .893 r
.74604 .45544 .75151 .46321 .76356 .45929 .75819 .45248 Mtetra
.658 .741 .911 r
.75819 .45248 .76356 .45929 .77564 .45522 .77035 .44891 Mtetra
.671 .763 .919 r
.77035 .44891 .77564 .45522 .78777 .45112 .78253 .4449 Mtetra
.677 .768 .92 r
.78253 .4449 .78777 .45112 .79996 .44708 .79475 .44069 Mtetra
.676 .763 .917 r
.79475 .44069 .79996 .44708 .8122 .44313 .80701 .43649 Mtetra
.672 .755 .913 r
.80701 .43649 .8122 .44313 .82451 .43925 .81934 .43241 Mtetra
.668 .748 .91 r
.81934 .43241 .82451 .43925 .83687 .43542 .83173 .42845 Mtetra
.666 .744 .908 r
.83173 .42845 .83687 .43542 .84929 .4316 .84418 .42454 Mtetra
.665 .742 .908 r
.84418 .42454 .84929 .4316 .86176 .42777 .85669 .42067 Mtetra
.664 .741 .907 r
.85669 .42067 .86176 .42777 .87428 .42392 .86925 .41679 Mtetra
.86925 .41679 .87428 .42392 .88686 .42007 .88187 .4129 Mtetra
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55026 Mtetra
.40992 .55026 .41626 .55638 .427 .55307 .42068 .54693 Mtetra
.42068 .54693 .427 .55307 .43778 .54975 .43149 .54359 Mtetra
.663 .741 .908 r
.43149 .54359 .43778 .54975 .4486 .54642 .44234 .54026 Mtetra
.661 .741 .909 r
.44234 .54026 .4486 .54642 .45946 .5431 .45323 .53696 Mtetra
.657 .742 .912 r
.45323 .53696 .45946 .5431 .47037 .5398 .46416 .53376 Mtetra
.652 .744 .917 r
.46416 .53376 .47037 .5398 .48132 .53656 .47514 .5307 Mtetra
.646 .749 .924 r
.47514 .5307 .48132 .53656 .49232 .53344 .48616 .52776 Mtetra
.648 .757 .929 r
.48616 .52776 .49232 .53344 .50336 .53043 .49723 .52473 Mtetra
.664 .761 .923 r
.49723 .52473 .50336 .53043 .51445 .52744 .50835 .52126 Mtetra
.69 .753 .9 r
.50835 .52126 .51445 .52744 .52558 .52427 .51952 .51699 Mtetra
.682 .719 .877 r
.51952 .51699 .52558 .52427 .53677 .52066 .53073 .51285 Mtetra
.663 .7 .874 r
.53073 .51285 .53677 .52066 .54799 .51645 .54198 .50937 Mtetra
.664 .721 .891 r
.54198 .50937 .54799 .51645 .55925 .51232 .55328 .50587 Mtetra
.664 .741 .907 r
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .74604 .45544 .74056 .44788 Mtetra
.664 .721 .891 r
.74056 .44788 .74604 .45544 .75819 .45248 .75268 .44413 Mtetra
.644 .692 .88 r
.75268 .44413 .75819 .45248 .77035 .44891 .76491 .44103 Mtetra
.639 .704 .893 r
.76491 .44103 .77035 .44891 .78253 .4449 .77721 .43808 Mtetra
.663 .746 .912 r
.77721 .43808 .78253 .4449 .79475 .44069 .7895 .43431 Mtetra
.676 .766 .918 r
.7895 .43431 .79475 .44069 .80701 .43649 .80181 .43008 Mtetra
.678 .766 .917 r
.80181 .43008 .80701 .43649 .81934 .43241 .81416 .42576 Mtetra
.674 .758 .914 r
.81416 .42576 .81934 .43241 .83173 .42845 .82657 .42156 Mtetra
.67 .75 .91 r
.82657 .42156 .83173 .42845 .84418 .42454 .83904 .4175 Mtetra
.666 .744 .909 r
.83904 .4175 .84418 .42454 .85669 .42067 .85159 .41353 Mtetra
.665 .742 .908 r
.85159 .41353 .85669 .42067 .86925 .41679 .86419 .40961 Mtetra
.664 .741 .907 r
.86419 .40961 .86925 .41679 .88187 .4129 .87684 .40568 Mtetra
.87684 .40568 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54745 Mtetra
.39278 .54745 .3992 .55358 .40992 .55026 .40353 .5441 Mtetra
.40353 .5441 .40992 .55026 .42068 .54693 .41432 .54075 Mtetra
.663 .741 .908 r
.41432 .54075 .42068 .54693 .43149 .54359 .42515 .5374 Mtetra
.661 .741 .909 r
.42515 .5374 .43149 .54359 .44234 .54026 .43603 .5341 Mtetra
.656 .741 .912 r
.43603 .5341 .44234 .54026 .45323 .53696 .44694 .53092 Mtetra
.65 .744 .918 r
.44694 .53092 .45323 .53696 .46416 .53376 .4579 .5279 Mtetra
.644 .749 .926 r
.4579 .5279 .46416 .53376 .47514 .5307 .46891 .52499 Mtetra
.651 .757 .928 r
.46891 .52499 .47514 .5307 .48616 .52776 .47996 .52188 Mtetra
.677 .759 .913 r
.47996 .52188 .48616 .52776 .49723 .52473 .49107 .51802 Mtetra
.698 .74 .883 r
.49107 .51802 .49723 .52473 .50835 .52126 .50223 .51339 Mtetra
.662 .698 .873 r
.50223 .51339 .50835 .52126 .51952 .51699 .51342 .50991 Mtetra
.664 .721 .891 r
.51342 .50991 .51952 .51699 .53073 .51285 .52465 .50641 Mtetra
.664 .741 .907 r
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.55864 .49584 .56462 .50236 .57601 .49883 .57006 .49228 Mtetra
.57006 .49228 .57601 .49883 .58745 .49529 .58153 .48871 Mtetra
.58153 .48871 .58745 .49529 .59894 .49173 .59305 .48513 Mtetra
.59305 .48513 .59894 .49173 .61047 .48816 .60461 .48153 Mtetra
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68068 .46642 .67502 .45962 Mtetra
.67502 .45962 .68068 .46642 .69256 .46274 .68693 .45591 Mtetra
.68693 .45591 .69256 .46274 .70448 .45905 .69889 .45219 Mtetra
.69889 .45219 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76491 .44103 .75945 .43335 Mtetra
.664 .721 .891 r
.75945 .43335 .76491 .44103 .77721 .43808 .77171 .42953 Mtetra
.629 .684 .883 r
.77171 .42953 .77721 .43808 .7895 .43431 .78413 .42689 Mtetra
.651 .725 .903 r
.78413 .42689 .7895 .43431 .80181 .43008 .79654 .42346 Mtetra
.674 .76 .915 r
.79654 .42346 .80181 .43008 .81416 .42576 .80894 .41926 Mtetra
.68 .767 .917 r
.80894 .41926 .81416 .42576 .82657 .42156 .82138 .41484 Mtetra
.676 .76 .914 r
.82138 .41484 .82657 .42156 .83904 .4175 .83388 .41054 Mtetra
.67 .75 .911 r
.83388 .41054 .83904 .4175 .85159 .41353 .84645 .4064 Mtetra
.666 .744 .909 r
.84645 .4064 .85159 .41353 .86419 .40961 .85908 .40238 Mtetra
.665 .742 .908 r
.85908 .40238 .86419 .40961 .87684 .40568 .87177 .3984 Mtetra
.664 .741 .907 r
.87177 .3984 .87684 .40568 .88956 .40174 .88453 .39443 Mtetra
.88453 .39443 .88956 .40174 .90232 .39779 .89734 .39044 Mtetra
.89734 .39044 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54745 .38632 .54126 Mtetra
.38632 .54126 .39278 .54745 .40353 .5441 .39709 .5379 Mtetra
.663 .741 .908 r
.39709 .5379 .40353 .5441 .41432 .54075 .40791 .53454 Mtetra
.661 .741 .909 r
.40791 .53454 .41432 .54075 .42515 .5374 .41877 .53122 Mtetra
.656 .741 .912 r
.41877 .53122 .42515 .5374 .43603 .5341 .42967 .52803 Mtetra
.648 .743 .919 r
.42967 .52803 .43603 .5341 .44694 .53092 .44061 .52504 Mtetra
.643 .749 .926 r
.44061 .52504 .44694 .53092 .4579 .5279 .45159 .52215 Mtetra
.654 .757 .926 r
.45159 .52215 .4579 .5279 .46891 .52499 .46263 .51895 Mtetra
.689 .757 .904 r
.46263 .51895 .46891 .52499 .47996 .52188 .47373 .51471 Mtetra
.686 .724 .879 r
.47373 .51471 .47996 .52188 .49107 .51802 .48487 .51044 Mtetra
.663 .707 .88 r
.48487 .51044 .49107 .51802 .50223 .51339 .49604 .50695 Mtetra
.664 .741 .907 r
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.52984 .49638 .53593 .5029 .54726 .49938 .5412 .49283 Mtetra
.5412 .49283 .54726 .49938 .55864 .49584 .55261 .48926 Mtetra
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.625 .728 .921 r
.56406 .48568 .57006 .49228 .58153 .48871 .57558 .48319 Mtetra
.489 .713 .97 r
.57558 .48319 .58153 .48871 .59305 .48513 .5872 .48307 Mtetra
.357 .786 .97 r
.5872 .48307 .59305 .48513 .60461 .48153 .59887 .48209 Mtetra
.159 .699 .752 r
.59887 .48209 .60461 .48153 .61622 .47792 .61059 .4802 Mtetra
0 0 0 r
.61059 .4802 .61622 .47792 .62789 .47429 .62234 .47741 Mtetra
.62234 .47741 .62789 .47429 .6396 .47064 .63412 .47375 Mtetra
.63412 .47375 .6396 .47064 .65136 .46698 .64591 .46921 Mtetra
.331 .795 .681 r
.64591 .46921 .65136 .46698 .66316 .46331 .65772 .46377 Mtetra
.604 .953 .886 r
.65772 .46377 .66316 .46331 .67502 .45962 .66952 .45739 Mtetra
.763 .931 .941 r
.66952 .45739 .67502 .45962 .68693 .45591 .68131 .45015 Mtetra
.699 .788 .92 r
.68131 .45015 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.664 .741 .907 r
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72296 .4447 .71739 .43773 Mtetra
.71739 .43773 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78413 .42689 .77865 .41858 Mtetra
.64 .697 .887 r
.77865 .41858 .78413 .42689 .79654 .42346 .79113 .41551 Mtetra
.64 .708 .896 r
.79113 .41551 .79654 .42346 .80894 .41926 .80366 .41241 Mtetra
.672 .754 .913 r
.80366 .41241 .80894 .41926 .82138 .41484 .81617 .40823 Mtetra
.681 .766 .916 r
.81617 .40823 .82138 .41484 .83388 .41054 .82869 .40374 Mtetra
.677 .76 .913 r
.82869 .40374 .83388 .41054 .84645 .4064 .84128 .39934 Mtetra
.671 .75 .91 r
.84128 .39934 .84645 .4064 .85908 .40238 .85394 .39515 Mtetra
.666 .744 .908 r
.85394 .39515 .85908 .40238 .87177 .3984 .86667 .39109 Mtetra
.665 .742 .908 r
.86667 .39109 .87177 .3984 .88453 .39443 .87946 .38706 Mtetra
.664 .741 .907 r
.87946 .38706 .88453 .39443 .89734 .39044 .89231 .38304 Mtetra
.89231 .38304 .89734 .39044 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53841 Mtetra
.36905 .53841 .37559 .54462 .38632 .54126 .37981 .53503 Mtetra
.663 .741 .908 r
.37981 .53503 .38632 .54126 .39709 .5379 .39061 .53166 Mtetra
.662 .741 .909 r
.39061 .53166 .39709 .5379 .40791 .53454 .40145 .52832 Mtetra
.657 .741 .912 r
.40145 .52832 .40791 .53454 .41877 .53122 .41233 .5251 Mtetra
.648 .743 .918 r
.41233 .5251 .41877 .53122 .42967 .52803 .42325 .52209 Mtetra
.642 .748 .926 r
.42325 .52209 .42967 .52803 .44061 .52504 .43422 .51923 Mtetra
.655 .756 .925 r
.43422 .51923 .44061 .52504 .45159 .52215 .44524 .516 Mtetra
.695 .756 .899 r
.44524 .516 .45159 .52215 .46263 .51895 .45633 .51154 Mtetra
.679 .716 .877 r
.45633 .51154 .46263 .51895 .47373 .51471 .46745 .50749 Mtetra
.664 .717 .889 r
.46745 .50749 .47373 .51471 .48487 .51044 .47861 .50398 Mtetra
.664 .741 .907 r
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.50106 .49693 .50726 .50344 .51853 .49992 .51236 .49338 Mtetra
.51236 .49338 .51853 .49992 .52984 .49638 .5237 .48981 Mtetra
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.39 .626 .947 r
.53509 .48623 .5412 .49283 .55261 .48926 .54657 .48814 Mtetra
0 .517 .739 r
.54657 .48814 .55261 .48926 .56406 .48568 .55812 .48975 Mtetra
.365 0 0 r
.55812 .48975 .56406 .48568 .57558 .48319 .56975 .49008 Mtetra
.39 0 .033 r
.56975 .49008 .57558 .48319 .5872 .48307 .58142 .48917 Mtetra
.307 0 0 r
.58142 .48917 .5872 .48307 .59887 .48209 .59315 .48721 Mtetra
.206 0 0 r
.59315 .48721 .59887 .48209 .61059 .4802 .60492 .4845 Mtetra
.105 0 0 r
.60492 .4845 .61059 .4802 .62234 .47741 .61673 .48125 Mtetra
.027 0 0 r
.61673 .48125 .62234 .47741 .63412 .47375 .62858 .47757 Mtetra
0 0 0 r
.62858 .47757 .63412 .47375 .64591 .46921 .64047 .47346 Mtetra
.64047 .47346 .64591 .46921 .65772 .46377 .65238 .4688 Mtetra
.65238 .4688 .65772 .46377 .66952 .45739 .66431 .46338 Mtetra
.66431 .46338 .66952 .45739 .68131 .45015 .67623 .45691 Mtetra
.67623 .45691 .68131 .45015 .69325 .44528 .68811 .44916 Mtetra
.436 .815 .568 r
.68811 .44916 .69325 .44528 .7053 .44152 .69995 .4401 Mtetra
.816 .963 .904 r
.69995 .4401 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.664 .741 .907 r
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74174 .43012 .7362 .42304 Mtetra
.7362 .42304 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79113 .41551 .78567 .40749 Mtetra
.647 .711 .894 r
.78567 .40749 .79113 .41551 .80366 .41241 .79823 .40413 Mtetra
.634 .699 .892 r
.79823 .40413 .80366 .41241 .81617 .40823 .81087 .40121 Mtetra
.671 .751 .911 r
.81087 .40121 .81617 .40823 .82869 .40374 .82347 .397 Mtetra
.682 .766 .915 r
.82347 .397 .82869 .40374 .84128 .39934 .83608 .39242 Mtetra
.677 .759 .913 r
.83608 .39242 .84128 .39934 .85394 .39515 .84876 .38798 Mtetra
.67 .749 .91 r
.84876 .38798 .85394 .39515 .86667 .39109 .86152 .38375 Mtetra
.666 .744 .908 r
.86152 .38375 .86667 .39109 .87946 .38706 .87435 .37965 Mtetra
.664 .741 .908 r
.87435 .37965 .87946 .38706 .89231 .38304 .88724 .37558 Mtetra
.664 .741 .907 r
.88724 .37558 .89231 .38304 .90521 .379 .90018 .37151 Mtetra
.90018 .37151 .90521 .379 .91818 .37495 .91319 .36742 Mtetra
.91319 .36742 .91818 .37495 .9312 .37088 .92625 .36331 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53555 Mtetra
.35172 .53555 .35834 .54178 .36905 .53841 .36246 .53216 Mtetra
.663 .741 .908 r
.36246 .53216 .36905 .53841 .37981 .53503 .37325 .52877 Mtetra
.662 .741 .908 r
.37325 .52877 .37981 .53503 .39061 .53166 .38407 .5254 Mtetra
.658 .741 .911 r
.38407 .5254 .39061 .53166 .40145 .52832 .39494 .52213 Mtetra
.649 .741 .917 r
.39494 .52213 .40145 .52832 .41233 .5251 .40584 .51909 Mtetra
.641 .746 .925 r
.40584 .51909 .41233 .5251 .42325 .52209 .41678 .51624 Mtetra
.652 .755 .925 r
.41678 .51624 .42325 .52209 .43422 .51923 .42778 .51308 Mtetra
.696 .757 .899 r
.42778 .51308 .43422 .51923 .44524 .516 .43887 .50858 Mtetra
.679 .717 .877 r
.43887 .50858 .44524 .516 .45633 .51154 .44998 .50452 Mtetra
.664 .724 .894 r
.44998 .50452 .45633 .51154 .46745 .50749 .46112 .501 Mtetra
.664 .741 .907 r
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.48354 .49392 .48981 .50046 .50106 .49693 .49482 .49036 Mtetra
.49482 .49036 .50106 .49693 .51236 .49338 .50614 .48678 Mtetra
.384 .624 .948 r
.50614 .48678 .51236 .49338 .5237 .48981 .5175 .48871 Mtetra
.263 0 0 r
.5175 .48871 .5237 .48981 .53509 .48623 .52895 .49196 Mtetra
.47 0 .033 r
.52895 .49196 .53509 .48623 .54657 .48814 .54049 .49335 Mtetra
.35 0 0 r
.54049 .49335 .54657 .48814 .55812 .48975 .55209 .49275 Mtetra
.079 0 0 r
.55209 .49275 .55812 .48975 .56975 .49008 .56374 .49057 Mtetra
.329 .814 .834 r
.56374 .49057 .56975 .49008 .58142 .48917 .57544 .48736 Mtetra
.577 .897 .986 r
.57544 .48736 .58142 .48917 .59315 .48721 .58718 .48362 Mtetra
.648 .853 .978 r
.58718 .48362 .59315 .48721 .60492 .4845 .59897 .4797 Mtetra
.661 .811 .955 r
.59897 .4797 .60492 .4845 .61673 .48125 .6108 .47583 Mtetra
.658 .788 .944 r
.6108 .47583 .61673 .48125 .62858 .47757 .62269 .47213 Mtetra
.651 .786 .946 r
.62269 .47213 .62858 .47757 .64047 .47346 .63464 .46858 Mtetra
.643 .805 .961 r
.63464 .46858 .64047 .47346 .65238 .4688 .64664 .46508 Mtetra
.631 .849 .983 r
.64664 .46508 .65238 .4688 .66431 .46338 .65869 .46141 Mtetra
.601 .905 .984 r
.65869 .46141 .66431 .46338 .67623 .45691 .67077 .4572 Mtetra
.515 .915 .883 r
.67077 .4572 .67623 .45691 .68811 .44916 .68284 .45194 Mtetra
.376 .809 .642 r
.68284 .45194 .68811 .44916 .69995 .4401 .69488 .44508 Mtetra
0 0 0 r
.69488 .44508 .69995 .4401 .71178 .43071 .70683 .43619 Mtetra
.70683 .43619 .71178 .43071 .72397 .42688 .71868 .42538 Mtetra
.816 .964 .903 r
.71868 .42538 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.664 .741 .907 r
.73062 .41589 .7362 .42304 .74849 .41917 .74295 .412 Mtetra
.74295 .412 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79823 .40413 .79279 .39626 Mtetra
.647 .717 .899 r
.79279 .39626 .79823 .40413 .81087 .40121 .80543 .39286 Mtetra
.633 .699 .893 r
.80543 .39286 .81087 .40121 .82347 .397 .81818 .3899 Mtetra
.674 .753 .91 r
.81818 .3899 .82347 .397 .83608 .39242 .83086 .38557 Mtetra
.683 .765 .914 r
.83086 .38557 .83608 .39242 .84876 .38798 .84356 .3809 Mtetra
.676 .757 .911 r
.84356 .3809 .84876 .38798 .86152 .38375 .85634 .37644 Mtetra
.669 .747 .909 r
.85634 .37644 .86152 .38375 .87435 .37965 .8692 .3722 Mtetra
.665 .743 .908 r
.8692 .3722 .87435 .37965 .88724 .37558 .88213 .36806 Mtetra
.664 .741 .907 r
.88213 .36806 .88724 .37558 .90018 .37151 .89511 .36395 Mtetra
.89511 .36395 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36331 .92126 .35569 Mtetra
.33433 .53268 .34102 .53893 .35172 .53555 .34506 .52928 Mtetra
.34506 .52928 .35172 .53555 .36246 .53216 .35583 .52587 Mtetra
.663 .741 .908 r
.35583 .52587 .36246 .53216 .37325 .52877 .36664 .52247 Mtetra
.66 .74 .91 r
.36664 .52247 .37325 .52877 .38407 .5254 .37749 .51914 Mtetra
.652 .741 .915 r
.37749 .51914 .38407 .5254 .39494 .52213 .38837 .51603 Mtetra
.641 .743 .923 r
.38837 .51603 .39494 .52213 .40584 .51909 .39929 .51316 Mtetra
.646 .751 .926 r
.39929 .51316 .40584 .51909 .41678 .51624 .41027 .51014 Mtetra
.689 .757 .904 r
.41027 .51014 .41678 .51624 .42778 .51308 .42133 .50585 Mtetra
.686 .724 .879 r
.42133 .50585 .42778 .51308 .43887 .50858 .43244 .50155 Mtetra
.664 .724 .894 r
.43244 .50155 .43887 .50858 .44998 .50452 .44356 .49802 Mtetra
.664 .741 .907 r
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.46595 .49091 .4723 .49747 .48354 .49392 .47721 .48734 Mtetra
.623 .728 .922 r
.47721 .48734 .48354 .49392 .49482 .49036 .48851 .48488 Mtetra
0 .432 .859 r
.48851 .48488 .49482 .49036 .50614 .48678 .4998 .49002 Mtetra
.506 0 0 r
.4998 .49002 .50614 .48678 .5175 .48871 .51121 .49326 Mtetra
.385 0 0 r
.51121 .49326 .5175 .48871 .52895 .49196 .52272 .49367 Mtetra
0 0 0 r
.52272 .49367 .52895 .49196 .54049 .49335 .5343 .49152 Mtetra
.596 .9 .986 r
.5343 .49152 .54049 .49335 .55209 .49275 .54592 .4876 Mtetra
.701 .805 .93 r
.54592 .4876 .55209 .49275 .56374 .49057 .55758 .48275 Mtetra
.701 .724 .868 r
.55758 .48275 .56374 .49057 .57544 .48736 .56928 .47761 Mtetra
.688 .677 .834 r
.56928 .47761 .57544 .48736 .58718 .48362 .58103 .47255 Mtetra
.674 .648 .816 r
.58103 .47255 .58718 .48362 .59897 .4797 .59281 .46784 Mtetra
.662 .63 .808 r
.59281 .46784 .59897 .4797 .6108 .47583 .60466 .46359 Mtetra
.65 .619 .806 r
.60466 .46359 .6108 .47583 .62269 .47213 .61656 .45985 Mtetra
.639 .614 .809 r
.61656 .45985 .62269 .47213 .63464 .46858 .62853 .45662 Mtetra
.629 .615 .817 r
.62853 .45662 .63464 .46858 .64664 .46508 .64058 .45385 Mtetra
.622 .624 .832 r
.64058 .45385 .64664 .46508 .65869 .46141 .6527 .45143 Mtetra
.619 .648 .857 r
.6527 .45143 .65869 .46141 .67077 .4572 .66488 .44911 Mtetra
.626 .697 .896 r
.66488 .44911 .67077 .4572 .68284 .45194 .67712 .44649 Mtetra
.646 .791 .951 r
.67712 .44649 .68284 .45194 .69488 .44508 .68937 .44293 Mtetra
.666 .923 .974 r
.68937 .44293 .69488 .44508 .70683 .43619 .70158 .43758 Mtetra
.604 .949 .807 r
.70158 .43758 .70683 .43619 .71868 .42538 .71368 .42962 Mtetra
.508 .841 .555 r
.71368 .42962 .71868 .42538 .73062 .41589 .72562 .41875 Mtetra
.741 .967 .695 r
.72562 .41875 .73062 .41589 .74295 .412 .73744 .40593 Mtetra
.7 .79 .921 r
.73744 .40593 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.664 .741 .907 r
.74978 .40083 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80543 .39286 .79998 .3849 Mtetra
.639 .714 .901 r
.79998 .3849 .80543 .39286 .81818 .3899 .81275 .38168 Mtetra
.64 .708 .896 r
.81275 .38168 .81818 .3899 .83086 .38557 .82557 .37845 Mtetra
.678 .757 .91 r
.82557 .37845 .83086 .38557 .84356 .3809 .83833 .37391 Mtetra
.683 .763 .912 r
.83833 .37391 .84356 .3809 .85634 .37644 .85113 .3692 Mtetra
.674 .754 .91 r
.85113 .3692 .85634 .37644 .8692 .3722 .86401 .36475 Mtetra
.668 .745 .908 r
.86401 .36475 .8692 .3722 .88213 .36806 .87697 .3605 Mtetra
.665 .742 .908 r
.87697 .3605 .88213 .36806 .89511 .36395 .89 .35633 Mtetra
.664 .741 .907 r
.89 .35633 .89511 .36395 .90816 .35983 .90309 .35217 Mtetra
.90309 .35217 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.32759 .52639 .33433 .53268 .34506 .52928 .33835 .52296 Mtetra
.663 .741 .908 r
.33835 .52296 .34506 .52928 .35583 .52587 .34914 .51953 Mtetra
.661 .741 .909 r
.34914 .51953 .35583 .52587 .36664 .52247 .35997 .51615 Mtetra
.655 .74 .912 r
.35997 .51615 .36664 .52247 .37749 .51914 .37084 .51293 Mtetra
.644 .741 .92 r
.37084 .51293 .37749 .51914 .38837 .51603 .38175 .51 Mtetra
.64 .747 .926 r
.38175 .51 .38837 .51603 .39929 .51316 .3927 .50712 Mtetra
.676 .757 .912 r
.3927 .50712 .39929 .51316 .41027 .51014 .40373 .50325 Mtetra
.698 .737 .882 r
.40373 .50325 .41027 .51014 .42133 .50585 .41484 .49856 Mtetra
.663 .718 .889 r
.41484 .49856 .42133 .50585 .43244 .50155 .42595 .49502 Mtetra
.664 .741 .907 r
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
.4483 .48789 .45473 .49447 .46595 .49091 .45955 .4843 Mtetra
.545 .7 .941 r
.45955 .4843 .46595 .49091 .47721 .48734 .47079 .48355 Mtetra
0 .273 .673 r
.47079 .48355 .47721 .48734 .48851 .48488 .48202 .48943 Mtetra
.522 .024 .015 r
.48202 .48943 .48851 .48488 .4998 .49002 .49338 .4925 Mtetra
.18 0 0 r
.49338 .4925 .4998 .49002 .51121 .49326 .50487 .49186 Mtetra
.559 .899 .979 r
.50487 .49186 .51121 .49326 .52272 .49367 .51643 .48817 Mtetra
.721 .796 .911 r
.51643 .48817 .52272 .49367 .5343 .49152 .52803 .48264 Mtetra
.719 .705 .836 r
.52803 .48264 .5343 .49152 .54592 .4876 .53967 .47632 Mtetra
.704 .656 .8 r
.53967 .47632 .54592 .4876 .55758 .48275 .55134 .46994 Mtetra
.689 .629 .783 r
.55134 .46994 .55758 .48275 .56928 .47761 .56305 .46387 Mtetra
.676 .611 .775 r
.56305 .46387 .56928 .47761 .58103 .47255 .57479 .45831 Mtetra
.664 .6 .773 r
.57479 .45831 .58103 .47255 .59281 .46784 .58658 .45332 Mtetra
.653 .592 .773 r
.58658 .45332 .59281 .46784 .60466 .46359 .59843 .44894 Mtetra
.642 .585 .775 r
.59843 .44894 .60466 .46359 .61656 .45985 .61034 .44516 Mtetra
.631 .579 .778 r
.61034 .44516 .61656 .45985 .62853 .45662 .62232 .44198 Mtetra
.619 .574 .781 r
.62232 .44198 .62853 .45662 .64058 .45385 .63438 .43942 Mtetra
.608 .571 .787 r
.63438 .43942 .64058 .45385 .6527 .45143 .64652 .43743 Mtetra
.597 .571 .796 r
.64652 .43743 .6527 .45143 .66488 .44911 .65874 .43597 Mtetra
.589 .58 .81 r
.65874 .43597 .66488 .44911 .67712 .44649 .67106 .43483 Mtetra
.589 .604 .835 r
.67106 .43483 .67712 .44649 .68937 .44293 .68344 .43364 Mtetra
.607 .662 .878 r
.68344 .43364 .68937 .44293 .70158 .43758 .69586 .43166 Mtetra
.658 .781 .94 r
.69586 .43166 .70158 .43758 .71368 .42962 .70825 .42781 Mtetra
.727 .95 .951 r
.70825 .42781 .71368 .42962 .72562 .41875 .7205 .42085 Mtetra
.7 .971 .753 r
.7205 .42085 .72562 .41875 .73744 .40593 .73254 .41009 Mtetra
.666 .912 .59 r
.73254 .41009 .73744 .40593 .74978 .40083 .74438 .39643 Mtetra
.753 .866 .931 r
.74438 .39643 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.664 .741 .907 r
.75669 .38952 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81275 .38168 .80727 .37339 Mtetra
.628 .702 .899 r
.80727 .37339 .81275 .38168 .82557 .37845 .82017 .37051 Mtetra
.653 .724 .901 r
.82017 .37051 .82557 .37845 .83833 .37391 .83305 .36678 Mtetra
.683 .761 .911 r
.83305 .36678 .83833 .37391 .85113 .3692 .8459 .36203 Mtetra
.681 .76 .911 r
.8459 .36203 .85113 .3692 .86401 .36475 .8588 .35732 Mtetra
.672 .75 .909 r
.8588 .35732 .86401 .36475 .87697 .3605 .87178 .35291 Mtetra
.666 .744 .908 r
.87178 .35291 .87697 .3605 .89 .35633 .88485 .34866 Mtetra
.664 .741 .907 r
.88485 .34866 .89 .35633 .90309 .35217 .89798 .34446 Mtetra
.89798 .34446 .90309 .35217 .91624 .348 .91117 .34025 Mtetra
.3208 .52005 .32759 .52639 .33835 .52296 .33158 .5166 Mtetra
.662 .741 .908 r
.33158 .5166 .33835 .52296 .34914 .51953 .3424 .51317 Mtetra
.659 .74 .91 r
.3424 .51317 .34914 .51953 .35997 .51615 .35326 .50984 Mtetra
.648 .74 .916 r
.35326 .50984 .35997 .51615 .37084 .51293 .36415 .50678 Mtetra
.638 .743 .925 r
.36415 .50678 .37084 .51293 .38175 .51 .37507 .50396 Mtetra
.658 .753 .92 r
.37507 .50396 .38175 .51 .3927 .50712 .38607 .50059 Mtetra
.708 .751 .885 r
.38607 .50059 .3927 .50712 .40373 .50325 .39718 .49556 Mtetra
.663 .707 .881 r
.39718 .49556 .40373 .50325 .41484 .49856 .40827 .49201 Mtetra
.664 .741 .907 r
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.43059 .48485 .4371 .49146 .4483 .48789 .44182 .48125 Mtetra
.544 .7 .941 r
.44182 .48125 .4483 .48789 .45955 .4843 .45303 .4805 Mtetra
.371 0 0 r
.45303 .4805 .45955 .4843 .47079 .48355 .46417 .48716 Mtetra
.511 0 0 r
.46417 .48716 .47079 .48355 .48202 .48943 .47549 .49037 Mtetra
0 0 0 r
.47549 .49037 .48202 .48943 .49338 .4925 .48695 .48906 Mtetra
.693 .865 .963 r
.48695 .48906 .49338 .4925 .50487 .49186 .4985 .4842 Mtetra
.738 .738 .851 r
.4985 .4842 .50487 .49186 .51643 .48817 .5101 .47738 Mtetra
.725 .672 .798 r
.5101 .47738 .51643 .48817 .52803 .48264 .52173 .46993 Mtetra
.709 .638 .776 r
.52173 .46993 .52803 .48264 .53967 .47632 .53339 .46261 Mtetra
.696 .621 .769 r
.53339 .46261 .53967 .47632 .55134 .46994 .54507 .45579 Mtetra
.684 .61 .768 r
.54507 .45579 .55134 .46994 .56305 .46387 .55678 .4496 Mtetra
.673 .604 .77 r
.55678 .4496 .56305 .46387 .57479 .45831 .56853 .44405 Mtetra
.663 .6 .774 r
.56853 .44405 .57479 .45831 .58658 .45332 .58034 .43911 Mtetra
.654 .596 .778 r
.58034 .43911 .58658 .45332 .59843 .44894 .59219 .43475 Mtetra
.644 .592 .781 r
.59219 .43475 .59843 .44894 .61034 .44516 .60411 .43093 Mtetra
.633 .586 .784 r
.60411 .43093 .61034 .44516 .62232 .44198 .6161 .42766 Mtetra
.622 .58 .786 r
.6161 .42766 .62232 .44198 .63438 .43942 .62816 .42498 Mtetra
.609 .572 .787 r
.62816 .42498 .63438 .43942 .64652 .43743 .6403 .42291 Mtetra
.595 .564 .789 r
.6403 .42291 .64652 .43743 .65874 .43597 .65253 .42149 Mtetra
.581 .558 .793 r
.65253 .42149 .65874 .43597 .67106 .43483 .66487 .42071 Mtetra
.569 .556 .8 r
.66487 .42071 .67106 .43483 .68344 .43364 .6773 .42046 Mtetra
.563 .567 .816 r
.6773 .42046 .68344 .43364 .69586 .43166 .68983 .42036 Mtetra
.574 .605 .846 r
.68983 .42036 .69586 .43166 .70825 .42781 .70241 .41962 Mtetra
.625 .701 .9 r
.70241 .41962 .70825 .42781 .7205 .42085 .71495 .4169 Mtetra
.732 .878 .948 r
.71495 .4169 .7205 .42085 .73254 .41009 .72733 .41056 Mtetra
.799 .999 .839 r
.72733 .41056 .73254 .41009 .74438 .39643 .73943 .39958 Mtetra
.775 .966 .667 r
.73943 .39958 .74438 .39643 .75669 .38952 .75129 .38504 Mtetra
.753 .866 .931 r
.75129 .38504 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.664 .741 .907 r
.76369 .37807 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82017 .37051 .81465 .36173 Mtetra
.619 .688 .893 r
.81465 .36173 .82017 .37051 .83305 .36678 .82769 .35914 Mtetra
.669 .742 .905 r
.82769 .35914 .83305 .36678 .8459 .36203 .84062 .35483 Mtetra
.685 .763 .91 r
.84062 .35483 .8459 .36203 .8588 .35732 .85355 .34995 Mtetra
.677 .755 .91 r
.85355 .34995 .8588 .35732 .87178 .35291 .86656 .34531 Mtetra
.669 .746 .908 r
.86656 .34531 .87178 .35291 .88485 .34866 .87966 .34095 Mtetra
.665 .742 .908 r
.87966 .34095 .88485 .34866 .89798 .34446 .89283 .33668 Mtetra
.664 .741 .907 r
.89283 .33668 .89798 .34446 .91117 .34025 .90606 .33243 Mtetra
.663 .741 .908 r
.31396 .51366 .3208 .52005 .33158 .5166 .32477 .51019 Mtetra
.661 .741 .909 r
.32477 .51019 .33158 .5166 .3424 .51317 .33561 .50678 Mtetra
.654 .74 .913 r
.33561 .50678 .3424 .51317 .35326 .50984 .34649 .50356 Mtetra
.641 .74 .921 r
.34649 .50356 .35326 .50984 .36415 .50678 .35739 .50066 Mtetra
.642 .747 .925 r
.35739 .50066 .36415 .50678 .37507 .50396 .36835 .49769 Mtetra
.693 .756 .9 r
.36835 .49769 .37507 .50396 .38607 .50059 .37943 .49322 Mtetra
.683 .722 .88 r
.37943 .49322 .38607 .50059 .39718 .49556 .39053 .48899 Mtetra
.664 .741 .907 r
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.41281 .48181 .41941 .48844 .43059 .48485 .42403 .47819 Mtetra
.623 .728 .922 r
.42403 .47819 .43059 .48485 .44182 .48125 .43525 .4757 Mtetra
0 .209 .677 r
.43525 .4757 .44182 .48125 .45303 .4805 .4463 .48329 Mtetra
.533 0 0 r
.4463 .48329 .45303 .4805 .46417 .48716 .45754 .4873 Mtetra
.155 .697 .787 r
.45754 .4873 .46417 .48716 .47549 .49037 .46897 .48598 Mtetra
.722 .834 .934 r
.46897 .48598 .47549 .49037 .48695 .48906 .48052 .48046 Mtetra
.747 .719 .826 r
.48052 .48046 .48695 .48906 .4985 .4842 .49213 .47273 Mtetra
.732 .665 .783 r
.49213 .47273 .4985 .4842 .5101 .47738 .50376 .4644 Mtetra
.717 .639 .769 r
.50376 .4644 .5101 .47738 .52173 .46993 .51541 .45636 Mtetra
.704 .627 .767 r
.51541 .45636 .52173 .46993 .53339 .46261 .52708 .44898 Mtetra
.693 .621 .771 r
.52708 .44898 .53339 .46261 .54507 .45579 .53877 .44235 Mtetra
.666 .611 .784 r
.53877 .44235 .54507 .45579 .55678 .4496 .55051 .43744 Mtetra
.65 .622 .808 r
.55051 .43744 .55678 .4496 .56853 .44405 .5623 .43364 Mtetra
.656 .655 .837 r
.5623 .43364 .56853 .44405 .58034 .43911 .57415 .42983 Mtetra
.66 .681 .859 r
.57415 .42983 .58034 .43911 .59219 .43475 .58604 .42599 Mtetra
.662 .694 .87 r
.58604 .42599 .59219 .43475 .60411 .43093 .59799 .42215 Mtetra
.59799 .42215 .60411 .43093 .6161 .42766 .60998 .41828 Mtetra
.66 .681 .859 r
.60998 .41828 .6161 .42766 .62816 .42498 .62203 .4144 Mtetra
.656 .655 .837 r
.62203 .4144 .62816 .42498 .6403 .42291 .63413 .4105 Mtetra
.626 .61 .815 r
.63413 .4105 .6403 .42291 .65253 .42149 .64633 .40772 Mtetra
.586 .57 .803 r
.64633 .40772 .65253 .42149 .66487 .42071 .65866 .40668 Mtetra
.567 .557 .803 r
.65866 .40668 .66487 .42071 .6773 .42046 .6711 .40642 Mtetra
.551 .549 .805 r
.6711 .40642 .6773 .42046 .68983 .42036 .68366 .40683 Mtetra
.541 .551 .815 r
.68366 .40683 .68983 .42036 .70241 .41962 .69632 .40756 Mtetra
.55 .581 .838 r
.69632 .40756 .70241 .41962 .71495 .4169 .70904 .40769 Mtetra
.606 .669 .884 r
.70904 .40769 .71495 .4169 .72733 .41056 .72172 .40558 Mtetra
.736 .844 .931 r
.72172 .40558 .72733 .41056 .73943 .39958 .73418 .39917 Mtetra
.848 .99 .85 r
.73418 .39917 .73943 .39958 .75129 .38504 .74631 .38731 Mtetra
.848 .986 .707 r
.74631 .38731 .75129 .38504 .76369 .37807 .75816 .37173 Mtetra
.7 .79 .921 r
.75816 .37173 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.664 .741 .907 r
.77078 .36647 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.643 .732 .914 r
.80921 .35409 .81465 .36173 .82769 .35914 .82219 .35062 Mtetra
.636 .705 .896 r
.82219 .35062 .82769 .35914 .84062 .35483 .83527 .34739 Mtetra
.681 .756 .908 r
.83527 .34739 .84062 .35483 .85355 .34995 .84826 .34259 Mtetra
.683 .76 .91 r
.84826 .34259 .85355 .34995 .86656 .34531 .86129 .33772 Mtetra
.673 .75 .909 r
.86129 .33772 .86656 .34531 .87966 .34095 .87442 .33319 Mtetra
.666 .744 .908 r
.87442 .33319 .87966 .34095 .89283 .33668 .88763 .32884 Mtetra
.664 .741 .907 r
.88763 .32884 .89283 .33668 .90606 .33243 .90091 .32455 Mtetra
.663 .741 .908 r
.30707 .50723 .31396 .51366 .32477 .51019 .3179 .50375 Mtetra
.659 .74 .91 r
.3179 .50375 .32477 .51019 .33561 .50678 .32877 .50038 Mtetra
.648 .74 .916 r
.32877 .50038 .33561 .50678 .34649 .50356 .33966 .49729 Mtetra
.637 .742 .924 r
.33966 .49729 .34649 .50356 .35739 .50066 .35059 .49447 Mtetra
.662 .752 .917 r
.35059 .49447 .35739 .50066 .36835 .49769 .3616 .49096 Mtetra
.706 .746 .883 r
.3616 .49096 .36835 .49769 .37943 .49322 .37273 .48596 Mtetra
.663 .721 .892 r
.37273 .48596 .37943 .49322 .39053 .48899 .38383 .48236 Mtetra
.664 .741 .907 r
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.39498 .47875 .40165 .4854 .41281 .48181 .40617 .47513 Mtetra
.40617 .47513 .41281 .48181 .42403 .47819 .41741 .47149 Mtetra
0 .365 .827 r
.41741 .47149 .42403 .47819 .43525 .4757 .42841 .47774 Mtetra
.589 .056 0 r
.42841 .47774 .43525 .4757 .4463 .48329 .43954 .48326 Mtetra
.055 .621 .743 r
.43954 .48326 .4463 .48329 .45754 .4873 .45092 .48287 Mtetra
.722 .833 .933 r
.45092 .48287 .45754 .4873 .46897 .48598 .46246 .47735 Mtetra
.755 .72 .82 r
.46246 .47735 .46897 .48598 .48052 .48046 .47409 .46906 Mtetra
.742 .67 .779 r
.47409 .46906 .48052 .48046 .49213 .47273 .48573 .46002 Mtetra
.728 .647 .769 r
.48573 .46002 .49213 .47273 .50376 .4644 .49739 .45136 Mtetra
.715 .638 .77 r
.49739 .45136 .50376 .4644 .51541 .45636 .50906 .44349 Mtetra
.679 .624 .787 r
.50906 .44349 .51541 .45636 .52708 .44898 .52074 .43803 Mtetra
.654 .644 .827 r
.52074 .43803 .52708 .44898 .53877 .44235 .53247 .43423 Mtetra
.663 .709 .882 r
.53247 .43423 .53877 .44235 .55051 .43744 .54424 .43041 Mtetra
.664 .741 .907 r
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64633 .40772 .64029 .39931 Mtetra
.663 .709 .882 r
.64029 .39931 .64633 .40772 .65866 .40668 .65253 .39535 Mtetra
.614 .625 .838 r
.65253 .39535 .65866 .40668 .6711 .40642 .6649 .39307 Mtetra
.553 .561 .816 r
.6649 .39307 .6711 .40642 .68366 .40683 .67746 .39323 Mtetra
.532 .547 .815 r
.67746 .39323 .68366 .40683 .69632 .40756 .69014 .39423 Mtetra
.52 .544 .821 r
.69014 .39423 .69632 .40756 .70904 .40769 .70294 .39561 Mtetra
.534 .574 .841 r
.70294 .39561 .70904 .40769 .72172 .40558 .7158 .39626 Mtetra
.607 .669 .884 r
.7158 .39626 .72172 .40558 .73418 .39917 .72857 .39409 Mtetra
.762 .849 .916 r
.72857 .39409 .73418 .39917 .74631 .38731 .74106 .38667 Mtetra
.884 .98 .826 r
.74106 .38667 .74631 .38731 .75816 .37173 .75315 .37316 Mtetra
.846 .995 .754 r
.75315 .37316 .75816 .37173 .77078 .36647 .76516 .35887 Mtetra
.664 .741 .907 r
.76516 .35887 .77078 .36647 .78353 .36236 .77795 .35473 Mtetra
.77795 .35473 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82219 .35062 .81668 .34219 Mtetra
.619 .702 .904 r
.81668 .34219 .82219 .35062 .83527 .34739 .82984 .33945 Mtetra
.665 .737 .903 r
.82984 .33945 .83527 .34739 .84826 .34259 .84293 .33516 Mtetra
.686 .761 .908 r
.84293 .33516 .84826 .34259 .86129 .33772 .856 .33014 Mtetra
.677 .754 .909 r
.856 .33014 .86129 .33772 .87442 .33319 .86915 .32541 Mtetra
.669 .746 .908 r
.86915 .32541 .87442 .33319 .88763 .32884 .88239 .32095 Mtetra
.665 .742 .908 r
.88239 .32095 .88763 .32884 .90091 .32455 .89571 .31661 Mtetra
.662 .741 .908 r
.30012 .50076 .30707 .50723 .3179 .50375 .31098 .49728 Mtetra
.655 .74 .912 r
.31098 .49728 .3179 .50375 .32877 .50038 .32187 .49398 Mtetra
.642 .739 .92 r
.32187 .49398 .32877 .50038 .33966 .49729 .33278 .49102 Mtetra
.64 .744 .924 r
.33278 .49102 .33966 .49729 .35059 .49447 .34374 .4881 Mtetra
.693 .754 .899 r
.34374 .4881 .35059 .49447 .3616 .49096 .35483 .48358 Mtetra
.683 .724 .881 r
.35483 .48358 .3616 .49096 .37273 .48596 .36595 .47931 Mtetra
.664 .741 .907 r
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
.38826 .47205 .39498 .47875 .40617 .47513 .39948 .46839 Mtetra
.369 .621 .949 r
.39948 .46839 .40617 .47513 .41741 .47149 .41056 .47027 Mtetra
.613 .046 0 r
.41056 .47027 .41741 .47149 .42841 .47774 .42154 .47785 Mtetra
.212 0 0 r
.42154 .47785 .42841 .47774 .43954 .48326 .43282 .47948 Mtetra
.686 .851 .962 r
.43282 .47948 .43954 .48326 .45092 .48287 .44433 .47485 Mtetra
.762 .735 .828 r
.44433 .47485 .45092 .48287 .46246 .47735 .45596 .46646 Mtetra
.754 .681 .781 r
.45596 .46646 .46246 .47735 .47409 .46906 .46763 .45686 Mtetra
.739 .658 .77 r
.46763 .45686 .47409 .46906 .48573 .46002 .47931 .44757 Mtetra
.726 .65 .774 r
.47931 .44757 .48573 .46002 .49739 .45136 .49098 .43918 Mtetra
.662 .627 .804 r
.49098 .43918 .49739 .45136 .50906 .44349 .50265 .43481 Mtetra
.661 .695 .87 r
.50265 .43481 .50906 .44349 .52074 .43803 .51436 .431 Mtetra
.664 .741 .907 r
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .6649 .39307 .65886 .38397 Mtetra
.646 .688 .876 r
.65886 .38397 .6649 .39307 .67746 .39323 .67127 .38052 Mtetra
.536 .564 .83 r
.67127 .38052 .67746 .39323 .69014 .39423 .68395 .38116 Mtetra
.511 .545 .827 r
.68395 .38116 .69014 .39423 .70294 .39561 .69677 .38273 Mtetra
.499 .542 .831 r
.69677 .38273 .70294 .39561 .7158 .39626 .70971 .38463 Mtetra
.527 .581 .852 r
.70971 .38463 .7158 .39626 .72857 .39409 .72268 .38533 Mtetra
.634 .697 .891 r
.72268 .38533 .72857 .39409 .74106 .38667 .73549 .38218 Mtetra
.814 .878 .893 r
.73549 .38218 .74106 .38667 .75315 .37316 .74793 .37262 Mtetra
.915 .97 .789 r
.74793 .37262 .75315 .37316 .76516 .35887 .75992 .35691 Mtetra
.816 .964 .903 r
.75992 .35691 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.664 .741 .907 r
.77233 .34703 .77795 .35473 .7908 .35057 .78522 .34284 Mtetra
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.643 .732 .914 r
.81118 .33439 .81668 .34219 .82984 .33945 .82431 .33083 Mtetra
.636 .707 .898 r
.82431 .33083 .82984 .33945 .84293 .33516 .83753 .32752 Mtetra
.684 .755 .906 r
.83753 .32752 .84293 .33516 .856 .33014 .85066 .32255 Mtetra
.682 .758 .908 r
.85066 .32255 .856 .33014 .86915 .32541 .86384 .31761 Mtetra
.672 .748 .908 r
.86384 .31761 .86915 .32541 .88239 .32095 .87711 .31301 Mtetra
.665 .743 .908 r
.87711 .31301 .88239 .32095 .89571 .31661 .89047 .30861 Mtetra
.661 .741 .909 r
.29312 .49425 .30012 .50076 .31098 .49728 .304 .49077 Mtetra
.651 .739 .914 r
.304 .49077 .31098 .49728 .32187 .49398 .31491 .48756 Mtetra
.637 .739 .922 r
.31491 .48756 .32187 .49398 .33278 .49102 .32584 .4847 Mtetra
.653 .747 .919 r
.32584 .4847 .33278 .49102 .34374 .4881 .33685 .48141 Mtetra
.709 .75 .884 r
.33685 .48141 .34374 .4881 .35483 .48358 .348 .47624 Mtetra
.663 .721 .892 r
.348 .47624 .35483 .48358 .36595 .47931 .35912 .47261 Mtetra
.664 .741 .907 r
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.37028 .46896 .37708 .47568 .38826 .47205 .38148 .46529 Mtetra
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
0 .156 .656 r
.39273 .46161 .39948 .46839 .41056 .47027 .40358 .47036 Mtetra
.492 0 0 r
.40358 .47036 .41056 .47027 .42154 .47785 .41468 .47509 Mtetra
.535 .847 .998 r
.41468 .47509 .42154 .47785 .43282 .47948 .42612 .4726 Mtetra
.762 .763 .854 r
.42612 .4726 .43282 .47948 .44433 .47485 .43774 .46484 Mtetra
.765 .699 .789 r
.43774 .46484 .44433 .47485 .45596 .46646 .44944 .45491 Mtetra
.752 .672 .773 r
.44944 .45491 .45596 .46646 .46763 .45686 .46115 .44498 Mtetra
.738 .663 .776 r
.46115 .44498 .46763 .45686 .47931 .44757 .47284 .43597 Mtetra
.664 .638 .814 r
.47284 .43597 .47931 .44757 .49098 .43918 .48449 .43159 Mtetra
.663 .724 .894 r
.48449 .43159 .49098 .43918 .50265 .43481 .49618 .42777 Mtetra
.664 .741 .907 r
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67127 .38052 .66527 .37245 Mtetra
.646 .717 .9 r
.66527 .37245 .67127 .38052 .68395 .38116 .67777 .36895 Mtetra
.514 .562 .842 r
.67777 .36895 .68395 .38116 .69677 .38273 .69059 .37016 Mtetra
.486 .541 .839 r
.69059 .37016 .69677 .38273 .70971 .38463 .70355 .37233 Mtetra
.483 .545 .844 r
.70355 .37233 .70971 .38463 .72268 .38533 .71662 .37452 Mtetra
.542 .607 .868 r
.71662 .37452 .72268 .38533 .73549 .38218 .72967 .37452 Mtetra
.698 .754 .895 r
.72967 .37452 .73549 .38218 .74793 .37262 .74244 .36911 Mtetra
.876 .91 .849 r
.74244 .36911 .74793 .37262 .75992 .35691 .75472 .35628 Mtetra
.929 .962 .77 r
.75472 .35628 .75992 .35691 .77233 .34703 .76666 .33927 Mtetra
.664 .741 .907 r
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.7796 .33504 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82431 .33083 .81874 .32223 Mtetra
.615 .7 .905 r
.81874 .32223 .82431 .33083 .83753 .32752 .83207 .31953 Mtetra
.673 .743 .903 r
.83207 .31953 .83753 .32752 .85066 .32255 .84527 .31488 Mtetra
.686 .759 .907 r
.84527 .31488 .85066 .32255 .86384 .31761 .85848 .30977 Mtetra
.675 .751 .908 r
.85848 .30977 .86384 .31761 .87711 .31301 .87179 .30503 Mtetra
.667 .744 .908 r
.87179 .30503 .87711 .31301 .89047 .30861 .88519 .30055 Mtetra
.66 .741 .91 r
.28607 .4877 .29312 .49425 .304 .49077 .29697 .48423 Mtetra
.646 .738 .916 r
.29697 .48423 .304 .49077 .31491 .48756 .3079 .48112 Mtetra
.636 .74 .923 r
.3079 .48112 .31491 .48756 .32584 .4847 .31886 .47827 Mtetra
.673 .75 .909 r
.31886 .47827 .32584 .4847 .33685 .48141 .32993 .47436 Mtetra
.698 .739 .883 r
.32993 .47436 .33685 .48141 .348 .47624 .34109 .46952 Mtetra
.664 .741 .907 r
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
.36342 .46218 .37028 .46896 .38148 .46529 .37465 .45848 Mtetra
.367 .621 .95 r
.37465 .45848 .38148 .46529 .39273 .46161 .3857 .46032 Mtetra
.644 .086 0 r
.3857 .46032 .39273 .46161 .40358 .47036 .39658 .46855 Mtetra
.047 .597 .833 r
.39658 .46855 .40358 .47036 .41468 .47509 .40785 .46971 Mtetra
.73 .803 .91 r
.40785 .46971 .41468 .47509 .42612 .4726 .41942 .46383 Mtetra
.774 .724 .806 r
.41942 .46383 .42612 .4726 .43774 .46484 .43114 .45413 Mtetra
.766 .689 .778 r
.43114 .45413 .43774 .46484 .44944 .45491 .44288 .44363 Mtetra
.753 .677 .778 r
.44288 .44363 .44944 .45491 .46115 .44498 .45461 .43387 Mtetra
.689 .656 .813 r
.45461 .43387 .46115 .44498 .47284 .43597 .46627 .42835 Mtetra
.663 .724 .894 r
.46627 .42835 .47284 .43597 .48449 .43159 .47794 .42452 Mtetra
.664 .741 .907 r
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67777 .36895 .67175 .36078 Mtetra
.609 .702 .91 r
.67175 .36078 .67777 .36895 .69059 .37016 .68441 .35836 Mtetra
.484 .556 .853 r
.68441 .35836 .69059 .37016 .70355 .37233 .69738 .36029 Mtetra
.46 .538 .85 r
.69738 .36029 .70355 .37233 .71662 .37452 .71049 .363 Mtetra
.482 .562 .86 r
.71049 .363 .71662 .37452 .72967 .37452 .72368 .3649 Mtetra
.597 .664 .885 r
.72368 .3649 .72967 .37452 .74244 .36911 .73671 .36292 Mtetra
.794 .826 .877 r
.73671 .36292 .74244 .36911 .75472 .35628 .74931 .35369 Mtetra
.923 .922 .793 r
.74931 .35369 .75472 .35628 .76666 .33927 .76138 .33716 Mtetra
.816 .963 .904 r
.76138 .33716 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.664 .741 .907 r
.77392 .32718 .7796 .33504 .79259 .33079 .78695 .3229 Mtetra
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.625 .724 .918 r
.81319 .31427 .81874 .32223 .83207 .31953 .82652 .31116 Mtetra
.655 .727 .902 r
.82652 .31116 .83207 .31953 .84527 .31488 .83983 .30708 Mtetra
.687 .757 .905 r
.83983 .30708 .84527 .31488 .85848 .30977 .85308 .30191 Mtetra
.679 .753 .907 r
.85308 .30191 .85848 .30977 .87179 .30503 .86642 .29699 Mtetra
.668 .745 .908 r
.86642 .29699 .87179 .30503 .88519 .30055 .87986 .29244 Mtetra
.658 .741 .911 r
.27896 .4811 .28607 .4877 .29697 .48423 .28989 .47766 Mtetra
.642 .738 .918 r
.28989 .47766 .29697 .48423 .3079 .48112 .30083 .47463 Mtetra
.638 .74 .922 r
.30083 .47463 .3079 .48112 .31886 .47827 .31182 .47168 Mtetra
.697 .752 .895 r
.31182 .47168 .31886 .47827 .32993 .47436 .32297 .46697 Mtetra
.68 .727 .885 r
.32297 .46697 .32993 .47436 .34109 .46952 .33412 .46274 Mtetra
.664 .741 .907 r
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.34529 .45905 .35223 .46586 .36342 .46218 .35651 .45534 Mtetra
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
0 .285 .766 r
.36777 .45162 .37465 .45848 .3857 .46032 .3786 .45869 Mtetra
.502 0 0 r
.3786 .45869 .3857 .46032 .39658 .46855 .3896 .46471 Mtetra
.551 .815 .995 r
.3896 .46471 .39658 .46855 .40785 .46971 .40102 .46253 Mtetra
.768 .758 .844 r
.40102 .46253 .40785 .46971 .41942 .46383 .41271 .45423 Mtetra
.779 .711 .788 r
.41271 .45423 .41942 .46383 .43114 .45413 .42449 .44352 Mtetra
.768 .692 .779 r
.42449 .44352 .43114 .45413 .44288 .44363 .43626 .43295 Mtetra
.731 .68 .801 r
.43626 .43295 .44288 .44363 .45461 .43387 .44798 .42511 Mtetra
.661 .695 .871 r
.44798 .42511 .45461 .43387 .46627 .42835 .45963 .42126 Mtetra
.664 .741 .907 r
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68441 .35836 .67832 .34896 Mtetra
.531 .636 .899 r
.67832 .34896 .68441 .35836 .69738 .36029 .6912 .34886 Mtetra
.449 .546 .863 r
.6912 .34886 .69738 .36029 .71049 .363 .70434 .35156 Mtetra
.443 .543 .864 r
.70434 .35156 .71049 .363 .72368 .3649 .71759 .35443 Mtetra
.521 .607 .88 r
.71759 .35443 .72368 .3649 .73671 .36292 .73081 .35486 Mtetra
.706 .751 .887 r
.73081 .35486 .73671 .36292 .74931 .35369 .74369 .349 Mtetra
.884 .875 .822 r
.74369 .349 .74931 .35369 .76138 .33716 .756 .33469 Mtetra
.913 .934 .81 r
.756 .33469 .76138 .33716 .77392 .32718 .7682 .31925 Mtetra
.664 .741 .907 r
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.78127 .31493 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.647 .734 .912 r
.8076 .30623 .81319 .31427 .82652 .31116 .82091 .30242 Mtetra
.631 .708 .902 r
.82091 .30242 .82652 .31116 .83983 .30708 .83433 .29911 Mtetra
.685 .753 .904 r
.83433 .29911 .83983 .30708 .85308 .30191 .84764 .29397 Mtetra
.682 .754 .906 r
.84764 .29397 .85308 .30191 .86642 .29699 .86101 .2889 Mtetra
.669 .746 .908 r
.86101 .2889 .86642 .29699 .87986 .29244 .87449 .28426 Mtetra
.656 .741 .912 r
.2718 .47447 .27896 .4811 .28989 .47766 .28275 .47105 Mtetra
.639 .737 .92 r
.28275 .47105 .28989 .47766 .30083 .47463 .29371 .46807 Mtetra
.645 .742 .919 r
.29371 .46807 .30083 .47463 .31182 .47168 .30474 .46492 Mtetra
.711 .752 .884 r
.30474 .46492 .31182 .47168 .32297 .46697 .31595 .45962 Mtetra
.663 .725 .895 r
.31595 .45962 .32297 .46697 .33412 .46274 .3271 .45591 Mtetra
.664 .741 .907 r
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.3383 .45219 .34529 .45905 .35651 .45534 .34955 .44846 Mtetra
.623 .729 .923 r
.34955 .44846 .35651 .45534 .36777 .45162 .36078 .44582 Mtetra
.531 .002 0 r
.36078 .44582 .36777 .45162 .3786 .45869 .37149 .45575 Mtetra
0 .427 .754 r
.37149 .45575 .3786 .45869 .3896 .46471 .38261 .45923 Mtetra
.698 .797 .926 r
.38261 .45923 .3896 .46471 .40102 .46253 .39417 .45437 Mtetra
.782 .739 .813 r
.39417 .45437 .40102 .46253 .41271 .45423 .40595 .44451 Mtetra
.783 .711 .784 r
.40595 .44451 .41271 .45423 .42449 .44352 .41778 .43336 Mtetra
.77 .701 .786 r
.41778 .43336 .42449 .44352 .43626 .43295 .42959 .42298 Mtetra
.684 .677 .838 r
.42959 .42298 .43626 .43295 .44798 .42511 .44126 .41798 Mtetra
.664 .741 .907 r
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.626 .726 .919 r
.67227 .34122 .67832 .34896 .6912 .34886 .68504 .33815 Mtetra
.445 .561 .878 r
.68504 .33815 .6912 .34886 .70434 .35156 .69817 .34059 Mtetra
.417 .54 .873 r
.69817 .34059 .70434 .35156 .71759 .35443 .71147 .34384 Mtetra
.463 .576 .882 r
.71147 .34384 .71759 .35443 .73081 .35486 .7248 .34578 Mtetra
.629 .696 .893 r
.7248 .34578 .73081 .35486 .74369 .349 .73791 .34262 Mtetra
.834 .83 .843 r
.73791 .34262 .74369 .349 .756 .33469 .75047 .33085 Mtetra
.93 .887 .768 r
.75047 .33085 .756 .33469 .7682 .31925 .76252 .31241 Mtetra
.699 .788 .92 r
.76252 .31241 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.664 .741 .907 r
.77555 .3069 .78127 .31493 .79441 .31059 .78872 .30252 Mtetra
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82091 .30242 .81525 .29371 Mtetra
.613 .703 .908 r
.81525 .29371 .82091 .30242 .83433 .29911 .82877 .29095 Mtetra
.679 .748 .903 r
.82877 .29095 .83433 .29911 .84764 .29397 .84215 .28595 Mtetra
.685 .755 .905 r
.84215 .28595 .84764 .29397 .86101 .2889 .85556 .28075 Mtetra
.671 .747 .908 r
.85556 .28075 .86101 .2889 .87449 .28426 .86908 .27602 Mtetra
.655 .74 .912 r
.26458 .46779 .2718 .47447 .28275 .47105 .27555 .46437 Mtetra
.637 .737 .92 r
.27555 .46437 .28275 .47105 .29371 .46807 .28654 .46143 Mtetra
.654 .743 .915 r
.28654 .46143 .29371 .46807 .30474 .46492 .29761 .45802 Mtetra
.708 .749 .883 r
.29761 .45802 .30474 .46492 .31595 .45962 .30885 .45277 Mtetra
.664 .741 .907 r
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.33125 .44528 .3383 .45219 .34955 .44846 .34253 .44152 Mtetra
.434 .654 .952 r
.34253 .44152 .34955 .44846 .36078 .44582 .35361 .44238 Mtetra
.619 .058 0 r
.35361 .44238 .36078 .44582 .37149 .45575 .36436 .45151 Mtetra
.268 .671 .968 r
.36436 .45151 .37149 .45575 .38261 .45923 .37561 .45268 Mtetra
.745 .773 .876 r
.37561 .45268 .38261 .45923 .39417 .45437 .38729 .44586 Mtetra
.79 .734 .801 r
.38729 .44586 .39417 .45437 .40595 .44451 .39914 .43507 Mtetra
.787 .717 .787 r
.39914 .43507 .40595 .44451 .41778 .43336 .41102 .4238 Mtetra
.759 .709 .805 r
.41102 .4238 .41778 .43336 .42959 .42298 .42282 .4147 Mtetra
.662 .709 .883 r
.42282 .4147 .42959 .42298 .44126 .41798 .43448 .4108 Mtetra
.664 .741 .907 r
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68504 .33815 .67892 .32915 Mtetra
.472 .621 .915 r
.67892 .32915 .68504 .33815 .69817 .34059 .692 .33021 Mtetra
.399 .546 .886 r
.692 .33021 .69817 .34059 .71147 .34384 .70532 .33351 Mtetra
.419 .559 .888 r
.70532 .33351 .71147 .34384 .7248 .34578 .71873 .33634 Mtetra
.566 .66 .9 r
.71873 .33634 .7248 .34578 .73791 .34262 .732 .33512 Mtetra
.786 .794 .859 r
.732 .33512 .73791 .34262 .75047 .33085 .74478 .32567 Mtetra
.911 .858 .776 r
.74478 .32567 .75047 .33085 .76252 .31241 .75697 .30799 Mtetra
.801 .894 .91 r
.75697 .30799 .76252 .31241 .77555 .3069 .76977 .2988 Mtetra
.664 .741 .907 r
.76977 .2988 .77555 .3069 .78872 .30252 .78299 .29439 Mtetra
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.614 .719 .921 r
.80961 .2855 .81525 .29371 .82877 .29095 .82316 .28262 Mtetra
.672 .742 .903 r
.82316 .28262 .82877 .29095 .84215 .28595 .8366 .27782 Mtetra
.686 .754 .903 r
.8366 .27782 .84215 .28595 .85556 .28075 .85005 .27252 Mtetra
.672 .747 .907 r
.85005 .27252 .85556 .28075 .86908 .27602 .86362 .26772 Mtetra
.654 .74 .913 r
.2573 .46105 .26458 .46779 .27555 .46437 .2683 .45764 Mtetra
.636 .736 .921 r
.2683 .45764 .27555 .46437 .28654 .46143 .27931 .45469 Mtetra
.662 .744 .911 r
.27931 .45469 .28654 .46143 .29761 .45802 .29042 .45101 Mtetra
.705 .747 .884 r
.29042 .45101 .29761 .45802 .30885 .45277 .30169 .44586 Mtetra
.664 .741 .907 r
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
.32415 .43832 .33125 .44528 .34253 .44152 .33546 .43452 Mtetra
.209 .535 .924 r
.33546 .43452 .34253 .44152 .35361 .44238 .34641 .43804 Mtetra
.505 0 0 r
.34641 .43804 .35361 .44238 .36436 .45151 .35722 .44618 Mtetra
.484 .738 .983 r
.35722 .44618 .36436 .45151 .37561 .45268 .36858 .44555 Mtetra
.766 .762 .85 r
.36858 .44555 .37561 .45268 .38729 .44586 .38035 .43741 Mtetra
.797 .737 .797 r
.38035 .43741 .38729 .44586 .39914 .43507 .39227 .4261 Mtetra
.792 .728 .793 r
.39227 .4261 .39914 .43507 .41102 .4238 .40418 .41483 Mtetra
.736 .716 .832 r
.40418 .41483 .41102 .4238 .42282 .4147 .41596 .40749 Mtetra
.664 .741 .907 r
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.535 .686 .936 r
.6728 .32124 .67892 .32915 .692 .33021 .68582 .32044 Mtetra
.385 .555 .899 r
.68582 .32044 .692 .33021 .70532 .33351 .69916 .32366 Mtetra
.384 .553 .898 r
.69916 .32366 .70532 .33351 .71873 .33634 .71262 .32695 Mtetra
.516 .638 .908 r
.71262 .32695 .71873 .33634 .732 .33512 .726 .32702 Mtetra
.745 .769 .872 r
.726 .32702 .732 .33512 .74478 .32567 .73896 .31936 Mtetra
.891 .835 .784 r
.73896 .31936 .74478 .32567 .75697 .30799 .75129 .30263 Mtetra
.848 .867 .855 r
.75129 .30263 .75697 .30799 .76977 .2988 .76394 .29064 Mtetra
.664 .741 .907 r
.76394 .29064 .76977 .2988 .78299 .29439 .7772 .28618 Mtetra
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.618 .721 .92 r
.80391 .27722 .80961 .2855 .82316 .28262 .8175 .27416 Mtetra
.665 .738 .904 r
.8175 .27416 .82316 .28262 .8366 .27782 .83101 .26957 Mtetra
.687 .753 .902 r
.83101 .26957 .8366 .27782 .85005 .27252 .8445 .26421 Mtetra
.673 .747 .906 r
.8445 .26421 .85005 .27252 .86362 .26772 .85811 .25933 Mtetra
.653 .739 .913 r
.24997 .45424 .2573 .46105 .2683 .45764 .26099 .45082 Mtetra
.636 .735 .92 r
.26099 .45082 .2683 .45764 .27931 .45469 .27203 .44786 Mtetra
.668 .744 .907 r
.27203 .44786 .27931 .45469 .29042 .45101 .28319 .44396 Mtetra
.702 .746 .886 r
.28319 .44396 .29042 .45101 .30169 .44586 .29447 .4389 Mtetra
.664 .741 .907 r
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.024 .419 .862 r
.32833 .42747 .33546 .43452 .34641 .43804 .33919 .43274 Mtetra
0 .178 .624 r
.33919 .43274 .34641 .43804 .35722 .44618 .35005 .44006 Mtetra
.574 .746 .958 r
.35005 .44006 .35722 .44618 .36858 .44555 .3615 .4382 Mtetra
.776 .759 .837 r
.3615 .4382 .36858 .44555 .38035 .43741 .37335 .42926 Mtetra
.803 .745 .799 r
.37335 .42926 .38035 .43741 .39227 .4261 .38532 .41766 Mtetra
.797 .74 .8 r
.38532 .41766 .39227 .4261 .40418 .41483 .39727 .40644 Mtetra
.719 .726 .856 r
.39727 .40644 .40418 .41483 .41596 .40749 .40904 .40022 Mtetra
.664 .741 .907 r
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.584 .708 .928 r
.66664 .31327 .6728 .32124 .68582 .32044 .67963 .31124 Mtetra
.371 .564 .911 r
.67963 .31124 .68582 .32044 .69916 .32366 .69299 .31435 Mtetra
.355 .552 .908 r
.69299 .31435 .69916 .32366 .71262 .32695 .70648 .31785 Mtetra
.478 .628 .918 r
.70648 .31785 .71262 .32695 .726 .32702 .71995 .31868 Mtetra
.717 .756 .883 r
.71995 .31868 .726 .32702 .73896 .31936 .73303 .31221 Mtetra
.875 .817 .788 r
.73303 .31221 .73896 .31936 .75129 .30263 .74549 .29626 Mtetra
.863 .839 .82 r
.74549 .29626 .75129 .30263 .76394 .29064 .75807 .2824 Mtetra
.664 .741 .907 r
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.622 .723 .919 r
.79817 .26886 .80391 .27722 .8175 .27416 .81178 .26564 Mtetra
.659 .735 .906 r
.81178 .26564 .8175 .27416 .83101 .26957 .82536 .26121 Mtetra
.687 .752 .901 r
.82536 .26121 .83101 .26957 .8445 .26421 .8389 .25581 Mtetra
.673 .746 .906 r
.8389 .25581 .8445 .26421 .85811 .25933 .85255 .25086 Mtetra
.653 .739 .913 r
.24258 .44737 .24997 .45424 .26099 .45082 .25363 .44393 Mtetra
.636 .734 .919 r
.25363 .44393 .26099 .45082 .27203 .44786 .26469 .44094 Mtetra
.672 .744 .905 r
.26469 .44094 .27203 .44786 .28319 .44396 .27589 .4369 Mtetra
.7 .747 .888 r
.27589 .4369 .28319 .44396 .29447 .4389 .2872 .43188 Mtetra
.664 .741 .907 r
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
0 .352 .817 r
.32114 .42036 .32833 .42747 .33919 .43274 .33196 .42649 Mtetra
0 .264 .729 r
.33196 .42649 .33919 .43274 .35005 .44006 .34285 .43335 Mtetra
.608 .739 .938 r
.34285 .43335 .35005 .44006 .3615 .4382 .35436 .43087 Mtetra
.782 .762 .834 r
.35436 .43087 .3615 .4382 .37335 .42926 .36627 .42152 Mtetra
.809 .755 .803 r
.36627 .42152 .37335 .42926 .38532 .41766 .37829 .40979 Mtetra
.802 .753 .807 r
.37829 .40979 .38532 .41766 .39727 .40644 .39029 .39858 Mtetra
.709 .738 .874 r
.39029 .39858 .39727 .40644 .40904 .40022 .40207 .3929 Mtetra
.664 .741 .907 r
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.606 .718 .924 r
.66042 .30522 .66664 .31327 .67963 .31124 .67342 .30258 Mtetra
.355 .573 .922 r
.67342 .30258 .67963 .31124 .69299 .31435 .6868 .3056 Mtetra
.328 .556 .918 r
.6868 .3056 .69299 .31435 .70648 .31785 .70033 .30918 Mtetra
.452 .628 .929 r
.70033 .30918 .70648 .31785 .71995 .31868 .71384 .31034 Mtetra
.702 .753 .891 r
.71384 .31034 .71995 .31868 .73303 .31221 .72701 .30444 Mtetra
.864 .804 .789 r
.72701 .30444 .73303 .31221 .74549 .29626 .73957 .28891 Mtetra
.863 .815 .801 r
.73957 .28891 .74549 .29626 .75807 .2824 .75214 .27409 Mtetra
.664 .741 .907 r
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.625 .724 .918 r
.79237 .26044 .79817 .26886 .81178 .26564 .80602 .2571 Mtetra
.656 .736 .908 r
.80602 .2571 .81178 .26564 .82536 .26121 .81965 .25275 Mtetra
.687 .751 .901 r
.81965 .25275 .82536 .26121 .8389 .25581 .83324 .2473 Mtetra
.673 .746 .905 r
.83324 .2473 .8389 .25581 .85255 .25086 .84694 .2423 Mtetra
.653 .738 .912 r
.23513 .44042 .24258 .44737 .25363 .44393 .24621 .43695 Mtetra
.636 .734 .919 r
.24621 .43695 .25363 .44393 .26469 .44094 .2573 .43393 Mtetra
.672 .743 .904 r
.2573 .43393 .26469 .44094 .27589 .4369 .26852 .42986 Mtetra
.7 .749 .89 r
.26852 .42986 .27589 .4369 .2872 .43188 .27987 .42481 Mtetra
.664 .741 .907 r
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
0 .352 .817 r
.3139 .4132 .32114 .42036 .33196 .42649 .32472 .41931 Mtetra
0 .298 .776 r
.32472 .41931 .33196 .42649 .34285 .43335 .33562 .42616 Mtetra
.61 .727 .928 r
.33562 .42616 .34285 .43335 .35436 .43087 .34716 .42365 Mtetra
.784 .766 .836 r
.34716 .42365 .35436 .43087 .36627 .42152 .3591 .41426 Mtetra
.814 .767 .809 r
.3591 .41426 .36627 .42152 .37829 .40979 .37118 .40249 Mtetra
.809 .767 .814 r
.37118 .40249 .37829 .40979 .39029 .39858 .38322 .39123 Mtetra
.712 .754 .885 r
.38322 .39123 .39029 .39858 .40207 .3929 .39504 .38551 Mtetra
.664 .741 .907 r
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.606 .718 .924 r
.65415 .29711 .66042 .30522 .67342 .30258 .66719 .29443 Mtetra
.335 .579 .932 r
.66719 .29443 .67342 .30258 .6868 .3056 .68059 .29743 Mtetra
.304 .561 .927 r
.68059 .29743 .6868 .3056 .70033 .30918 .69415 .30098 Mtetra
.44 .638 .94 r
.69415 .30098 .70033 .30918 .71384 .31034 .7077 .30212 Mtetra
.703 .758 .895 r
.7077 .30212 .71384 .31034 .72701 .30444 .72091 .29618 Mtetra
.859 .794 .786 r
.72091 .29618 .72701 .30444 .73957 .28891 .73353 .28058 Mtetra
.852 .794 .793 r
.73353 .28058 .73957 .28891 .75214 .27409 .74616 .26571 Mtetra
.664 .741 .907 r
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.625 .724 .918 r
.78653 .25194 .79237 .26044 .80602 .2571 .80022 .24857 Mtetra
.656 .738 .91 r
.80022 .24857 .80602 .2571 .81965 .25275 .8139 .24417 Mtetra
.687 .75 .9 r
.8139 .24417 .81965 .25275 .83324 .2473 .82753 .23868 Mtetra
.673 .745 .904 r
.82753 .23868 .83324 .2473 .84694 .2423 .84128 .23364 Mtetra
.653 .738 .911 r
.22763 .43339 .23513 .44042 .24621 .43695 .23874 .42988 Mtetra
.636 .733 .918 r
.23874 .42988 .24621 .43695 .2573 .43393 .24985 .42683 Mtetra
.668 .741 .905 r
.24985 .42683 .2573 .43393 .26852 .42986 .2611 .42284 Mtetra
.702 .752 .89 r
.2611 .42284 .26852 .42986 .27987 .42481 .27248 .41768 Mtetra
.664 .741 .907 r
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.024 .419 .862 r
.3066 .40598 .3139 .4132 .32472 .41931 .31748 .4112 Mtetra
0 .291 .782 r
.31748 .4112 .32472 .41931 .33562 .42616 .32835 .41849 Mtetra
.588 .707 .925 r
.32835 .41849 .33562 .42616 .34716 .42365 .33988 .41655 Mtetra
.78 .77 .843 r
.33988 .41655 .34716 .42365 .3591 .41426 .35186 .40748 Mtetra
.819 .779 .816 r
.35186 .40748 .3591 .41426 .37118 .40249 .36398 .39575 Mtetra
.816 .782 .821 r
.36398 .39575 .37118 .40249 .38322 .39123 .37608 .38439 Mtetra
.729 .773 .887 r
.37608 .38439 .38322 .39123 .39504 .38551 .38796 .37807 Mtetra
.664 .741 .907 r
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.584 .708 .928 r
.64783 .28893 .65415 .29711 .66719 .29443 .66093 .2868 Mtetra
.309 .583 .939 r
.66093 .2868 .66719 .29443 .68059 .29743 .67437 .28983 Mtetra
.283 .569 .935 r
.67437 .28983 .68059 .29743 .69415 .30098 .68795 .29327 Mtetra
.445 .658 .952 r
.68795 .29327 .69415 .30098 .7077 .30212 .70151 .294 Mtetra
.719 .768 .891 r
.70151 .294 .7077 .30212 .72091 .29618 .71474 .28741 Mtetra
.859 .785 .778 r
.71474 .28741 .72091 .29618 .73353 .28058 .72738 .27129 Mtetra
.833 .772 .794 r
.72738 .27129 .73353 .28058 .74616 .26571 .74014 .25726 Mtetra
.664 .741 .907 r
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.622 .723 .919 r
.78063 .24337 .78653 .25194 .80022 .24857 .79438 .24004 Mtetra
.66 .741 .91 r
.79438 .24004 .80022 .24857 .8139 .24417 .80809 .23549 Mtetra
.686 .749 .899 r
.80809 .23549 .8139 .24417 .82753 .23868 .82177 .22995 Mtetra
.673 .744 .904 r
.82177 .22995 .82753 .23868 .84128 .23364 .83556 .22489 Mtetra
.654 .737 .911 r
.22007 .42629 .22763 .43339 .23874 .42988 .23121 .42273 Mtetra
.636 .732 .917 r
.23121 .42273 .23874 .42988 .24985 .42683 .24235 .41964 Mtetra
.662 .739 .907 r
.24235 .41964 .24985 .42683 .2611 .42284 .2536 .41582 Mtetra
.706 .754 .889 r
.2536 .41582 .2611 .42284 .27248 .41768 .26503 .4105 Mtetra
.664 .741 .907 r
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.209 .535 .924 r
.29924 .3987 .3066 .40598 .31748 .4112 .31025 .40213 Mtetra
0 .257 .764 r
.31025 .40213 .31748 .4112 .32835 .41849 .32106 .41023 Mtetra
.538 .672 .924 r
.32106 .41023 .32835 .41849 .33988 .41655 .33254 .40947 Mtetra
.768 .771 .855 r
.33254 .40947 .33988 .41655 .35186 .40748 .34452 .40112 Mtetra
.821 .791 .824 r
.34452 .40112 .35186 .40748 .36398 .39575 .35668 .38959 Mtetra
.823 .797 .827 r
.35668 .38959 .36398 .39575 .37608 .38439 .36884 .3781 Mtetra
.76 .794 .881 r
.36884 .3781 .37608 .38439 .38796 .37807 .38082 .37056 Mtetra
.664 .741 .907 r
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.535 .686 .936 r
.64145 .28068 .64783 .28893 .66093 .2868 .65464 .27971 Mtetra
.276 .584 .944 r
.65464 .27971 .66093 .2868 .67437 .28983 .66811 .28281 Mtetra
.269 .583 .944 r
.66811 .28281 .67437 .28983 .68795 .29327 .68172 .28597 Mtetra
.474 .69 .961 r
.68172 .28597 .68795 .29327 .70151 .294 .69527 .28589 Mtetra
.748 .779 .878 r
.69527 .28589 .70151 .294 .71474 .28741 .70847 .27801 Mtetra
.86 .774 .765 r
.70847 .27801 .71474 .28741 .72738 .27129 .72112 .26098 Mtetra
.801 .746 .802 r
.72112 .26098 .72738 .27129 .74014 .25726 .73405 .24874 Mtetra
.664 .741 .907 r
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.618 .721 .92 r
.77468 .23472 .78063 .24337 .79438 .24004 .78848 .23148 Mtetra
.666 .745 .91 r
.78848 .23148 .79438 .24004 .80809 .23549 .80222 .22669 Mtetra
.686 .748 .899 r
.80222 .22669 .80809 .23549 .82177 .22995 .81596 .22112 Mtetra
.672 .743 .903 r
.81596 .22112 .82177 .22995 .83556 .22489 .8298 .21603 Mtetra
.655 .737 .91 r
.21246 .41912 .22007 .42629 .23121 .42273 .22362 .4155 Mtetra
.637 .731 .916 r
.22362 .4155 .23121 .42273 .24235 .41964 .23479 .41236 Mtetra
.654 .735 .909 r
.23479 .41236 .24235 .41964 .2536 .41582 .24605 .40874 Mtetra
.71 .755 .887 r
.24605 .40874 .2536 .41582 .26503 .4105 .25752 .40326 Mtetra
.664 .741 .907 r
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.28033 .39535 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.434 .654 .952 r
.29182 .39136 .29924 .3987 .31025 .40213 .30303 .39207 Mtetra
0 .213 .736 r
.30303 .39207 .31025 .40213 .32106 .41023 .31377 .40114 Mtetra
.455 .613 .916 r
.31377 .40114 .32106 .41023 .33254 .40947 .32515 .40216 Mtetra
.742 .763 .87 r
.32515 .40216 .33254 .40947 .34452 .40112 .3371 .39508 Mtetra
.819 .8 .834 r
.3371 .39508 .34452 .40112 .35668 .38959 .34929 .38398 Mtetra
.83 .812 .833 r
.34929 .38398 .35668 .38959 .36884 .3781 .36151 .37239 Mtetra
.798 .813 .864 r
.36151 .37239 .36884 .3781 .38082 .37056 .37362 .363 Mtetra
.664 .741 .907 r
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.448 .642 .94 r
.63502 .27235 .64145 .28068 .65464 .27971 .64832 .27321 Mtetra
.239 .584 .945 r
.64832 .27321 .65464 .27971 .66811 .28281 .66183 .27633 Mtetra
.272 .606 .954 r
.66183 .27633 .66811 .28281 .68172 .28597 .67544 .27898 Mtetra
.533 .731 .965 r
.67544 .27898 .68172 .28597 .69527 .28589 .68897 .27753 Mtetra
.782 .783 .854 r
.68897 .27753 .69527 .28589 .70847 .27801 .70211 .26775 Mtetra
.86 .76 .751 r
.70211 .26775 .70847 .27801 .72112 .26098 .71476 .24965 Mtetra
.752 .712 .815 r
.71476 .24965 .72112 .26098 .73405 .24874 .72792 .24014 Mtetra
.664 .741 .907 r
.72792 .24014 .73405 .24874 .74753 .24409 .74144 .23545 Mtetra
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.614 .719 .921 r
.76869 .226 .77468 .23472 .78848 .23148 .78254 .22286 Mtetra
.673 .748 .907 r
.78254 .22286 .78848 .23148 .80222 .22669 .7963 .21777 Mtetra
.685 .747 .898 r
.7963 .21777 .80222 .22669 .81596 .22112 .81009 .21219 Mtetra
.671 .742 .903 r
.81009 .21219 .81596 .22112 .8298 .21603 .82398 .20709 Mtetra
.656 .737 .909 r
.20478 .41189 .21246 .41912 .22362 .4155 .21597 .4082 Mtetra
.639 .732 .915 r
.21597 .4082 .22362 .4155 .23479 .41236 .22717 .40497 Mtetra
.646 .732 .912 r
.22717 .40497 .23479 .41236 .24605 .40874 .23844 .40156 Mtetra
.711 .754 .885 r
.23844 .40156 .24605 .40874 .25752 .40326 .24995 .39596 Mtetra
.664 .741 .907 r
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.27283 .38798 .28033 .39535 .29182 .39136 .28434 .38397 Mtetra
.623 .729 .923 r
.28434 .38397 .29182 .39136 .30303 .39207 .29582 .38107 Mtetra
0 .183 .716 r
.29582 .38107 .30303 .39207 .31377 .40114 .30649 .39094 Mtetra
.337 .524 .891 r
.30649 .39094 .31377 .40114 .32515 .40216 .31773 .39426 Mtetra
.694 .739 .886 r
.31773 .39426 .32515 .40216 .3371 .39508 .3296 .38909 Mtetra
.808 .804 .848 r
.3296 .38909 .3371 .39508 .34929 .38398 .34179 .37885 Mtetra
.834 .826 .84 r
.34179 .37885 .34929 .38398 .36151 .37239 .35407 .3673 Mtetra
.824 .83 .853 r
.35407 .3673 .36151 .37239 .37362 .363 .3663 .35652 Mtetra
.701 .783 .915 r
.3663 .35652 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.664 .741 .907 r
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.626 .726 .919 r
.61546 .26851 .62199 .27687 .63502 .27235 .62857 .26513 Mtetra
.332 .617 .954 r
.62857 .26513 .63502 .27235 .64832 .27321 .64196 .26733 Mtetra
.205 .587 .944 r
.64196 .26733 .64832 .27321 .66183 .27633 .6555 .27035 Mtetra
.311 .649 .969 r
.6555 .27035 .66183 .27633 .67544 .27898 .66912 .27205 Mtetra
.619 .772 .954 r
.66912 .27205 .67544 .27898 .68897 .27753 .68259 .26856 Mtetra
.813 .777 .819 r
.68259 .26856 .68897 .27753 .70211 .26775 .69565 .25633 Mtetra
.855 .742 .738 r
.69565 .25633 .70211 .26775 .71476 .24965 .7083 .23734 Mtetra
.679 .666 .831 r
.7083 .23734 .71476 .24965 .72792 .24014 .72173 .23146 Mtetra
.664 .741 .907 r
.72173 .23146 .72792 .24014 .74144 .23545 .7353 .22673 Mtetra
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.611 .718 .921 r
.76263 .2172 .76869 .226 .78254 .22286 .77654 .2141 Mtetra
.68 .75 .904 r
.77654 .2141 .78254 .22286 .7963 .21777 .79033 .20873 Mtetra
.684 .745 .898 r
.79033 .20873 .7963 .21777 .81009 .21219 .80416 .20316 Mtetra
.67 .741 .903 r
.80416 .20316 .81009 .21219 .82398 .20709 .81811 .19806 Mtetra
.658 .738 .909 r
.19704 .4046 .20478 .41189 .21597 .4082 .20827 .40084 Mtetra
.643 .732 .914 r
.20827 .40084 .21597 .4082 .22717 .40497 .2195 .39749 Mtetra
.639 .729 .913 r
.2195 .39749 .22717 .40497 .23844 .40156 .23078 .39422 Mtetra
.696 .748 .892 r
.23078 .39422 .23844 .40156 .24995 .39596 .24227 .38915 Mtetra
.683 .761 .911 r
.24227 .38915 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.664 .741 .907 r
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.26526 .38056 .27283 .38798 .28434 .38397 .2768 .37651 Mtetra
.2768 .37651 .28434 .38397 .29582 .38107 .28839 .37245 Mtetra
0 .317 .803 r
.28839 .37245 .29582 .38107 .30649 .39094 .29926 .37939 Mtetra
.204 .414 .845 r
.29926 .37939 .30649 .39094 .31773 .39426 .31033 .38525 Mtetra
.608 .686 .897 r
.31033 .38525 .31773 .39426 .3296 .38909 .32205 .38276 Mtetra
.781 .797 .866 r
.32205 .38276 .3296 .38909 .34179 .37885 .33421 .37401 Mtetra
.832 .836 .85 r
.33421 .37401 .34179 .37885 .35407 .3673 .34652 .36282 Mtetra
.833 .848 .857 r
.34652 .36282 .35407 .3673 .3663 .35652 .35883 .35176 Mtetra
.783 .846 .899 r
.35883 .35176 .3663 .35652 .37829 .35121 .371 .34348 Mtetra
.664 .741 .907 r
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.507 .673 .939 r
.60888 .26009 .61546 .26851 .62857 .26513 .62212 .25965 Mtetra
.223 .614 .953 r
.62212 .25965 .62857 .26513 .64196 .26733 .63556 .26207 Mtetra
.196 .605 .946 r
.63556 .26207 .64196 .26733 .6555 .27035 .64913 .26465 Mtetra
.404 .714 .986 r
.64913 .26465 .6555 .27035 .66912 .27205 .66271 .26475 Mtetra
.712 .795 .916 r
.66271 .26475 .66912 .27205 .68259 .26856 .67609 .25843 Mtetra
.833 .759 .782 r
.67609 .25843 .68259 .26856 .69565 .25633 .68906 .24352 Mtetra
.817 .714 .751 r
.68906 .24352 .69565 .25633 .7083 .23734 .70194 .22746 Mtetra
.662 .71 .884 r
.70194 .22746 .7083 .23734 .72173 .23146 .71549 .22271 Mtetra
.664 .741 .907 r
.71549 .22271 .72173 .23146 .7353 .22673 .7291 .21794 Mtetra
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.647 .734 .912 r
.74278 .21314 .74893 .22198 .76263 .2172 .75657 .2089 Mtetra
.628 .742 .929 r
.75657 .2089 .76263 .2172 .77654 .2141 .77047 .20517 Mtetra
.684 .749 .9 r
.77047 .20517 .77654 .2141 .79033 .20873 .7843 .19958 Mtetra
.681 .743 .898 r
.7843 .19958 .79033 .20873 .80416 .20316 .79819 .19405 Mtetra
.669 .74 .904 r
.79819 .19405 .80416 .20316 .81811 .19806 .81219 .18895 Mtetra
.66 .739 .908 r
.18924 .39727 .19704 .4046 .20827 .40084 .2005 .39342 Mtetra
.646 .734 .913 r
.2005 .39342 .20827 .40084 .2195 .39749 .21177 .38993 Mtetra
.637 .728 .914 r
.21177 .38993 .2195 .39749 .23078 .39422 .22307 .38671 Mtetra
.673 .74 .901 r
.22307 .38671 .23078 .39422 .24227 .38915 .23452 .38239 Mtetra
.702 .768 .903 r
.23452 .38239 .24227 .38915 .25376 .38459 .2461 .37713 Mtetra
.664 .741 .907 r
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .2768 .37651 .2692 .36899 Mtetra
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.367 .621 .95 r
.28082 .3649 .28839 .37245 .29926 .37939 .29208 .36645 Mtetra
.096 .314 .791 r
.29208 .36645 .29926 .37939 .31033 .38525 .30298 .37455 Mtetra
.479 .589 .886 r
.30298 .37455 .31033 .38525 .32205 .38276 .31449 .37543 Mtetra
.724 .765 .885 r
.31449 .37543 .32205 .38276 .33421 .37401 .32655 .36908 Mtetra
.817 .837 .864 r
.32655 .36908 .33421 .37401 .34652 .36282 .33886 .35882 Mtetra
.837 .862 .863 r
.33886 .35882 .34652 .36282 .35883 .35176 .35123 .34774 Mtetra
.826 .866 .876 r
.35123 .34774 .35883 .35176 .371 .34348 .36356 .33742 Mtetra
.719 .804 .917 r
.36356 .33742 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.664 .741 .907 r
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.606 .718 .924 r
.58915 .2562 .59583 .26466 .60888 .26009 .60228 .25334 Mtetra
.345 .645 .966 r
.60228 .25334 .60888 .26009 .62212 .25965 .61562 .25492 Mtetra
.172 .61 .939 r
.61562 .25492 .62212 .25965 .63556 .26207 .6291 .25729 Mtetra
.245 .656 .962 r
.6291 .25729 .63556 .26207 .64913 .26465 .64268 .25884 Mtetra
.552 .785 .985 r
.64268 .25884 .64913 .26465 .66271 .26475 .65621 .25641 Mtetra
.783 .788 .857 r
.65621 .25641 .66271 .26475 .67609 .25843 .66947 .24657 Mtetra
.837 .733 .749 r
.66947 .24657 .67609 .25843 .68906 .24352 .68237 .22927 Mtetra
.743 .668 .776 r
.68237 .22927 .68906 .24352 .70194 .22746 .6956 .21867 Mtetra
.664 .741 .907 r
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.70919 .21388 .71549 .22271 .7291 .21794 .72285 .20907 Mtetra
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.625 .724 .918 r
.73657 .20423 .74278 .21314 .75657 .2089 .75046 .20063 Mtetra
.655 .756 .924 r
.75046 .20063 .75657 .2089 .77047 .20517 .76435 .19604 Mtetra
.686 .746 .897 r
.76435 .19604 .77047 .20517 .7843 .19958 .77821 .19032 Mtetra
.678 .741 .898 r
.77821 .19032 .7843 .19958 .79819 .19405 .79216 .18486 Mtetra
.667 .74 .904 r
.79216 .18486 .79819 .19405 .81219 .18895 .80621 .17978 Mtetra
.661 .739 .908 r
.18137 .38988 .18924 .39727 .2005 .39342 .19266 .38596 Mtetra
.651 .736 .911 r
.19266 .38596 .2005 .39342 .21177 .38993 .20398 .38231 Mtetra
.638 .728 .914 r
.20398 .38231 .21177 .38993 .22307 .38671 .2153 .37902 Mtetra
.653 .732 .907 r
.2153 .37902 .22307 .38671 .23452 .38239 .22673 .37529 Mtetra
.711 .761 .892 r
.22673 .37529 .23452 .38239 .2461 .37713 .23838 .36962 Mtetra
.664 .741 .907 r
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.26153 .36141 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.27319 .35728 .28082 .3649 .29208 .36645 .28489 .35313 Mtetra
.069 .29 .776 r
.28489 .35313 .29208 .36645 .30298 .37455 .29573 .36175 Mtetra
.325 .461 .844 r
.29573 .36175 .30298 .37455 .31449 .37543 .307 .36623 Mtetra
.621 .69 .893 r
.307 .36623 .31449 .37543 .32655 .36908 .31886 .36329 Mtetra
.777 .816 .884 r
.31886 .36329 .32655 .36908 .33886 .35882 .33111 .35494 Mtetra
.83 .869 .874 r
.33111 .35494 .33886 .35882 .35123 .34774 .34352 .34437 Mtetra
.833 .885 .879 r
.34352 .34437 .35123 .34774 .36356 .33742 .35593 .33379 Mtetra
.815 .882 .894 r
.35593 .33379 .36356 .33742 .3757 .33145 .3683 .32415 Mtetra
.683 .763 .912 r
.3683 .32415 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.664 .741 .907 r
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.645 .734 .914 r
.56934 .2523 .57612 .26079 .58915 .2562 .58242 .24827 Mtetra
.429 .653 .953 r
.58242 .24827 .58915 .2562 .60228 .25334 .59567 .24906 Mtetra
.187 .636 .942 r
.59567 .24906 .60228 .25334 .61562 .25492 .60907 .25083 Mtetra
.172 .633 .936 r
.60907 .25083 .61562 .25492 .6291 .25729 .62258 .25262 Mtetra
.391 .747 .992 r
.62258 .25262 .6291 .25729 .64268 .25884 .63613 .25215 Mtetra
.702 .813 .934 r
.63613 .25215 .64268 .25884 .65621 .25641 .64957 .24615 Mtetra
.817 .755 .794 r
.64957 .24615 .65621 .25641 .66947 .24657 .66271 .23252 Mtetra
.821 .701 .732 r
.66271 .23252 .66947 .24657 .68237 .22927 .67563 .21462 Mtetra
.645 .617 .807 r
.67563 .21462 .68237 .22927 .6956 .21867 .6892 .20981 Mtetra
.664 .741 .907 r
.6892 .20981 .6956 .21867 .70919 .21388 .70284 .20497 Mtetra
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.613 .719 .921 r
.73031 .19523 .73657 .20423 .75046 .20063 .74427 .19197 Mtetra
.674 .755 .912 r
.74427 .19197 .75046 .20063 .76435 .19604 .75816 .18671 Mtetra
.685 .743 .895 r
.75816 .18671 .76435 .19604 .77821 .19032 .77207 .18098 Mtetra
.674 .74 .9 r
.77207 .18098 .77821 .19032 .79216 .18486 .78608 .17561 Mtetra
.666 .74 .905 r
.78608 .17561 .79216 .18486 .80621 .17978 .80018 .17052 Mtetra
.662 .74 .908 r
.17344 .38245 .18137 .38988 .19266 .38596 .18476 .37846 Mtetra
.655 .737 .91 r
.18476 .37846 .19266 .38596 .20398 .38231 .19612 .37466 Mtetra
.642 .73 .912 r
.19612 .37466 .20398 .38231 .2153 .37902 .20748 .37122 Mtetra
.641 .726 .91 r
.20748 .37122 .2153 .37902 .22673 .37529 .2189 .36779 Mtetra
.693 .749 .895 r
.2189 .36779 .22673 .37529 .23838 .36962 .23053 .36274 Mtetra
.687 .766 .911 r
.23053 .36274 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.664 .741 .907 r
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27319 .35728 .26549 .34961 Mtetra
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.369 .621 .949 r
.27723 .34542 .28489 .35313 .29573 .36175 .28859 .34693 Mtetra
.207 .352 .79 r
.28859 .34693 .29573 .36175 .307 .36623 .29963 .35432 Mtetra
.47 .562 .867 r
.29963 .35432 .307 .36623 .31886 .36329 .31123 .35557 Mtetra
.691 .752 .898 r
.31123 .35557 .31886 .36329 .33111 .35494 .32332 .35037 Mtetra
.799 .854 .892 r
.32332 .35037 .33111 .35494 .34352 .34437 .33569 .34128 Mtetra
.829 .896 .888 r
.33569 .34128 .34352 .34437 .35593 .33379 .34816 .33095 Mtetra
.824 .906 .896 r
.34816 .33095 .35593 .33379 .3683 .32415 .36061 .32094 Mtetra
.804 .9 .91 r
.36061 .32094 .3683 .32415 .38046 .31925 .37303 .31185 Mtetra
.683 .763 .912 r
.37303 .31185 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.664 .741 .907 r
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.645 .734 .914 r
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24433 Mtetra
.462 .67 .954 r
.5625 .24433 .56934 .2523 .58242 .24827 .57569 .24448 Mtetra
.207 .666 .945 r
.57569 .24448 .58242 .24827 .59567 .24906 .58901 .24558 Mtetra
.153 .639 .92 r
.58901 .24558 .59567 .24906 .60907 .25083 .60245 .24702 Mtetra
.286 .717 .968 r
.60245 .24702 .60907 .25083 .62258 .25262 .61597 .24723 Mtetra
.607 .824 .983 r
.61597 .24723 .62258 .25262 .63613 .25215 .62946 .24346 Mtetra
.788 .783 .848 r
.62946 .24346 .63613 .25215 .64957 .24615 .64277 .2331 Mtetra
.82 .714 .747 r
.64277 .2331 .64957 .24615 .66271 .23252 .65583 .21641 Mtetra
.73 .641 .76 r
.65583 .21641 .66271 .23252 .67563 .21462 .66913 .20572 Mtetra
.664 .741 .907 r
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.68274 .20086 .6892 .20981 .70284 .20497 .69643 .19599 Mtetra
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.643 .732 .914 r
.71018 .19108 .71654 .20011 .73031 .19523 .72404 .18687 Mtetra
.633 .748 .931 r
.72404 .18687 .73031 .19523 .74427 .19197 .738 .1829 Mtetra
.683 .75 .902 r
.738 .1829 .74427 .19197 .75816 .18671 .75191 .17724 Mtetra
.681 .74 .895 r
.75191 .17724 .75816 .18671 .77207 .18098 .76588 .17159 Mtetra
.671 .739 .901 r
.76588 .17159 .77207 .18098 .78608 .17561 .77995 .1663 Mtetra
.665 .74 .906 r
.77995 .1663 .78608 .17561 .80018 .17052 .7941 .1612 Mtetra
.663 .74 .907 r
.16544 .37496 .17344 .38245 .18476 .37846 .1768 .37092 Mtetra
.659 .738 .909 r
.1768 .37092 .18476 .37846 .19612 .37466 .18819 .36699 Mtetra
.648 .733 .911 r
.18819 .36699 .19612 .37466 .20748 .37122 .1996 .36334 Mtetra
.638 .725 .911 r
.1996 .36334 .20748 .37122 .2189 .36779 .21104 .35997 Mtetra
.662 .734 .904 r
.21104 .35997 .2189 .36779 .23053 .36274 .2226 .35588 Mtetra
.71 .772 .901 r
.2226 .35588 .23053 .36274 .24217 .35792 .23435 .35025 Mtetra
.664 .741 .907 r
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.25773 .34187 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.2695 .33765 .27723 .34542 .28859 .34693 .28132 .33341 Mtetra
.246 .402 .821 r
.28132 .33341 .28859 .34693 .29963 .35432 .29244 .3394 Mtetra
.325 .424 .81 r
.29244 .3394 .29963 .35432 .31123 .35557 .30375 .34463 Mtetra
.548 .623 .879 r
.30375 .34463 .31123 .35557 .32332 .35037 .31558 .34374 Mtetra
.721 .791 .907 r
.31558 .34374 .32332 .35037 .33569 .34128 .32782 .33754 Mtetra
.801 .882 .905 r
.32782 .33754 .33569 .34128 .34816 .33095 .34027 .32847 Mtetra
.82 .918 .903 r
.34027 .32847 .34816 .33095 .36061 .32094 .35278 .31863 Mtetra
.811 .926 .912 r
.35278 .31863 .36061 .32094 .37303 .31185 .36529 .30918 Mtetra
.79 .919 .925 r
.36529 .30918 .37303 .31185 .38528 .3069 .37777 .30055 Mtetra
.719 .804 .917 r
.37777 .30055 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.664 .741 .907 r
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.605 .719 .925 r
.52949 .24445 .53647 .25301 .54945 .24838 .54252 .24154 Mtetra
.463 .709 .975 r
.54252 .24154 .54945 .24838 .5625 .24433 .55566 .24114 Mtetra
.219 .692 .939 r
.55566 .24114 .5625 .24433 .57569 .24448 .56891 .2416 Mtetra
.157 .659 .909 r
.56891 .2416 .57569 .24448 .58901 .24558 .58227 .24246 Mtetra
.246 .712 .946 r
.58227 .24246 .58901 .24558 .60245 .24702 .59573 .24255 Mtetra
.534 .826 .999 r
.59573 .24255 .60245 .24702 .61597 .24723 .60922 .23973 Mtetra
.757 .806 .892 r
.60922 .23973 .61597 .24723 .62946 .24346 .62262 .23148 Mtetra
.81 .726 .772 r
.62262 .23148 .62946 .24346 .64277 .2331 .63582 .21695 Mtetra
.781 .664 .734 r
.63582 .21695 .64277 .2331 .65583 .21641 .64897 .20161 Mtetra
.645 .617 .808 r
.64897 .20161 .65583 .21641 .66913 .20572 .66257 .19674 Mtetra
.664 .741 .907 r
.66257 .19674 .66913 .20572 .68274 .20086 .67623 .19184 Mtetra
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.617 .721 .92 r
.70375 .18197 .71018 .19108 .72404 .18687 .71772 .17852 Mtetra
.666 .764 .923 r
.71772 .17852 .72404 .18687 .738 .1829 .73165 .17347 Mtetra
.685 .744 .896 r
.73165 .17347 .738 .1829 .75191 .17724 .7456 .16767 Mtetra
.676 .738 .897 r
.7456 .16767 .75191 .17724 .76588 .17159 .75963 .16215 Mtetra
.668 .739 .903 r
.75963 .16215 .76588 .17159 .77995 .1663 .77376 .15692 Mtetra
.665 .74 .906 r
.77376 .15692 .77995 .1663 .7941 .1612 .78797 .1518 Mtetra
.663 .74 .907 r
.15738 .36743 .16544 .37496 .1768 .37092 .16877 .36333 Mtetra
.661 .74 .908 r
.16877 .36333 .1768 .37092 .18819 .36699 .18019 .3593 Mtetra
.654 .736 .91 r
.18019 .3593 .18819 .36699 .1996 .36334 .19165 .35545 Mtetra
.642 .728 .911 r
.19165 .35545 .1996 .36334 .21104 .35997 .20313 .35194 Mtetra
.643 .725 .908 r
.20313 .35194 .21104 .35997 .2226 .35588 .21466 .34836 Mtetra
.693 .753 .897 r
.21466 .34836 .2226 .35588 .23435 .35025 .2264 .3432 Mtetra
.687 .765 .911 r
.2264 .3432 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.664 .741 .907 r
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .2695 .33765 .26171 .32981 Mtetra
.26171 .32981 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.623 .728 .922 r
.27356 .32553 .28132 .33341 .29244 .3394 .28538 .32242 Mtetra
.259 .352 .769 r
.28538 .32242 .29244 .3394 .30375 .34463 .2965 .32976 Mtetra
.396 .47 .818 r
.2965 .32976 .30375 .34463 .31558 .34374 .30802 .33338 Mtetra
.581 .653 .886 r
.30802 .33338 .31558 .34374 .32782 .33754 .32001 .33148 Mtetra
.724 .811 .919 r
.32001 .33148 .32782 .33754 .34027 .32847 .33234 .3252 Mtetra
.789 .9 .921 r
.33234 .3252 .34027 .32847 .35278 .31863 .34484 .31663 Mtetra
.801 .936 .919 r
.34484 .31663 .35278 .31863 .36529 .30918 .3574 .30743 Mtetra
.79 .945 .925 r
.3574 .30743 .36529 .30918 .37777 .30055 .36997 .29854 Mtetra
.77 .94 .937 r
.36997 .29854 .37777 .30055 .39017 .29439 .38252 .29032 Mtetra
.757 .881 .935 r
.38252 .29032 .39017 .29439 .40254 .28995 .39507 .28288 Mtetra
.701 .783 .915 r
.39507 .28288 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.664 .741 .907 r
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.626 .727 .92 r
.4965 .24516 .50362 .25372 .51652 .24909 .50943 .24167 Mtetra
.542 .727 .96 r
.50943 .24167 .51652 .24909 .52949 .24445 .52244 .23998 Mtetra
.409 .765 .995 r
.52244 .23998 .52949 .24445 .54252 .24154 .53553 .23909 Mtetra
.222 .713 .922 r
.53553 .23909 .54252 .24154 .55566 .24114 .54873 .23889 Mtetra
.174 .686 .897 r
.54873 .23889 .55566 .24114 .56891 .2416 .56204 .23902 Mtetra
.258 .734 .937 r
.56204 .23902 .56891 .2416 .58227 .24246 .57544 .23852 Mtetra
.514 .836 .999 r
.57544 .23852 .58227 .24246 .59573 .24255 .58889 .2357 Mtetra
.736 .82 .917 r
.58889 .2357 .59573 .24255 .60922 .23973 .60231 .22841 Mtetra
.799 .734 .792 r
.60231 .22841 .60922 .23973 .62262 .23148 .61561 .21547 Mtetra
.795 .672 .728 r
.61561 .21547 .62262 .23148 .63582 .21695 .62877 .19869 Mtetra
.652 .581 .762 r
.62877 .19869 .63582 .21695 .64897 .20161 .64231 .19259 Mtetra
.664 .741 .907 r
.64231 .19259 .64897 .20161 .66257 .19674 .65595 .18768 Mtetra
.65595 .18768 .66257 .19674 .67623 .19184 .66966 .18273 Mtetra
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.643 .732 .914 r
.68343 .17777 .68996 .18692 .70375 .18197 .69732 .17349 Mtetra
.633 .747 .931 r
.69732 .17349 .70375 .18197 .71772 .17852 .71129 .16946 Mtetra
.682 .753 .905 r
.71129 .16946 .71772 .17852 .73165 .17347 .72524 .16381 Mtetra
.681 .738 .894 r
.72524 .16381 .73165 .17347 .7456 .16767 .73924 .15807 Mtetra
.672 .737 .899 r
.73924 .15807 .7456 .16767 .75963 .16215 .75334 .15268 Mtetra
.666 .739 .905 r
.75334 .15268 .75963 .16215 .77376 .15692 .76752 .14748 Mtetra
.664 .74 .907 r
.76752 .14748 .77376 .15692 .78797 .1518 .78177 .14232 Mtetra
.664 .741 .907 r
.14925 .35983 .15738 .36743 .16877 .36333 .16067 .35569 Mtetra
.662 .74 .908 r
.16067 .35569 .16877 .36333 .18019 .3593 .17213 .35158 Mtetra
.659 .738 .908 r
.17213 .35158 .18019 .3593 .19165 .35545 .18363 .34757 Mtetra
.649 .732 .91 r
.18363 .34757 .19165 .35545 .20313 .35194 .19515 .34383 Mtetra
.639 .724 .909 r
.19515 .34383 .20313 .35194 .21466 .34836 .2067 .34033 Mtetra
.658 .732 .904 r
.2067 .34033 .21466 .34836 .2264 .3432 .21836 .33627 Mtetra
.712 .775 .901 r
.21836 .33627 .2264 .3432 .23816 .3383 .23024 .33046 Mtetra
.664 .741 .907 r
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27356 .32553 .26573 .31759 Mtetra
.26573 .31759 .27356 .32553 .28538 .32242 .27767 .31327 Mtetra
.555 .671 .915 r
.27767 .31327 .28538 .32242 .2965 .32976 .28944 .31189 Mtetra
.32 .38 .768 r
.28944 .31189 .2965 .32976 .30802 .33338 .30074 .31824 Mtetra
.432 .488 .817 r
.30074 .31824 .30802 .33338 .32001 .33148 .31241 .321 Mtetra
.582 .653 .885 r
.31241 .321 .32001 .33148 .33234 .3252 .3245 .31903 Mtetra
.704 .807 .929 r
.3245 .31903 .33234 .3252 .34484 .31663 .33688 .31336 Mtetra
.763 .903 .938 r
.33688 .31336 .34484 .31663 .3574 .30743 .34942 .30566 Mtetra
.772 .945 .935 r
.34942 .30566 .3574 .30743 .36997 .29854 .36202 .29728 Mtetra
.759 .958 .936 r
.36202 .29728 .36997 .29854 .38252 .29032 .37465 .28904 Mtetra
.737 .957 .943 r
.37465 .28904 .38252 .29032 .39507 .28288 .38728 .28132 Mtetra
.713 .949 .954 r
.38728 .28132 .39507 .28288 .40759 .27722 .39992 .27426 Mtetra
.708 .914 .966 r
.39992 .27426 .40759 .27722 .42011 .2727 .41257 .26785 Mtetra
.7 .856 .957 r
.41257 .26785 .42011 .2727 .43269 .26816 .42524 .26208 Mtetra
.683 .814 .946 r
.42524 .26208 .43269 .26816 .44533 .26361 .43794 .25689 Mtetra
.663 .791 .943 r
.43794 .25689 .44533 .26361 .45803 .25903 .45069 .25228 Mtetra
.641 .784 .95 r
.45069 .25228 .45803 .25903 .4708 .25443 .46349 .24823 Mtetra
.611 .792 .969 r
.46349 .24823 .4708 .25443 .48362 .24981 .47634 .24478 Mtetra
.558 .813 .993 r
.47634 .24478 .48362 .24981 .4965 .24516 .48925 .24196 Mtetra
.445 .822 .991 r
.48925 .24196 .4965 .24516 .50943 .24167 .50223 .23981 Mtetra
.3 .775 .929 r
.50223 .23981 .50943 .24167 .52244 .23998 .5153 .23833 Mtetra
.23 .734 .897 r
.5153 .23833 .52244 .23998 .53553 .23909 .52846 .23739 Mtetra
.217 .725 .894 r
.52846 .23739 .53553 .23909 .54873 .23889 .54172 .2366 Mtetra
.322 .78 .947 r
.54172 .2366 .54873 .23889 .56204 .23902 .55506 .23514 Mtetra
.555 .855 .997 r
.55506 .23514 .56204 .23902 .57544 .23852 .56848 .23162 Mtetra
.736 .819 .916 r
.56848 .23162 .57544 .23852 .58889 .2357 .58189 .22433 Mtetra
.788 .731 .799 r
.58189 .22433 .58889 .2357 .60231 .22841 .59524 .2122 Mtetra
.785 .666 .732 r
.59524 .2122 .60231 .22841 .61561 .21547 .60849 .19639 Mtetra
.675 .586 .748 r
.60849 .19639 .61561 .21547 .62877 .19869 .62196 .18843 Mtetra
.661 .71 .884 r
.62196 .18843 .62877 .19869 .64231 .19259 .63558 .1835 Mtetra
.664 .741 .907 r
.63558 .1835 .64231 .19259 .65595 .18768 .64927 .17853 Mtetra
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.614 .72 .921 r
.67685 .16854 .68343 .17777 .69732 .17349 .69082 .1651 Mtetra
.67 .767 .923 r
.69082 .1651 .69732 .17349 .71129 .16946 .70478 .15987 Mtetra
.684 .742 .895 r
.70478 .15987 .71129 .16946 .72524 .16381 .71876 .15404 Mtetra
.676 .736 .895 r
.71876 .15404 .72524 .16381 .73924 .15807 .73283 .14846 Mtetra
.668 .738 .902 r
.73283 .14846 .73924 .15807 .75334 .15268 .74699 .14316 Mtetra
.665 .74 .906 r
.74699 .14316 .75334 .15268 .76752 .14748 .76122 .13795 Mtetra
.664 .74 .907 r
.76122 .13795 .76752 .14748 .78177 .14232 .77553 .13276 Mtetra
.664 .741 .907 r
.14106 .35217 .14925 .35983 .16067 .35569 .1525 .348 Mtetra
.663 .741 .907 r
.1525 .348 .16067 .35569 .17213 .35158 .16399 .34383 Mtetra
.661 .739 .908 r
.16399 .34383 .17213 .35158 .18363 .34757 .17553 .3397 Mtetra
.655 .735 .909 r
.17553 .3397 .18363 .34757 .19515 .34383 .1871 .33573 Mtetra
.644 .727 .909 r
.1871 .33573 .19515 .34383 .2067 .34033 .19869 .33206 Mtetra
.642 .723 .907 r
.19869 .33206 .2067 .34033 .21836 .33627 .21034 .32844 Mtetra
.675 .745 .903 r
.21034 .32844 .21836 .33627 .23024 .33046 .22213 .32378 Mtetra
.704 .783 .913 r
.22213 .32378 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.664 .741 .907 r
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.26981 .30522 .27767 .31327 .28944 .31189 .28184 .30084 Mtetra
.564 .632 .877 r
.28184 .30084 .28944 .31189 .30074 .31824 .2937 .29941 Mtetra
.365 .398 .762 r
.2937 .29941 .30074 .31824 .31241 .321 .30516 .3049 Mtetra
.446 .483 .804 r
.30516 .3049 .31241 .321 .3245 .31903 .31693 .30746 Mtetra
.56 .623 .871 r
.31693 .30746 .3245 .31903 .33688 .31336 .32906 .30614 Mtetra
.664 .77 .929 r
.32906 .30614 .33688 .31336 .34942 .30566 .34146 .30162 Mtetra
.723 .88 .954 r
.34146 .30162 .34942 .30566 .36202 .29728 .35402 .29517 Mtetra
.733 .937 .954 r
.35402 .29517 .36202 .29728 .37465 .28904 .36667 .2879 Mtetra
.715 .957 .947 r
.36667 .2879 .37465 .28904 .38728 .28132 .37935 .28055 Mtetra
.686 .96 .945 r
.37935 .28055 .38728 .28132 .39992 .27426 .39206 .27352 Mtetra
.652 .953 .947 r
.39206 .27352 .39992 .27426 .41257 .26785 .40478 .26703 Mtetra
.616 .941 .95 r
.40478 .26703 .41257 .26785 .42524 .26208 .41753 .26113 Mtetra
.577 .926 .952 r
.41753 .26113 .42524 .26208 .43794 .25689 .43031 .25586 Mtetra
.533 .908 .952 r
.43031 .25586 .43794 .25689 .45069 .25228 .44312 .2512 Mtetra
.482 .885 .946 r
.44312 .2512 .45069 .25228 .46349 .24823 .45598 .24718 Mtetra
.424 .857 .934 r
.45598 .24718 .46349 .24823 .47634 .24478 .4689 .24378 Mtetra
.362 .824 .915 r
.4689 .24378 .47634 .24478 .48925 .24196 .48188 .24099 Mtetra
.306 .791 .897 r
.48188 .24099 .48925 .24196 .50223 .23981 .49493 .23873 Mtetra
.28 .774 .892 r
.49493 .23873 .50223 .23981 .5153 .23833 .50807 .23681 Mtetra
.317 .791 .921 r
.50807 .23681 .5153 .23833 .52846 .23739 .52129 .23483 Mtetra
.452 .845 .979 r
.52129 .23483 .52846 .23739 .54172 .2366 .5346 .23201 Mtetra
.638 .863 .984 r
.5346 .23201 .54172 .2366 .55506 .23514 .54798 .22724 Mtetra
.748 .795 .89 r
.54798 .22724 .55506 .23514 .56848 .23162 .56138 .21922 Mtetra
.777 .711 .79 r
.56138 .21922 .56848 .23162 .58189 .22433 .57475 .20724 Mtetra
.77 .652 .731 r
.57475 .20724 .58189 .22433 .59524 .2122 .58807 .19223 Mtetra
.671 .577 .741 r
.58807 .19223 .59524 .2122 .60849 .19639 .60154 .18426 Mtetra
.655 .669 .852 r
.60154 .18426 .60849 .19639 .62196 .18843 .61514 .1793 Mtetra
.664 .741 .907 r
.61514 .1793 .62196 .18843 .63558 .1835 .6288 .17432 Mtetra
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.625 .725 .918 r
.65633 .16428 .66303 .17355 .67685 .16854 .67026 .16047 Mtetra
.652 .77 .936 r
.67026 .16047 .67685 .16854 .69082 .1651 .68422 .15577 Mtetra
.682 .749 .902 r
.68422 .15577 .69082 .1651 .70478 .15987 .6982 .15 Mtetra
.679 .736 .893 r
.6982 .15 .70478 .15987 .71876 .15404 .71224 .14427 Mtetra
.671 .736 .899 r
.71224 .14427 .71876 .15404 .73283 .14846 .72637 .13884 Mtetra
.666 .739 .904 r
.72637 .13884 .73283 .14846 .74699 .14316 .74058 .13358 Mtetra
.664 .74 .907 r
.74058 .13358 .74699 .14316 .76122 .13795 .75486 .12835 Mtetra
.664 .741 .907 r
.75486 .12835 .76122 .13795 .77553 .13276 .76922 .12311 Mtetra
.13279 .34445 .14106 .35217 .1525 .348 .14427 .34025 Mtetra
.14427 .34025 .1525 .348 .16399 .34383 .15579 .33603 Mtetra
.663 .74 .908 r
.15579 .33603 .16399 .34383 .17553 .3397 .16736 .33181 Mtetra
.66 .738 .908 r
.16736 .33181 .17553 .3397 .1871 .33573 .17898 .32768 Mtetra
.652 .732 .908 r
.17898 .32768 .1871 .33573 .19869 .33206 .19062 .32375 Mtetra
.642 .724 .908 r
.19062 .32375 .19869 .33206 .21034 .32844 .20229 .32009 Mtetra
.647 .725 .905 r
.20229 .32009 .21034 .32844 .22213 .32378 .21403 .31625 Mtetra
.69 .759 .904 r
.21403 .31625 .22213 .32378 .23406 .31826 .22596 .31108 Mtetra
.691 .77 .912 r
.22596 .31108 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.664 .741 .907 r
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.27395 .29269 .28184 .30084 .2937 .29941 .28606 .28824 Mtetra
.623 .657 .863 r
.28606 .28824 .2937 .29941 .30516 .3049 .29815 .28496 Mtetra
.402 .41 .753 r
.29815 .28496 .30516 .3049 .31693 .30746 .30975 .28964 Mtetra
.451 .465 .782 r
.30975 .28964 .31693 .30746 .32906 .30614 .3216 .29233 Mtetra
.529 .568 .838 r
.3216 .29233 .32906 .30614 .34146 .30162 .33375 .29205 Mtetra
.611 .693 .901 r
.33375 .29205 .34146 .30162 .35402 .29517 .34615 .28907 Mtetra
.67 .809 .95 r
.34615 .28907 .35402 .29517 .36667 .2879 .35871 .28423 Mtetra
.691 .89 .97 r
.35871 .28423 .36667 .2879 .37935 .28055 .37138 .27841 Mtetra
.676 .93 .97 r
.37138 .27841 .37935 .28055 .39206 .27352 .38412 .27228 Mtetra
.642 .941 .96 r
.38412 .27228 .39206 .27352 .40478 .26703 .39689 .26623 Mtetra
.598 .936 .949 r
.39689 .26623 .40478 .26703 .41753 .26113 .4097 .26055 Mtetra
.55 .921 .939 r
.4097 .26055 .41753 .26113 .43031 .25586 .42255 .25533 Mtetra
.502 .901 .93 r
.42255 .25533 .43031 .25586 .44312 .2512 .43543 .25065 Mtetra
.457 .88 .922 r
.43543 .25065 .44312 .2512 .45598 .24718 .44837 .24649 Mtetra
.42 .86 .918 r
.44837 .24649 .45598 .24718 .4689 .24378 .46136 .24281 Mtetra
.404 .848 .925 r
.46136 .24281 .4689 .24378 .48188 .24099 .47441 .2395 Mtetra
.427 .853 .948 r
.47441 .2395 .48188 .24099 .49493 .23873 .48754 .23628 Mtetra
.503 .871 .982 r
.48754 .23628 .49493 .23873 .50807 .23681 .50075 .23274 Mtetra
.617 .872 .99 r
.50075 .23274 .50807 .23681 .52129 .23483 .51404 .22821 Mtetra
.712 .821 .933 r
.51404 .22821 .52129 .23483 .5346 .23201 .52739 .22181 Mtetra
.754 .742 .842 r
.52739 .22181 .5346 .23201 .54798 .22724 .54079 .21266 Mtetra
.76 .675 .767 r
.54079 .21266 .54798 .22724 .56138 .21922 .55417 .20046 Mtetra
.751 .628 .724 r
.55417 .20046 .56138 .21922 .57475 .20724 .56753 .18623 Mtetra
.64 .551 .738 r
.56753 .18623 .57475 .20724 .58807 .19223 .58103 .18006 Mtetra
.655 .669 .852 r
.58103 .18006 .58807 .19223 .60154 .18426 .5946 .17508 Mtetra
.664 .741 .907 r
.5946 .17508 .60154 .18426 .61514 .1793 .60825 .17008 Mtetra
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.638 .73 .915 r
.63574 .16 .64253 .16931 .65633 .16428 .64962 .15577 Mtetra
.637 .753 .932 r
.64962 .15577 .65633 .16428 .67026 .16047 .66357 .15152 Mtetra
.679 .758 .911 r
.66357 .15152 .67026 .16047 .68422 .15577 .67754 .14589 Mtetra
.681 .737 .893 r
.67754 .14589 .68422 .15577 .6982 .15 .69156 .14008 Mtetra
.673 .734 .896 r
.69156 .14008 .6982 .15 .71224 .14427 .70566 .13453 Mtetra
.667 .737 .902 r
.70566 .13453 .71224 .14427 .72637 .13884 .71985 .12919 Mtetra
.665 .74 .906 r
.71985 .12919 .72637 .13884 .74058 .13358 .73411 .12393 Mtetra
.664 .741 .907 r
.73411 .12393 .74058 .13358 .75486 .12835 .74845 .11866 Mtetra
.74845 .11866 .75486 .12835 .76922 .12311 .76286 .11338 Mtetra
.12446 .33667 .13279 .34445 .14427 .34025 .13596 .33243 Mtetra
.13596 .33243 .14427 .34025 .15579 .33603 .14751 .32817 Mtetra
.663 .741 .907 r
.14751 .32817 .15579 .33603 .16736 .33181 .15912 .3239 Mtetra
.662 .74 .908 r
.15912 .3239 .16736 .33181 .17898 .32768 .17077 .31965 Mtetra
.658 .737 .908 r
.17077 .31965 .17898 .32768 .19062 .32375 .18246 .31551 Mtetra
.65 .729 .907 r
.18246 .31551 .19062 .32375 .20229 .32009 .19418 .31159 Mtetra
.642 .722 .906 r
.19418 .31159 .20229 .32009 .21403 .31625 .20594 .30788 Mtetra
.653 .729 .905 r
.20594 .30788 .21403 .31625 .22596 .31108 .21778 .30383 Mtetra
.698 .771 .908 r
.21778 .30383 .22596 .31108 .23793 .30589 .22982 .29837 Mtetra
.683 .761 .911 r
.22982 .29837 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.664 .741 .907 r
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.27813 .27998 .28606 .28824 .29815 .28496 .29034 .27548 Mtetra
.661 .711 .884 r
.29034 .27548 .29815 .28496 .30975 .28964 .3026 .27096 Mtetra
.496 .482 .771 r
.3026 .27096 .30975 .28964 .3216 .29233 .31453 .27221 Mtetra
.463 .448 .756 r
.31453 .27221 .3216 .29233 .33375 .29205 .32647 .27486 Mtetra
.508 .508 .791 r
.32647 .27486 .33375 .29205 .34615 .28907 .33864 .27554 Mtetra
.562 .592 .841 r
.33864 .27554 .34615 .28907 .35871 .28423 .35102 .27413 Mtetra
.613 .684 .893 r
.35102 .27413 .35871 .28423 .37138 .27841 .36358 .27105 Mtetra
.647 .769 .938 r
.36358 .27105 .37138 .27841 .38412 .27228 .37626 .26687 Mtetra
.658 .833 .967 r
.37626 .26687 .38412 .27228 .39689 .26623 .38903 .26213 Mtetra
.65 .873 .982 r
.38903 .26213 .39689 .26623 .4097 .26055 .40187 .2572 Mtetra
.631 .891 .987 r
.40187 .2572 .4097 .26055 .42255 .25533 .41477 .25232 Mtetra
.611 .895 .988 r
.41477 .25232 .42255 .25533 .43543 .25065 .42771 .2476 Mtetra
.601 .892 .989 r
.42771 .2476 .43543 .25065 .44837 .24649 .44072 .24303 Mtetra
.607 .883 .991 r
.44072 .24303 .44837 .24649 .46136 .24281 .45379 .23852 Mtetra
.633 .868 .986 r
.45379 .23852 .46136 .24281 .47441 .2395 .46693 .23382 Mtetra
.672 .837 .962 r
.46693 .23382 .47441 .2395 .48754 .23628 .48014 .22855 Mtetra
.709 .788 .913 r
.48014 .22855 .48754 .23628 .50075 .23274 .49342 .22217 Mtetra
.731 .727 .847 r
.49342 .22217 .50075 .23274 .51404 .22821 .50676 .21409 Mtetra
.739 .672 .785 r
.50676 .21409 .51404 .22821 .52739 .22181 .52014 .20389 Mtetra
.736 .628 .739 r
.52014 .20389 .52739 .22181 .54079 .21266 .53354 .19166 Mtetra
.701 .585 .723 r
.53354 .19166 .54079 .21266 .55417 .20046 .54694 .18083 Mtetra
.626 .556 .755 r
.54694 .18083 .55417 .20046 .56753 .18623 .56043 .17585 Mtetra
.661 .711 .884 r
.56043 .17585 .56753 .18623 .58103 .18006 .57399 .17085 Mtetra
.664 .741 .907 r
.57399 .17085 .58103 .18006 .5946 .17508 .58761 .16583 Mtetra
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.646 .734 .913 r
.61505 .1557 .62196 .16505 .63574 .16 .6289 .1512 Mtetra
.629 .743 .929 r
.6289 .1512 .63574 .16 .64962 .15577 .64283 .14717 Mtetra
.675 .767 .92 r
.64283 .14717 .64962 .15577 .66357 .15152 .65679 .14168 Mtetra
.681 .739 .895 r
.65679 .14168 .66357 .15152 .67754 .14589 .67079 .13584 Mtetra
.675 .733 .894 r
.67079 .13584 .67754 .14589 .69156 .14008 .68487 .1302 Mtetra
.668 .735 .9 r
.68487 .1302 .69156 .14008 .70566 .13453 .69903 .12479 Mtetra
.665 .739 .905 r
.69903 .12479 .70566 .13453 .71985 .12919 .71327 .11949 Mtetra
.664 .74 .907 r
.71327 .11949 .71985 .12919 .73411 .12393 .72759 .11419 Mtetra
.664 .741 .907 r
.72759 .11419 .73411 .12393 .74845 .11866 .74197 .10889 Mtetra
.74197 .10889 .74845 .11866 .76286 .11338 .75643 .10355 Mtetra
.11606 .32882 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14751 .32817 .13917 .32025 Mtetra
.13917 .32025 .14751 .32817 .15912 .3239 .15081 .31594 Mtetra
.663 .74 .907 r
.15081 .31594 .15912 .3239 .17077 .31965 .16249 .31162 Mtetra
.661 .739 .907 r
.16249 .31162 .17077 .31965 .18246 .31551 .17423 .30733 Mtetra
.657 .735 .907 r
.17423 .30733 .18246 .31551 .19418 .31159 .186 .30317 Mtetra
.649 .727 .906 r
.186 .30317 .19418 .31159 .20594 .30788 .1978 .29923 Mtetra
.643 .721 .905 r
.1978 .29923 .20594 .30788 .21778 .30383 .20965 .29543 Mtetra
.655 .732 .905 r
.20965 .29543 .21778 .30383 .22982 .29837 .22159 .29124 Mtetra
.698 .777 .913 r
.22159 .29124 .22982 .29837 .24186 .29337 .2337 .28574 Mtetra
.683 .761 .911 r
.2337 .28574 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.664 .741 .907 r
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .29034 .27548 .28238 .26711 Mtetra
.28238 .26711 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.29467 .26255 .3026 .27096 .31453 .27221 .30703 .25797 Mtetra
.643 .618 .809 r
.30703 .25797 .31453 .27221 .32647 .27486 .31944 .25336 Mtetra
.503 .461 .742 r
.31944 .25336 .32647 .27486 .33864 .27554 .33155 .25454 Mtetra
.51 .47 .748 r
.33155 .25454 .33864 .27554 .35102 .27413 .34378 .2554 Mtetra
.54 .51 .772 r
.34378 .2554 .35102 .27413 .36358 .27105 .35618 .2549 Mtetra
.572 .56 .801 r
.35618 .2549 .36358 .27105 .37626 .26687 .36875 .25308 Mtetra
.603 .61 .832 r
.36875 .25308 .37626 .26687 .38903 .26213 .38145 .25015 Mtetra
.627 .654 .857 r
.38145 .25015 .38903 .26213 .40187 .2572 .39426 .24642 Mtetra
.646 .687 .875 r
.39426 .24642 .40187 .2572 .41477 .25232 .40716 .24212 Mtetra
.659 .706 .882 r
.40716 .24212 .41477 .25232 .42771 .2476 .42014 .23735 Mtetra
.671 .71 .878 r
.42014 .23735 .42771 .2476 .44072 .24303 .4332 .23213 Mtetra
.682 .701 .862 r
.4332 .23213 .44072 .24303 .45379 .23852 .44633 .22632 Mtetra
.692 .681 .835 r
.44633 .22632 .45379 .23852 .46693 .23382 .45954 .2197 Mtetra
.701 .655 .801 r
.45954 .2197 .46693 .23382 .48014 .22855 .47281 .21196 Mtetra
.705 .626 .766 r
.47281 .21196 .48014 .22855 .49342 .22217 .48613 .20288 Mtetra
.707 .601 .736 r
.48613 .20288 .49342 .22217 .50676 .21409 .4995 .19241 Mtetra
.697 .578 .718 r
.4995 .19241 .50676 .21409 .52014 .20389 .51289 .18159 Mtetra
.617 .529 .732 r
.51289 .18159 .52014 .20389 .53354 .19166 .52629 .17662 Mtetra
.643 .618 .809 r
.52629 .17662 .53354 .19166 .54694 .18083 .53975 .17162 Mtetra
.664 .741 .907 r
.53975 .17162 .54694 .18083 .56043 .17585 .55328 .1666 Mtetra
.55328 .1666 .56043 .17585 .57399 .17085 .56688 .16156 Mtetra
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.646 .734 .913 r
.59428 .15139 .6013 .16078 .61505 .1557 .6081 .14687 Mtetra
.63 .743 .929 r
.6081 .14687 .61505 .1557 .6289 .1512 .62201 .1428 Mtetra
.672 .773 .925 r
.62201 .1428 .6289 .1512 .64283 .14717 .63594 .13737 Mtetra
.681 .741 .896 r
.63594 .13737 .64283 .14717 .65679 .14168 .64993 .13154 Mtetra
.675 .732 .892 r
.64993 .13154 .65679 .14168 .67079 .13584 .66399 .12585 Mtetra
.669 .734 .898 r
.66399 .12585 .67079 .13584 .68487 .1302 .67813 .12038 Mtetra
.666 .738 .904 r
.67813 .12038 .68487 .1302 .69903 .12479 .69235 .11503 Mtetra
.664 .74 .906 r
.69235 .11503 .69903 .12479 .71327 .11949 .70664 .10971 Mtetra
.664 .741 .907 r
.70664 .10971 .71327 .11949 .72759 .11419 .721 .10437 Mtetra
.721 .10437 .72759 .11419 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32455 .11914 .3166 Mtetra
.11914 .3166 .12759 .32455 .13917 .32025 .13076 .31226 Mtetra
.13076 .31226 .13917 .32025 .15081 .31594 .14242 .30791 Mtetra
.14242 .30791 .15081 .31594 .16249 .31162 .15414 .30354 Mtetra
.663 .74 .907 r
.15414 .30354 .16249 .31162 .17423 .30733 .16591 .29917 Mtetra
.661 .738 .907 r
.16591 .29917 .17423 .30733 .186 .30317 .17773 .29484 Mtetra
.656 .734 .907 r
.17773 .29484 .186 .30317 .1978 .29923 .18958 .29064 Mtetra
.648 .726 .905 r
.18958 .29064 .1978 .29923 .20965 .29543 .20147 .28664 Mtetra
.644 .72 .903 r
.20147 .28664 .20965 .29543 .22159 .29124 .21341 .28275 Mtetra
.655 .732 .906 r
.21341 .28275 .22159 .29124 .2337 .28574 .22544 .27852 Mtetra
.691 .776 .916 r
.22544 .27852 .2337 .28574 .24583 .28068 .23762 .27319 Mtetra
.691 .77 .912 r
.23762 .27319 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.664 .741 .907 r
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29467 .26255 .28668 .25407 Mtetra
.28668 .25407 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33155 .25454 .32402 .24014 Mtetra
.643 .618 .81 r
.32402 .24014 .33155 .25454 .34378 .2554 .33659 .23545 Mtetra
.602 .534 .751 r
.33659 .23545 .34378 .2554 .35618 .2549 .34915 .2319 Mtetra
.55 .479 .729 r
.34915 .2319 .35618 .2549 .36875 .25308 .36164 .23086 Mtetra
.567 .496 .735 r
.36164 .23086 .36875 .25308 .38145 .25015 .37427 .22891 Mtetra
.587 .516 .742 r
.37427 .22891 .38145 .25015 .39426 .24642 .38702 .22598 Mtetra
.606 .534 .748 r
.38702 .22598 .39426 .24642 .40716 .24212 .39989 .22209 Mtetra
.623 .548 .75 r
.39989 .22209 .40716 .24212 .42014 .23735 .41287 .21727 Mtetra
.638 .556 .747 r
.41287 .21727 .42014 .23735 .4332 .23213 .42594 .21152 Mtetra
.65 .559 .739 r
.42594 .21152 .4332 .23213 .44633 .22632 .43909 .20481 Mtetra
.66 .558 .729 r
.43909 .20481 .44633 .22632 .45954 .2197 .45231 .1971 Mtetra
.667 .555 .718 r
.45231 .1971 .45954 .2197 .47281 .21196 .46558 .18847 Mtetra
.63 .527 .719 r
.46558 .18847 .47281 .21196 .48613 .20288 .47885 .18235 Mtetra
.622 .546 .747 r
.47885 .18235 .48613 .20288 .4995 .19241 .49217 .17739 Mtetra
.643 .618 .81 r
.49217 .17739 .4995 .19241 .51289 .18159 .50554 .17239 Mtetra
.664 .741 .907 r
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.51898 .16738 .52629 .17662 .53975 .17162 .53249 .16233 Mtetra
.53249 .16233 .53975 .17162 .55328 .1666 .54607 .15727 Mtetra
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.638 .731 .915 r
.57342 .14706 .58055 .15649 .59428 .15139 .58722 .14277 Mtetra
.637 .753 .932 r
.58722 .14277 .59428 .15139 .6081 .14687 .60109 .13844 Mtetra
.673 .773 .925 r
.60109 .13844 .6081 .14687 .62201 .1428 .61501 .13298 Mtetra
.68 .741 .897 r
.61501 .13298 .62201 .1428 .63594 .13737 .62898 .12716 Mtetra
.675 .731 .892 r
.62898 .12716 .63594 .13737 .64993 .13154 .64302 .12145 Mtetra
.67 .733 .897 r
.64302 .12145 .64993 .13154 .66399 .12585 .65714 .11594 Mtetra
.666 .737 .903 r
.65714 .11594 .66399 .12585 .67813 .12038 .67133 .11055 Mtetra
.664 .739 .906 r
.67133 .11055 .67813 .12038 .69235 .11503 .6856 .1052 Mtetra
.664 .74 .907 r
.6856 .1052 .69235 .11503 .70664 .10971 .69994 .09985 Mtetra
.664 .741 .907 r
.69994 .09985 .70664 .10971 .721 .10437 .71435 .09446 Mtetra
.71435 .09446 .721 .10437 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09363 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11914 .3166 .11063 .30858 Mtetra
.11063 .30858 .11914 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30791 .13397 .29982 Mtetra
.13397 .29982 .14242 .30791 .15414 .30354 .14572 .29541 Mtetra
.14572 .29541 .15414 .30354 .16591 .29917 .15752 .29099 Mtetra
.663 .74 .907 r
.15752 .29099 .16591 .29917 .17773 .29484 .16937 .28656 Mtetra
.661 .738 .907 r
.16937 .28656 .17773 .29484 .18958 .29064 .18128 .28218 Mtetra
.656 .733 .906 r
.18128 .28218 .18958 .29064 .20147 .28664 .19322 .27791 Mtetra
.65 .725 .904 r
.19322 .27791 .20147 .28664 .21341 .28275 .2052 .27382 Mtetra
.645 .72 .902 r
.2052 .27382 .21341 .28275 .22544 .27852 .21723 .26984 Mtetra
.652 .729 .905 r
.21723 .26984 .22544 .27852 .23762 .27319 .22934 .26562 Mtetra
.679 .767 .917 r
.22934 .26562 .23762 .27319 .24986 .26781 .24158 .26061 Mtetra
.704 .783 .913 r
.24158 .26061 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.664 .741 .907 r
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31152 .2448 .30352 .23617 Mtetra
.30352 .23617 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34915 .2319 .34133 .22198 Mtetra
.661 .711 .885 r
.34133 .22198 .34915 .2319 .36164 .23086 .35405 .2172 Mtetra
.647 .635 .824 r
.35405 .2172 .36164 .23086 .37427 .22891 .36683 .2124 Mtetra
.636 .591 .787 r
.36683 .2124 .37427 .22891 .38702 .22598 .37968 .20758 Mtetra
.628 .566 .766 r
.37968 .20758 .38702 .22598 .39989 .22209 .39259 .20273 Mtetra
.625 .556 .756 r
.39259 .20273 .39989 .22209 .41287 .21727 .40556 .19786 Mtetra
.40556 .19786 .41287 .21727 .42594 .21152 .41859 .19297 Mtetra
.628 .566 .766 r
.41859 .19297 .42594 .21152 .43909 .20481 .43169 .18806 Mtetra
.636 .591 .787 r
.43169 .18806 .43909 .20481 .45231 .1971 .44485 .18312 Mtetra
.647 .635 .824 r
.44485 .18312 .45231 .1971 .46558 .18847 .45807 .17815 Mtetra
.661 .711 .885 r
.45807 .17815 .46558 .18847 .47885 .18235 .47136 .17316 Mtetra
.664 .741 .907 r
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.48471 .16815 .49217 .17739 .50554 .17239 .49813 .16311 Mtetra
.49813 .16311 .50554 .17239 .51898 .16738 .51162 .15805 Mtetra
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.625 .725 .919 r
.55248 .14271 .55971 .15218 .57342 .14706 .56625 .1388 Mtetra
.65 .769 .936 r
.56625 .1388 .57342 .14706 .58722 .14277 .58009 .13406 Mtetra
.675 .767 .92 r
.58009 .13406 .58722 .14277 .60109 .13844 .59398 .12849 Mtetra
.679 .738 .896 r
.59398 .12849 .60109 .13844 .61501 .13298 .60793 .12269 Mtetra
.674 .73 .892 r
.60793 .12269 .61501 .13298 .62898 .12716 .62196 .11699 Mtetra
.669 .732 .896 r
.62196 .11699 .62898 .12716 .64302 .12145 .63605 .11146 Mtetra
.666 .736 .902 r
.63605 .11146 .64302 .12145 .65714 .11594 .65022 .10605 Mtetra
.665 .739 .906 r
.65022 .10605 .65714 .11594 .67133 .11055 .66447 .10068 Mtetra
.664 .74 .907 r
.66447 .10068 .67133 .11055 .6856 .1052 .67879 .09529 Mtetra
.664 .741 .907 r
.67879 .09529 .6856 .1052 .69994 .09985 .69318 .08989 Mtetra
.69318 .08989 .69994 .09985 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30489 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14572 .29541 .13722 .28721 Mtetra
.13722 .28721 .14572 .29541 .15752 .29099 .14905 .28275 Mtetra
.14905 .28275 .15752 .29099 .16937 .28656 .16094 .27826 Mtetra
.663 .74 .907 r
.16094 .27826 .16937 .28656 .18128 .28218 .17288 .27378 Mtetra
.661 .738 .907 r
.17288 .27378 .18128 .28218 .19322 .27791 .18487 .26933 Mtetra
.657 .733 .905 r
.18487 .26933 .19322 .27791 .2052 .27382 .19691 .26497 Mtetra
.652 .726 .903 r
.19691 .26497 .2052 .27382 .21723 .26984 .20898 .26076 Mtetra
.647 .719 .901 r
.20898 .26076 .21723 .26984 .22934 .26562 .22111 .25667 Mtetra
.649 .724 .903 r
.22111 .25667 .22934 .26562 .24158 .26061 .2333 .25248 Mtetra
.665 .751 .914 r
.2333 .25248 .24158 .26061 .25394 .25478 .24559 .24782 Mtetra
.694 .791 .925 r
.24559 .24782 .25394 .25478 .26625 .25016 .25801 .24228 Mtetra
.687 .765 .911 r
.25801 .24228 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.664 .741 .907 r
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32866 .22673 .32067 .21794 Mtetra
.32067 .21794 .32866 .22673 .34133 .22198 .33337 .21314 Mtetra
.33337 .21314 .34133 .22198 .35405 .2172 .34613 .20832 Mtetra
.34613 .20832 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.424 .17892 .43169 .18806 .44485 .18312 .4372 .17393 Mtetra
.4372 .17393 .44485 .18312 .45807 .17815 .45047 .16892 Mtetra
.45047 .16892 .45807 .17815 .47136 .17316 .4638 .16389 Mtetra
.4638 .16389 .47136 .17316 .48471 .16815 .47719 .15883 Mtetra
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.642 .733 .914 r
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13906 Mtetra
.636 .749 .93 r
.53144 .13906 .53879 .14785 .55248 .14271 .54519 .13477 Mtetra
.664 .784 .938 r
.54519 .13477 .55248 .14271 .56625 .1388 .55899 .12959 Mtetra
.677 .756 .91 r
.55899 .12959 .56625 .1388 .58009 .13406 .57286 .12391 Mtetra
.677 .734 .893 r
.57286 .12391 .58009 .13406 .59398 .12849 .5868 .11814 Mtetra
.672 .728 .892 r
.5868 .11814 .59398 .12849 .60793 .12269 .6008 .11247 Mtetra
.668 .731 .897 r
.6008 .11247 .60793 .12269 .62196 .11699 .61488 .10696 Mtetra
.666 .736 .902 r
.61488 .10696 .62196 .11699 .63605 .11146 .62903 .10153 Mtetra
.665 .739 .905 r
.62903 .10153 .63605 .11146 .65022 .10605 .64325 .09613 Mtetra
.664 .74 .907 r
.64325 .09613 .65022 .10605 .66447 .10068 .65754 .09073 Mtetra
.664 .741 .907 r
.65754 .09073 .66447 .10068 .67879 .09529 .67191 .0853 Mtetra
.67191 .0853 .67879 .09529 .69318 .08989 .68635 .07984 Mtetra
.68635 .07984 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30489 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28721 .12865 .27895 Mtetra
.12865 .27895 .13722 .28721 .14905 .28275 .14051 .27444 Mtetra
.14051 .27444 .14905 .28275 .16094 .27826 .15243 .26991 Mtetra
.15243 .26991 .16094 .27826 .17288 .27378 .16441 .26537 Mtetra
.663 .74 .907 r
.16441 .26537 .17288 .27378 .18487 .26933 .17644 .26082 Mtetra
.662 .738 .907 r
.17644 .26082 .18487 .26933 .19691 .26497 .18852 .25629 Mtetra
.659 .734 .905 r
.18852 .25629 .19691 .26497 .20898 .26076 .20065 .25183 Mtetra
.654 .727 .903 r
.20065 .25183 .20898 .26076 .22111 .25667 .21282 .24748 Mtetra
.649 .72 .9 r
.21282 .24748 .22111 .25667 .2333 .25248 .22504 .24325 Mtetra
.648 .72 .901 r
.22504 .24325 .2333 .25248 .24559 .24782 .23732 .23903 Mtetra
.655 .734 .908 r
.23732 .23903 .24559 .24782 .25801 .24228 .24968 .2346 Mtetra
.671 .769 .924 r
.24968 .2346 .25801 .24228 .27048 .23689 .26214 .2297 Mtetra
.691 .788 .925 r
.26214 .2297 .27048 .23689 .28293 .23219 .2747 .22415 Mtetra
.687 .766 .911 r
.2747 .22415 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.664 .741 .907 r
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.642 .733 .915 r
.48311 .14429 .49065 .15375 .50418 .14864 .49667 .13986 Mtetra
.638 .75 .929 r
.49667 .13986 .50418 .14864 .51778 .1435 .51031 .13549 Mtetra
.659 .78 .938 r
.51031 .13549 .51778 .1435 .53144 .13906 .52403 .13046 Mtetra
.673 .77 .923 r
.52403 .13046 .53144 .13906 .54519 .13477 .53781 .12495 Mtetra
.677 .741 .9 r
.53781 .12495 .54519 .13477 .55899 .12959 .55166 .11923 Mtetra
.674 .729 .891 r
.55166 .11923 .55899 .12959 .57286 .12391 .56557 .11351 Mtetra
.67 .727 .892 r
.56557 .11351 .57286 .12391 .5868 .11814 .57956 .10791 Mtetra
.667 .731 .898 r
.57956 .10791 .5868 .11814 .6008 .11247 .59361 .10241 Mtetra
.665 .736 .903 r
.59361 .10241 .6008 .11247 .61488 .10696 .60774 .09698 Mtetra
.664 .739 .905 r
.60774 .09698 .61488 .10696 .62903 .10153 .62194 .09156 Mtetra
.664 .74 .907 r
.62194 .09156 .62903 .10153 .64325 .09613 .63621 .08614 Mtetra
.664 .741 .907 r
.63621 .08614 .64325 .09613 .65754 .09073 .65055 .08068 Mtetra
.65055 .08068 .65754 .09073 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07984 .67946 .0697 Mtetra
.67946 .0697 .68635 .07984 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26991 .14385 .2615 Mtetra
.14385 .2615 .15243 .26991 .16441 .26537 .15586 .25691 Mtetra
.15586 .25691 .16441 .26537 .17644 .26082 .16792 .2523 Mtetra
.663 .74 .907 r
.16792 .2523 .17644 .26082 .18852 .25629 .18004 .24769 Mtetra
.662 .739 .907 r
.18004 .24769 .18852 .25629 .20065 .25183 .19222 .24308 Mtetra
.66 .735 .905 r
.19222 .24308 .20065 .25183 .21282 .24748 .20444 .23851 Mtetra
.657 .73 .903 r
.20444 .23851 .21282 .24748 .22504 .24325 .21672 .234 Mtetra
.653 .723 .9 r
.21672 .234 .22504 .24325 .23732 .23903 .22904 .2296 Mtetra
.65 .719 .898 r
.22904 .2296 .23732 .23903 .24968 .2346 .24142 .22525 Mtetra
.651 .722 .9 r
.24142 .22525 .24968 .2346 .26214 .2297 .25386 .22086 Mtetra
.656 .737 .909 r
.25386 .22086 .26214 .2297 .2747 .22415 .26637 .21631 Mtetra
.667 .767 .925 r
.26637 .21631 .2747 .22415 .28732 .21867 .27897 .21145 Mtetra
.678 .788 .933 r
.27897 .21145 .28732 .21867 .29993 .21388 .29166 .20623 Mtetra
.687 .78 .922 r
.29166 .20623 .29993 .21388 .31261 .20907 .30443 .20069 Mtetra
.683 .761 .911 r
.30443 .20069 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.664 .741 .907 r
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.646 .734 .913 r
.43505 .15021 .44279 .15961 .45616 .15453 .44845 .14567 Mtetra
.643 .748 .926 r
.44845 .14567 .45616 .15453 .4696 .14942 .46192 .1412 Mtetra
.652 .77 .935 r
.46192 .1412 .4696 .14942 .48311 .14429 .47546 .13641 Mtetra
.663 .785 .939 r
.47546 .13641 .48311 .14429 .49667 .13986 .48909 .13126 Mtetra
.672 .769 .923 r
.48909 .13126 .49667 .13986 .51031 .13549 .50278 .1258 Mtetra
.675 .744 .902 r
.50278 .1258 .51031 .13549 .52403 .13046 .51654 .12016 Mtetra
.673 .73 .892 r
.51654 .12016 .52403 .13046 .53781 .12495 .53037 .11448 Mtetra
.671 .726 .891 r
.53037 .11448 .53781 .12495 .55166 .11923 .54426 .10885 Mtetra
.668 .728 .894 r
.54426 .10885 .55166 .11923 .56557 .11351 .55822 .10331 Mtetra
.666 .733 .9 r
.55822 .10331 .56557 .11351 .57956 .10791 .57225 .09785 Mtetra
.665 .737 .904 r
.57225 .09785 .57956 .10791 .59361 .10241 .58636 .09241 Mtetra
.664 .739 .906 r
.58636 .09241 .59361 .10241 .60774 .09698 .60053 .08698 Mtetra
.664 .74 .907 r
.60053 .08698 .60774 .09698 .62194 .09156 .61478 .08153 Mtetra
.664 .741 .907 r
.61478 .08153 .62194 .09156 .63621 .08614 .6291 .07605 Mtetra
.6291 .07605 .63621 .08614 .65055 .08068 .6435 .07055 Mtetra
.6435 .07055 .65055 .08068 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26676 Mtetra
.09942 .26676 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25691 .14724 .24838 Mtetra
.14724 .24838 .15586 .25691 .16792 .2523 .15933 .24373 Mtetra
.15933 .24373 .16792 .2523 .18004 .24769 .17149 .23906 Mtetra
.664 .74 .907 r
.17149 .23906 .18004 .24769 .19222 .24308 .1837 .23438 Mtetra
.663 .739 .907 r
.1837 .23438 .19222 .24308 .20444 .23851 .19596 .22968 Mtetra
.662 .737 .906 r
.19596 .22968 .20444 .23851 .21672 .234 .20828 .22501 Mtetra
.66 .733 .904 r
.20828 .22501 .21672 .234 .22904 .2296 .22066 .22036 Mtetra
.657 .727 .901 r
.22066 .22036 .22904 .2296 .24142 .22525 .23309 .21577 Mtetra
.654 .722 .898 r
.23309 .21577 .24142 .22525 .25386 .22086 .24557 .21123 Mtetra
.652 .718 .897 r
.24557 .21123 .25386 .22086 .26637 .21631 .25811 .20671 Mtetra
.653 .72 .898 r
.25811 .20671 .26637 .21631 .27897 .21145 .27071 .20218 Mtetra
.656 .73 .904 r
.27071 .20218 .27897 .21145 .29166 .20623 .28339 .19754 Mtetra
.66 .747 .915 r
.28339 .19754 .29166 .20623 .30443 .20069 .29613 .19278 Mtetra
.665 .77 .928 r
.29613 .19278 .30443 .20069 .31724 .19523 .30895 .18787 Mtetra
.668 .788 .938 r
.30895 .18787 .31724 .19523 .33008 .19033 .32184 .18283 Mtetra
.67 .786 .936 r
.32184 .18283 .33008 .19033 .34298 .1854 .33479 .17772 Mtetra
.67 .782 .933 r
.33479 .17772 .34298 .1854 .35594 .18045 .3478 .17259 Mtetra
.668 .778 .932 r
.3478 .17259 .35594 .18045 .36896 .17547 .36087 .16749 Mtetra
.665 .775 .931 r
.36087 .16749 .36896 .17547 .38205 .17047 .37401 .16244 Mtetra
.663 .774 .932 r
.37401 .16244 .38205 .17047 .3952 .16544 .3872 .15745 Mtetra
.661 .775 .934 r
.3872 .15745 .3952 .16544 .40842 .16039 .40046 .15249 Mtetra
.66 .779 .937 r
.40046 .15249 .40842 .16039 .4217 .15531 .41378 .14751 Mtetra
.662 .783 .939 r
.41378 .14751 .4217 .15531 .43505 .15021 .42718 .14245 Mtetra
.665 .787 .939 r
.42718 .14245 .43505 .15021 .44845 .14567 .44064 .13727 Mtetra
.67 .772 .927 r
.44064 .13727 .44845 .14567 .46192 .1412 .45418 .13193 Mtetra
.672 .751 .91 r
.45418 .13193 .46192 .1412 .47546 .13641 .46778 .12646 Mtetra
.672 .736 .898 r
.46778 .12646 .47546 .13641 .48909 .13126 .48145 .12089 Mtetra
.671 .727 .891 r
.48145 .12089 .48909 .13126 .50278 .1258 .49519 .11529 Mtetra
.669 .724 .89 r
.49519 .11529 .50278 .1258 .51654 .12016 .50899 .10971 Mtetra
.668 .726 .893 r
.50899 .10971 .51654 .12016 .53037 .11448 .52286 .10418 Mtetra
.666 .73 .898 r
.52286 .10418 .53037 .11448 .54426 .10885 .5368 .09871 Mtetra
.665 .735 .902 r
.5368 .09871 .54426 .10885 .55822 .10331 .55081 .09326 Mtetra
.664 .738 .905 r
.55081 .09326 .55822 .10331 .57225 .09785 .56488 .08782 Mtetra
.664 .74 .906 r
.56488 .08782 .57225 .09785 .58636 .09241 .57904 .08237 Mtetra
.664 .74 .907 r
.57904 .08237 .58636 .09241 .60053 .08698 .59326 .0769 Mtetra
.664 .741 .907 r
.59326 .0769 .60053 .08698 .61478 .08153 .60756 .0714 Mtetra
.60756 .0714 .61478 .08153 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24373 .15067 .23509 Mtetra
.15067 .23509 .15933 .24373 .17149 .23906 .16285 .23037 Mtetra
.16285 .23037 .17149 .23906 .1837 .23438 .1751 .22564 Mtetra
.664 .74 .907 r
.1751 .22564 .1837 .23438 .19596 .22968 .1874 .22088 Mtetra
.663 .74 .907 r
.1874 .22088 .19596 .22968 .20828 .22501 .19976 .21612 Mtetra
.663 .738 .906 r
.19976 .21612 .20828 .22501 .22066 .22036 .21218 .21134 Mtetra
.662 .736 .905 r
.21218 .21134 .22066 .22036 .23309 .21577 .22465 .20657 Mtetra
.66 .732 .903 r
.22465 .20657 .23309 .21577 .24557 .21123 .23718 .20182 Mtetra
.658 .728 .9 r
.23718 .20182 .24557 .21123 .25811 .20671 .24977 .19709 Mtetra
.657 .723 .898 r
.24977 .19709 .25811 .20671 .27071 .20218 .26242 .19237 Mtetra
.656 .719 .896 r
.26242 .19237 .27071 .20218 .28339 .19754 .27513 .18767 Mtetra
.656 .719 .895 r
.27513 .18767 .28339 .19754 .29613 .19278 .2879 .18293 Mtetra
.656 .721 .896 r
.2879 .18293 .29613 .19278 .30895 .18787 .30074 .17816 Mtetra
.658 .725 .899 r
.30074 .17816 .30895 .18787 .32184 .18283 .31364 .17333 Mtetra
.66 .732 .903 r
.31364 .17333 .32184 .18283 .33479 .17772 .32662 .16842 Mtetra
.661 .739 .907 r
.32662 .16842 .33479 .17772 .3478 .17259 .33966 .16345 Mtetra
.663 .744 .911 r
.33966 .16345 .3478 .17259 .36087 .16749 .35276 .15842 Mtetra
.664 .748 .912 r
.35276 .15842 .36087 .16749 .37401 .16244 .36594 .15332 Mtetra
.665 .748 .912 r
.36594 .15332 .37401 .16244 .3872 .15745 .37918 .14817 Mtetra
.666 .745 .909 r
.37918 .14817 .3872 .15745 .40046 .15249 .39249 .14296 Mtetra
.667 .741 .905 r
.39249 .14296 .40046 .15249 .41378 .14751 .40586 .13768 Mtetra
.668 .735 .9 r
.40586 .13768 .41378 .14751 .42718 .14245 .41931 .13232 Mtetra
.668 .729 .895 r
.41931 .13232 .42718 .14245 .44064 .13727 .43282 .12691 Mtetra
.668 .725 .892 r
.43282 .12691 .44064 .13727 .45418 .13193 .44639 .12144 Mtetra
.668 .723 .89 r
.44639 .12144 .45418 .13193 .46778 .12646 .46004 .11595 Mtetra
.667 .723 .891 r
.46004 .11595 .46778 .12646 .48145 .12089 .47375 .11047 Mtetra
.666 .726 .894 r
.47375 .11047 .48145 .12089 .49519 .11529 .48752 .105 Mtetra
.666 .73 .898 r
.48752 .105 .49519 .11529 .50899 .10971 .50137 .09954 Mtetra
.665 .734 .901 r
.50137 .09954 .50899 .10971 .52286 .10418 .51528 .0941 Mtetra
.664 .737 .904 r
.51528 .0941 .52286 .10418 .5368 .09871 .52926 .08866 Mtetra
.664 .739 .906 r
.52926 .08866 .5368 .09871 .55081 .09326 .54332 .08321 Mtetra
.664 .74 .907 r
.54332 .08321 .55081 .09326 .56488 .08782 .55745 .07774 Mtetra
.664 .741 .907 r
.55745 .07774 .56488 .08782 .57904 .08237 .57165 .07225 Mtetra
.57165 .07225 .57904 .08237 .59326 .0769 .58592 .06673 Mtetra
.58592 .06673 .59326 .0769 .60756 .0714 .60027 .06118 Mtetra
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23037 .15414 .22161 Mtetra
.15414 .22161 .16285 .23037 .1751 .22564 .16642 .21683 Mtetra
.16642 .21683 .1751 .22564 .1874 .22088 .17876 .21203 Mtetra
.17876 .21203 .1874 .22088 .19976 .21612 .19115 .20721 Mtetra
.664 .74 .907 r
.19115 .20721 .19976 .21612 .21218 .21134 .20361 .20237 Mtetra
.663 .74 .907 r
.20361 .20237 .21218 .21134 .22465 .20657 .21612 .19751 Mtetra
.663 .738 .906 r
.21612 .19751 .22465 .20657 .23718 .20182 .22869 .19264 Mtetra
.662 .736 .905 r
.22869 .19264 .23718 .20182 .24977 .19709 .24133 .18776 Mtetra
.661 .733 .903 r
.24133 .18776 .24977 .19709 .26242 .19237 .25402 .18288 Mtetra
.661 .73 .901 r
.25402 .18288 .26242 .19237 .27513 .18767 .26678 .17799 Mtetra
.66 .727 .899 r
.26678 .17799 .27513 .18767 .2879 .18293 .27959 .1731 Mtetra
.659 .724 .897 r
.27959 .1731 .2879 .18293 .30074 .17816 .29247 .16819 Mtetra
.659 .722 .895 r
.29247 .16819 .30074 .17816 .31364 .17333 .30542 .16325 Mtetra
.659 .72 .894 r
.30542 .16325 .31364 .17333 .32662 .16842 .31843 .15828 Mtetra
.66 .72 .893 r
.31843 .15828 .32662 .16842 .33966 .16345 .3315 .15325 Mtetra
.661 .72 .893 r
.3315 .15325 .33966 .16345 .35276 .15842 .34465 .14817 Mtetra
.662 .721 .892 r
.34465 .14817 .35276 .15842 .36594 .15332 .35786 .14303 Mtetra
.663 .721 .892 r
.35786 .14303 .36594 .15332 .37918 .14817 .37113 .13783 Mtetra
.37113 .13783 .37918 .14817 .39249 .14296 .38448 .13258 Mtetra
.664 .722 .892 r
.38448 .13258 .39249 .14296 .40586 .13768 .39789 .12727 Mtetra
.665 .722 .892 r
.39789 .12727 .40586 .13768 .41931 .13232 .41137 .12193 Mtetra
.665 .724 .893 r
.41137 .12193 .41931 .13232 .43282 .12691 .42492 .11655 Mtetra
.665 .726 .895 r
.42492 .11655 .43282 .12691 .44639 .12144 .43853 .11115 Mtetra
.665 .728 .897 r
.43853 .11115 .44639 .12144 .46004 .11595 .45222 .10575 Mtetra
.665 .732 .9 r
.45222 .10575 .46004 .11595 .47375 .11047 .46597 .10034 Mtetra
.664 .734 .902 r
.46597 .10034 .47375 .11047 .48752 .105 .47978 .09492 Mtetra
.664 .737 .904 r
.47978 .09492 .48752 .105 .50137 .09954 .49367 .08949 Mtetra
.664 .739 .906 r
.49367 .08949 .50137 .09954 .51528 .0941 .50763 .08405 Mtetra
.664 .74 .906 r
.50763 .08405 .51528 .0941 .52926 .08866 .52166 .07858 Mtetra
.664 .74 .907 r
.52166 .07858 .52926 .08866 .54332 .08321 .53576 .07309 Mtetra
.664 .741 .907 r
.53576 .07309 .54332 .08321 .55745 .07774 .54994 .06758 Mtetra
.54994 .06758 .55745 .07774 .57165 .07225 .56419 .06203 Mtetra
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10877 .2271 Mtetra
.10877 .2271 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21683 .15767 .20795 Mtetra
.15767 .20795 .16642 .21683 .17876 .21203 .17004 .20311 Mtetra
.17004 .20311 .17876 .21203 .19115 .20721 .18247 .19824 Mtetra
.18247 .19824 .19115 .20721 .20361 .20237 .19496 .19335 Mtetra
.19496 .19335 .20361 .20237 .21612 .19751 .20751 .18844 Mtetra
.664 .74 .907 r
.20751 .18844 .21612 .19751 .22869 .19264 .22012 .18351 Mtetra
.663 .74 .907 r
.22012 .18351 .22869 .19264 .24133 .18776 .23279 .17857 Mtetra
.663 .739 .907 r
.23279 .17857 .24133 .18776 .25402 .18288 .24552 .1736 Mtetra
.662 .738 .906 r
.24552 .1736 .25402 .18288 .26678 .17799 .25832 .16863 Mtetra
.662 .737 .906 r
.25832 .16863 .26678 .17799 .27959 .1731 .27117 .16364 Mtetra
.662 .736 .905 r
.27117 .16364 .27959 .1731 .29247 .16819 .28409 .15864 Mtetra
.662 .734 .904 r
.28409 .15864 .29247 .16819 .30542 .16325 .29708 .15361 Mtetra
.662 .733 .903 r
.29708 .15361 .30542 .16325 .31843 .15828 .31013 .14855 Mtetra
.662 .733 .902 r
.31013 .14855 .31843 .15828 .3315 .15325 .32324 .14346 Mtetra
.662 .732 .902 r
.32324 .14346 .3315 .15325 .34465 .14817 .33643 .13832 Mtetra
.663 .732 .901 r
.33643 .13832 .34465 .14817 .35786 .14303 .34967 .13313 Mtetra
.664 .733 .901 r
.34967 .13313 .35786 .14303 .37113 .13783 .36299 .1279 Mtetra
.36299 .1279 .37113 .13783 .38448 .13258 .37638 .12261 Mtetra
.665 .734 .901 r
.37638 .12261 .38448 .13258 .39789 .12727 .38983 .1173 Mtetra
.665 .735 .902 r
.38983 .1173 .39789 .12727 .41137 .12193 .40335 .11194 Mtetra
.665 .736 .903 r
.40335 .11194 .41137 .12193 .42492 .11655 .41694 .10657 Mtetra
.665 .737 .903 r
.41694 .10657 .42492 .11655 .43853 .11115 .43059 .10118 Mtetra
.665 .738 .905 r
.43059 .10118 .43853 .11115 .45222 .10575 .44431 .09576 Mtetra
.664 .739 .905 r
.44431 .09576 .45222 .10575 .46597 .10034 .45811 .09034 Mtetra
.664 .74 .906 r
.45811 .09034 .46597 .10034 .47978 .09492 .47197 .08489 Mtetra
.664 .74 .907 r
.47197 .08489 .47978 .09492 .49367 .08949 .4859 .07943 Mtetra
.4859 .07943 .49367 .08949 .50763 .08405 .49991 .07394 Mtetra
.664 .741 .907 r
.49991 .07394 .50763 .08405 .52166 .07858 .51399 .06843 Mtetra
.51399 .06843 .52166 .07858 .53576 .07309 .52814 .06289 Mtetra
.52814 .06289 .53576 .07309 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000003H0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0ZKgX00<000000:Vmj02Y_NP0<`2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0030?ooo`000000oooo05`0oooo002a0?ooo`<00000?02Y_NP00`000000ZKgX0:Vmj00;0:Vmj080
0000G03oool00:h0oooo0`0000090:Vmj0<0ZKgW<`2Y_NP00`000000ZKgX0:Vmj00<0:Vmj0030000
003oool0oooo05X0oooo002/0?ooo`@00000202Y_NP60:Vmi`<0ZKgX0`2Y_NL80:Vmj0<0ZKgW8@2Y
_NP00`000000ZKgX0:Vmj00<0:Vmj0030?ooo`000000oooo05X0oooo001k0?ooo`050?ooS`0e0000
0000000DG`34ool0:P3oool200000080ZKgW1P2Y_NP@0:Vmi`D0ZKgX1`2Y_NLP0:Vmj0030000002Y
_NP0ZKgX00d0ZKgX00<0oooo0000003oool0F@3oool007X0oooo00H0ooo405lD000DGl@0oooo0<AO
5000=HlW0?ooo`<000001@2Y_NL30:Vmj0<0ZKcW1`2Y_NL30:Vli`H0ZKgW0P2Y_NP30:Vli`/0ZKgW
6`2Y_NP00`000000ZKgX0:Vmj00>0:Vmj0030000003oool0oooo05P0oooo001j0?ooo`070?ooS`0e
03D0Sooo0?ooo`3oa5l0500e08ooo`0T0?ooo`800000202Y_NL70:Vli`@0ZKgW1P2Y_>L50:Vmi`H0
ZKcW0`2Y_NL30:Zli`D0ZKgW0`2Y_NP30:VmiaD0ZKgX00<000000:Vmj02Y_NP03@2Y_NP00`3oool0
00000?ooo`1H0?ooo`00NP3oool01`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l08@3oool40000
00L0ZKgW0`2Y^nH60:Vli`D0Z[_V1P2Y_>L50:ZliPD0ZKcW1`2Z_>L;0:Vmi`80ZKgX0`2Z_NL?0:Vm
j0030000002Y_NP0ZKgX00h0ZKgX00<000000?ooo`3oool0E`3oool007X0oooo00L0ohle000DG`34
ool0oooo0?ooS`0e01@0GlCo01l0oooo0P0000050:Zli`@0ZKgW1P2Y^nH30:Vli`<0Z[[U1@2Z^nH3
0:Vli`<0Z[[U1@2Z_>H20:Vli`<0Z[_V2`2Z_>L60:Vmi`H0Z[gW3P2Y_NP00`000000ZKgX0:Vmj00?
0:Vmj0030000003oool0oooo0180oooo00D0gia8000000000000001809cOo`0o0?ooo`00NP3oool0
1`3oa5l051AO0<Coo`3oool0oon?03D0501Oa?l0703oool3000000L0Z[cW1@2Z^nH60:VkiPD0Z[[U
1@2Z^nH70:Zji@@0Z[cV1P2Z^nH30:Zli`<0Z[_U1@2Z_>L30:Vmi`<0Z[cV2P2Z_NL90:Vmj0030000
002Y_NP0ZKgX00l0ZKgX00<0oooo0000003oool04@3oool01`3o_g@004RL0=ooo`3oool0oooO09a8
M02oool0?P3oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo01T0oooo0`000008
0:Zli`<0Z[[U1@2Z^nH30:VkiP<0Z[WT1@2Z^^D20:ZkiP<0ZkWT1P2Z^^D50:^ji0H0Z[_V1P2Z^nD4
0:Zli`L0Z[cV0P2Z_NL30:ZliPD0Z[gW0`2Y_NP30:Vmi`80ZKgX00<000000:Vmj02Y_NP0402Y_NP0
0`000000oooo0?ooo`0E0?ooo`030;md001d_ol0oooo03d0oooo001j0?ooo`060?ooa01O5000=Hoo
0?ooo`34Ga@003F?603oool2000000030:Zli`000000Z[cW00H0Z[cW1P2Z^^D50:ZkiPH0Z[WT102Z
^^D60:^ii0<0Z[[U0`2[^N@50:^ji0<0Z[_V0`2[^^@50:Zki@D0Zk_U302Z_>H50:Zmi`H0ZKgW00<0
ZKgX0000002Y_NP04P2Y_NP00`000000oooo0?ooo`070?ooo`030?oOW0180000000000<0000000<0
001d0;ooo`3oool0103oool00`2oM000M;oo0?ooo`0m0?ooo`00N`3oool01@3oohl0=@0000000000
55l0a?oo01D0oooo0`0000000`2Z_>H0Z[cW0:Zli`060:Zli`<0Z[WU1@2Z^^D;0:Zii0D0ZkWS302[
^N@;0:^ji080Z[_U0`2/^^@50:^ki@<0Z[cV0`2[^nD50:ZliPH0Z[cW1P2Y_NL010000000ZKgW0:Vm
i`2Y_NL@0:Vmj0030?ooo`000000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo
03h0oooo002C0?ooo`8000001@2Z_>H50:Zli`H0Z[WU0P2Z^^D30:^ih`P0Z[WT0`2[^^@50:^ih`<0
ZkWT0`2/^^@50:^ii0D0[;[T1P2[^^@60:bji0/0Zk_U0P2Z_>H30:^ki@H0Z[cW0P2Y_NL30:Zli`03
0000002Y_NL0ZKgW0080ZKgW402Y_NP00`000000oooo0?ooo`0>0?ooo`030?oo_`1d000000000080
000000<0M;oo0?ooo`3oool0?@3oool00900oooo0`0000020:ZkiPH0Z[cV1@2Z^N@50:Zii@H0ZkWS
1@2Z^N@60:^ji0D0ZkWS1P2/^^@20:^ii0<0[KgV1@2/^^@30:^ji0<0[K_T2`2/^^@;0:^ki@X0Z[cW
00<000000:Vmi`2Y_NL00`2Z_NL@0:Vmj0030000003oool0oooo00d0oooo00<0oooO09a8B02Lgol0
@P3oool008h0oooo0P0000000`2Y^nH000000:ZkiP030:ZkiP<0Z[cV0`2Z^>@50:Zii080Z[WU0`2[
^N@60:^ih`80Z[WT0`2/_>D50:^ji0H0[;kV1@2/^^@50:fmiPH0[;[T1P2]^n@20:bji0<0[KcU1P2/
^^@20:^ki@<0[;_T2`2[^nD40:Zli`030000002Z_NL0Z[gW00@0Z[gW3`2Y_NP00`3oool000000?oo
o`0>0?ooo`030;md001d_ol0oooo0440oooo002;0?ooo`<00000102Y^nH50:ZkiPH0Z[ST102Z^N@6
0:^ii0D0ZkWS1P2/_>D20:^ji0<0[<C/1P2/_^H20:bji0<0[<G/1@2]_NH30:bji0<0[L7X1@2]^n@5
0:fli@H0[;[T1P2/^n@20:^ki@<0[;_T1P2[^nD20:Zli`030:^liP000000ZkcV00/0Z[gW2P2Y_NP0
0`000000oooo0?ooo`0=0?ooo`060=nLB000000000000000000007@0_ooo?P3oool008T0oooo0P00
00070:VkiPH0ZKST1@2Z^>@50:^ji@H0ZkWT1@2/`>P50:bli@H0[<C/1@2/_^H60:c5k0@0[KgV1`2]
`NP20:fki0<0[<C[1@2]_>D30:bji0<0[[gU2`2/^n@50:^ki@<0ZkcV00<000000:^liP2[_>H00P2Z
_NL30:ZliPH0Z[gW2P2Y_NP00`000000oooo0?ooo`1@0?ooo`00QP3oool3000000L0ZK_V2@2Y^>@2
0:Zhi0<0ZkcV1@2[^^D30:^ii0<0ZlG]1@2/`>P20:bli@<0ZLS`1P2/a>`50:S7l0D0[<G/1P2Yb?05
0:g1j0H0[<C[102]_>D70:jmi@80[;_T0`2^_ND;0:bki080ZkcV00<000000:^liP2[_>H01P2Z_>H5
0:Zmi`X0ZKgX00<0oooo0000003oool0D03oool008@0oooo0`0000070:VkiP/0ZKST1P2[_>H40:^j
i@L0ZlG]102/`>P60:W8l0<0[<C/0`2S_nd50:S7l0D0X[o^1P2Yb?050:K4k`D0[<C[1@2/aN`<0:jm
i@80[;_T0`2^_ND60:bki0030:^liP000000[;_U0080[;_U1@2Z_>H60:Zmi`X0ZKgX00<000000?oo
o`3oool0C`3oool00840oooo0`0000030:VkiP030000002Y^nH0ZK_V0080ZK_V2`2Y^>@30:Zmi`D0
ZkcV1P2ZbO050:_5k@D0Y/G_1P2Yb?060:>ok@80Z<O`0`2T^nT50::okP<0ZLS`0`2O^N/50:K4k`80
[<C[0`2S`>h50:c5k0<0[[gU0`2/aN`:0:jmi@H0[;_T00<0[;_U0000002/^nD00`2/^nD20:ZliP<0
ZkcV1P2Z_NL20:Vmj0<0Z[gW1@2Y_NP00`000000oooo0?ooo`1>0?ooo`00O`3oool2000000T0ZK_V
2`2Y^>@60:Zmi`80ZkcV0`2Yb?060:[9l0D0Y;o]1@2VaNl60:BkjPD0Xko]1P2T^nT40::okPL0WkW[
102Va>l60:?0kP/0[<G/0P2^_ND30:c4j`D0[[gU0`2/^n@30:jli0030000002/^nD0[;_U0080[;_U
1P2[_>H;0:Zmi`D0ZKgX00<000000?ooo`3oool0C@3oool007`0oooo0`0000070:VkiP/0ZKST1@2Z
_^P50:Zmi`H0ZLS`0`2ZbO030:Fkj@D0Y;o]0P2VaNl30:Vmj0H0Y;_Z1@2Y_NP50:Bkj@H0ZKgX1@2O
^N/50:>kjPD0Xl3^1P2Q_^d50:c5k0H0[<C[102^_ND60:jli0030000002/^nD0[;_U00<0[KcT2`2[
_>H50:Zmi`D0ZKgX00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD000000000000000D05o4
o`0Y0?ooo`<0000000<0ZK_W0000002Y^nH01@2Y^nH;0:Vhi0<0Z[oY1@2Z_^P20:Zmi`@0Z<O_1@2Y
b?060:Fkj@@0Y;o]1P2Y_NP30:BkjPP0ZKgX0P2T^nT>0:Vmj0D0Xk_Z1@2U^nT;0:6nk@D0[<C[1@2]
`^T50:jli0030000002]_>@0[KcT00@0[KcT0P2[_>H30:fli@D0ZkcV1P2Z_NL50:Vmj0030000003o
ool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08ooo`0V0?ooo`800000
1@2Y^nL40:VkiP/0ZKST1P2Z_nT40:Znj0L0Z<O_1@2Y_NP50:FkjBH0ZKgX0P2S^nX30:Vmj0/0YK_Y
1@2Q_^d20:c4j`<0Xl3^1@2]`^T30:jli080[[oV00<000000:fli02]_>@00`2]_>@60:fli@@0ZkcV
1`2Z_NL20:Vmj080Z[gW00<000000?ooo`3oool0C03oool004l0oooo00<0ScD003F?o`3oool08P3o
ool3000000L0ZK_W1@2X^>@60:Vhi0D0ZKoY1@2Z_nT60:W6k`<0Z<O_202Y_NP20:FkjBh0ZKgX0P2U
^nT30:Vmj0H0YK_Y102Q_^d60:?0kP@0[L;Y1@2^_nH010000000[[oV0:fli02]_>@30:nmi@D0[KcU
1@2/_>H;0:Zmi`030000003oool0oooo04/0oooo00120?ooo`030?o4G`0D0000000000<0000000<0
000e08ooo`3oool0103oool00`2?=@00=Hoo0?ooo`0P0?ooo`80000000<0ZKcW0:Vki`2Y^nL01@2Y
^nL80:Rhi0<0ZKST0`2Y_^T50:Voj@80Z[oY102Ya^h50:W6kd00ZKgX1@2U^nT50:>jjPD0Xl3^1P2V
aNl30:joiP030000002^_nH0[kgU00D0[kgU0P2]_>D30:jli0D0[;cV1P2[_NL50:Zmi`030000003o
ool0oooo04X0oooo001:0?ooo`070?o4G`0D01@0GlCo0?ooo`3ool@0Ga@D05o4o`0N0?ooo`<00000
00@0ZKcW0000002Y_>L0ZKcW102Y^nL;0:Rhi0H0ZKkY102Y_nT70:W6kTX0ZKgX1@2S^^X509nij`H0
Y/G_0P2[a>`00`000000ZlC/0:_4k0050:nmi@H0[[cT0P2/_>H30:fli@H0ZkgW102Z_NL00`000000
oooo0?ooo`1:0?ooo`00BP3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01X0oooo
00<0ZKcW0000000000001`2Y_>L50:Rhi@H0Z;ST1@2Y_NP50:Vnj@H0Z/K^0`2Ya^i=0:Vmj080Xk[Z
0`2Y_NP509nij`H0WKS[00<0ZlC/0000002[a>`00P2[a>`20:nmi@<0[/3W1@2^_>@60:fli@D0ZkgW
1@2Z_NL00`000000oooo0?ooo`190?ooo`00BP3oool00`3ool@0Ga@D05o4o`0M0?ooo`<00000202Y
_>L20:Rii@D0Z;SU0`2X^>@30:Rki`D0ZKgX0P2Y_^T40:_7kPD0Z/K^E@2Y_NP209nij`<0ZKgX1@2M
^>/00`2[a>`000000:_4k0020:_4k0H0[/3W0P2^_>@30:nni@D0[KcU1P2[_NH50:Zmi`030000003o
ool0oooo04P0oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000090:Vli`D0Z;WU1@2X^>D6
0:Rki`@0ZKgX1`2[anhb0:Vmj0<0Y9k?1`2Y_NP30:VfhR00ZKgX102M^>/00`2R_nh000000::okP03
0::okPD0[/3W1P2__^D20:fli@<0[[gU1@2[_NH50:Zmi`030000003oool0oooo04P0oooo001;0?oo
o`060<AO5000000000000000000003D0Sooo4`3oool01`2Y_NP00000000000000000ZKgX0:Vli`00
0000102Y_>L50:RjiPD0Z;WU1@2X^NH50:Rki`H0ZlS^0`2[anhM0:Vmj0D0ZKKR1@2Y_NP50:BNc`H0
ZKgX1P2TW/l40:Vmj0H0ZKKR0P2Y_NP30:N[fQX0ZKgX1@2T^nT00`000000X[o^0::okP030::okPD0
Z/?/1@2__^D60:jmi@@0ZkgV1P2Z_NL00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_NP00000
000000050:Vmj0<0ZKcW0`2Y^^H50:RjiP80Z;WU0`2W^>D50:RiiP80Z;_W0`2[bNl60:_8kQd0ZKgX
0`2UX]850:VfhP80ZKgX0`2ORkl50:BNc`H0WHNk1@2TW/l50:2>`@D0ZKKR1P2WZmXJ0:Vmj0@0Y;_Y
00<0000009fhj`2M^>/0102M^>/50:[3k080[kkU0`2^_nH50:jmi@D0[;gV1P2Z_NL00`000000oooo
0?ooo`160?ooo`00G`3oool4000000P0ZKgX1P2Y^^H40:RjiPH0YkSU102X^NH60:_9k`<0ZlS^7@2Y
_NP60:FRdP@0ZKKR1@2ORkl40:BNc`80/Y>g1@2MQk/40:BNc`80/iFi1@2PS/420:VfhP<0Xhfl2`2W
ZmXE0:Vmj080Y;_Y00<0ZKgX0000002Y_NP01P2M^>/40:[3k0H0[[oV0P2^_ND30:nni@D0[;gV1@2Z
_NL00`000000oooo0?ooo`160?ooo`00G@3oool0102Y_NP000000000000000060:Vmj0D0ZK_W1@2Y
^^H:0:Nhi@H0ZlW`1@2[bNlK0:Vmj0D0XYO91@2UX]850:66^0D0Wh^o0P2TW/l30;:C]`H0WHNk0P2T
W/l30;>E^@D0X8k11@2SSK`40:N[fP80Zi>m1P2WZmX50:VehQ80ZKgX00<000000:Vmj02Y_NP01@2M
^>/50::okPD0[[oV1P2__^D20:bmiP<0[KgU1@2Z_NL00`000000oooo0?ooo`150?ooo`00F`3oool3
000000L0ZKgX0`2Y_>L50:Vki`80ZK[V2`2W^>D30:[5k@D0ZlW`7@2Y_NP30:2@a0@0XYO9102UX]82
0:Z>]`@0XHJh1@2ORkl00`2TW/l0/Y>g0;:C]`030;:C]`D0WHNk1@2cUKT40:2>`@80`:2i1@2SSK`2
0:N[fP<0Zi>m1@2WZmX20:bF_`D0ZKGR4@2Y_NP00`000000ZKgX0:Vmj0060:Bkj@D0X[o^0P2^_nH3
0:c1j@D0[kkU1P2]_ND40:Zmi`030?ooo`000000oooo04D0oooo001H0?ooo`<00000202Y_NP60:Vl
i`@0ZK_W2`2W^>D60:[5kAl0ZKgX1@2PT<@50::Gb@80YJ;B0`2ZS[L40:66^0D0Wh^o1P2bTkL409f7
^`80_:2m1@2cUKT20:2>`@<0`:2i1@2SSK`60:^C_@80Yj_J102/U[l50:VehQ40ZKgX00@000000:Vm
j02Y_NP0ZKgX1@2T^nT50::okPH0[<7Y1@2__^D50:fmi@D0ZkgW00<000000?ooo`3oool0A03oool0
05D0oooo00<0ZKgX0000000000001`2Y_NP;0:Vli`@0Z;WU1P2W^>D50:RojP<0Z/G]0`2^`^TJ0:Vm
j0D0Whk11@2PT<@40::Gb@D0ZXjg1@2QQ[P309n;_`80]9Vl1P2bTkL209f7^`<0_:2m1@2cUKT00`2P
S/40`:2i0<2P^@020<2P^@@0Xhfl0P35Y[/50:^C_@L0[9Jo0P2Y]N830:JD`a00ZKgX00<000000:Vm
j02Y_NP00P2Y_NP20:Bkj@<0ZKgX1@2L^>/50:c1j@H0[kkU0P2]_ND30:jni@D0ZkgW00<000000?oo
o`3oool0@`3oool005<0oooo0`0000000`2Y_NP000000:Vmj0070:Vmj0H0ZKcW1@2X^^H40:Rii@<0
YkSU0`2W^^L50:RojPH0[/;Y5`2Y_NP709n>`@D0X9340P2RUlT30:R>^P@0ZXjg1@2QQ[P209n;_`<0
]9Vl1P2bTkL00`2MQk/0_:2m0;bP_@020;bP_@D0/iFi1P30X;T20:>=_0<0aJJk1@2[Tkd00`38Z[/0
[9Jo0:bF_`040:bF_`H0YYC31@2UWLh:0:Vmj0030000002Y_NP0ZKgX00P0ZKgX1@2L^>/50:O1k0D0
[kkU1P2^_^D50:^mi`030000003oool0oooo0480oooo001A0?ooo`8000003P2Y_NP30:Vli`<0Z;_W
1@2X^^H40:Rii@H0Yk[W0P2X_nX30:o7k0D0[/;Y5@2Y_NP:09n>`@@0X9341@2XS[X50:Z>]`@0XHJh
1P2dVK`50;:C]`H0_:2m0`2cUKT20<:/a0D0`:2i00<0Xhfl0<FV^`35Y[/00P35Y[/40:^C_@80b:Zk
1P2/U[l00`3;[;X0YYC30:JD``030:JD``030<NY^`2UWLh0YIg>00<0YIg>2@2Y_NP00`000000ZKgX
0:Vmj0080:Vmj0H0WkW[1@2W`N`20:nni@<0[koV1@2^_^D50:^mi`030000003oool0oooo0480oooo
001>0?ooo`<000004@2Y_NP60:Rki`@0Z;[V1@2W^>D50:Nji`H0[lO/0`2^`^TB0:Vmj0D0X9342@2O
S/420:2@a0<0YXnm102XS[X50:Z>]`<0XHJh0P2dX<@50;BI_0@0/Y>g0P2m[<P50;bP_@80/iFi0`32
[<@50<2P^@H0aJJk0P2[Tkd40<RZ^`@0[9Jo0P3;[;X40:JD``80ajVk1@2UWLh90:Vmj0030000002Y
_NP0ZKgX00T0ZKgX1@2O^N/50:O1k0H0[koV0P2^_^D30:nni@D0ZkgW00<000000?ooo`3oool0@@3o
ool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo02T0oooo0P00
000@0:Vmj0D0ZKcW1@2X^nL50:Jgi@D0YkSU1P2]bNh50:o7k180ZKgX0`2RUlT40:2@a0T0Whk11@2V
Skd50:R>^P@0ZXjg0P2QQ[P30;BPa0H0]9Vl0P2bTkL30;f/b0D0_:2m00<0/iFi0<:/a032[<@00P32
[<@40<2P^@80a[K:1@35Y[/00`2[Tkd0b:Zk0<RZ^`030<RZ^`<0[9Jo103;[;X20:JD``@0ajVk0`2U
WLh20;ZT`PP0ZKgX00<000000:Vmj02Y_NP02P2Y_NP409nij`H0X;g]1@2__nH60:nni@D0ZkgW00<0
00000?ooo`3oool0@03oool001T0oooo00X0omnL04P0M02oool0oooo0?oog`1O500055o40?ooo`34
Ga@003F?9P3oool300000080ZKgX00<000000:Vmj02Y_NP02`2Y_NP80:Vli`80Z;_W0`2W^>D50:Jg
i@<0YkSU0P2Za>`60:g9kQ@0ZKgX1@2RUlT40:2@a0L0Whk10`2SS[l40:J?_@D0Z8jj102ZS[L60;BP
a0D0]9Vl1@2m[<P50;bP_@H0`Zc40P30X;T30<JfbPD0aJJk1`38Z[/00`2/U[l0bjbj0<^/^P030<^/
^P030:JD``37ZK/0ajVk00<0ajVk0P2UWLh40;ZT`PD0YIg>0P2Y_NP00`000000ZKgX0:Vmj00:0:Vm
j0D0YK_Y1P2P_Nd50:joi`D0[kkU1@2[_NL00`000000oooo0?ooo`0:0?ooo`050?oo_`1d00000000
0018W03Oool0<@3oool001T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0
500e08ooo`0R0?ooo`030:Vmj000000000000140ZKgX2P2Y_>L60:Nhi@D0Y[OU1@2Za>`30:g9kQ80
ZKgX1@2UX]840::Gb@D0X934102OS/450:>>_`D0YXnm102XS[X20:Z>]`<0/jO=1@2dX<@40;BI_080
^k[H1@2m[<P30;bP_@80`KgG1@32[<@00`30X;T0a[K:0<JfbP030<JfbP<0aJJk0P39^l`60<RZ^`H0
bjbj1P37ZK/60;ZT`P030=:c^`2UWLh0YIg>00<0YIg>0P2Y_NP00`000000ZKgX0:Vmj00:0:Vmj0D0
YK_Y1P2L]n/50:joi`D0[koU1@2[_NL00`000000oooo0?ooo`080?ooo`060?oog`2LB000B9cO0?oo
o`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`030?oo
o`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l0803oool3000001@0
ZKgX1P2Y_>L40:RjiPH0YkSU1@2W_>P50:[4k180ZKgX0`2Y]^840:FRdPD0XYO9102PT<@209n>`@<0
Whbo102SS[l50:J?_@@0Z8jj1@2cYld60;BPa080]9Vl0`2k^]P50;f/b080_:2m0`31_ML50<:/a0H0
a[K:0P35Y[/40<Vkc0@0b:Zk0P3<^lX50<^/^P030<nia@37ZK/0ajVk00<0ajVk00<0dKJo0;ZT`P2j
Y<800P2jY<820=:c^`D0YIg>0P2Y_NP00`000000ZKgX0:Vmj00;0:Vmj080YK_Y0`2Y_NP509bgj`<0
[[oW0`2/_nP50:noi@@0[;kW00<000000?ooo`3oool0203oool01`3ookl0M01d0;ooo`3oool0omnL
04P0M02oool0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?noM00055l0a?oo0?ooo`3oohl0
=@0D05o4o`0N0?ooo`<000005`2Y_NP30:Vli`<0Z;_W102X^^H30:Nhi@<0Y[SV1@2W_>P50:o4j@l0
ZKgX1@2Y]^850:FRdP@0XYO9102PT<@509n<_`D0Xhjo102VSkd20:R>^P<0/JkE1@2cYld50;BPa0H0
^k[H102m[<P60<6me`80`Zc40`2obn<50<JfbPH0bK_<0`38Z[/30<bkbP@0bjbj0P3?^LD40<NY^`80
dKJo0`2jY<840=:c^`<0YIg>0P2nZlH00`2Y_NP000000:Vmj00B0:Vmj0@0W;O[1P2/_nP30:noi@<0
[koV102/_^L00`000000oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`
0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0
oooo0`00000K0:Vmj0H0Z;_W102X^^H60:JhiP80YkcX0`2`bN`50:o4j@l0ZKgX1@2Y]^840:FRdP@0
XYO91@2KR;l409n<_`D0Xhjo102VSkd50;6^e@D0/jO=0`2dX<@30;G9j@D0^k[H0P2m[<P30;KBkPD0
`KgG1@2obn<40<JfbP80_=7Z1P39^l`00`38Z[/0c;_:0<bkbP030<bkbP80bjbj103?^LD20<NY^`@0
dKJo0P2jY<840=:c^`80YIg>102nZlH00`000000ZKGR0:VehP020:VehPl0ZKgX1@2M^>/50:boj0H0
[koV102/_^L00`3oool000000?ooo`070?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0`
0?ooo`005`3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0
=@2?ool06@3oool2000001X0ZKgX1@2Y_>L50:Rki`D0Y[SU1@2V^>H60;39k0<0[lCY4@2Y_NP40:Vf
hP@0YJ;B1@2FQ;d409^8_`D0Whbo102SS[l20:J?_@<0[[?L1@2a[]D40;>Wc@L0]LWY102k^]P60;KB
kP80`KgG0`2Sg?/50;o;h`80a[K:102ldNX50<Vkc0H0c;_:00<0bjbj0<nia@3?^LD00`3?^LD00`37
ZK/0dKJo0=6f_`030=6f_`030;ZT`P3B/k/0d[>k00<0d[>k1P2nZlH00`000000ZKGR0:VehP030:Ve
hPl0ZKgX1@2M^>/20:boj0<0Z[kX1@2__nH50:bni`030000003oool0oooo00H0oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO
05lD000eSol0oooo0<AO5000=Hl05`3oool3000001d0ZKgX1@2Y_>L50:NiiPD0Y[SU1P2[a>`50;39
k1@0ZKgX102<N[X4095n_0@0UXBm102KR;l509n<_`@0Xhjo1@2^/m`50;6^e@H0[=Kf1@2ebNT509gO
o@D0]];^1P2Sg?/40;o;h`L0_=7Z0P39^l`30;cAjPD0c;_:1P3?^LD60=6f_`H0d[>k00<0e[^o0;j[
aP2nZlH00P2nZlH00`3A]/0000000=6f`0040:VehQ00ZKgX102M^>/60:Znj0D0[koV1@2/_^L00`00
0000oooo0?ooo`050?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool0
0`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e00000000000DG`34ool0503oool3000000030:Vmj000
0000ZKgX01h0ZKgX0`2Y_>L20:Rji`D0YkWV0`2V^>D20:Nkj0H0ZlC/502Y_NP509Z8`0<0S7Zj102A
O[`409J4_@D0VhRo102OS;l50:^eh0D0[[?L0P2a[]D40:;No0D0[=Kf1P20g_/409gOo@H0LmSj102S
g?/508kJo``0_=7Z0P3<^lX30<7>i0@0ckW50P39b=T40=6f_`80dL7;103B/k/20=Jk_`<0_Z_60P3A
]/000`000000dKK00:fZe0040:fZe100ZKgX102N^>/50:Znj0H0[koV1@2/_^L00`000000oooo0?oo
o`040?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo00<0ZKgX000000000000
9@2Y_NP50:Rji`D0YkWV1@2W^nP30:_4k0<0[l?Y3`2Y_NP50:BNc`@0VXS0102<N[X4095n_0@0UXBm
102KR;l209n<_`<0Z;CQ1@2[]N040:jcg0L0X]kl1P1]f_8604O6i0H0>[_U100g^N@405;7lP@0S][o
1P23e_l50;cAjPH0`LkT0P3?^LD30<W8f@<0dKJo0`3A`L/30=:c^`@0e[^o00L0_Z_60=6f`03A]/00
dKK00000003A]/00f[fl00D0[J[D402Y_NP409jhj`D0Z;gX1@2__nH50:bni`030000003oool0oooo
00D0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`00<P3oool3000002<0ZKgX1@2X_>L50:Rj
i`D0YKSV1@2W^nP60:o3j@l0ZKgX102TW/l409Z8`0@0S7Zj102AO[`409J4_@@0VhRo1P2X]>450:^e
h0H0Vn;m0P1WfN`605cBjPH0LM;m1P2:^_D406S3oPL0M[Gi00<0>;7`04:kk`12^nl00`12^nl408?F
o`D0R=?o1@31c^@60<W8f@030=6f_`3A`L/0dL7;00<0dL7;00<0d[>k0=Jk_`3F^kl00`3F^kl40=6f
`0030000003J_K`0f[fl00@0[J[D0P30]]0?0:Vmj0D0WkW[1@2X_NP50:noiPD0[;kW00<000000?oo
o`3oool0>P3oool00300oooo0P0000000`2Y_NP000000:Vmj00T0:Vmj0D0Z;cW1@2V^>H50:FhiPH0
/L[/102_`nT?0:Vmj0@0Y9k?1@2JR<0408aj^P@0TGjl0`2FQ;d50:F_g`H0Z;CQ1P2Ii?d206_Lj`H0
K=__1P2>d?h60:2jj`<0R[[e0P2Y_NP509Zhk0<0M[Gi0`2U^nT407J[m0<0=:[a100n]_8408SCo`D0
Vm;k1@39b=T60=71b`H0e[^o00<0eL;80=6f`03A]/000P0000030=Zm_080[J[D1030]]0?0:Vmj0D0
WkW[0P2X_NP30:Nlj0D0[koV1@2/_^L00`000000oooo0?ooo`0i0?ooo`00;03oool0102Y_NP00000
00000000000Z0:Vmj0<0Z;cW0P2W^^L50:JhiP80YKSV0`2Z`>T60;7:k1<0ZKgX102TW/l409Z8`0@0
S7Zj102AO[`40:2Wf`D0YJoO0`2X]>4409cUo0@0M>7/101kh_8709c:n0D0ZKgX1@2P^^/50:Vmj0D0
V[S/1P2U^nT407J[m0@0=:[a100WXn/304Vgm`D0Vm;k0P39b=T30;?@k`@0dL7;0P38bM/40=Jk_`07
0=G2b000000000000000003A]/00f[fl000000020=Zm_0H0`;K@402Y_NP409nij`H0YkcX0P2__nH3
0:o0iP@0[;kW00<000000?ooo`3oool0>@3oool002/0oooo0P00000^0:Vmj0D0Yk[W102V^>H60:[0
j@<0/L[/5@2Y_NP40:BNc`@0VXS0102<N[X509ZLe0@0X:OK1@2U[ml409cUo0@0P>K^0`1kh_860:C8
laT0ZKgX2P2U^nT506fWl`<0;j;a0`0/X^l409_Bn`H0/m3_0P3A`L/30<S9f`80e[^o0`0000020=G2
b0040=6f`03J_K`0f[fl00000080f[fl00<0g<;00<2fd030]]000P30]]020<fnc@l0ZKgX1@2O^N/5
0:Nlj0D0[l3V1@2/_^L00`000000oooo0?ooo`0h0?ooo`00:@3oool2000002`0ZKgX1@2X^nL50:Nj
i`D0Y[WW1@2Z`>TB0:Vmj0<0Y9k?0P20M[d40:BNc`@0VXS01@2BSld409ZLe0D0X:OK1P2Qi?`2083V
kP<0R>Sc1@2Yb_430:C8lb40ZKgX1@2U^nT509^gk0<0F:Gg100/X^l306Boo@D0/m3_1038bM/30000
00D0eL;8103J_K`010000000g<;00=c2`03L`/020<2fd0<0cKk=402Y_NP409nij`H0YkcX102_`>H6
0:bni`030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool2
000002P0ZKgX1@2Y_>P50:Rki`D0YKSV1@2V^NL50;C8j@l0ZKgX1@2TW/l3081f_@@0PWRo102:P/D4
09:?c@D0VYcD0P2PYm/40:KOn`@0S>_`0`2CkO<30:k@lPD0ZL[a:@2Y_NP509^gk0@0F:Gg0`0/W?03
03jWmPD0SLSl00<0b<WK0000000000000P38bM/50=G2b080d<KA0`3J_K`0103L`/0000000=c2`03L
`/050<fnc@030=G5b`2Y_NP0ZKgX00d0ZKgX1@2O^N/50:Nlj0D0[l3V1@2/_^L00`000000oooo0?oo
o`0g0?ooo`00703oool01P3ooml0W4P004RLg`3oool0gia8001d_`L0oooo00<000000?ooo`000000
:02Y_NP50:Vlj080Z;_W0`2V^NL50:FhiP80Y[WW0`2]a>X50;C8j@l0ZKgX102TW/l3081f_@@0PWRo
102:P/D509:?c@@0VYcD102Vgo/409W_lP<0Tngc1P2^d?8^0:Vmj080VkO/0`2Y_NP4086/l0<0>Igc
0`0nYoH208g8o0<000000P38bM/30;K;jP<0eL;80`3@a]430=Zm_080g<;000<000000=c2`03La/<0
0`3=_/d30=G5b`l0ZKgX1@2O^N/40:Nlj0H0[l3V1@2/_nL00`000000oooo0?ooo`0f0?ooo`00703o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y
_NP09P2Y_NP40:Vlj0H0Y[WW102U^>H60:g4jP<0]<SY402Y_NP50:BNc`<0P7Jm1022N;l408Z2a@@0
TXo=1P2XeOL309W_lP@0WO3c0`2cfo@30:k@lSH0ZKgX1021[?0403VMl`<000000`2=b?`60;K;jP03
0=G2b03@a]40d<KA00<0d<KA00D0f[fl0=c2`03L`/00g<;0000000020=c6``<0cKk=0`3EaL/@0:Vm
j0@0WkW[1@2X_>L60:o0iPD0[;oW00<000000?ooo`3oool0=@3oool001`0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool00P3oool00`000000ZKgX0:Vmj00V
0:Vmj0D0Z;_W1@2V^NL50:Jji`D0[LCZ4`2Y_NP40:BNc`<0P7Jm1022N;l408Z2a@80TXo=0`2Ua?03
0:SEm`<0Y?3e102Vlo860;?Km3P0ZKgX1@2P^N/30000000405BMm00dU_40=9Ka03BFl@<0IkKl1@2f
bnX60=36d@@0g<;000D0g<K30000003La/<0g<K30<fnc@030=G5b`80f/_;3`2Y_NP509nij`D0Z;cW
1P2_`>H40:boi`030000003oool0oooo03D0oooo000L0?ooo`070?noM000B9`0gooo0?ooo`3ookl0
M01809cOo`050?ooo`030000003oool0oooo00<0oooo902Y_NP50:Vlj0D0Z;_W1@2U^>H50:Jji`D0
/<GY4P2Y_NP40:BNc`@0P7Jm0`22N;l408Z2a@H0YLC`0`2Tl?D40:KclP@0]NWg?@2Y_NP01@2P^N/0
0000000000000000X;W[00@0E9gd0`0dU_4304nVn0D0W/Gd0`3@a]430<S8fP<0g<;00P3La/<00`00
0000g<K30=G5b`020=G5b`@0f/_;3`2Y_NP509nij`D0Z[cW1@2_`>H50:boj0030000003oool0oooo
03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`8000001@3oool0
0`000000ZKgX0:Vmj00Q0:Vmj0D0ZKcX0P2X^nL30:Jii`D0YKSV0P2V^^L30;36jPD0/<GY2P2Y_NP5
0:VfhP<0OW_50`1fL/44081f_@@0SiOG102L[n@30:G4l0<0[Nkh102_mO420;GYmcl0ZKgX0`000005
0:Vmj0@0LZC`0`0mUO4304nVn0D0W/Gd1P38b=X00`3L`/00g<K30=c6``020=c6``030000003Kb<L0
eLG;00D0f/_;00<0g=3=0:Vmj02Y_NP03@2Y_NP509jhj`D0Z[cW0P2_`>H30:o1i`D0[;oX00<00000
0?ooo`3oool0<`3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000ZKgX0:Vmj00Q0:Vmj0@0ZKcX1P2V^NL40:FhiPH0/<KZ3`2Y
_NP40:VfhP<0OW_5101fL/4408:2bP@0SiOG102L[n@30:g^n0@0[oGa0`2fl_@20;?8jS/0ZKgX0`00
00090:Vmj0@0LZC`0`0mUO4304FKm0D0R;_g1@38b=X50=c6``030000003Kb<L0f/_;00@0f/_;0`3L
d<d?0:Vmj0D0W[S[102Z_>L60:o1i`@0ZkoX00<000000?ooo`3oool0<`3oool001`0oooo00H0oooO
09a8001d_ol0oooo0=nLB000M;l60?ooo`030000003oool0oooo00L0oooo8`2Y_NP50:Nki`@0Y[WW
1P2W^nL30;36jP80[/;Y3`2Y_NP40:VfhP80OW_5101fL/4408:2bPD0SiOG0P2L[n@30;3Sn0<0]oCb
0`2fl_@50;?8jSL0ZKgX0`00000=0:Vmj0@0R:o_0`16UO4304FKm0D0R;_g0P38b=X30;o7h0<0g<K3
0P3Kb<L00`000000fl_90=[;b`020=[;b`@0g=3=402Y_NP409jhj`D0[;gW1P2_`NL40:^oj0030000
003oool0oooo0380oooo000M0?ooo`050?oo_`1d000000000018W03Oool01P3oool00`000000oooo
0?ooo`080?oooah0ZKgX1@2Y_>P50:Nki`@0Y;SW1P2W^nL50:k2j@h0ZKgX102Y]^8307ika@@0MW;1
1022P/X408nGe`@0/>?h0P2gm?830;cdl@<0`N7_1@2cb>Xd0:Vmj0800000402Y_NP408R_k`@0AYGa
0`14UO4408Rkm`H0_lOP00P0g<K30=_8a`3Kb<L0flS70=_;b@000000fl_90=[;b`@0g=3=0P3Le]4?
0:Vmj0D0WKS[102/_NL60:o1i`@0ZkoX00<000000?ooo`3oool0<P3oool002L0oooo00<000000?oo
o`3oool02P3ooolN0:Vmj0D0ZKcX1@2U^NL40:Bhi`<0Yk_W0`2ba^T50:k2j@X0ZKgX102OZ=`306IX
`0<0OW_5101fL/4408:2bPH0Zloc0P2gm?830;cdl@H0`N7_=@2Y_NP300000180ZKgX1@2E]Nd404nE
l0<0A9Ga101i/?H50;o7h0@0flS700<0fl_90000003KblT0103Ld<d40=cFd@l0ZKgX102M^>/20:bm
i`<0[KoW1@2_`NL50:^nj0030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0
oooo7P2Y_NP30:Vlj080Yk_X1@2U^NL40:Bhi`H0//KY3`2Y_NP309nXg0@0IVS00P1cMlP407Ib`@D0
W;7V0`2[co<30;__m0<0`_G_0P35l>l30<7Qkc@0ZKgX0`00000F0:Vmj0D0UKG]101?UO0304RAk`@0
NK3f0P2oan030;S4i080flS70`3KblT010000000gLg90=c@c@3Ld<d40=cFd@80fMgJ3P2Y_NP409fh
j`H0[KoW1@2^`NL50:^nj0030000003oool0oooo0300oooo000W0?ooo`030000003oool0oooo00`0
oooo7P2Y_NP50:Nkj0@0YKWW1@2W^nL30;;6j@<0[/;Y3`2Y_NP209nXg0@0IVS00`1cMlP408NAePD0
W;7V102kko@30<;ek`@0aO3_<`2Y_NP3000001X0ZKgX102E]Nd404nEl0@0B97_0`1aZ?<60;S4i0@0
fl_900<0gLg90000003McLT0103Le]430=WMfPl0ZKgX102L/nP30:foi`<0[l3W1@2^`NL40:^nj003
0000003oool0oooo0300oooo000W0?ooo`8000003P3ooolI0:Vmj0D0ZKcX1@2W^nP50:Bhi`@0Yk_W
1P2^`^T>0:Vmj0<0WjSL0`1VJ<0407=gb0@0Qi7F0P2L/NH50;WQm080`_G_0P35l>l50;S=jRl0ZKgX
0`00000N0:Vmj0@0VkO/0`1EU>h504RAk`<0LJSc0`2ha>@30;?2i@80fl_90`3McLT010000000gm79
0=cFd@3Le]440=WMfQ00ZKgX102L/nP60:o0i`80[/7W0`2]`>P40:^nj0030000003oool0oooo02l0
oooo000W0?ooo`030000003oool0oooo00h0oooo6@2Y_NP50:Vlj0D0Y[[W1@2T^>L50;;5j0D0[/;Y
2@2Y_NP5092Qh00305eU``2OZ=`0IVS000<0IVS0101cMlP308NAePD0^N7d0`35lNl20<[ak0<0b^_/
102hcNX[0:Vmj0<000008P2Y_NP409^gk0<0EIC^101=Snd4076Xl`D0/l;U00<0fl_90=g=b@3McLT0
0P3McLT00`000000gm790=oAb@040=WMfP80cNCX3`2Y_NP50:6eiPD0[l3W1@2]`>P30:^nj080Z[kX
00<000000?ooo`3oool0;P3oool002L0oooo00<000000?ooo`3oool03`3ooolI0:Vmj0<0ZKcX0P2X
_>P50:Jji`80Y;SW0`2W^^L50;;5j0h0ZKgX102@XN0205eU``@0IVS0101cMlP60:W5k@@0aO7_0P3:
lN`50<[[k2/0ZKgX0`00000U0:Vmj0D0VkO/0`1JT^`404f?k@@0L:?`102c`^D40=g=b@80gm7900<0
00000=oAb@3TeLP00P3IgMX40<gTj0X0ZKgX1@2U^nT50:6eiPD0[l7W102]`>P50:Znj0030000003o
ool0oooo02h0oooo000W0?ooo`8000004@3oool00`000000ZKgX0:Vmj00F0:Vmj0D0Z;cX102V^^L6
0:Nji`80//GX0`2`aNT>0:Vmj0<0T:7P0`1MIL<3079kc@D0SioN0`2YaNd40<?Wl0<0b_7/103:jn`3
0:k3jBL0ZKgX0`00000Y0:Vmj0D0VkO/0`1JT^`305>>j`@0L:?`1@2c`>@20=g=b@@0gm7900<00000
0>CEb03TeLP00`3=i>P30;;9j`X0ZKgX1@2U^nT20:6eiP<0Yk[V102_`NL50:c0j0D0Z[kX00<00000
0?ooo`3oool0;@3oool002H0oooo0P00000C0?ooo`030000002Y_NP0ZKgX01H0ZKgX1@2X_>P50:Bh
i`@0Yk[W1P2`aNT>0:Vmj0<0T:7P0`1MIL<3079kc@D0SioN1033io040<g_j`<0cngY1P2^`nTS0:Vm
j0<00000;@2Y_NP409^gk0@0FY;/0`1CS^/407>Pk@D0/l3T103OdLT20>CEb0030000003TeLP0jM_6
00H0//W[2P2Y_NP40:Fkj@D0Yk[V0P2_`NL30:o2j0D0[<3X1@2Z_^P00`000000oooo0?ooo`0/0?oo
o`002@3oool02P3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3OW4P50000000307Bo
o`3oool0gia80080000000<0001809cOo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000
002Y_NP0ZKgX01H0ZKgX1@2V^^P50:Bhi`D0/<;W102`aNT;0:Vmj0@0SZ_Z00<0DF74092Qh01MIL<0
0P1MIL<4079kc@80SioN102dc^d50<g_j`<0cngY0P3=i^P50:k3jB40ZKgX0P00000a0:Vmj0@0UKG]
0`1NT>T405>>j`@0Lj3]0P2c`>@30;O1hP80gm790`3TeLP010000000jM_60>WKaP3^hl@50;;9j`X0
ZKgX1@2O^N/40:NjiPH0[l;X0P2/`>P30:boj0@0Z[kX00<000000?ooo`3oool02P3oool01@3OW4P0
00000000000004P0W=oo01d0oooo00080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool0
0`3ogi`0B00007Boo`040?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000
003oool0oooo01@0oooo00<000000:Vmj02Y_NP04P2Y_NP40:Rlj0D0Y[[X1@2U^NL50;32i`l0ZKgX
0`2>ZnX2055Qa0@0GFG30`1bNld50;C>k@@0bNK[103?kNT40<gVj280ZKgX0`00000d0:Vmj0@0UKG]
0`1NT>T305Z=j0@0Lj3]1P2g`N840>CEb0030>WKaP000000k^?40080k^?43`2Y_NP409nij`D0[;kW
1@2_`^P60:boj080Z[kX0P2Z_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0gooo0?ooo`3o
oml0W4Qd0;ooo`0L0?ooo`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0103oool0
0`3ogi`0B00007Boo`080?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?oooaD0ZKgX102X_>P3
0:Jjj080Y;WX1@2U^NL20;32i`<0]<SY3P2Y_NP408j[jP80DF740`1^O=4509BWhP80]<k]1039i^/3
0=7[i`D0cNKX0P2^`nTN0:Vmj0<00000=`2Y_NP409Fek@@0GY3Y0`1JSNP407ZPj`@0]l7R0P2na=l2
0>CEb0<0jM_600@000000>kSa03^hl@0jNo?3P2Y_NP509fci`D0[;kW1@2^`^P50:boj0D0Z[gX00<0
00000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol01@3oool00`3ookl0M00004RLg`070?ooo`030;md001d_ol0oooo00D0oooo
00<000000?ooo`3oool05`3ooolD0:Vmj0@0Z;cX1@2T^NP40:Fii`H0]<SY2P2Y_NP409njk003049J
a02>ZnX0SZ_Z0080DF74101^O=4509BWhP@0bNK[0`3AjnL40=;Wi@D0[/?Y6P2Y_NP3000003/0ZKgX
1028[nl306:>iP@0FXgX101jX>/20;O1hP@0_/CO0`3YflH00`3^hl@000000>kSa0030>W_c`h0ZKgX
1@2M/nL20:bni`<0[l7W1@2^`^P50:^nj0@0Z[gX00<000000?ooo`3oool0303oool00`2oM000M;oo
0?ooo`0K0?ooo`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01P3oool02`3ooml0
W4P004RLg`3oool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0
603ooolC0:Vmj0D0Y[_X1@2T^NP50:bni`<0]<SY302Y_NP309njk0<0@U[40`1AHL@406ild@80U:OR
102icn/40=7[i`@0d^OU0P3@hN@40:k3jAL0ZKgX0`00000o0:Vmj0@0R:o_0`1RS^H306:=i@@0NZ3[
1@2na=l20<W;f`80jM_60P3^hl@010000000jNo?0>W_c`3Ykll?0:Vmj0@0WK?W1P2_`NL50:g1j0@0
ZkkX1@2Y_NP00`000000oooo0?ooo`060?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0L
0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool01@3ookl0M01809cO
o`3ookl0M00000<0000000<0M;oo0?ooo`3oool0103oool2000001/0oooo3P2Y_NP50:Rlj0D0Y[_X
1@2T^NP50:bni`l0ZKgX0`2O^^`3049Ja080IGSA101^O=450;W?j`<0cN7W1@3BinD40=3Qi1L0ZKgX
0`0000130:Vmj0<0N9kZ101RS^H306:=i@@0Q:?X0`2na=l40<W;f`80k^?40P3Ykll010000000jNo?
0=3fi`3@m^L>0:Vmj0D0X[CU0`2_`NL30:o2j0@0[L7X1@2Z_^P50:Vmj0030000003oool0oooo00D0
oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0K0?ooo`00203oool01`3ookl0M01d
0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md001d_ol0oooO
09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?ooo`l0ZKgX102X_>P50:Bjj0D0Y;WX1@2fa^H?
0:Vmj00303iVdP2O^^`0@U[40080@U[40`1UN=4409BWhP<0^Lo[0`3=hNL40=CUh`@0d>7T0`2hcNXC
0:Vmj0<00000A`2Y_NP307RNjP<0IX_R101RSND408BSj0D0bL_K0P3Ee=L40>W_c`030000003@m^L0
d?KW00X0ZKgX1@2T^nT50::di@D0[l;X0P2]`NP30:boj0D0Z[kX102Y_NP00`000000oooo0?ooo`05
0?ooo`030?oog`2LB4P0W=oo0200oooo00080?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo103o
ool02P3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooo0;md001d_ol90?ooo`030000003oool0
oooo01`0oooo3`2Y_NP40:Nlj0D0Y;[X0P2T^NP30:Rki`D0]/KV3P2Y_NP203iVdP@0@U[40P1UN=45
09BWhP@0cN7W103DiN<30=GRh@H0^<gZ3`2Y_NP3000004X0ZKgX101hW^X306J;hP@0JhoS102@Z>H3
0<W;f`<0eMCG0P3Rgm820=3fi`030000002Y_NP0ZKgX00/0ZKgX1@2T^nT50:Zli`@0[l;X1P2/_nP2
0:Znj0<0Z[gX102Y_NP00`000000oooo0?ooo`050?ooo`030;md001d_ol0oooo01l0oooo00090?oo
o`050?oo_`1d000000000018W03Oool01@3oool01@3ogi`0B000000000000000M;oo0080oooo00H0
gia800000000000000000000M02oool50?ooo`030000003oool0oooo01d0oooo3`2Y_NP40:Nlj0@0
Y;[X1P2X^nL50:o3j@h0ZKgX0P0nI]800`1CK<l0@U[4049Ja00306Ehd@80U:OR1@2hb^P40=CUh`<0
eN;Q0P3CgN030;S=jPl0ZKgX0P0000190:Vmj0D0X;W[0`1aSn0406J;hP@0JhoS102@Z>H40=GDe`<0
h]oB0P3/k</00`3]m/D000000:Vmj00<0:Vmj0D0W[?W102Z_>L50:k2j0D0[;oX1@2Z_NP40:Vmj003
0000003oool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool20000
01l0oooo3`2Y_NP40:Nlj0D0XkWX0`2X^nL20;70i@D0[l?Y3@2Y_NP303iVdP80Dfc?0`1UN=460;S:
j0<0c=[T103Eh^440=?Mh0h0ZKgX0`00001<0:Vmj0D0X;W[0`1aSn0306Z:g`@0JhoS1@2Q/^@20=GD
e`<0h]oB0P3/k</20>gfa@030:Vmj0000000ZKgX00`0ZKgX102N/nL20:Zli`<0[/7X1@2^`^P50:^n
j0@0Z[gX1@2Y_NP00`000000oooo0?ooo`0V0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`h0
ZKgX1@2V^nP50:>ij0D0/L3U0`2_`nT<0:Vmj080GYkb0`0nI]8305=/c`@0S9oQ0`2hb^P30<cJi0<0
e=kO1@3CgN030<SHiPT0ZKgX0`00001@0:Vmj0@0X;W[101aSn0306Z:g`@0MY?Q1@2Q/^@30>;OdP80
k>c;0`3]m/D00`2Y_NP000000:Vmj00<0:Vmj0@0W[?W1P2^`NP20:k2j0<0[L7X102[_^P:0:Vmj003
0000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo0200oooo2P2Y_NP50:Rlj0@0Y[_X
1@2T^NP50;70i@l0ZKgX0P1NW_800`0dF/X0?VKB03iVdP0305=/c`@0S9oQ103<f^@30=CNg`@0e]cL
1P38f>H50:Vmj0<00000E02Y_NP408NRiP<0LX_L101ZR]l407JCh@80XK;T0`2d`><00`3Rgm80k>c;
0>c/b`030>gfa@80d?KW00<0ZKgX0000002Y_NP02`2Y_NP50::di@D0[/7X1@2]`NP50:Znj0T0ZKgX
00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?ooo`X0ZKgX1@2X_>P40:Bjj@D0Y;WX1@2e
aNH?0:Vmj00405jNlP0dF/X0=5[:03AJbP<0Dfc?1P2``>D40=CNg`@0e]cL0`3EfM/50;?8jP040:Vm
j00000000000000005P0ZKgX0`27X^H407:;g0<0LH_M101fTn450;C0h`80k>c;0`3]m/D40=3fi`03
0:Vmj0000000ZKgX00H0ZKgX1@2T^nT50::di@D0[l?X0`2]`NP20:boj0D0Z[kX2@2Y_NP00`000000
oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`0S0?ooo`X0ZKgX1@2W_>P40:Bjj@<0Y;WX
0`2Y^nL40;G5iPh0ZKgX00<04D[605jNlP0dF/X00P0dF/X307R?g@@0/<3U1036d>840=KLg0<0eMWK
0P3Be=X20;?8jP<00000F`2Y_NP308NRiP@0LX_L101aRmd408FKh@80]<3S0`3;dn020>3Xf@80d?KW
1P2Y_NP00`000000ZKgX0:Vmj0050:Vmj0D0Y;_Y1@2[_NL50:o3j0D0[;oX0P2Z_^P30:Zmj0T0ZKgX
00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0903oool:0:Vmj0D0YkcX102T
^^T60:Vki`D0[lCY3@2Y_NP00`0AB/H0=5[:03AJbP0203AJbP<0N8oM0P2``>D40<K@hP<0dMKM103E
fM/20=;DfP<00000FP2Y_NP509^cj080NhkJ101bRm`4076;g@@0QI_Q103;dn030>3Xf@80j_S900<0
f?k10:Vmj02Y_NP00`2Y_NP00`000000ZKgX0:Vmj0060:Vmj0D0W[3T1@2[_NL50:k2j@@0[;oX1P2Z
_NP80:Vmj0030000003oool0oooo02<0oooo000T0?ooo`8000009P3oool:0:Vmj0@0YkcX1@2S^NT3
0:Vki`<0/KoU1@2_a>T<0:Vmj0804D[60`1CM]P307R?g@D0a]3R0`3Ae]d20=CFf@80eMWK0`000000
0`3Be=X0c=3M0<c@g@1K0:Vmj0@0Vk?X0`1kS]X407F9f@<0NhoL1@2HZN820<_Ch0<0h>SI0P3Zn<T3
0=Sn`@D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP509j`i080ZkgW1`2^`^T50:^nj0D0Z[gX2@2Y_NP0
0`000000oooo0?ooo`0R0?ooo`008`3oool2000002P0oooo2P2Y_NP50:Fkj@@0XkWY1P2a_nD>0:Vm
j080GIkc0`0AB/H305=ff0D0W[3T103Ae]d30=CFf@8000000`3Be=X40<c@gE/0ZKgX0`2K/nP407^>
fP<0MHWI101kSm`509RYhP<0h>SI0P3Zn<T40=Sn`@H0ZKgX00<000000:Vmj02Y_NP01P2Y_NP409j`
i0D0[/;Y1@2/`NP50:^nj0h0ZKgX00<000000?ooo`3oool08@3oool000d0oooo00/0oono07@00000
000004RL0=ooo`3oool0omnL04P0M02oool0oooo0=nLB002000000030000B02Lgol0oooo00L0oooo
00<000000?ooo`3oool0:03oool40:Vmj0D0Z;cX1@2U^nT50:Bij0<0/KoU0P2f`^@>0:Vmj080GIkc
00<0653:015:aP0AB/H00`1CM]P209j`i0<0^L?R0P3Ae]d0103De]T000000000000000030=GCe`H0
c=3ME`2Y_NP50:FgiP80PhoG101kS]X407F9f@@0NhoL0P2HZN840;;1i@80j_S900<0f?k10;?:j`2c
b^/00`2cb^/60:Vmj0030000002Y_NP0ZKgX00D0ZKgX1@2W^NH20:k2j@<0[/?Y1@2/`NP50:Znj0d0
ZKgX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo1@2Y
_NP40:Rlj0D0Y;[Y1@2T^NP50;K2i0h0ZKgX00@0057=05fNl`0HD<X0653:0`1CM]P50;W3hP<00000
0P3De]T40=GCe`80e<oE0`3<d=d20<;;hEL0ZKgX102U]nH308>?e`@0O8[F0`1kRmP407^?g0D0//7U
0P3@h>@20>;jd`030=Wl]02cb^/0/l[[0080/l[[1P2Y_NP010000000ZKgX0:Vmj02Y_NP50:2ciP@0
YkWV1P2^`nT20:c1j0<0ZkoX102Z_^P>0:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0
oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002`0oooo1@2Y_NP50:Nl
j0@0Y;[Y1@2W^nP40;K2i0l0ZKgX0P00DLd201Q@bP<0NYKR00@0^L?R00000000000000000`37c=d5
0=GCe`@0e<oE1@32bn5G0:Vmj0<0YKOV1023SmL307b:eP@0Nh_H102:Vmh30;;1i@<0d>3T00@0h_[C
0=Wl]03Io;@0fObd2P2Y_NP010000000ZKgX0:Vmj02Y_NP40:2ciPD0[L7X1@2^`nT50:^oj080Z[kX
4@2Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02L
gol0203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02`0oooo1@2Y_NP50:Nlj0@0
Xk[Y1@2W^nP50;?4i`d0ZKgX0`00DLd00`0dJMP0653:00000002000000D0alcM0`3>cMT20=GCe`@0
e<oE0P3Bc=<30<;;h@<0^/GSE@2Y_NP30:FgiP@0PhoG101lR]H407^;f0@0RY_N103@h>@00`3Rn]<0
fObd0=Wl]0030<3MkPX0ZKgX00@000000:Vmj02Y_NP0ZKgX102S]ND50:g1j0D0[L7Y102[_nPC0:Vm
j0030000003oool0oooo01l0oooo000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`03
0?ooo`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02d0oooo
1@2Y_NP50:Jlj@@0Xk[Y0P2W^nP30:bmiPD0/lCW2@2Y_NP409njk004000^]`0000000000000000D0
VjoU0P37c=d50<k=f@@0e<oE103Bc=<60;[5he00ZKgX1@2U/>0308V@e0@0PX_C0`1oR]@407^;f0D0
X[;T0P3@h>@00`3Rn]<0fObd0<3MkP040<3MkPX0ZKgX00<000000:>fiP2S]^H00P2S]^H40:>ei@D0
[/?Y102]`NT50:Znj1<0ZKgX00<000000?ooo`3oool07P3oool000`0oooo00L0omnL04Q8W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`050?oo
o`030000003oool0oooo02h0oooo1@2Y_NP50:Jlj@<0Xk[Y1P2/_NH50:k2j@T0ZKgX00H0Wk[/0000
000000000000000^]`00DLd203AYf0D0VjoU1@3>cMT20=7<e@80e<oE103Bc=<20=38dP<0^/GS0`2f
`N9@0:Vmj0@0YK3P0`29T=@408:;d`@0Oh[D1026U=X50::bi0040>;jd`3IoMT0fOgI0<KgZP<0`=g^
302Y_NP010000000XkKV0:>fiP2S]^H20:>ei@<0[<3X102^`nT50:^oj0D0Z[kX4`2Y_NP00`000000
oooo0?ooo`0M0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o
oml0W4Q809cOo`090?ooo`800000<@3oool50:Vmj0@0Y[cY1@2S^^T30:bmiP<0/[oT102^`^T60:Vm
j0<00000102O^^`01000;[L0=6WH03AYf00dJMP209^_i@<0/KgR0`3>cMT40=7<e@@0d/cC103@b=86
0;K1hU00ZKgX0`2U/>0408V@e0@0PX_C0`1oR]@508JDfP80X[;T0P33fNX20=Wmf@<0a_NZ3P2Y_NP0
102S]^H000000:>fiP2S]^H60:c0j0@0[L;Y1@2[_nP50:Zmj180ZKgX00<000000?ooo`3oool07@3o
ool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`030;md001d_ol0oooo00P0oooo
00<000000?ooo`3oool0<@3oool50:Vmj0@0YK_Y1@2S^^T60;:oi0L0ZKgX0P0000050:Vmj0<0KjOc
00<002jg05J6i01FQ^@01P2a_N850=7<e@<0d/[B1@3@b=820<o4d0D0]/7RD02Y_NP30:F`h0@0RI3D
1022Rm<407n:e0@0QYCJ0`33fNX20=Wmf@80a_NZ0`30gNh=0:Vmj080X[;T00<000000::bi02R/^@0
0`2/`>P30:k4jP@0[L;Y1@2Z_^P40:Zmj1<0ZKgX00<000000?ooo`3oool0703oool000d0oooo00D0
oono07@00000000004RL0=ooo`050?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`00
0000oooo0?ooo`0b0?ooo`D0Z;gX102U^nT50:>jj@<0/[oT0`2f`N830:Vmj0<00000202Y_NP306nW
l`03000^]`1FQ^@0EXKT00<0/KgR0`2m`mh30=7<e@@0d/[B00@0dLO@0=38dP3@b=80d<SB103?a=05
0;FlgdL0ZKgX1@2Y]N4409fOeP<0SHo@1028S=0408F;dP<0R9;G1P2KZn820=Wmf@030<KgZP30gNh0
`=g^00<0`=g^2@2Y_NP50:FgiP030::bi0000000X[;T0080X[;T1@2^a>X20:g2j@<0ZkoX102Z_^PH
0:Vmj0030000003oool0oooo01/0oooo000R0?ooo`800000=03oool50:Rmj0D0Y;_Y102S^^T50;K1
hP<00000302Y_NP203F8k004000f_01FQ^@0EXKT05J6i0H0_L?N1@3Bb]830=77d0H0clC@00<0cL3>
0;Flg`2e_=l00`2e_=m70:Vmj0@0ZKGQ102MWmH308f?d0@0R8c@1025Rm8408RBe`<0Vj_R0`2lf>h0
0`3<omH0Z^VG0:[YU`0>0:Vmj0D0YKOV00<0Zl3Y0000002[`>T00P2[`>T40:k4jPH0ZkoX102Z_NPG
0:Vmj0030000003oool0oooo01/0oooo000R0?ooo`030000003oool0oooo03@0oooo1@2X_>P50:Bk
j@@0YK_Y00D0]/7R00000000000000000;K1hP0?0:Vmj080=HS/00@003Jl07BLjP1dW>X0M9cZ102m
`mh30<C5fP80d/[B103Aam000`3@a<l0clC@0<o4d0020<o4d0<0cL3>0P2e_=l30;RifdL0ZKgX102Y
]N4409fOeP<0SHo@1028S=0408F;dP@0R9;G102lf>h00`3<omH0Z^VG0:[YU`020;?:j`h0ZKgX1@2R
/^@0102[`>T000000:_0j@2[`>T50:g2j@<0ZkoX0`2Z_^P40:Zmj1L0ZKgX00<000000?ooo`3oool0
6P3oool00280oooo00<000000?ooo`3oool0=@3oool00`000000Z;cX0:Rlj0020:Rlj0D0Xk_Z00@0
YK_Y00000000000000001@2e`N<>0:Vmj0<0=HS/00@003Jl07BLjP1dW>X0M9cZ0P2m`mh50<C5fP@0
dLO@0`3@a<l20<o4d0@0cL3>1P2h^M]60:Vmj0@0ZKGQ102MWmH308f?d0@0R8c@1025Rm8509^[hP80
_=S^00<0c?oF0:[YU`2cb^/0102cb^/90:Vmj0D0YKKT1@2R/^@0102^a>X000000:k4jP2^a>X50:g2
j@D0Z[kX0P2Z_NPI0:Vmj0030000003oool0oooo00`0oooo00<0omnL04P0M02oool00P3oool01@3o
okl0M00000000000B9`0gooo00@0oooo000R0?ooo`030000003oool0oooo03L0oooo1@2W_>P0102S
^nX000000000000000040:Nlj0D0]L7S3P2Y_NP200I[g0030011``1dW>X0M9cZ0080M9cZ1@34aMX2
0<O5e`80dLO@1@3@a<l40<g0cP80c;g<0`2h^M/30;bge440ZKgX1@2PW=0409JAc@@0THk=0`2=S<h4
08Z=d0@0S9CF1@2KZn80103<omH0/oS00;gg/@2mmk4>0:Vmj0D0YKKT1@2/`NT010000000[/CZ0:k4
jP2^a>X50:^oj@@0Z[kX702Y_NP2000000`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007Bo103oool00240oooo0P00000j0?ooo`80YkcX0`0000040:>kjP@0YkcX0`2e`N<2
0;C1h`h0ZKgX0P06Jm`00`00B/P0RJc/08V/k00208V/k0<0a<GJ1037aML50=34c`80cl7=0P3=`<h4
0<bmc0H0_;OD1@2Y]N8h0:Vmj0@0YjOF102PW=0409JAc@@0THk=0`2=S<h408Z=d0D0S9CF0P2KZn82
0;_PlP030;?h`02mmk40_ONa0100ZKgX1@2S]ND40:c1j@030:g2j@000000[L;Y0080[L;Y102[_nT5
0:Zmj1`0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0oono07@0M02oool0
oooo0?oOW01807@0_ooo00<0oooo000Q0?ooo`030000003oool0oooo03P0oooo0`0000040:Nlj0@0
Xk_Z102W_>P50;C1h`h0ZKgX00<005[A00I[g000B/P01029[>`50<O5e`80b<CF0`3@a<l40<o1c@D0
c;g<00<0b[[;0;bge02l]m@00P2l]m@20<:ecPD0ZKGR<`2Y_NP50:R^f`<0YjOF1@2PW=0409JAc@<0
THk=102=S<h408Z=d0@0S9CF0`2kh?820;gg/@h0ZKgX1@2S/^<40:>ei@80[<7Y0`2^a>X00`2]`^T0
00000:g2j@020:g2j@@0Z[kX1@2Z_NPK0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02o
ool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?oo
o`0f0?ooo`8000000P3oool60:Nlj0<0Xk_Z1@2Y_NP30;C1h`<0/l3S3@2Y_NP00`00F]4004[8001:
b00409Jdk0<0alGG1038a=H50<o1c@80cKk<0`3<_L`30<Zjb`80_;OD1032]Lh20:VehP<0[jgF;P2Y
_NP50:VagP@0Z:kK102WYmH40:2Ld0@0UY7=0`2AS/d408f<cP@0RXg@1P2O/nH01022ehh0d?KW0=3f
i`3@m^L>0:Vmj0D0Xk;S0`2S]ND60:k4jP030000002[_nP0ZkoX0080ZkoX102Z_^PP0:Vmj0030000
003oool0oooo00T0oooo00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cO
o`030?ooo`008@3oool2000003@0oooo0`0000050?ooo`D0YkcX1@2R^nX40:Vmj0H0/l3S3@2Y_NP0
0`00F]4004c6001:b00409Jdk0D0b<CF0P38`mD30<o1c@@0cKk<00<0c;g<0<Zjb`3:^//00P3:^//6
0<:ecPH0[jgF102Y/MhX0:Vmj0L0ZK7N0`2X[]/40:NWePD0V939102DS//3096>c0@0T97@102BV]P3
09nciP030;[cl`3@m^L0d?KW00<0d?KW3`2Y_NP40:>bh`@0[<;Z0`2^a>X30:c2j@040000002[_nP0
ZkoX0:^oj0D0Z[gX802Y_NP00`000000oooo0?ooo`080?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0<03oool30000
00T0oooo1@2W_>T50::kjP@0ZkgW0`2c`><30;>oh`d0ZKgX00<005[A001<aP00C<H0102L^^d30<S4
eP@0b<?E00<0cl7=0<fnc03=_/`00`3=_/`40<Zjb`80bKO91032]Lh20<Fcb@@0[jgF0P2k[/d40:Va
gPD0ZKWT802Y_NP90:VagP@0WiC9102KT/T409R@b@@0U8k;0`2AS/`5092Ad0@0TY[H0P2jlo<30000
0180ZKgX1@2V^NL40:c2jPD0[<;Y00<0Z[kX0000002Z_^P00P2Z_^P40:Zmj200ZKgX00<000000?oo
o`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0
M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo
0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo
02d0oooo0`00000>0?ooo`@0YkcY1@2R^n/40:^mi`H0/koS3P2Y_NP00`00F]4004c609bjk@0309bj
k@H0b<?E1@3=_/`20<blc080b[[;1039]lT20<:ecP@0aK?90P2_[MH40;^^c@80ZK7N0P2`Ym090:Vi
i1L0ZKgX1@2X[]/40:VagPD0XYK80`2OU<T409^Bb@D0V9390`2DS//4096>c0@0T97@1@2Xao0B0:Vm
j0D0XJoR102V^NL50:g4jP<0[<;Y0P2[_nP00`2Z_^P000000:Znj0020:Znj2@0ZKgX00<000000?oo
o`3oool01P3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0
oooo00030?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?oo
o`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00
000B0?ooo`@0YkcY1@2R^n/40:bni`H0/koS3P2Y_NP00`06Jm`004>j09^ml00309^ml0<0b<?E0`36
`]H30<fnc0@0c;c<1P39]lT50<Fcb@H0^jk=1@2`Ym020:Vii0<0ZJ?@102Y^N@50:VagP@0ZKgX1@2Y
]N440:Vmj0D0YjOF1@2X[]/40:BGa`@0XYK8102OU<T409^Bb@@0V9390`2DS//4096>c0D0VjWP0`2X
ao020=3fi`d0ZKgX1@2Y^>@40:6_hPD0[LC[1@2]a>X50:^oj0030000002Y_NP0ZKgX0240ZKgX0`00
00000`3oool000000?ooo`080?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL
0=ooo`040?ooo`000`3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`2oM000
B9cO0?ooo`070?ooo`030;md001d_ol0oooo00@0oooo0P00000Y0?ooo`<000005P3oool40:Nlj@D0
X[_[102/_^L60;>oh`h0ZKgX0P0eR>`409^ml0H0a/;F1@3<_<`20<Zkc@@0bKO90P38]/P30<Fcb@80
a;77102k[/d20<2]a`@0/:O@1P2YXm020:Vii080ZJ3=1@2Y/Mh40:NTd`D0ZKGQ102VWlh50:NWeP80
Z:kK0`2WV<L30:BGa`D0XYK80`2OU<T409^Bb@@0V939102FU<l409JJe@D0VjWP00<0V_;>0=3fi`3@
m^L00P3@m^L=0:Vmj0D0ZKST102Y_^T50:g4j`D0[<7Y0P2[_nP30:Znj0030000002Y_NP0ZKgX01`0
ZKgX0`0000050?ooo`030000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103oool00`00
0000oooo0?ooo`0U0?ooo`<000006P3oool50:Nlj@@0X[_[1@2/_^L40;>oh`l0ZKgX0P0eR>`409:n
m@@0a/;F0P34`mT30<blc0@0b[_=0P39]lT40<Rfb0030<Fcb@34/LL0a;770080a;770P2k[/d40<2]
a`80/:O@0P2lZLH50:VSd0D0ZJ3=0P2Y/Mh30:fOb@@0YjCC0P2Y]N430:ZLb0@0YYo>102WYmH50:NH
a`@0Y9O7102RU/P309nDb@D0Vi;9102HT//309JDc`D0UY[E0P2KZN020:[/n@030=3fi`2Y_NP0ZKgX
0100ZKgX1@2S]>@40:Vnj@D0[L?Z102/`NT50:Znj0030:Vmj0000000ZKgX01T0ZKgX0`0000080?oo
o`030000003oool0oooo01D0oooo00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`05
0?ooo`030?oo_`1d04P0W=oo0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo
00<000000?ooo`3oool08P3oool3000001h0oooo1@2W_>T40::kj`D0[;kW102c_^8?0:Vmj080KjOc
102B__D20<K2eP@0a<?I00<0c;c<0<Zkc@3:^ld00`3:^ld60<Rfb0D0a;771P30[LL50;bYaP80ZJ?@
0`2iY/H40:VPc@D0[Io9102WY=<50:ZLb0@0YYo>1@2YVLH40:NHa`@0Y9O71@2QU<L309jBa`@0Vi;9
102HT//409JDc`@0UY[E0P2Zk?TA0:Vmj0D0Y;7Q102S]>@50:g4j`@0[L?Z2@2Z_^P20:Vmj0030000
002Y_NP0ZKgX01<0ZKgX1000000<0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000M;l0oooo0?ooo`3ookl0M0000`000000
0`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo0`00000R0?ooo`D0YkgY102R^n/5
0:^nj0@0/kkR3`2Y_NP206nWl`@0T[ke1@34`mT50<Zkc@80b;g@1038]/P20<Nfb@<0a;770P34/<L4
0<2]a`80`:c5102lZLH60;VVaP80ZJ3=0P2gXlD50:fOb@80YjCC0P2aW/D50:ZLb080YYo>0P2/V/D4
0:VIaP@0YiS70P2TUlL30:BEaP@0XIC70`2NT/L509^Bb@@0V9;;0`2FU<l40:G:l`03063?Y02bbN/0
ZKgX00d0ZKgX102Y^>@50:Bah@80XkCT0P2[`n/50:g4j`@0Zl3Y1@2Z_^P50:Vmj0030000002Y_NP0
ZKgX00l0ZKgX00@0oooo0000000000000000403oool00`000000oooo0?ooo`0D0?ooo`000`3oool0
1`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01P3oool01`3ookl0M01809cOo`3oool0oooO09a8
B02Lgol02@3oool2000001h0oooo0P00000V0?ooo`030000002W_NT0YkgY0080YkgY102R_>/50:^n
j0@0];oR3`2Y_NP309njk0<0Nkck0`34`mT20;k5h0<0b[_=1038_M020<Rfb0@0akK900<0a;770<B`
a`34/<L00P34/<L20<2]a`<0`:c50`2lZLH20;fXa@D0^JK6102gXlD50:fOb@@0/Ik51@2ZW<P40:bJ
a@D0ZIW60`2WV<L50:BEaPD0XIC70`2NT/L409^Bb@@0V9;;1@2P/^D2063?Y0<0//W[3P2Y_NP40:Vh
i0@0Y;7Q1@2[`n/50:c2jP@0Zl3Y1@2Z_NP50:Vmj0030000002Y_NP0ZKgX00X0ZKgX0P3oool30000
01<0oooo00<000000?ooo`3oool0503oool000<0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l8
0?ooo`060?noM000B9`0gooo0?ooo`2oM000M;oo203oool2000001`0oooo0`00000Z0?ooo`@0YkgY
102R_>/50:Vnj@@0];oR3`2Y_NP209njk0040:Vmj014ZoL0A:_g04B[m`D0_/GP1P38_M060<Nfb@D0
a;371P30[<D0102lZLH0_JS50;fXa@2mZ<D40;VVaP80^ZG4102gXlD20:fOb@<0]:34102aW/D20:ZL
b0<0[ic4102/V/D40:VIaP@0YiO51@2TULH40:6Da`<0WY;71@2OWm@409jUf`80X;;U0P23j^800`33
k_00//W[0;;9j`020;;9j`h0ZKgX102Y^>@50:Rmj@D0[<C[102/`^X50:Znj0@0Z[gX1P2Y_NP00`00
0000ZKgX0:Vmj0070:Vmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3ookl0
M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB0030000
00030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo102W_NT50::l
j`@0ZKkY1@2e_n8A0:Vmj0<0A:_g0`2naN020;;<k@@0b;g@0P34`]P40<Nfb@80a[W>0`34/<L20<>b
b@D0`:c51@2mZ<D20;VVaP<0^ZG4102gXlD50;BPa0@0/Ik51@2_W<@40:bJa@D0ZIW50`2WUlD50:BE
aP@0XIC7102QWM4509nOe0<0WZGK0P23j^830<?^l180ZKgX1@2T]>@30:Rmj@80[<C/1@2/a>/40:Zo
j0D0Z[kX2@2Y_NP00`000000ZKgX0:Vmj0050:Vmj08000006P3oool00`000000oooo0?ooo`0D0?oo
o`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3oool40:Nmj@D0X[c[102W_^X50;FohP@0
ZKWU3P2Y_NP00`1MW_<006g10;;<k@040;;<k@80b;g@1034`]P20<Nfb@@0a[W>00@0a;370<>bb@33
//T0`k;91030[<D20<6^a`@0_JS51P2jYL@20;NSa@80]j?41@2dX<@20;6Na@80/Yk41@2_W<@20:bJ
a@80[Ic6102YVLD40:NGa@@0Y9G61@2SWLl40:6Md@@0WioD0`2Iio/209[chQ00ZKgX0`2Y]>430:B`
h0D0Y;CT1@2/a>`50:_0j@@0Z[oX3P2Y_NP010000000ZKgX0:Vmj02Y_NP2000001d0oooo00<00000
0?ooo`3oool0503oool001l0oooo0P00000C0?ooo`<00000=P3oool40:Nmj@D0Xkc[102W_^X50;K0
hP@0ZKWU3P2Y_NP305fNl`<0//c]1P34`]P60<JicPD0`k;90P30[<D30<6^a`<0_JS50P2mZlL50;ZU
a0@0]j?41@2dX<@40;:Na0D0[ic4102]W<H50:VIa@<0YiO51@2VW/h40:>Mc`@0XIgA1@2QfO/B0:Vm
j0D0ZKCQ102T/>050:_3j`80[<C/0`2[`^X40:_0j@D0Z[kX3@2Y_NP300000200oooo00<000000?oo
o`3oool0503oool001l0oooo00<000000?ooo`3oool03`3oool3000003X0oooo1@2W_NT40:>lj`@0
YKg[1@2f`>840:jjhQ40ZKgX102=d?h30<C2f080^/gX1036^Lh20<?3fP@0`k;91P31[/L0102mZ<D0
_J_70;f[a`2mZlL40;ZUa080^j[8102gXl@20;BPa0<0]J?6102bW/@20:nLa0<0/:78102]W<H40:VI
a@@0ZJ7>102VW/h40:>Mc`80XIgA0`2Tc_H30:7In`l0ZKgX1@2Y^N@40:Vdh@D0ZKoZ102[`n/50:_2
jPT0Z[kX2@2Y_NP3000000<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?oo
o`007`3oool00`000000oooo0?ooo`0<0?ooo`<00000?P3oool50:Nmj@@0Xkc[102U_N/50;;0i@@0
[[[R4@2Y_NP408g@oPD0^/gX0P36^Lh40<?3fP80`k;90P33_=<50<6^a`D0_J_70P2jYL@30;^Zb0@0
]j?41@2eXlH40;:Na0D0/:78102]W<H20:VIa@<0[:G@0`2YXLh50:JNcP<0Xig?1P2Tc_HB0:Vmj0D0
ZKWT102W^^L50:VojPD0[<?[102Z_nP50:Znj0T0ZKgX0`0000060?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3oool300000480oooo
1@2W_NT40:>lj`@0Xkg/1@2b`>D40;:mhQ<0ZKgX00<0GYkb00bHe@2jcNP00`2jcNP60<?3fPD0`kcC
0P31[/L30<6hd@@0_J_71P2kZ/P20;NSa080^Jc<1@2eXlH20;:Na080]:O<1@2`XLP30:fLaPD0[:G@
102YXLh40:JNcPD0Y/Wb5`2Y_NP50:Fch`@0Yk[W1@2/a>`20:c3j`<0ZkoY102Z_nP90:Vmj0@00000
2P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo000N0?ooo`8000002@3o
ool2000004H0oooo1@2W_NT40:Blj`@0Xkg/1@2/_nP40;:mhPD0ZKST402Y_NP408SHo`<0`l?J0`2_
fOH40<>ld`H0`KSA0P2mZlL20;nhd`D0^j[8102i[<`50;FSaP@0]:O<1@2`XLP40;2]e@D0[:G@0`2Y
XLh60:S9lAH0ZKgX1@2U/=l40:Fch`D0ZlC/102/a>`50:^oj@D0Z[gX102Y_NP0103oool000000000
0000000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool001h0oooo00<0
00000?ooo`3oool01@3oool3000004T0oooo1@2X_NT40:Blj`D0X[g/102/_nP40;FohPD0ZKST4P2Y
_NP209njk0H0[mWf0P33_=<20;SEkPD0`KSA1@2o^=<20;^Zb0<0_;cI102i[<`20;FSaP<0^;CF102d
Yl`20;2Qb0<0/kWN102`[MD40:bUd0D0ZLod5`2Y_NP40:Vbg`D0YK3O102Z`n`50:_4k0@0Zl7Z0`2[
_nT20:Znj0D0Z[gX00@0oooo00000000000000004`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01<0oooo000N0?ooo`030000003oool0oooo0080oooo0`00001=0?ooo`030000002X
_NT0Z;gY0080Z;gY102U_>X50::mk0@0Yko[102e_n850:jihAD0ZKgX102_fOH50;SEkP80`KSA0`2h
eNl40;nhd`H0_;cI0`2i[<`50;RdeP@0]:O<1@2c^Mh40;2]e@D0YM[j5`2Y_NP50:Vcg`@0ZK;O1@2Y
`^/40:[3k0D0Zl;[102[`NX50:Znj0030?ooo`0000000000008000005P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01<0oooo000N0?ooo`030000003oool0000000800000D@3oool0
0`000000Z;gX0:Rmj0020:Rmj0@0YKcZ1@2S_N`40:Noj`@0/L7V1@2^^N440:Vhi1H0ZKgX0`2heNh6
0;SEk`80_kSC0P2agOH50;blf@@0^<_Y102h]=H50;?>kP@0/kWN1P2CiO`G0:Vmj0@0ZKCP1@2Y/ml4
0:VojP@0ZL;[1@2[`n/40:_2j`L0Z[kX0`00000K0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool04`3oool001h0oooo0P00001E0?ooo`030000002X_NP0Z;gX0080Z;gX102V_NT50:>m
k0@0Xkk/102a`NH50;BnhP@0ZKST6P2Y_NP40;SEk`D0/Mgf0P2l_=T308oVnP@0^<_Y0P2h]=H209SV
o0D0/lk^1@1Dd=DG0:Vmj0D0ZKCQ102Y]>020:Vcg`<0Z;gX102Y_nX40:_3k0D0Zl?[202Z_^P20000
01l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0
B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo00<000000:Vmj02Y_NP00P2Y_NP40:Jmj@D0
Y;g[102S_^`50:W0jP@0];kR102^^>4O0:Vmj0<0/Mgf1@2?i_X40;S;j@D0V>Kl7@2Y_NP80:Vdh@@0
ZKCP1@2X_NP50:[4k0@0Zl?/1@2Z_nT40:Znj0030000003oool0oooo0240oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000
EP3oool40:Vmj0D0YkgY102T_N/40:>mk0D0ZL3Z102a`NH40:jhh@D0ZKCQ@`2Y_NP50:Vdh0L0ZKCQ
1P2X_>L40:[4k@@0Z/C/2@2Z_nT2000002L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05@0oooo102Y
_NP50:Nmj@@0YKgZ102S_N`50:Bok0@0/L7V102e`>850:Vdh@@0ZKOS0`2Y_NP20:Vii3H0ZKgX102Y
/ml40:Vdh0@0ZKCQ102Y^nH30:Rli`L0Z/C]2@2Z_nT2000002/0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0
oooo05@0oooo102Y_NP50:Rmj0@0YKgZ102T_N/50:Bok0@0Z<3[102e`>850;:lh@@0ZKOS2P2Y^N@^
0:Vmj0<0ZK;O102Y/ml30:Vdh0T0ZK_V1@2Za>d50:[0j@@0Z[oY0P00000`0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03P3oool00`00
0000oooo0?ooo`1D0?ooo`@0ZKgX1@2X_NP40:Nmj@@0Y;g[1@2S_^`40:S0j`@0[L7Y1@2b_>440:ni
h@<0ZKWT0P2]]n050:Vii0@0ZKOS7P2Y_NP50:Vii0@0ZKgX1@2Y/]l40:Vcg`@0Z[cW1@2Y^nH50:W4
k@P0Z/3Y0`00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0
oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?ooo`T0ZKgX102W_NT40:FmjPD0
Xkk/102S_nd40:g1j@D0/<7W102_^N450:fgh080ZKWT0`2]]n040:Vgh`@0ZKCQ1@2Y_NP40:Vhi0@0
ZKgX1@2Y^>@40:Vmj0@0ZKCQ1@2Y^N@40:VagP@0ZK;O1@2[_^P40:Zli`D0ZLC]1@2Y`>X40:[0j@<0
0000=`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo000A0?ooo`050;md
000004P0W;nL04P0M02oool0403oool2000005D0oooo2@2Y_NP40:Rmj0@0YKgZ1@2T_N/40:>ok@@0
YL3]1@2``NL40;;1iPX0[KOP0P2Y]n<20:nih@@0ZKCQ1@2Y/]l40:Vhi0@0ZK?O1@2Y^>@40:VbgP@0
ZKCQ1@2]]n040:VagP@0Zl3Y1@2[_^P50:W4k@P0ZL3Z0`00000l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000
oooo0?ooo`1C0?ooo`T0ZKgX102X_NP40:Nmj@D0Y;g[102T_^`40:G0k@D0Y/7/102b`NH40;71iPD0
[KOP1@2_^N420:Vdh@80/[gR102Y/]l50:jhh0@0ZK?O1@2^^>040:VbgP@0[[cT102]]n050:[2j`@0
Zl3Y1@2X`nd50:VojP@0ZL3Z0`0000100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool04P3oool001<0oooo00<0omnL04P0M02oool04`3oool00`000000oooo0?ooo`1C0?ooo`d0ZKgX
102W_NT50:JmjPP0Y;k/1@2V`N`40:O1k0@0/L7V1@2``NL40:nih@D0/[gR0P2Y/]l20;30iPD0[[SP
102__nH40:jhh0D0[<7X102^_>@40:W3k0D0Z/;[1`2X`nd60:VojP@00000@`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0140oooo000Z0?ooo`030000003oool0oooo05<0oooo3@2Y
_NP40:Rmj0T0Y[gZ102T_^`50:Bok@@0Yl7/102W`Nd40;31i`D0[L;Y102b_N850;30iPD0Zl;[102_
_nH40:W3k0D0[<7X102X`nd40:W3k0T0Z<?]1@2Y_nX3000004P0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo3@2Y_NP40:Rmj0D0Z;gY102V_NX4
0:Fnj`T0Y;o]102W`Nd40:K1k@D0[L;Y1@2Y`^`40:O2k@D0Zl;[102W`nd40:W3k0D0Yl?]102X`nd4
0:O2k0@0Z<?]1@2Y_nX0103oool0000000000000001<0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool002d0oooo00<000000?ooo`3oool0DP3ooolA0:Vmj0T0Z;gY2@2U_^/9
0:Bok@<0Y/7]2P2U`Nd40:O2k@D0Y/7]102W`nd40:K2k@@0Yl?]1@2W`N`40:O2k0D0Z;oY1000001?
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002h0oooo00<000000?oo
o`3oool0DP3ooolF0:Vmj0@0Z;gY2@2W_NT50:Jnj`@0Y[kZ102U_n`50:Jok0@0YL7]102V`>`40:K1
k@D0Yl3/102V`^d40:O0j`@0Yl7/1P2X_^T3000005@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0A0?ooo`00;`3oool00`000000oooo0?ooo`1B0?oooal0ZKgX102W_NT50:Rmj@@0
Y[kZ102W_^X40:Jok0D0Ykk[102V`>`40:Noj`@0Yl3/1@2X_nX40:O0j`D0ZKkY00@0oooo00000000
00000000F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?ooo`03
0000003oool0oooo0580oooo8`2Y_NP90:Rmj@@0YkkZ102X_^T50:Nnj`@0Z;kY102W_n/40:Rnj@D0
Z;oZ1@2Y_^P4000005`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00
<@3oool2000005<0oooo:02Y_NP40:Rmj@@0ZKgX102X_^T50:Rmj@@0Z;kY102Y_^T40:Rnj@D0ZKgX
00@0oooo0000000000000000H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo000c0?ooo`030000003oool0oooo0540oooo=02Y_NP40:Rmj@D0ZKgX102Y_^T50:Vmj0@00000
I03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo000d0?ooo`030000003o
ool0oooo0540oooo@P2Y_NP3000006T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`00=@3oool00`000000oooo0?ooo`1A0?ooocd0ZKgX00@0oooo0000000000000000K03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000f0?ooo`800000DP3oooli
0:Vmj0@00000L03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000h0?oo
o`030000003oool0oooo0500oooo=@2Y_NP3000007D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo00000000
00000000N@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000j0?ooo`03
0000003oool0oooo0540oooo:`2Y_NP4000007`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`00>`3oool00`000000oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool003`0oooo0P00001B0?ooob80ZKgX00@0
oooo0000000000000000Q@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
000n0?ooo`030000003oool0oooo0500oooo7P2Y_NP4000008T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`00?`3oool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00002=
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00400oooo00<000000?oo
o`3oool0D03ooolF0:Vmj0<00000T@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo00110?ooo`800000D@3ooolB0:Vmj0<00000U@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00l0oooo00130?ooo`030000003oool0oooo04l0oooo3@2Y_NP3000009T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00A03oool00`000000oooo0?oo
o`1@0?ooo`P0ZKgX0`00002M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3o
ool004D0oooo00<000000?ooo`3oool0D03oool40:Vmj0<00000X@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00160?ooo`800000D@3oool200000:H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B03oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00
B@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00B`3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0>0?ooo`00C03oool2000004/0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo001>0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo001?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo001@0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001A
0?ooo`800000AP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool005<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2/0?oo
o`050000003oool0oooo0?ooo`0000003`3oool005@0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001E0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00EP3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`0000003`3oool005L0
oooo0P00000o0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`0000003P3oool005T0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005/0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`2a0?ooo`8000003P3oool005`0oooo0P00000j0?oo
o`030000003oool0oooo0:d0oooo1000000@0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0:T0oooo1000000D0?ooo`00G`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo0:D0oooo1000000H0?ooo`00H03oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0:40oooo1000000L0?ooo`00H@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo09h0oooo0`00000P0?ooo`00HP3oool2000003@0oooo00<000000?ooo`3oool0VP3oool40000
02<0oooo001T0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0UP3oool4000002L0
oooo001U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0TP3oool4000002/0oooo
001V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0SP3oool4000002l0oooo001W
0?ooo`800000;`3oool00`000000oooo0?ooo`2:0?ooo`@00000<`3oool006T0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`270?ooo`<00000=`3oool006X0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`230?ooo`@00000>P3oool006/0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`1o0?ooo`@00000?P3oool006`0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1k0?ooo`@00000@P3oool006d0oooo0P00000Y0?ooo`030000003oool0
oooo07L0oooo100000160?ooo`00K`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
07D0oooo0`00001:0?ooo`00L03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0740
oooo1000001=0?ooo`00L@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001A0?ooo`00LP3oool2000002<0oooo00<000000?ooo`3oool0J@3oool4000005D0oooo001d
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I@3oool4000005T0oooo001e0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool3000005d0oooo001f0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool400000600oooo001g0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0FP3oool4000006@0oooo001h0?ooo`8000007@3o
ool00`000000oooo0?ooo`1F0?ooo`@00000J03oool007X0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1B0?ooo`@00000K03oool007/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1>0?ooo`@00000L03oool007`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1;0?ooo`<00000M03oool007d0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo
1000001g0?ooo`00O`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000
001k0?ooo`00P03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000001o
0?ooo`00P@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo100000230?oo
o`00PP3oool2000001<0oooo00<000000?ooo`3oool0>03oool3000008L0oooo00240?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0=03oool4000008X0oooo00250?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0<03oool4000008h0oooo00260?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0;03oool400000980oooo00270?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0:03oool4000009H0oooo00280?ooo`8000003@3oool00`000000
oooo0?ooo`0U0?ooo`<00000VP3oool008X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0R0?ooo`@00000W@3oool008/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0N0?ooo`@00000X@3oool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J
0?ooo`@00000Y@3oool008d0oooo0P0000070?ooo`030000003oool0oooo01H0oooo1000002Y0?oo
o`00S`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo1000002]0?ooo`00
T03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0`00002a0?ooo`00T@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000002d0?ooo`00TP3oool0
1@000000oooo0?ooo`3oool0000000T0oooo1000002h0?ooo`00T`3oool2000000030?ooo`000000
oooo00@0oooo1000002l0?ooo`00U@3oool2000000030?ooo`000000000000800000`03oool009H0
oooo0P0000340?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?oo
o`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57073 Mtetra
.47319 .57073 .47922 .5767 .48995 .57348 .48394 .56749 Mtetra
.48394 .56749 .48995 .57348 .50072 .57024 .49474 .56422 Mtetra
.49474 .56422 .50072 .57024 .51154 .56698 .50558 .56095 Mtetra
.50558 .56095 .51154 .56698 .52239 .56372 .51647 .55766 Mtetra
.663 .741 .908 r
.51647 .55766 .52239 .56372 .53329 .56045 .52739 .55437 Mtetra
.52739 .55437 .53329 .56045 .54423 .55717 .53837 .55109 Mtetra
.662 .741 .909 r
.53837 .55109 .54423 .55717 .55522 .55389 .54938 .54782 Mtetra
.66 .742 .911 r
.54938 .54782 .55522 .55389 .56625 .55062 .56044 .54458 Mtetra
.659 .743 .912 r
.56044 .54458 .56625 .55062 .57733 .54737 .57155 .54137 Mtetra
.658 .745 .914 r
.57155 .54137 .57733 .54737 .58845 .54414 .5827 .53817 Mtetra
.657 .747 .916 r
.5827 .53817 .58845 .54414 .59962 .54092 .5939 .53499 Mtetra
.657 .749 .918 r
.5939 .53499 .59962 .54092 .61083 .53772 .60514 .53178 Mtetra
.60514 .53178 .61083 .53772 .62209 .53451 .61644 .52855 Mtetra
.659 .75 .918 r
.61644 .52855 .62209 .53451 .6334 .53128 .62777 .52527 Mtetra
.66 .75 .916 r
.62777 .52527 .6334 .53128 .64475 .528 .63916 .52193 Mtetra
.661 .749 .915 r
.63916 .52193 .64475 .528 .65615 .52467 .65058 .51854 Mtetra
.662 .748 .914 r
.65058 .51854 .65615 .52467 .66759 .52128 .66206 .51511 Mtetra
.664 .748 .913 r
.66206 .51511 .66759 .52128 .67907 .51783 .67358 .51163 Mtetra
.665 .748 .913 r
.67358 .51163 .67907 .51783 .69061 .51431 .68514 .5081 Mtetra
.666 .749 .913 r
.68514 .5081 .69061 .51431 .70218 .51073 .69676 .50453 Mtetra
.667 .751 .913 r
.69676 .50453 .70218 .51073 .7138 .5071 .70841 .50091 Mtetra
.668 .752 .913 r
.70841 .50091 .7138 .5071 .72547 .50342 .72011 .49723 Mtetra
.669 .754 .914 r
.72011 .49723 .72547 .50342 .73718 .49972 .73186 .4935 Mtetra
.67 .753 .913 r
.73186 .4935 .73718 .49972 .74894 .49601 .74365 .48974 Mtetra
.74365 .48974 .74894 .49601 .76075 .49231 .75549 .48595 Mtetra
.669 .751 .912 r
.75549 .48595 .76075 .49231 .7726 .48862 .76738 .48218 Mtetra
.668 .749 .91 r
.76738 .48218 .7726 .48862 .78451 .48495 .77932 .47842 Mtetra
.667 .746 .909 r
.77932 .47842 .78451 .48495 .79647 .48131 .79131 .47469 Mtetra
.666 .744 .908 r
.79131 .47469 .79647 .48131 .80849 .47766 .80336 .47099 Mtetra
.665 .742 .908 r
.80336 .47099 .80849 .47766 .82055 .47402 .81546 .46729 Mtetra
.664 .742 .908 r
.81546 .46729 .82055 .47402 .83266 .47037 .82761 .4636 Mtetra
.664 .741 .907 r
.82761 .4636 .83266 .47037 .84483 .4667 .83981 .45991 Mtetra
.83981 .45991 .84483 .4667 .85705 .46303 .85206 .4562 Mtetra
.85206 .4562 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44875 Mtetra
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44442 .91411 .43744 Mtetra
.91411 .43744 .91891 .44442 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .426 Mtetra
.95198 .426 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57073 .46711 .56472 Mtetra
.46711 .56472 .47319 .57073 .48394 .56749 .47789 .56145 Mtetra
.47789 .56145 .48394 .56749 .49474 .56422 .48872 .55817 Mtetra
.663 .741 .908 r
.48872 .55817 .49474 .56422 .50558 .56095 .49959 .55488 Mtetra
.49959 .55488 .50558 .56095 .51647 .55766 .5105 .5516 Mtetra
.662 .742 .909 r
.5105 .5516 .51647 .55766 .52739 .55437 .52145 .54834 Mtetra
.66 .743 .911 r
.52145 .54834 .52739 .55437 .53837 .55109 .53245 .54512 Mtetra
.657 .745 .915 r
.53245 .54512 .53837 .55109 .54938 .54782 .5435 .54195 Mtetra
.655 .749 .919 r
.5435 .54195 .54938 .54782 .56044 .54458 .55459 .53882 Mtetra
.654 .753 .923 r
.55459 .53882 .56044 .54458 .57155 .54137 .56573 .5357 Mtetra
.654 .757 .925 r
.56573 .5357 .57155 .54137 .5827 .53817 .57691 .53254 Mtetra
.657 .76 .926 r
.57691 .53254 .5827 .53817 .5939 .53499 .58814 .52929 Mtetra
.661 .759 .923 r
.58814 .52929 .5939 .53499 .60514 .53178 .59942 .52592 Mtetra
.665 .756 .918 r
.59942 .52592 .60514 .53178 .61644 .52855 .61074 .52242 Mtetra
.668 .749 .911 r
.61074 .52242 .61644 .52855 .62777 .52527 .6221 .51884 Mtetra
.669 .741 .904 r
.6221 .51884 .62777 .52527 .63916 .52193 .6335 .51522 Mtetra
.668 .732 .897 r
.6335 .51522 .63916 .52193 .65058 .51854 .64495 .5116 Mtetra
.666 .725 .893 r
.64495 .5116 .65058 .51854 .66206 .51511 .65645 .50803 Mtetra
.664 .721 .891 r
.65645 .50803 .66206 .51511 .67358 .51163 .668 .50452 Mtetra
.661 .72 .892 r
.668 .50452 .67358 .51163 .68514 .5081 .6796 .50108 Mtetra
.66 .723 .896 r
.6796 .50108 .68514 .5081 .69676 .50453 .69126 .49768 Mtetra
.659 .729 .901 r
.69126 .49768 .69676 .50453 .70841 .50091 .70296 .4943 Mtetra
.66 .737 .907 r
.70296 .4943 .70841 .50091 .72011 .49723 .71471 .49087 Mtetra
.662 .747 .913 r
.71471 .49087 .72011 .49723 .73186 .4935 .72651 .48735 Mtetra
.665 .756 .918 r
.72651 .48735 .73186 .4935 .74365 .48974 .73834 .4837 Mtetra
.668 .762 .92 r
.73834 .4837 .74365 .48974 .75549 .48595 .75022 .47994 Mtetra
.671 .764 .921 r
.75022 .47994 .75549 .48595 .76738 .48218 .76215 .47607 Mtetra
.672 .763 .919 r
.76215 .47607 .76738 .48218 .77932 .47842 .77411 .47217 Mtetra
.671 .758 .916 r
.77411 .47217 .77932 .47842 .79131 .47469 .78613 .46827 Mtetra
.67 .753 .913 r
.78613 .46827 .79131 .47469 .80336 .47099 .7982 .46441 Mtetra
.668 .748 .911 r
.7982 .46441 .80336 .47099 .81546 .46729 .81033 .4606 Mtetra
.666 .745 .909 r
.81033 .4606 .81546 .46729 .82761 .4636 .82251 .45683 Mtetra
.665 .743 .908 r
.82251 .45683 .82761 .4636 .83981 .45991 .83475 .45307 Mtetra
.664 .741 .908 r
.83475 .45307 .83981 .45991 .85206 .4562 .84704 .44933 Mtetra
.664 .741 .907 r
.84704 .44933 .85206 .4562 .86437 .45248 .85938 .44557 Mtetra
.85938 .44557 .86437 .45248 .87672 .44875 .87177 .44181 Mtetra
.87177 .44181 .87672 .44875 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43042 Mtetra
.90928 .43042 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .426 .94727 .41888 Mtetra
.94727 .41888 .95198 .426 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56848 Mtetra
.42881 .56848 .43501 .57447 .44567 .57123 .43949 .56522 Mtetra
.43949 .56522 .44567 .57123 .45637 .56798 .45022 .56195 Mtetra
.45022 .56195 .45637 .56798 .46711 .56472 .46098 .55867 Mtetra
.46098 .55867 .46711 .56472 .47789 .56145 .47179 .55538 Mtetra
.663 .741 .908 r
.47179 .55538 .47789 .56145 .48872 .55817 .48265 .55208 Mtetra
.662 .741 .909 r
.48265 .55208 .48872 .55817 .49959 .55488 .49354 .54882 Mtetra
.66 .742 .911 r
.49354 .54882 .49959 .55488 .5105 .5516 .50448 .54559 Mtetra
.657 .744 .914 r
.50448 .54559 .5105 .5516 .52145 .54834 .51547 .54244 Mtetra
.653 .747 .919 r
.51547 .54244 .52145 .54834 .53245 .54512 .5265 .53937 Mtetra
.651 .752 .924 r
.5265 .53937 .53245 .54512 .5435 .54195 .53757 .53631 Mtetra
.653 .758 .926 r
.53757 .53631 .5435 .54195 .55459 .53882 .5487 .53318 Mtetra
.66 .76 .924 r
.5487 .53318 .55459 .53882 .56573 .5357 .55986 .52985 Mtetra
.67 .757 .915 r
.55986 .52985 .56573 .5357 .57691 .53254 .57107 .52623 Mtetra
.679 .745 .901 r
.57107 .52623 .57691 .53254 .58814 .52929 .58232 .52231 Mtetra
.684 .727 .883 r
.58232 .52231 .58814 .52929 .59942 .52592 .59361 .51819 Mtetra
.663 .7 .874 r
.59361 .51819 .59942 .52592 .61074 .52242 .60495 .51472 Mtetra
.663 .702 .876 r
.60495 .51472 .61074 .52242 .6221 .51884 .61635 .51125 Mtetra
.663 .706 .879 r
.61635 .51125 .6221 .51884 .6335 .51522 .62778 .50776 Mtetra
.664 .71 .882 r
.62778 .50776 .6335 .51522 .64495 .5116 .63927 .50425 Mtetra
.664 .714 .886 r
.63927 .50425 .64495 .5116 .65645 .50803 .6508 .50073 Mtetra
.664 .716 .888 r
.6508 .50073 .65645 .50803 .668 .50452 .66238 .4972 Mtetra
.66238 .4972 .668 .50452 .6796 .50108 .67401 .49365 Mtetra
.664 .714 .886 r
.67401 .49365 .6796 .50108 .69126 .49768 .68568 .49009 Mtetra
.664 .71 .882 r
.68568 .49009 .69126 .49768 .70296 .4943 .69741 .48651 Mtetra
.663 .706 .879 r
.69741 .48651 .70296 .4943 .71471 .49087 .70918 .48292 Mtetra
.663 .702 .876 r
.70918 .48292 .71471 .49087 .72651 .48735 .721 .47931 Mtetra
.644 .693 .881 r
.721 .47931 .72651 .48735 .73834 .4837 .73291 .47637 Mtetra
.649 .715 .897 r
.73291 .47637 .73834 .4837 .75022 .47994 .74487 .47322 Mtetra
.657 .738 .909 r
.74487 .47322 .75022 .47994 .76215 .47607 .75686 .46977 Mtetra
.666 .756 .917 r
.75686 .46977 .76215 .47607 .77411 .47217 .76888 .46603 Mtetra
.672 .764 .92 r
.76888 .46603 .77411 .47217 .78613 .46827 .78093 .46208 Mtetra
.674 .764 .919 r
.78093 .46208 .78613 .46827 .7982 .46441 .79303 .45805 Mtetra
.673 .759 .916 r
.79303 .45805 .7982 .46441 .81033 .4606 .80518 .45404 Mtetra
.67 .753 .912 r
.80518 .45404 .81033 .4606 .82251 .45683 .81739 .45011 Mtetra
.667 .747 .91 r
.81739 .45011 .82251 .45683 .83475 .45307 .82965 .44624 Mtetra
.666 .744 .908 r
.82965 .44624 .83475 .45307 .84704 .44933 .84197 .44242 Mtetra
.665 .742 .908 r
.84197 .44242 .84704 .44933 .85938 .44557 .85435 .43862 Mtetra
.664 .741 .908 r
.85435 .43862 .85938 .44557 .87177 .44181 .86679 .43482 Mtetra
.664 .741 .907 r
.86679 .43482 .87177 .44181 .88422 .43803 .87927 .431 Mtetra
.87927 .431 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43042 .90441 .42333 Mtetra
.90441 .42333 .90928 .43042 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56848 .42256 .56246 Mtetra
.42256 .56246 .42881 .56848 .43949 .56522 .43327 .55917 Mtetra
.43327 .55917 .43949 .56522 .45022 .56195 .44402 .55588 Mtetra
.44402 .55588 .45022 .56195 .46098 .55867 .45481 .55258 Mtetra
.663 .741 .908 r
.45481 .55258 .46098 .55867 .47179 .55538 .46565 .54928 Mtetra
.661 .741 .909 r
.46565 .54928 .47179 .55538 .48265 .55208 .47653 .54603 Mtetra
.658 .742 .912 r
.47653 .54603 .48265 .55208 .49354 .54882 .48746 .54285 Mtetra
.653 .745 .917 r
.48746 .54285 .49354 .54882 .50448 .54559 .49842 .53978 Mtetra
.65 .75 .923 r
.49842 .53978 .50448 .54559 .51547 .54244 .50944 .53677 Mtetra
.651 .756 .926 r
.50944 .53677 .51547 .54244 .5265 .53937 .5205 .5337 Mtetra
.661 .759 .923 r
.5205 .5337 .5265 .53937 .53757 .53631 .5316 .53035 Mtetra
.677 .755 .909 r
.5316 .53035 .53757 .53631 .5487 .53318 .54275 .52652 Mtetra
.691 .738 .886 r
.54275 .52652 .5487 .53318 .55986 .52985 .55394 .52216 Mtetra
.663 .701 .875 r
.55394 .52216 .55986 .52985 .57107 .52623 .56518 .51872 Mtetra
.663 .706 .879 r
.56518 .51872 .57107 .52623 .58232 .52231 .57646 .51526 Mtetra
.664 .72 .891 r
.57646 .51526 .58232 .52231 .59361 .51819 .58779 .51178 Mtetra
.664 .741 .907 r
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73291 .47637 .72744 .46896 Mtetra
.664 .72 .891 r
.72744 .46896 .73291 .47637 .74487 .47322 .73939 .46529 Mtetra
.663 .706 .879 r
.73939 .46529 .74487 .47322 .75686 .46977 .7514 .46161 Mtetra
.636 .69 .883 r
.7514 .46161 .75686 .46977 .76888 .46603 .76352 .45885 Mtetra
.651 .725 .903 r
.76352 .45885 .76888 .46603 .78093 .46208 .77567 .45556 Mtetra
.665 .752 .915 r
.77567 .45556 .78093 .46208 .79303 .45805 .78782 .45178 Mtetra
.673 .764 .919 r
.78782 .45178 .79303 .45805 .80518 .45404 .80001 .44771 Mtetra
.675 .763 .917 r
.80001 .44771 .80518 .45404 .81739 .45011 .81224 .44357 Mtetra
.673 .757 .914 r
.81224 .44357 .81739 .45011 .82965 .44624 .82453 .4395 Mtetra
.669 .75 .911 r
.82453 .4395 .82965 .44624 .84197 .44242 .83688 .43553 Mtetra
.666 .745 .909 r
.83688 .43553 .84197 .44242 .85435 .43862 .84929 .43164 Mtetra
.665 .742 .908 r
.84929 .43164 .85435 .43862 .86679 .43482 .86176 .42778 Mtetra
.664 .741 .907 r
.86176 .42778 .86679 .43482 .87927 .431 .87428 .42393 Mtetra
.87428 .42393 .87927 .431 .89181 .42718 .88686 .42007 Mtetra
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55638 Mtetra
.41626 .55638 .42256 .56246 .43327 .55917 .427 .55308 Mtetra
.663 .741 .908 r
.427 .55308 .43327 .55917 .44402 .55588 .43778 .54977 Mtetra
.662 .741 .908 r
.43778 .54977 .44402 .55588 .45481 .55258 .4486 .54647 Mtetra
.66 .741 .91 r
.4486 .54647 .45481 .55258 .46565 .54928 .45946 .54323 Mtetra
.656 .742 .914 r
.45946 .54323 .46565 .54928 .47653 .54603 .47037 .5401 Mtetra
.651 .746 .919 r
.47037 .5401 .47653 .54603 .48746 .54285 .48132 .53709 Mtetra
.648 .751 .925 r
.48132 .53709 .48746 .54285 .49842 .53978 .49231 .5341 Mtetra
.656 .758 .925 r
.49231 .5341 .49842 .53978 .50944 .53677 .50336 .53089 Mtetra
.676 .757 .912 r
.50336 .53089 .50944 .53677 .5205 .5337 .51445 .52711 Mtetra
.693 .74 .887 r
.51445 .52711 .5205 .5337 .5316 .53035 .52558 .52269 Mtetra
.663 .702 .876 r
.52558 .52269 .5316 .53035 .54275 .52652 .53676 .51925 Mtetra
.664 .713 .885 r
.53676 .51925 .54275 .52652 .55394 .52216 .54798 .51579 Mtetra
.664 .741 .907 r
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.61629 .49474 .62206 .50127 .63357 .49774 .62783 .49118 Mtetra
.62783 .49118 .63357 .49774 .64514 .4942 .63943 .48761 Mtetra
.63943 .48761 .64514 .4942 .65675 .49064 .65108 .48402 Mtetra
.65108 .48402 .65675 .49064 .66841 .48706 .66277 .48042 Mtetra
.66277 .48042 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76352 .45885 .75809 .45105 Mtetra
.664 .713 .885 r
.75809 .45105 .76352 .45885 .77567 .45556 .77023 .4473 Mtetra
.635 .69 .884 r
.77023 .4473 .77567 .45556 .78782 .45178 .78251 .44455 Mtetra
.652 .727 .904 r
.78251 .44455 .78782 .45178 .80001 .44771 .79479 .44116 Mtetra
.67 .756 .915 r
.79479 .44116 .80001 .44771 .81224 .44357 .80707 .43717 Mtetra
.676 .764 .917 r
.80707 .43717 .81224 .44357 .82453 .4395 .81939 .43295 Mtetra
.675 .76 .915 r
.81939 .43295 .82453 .4395 .83688 .43553 .83176 .42876 Mtetra
.671 .752 .911 r
.83176 .42876 .83688 .43553 .84929 .43164 .8442 .42468 Mtetra
.667 .746 .909 r
.8442 .42468 .84929 .43164 .86176 .42778 .8567 .42072 Mtetra
.665 .743 .908 r
.8567 .42072 .86176 .42778 .87428 .42393 .86926 .41681 Mtetra
.664 .741 .908 r
.86926 .41681 .87428 .42393 .88686 .42007 .88187 .4129 Mtetra
.664 .741 .907 r
.88187 .4129 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40507 Mtetra
.90727 .40507 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55358 Mtetra
.3992 .55358 .40557 .55968 .41626 .55638 .40992 .55027 Mtetra
.663 .741 .908 r
.40992 .55027 .41626 .55638 .427 .55308 .42068 .54695 Mtetra
.662 .741 .908 r
.42068 .54695 .427 .55308 .43778 .54977 .43149 .54365 Mtetra
.66 .741 .91 r
.43149 .54365 .43778 .54977 .4486 .54647 .44233 .54041 Mtetra
.654 .742 .914 r
.44233 .54041 .4486 .54647 .45946 .54323 .45322 .53731 Mtetra
.649 .746 .921 r
.45322 .53731 .45946 .54323 .47037 .5401 .46415 .53433 Mtetra
.648 .752 .925 r
.46415 .53433 .47037 .5401 .48132 .53709 .47513 .53134 Mtetra
.664 .758 .92 r
.47513 .53134 .48132 .53709 .49231 .5341 .48616 .52791 Mtetra
.692 .751 .897 r
.48616 .52791 .49231 .5341 .50336 .53089 .49724 .52357 Mtetra
.673 .714 .879 r
.49724 .52357 .50336 .53089 .51445 .52711 .50836 .51978 Mtetra
.663 .712 .884 r
.50836 .51978 .51445 .52711 .52558 .52269 .51952 .51632 Mtetra
.664 .741 .907 r
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.56462 .50236 .57056 .50883 .58192 .50533 .57601 .49883 Mtetra
.57601 .49883 .58192 .50533 .59333 .50182 .58745 .49529 Mtetra
.58745 .49529 .59333 .50182 .60478 .49829 .59894 .49173 Mtetra
.59894 .49173 .60478 .49829 .61629 .49474 .61047 .48816 Mtetra
.61047 .48816 .61629 .49474 .62783 .49118 .62205 .48458 Mtetra
.62205 .48458 .62783 .49118 .63943 .48761 .63368 .48097 Mtetra
.63368 .48097 .63943 .48761 .65108 .48402 .64536 .47736 Mtetra
.64536 .47736 .65108 .48402 .66277 .48042 .65708 .47373 Mtetra
.65708 .47373 .66277 .48042 .67451 .4768 .66886 .47008 Mtetra
.66886 .47008 .67451 .4768 .6863 .47317 .68068 .46642 Mtetra
.68068 .46642 .6863 .47317 .69814 .46952 .69256 .46274 Mtetra
.69256 .46274 .69814 .46952 .71003 .46586 .70448 .45905 Mtetra
.70448 .45905 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78251 .44455 .77709 .43657 Mtetra
.653 .707 .887 r
.77709 .43657 .78251 .44455 .79479 .44116 .7894 .43312 Mtetra
.636 .7 .891 r
.7894 .43312 .79479 .44116 .80707 .43717 .80182 .43023 Mtetra
.663 .744 .91 r
.80182 .43023 .80707 .43717 .81939 .43295 .81421 .42642 Mtetra
.676 .763 .916 r
.81421 .42642 .81939 .43295 .83176 .42876 .82662 .42215 Mtetra
.677 .761 .915 r
.82662 .42215 .83176 .42876 .8442 .42468 .83908 .41786 Mtetra
.672 .754 .912 r
.83908 .41786 .8442 .42468 .8567 .42072 .8516 .41369 Mtetra
.668 .746 .909 r
.8516 .41369 .8567 .42072 .86926 .41681 .86419 .40966 Mtetra
.665 .743 .908 r
.86419 .40966 .86926 .41681 .88187 .4129 .87685 .40569 Mtetra
.664 .741 .907 r
.87685 .40569 .88187 .4129 .89455 .409 .88956 .40174 Mtetra
.88956 .40174 .89455 .409 .90727 .40507 .90232 .39779 Mtetra
.90232 .39779 .90727 .40507 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .55409 Mtetra
.37142 .55409 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.38208 .55078 .38852 .55689 .3992 .55358 .39278 .54745 Mtetra
.664 .741 .908 r
.39278 .54745 .3992 .55358 .40992 .55027 .40353 .54411 Mtetra
.662 .741 .908 r
.40353 .54411 .40992 .55027 .42068 .54695 .41432 .5408 Mtetra
.659 .741 .91 r
.41432 .5408 .42068 .54695 .43149 .54365 .42515 .53756 Mtetra
.654 .742 .915 r
.42515 .53756 .43149 .54365 .44233 .54041 .43602 .53446 Mtetra
.647 .746 .921 r
.43602 .53446 .44233 .54041 .45322 .53731 .44693 .53152 Mtetra
.649 .752 .925 r
.44693 .53152 .45322 .53731 .46415 .53433 .45789 .52849 Mtetra
.671 .757 .915 r
.45789 .52849 .46415 .53433 .47513 .53134 .46891 .52485 Mtetra
.697 .744 .888 r
.46891 .52485 .47513 .53134 .48616 .52791 .47998 .52031 Mtetra
.663 .704 .878 r
.47998 .52031 .48616 .52791 .49724 .52357 .49108 .51686 Mtetra
.664 .73 .899 r
.49108 .51686 .49724 .52357 .50836 .51978 .50223 .51339 Mtetra
.664 .741 .907 r
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.52465 .50641 .53073 .51285 .54198 .50937 .53593 .5029 Mtetra
.53593 .5029 .54198 .50937 .55328 .50587 .54726 .49938 Mtetra
.54726 .49938 .55328 .50587 .56462 .50236 .55864 .49584 Mtetra
.641 .733 .916 r
.55864 .49584 .56462 .50236 .57601 .49883 .57007 .49296 Mtetra
.478 .693 .962 r
.57007 .49296 .57601 .49883 .58745 .49529 .58161 .49323 Mtetra
.302 .755 .957 r
.58161 .49323 .58745 .49529 .59894 .49173 .5932 .49279 Mtetra
0 0 0 r
.5932 .49279 .59894 .49173 .61047 .48816 .60485 .49151 Mtetra
.132 0 0 r
.60485 .49151 .61047 .48816 .62205 .48458 .61654 .48939 Mtetra
.181 0 0 r
.61654 .48939 .62205 .48458 .63368 .48097 .62827 .48649 Mtetra
.175 0 0 r
.62827 .48649 .63368 .48097 .64536 .47736 .64002 .48286 Mtetra
.12 0 0 r
.64002 .48286 .64536 .47736 .65708 .47373 .6518 .47849 Mtetra
0 0 0 r
.6518 .47849 .65708 .47373 .66886 .47008 .66359 .47334 Mtetra
.66359 .47334 .66886 .47008 .68068 .46642 .67538 .46734 Mtetra
.597 .95 .851 r
.67538 .46734 .68068 .46642 .69256 .46274 .68716 .46047 Mtetra
.776 .931 .934 r
.68716 .46047 .69256 .46274 .70448 .45905 .69893 .45288 Mtetra
.685 .77 .916 r
.69893 .45288 .70448 .45905 .71645 .45534 .7109 .44846 Mtetra
.664 .741 .907 r
.7109 .44846 .71645 .45534 .72848 .45162 .72296 .4447 Mtetra
.72296 .4447 .72848 .45162 .74056 .44788 .73507 .44094 Mtetra
.73507 .44094 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .7894 .43312 .78403 .4257 Mtetra
.664 .73 .899 r
.78403 .4257 .7894 .43312 .80182 .43023 .79641 .42185 Mtetra
.631 .69 .887 r
.79641 .42185 .80182 .43023 .81421 .42642 .80893 .41911 Mtetra
.657 .733 .905 r
.80893 .41911 .81421 .42642 .82662 .42215 .82144 .41545 Mtetra
.676 .76 .914 r
.82144 .41545 .82662 .42215 .83908 .41786 .83394 .41116 Mtetra
.678 .762 .914 r
.83394 .41116 .83908 .41786 .8516 .41369 .84648 .40677 Mtetra
.673 .754 .912 r
.84648 .40677 .8516 .41369 .86419 .40966 .8591 .40254 Mtetra
.668 .746 .909 r
.8591 .40254 .86419 .40966 .87685 .40569 .87178 .39846 Mtetra
.665 .743 .908 r
.87178 .39846 .87685 .40569 .88956 .40174 .88453 .39444 Mtetra
.664 .741 .907 r
.88453 .39444 .88956 .40174 .90232 .39779 .89734 .39045 Mtetra
.89734 .39045 .90232 .39779 .91515 .39382 .9102 .38644 Mtetra
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .55409 .3649 .54796 Mtetra
.3649 .54796 .37142 .55409 .38208 .55078 .37559 .54462 Mtetra
.37559 .54462 .38208 .55078 .39278 .54745 .38632 .54127 Mtetra
.663 .741 .908 r
.38632 .54127 .39278 .54745 .40353 .54411 .39709 .53794 Mtetra
.66 .741 .91 r
.39709 .53794 .40353 .54411 .41432 .5408 .4079 .53467 Mtetra
.654 .742 .914 r
.4079 .53467 .41432 .5408 .42515 .53756 .41876 .53157 Mtetra
.646 .745 .921 r
.41876 .53157 .42515 .53756 .43602 .53446 .42965 .52863 Mtetra
.649 .752 .925 r
.42965 .52863 .43602 .53446 .44693 .53152 .44059 .52561 Mtetra
.676 .757 .912 r
.44059 .52561 .44693 .53152 .45789 .52849 .4516 .52182 Mtetra
.693 .738 .886 r
.4516 .52182 .45789 .52849 .46891 .52485 .46266 .51739 Mtetra
.663 .708 .881 r
.46266 .51739 .46891 .52485 .47998 .52031 .47374 .51392 Mtetra
.664 .741 .907 r
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50344 Mtetra
.50726 .50344 .51342 .50991 .52465 .50641 .51853 .49992 Mtetra
.51853 .49992 .52465 .50641 .53593 .5029 .52984 .49638 Mtetra
.499 .679 .946 r
.52984 .49638 .53593 .5029 .54726 .49938 .54122 .49657 Mtetra
.101 .602 .898 r
.54122 .49657 .54726 .49938 .55864 .49584 .55268 .4985 Mtetra
.33 0 0 r
.55268 .4985 .55864 .49584 .57007 .49296 .56422 .49928 Mtetra
.398 0 .016 r
.56422 .49928 .57007 .49296 .58161 .49323 .57582 .49878 Mtetra
.307 0 0 r
.57582 .49878 .58161 .49323 .5932 .49279 .58746 .49716 Mtetra
.177 0 0 r
.58746 .49716 .5932 .49279 .60485 .49151 .59915 .49468 Mtetra
.022 0 0 r
.59915 .49468 .60485 .49151 .61654 .48939 .61088 .49165 Mtetra
0 0 0 r
.61088 .49165 .61654 .48939 .62827 .48649 .62266 .48825 Mtetra
.62266 .48825 .62827 .48649 .64002 .48286 .63448 .4846 Mtetra
.233 .739 .685 r
.63448 .4846 .64002 .48286 .6518 .47849 .64634 .48069 Mtetra
0 0 0 r
.64634 .48069 .6518 .47849 .66359 .47334 .65823 .47642 Mtetra
.65823 .47642 .66359 .47334 .67538 .46734 .67015 .47158 Mtetra
.67015 .47158 .67538 .46734 .68716 .46047 .68207 .46588 Mtetra
.68207 .46588 .68716 .46047 .69893 .45288 .69396 .45903 Mtetra
.69396 .45903 .69893 .45288 .7109 .44846 .70581 .45087 Mtetra
.61 .936 .727 r
.70581 .45087 .7109 .44846 .72296 .4447 .71762 .44153 Mtetra
.778 .904 .929 r
.71762 .44153 .72296 .4447 .73507 .44094 .72954 .43394 Mtetra
.664 .741 .907 r
.72954 .43394 .73507 .44094 .74723 .43715 .74174 .43012 Mtetra
.74174 .43012 .74723 .43715 .75945 .43335 .75399 .42629 Mtetra
.75399 .42629 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80893 .41911 .80353 .4108 Mtetra
.634 .696 .89 r
.80353 .4108 .80893 .41911 .82144 .41545 .81614 .40789 Mtetra
.653 .726 .903 r
.81614 .40789 .82144 .41545 .83394 .41116 .82875 .40433 Mtetra
.676 .759 .913 r
.82875 .40433 .83394 .41116 .84648 .40677 .84134 .39997 Mtetra
.679 .761 .914 r
.84134 .39997 .84648 .40677 .8591 .40254 .85397 .39551 Mtetra
.673 .753 .911 r
.85397 .39551 .8591 .40254 .87178 .39846 .86668 .39123 Mtetra
.668 .746 .909 r
.86668 .39123 .87178 .39846 .88453 .39444 .87946 .3871 Mtetra
.665 .742 .908 r
.87946 .3871 .88453 .39444 .89734 .39045 .89231 .38305 Mtetra
.664 .741 .907 r
.89231 .38305 .89734 .39045 .9102 .38644 .90521 .379 Mtetra
.90521 .379 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35834 .54178 Mtetra
.35834 .54178 .3649 .54796 .37559 .54462 .36905 .53842 Mtetra
.663 .741 .908 r
.36905 .53842 .37559 .54462 .38632 .54127 .37981 .53506 Mtetra
.66 .741 .909 r
.37981 .53506 .38632 .54127 .39709 .53794 .3906 .53177 Mtetra
.655 .741 .913 r
.3906 .53177 .39709 .53794 .4079 .53467 .40144 .52862 Mtetra
.646 .743 .92 r
.40144 .52862 .4079 .53467 .41876 .53157 .41231 .52568 Mtetra
.647 .75 .924 r
.41231 .52568 .41876 .53157 .42965 .52863 .42323 .52269 Mtetra
.675 .756 .912 r
.42323 .52269 .42965 .52863 .44059 .52561 .43422 .5189 Mtetra
.693 .738 .885 r
.43422 .5189 .44059 .52561 .4516 .52182 .44527 .51446 Mtetra
.663 .712 .884 r
.44527 .51446 .4516 .52182 .46266 .51739 .45634 .51098 Mtetra
.664 .741 .907 r
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.47861 .50398 .48487 .51044 .49604 .50695 .48981 .50046 Mtetra
.48981 .50046 .49604 .50695 .50726 .50344 .50106 .49693 Mtetra
.539 .697 .941 r
.50106 .49693 .50726 .50344 .51853 .49992 .51235 .49636 Mtetra
0 .498 .855 r
.51235 .49636 .51853 .49992 .52984 .49638 .5237 .49983 Mtetra
.445 0 0 r
.5237 .49983 .52984 .49638 .54122 .49657 .53514 .50179 Mtetra
.386 0 0 r
.53514 .50179 .54122 .49657 .55268 .4985 .54665 .50173 Mtetra
.135 0 0 r
.54665 .50173 .55268 .4985 .56422 .49928 .55822 .49988 Mtetra
.313 .804 .821 r
.55822 .49988 .56422 .49928 .57582 .49878 .56984 .49674 Mtetra
.603 .896 .988 r
.56984 .49674 .57582 .49878 .58746 .49716 .58149 .49287 Mtetra
.672 .83 .959 r
.58149 .49287 .58746 .49716 .59915 .49468 .59318 .4887 Mtetra
.678 .771 .92 r
.59318 .4887 .59915 .49468 .61088 .49165 .60492 .48455 Mtetra
.672 .734 .897 r
.60492 .48455 .61088 .49165 .62266 .48825 .61671 .48059 Mtetra
.662 .716 .888 r
.61671 .48059 .62266 .48825 .63448 .4846 .62856 .47691 Mtetra
.653 .713 .892 r
.62856 .47691 .63448 .4846 .64634 .48069 .64047 .47351 Mtetra
.647 .726 .906 r
.64047 .47351 .64634 .48069 .65823 .47642 .65244 .4703 Mtetra
.642 .759 .934 r
.65244 .4703 .65823 .47642 .67015 .47158 .66447 .46711 Mtetra
.637 .82 .971 r
.66447 .46711 .67015 .47158 .68207 .46588 .67654 .46362 Mtetra
.615 .9 .986 r
.67654 .46362 .68207 .46588 .69396 .45903 .68863 .4594 Mtetra
.528 .921 .878 r
.68863 .4594 .69396 .45903 .70581 .45087 .70069 .45386 Mtetra
.387 .809 .621 r
.70069 .45386 .70581 .45087 .71762 .44153 .71269 .4465 Mtetra
0 0 0 r
.71269 .4465 .71762 .44153 .72954 .43394 .72459 .43707 Mtetra
.63 .926 .664 r
.72459 .43707 .72954 .43394 .74174 .43012 .7364 .42607 Mtetra
.757 .872 .931 r
.7364 .42607 .74174 .43012 .75399 .42629 .74849 .41917 Mtetra
.664 .741 .907 r
.74849 .41917 .75399 .42629 .76629 .42244 .76083 .4153 Mtetra
.76083 .4153 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81614 .40789 .81073 .39961 Mtetra
.634 .7 .893 r
.81073 .39961 .81614 .40789 .82875 .40433 .82344 .39666 Mtetra
.653 .726 .902 r
.82344 .39666 .82875 .40433 .84134 .39997 .83614 .39303 Mtetra
.678 .759 .912 r
.83614 .39303 .84134 .39997 .85397 .39551 .84882 .38858 Mtetra
.679 .76 .913 r
.84882 .38858 .85397 .39551 .86668 .39123 .86155 .38407 Mtetra
.672 .751 .91 r
.86155 .38407 .86668 .39123 .87946 .3871 .87436 .37976 Mtetra
.667 .745 .908 r
.87436 .37976 .87946 .3871 .89231 .38305 .88724 .37561 Mtetra
.665 .742 .908 r
.88724 .37561 .89231 .38305 .90521 .379 .90018 .37151 Mtetra
.664 .741 .907 r
.90018 .37151 .90521 .379 .91818 .37495 .91319 .36742 Mtetra
.91319 .36742 .91818 .37495 .9312 .37088 .92625 .36332 Mtetra
.34102 .53893 .34766 .54513 .35834 .54178 .35172 .53556 Mtetra
.663 .741 .908 r
.35172 .53556 .35834 .54178 .36905 .53842 .36246 .53218 Mtetra
.661 .741 .909 r
.36246 .53218 .36905 .53842 .37981 .53506 .37324 .52884 Mtetra
.656 .741 .912 r
.37324 .52884 .37981 .53506 .3906 .53177 .38406 .52564 Mtetra
.647 .742 .918 r
.38406 .52564 .3906 .53177 .40144 .52862 .39492 .52266 Mtetra
.644 .747 .924 r
.39492 .52266 .40144 .52862 .41231 .52568 .40582 .51973 Mtetra
.67 .755 .915 r
.40582 .51973 .41231 .52568 .42323 .52269 .41679 .51609 Mtetra
.697 .743 .887 r
.41679 .51609 .42323 .52269 .43422 .5189 .42783 .51152 Mtetra
.663 .712 .884 r
.42783 .51152 .43422 .5189 .44527 .51446 .43888 .50803 Mtetra
.664 .741 .907 r
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.46112 .501 .46745 .50749 .47861 .50398 .4723 .49747 Mtetra
.4723 .49747 .47861 .50398 .48981 .50046 .48354 .49392 Mtetra
.263 .561 .933 r
.48354 .49392 .48981 .50046 .50106 .49693 .49475 .49729 Mtetra
.435 0 0 r
.49475 .49729 .50106 .49693 .51235 .49636 .50606 .50109 Mtetra
.44 0 0 r
.50606 .50109 .51235 .49636 .5237 .49983 .51747 .50229 Mtetra
.086 0 0 r
.51747 .50229 .5237 .49983 .53514 .50179 .52896 .50072 Mtetra
.538 .9 .969 r
.52896 .50072 .53514 .50179 .54665 .50173 .5405 .49704 Mtetra
.705 .819 .936 r
.5405 .49704 .54665 .50173 .55822 .49988 .55208 .49208 Mtetra
.709 .725 .862 r
.55208 .49208 .55822 .49988 .56984 .49674 .5637 .48661 Mtetra
.696 .671 .822 r
.5637 .48661 .56984 .49674 .58149 .49287 .57534 .48111 Mtetra
.681 .638 .8 r
.57534 .48111 .58149 .49287 .59318 .4887 .58704 .47589 Mtetra
.668 .618 .789 r
.58704 .47589 .59318 .4887 .60492 .48455 .59877 .47111 Mtetra
.656 .604 .785 r
.59877 .47111 .60492 .48455 .61671 .48059 .61057 .46684 Mtetra
.645 .595 .784 r
.61057 .46684 .61671 .48059 .62856 .47691 .62243 .46312 Mtetra
.634 .59 .787 r
.62243 .46312 .62856 .47691 .64047 .47351 .63435 .45996 Mtetra
.624 .588 .793 r
.63435 .45996 .64047 .47351 .65244 .4703 .64635 .45731 Mtetra
.616 .592 .804 r
.64635 .45731 .65244 .4703 .66447 .46711 .65843 .45511 Mtetra
.61 .605 .821 r
.65843 .45511 .66447 .46711 .67654 .46362 .67059 .4532 Mtetra
.61 .634 .85 r
.67059 .4532 .67654 .46362 .68863 .4594 .68281 .45127 Mtetra
.621 .694 .896 r
.68281 .45127 .68863 .4594 .70069 .45386 .69507 .44881 Mtetra
.65 .807 .958 r
.69507 .44881 .70069 .45386 .71269 .4465 .70733 .44508 Mtetra
.667 .945 .96 r
.70733 .44508 .71269 .4465 .72459 .43707 .71951 .43919 Mtetra
.582 .929 .741 r
.71951 .43919 .72459 .43707 .7364 .42607 .73155 .43046 Mtetra
.516 .838 .537 r
.73155 .43046 .7364 .42607 .74849 .41917 .74342 .41907 Mtetra
.825 .995 .855 r
.74342 .41907 .74849 .41917 .76083 .4153 .75533 .40809 Mtetra
.664 .741 .907 r
.75533 .40809 .76083 .4153 .77323 .4114 .76776 .40417 Mtetra
.76776 .40417 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82344 .39666 .81803 .38829 Mtetra
.63 .698 .894 r
.81803 .38829 .82344 .39666 .83614 .39303 .83085 .38541 Mtetra
.658 .732 .904 r
.83085 .38541 .83614 .39303 .84882 .38858 .84363 .38157 Mtetra
.68 .76 .912 r
.84363 .38157 .84882 .38858 .86155 .38407 .8564 .37698 Mtetra
.678 .758 .912 r
.8564 .37698 .86155 .38407 .87436 .37976 .86923 .37245 Mtetra
.67 .749 .909 r
.86923 .37245 .87436 .37976 .88724 .37561 .88213 .36814 Mtetra
.666 .744 .908 r
.88213 .36814 .88724 .37561 .90018 .37151 .89512 .36397 Mtetra
.664 .741 .907 r
.89512 .36397 .90018 .37151 .91319 .36742 .90816 .35983 Mtetra
.90816 .35983 .91319 .36742 .92625 .36332 .92126 .35569 Mtetra
.33433 .53269 .34102 .53893 .35172 .53556 .34506 .52929 Mtetra
.662 .741 .908 r
.34506 .52929 .35172 .53556 .36246 .53218 .35582 .52591 Mtetra
.659 .741 .91 r
.35582 .52591 .36246 .53218 .37324 .52884 .36663 .52264 Mtetra
.65 .741 .916 r
.36663 .52264 .37324 .52884 .38406 .52564 .37747 .51958 Mtetra
.643 .745 .923 r
.37747 .51958 .38406 .52564 .39492 .52266 .38834 .51669 Mtetra
.66 .753 .919 r
.38834 .51669 .39492 .52266 .40582 .51973 .39929 .51331 Mtetra
.702 .75 .889 r
.39929 .51331 .40582 .51973 .41679 .51609 .41032 .50856 Mtetra
.663 .709 .882 r
.41032 .50856 .41679 .51609 .42783 .51152 .42136 .50506 Mtetra
.664 .741 .907 r
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.44356 .49802 .44998 .50452 .46112 .501 .45473 .49447 Mtetra
.45473 .49447 .46112 .501 .4723 .49747 .46595 .49091 Mtetra
.03 .417 .862 r
.46595 .49091 .4723 .49747 .48354 .49392 .47708 .4966 Mtetra
.527 0 0 r
.47708 .4966 .48354 .49392 .49475 .49729 .48834 .50046 Mtetra
.317 0 0 r
.48834 .50046 .49475 .49729 .50606 .50109 .49972 .50078 Mtetra
.418 .858 .918 r
.49972 .50078 .50606 .50109 .51747 .50229 .5112 .49771 Mtetra
.719 .825 .931 r
.5112 .49771 .51747 .50229 .52896 .50072 .52272 .49233 Mtetra
.727 .716 .84 r
.52272 .49233 .52896 .50072 .5405 .49704 .53428 .48582 Mtetra
.711 .658 .796 r
.53428 .48582 .5405 .49704 .55208 .49208 .54587 .47903 Mtetra
.696 .627 .775 r
.54587 .47903 .55208 .49208 .5637 .48661 .55748 .47247 Mtetra
.683 .608 .766 r
.55748 .47247 .5637 .48661 .57534 .48111 .56913 .46639 Mtetra
.671 .597 .764 r
.56913 .46639 .57534 .48111 .58704 .47589 .58083 .46088 Mtetra
.661 .589 .764 r
.58083 .46088 .58704 .47589 .59877 .47111 .59257 .45596 Mtetra
.651 .582 .765 r
.59257 .45596 .59877 .47111 .61057 .46684 .60437 .45163 Mtetra
.641 .577 .767 r
.60437 .45163 .61057 .46684 .62243 .46312 .61623 .44788 Mtetra
.63 .572 .77 r
.61623 .44788 .62243 .46312 .63435 .45996 .62816 .4447 Mtetra
.619 .566 .773 r
.62816 .4447 .63435 .45996 .64635 .45731 .64016 .44212 Mtetra
.608 .561 .776 r
.64016 .44212 .64635 .45731 .65843 .45511 .65225 .44013 Mtetra
.597 .558 .781 r
.65225 .44013 .65843 .45511 .67059 .4532 .66444 .43873 Mtetra
.586 .559 .79 r
.66444 .43873 .67059 .4532 .68281 .45127 .67671 .43782 Mtetra
.58 .569 .806 r
.67671 .43782 .68281 .45127 .69507 .44881 .68908 .43716 Mtetra
.583 .6 .835 r
.68908 .43716 .69507 .44881 .70733 .44508 .7015 .43623 Mtetra
.609 .673 .885 r
.7015 .43623 .70733 .44508 .71951 .43919 .71394 .43414 Mtetra
.674 .818 .952 r
.71394 .43414 .71951 .43919 .73155 .43046 .7263 .42972 Mtetra
.732 .978 .919 r
.7263 .42972 .73155 .43046 .74342 .41907 .73848 .42183 Mtetra
.678 .95 .694 r
.73848 .42183 .74342 .41907 .75533 .40809 .75044 .4103 Mtetra
.795 .985 .725 r
.75044 .4103 .75533 .40809 .76776 .40417 .76225 .39687 Mtetra
.664 .741 .907 r
.76225 .39687 .76776 .40417 .78024 .40022 .77477 .3929 Mtetra
.77477 .3929 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83085 .38541 .82542 .37682 Mtetra
.626 .692 .892 r
.82542 .37682 .83085 .38541 .84363 .38157 .83835 .37407 Mtetra
.667 .742 .906 r
.83835 .37407 .84363 .38157 .8564 .37698 .8512 .36989 Mtetra
.681 .761 .911 r
.8512 .36989 .8564 .37698 .86923 .37245 .86406 .3652 Mtetra
.676 .755 .91 r
.86406 .3652 .86923 .37245 .88213 .36814 .87699 .36068 Mtetra
.669 .746 .909 r
.87699 .36068 .88213 .36814 .89512 .36397 .89001 .35638 Mtetra
.665 .743 .908 r
.89001 .35638 .89512 .36397 .90816 .35983 .90309 .35218 Mtetra
.664 .741 .907 r
.90309 .35218 .90816 .35983 .92126 .35569 .91624 .348 Mtetra
.663 .741 .908 r
.32759 .5264 .33433 .53269 .34506 .52929 .33834 .52298 Mtetra
.661 .741 .909 r
.33834 .52298 .34506 .52929 .35582 .52591 .34913 .51964 Mtetra
.654 .74 .913 r
.34913 .51964 .35582 .52591 .36663 .52264 .35996 .51647 Mtetra
.643 .742 .921 r
.35996 .51647 .36663 .52264 .37747 .51958 .37082 .51355 Mtetra
.649 .749 .922 r
.37082 .51355 .37747 .51958 .38834 .51669 .38173 .51046 Mtetra
.696 .754 .897 r
.38173 .51046 .38834 .51669 .39929 .51331 .39275 .50595 Mtetra
.673 .717 .881 r
.39275 .50595 .39929 .51331 .41032 .50856 .40378 .50209 Mtetra
.664 .741 .907 r
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.42595 .49502 .43244 .50155 .44356 .49802 .4371 .49146 Mtetra
.4371 .49146 .44356 .49802 .45473 .49447 .4483 .48789 Mtetra
0 .357 .822 r
.4483 .48789 .45473 .49447 .46595 .49091 .45935 .49432 Mtetra
.554 .04 0 r
.45935 .49432 .46595 .49091 .47708 .4966 .47055 .49845 Mtetra
.169 0 0 r
.47055 .49845 .47708 .4966 .48834 .50046 .4819 .49823 Mtetra
.638 .896 .985 r
.4819 .49823 .48834 .50046 .49972 .50078 .49337 .49401 Mtetra
.743 .759 .866 r
.49337 .49401 .49972 .50078 .5112 .49771 .50489 .48731 Mtetra
.732 .679 .799 r
.50489 .48731 .5112 .49771 .52272 .49233 .51645 .47959 Mtetra
.715 .639 .772 r
.51645 .47959 .52272 .49233 .53428 .48582 .52802 .47185 Mtetra
.701 .619 .762 r
.52802 .47185 .53428 .48582 .54587 .47903 .53962 .46455 Mtetra
.689 .608 .76 r
.53962 .46455 .54587 .47903 .55748 .47247 .55125 .45792 Mtetra
.679 .602 .763 r
.55125 .45792 .55748 .47247 .56913 .46639 .56291 .45194 Mtetra
.653 .591 .773 r
.56291 .45194 .56913 .46639 .58083 .46088 .57463 .44759 Mtetra
.647 .602 .79 r
.57463 .44759 .58083 .46088 .59257 .45596 .5864 .44384 Mtetra
.651 .621 .807 r
.5864 .44384 .59257 .45596 .60437 .45163 .59823 .44006 Mtetra
.653 .631 .816 r
.59823 .44006 .60437 .45163 .61623 .44788 .61011 .43627 Mtetra
.61011 .43627 .61623 .44788 .62816 .4447 .62204 .43247 Mtetra
.651 .621 .807 r
.62204 .43247 .62816 .4447 .64016 .44212 .63402 .42865 Mtetra
.635 .596 .794 r
.63402 .42865 .64016 .44212 .65225 .44013 .64607 .42543 Mtetra
.6 .563 .785 r
.64607 .42543 .65225 .44013 .66444 .43873 .65825 .42384 Mtetra
.585 .554 .785 r
.65825 .42384 .66444 .43873 .67671 .43782 .67052 .42294 Mtetra
.571 .546 .788 r
.67052 .42294 .67671 .43782 .68908 .43716 .68291 .4227 Mtetra
.559 .546 .796 r
.68291 .4227 .68908 .43716 .7015 .43623 .69541 .42295 Mtetra
.556 .561 .814 r
.69541 .42295 .7015 .43623 .71394 .43414 .70799 .42318 Mtetra
.575 .612 .851 r
.70799 .42318 .71394 .43414 .7263 .42972 .72059 .42239 Mtetra
.643 .732 .914 r
.72059 .42239 .7263 .42972 .73848 .42183 .73311 .41907 Mtetra
.759 .926 .944 r
.73311 .41907 .73848 .42183 .75044 .4103 .74542 .41167 Mtetra
.786 .995 .785 r
.74542 .41167 .75044 .4103 .76225 .39687 .75743 .39979 Mtetra
.773 .968 .673 r
.75743 .39979 .76225 .39687 .77477 .3929 .76925 .38551 Mtetra
.664 .741 .907 r
.76925 .38551 .77477 .3929 .78735 .38891 .78187 .38149 Mtetra
.78187 .38149 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.653 .736 .911 r
.82006 .36931 .82542 .37682 .83835 .37407 .83294 .36557 Mtetra
.633 .701 .895 r
.83294 .36557 .83835 .37407 .8512 .36989 .84594 .36251 Mtetra
.676 .752 .908 r
.84594 .36251 .8512 .36989 .86406 .3652 .85886 .35797 Mtetra
.681 .759 .911 r
.85886 .35797 .86406 .3652 .87699 .36068 .87182 .35324 Mtetra
.673 .751 .909 r
.87182 .35324 .87699 .36068 .89001 .35638 .88486 .34877 Mtetra
.667 .744 .908 r
.88486 .34877 .89001 .35638 .90309 .35218 .89798 .34448 Mtetra
.664 .742 .908 r
.89798 .34448 .90309 .35218 .91624 .348 .91117 .34026 Mtetra
.663 .741 .908 r
.3208 .52007 .32759 .5264 .33834 .52298 .33158 .51665 Mtetra
.657 .74 .911 r
.33158 .51665 .33834 .52298 .34913 .51964 .34239 .51337 Mtetra
.647 .74 .917 r
.34239 .51337 .34913 .51964 .35996 .51647 .35323 .51034 Mtetra
.642 .744 .923 r
.35323 .51034 .35996 .51647 .37082 .51355 .36412 .50743 Mtetra
.674 .753 .911 r
.36412 .50743 .37082 .51355 .38173 .51046 .37509 .50362 Mtetra
.693 .737 .885 r
.37509 .50362 .38173 .51046 .39275 .50595 .38613 .4991 Mtetra
.664 .73 .899 r
.38613 .4991 .39275 .50595 .40378 .50209 .39718 .49556 Mtetra
.664 .741 .907 r
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.40827 .49201 .41484 .49856 .42595 .49502 .41941 .48844 Mtetra
.41941 .48844 .42595 .49502 .4371 .49146 .43059 .48485 Mtetra
.014 .409 .856 r
.43059 .48485 .4371 .49146 .4483 .48789 .44158 .49053 Mtetra
.574 .05 0 r
.44158 .49053 .4483 .48789 .45935 .49432 .45271 .49541 Mtetra
.103 0 0 r
.45271 .49541 .45935 .49432 .47055 .49845 .46403 .49527 Mtetra
.691 .872 .967 r
.46403 .49527 .47055 .49845 .4819 .49823 .47549 .49045 Mtetra
.752 .736 .837 r
.47549 .49045 .4819 .49823 .49337 .49401 .48702 .48282 Mtetra
.738 .669 .783 r
.48702 .48282 .49337 .49401 .50489 .48731 .49858 .47419 Mtetra
.722 .638 .764 r
.49858 .47419 .50489 .48731 .51645 .47959 .51016 .46572 Mtetra
.708 .624 .76 r
.51016 .46572 .51645 .47959 .52802 .47185 .52174 .45792 Mtetra
.682 .611 .77 r
.52174 .45792 .52802 .47185 .53962 .46455 .53336 .45191 Mtetra
.648 .612 .799 r
.53336 .45191 .53962 .46455 .55125 .45792 .54502 .44817 Mtetra
.658 .666 .847 r
.54502 .44817 .55125 .45792 .56291 .45194 .55673 .44441 Mtetra
.664 .723 .893 r
.55673 .44441 .56291 .45194 .57463 .44759 .56849 .44064 Mtetra
.664 .741 .907 r
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64607 .42543 .64011 .41768 Mtetra
.664 .723 .893 r
.64011 .41768 .64607 .42543 .65825 .42384 .65223 .4138 Mtetra
.658 .666 .847 r
.65223 .4138 .65825 .42384 .67052 .42294 .6644 .4099 Mtetra
.599 .587 .81 r
.6644 .4099 .67052 .42294 .68291 .4227 .67673 .4083 Mtetra
.558 .546 .798 r
.67673 .4083 .68291 .4227 .69541 .42295 .68923 .40852 Mtetra
.541 .537 .8 r
.68923 .40852 .69541 .42295 .70799 .42318 .70185 .40944 Mtetra
.534 .544 .811 r
.70185 .40944 .70799 .42318 .72059 .42239 .71457 .41054 Mtetra
.552 .585 .841 r
.71457 .41054 .72059 .42239 .73311 .41907 .72733 .41064 Mtetra
.626 .696 .895 r
.72733 .41064 .73311 .41907 .74542 .41167 .73999 .40788 Mtetra
.769 .893 .932 r
.73999 .40788 .74542 .41167 .75743 .39979 .75237 .40032 Mtetra
.844 .999 .809 r
.75237 .40032 .75743 .39979 .76925 .38551 .7644 .38759 Mtetra
.795 .985 .725 r
.7644 .38759 .76925 .38551 .78187 .38149 .77635 .37401 Mtetra
.664 .741 .907 r
.77635 .37401 .78187 .38149 .79454 .37745 .78906 .36994 Mtetra
.78906 .36994 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .83294 .36557 .82754 .3576 Mtetra
.633 .717 .908 r
.82754 .3576 .83294 .36557 .84594 .36251 .84058 .35448 Mtetra
.655 .726 .901 r
.84058 .35448 .84594 .36251 .85886 .35797 .85362 .35063 Mtetra
.682 .758 .909 r
.85362 .35063 .85886 .35797 .87182 .35324 .86661 .34583 Mtetra
.678 .756 .91 r
.86661 .34583 .87182 .35324 .88486 .34877 .87968 .34115 Mtetra
.67 .747 .908 r
.87968 .34115 .88486 .34877 .89798 .34448 .89283 .33674 Mtetra
.665 .742 .908 r
.89283 .33674 .89798 .34448 .91117 .34026 .90606 .33245 Mtetra
.661 .741 .909 r
.31396 .51371 .3208 .52007 .33158 .51665 .32476 .5103 Mtetra
.653 .74 .913 r
.32476 .5103 .33158 .51665 .34239 .51337 .33559 .50712 Mtetra
.642 .741 .921 r
.33559 .50712 .34239 .51337 .35323 .51034 .34645 .5042 Mtetra
.652 .748 .92 r
.34645 .5042 .35323 .51034 .36412 .50743 .35738 .50099 Mtetra
.705 .752 .889 r
.35738 .50099 .36412 .50743 .37509 .50362 .36843 .49611 Mtetra
.663 .712 .885 r
.36843 .49611 .37509 .50362 .38613 .4991 .37946 .49256 Mtetra
.664 .741 .907 r
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.39053 .48899 .39718 .49556 .40827 .49201 .40165 .4854 Mtetra
.40165 .4854 .40827 .49201 .41941 .48844 .41281 .48181 Mtetra
.246 .555 .932 r
.41281 .48181 .41941 .48844 .43059 .48485 .42381 .48514 Mtetra
.588 .028 0 r
.42381 .48514 .43059 .48485 .44158 .49053 .43483 .49132 Mtetra
.181 0 0 r
.43483 .49132 .44158 .49053 .45271 .49541 .44609 .49211 Mtetra
.688 .867 .966 r
.44609 .49211 .45271 .49541 .46403 .49527 .45753 .48737 Mtetra
.76 .735 .83 r
.45753 .48737 .46403 .49527 .47549 .49045 .46908 .47921 Mtetra
.747 .672 .777 r
.46908 .47921 .47549 .49045 .48702 .48282 .48066 .46989 Mtetra
.731 .644 .762 r
.48066 .46989 .48702 .48282 .49858 .47419 .49224 .4608 Mtetra
.717 .633 .763 r
.49224 .4608 .49858 .47419 .51016 .46572 .50384 .45255 Mtetra
.648 .604 .791 r
.50384 .45255 .51016 .46572 .52174 .45792 .51543 .44874 Mtetra
.66 .68 .858 r
.51543 .44874 .52174 .45792 .53336 .45191 .52707 .44499 Mtetra
.664 .741 .907 r
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67673 .4083 .67075 .3987 Mtetra
.658 .679 .858 r
.67075 .3987 .67673 .4083 .68923 .40852 .68307 .3948 Mtetra
.544 .55 .811 r
.68307 .3948 .68923 .40852 .70185 .40944 .69568 .39543 Mtetra
.523 .534 .809 r
.69568 .39543 .70185 .40944 .71457 .41054 .70843 .39692 Mtetra
.513 .536 .816 r
.70843 .39692 .71457 .41054 .72733 .41064 .7213 .39867 Mtetra
.537 .576 .842 r
.7213 .39867 .72733 .41064 .73999 .40788 .73419 .39925 Mtetra
.629 .695 .892 r
.73419 .39925 .73999 .40788 .75237 .40032 .74694 .39634 Mtetra
.795 .892 .914 r
.74694 .39634 .75237 .40032 .7644 .38759 .75934 .38776 Mtetra
.882 .991 .798 r
.75934 .38776 .7644 .38759 .77635 .37401 .77133 .37362 Mtetra
.825 .995 .855 r
.77133 .37362 .77635 .37401 .78906 .36994 .78353 .36236 Mtetra
.664 .741 .907 r
.78353 .36236 .78906 .36994 .80183 .36584 .79634 .35824 Mtetra
.79634 .35824 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84058 .35448 .83511 .34574 Mtetra
.623 .694 .895 r
.83511 .34574 .84058 .35448 .85362 .35063 .8483 .34294 Mtetra
.673 .746 .906 r
.8483 .34294 .85362 .35063 .86661 .34583 .86137 .33839 Mtetra
.682 .758 .909 r
.86137 .33839 .86661 .34583 .87968 .34115 .87446 .33354 Mtetra
.673 .751 .909 r
.87446 .33354 .87968 .34115 .89283 .33674 .88764 .32895 Mtetra
.666 .744 .908 r
.88764 .32895 .89283 .33674 .90606 .33245 .90091 .3246 Mtetra
.66 .741 .91 r
.30706 .50732 .31396 .51371 .32476 .5103 .31789 .50394 Mtetra
.648 .74 .917 r
.31789 .50394 .32476 .5103 .33559 .50712 .32874 .50087 Mtetra
.641 .742 .922 r
.32874 .50087 .33559 .50712 .34645 .5042 .33962 .49795 Mtetra
.676 .752 .908 r
.33962 .49795 .34645 .5042 .35738 .50099 .35061 .49403 Mtetra
.691 .735 .885 r
.35061 .49403 .35738 .50099 .36843 .49611 .36167 .48954 Mtetra
.664 .741 .907 r
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.38383 .48236 .39053 .48899 .40165 .4854 .39498 .47875 Mtetra
.535 .697 .944 r
.39498 .47875 .40165 .4854 .41281 .48181 .40606 .47812 Mtetra
.5 0 0 r
.40606 .47812 .41281 .48181 .42381 .48514 .41695 .48585 Mtetra
.368 0 0 r
.41695 .48585 .42381 .48514 .43483 .49132 .4281 .48854 Mtetra
.627 .873 .988 r
.4281 .48854 .43483 .49132 .44609 .49211 .43951 .48478 Mtetra
.765 .749 .839 r
.43951 .48478 .44609 .49211 .45753 .48737 .45106 .47661 Mtetra
.758 .683 .779 r
.45106 .47661 .45753 .48737 .46908 .47921 .46266 .46676 Mtetra
.742 .655 .763 r
.46266 .46676 .46908 .47921 .48066 .46989 .47427 .45707 Mtetra
.715 .639 .772 r
.47427 .45707 .48066 .46989 .49224 .4608 .48586 .44932 Mtetra
.652 .632 .817 r
.48586 .44932 .49224 .4608 .50384 .45255 .49744 .44557 Mtetra
.664 .739 .906 r
.49744 .44557 .50384 .45255 .51543 .44874 .50906 .44181 Mtetra
.664 .741 .907 r
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68307 .3948 .67718 .38737 Mtetra
.664 .739 .906 r
.67718 .38737 .68307 .3948 .69568 .39543 .68958 .38335 Mtetra
.551 .582 .838 r
.68958 .38335 .69568 .39543 .70843 .39692 .70227 .3834 Mtetra
.502 .532 .82 r
.70227 .3834 .70843 .39692 .7213 .39867 .71516 .38546 Mtetra
.494 .533 .825 r
.71516 .38546 .7213 .39867 .73419 .39925 .72817 .3877 Mtetra
.534 .584 .852 r
.72817 .3877 .73419 .39925 .74694 .39634 .74117 .38823 Mtetra
.659 .724 .897 r
.74117 .38823 .74694 .39634 .75934 .38776 .75394 .38425 Mtetra
.84 .912 .885 r
.75394 .38425 .75934 .38776 .77133 .37362 .76628 .37364 Mtetra
.91 .98 .775 r
.76628 .37364 .77133 .37362 .78353 .36236 .7782 .35781 Mtetra
.757 .872 .931 r
.7782 .35781 .78353 .36236 .79634 .35824 .7908 .35057 Mtetra
.664 .741 .907 r
.7908 .35057 .79634 .35824 .80921 .35409 .80371 .34639 Mtetra
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.634 .728 .916 r
.8297 .33797 .83511 .34574 .8483 .34294 .84288 .3347 Mtetra
.653 .724 .901 r
.84288 .3347 .8483 .34294 .86137 .33839 .85607 .33083 Mtetra
.683 .757 .907 r
.85607 .33083 .86137 .33839 .87446 .33354 .8692 .32591 Mtetra
.678 .754 .909 r
.8692 .32591 .87446 .33354 .88764 .32895 .88241 .32115 Mtetra
.668 .746 .909 r
.88241 .32115 .88764 .32895 .90091 .3246 .89572 .3167 Mtetra
.657 .742 .912 r
.30011 .50092 .30706 .50732 .31789 .50394 .31096 .49757 Mtetra
.643 .74 .919 r
.31096 .49757 .31789 .50394 .32874 .50087 .32183 .49459 Mtetra
.648 .745 .92 r
.32183 .49459 .32874 .50087 .33962 .49795 .33275 .49146 Mtetra
.705 .753 .889 r
.33275 .49146 .33962 .49795 .35061 .49403 .34383 .48651 Mtetra
.663 .714 .886 r
.34383 .48651 .35061 .49403 .36167 .48954 .35486 .48292 Mtetra
.664 .741 .907 r
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.36595 .47931 .37273 .48596 .38383 .48236 .37708 .47568 Mtetra
.37708 .47568 .38383 .48236 .39498 .47875 .38826 .47205 Mtetra
0 .34 .808 r
.38826 .47205 .39498 .47875 .40606 .47812 .3991 .47847 Mtetra
.551 0 0 r
.3991 .47847 .40606 .47812 .41695 .48585 .41008 .48392 Mtetra
.407 .817 .977 r
.41008 .48392 .41695 .48585 .4281 .48854 .4214 .48232 Mtetra
.761 .778 .867 r
.4214 .48232 .4281 .48854 .43951 .48478 .43294 .47491 Mtetra
.768 .7 .787 r
.43294 .47491 .43951 .48478 .45106 .47661 .44457 .46482 Mtetra
.755 .668 .766 r
.44457 .46482 .45106 .47661 .46266 .46676 .45621 .4545 Mtetra
.727 .652 .775 r
.45621 .4545 .46266 .46676 .47427 .45707 .46782 .44615 Mtetra
.654 .643 .827 r
.46782 .44615 .47427 .45707 .48586 .44932 .47938 .44239 Mtetra
.664 .741 .907 r
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70227 .3834 .69618 .37182 Mtetra
.53 .581 .851 r
.69618 .37182 .70227 .3834 .71516 .38546 .70901 .37244 Mtetra
.478 .528 .83 r
.70901 .37244 .71516 .38546 .72817 .3877 .72205 .37507 Mtetra
.481 .537 .838 r
.72205 .37507 .72817 .3877 .74117 .38823 .73519 .37751 Mtetra
.553 .613 .867 r
.73519 .37751 .74117 .38823 .75394 .38425 .74825 .37721 Mtetra
.723 .78 .898 r
.74825 .37721 .75394 .38425 .76628 .37364 .76096 .37095 Mtetra
.89 .933 .839 r
.76096 .37095 .76628 .37364 .7782 .35781 .77314 .35742 Mtetra
.894 .984 .801 r
.77314 .35742 .7782 .35781 .7908 .35057 .78522 .34284 Mtetra
.664 .741 .907 r
.78522 .34284 .7908 .35057 .80371 .34639 .79817 .33862 Mtetra
.79817 .33862 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84288 .3347 .83737 .32586 Mtetra
.622 .696 .897 r
.83737 .32586 .84288 .3347 .85607 .33083 .8507 .323 Mtetra
.677 .749 .905 r
.8507 .323 .85607 .33083 .8692 .32591 .8639 .31825 Mtetra
.681 .756 .908 r
.8639 .31825 .8692 .32591 .88241 .32115 .87715 .31332 Mtetra
.67 .748 .909 r
.87715 .31332 .88241 .32115 .89572 .3167 .89049 .30877 Mtetra
.655 .742 .914 r
.29311 .4945 .30011 .50092 .31096 .49757 .30398 .49118 Mtetra
.641 .74 .921 r
.30398 .49118 .31096 .49757 .32183 .49459 .31487 .48824 Mtetra
.664 .748 .913 r
.31487 .48824 .32183 .49459 .33275 .49146 .32585 .48464 Mtetra
.699 .743 .886 r
.32585 .48464 .33275 .49146 .34383 .48651 .33694 .47986 Mtetra
.664 .741 .907 r
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.35912 .47261 .36595 .47931 .37708 .47568 .37028 .46896 Mtetra
.49 .679 .95 r
.37028 .46896 .37708 .47568 .38826 .47205 .38132 .46906 Mtetra
.585 .015 0 r
.38132 .46906 .38826 .47205 .3991 .47847 .3921 .47727 Mtetra
0 .473 .699 r
.3921 .47727 .3991 .47847 .41008 .48392 .40325 .47917 Mtetra
.719 .82 .928 r
.40325 .47917 .41008 .48392 .4214 .48232 .41473 .47374 Mtetra
.776 .726 .806 r
.41473 .47374 .4214 .48232 .43294 .47491 .42637 .46398 Mtetra
.768 .685 .771 r
.42637 .46398 .43294 .47491 .44457 .46482 .43805 .45313 Mtetra
.753 .67 .769 r
.43805 .45313 .44457 .46482 .45621 .4545 .44971 .44303 Mtetra
.653 .634 .818 r
.44971 .44303 .45621 .4545 .46782 .44615 .46126 .43919 Mtetra
.664 .741 .907 r
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.662 .74 .908 r
.69028 .36426 .69618 .37182 .70901 .37244 .70287 .36021 Mtetra
.477 .542 .845 r
.70287 .36021 .70901 .37244 .72205 .37507 .71591 .36255 Mtetra
.454 .525 .841 r
.71591 .36255 .72205 .37507 .73519 .37751 .7291 .36569 Mtetra
.483 .555 .854 r
.7291 .36569 .73519 .37751 .74825 .37721 .74234 .36773 Mtetra
.61 .672 .884 r
.74234 .36773 .74825 .37721 .76096 .37095 .75537 .36534 Mtetra
.812 .847 .875 r
.75537 .36534 .76096 .37095 .77314 .35742 .7679 .35541 Mtetra
.926 .938 .79 r
.7679 .35541 .77314 .35742 .78522 .34284 .77991 .33893 Mtetra
.778 .904 .929 r
.77991 .33893 .78522 .34284 .79817 .33862 .79259 .33079 Mtetra
.664 .741 .907 r
.79259 .33079 .79817 .33862 .81118 .33439 .80563 .32652 Mtetra
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.626 .724 .918 r
.83191 .31793 .83737 .32586 .8507 .323 .84526 .31482 Mtetra
.663 .735 .903 r
.84526 .31482 .8507 .323 .8639 .31825 .85856 .31048 Mtetra
.683 .756 .907 r
.85856 .31048 .8639 .31825 .87715 .31332 .87184 .30546 Mtetra
.671 .749 .909 r
.87184 .30546 .87715 .31332 .89049 .30877 .88522 .30081 Mtetra
.653 .742 .915 r
.28604 .48805 .29311 .4945 .30398 .49118 .29694 .48478 Mtetra
.643 .742 .921 r
.29694 .48478 .30398 .49118 .31487 .48824 .30786 .48176 Mtetra
.685 .75 .901 r
.30786 .48176 .31487 .48824 .32585 .48464 .3189 .47749 Mtetra
.684 .732 .887 r
.3189 .47749 .32585 .48464 .33694 .47986 .33 .47317 Mtetra
.664 .741 .907 r
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
.35223 .46586 .35912 .47261 .37028 .46896 .36342 .46218 Mtetra
0 .397 .848 r
.36342 .46218 .37028 .46896 .38132 .46906 .37423 .46779 Mtetra
.539 0 0 r
.37423 .46779 .38132 .46906 .3921 .47727 .38512 .47401 Mtetra
.5 .816 1 r
.38512 .47401 .3921 .47727 .40325 .47917 .39644 .47226 Mtetra
.77 .762 .846 r
.39644 .47226 .40325 .47917 .41473 .47374 .40805 .46398 Mtetra
.78 .706 .782 r
.40805 .46398 .41473 .47374 .42637 .46398 .41977 .45298 Mtetra
.768 .684 .771 r
.41977 .45298 .42637 .46398 .43805 .45313 .43148 .44207 Mtetra
.7 .66 .808 r
.43148 .44207 .43805 .45313 .44971 .44303 .44307 .43598 Mtetra
.664 .739 .906 r
.44307 .43598 .44971 .44303 .46126 .43919 .45464 .43218 Mtetra
.664 .741 .907 r
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36021 .69695 .35249 Mtetra
.583 .706 .927 r
.69695 .35249 .70287 .36021 .71591 .36255 .70978 .35067 Mtetra
.443 .532 .853 r
.70978 .35067 .71591 .36255 .7291 .36569 .72298 .35379 Mtetra
.439 .53 .854 r
.72298 .35379 .7291 .36569 .74234 .36773 .73632 .35704 Mtetra
.523 .603 .874 r
.73632 .35704 .74234 .36773 .75537 .36534 .74958 .35751 Mtetra
.717 .76 .887 r
.74958 .35751 .75537 .36534 .7679 .35541 .76243 .35127 Mtetra
.892 .892 .822 r
.76243 .35127 .7679 .35541 .77991 .33893 .77468 .33679 Mtetra
.894 .953 .833 r
.77468 .33679 .77991 .33893 .79259 .33079 .78695 .3229 Mtetra
.664 .741 .907 r
.78695 .3229 .79259 .33079 .80563 .32652 .80004 .31859 Mtetra
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.642 .732 .914 r
.8264 .30992 .83191 .31793 .84526 .31482 .83975 .30627 Mtetra
.644 .718 .902 r
.83975 .30627 .84526 .31482 .85856 .31048 .85315 .30257 Mtetra
.681 .753 .905 r
.85315 .30257 .85856 .31048 .87184 .30546 .86649 .29756 Mtetra
.673 .751 .909 r
.86649 .29756 .87184 .30546 .88522 .30081 .87991 .29281 Mtetra
.652 .743 .916 r
.27892 .4816 .28604 .48805 .29694 .48478 .28984 .4783 Mtetra
.648 .743 .919 r
.28984 .4783 .29694 .48478 .30786 .48176 .3008 .47512 Mtetra
.706 .752 .888 r
.3008 .47512 .30786 .48176 .3189 .47749 .31192 .47008 Mtetra
.663 .721 .892 r
.31192 .47008 .3189 .47749 .33 .47317 .323 .46642 Mtetra
.664 .741 .907 r
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.33412 .46274 .34109 .46952 .35223 .46586 .34529 .45905 Mtetra
.64 .734 .917 r
.34529 .45905 .35223 .46586 .36342 .46218 .35647 .45603 Mtetra
0 .057 .537 r
.35647 .45603 .36342 .46218 .37423 .46779 .36712 .46535 Mtetra
0 .383 .69 r
.36712 .46535 .37423 .46779 .38512 .47401 .37815 .46891 Mtetra
.7 .807 .931 r
.37815 .46891 .38512 .47401 .39644 .47226 .38963 .46403 Mtetra
.784 .735 .808 r
.38963 .46403 .39644 .47226 .40805 .46398 .40134 .4539 Mtetra
.783 .703 .775 r
.40134 .4539 .40805 .46398 .41977 .45298 .41311 .44239 Mtetra
.757 .688 .786 r
.41311 .44239 .41977 .45298 .43148 .44207 .42482 .43276 Mtetra
.659 .68 .859 r
.42482 .43276 .43148 .44207 .44307 .43598 .43637 .42894 Mtetra
.664 .741 .907 r
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70978 .35067 .70371 .34057 Mtetra
.467 .586 .889 r
.70371 .34057 .70978 .35067 .72298 .35379 .71686 .34231 Mtetra
.412 .525 .862 r
.71686 .34231 .72298 .35379 .73632 .35704 .73023 .346 Mtetra
.459 .562 .872 r
.73023 .346 .73632 .35704 .74958 .35751 .74364 .3483 Mtetra
.628 .691 .89 r
.74364 .3483 .74958 .35751 .76243 .35127 .75677 .34522 Mtetra
.839 .84 .846 r
.75677 .34522 .76243 .35127 .77468 .33679 .7693 .33342 Mtetra
.93 .902 .776 r
.7693 .33342 .77468 .33679 .78695 .3229 .78133 .31564 Mtetra
.685 .77 .916 r
.78133 .31564 .78695 .3229 .80004 .31859 .79441 .31059 Mtetra
.664 .741 .907 r
.79441 .31059 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83975 .30627 .83417 .29745 Mtetra
.621 .702 .903 r
.83417 .29745 .83975 .30627 .85315 .30257 .84769 .29448 Mtetra
.677 .748 .904 r
.84769 .29448 .85315 .30257 .86649 .29756 .86109 .28957 Mtetra
.674 .751 .909 r
.86109 .28957 .86649 .29756 .87991 .29281 .87455 .28477 Mtetra
.652 .743 .916 r
.27175 .47508 .27892 .4816 .28984 .4783 .28269 .47177 Mtetra
.657 .745 .915 r
.28269 .47177 .28984 .4783 .3008 .47512 .29369 .46832 Mtetra
.704 .748 .886 r
.29369 .46832 .3008 .47512 .31192 .47008 .30485 .46331 Mtetra
.664 .741 .907 r
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.3271 .45591 .33412 .46274 .34529 .45905 .3383 .45219 Mtetra
.437 .656 .953 r
.3383 .45219 .34529 .45905 .35647 .45603 .3493 .45302 Mtetra
.611 .045 0 r
.3493 .45302 .35647 .45603 .36712 .46535 .35999 .46157 Mtetra
.266 .685 .967 r
.35999 .46157 .36712 .46535 .37815 .46891 .37117 .46247 Mtetra
.755 .775 .869 r
.37117 .46247 .37815 .46891 .38963 .46403 .38279 .45524 Mtetra
.792 .727 .791 r
.38279 .45524 .38963 .46403 .40134 .4539 .39459 .44401 Mtetra
.786 .707 .777 r
.39459 .44401 .40134 .4539 .41311 .44239 .40639 .43241 Mtetra
.718 .687 .82 r
.40639 .43241 .41311 .44239 .42482 .43276 .41803 .4257 Mtetra
.664 .741 .907 r
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.559 .697 .932 r
.69774 .33276 .70371 .34057 .71686 .34231 .71074 .33144 Mtetra
.396 .53 .874 r
.71074 .33144 .71686 .34231 .73023 .346 .72413 .33515 Mtetra
.411 .54 .876 r
.72413 .33515 .73023 .346 .74364 .3483 .73763 .33851 Mtetra
.553 .643 .893 r
.73763 .33851 .74364 .3483 .75677 .34522 .75096 .33778 Mtetra
.78 .794 .864 r
.75096 .33778 .75677 .34522 .7693 .33342 .76375 .32866 Mtetra
.912 .872 .786 r
.76375 .32866 .7693 .33342 .78133 .31564 .77592 .31162 Mtetra
.799 .908 .916 r
.77592 .31162 .78133 .31564 .79441 .31059 .78872 .30252 Mtetra
.664 .741 .907 r
.78872 .30252 .79441 .31059 .8076 .30623 .80196 .29813 Mtetra
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.62 .722 .919 r
.82861 .28927 .83417 .29745 .84769 .29448 .84217 .2862 Mtetra
.67 .742 .904 r
.84217 .2862 .84769 .29448 .86109 .28957 .85564 .28151 Mtetra
.674 .751 .908 r
.85564 .28151 .86109 .28957 .87455 .28477 .86915 .27666 Mtetra
.653 .743 .916 r
.26452 .46852 .27175 .47508 .28269 .47177 .27549 .46515 Mtetra
.666 .746 .91 r
.27549 .46515 .28269 .47177 .29369 .46832 .28654 .4614 Mtetra
.7 .745 .887 r
.28654 .4614 .29369 .46832 .30485 .46331 .29771 .45649 Mtetra
.664 .741 .907 r
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
.32003 .44903 .3271 .45591 .3383 .45219 .33125 .44528 Mtetra
.158 .506 .911 r
.33125 .44528 .3383 .45219 .3493 .45302 .3421 .44927 Mtetra
.487 0 0 r
.3421 .44927 .3493 .45302 .35999 .46157 .35286 .45662 Mtetra
.527 .766 .985 r
.35286 .45662 .35999 .46157 .37117 .46247 .36418 .45525 Mtetra
.777 .758 .837 r
.36418 .45525 .37117 .46247 .38279 .45524 .3759 .44637 Mtetra
.798 .727 .786 r
.3759 .44637 .38279 .45524 .39459 .44401 .38776 .43455 Mtetra
.789 .716 .784 r
.38776 .43455 .39459 .44401 .40639 .43241 .39961 .42306 Mtetra
.675 .687 .854 r
.39961 .42306 .40639 .43241 .41803 .4257 .4112 .41858 Mtetra
.664 .741 .907 r
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.644 .733 .914 r
.69172 .32488 .69774 .33276 .71074 .33144 .70461 .32121 Mtetra
.386 .542 .888 r
.70461 .32121 .71074 .33144 .72413 .33515 .71802 .32474 Mtetra
.375 .531 .884 r
.71802 .32474 .72413 .33515 .73763 .33851 .73157 .32863 Mtetra
.492 .611 .898 r
.73157 .32863 .73763 .33851 .75096 .33778 .74505 .32953 Mtetra
.727 .759 .878 r
.74505 .32953 .75096 .33778 .76375 .32866 .75806 .32268 Mtetra
.888 .845 .796 r
.75806 .32268 .76375 .32866 .77592 .31162 .7704 .30682 Mtetra
.86 .885 .854 r
.7704 .30682 .77592 .31162 .78872 .30252 .78299 .29439 Mtetra
.664 .741 .907 r
.78299 .29439 .78872 .30252 .80196 .29813 .79627 .28995 Mtetra
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.625 .724 .918 r
.82301 .28102 .82861 .28927 .84217 .2862 .8366 .27778 Mtetra
.662 .736 .905 r
.8366 .27778 .84217 .2862 .85564 .28151 .85014 .27333 Mtetra
.673 .749 .908 r
.85014 .27333 .85564 .28151 .86915 .27666 .8637 .26848 Mtetra
.654 .743 .915 r
.25723 .46186 .26452 .46852 .27549 .46515 .26824 .45844 Mtetra
.675 .747 .905 r
.26824 .45844 .27549 .46515 .28654 .4614 .27933 .45438 Mtetra
.695 .743 .889 r
.27933 .45438 .28654 .4614 .29771 .45649 .29052 .44961 Mtetra
.664 .741 .907 r
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
.31289 .4421 .32003 .44903 .33125 .44528 .32415 .43832 Mtetra
0 .335 .803 r
.32415 .43832 .33125 .44528 .3421 .44927 .33487 .44462 Mtetra
0 .248 .666 r
.33487 .44462 .3421 .44927 .35286 .45662 .34571 .45078 Mtetra
.632 .77 .946 r
.34571 .45078 .35286 .45662 .36418 .45525 .35714 .4477 Mtetra
.789 .753 .82 r
.35714 .4477 .36418 .45525 .3759 .44637 .36896 .43774 Mtetra
.803 .733 .787 r
.36896 .43774 .3759 .44637 .38776 .43455 .38087 .42563 Mtetra
.781 .725 .801 r
.38087 .42563 .38776 .43455 .39961 .42306 .39271 .4153 Mtetra
.663 .723 .894 r
.39271 .4153 .39961 .42306 .4112 .41858 .40431 .4114 Mtetra
.664 .741 .907 r
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70461 .32121 .69855 .3126 Mtetra
.403 .597 .924 r
.69855 .3126 .70461 .32121 .71802 .32474 .7119 .31486 Mtetra
.345 .53 .893 r
.7119 .31486 .71802 .32474 .73157 .32863 .72549 .31899 Mtetra
.443 .592 .905 r
.72549 .31899 .73157 .32863 .74505 .32953 .73906 .32091 Mtetra
.683 .735 .891 r
.73906 .32091 .74505 .32953 .75806 .32268 .75224 .31577 Mtetra
.866 .824 .805 r
.75224 .31577 .75806 .32268 .7704 .30682 .76474 .30107 Mtetra
.882 .856 .811 r
.76474 .30107 .7704 .30682 .78299 .29439 .7772 .28618 Mtetra
.664 .741 .907 r
.7772 .28618 .78299 .29439 .79627 .28995 .79053 .28171 Mtetra
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.631 .726 .917 r
.81736 .2727 .82301 .28102 .8366 .27778 .83097 .26925 Mtetra
.653 .732 .907 r
.83097 .26925 .8366 .27778 .85014 .27333 .84459 .26505 Mtetra
.672 .748 .907 r
.84459 .26505 .85014 .27333 .8637 .26848 .8582 .26018 Mtetra
.656 .742 .913 r
.24989 .45512 .25723 .46186 .26824 .45844 .26093 .45163 Mtetra
.681 .747 .901 r
.26093 .45163 .26824 .45844 .27933 .45438 .27207 .44734 Mtetra
.691 .743 .891 r
.27207 .44734 .27933 .45438 .29052 .44961 .28328 .44268 Mtetra
.664 .741 .907 r
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.29447 .4389 .30169 .44586 .31289 .4421 .30571 .43511 Mtetra
.30571 .43511 .31289 .4421 .32415 .43832 .31699 .4313 Mtetra
0 .208 .699 r
.31699 .4313 .32415 .43832 .33487 .44462 .32762 .4391 Mtetra
0 .376 .804 r
.32762 .4391 .33487 .44462 .34571 .45078 .33853 .44433 Mtetra
.675 .764 .917 r
.33853 .44433 .34571 .45078 .35714 .4477 .35005 .44011 Mtetra
.797 .754 .814 r
.35005 .44011 .35714 .4477 .36896 .43774 .36194 .42952 Mtetra
.809 .743 .79 r
.36194 .42952 .36896 .43774 .38087 .42563 .37391 .41726 Mtetra
.771 .736 .821 r
.37391 .41726 .38087 .42563 .39271 .4153 .38573 .40809 Mtetra
.664 .741 .907 r
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.45 .642 .939 r
.69246 .30455 .69855 .3126 .7119 .31486 .70577 .30555 Mtetra
.32 .532 .903 r
.70577 .30555 .7119 .31486 .72549 .31899 .71939 .30975 Mtetra
.404 .584 .914 r
.71939 .30975 .72549 .31899 .73906 .32091 .73303 .31226 Mtetra
.651 .724 .902 r
.73303 .31226 .73906 .32091 .75224 .31577 .74633 .30822 Mtetra
.849 .809 .811 r
.74633 .30822 .75224 .31577 .76474 .30107 .75897 .29441 Mtetra
.888 .832 .786 r
.75897 .29441 .76474 .30107 .7772 .28618 .77137 .27791 Mtetra
.664 .741 .907 r
.77137 .27791 .7772 .28618 .79053 .28171 .78474 .2734 Mtetra
.78474 .2734 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.635 .729 .915 r
.81166 .26431 .81736 .2727 .83097 .26925 .8253 .26068 Mtetra
.647 .73 .909 r
.8253 .26068 .83097 .26925 .84459 .26505 .83898 .25665 Mtetra
.671 .746 .907 r
.83898 .25665 .84459 .26505 .8582 .26018 .85265 .25178 Mtetra
.656 .741 .912 r
.2425 .44828 .24989 .45512 .26093 .45163 .25356 .44474 Mtetra
.685 .747 .898 r
.25356 .44474 .26093 .45163 .27207 .44734 .26474 .4403 Mtetra
.689 .744 .894 r
.26474 .4403 .27207 .44734 .28328 .44268 .27598 .43569 Mtetra
.664 .741 .907 r
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.2872 .43188 .29447 .4389 .30571 .43511 .29846 .42806 Mtetra
.29846 .42806 .30571 .43511 .31699 .4313 .30978 .42422 Mtetra
0 .146 .643 r
.30978 .42422 .31699 .4313 .32762 .4391 .32036 .43274 Mtetra
.019 .443 .869 r
.32036 .43274 .32762 .4391 .33853 .44433 .33131 .43747 Mtetra
.691 .757 .902 r
.33131 .43747 .33853 .44433 .35005 .44011 .34289 .43268 Mtetra
.802 .759 .814 r
.34289 .43268 .35005 .44011 .36194 .42952 .35484 .42177 Mtetra
.815 .754 .796 r
.35484 .42177 .36194 .42952 .37391 .41726 .36686 .40944 Mtetra
.767 .749 .836 r
.36686 .40944 .37391 .41726 .38573 .40809 .3787 .40083 Mtetra
.664 .741 .907 r
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.48 .658 .939 r
.68632 .29643 .69246 .30455 .70577 .30555 .69963 .29679 Mtetra
.295 .535 .912 r
.69963 .29679 .70577 .30555 .71939 .30975 .71328 .30099 Mtetra
.374 .583 .923 r
.71328 .30099 .71939 .30975 .73303 .31226 .72697 .30376 Mtetra
.634 .722 .912 r
.72697 .30376 .73303 .31226 .74633 .30822 .74035 .30024 Mtetra
.839 .799 .813 r
.74035 .30024 .74633 .30822 .75897 .29441 .75308 .28688 Mtetra
.885 .813 .773 r
.75308 .28688 .75897 .29441 .77137 .27791 .76549 .26956 Mtetra
.664 .741 .907 r
.76549 .26956 .77137 .27791 .78474 .2734 .7789 .26501 Mtetra
.7789 .26501 .78474 .2734 .79817 .26886 .79237 .26044 Mtetra
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.638 .73 .915 r
.80591 .25585 .81166 .26431 .8253 .26068 .81959 .25209 Mtetra
.643 .73 .911 r
.81959 .25209 .8253 .26068 .83898 .25665 .83333 .24814 Mtetra
.67 .745 .906 r
.83333 .24814 .83898 .25665 .85265 .25178 .84704 .24325 Mtetra
.656 .739 .911 r
.23505 .44133 .2425 .44828 .25356 .44474 .24614 .43776 Mtetra
.685 .746 .898 r
.24614 .43776 .25356 .44474 .26474 .4403 .25735 .43329 Mtetra
.689 .747 .895 r
.25735 .43329 .26474 .4403 .27598 .43569 .26862 .42865 Mtetra
.664 .741 .907 r
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.27987 .42481 .2872 .43188 .29846 .42806 .29116 .42096 Mtetra
.29116 .42096 .29846 .42806 .30978 .42422 .3025 .41709 Mtetra
0 .146 .643 r
.3025 .41709 .30978 .42422 .32036 .43274 .31309 .4256 Mtetra
.079 .457 .885 r
.31309 .4256 .32036 .43274 .33131 .43747 .32404 .43031 Mtetra
.691 .75 .897 r
.32404 .43031 .33131 .43747 .34289 .43268 .33566 .42549 Mtetra
.805 .766 .817 r
.33566 .42549 .34289 .43268 .35484 .42177 .34766 .41454 Mtetra
.821 .766 .801 r
.34766 .41454 .35484 .42177 .36686 .40944 .35972 .40216 Mtetra
.773 .764 .845 r
.35972 .40216 .36686 .40944 .3787 .40083 .37161 .39351 Mtetra
.664 .741 .907 r
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.48 .658 .939 r
.68014 .28824 .68632 .29643 .69963 .29679 .69348 .28857 Mtetra
.27 .539 .919 r
.69348 .28857 .69963 .29679 .71328 .30099 .70715 .29275 Mtetra
.356 .59 .933 r
.70715 .29275 .71328 .30099 .72697 .30376 .72087 .29549 Mtetra
.633 .731 .918 r
.72087 .29549 .72697 .30376 .74035 .30024 .73429 .29193 Mtetra
.836 .793 .81 r
.73429 .29193 .74035 .30024 .75308 .28688 .74708 .27852 Mtetra
.876 .796 .768 r
.74708 .27852 .75308 .28688 .76549 .26956 .75956 .26114 Mtetra
.664 .741 .907 r
.75956 .26114 .76549 .26956 .7789 .26501 .77301 .25655 Mtetra
.77301 .25655 .7789 .26501 .79237 .26044 .78653 .25194 Mtetra
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.638 .73 .915 r
.80011 .24731 .80591 .25585 .81959 .25209 .81383 .24351 Mtetra
.643 .732 .913 r
.81383 .24351 .81959 .25209 .83333 .24814 .82762 .23952 Mtetra
.67 .744 .905 r
.82762 .23952 .83333 .24814 .84704 .24325 .84137 .2346 Mtetra
.656 .737 .91 r
.22755 .43427 .23505 .44133 .24614 .43776 .23867 .43069 Mtetra
.681 .744 .899 r
.23867 .43069 .24614 .43776 .25735 .43329 .2499 .42631 Mtetra
.692 .75 .896 r
.2499 .42631 .25735 .43329 .26862 .42865 .2612 .42155 Mtetra
.664 .741 .907 r
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.27248 .41768 .27987 .42481 .29116 .42096 .2838 .4138 Mtetra
.2838 .4138 .29116 .42096 .3025 .41709 .29517 .4099 Mtetra
0 .208 .699 r
.29517 .4099 .3025 .41709 .31309 .4256 .30581 .41767 Mtetra
.082 .434 .874 r
.30581 .41767 .31309 .4256 .32404 .43031 .31673 .42286 Mtetra
.674 .739 .899 r
.31673 .42286 .32404 .43031 .33566 .42549 .32835 .41854 Mtetra
.805 .773 .824 r
.32835 .41854 .33566 .42549 .34766 .41454 .34038 .40782 Mtetra
.826 .779 .807 r
.34038 .40782 .34766 .41454 .35972 .40216 .3525 .39542 Mtetra
.788 .78 .846 r
.3525 .39542 .35972 .40216 .37161 .39351 .36446 .38613 Mtetra
.664 .741 .907 r
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.45 .642 .939 r
.67389 .27998 .68014 .28824 .69348 .28857 .6873 .2809 Mtetra
.243 .542 .925 r
.6873 .2809 .69348 .28857 .70715 .29275 .701 .28502 Mtetra
.351 .606 .945 r
.701 .28502 .70715 .29275 .72087 .29549 .71474 .28746 Mtetra
.65 .747 .92 r
.71474 .28746 .72087 .29549 .73429 .29193 .72817 .2833 Mtetra
.839 .788 .802 r
.72817 .2833 .73429 .29193 .74708 .27852 .74098 .26933 Mtetra
.861 .78 .77 r
.74098 .26933 .74708 .27852 .75956 .26114 .75357 .25265 Mtetra
.664 .741 .907 r
.75357 .25265 .75956 .26114 .77301 .25655 .76707 .24802 Mtetra
.76707 .24802 .77301 .25655 .78653 .25194 .78063 .24337 Mtetra
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.635 .729 .915 r
.79426 .2387 .80011 .24731 .81383 .24351 .80804 .23495 Mtetra
.647 .736 .914 r
.80804 .23495 .81383 .24351 .82762 .23952 .82185 .2308 Mtetra
.671 .743 .905 r
.82185 .2308 .82762 .23952 .84137 .2346 .83566 .22581 Mtetra
.654 .736 .909 r
.22 .42711 .22755 .43427 .23867 .43069 .23113 .42354 Mtetra
.675 .742 .901 r
.23113 .42354 .23867 .43069 .2499 .42631 .24238 .41933 Mtetra
.696 .752 .895 r
.24238 .41933 .2499 .42631 .2612 .42155 .25372 .4144 Mtetra
.664 .741 .907 r
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .2838 .4138 .27638 .40658 Mtetra
.27638 .40658 .2838 .4138 .29517 .4099 .28778 .40265 Mtetra
0 .335 .803 r
.28778 .40265 .29517 .4099 .30581 .41767 .29852 .40889 Mtetra
.044 .384 .847 r
.29852 .40889 .30581 .41767 .31673 .42286 .30939 .41499 Mtetra
.638 .719 .906 r
.30939 .41499 .31673 .42286 .32835 .41854 .32097 .41175 Mtetra
.799 .778 .834 r
.32097 .41175 .32835 .41854 .34038 .40782 .33301 .40159 Mtetra
.831 .791 .814 r
.33301 .40159 .34038 .40782 .3525 .39542 .34518 .38924 Mtetra
.811 .796 .838 r
.34518 .38924 .3525 .39542 .36446 .38613 .35725 .37869 Mtetra
.664 .741 .907 r
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.384 .606 .936 r
.6676 .27166 .67389 .27998 .6873 .2809 .6811 .27379 Mtetra
.218 .547 .93 r
.6811 .27379 .6873 .2809 .701 .28502 .69483 .27779 Mtetra
.368 .634 .957 r
.69483 .27779 .701 .28502 .71474 .28746 .70856 .27958 Mtetra
.685 .766 .913 r
.70856 .27958 .71474 .28746 .72817 .2833 .72197 .27424 Mtetra
.845 .781 .789 r
.72197 .27424 .72817 .2833 .74098 .26933 .73477 .25926 Mtetra
.837 .761 .778 r
.73477 .25926 .74098 .26933 .75357 .25265 .74753 .24409 Mtetra
.664 .741 .907 r
.74753 .24409 .75357 .25265 .76707 .24802 .76108 .23942 Mtetra
.76108 .23942 .76707 .24802 .78063 .24337 .77468 .23472 Mtetra
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.631 .726 .917 r
.78836 .23001 .79426 .2387 .80804 .23495 .80219 .22637 Mtetra
.653 .741 .914 r
.80219 .22637 .80804 .23495 .82185 .2308 .81604 .22196 Mtetra
.672 .743 .904 r
.81604 .22196 .82185 .2308 .83566 .22581 .82988 .21689 Mtetra
.653 .734 .909 r
.21239 .41986 .22 .42711 .23113 .42354 .22355 .41628 Mtetra
.666 .738 .904 r
.22355 .41628 .23113 .42354 .24238 .41933 .23479 .41232 Mtetra
.701 .754 .893 r
.23479 .41232 .24238 .41933 .25372 .4144 .24619 .40719 Mtetra
.664 .741 .907 r
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
.2689 .39931 .27638 .40658 .28778 .40265 .28033 .39535 Mtetra
.158 .506 .911 r
.28033 .39535 .28778 .40265 .29852 .40889 .29125 .39922 Mtetra
0 .32 .808 r
.29125 .39922 .29852 .40889 .30939 .41499 .30203 .40649 Mtetra
.574 .681 .913 r
.30203 .40649 .30939 .41499 .32097 .41175 .31352 .40493 Mtetra
.784 .779 .848 r
.31352 .40493 .32097 .41175 .33301 .40159 .32555 .39577 Mtetra
.833 .803 .822 r
.32555 .39577 .33301 .40159 .34518 .38924 .33776 .38362 Mtetra
.832 .809 .829 r
.33776 .38362 .34518 .38924 .35725 .37869 .34995 .37182 Mtetra
.684 .764 .912 r
.34995 .37182 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.664 .741 .907 r
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.644 .733 .914 r
.6481 .26781 .65449 .27618 .6676 .27166 .66128 .26389 Mtetra
.287 .57 .935 r
.66128 .26389 .6676 .27166 .6811 .27379 .67487 .26724 Mtetra
.201 .559 .935 r
.67487 .26724 .6811 .27379 .69483 .27779 .68862 .27097 Mtetra
.415 .677 .97 r
.68862 .27097 .69483 .27779 .70856 .27958 .70234 .27165 Mtetra
.731 .782 .893 r
.70234 .27165 .70856 .27958 .72197 .27424 .71568 .26451 Mtetra
.851 .77 .772 r
.71568 .26451 .72197 .27424 .73477 .25926 .72846 .24824 Mtetra
.801 .736 .792 r
.72846 .24824 .73477 .25926 .74753 .24409 .74144 .23545 Mtetra
.664 .741 .907 r
.74144 .23545 .74753 .24409 .76108 .23942 .75503 .23073 Mtetra
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.625 .724 .918 r
.7824 .22124 .78836 .23001 .80219 .22637 .7963 .21774 Mtetra
.662 .745 .912 r
.7963 .21774 .80219 .22637 .81604 .22196 .81016 .213 Mtetra
.673 .742 .902 r
.81016 .213 .81604 .22196 .82988 .21689 .82405 .20786 Mtetra
.652 .733 .909 r
.20472 .41251 .21239 .41986 .22355 .41628 .2159 .40894 Mtetra
.657 .735 .907 r
.2159 .40894 .22355 .41628 .23479 .41232 .22715 .40522 Mtetra
.704 .754 .89 r
.22715 .40522 .23479 .41232 .24619 .40719 .23859 .39992 Mtetra
.664 .741 .907 r
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.26136 .39198 .2689 .39931 .28033 .39535 .27283 .38798 Mtetra
.437 .656 .953 r
.27283 .38798 .28033 .39535 .29125 .39922 .28399 .38861 Mtetra
0 .258 .769 r
.28399 .38861 .29125 .39922 .30203 .40649 .29468 .39708 Mtetra
.475 .615 .909 r
.29468 .39708 .30203 .40649 .31352 .40493 .30603 .39777 Mtetra
.753 .769 .866 r
.30603 .39777 .31352 .40493 .32555 .39577 .318 .3902 Mtetra
.83 .811 .833 r
.318 .3902 .32555 .39577 .33776 .38362 .33024 .37857 Mtetra
.84 .824 .833 r
.33024 .37857 .33776 .38362 .34995 .37182 .3425 .36655 Mtetra
.754 .825 .908 r
.3425 .36655 .34995 .37182 .36178 .3671 .35449 .35951 Mtetra
.664 .741 .907 r
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.559 .697 .932 r
.64166 .25938 .6481 .26781 .66128 .26389 .65497 .25777 Mtetra
.186 .566 .936 r
.65497 .25777 .66128 .26389 .67487 .26724 .66861 .26126 Mtetra
.207 .585 .944 r
.66861 .26126 .67487 .26724 .68862 .27097 .68237 .26439 Mtetra
.5 .732 .976 r
.68237 .26439 .68862 .27097 .70234 .27165 .69604 .26336 Mtetra
.778 .787 .86 r
.69604 .26336 .70234 .27165 .71568 .26451 .70929 .25383 Mtetra
.852 .755 .754 r
.70929 .25383 .71568 .26451 .72846 .24824 .72204 .23625 Mtetra
.746 .701 .809 r
.72204 .23625 .72846 .24824 .74144 .23545 .7353 .22673 Mtetra
.664 .741 .907 r
.7353 .22673 .74144 .23545 .75503 .23073 .74893 .22198 Mtetra
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.62 .722 .919 r
.7764 .2124 .7824 .22124 .7963 .21774 .79035 .20899 Mtetra
.67 .747 .908 r
.79035 .20899 .7963 .21774 .81016 .213 .80424 .20393 Mtetra
.674 .741 .901 r
.80424 .20393 .81016 .213 .82405 .20786 .81817 .19871 Mtetra
.653 .733 .908 r
.19699 .4051 .20472 .41251 .2159 .40894 .2082 .40149 Mtetra
.648 .732 .91 r
.2082 .40149 .2159 .40894 .22715 .40522 .21945 .39799 Mtetra
.706 .752 .888 r
.21945 .39799 .22715 .40522 .23859 .39992 .23093 .39259 Mtetra
.664 .741 .907 r
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.25376 .38459 .26136 .39198 .27283 .38798 .26526 .38056 Mtetra
.64 .734 .917 r
.26526 .38056 .27283 .38798 .28399 .38861 .27674 .37721 Mtetra
0 .224 .745 r
.27674 .37721 .28399 .38861 .29468 .39708 .28735 .38645 Mtetra
.342 .516 .884 r
.28735 .38645 .29468 .39708 .30603 .39777 .29852 .38981 Mtetra
.695 .739 .885 r
.29852 .38981 .30603 .39777 .318 .3902 .31037 .38456 Mtetra
.816 .813 .847 r
.31037 .38456 .318 .3902 .33024 .37857 .32261 .37396 Mtetra
.844 .837 .839 r
.32261 .37396 .33024 .37857 .3425 .36655 .33493 .36194 Mtetra
.818 .844 .869 r
.33493 .36194 .3425 .36655 .35449 .35951 .34713 .35185 Mtetra
.664 .741 .907 r
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.416 .625 .939 r
.63515 .25087 .64166 .25938 .65497 .25777 .64863 .2523 Mtetra
.144 .563 .927 r
.64863 .2523 .65497 .25777 .66861 .26126 .66231 .25573 Mtetra
.261 .637 .963 r
.66231 .25573 .66861 .26126 .68237 .26439 .67606 .25773 Mtetra
.614 .782 .962 r
.67606 .25773 .68237 .26439 .69604 .26336 .68964 .25424 Mtetra
.814 .778 .819 r
.68964 .25424 .69604 .26336 .70929 .25383 .70278 .24188 Mtetra
.847 .735 .74 r
.70278 .24188 .70929 .25383 .72204 .23625 .71553 .22343 Mtetra
.668 .655 .828 r
.71553 .22343 .72204 .23625 .7353 .22673 .7291 .21794 Mtetra
.664 .741 .907 r
.7291 .21794 .7353 .22673 .74893 .22198 .74278 .21314 Mtetra
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.618 .721 .919 r
.77034 .20348 .7764 .2124 .79035 .20899 .78434 .20009 Mtetra
.677 .748 .904 r
.78434 .20009 .79035 .20899 .80424 .20393 .79825 .19473 Mtetra
.673 .74 .9 r
.79825 .19473 .80424 .20393 .81817 .19871 .81224 .18948 Mtetra
.653 .733 .908 r
.1892 .39763 .19699 .4051 .2082 .40149 .20044 .39397 Mtetra
.643 .73 .912 r
.20044 .39397 .2082 .40149 .21945 .39799 .21171 .39058 Mtetra
.684 .744 .897 r
.21171 .39058 .21945 .39799 .23093 .39259 .22314 .38591 Mtetra
.687 .766 .911 r
.22314 .38591 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.664 .741 .907 r
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26526 .38056 .25762 .37307 Mtetra
.25762 .37307 .26526 .38056 .27674 .37721 .2692 .36899 Mtetra
.044 .41 .86 r
.2692 .36899 .27674 .37721 .28735 .38645 .28009 .37442 Mtetra
.201 .402 .836 r
.28009 .37442 .28735 .38645 .29852 .38981 .29106 .38047 Mtetra
.595 .673 .895 r
.29106 .38047 .29852 .38981 .31037 .38456 .30272 .37835 Mtetra
.783 .8 .867 r
.30272 .37835 .31037 .38456 .32261 .37396 .31488 .36956 Mtetra
.84 .846 .849 r
.31488 .36956 .32261 .37396 .33493 .36194 .32724 .35797 Mtetra
.843 .859 .855 r
.32724 .35797 .33493 .36194 .34713 .35185 .33958 .34648 Mtetra
.739 .825 .918 r
.33958 .34648 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.664 .741 .907 r
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.583 .708 .929 r
.61538 .24695 .62198 .25549 .63515 .25087 .62868 .24469 Mtetra
.232 .597 .95 r
.62868 .24469 .63515 .25087 .64863 .2523 .64225 .24748 Mtetra
.136 .582 .926 r
.64225 .24748 .64863 .2523 .66231 .25573 .65595 .2504 Mtetra
.386 .72 .989 r
.65595 .2504 .66231 .25573 .67606 .25773 .66965 .25047 Mtetra
.723 .803 .914 r
.66965 .25047 .67606 .25773 .68964 .25424 .68311 .24369 Mtetra
.832 .755 .778 r
.68311 .24369 .68964 .25424 .70278 .24188 .69615 .22848 Mtetra
.798 .702 .758 r
.69615 .22848 .70278 .24188 .71553 .22343 .70919 .21388 Mtetra
.663 .722 .893 r
.70919 .21388 .71553 .22343 .7291 .21794 .72285 .20907 Mtetra
.664 .741 .907 r
.72285 .20907 .7291 .21794 .74278 .21314 .73657 .20423 Mtetra
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.642 .732 .914 r
.75037 .19937 .75653 .20832 .77034 .20348 .76428 .19521 Mtetra
.642 .752 .929 r
.76428 .19521 .77034 .20348 .78434 .20009 .77827 .19099 Mtetra
.681 .747 .901 r
.77827 .19099 .78434 .20009 .79825 .19473 .79221 .18544 Mtetra
.673 .739 .9 r
.79221 .18544 .79825 .19473 .81224 .18948 .80625 .18015 Mtetra
.655 .735 .908 r
.18134 .39014 .1892 .39763 .20044 .39397 .19262 .38639 Mtetra
.641 .729 .912 r
.19262 .38639 .20044 .39397 .21171 .39058 .20391 .38301 Mtetra
.664 .737 .904 r
.20391 .38301 .21171 .39058 .22314 .38591 .21531 .37896 Mtetra
.702 .763 .9 r
.21531 .37896 .22314 .38591 .23463 .38118 .22688 .3737 Mtetra
.664 .741 .907 r
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.24993 .36553 .25762 .37307 .2692 .36899 .26153 .36141 Mtetra
.49 .679 .95 r
.26153 .36141 .2692 .36899 .28009 .37442 .27288 .36116 Mtetra
.102 .313 .788 r
.27288 .36116 .28009 .37442 .29106 .38047 .28368 .36922 Mtetra
.449 .563 .878 r
.28368 .36922 .29106 .38047 .30272 .37835 .29508 .3708 Mtetra
.713 .758 .887 r
.29508 .3708 .30272 .37835 .31488 .36956 .30709 .36485 Mtetra
.821 .842 .865 r
.30709 .36485 .31488 .36956 .32724 .35797 .31943 .35445 Mtetra
.846 .873 .86 r
.31943 .35445 .32724 .35797 .33958 .34648 .33185 .34292 Mtetra
.835 .877 .873 r
.33185 .34292 .33958 .34648 .35166 .33992 .34421 .33217 Mtetra
.666 .743 .908 r
.34421 .33217 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.664 .741 .907 r
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.662 .74 .908 r
.59553 .24301 .60223 .25159 .61538 .24695 .60873 .2384 Mtetra
.381 .608 .939 r
.60873 .2384 .61538 .24695 .62868 .24469 .62219 .24035 Mtetra
.108 .58 .913 r
.62219 .24035 .62868 .24469 .64225 .24748 .63581 .2431 Mtetra
.208 .647 .95 r
.63581 .2431 .64225 .24748 .65595 .2504 .64951 .24473 Mtetra
.57 .801 .986 r
.64951 .24473 .65595 .2504 .66965 .25047 .66313 .24181 Mtetra
.794 .786 .845 r
.66313 .24181 .66965 .25047 .68311 .24369 .67645 .23115 Mtetra
.832 .725 .746 r
.67645 .23115 .68311 .24369 .69615 .22848 .68942 .2138 Mtetra
.715 .651 .785 r
.68942 .2138 .69615 .22848 .70919 .21388 .70284 .20497 Mtetra
.664 .741 .907 r
.70284 .20497 .70919 .21388 .72285 .20907 .71654 .20011 Mtetra
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.626 .724 .918 r
.74415 .19033 .75037 .19937 .76428 .19521 .75815 .18665 Mtetra
.664 .755 .918 r
.75815 .18665 .76428 .19521 .77827 .19099 .77213 .18171 Mtetra
.682 .744 .898 r
.77213 .18171 .77827 .19099 .79221 .18544 .78612 .17605 Mtetra
.671 .738 .901 r
.78612 .17605 .79221 .18544 .80625 .18015 .80021 .17079 Mtetra
.657 .736 .908 r
.17342 .38261 .18134 .39014 .19262 .38639 .18473 .37876 Mtetra
.644 .731 .912 r
.18473 .37876 .19262 .38639 .20391 .38301 .19605 .3753 Mtetra
.649 .73 .909 r
.19605 .3753 .20391 .38301 .21531 .37896 .20744 .37166 Mtetra
.706 .756 .891 r
.20744 .37166 .21531 .37896 .22688 .3737 .21906 .36616 Mtetra
.664 .741 .907 r
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.24217 .35792 .24993 .36553 .26153 .36141 .25381 .35377 Mtetra
.25381 .35377 .26153 .36141 .27288 .36116 .26549 .34961 Mtetra
.157 .389 .837 r
.26549 .34961 .27288 .36116 .28368 .36922 .27642 .35581 Mtetra
.293 .431 .83 r
.27642 .35581 .28368 .36922 .29508 .3708 .28754 .361 Mtetra
.591 .665 .89 r
.28754 .361 .29508 .3708 .30709 .36485 .29931 .35892 Mtetra
.77 .812 .886 r
.29931 .35892 .30709 .36485 .31943 .35445 .31154 .35086 Mtetra
.835 .875 .872 r
.31154 .35086 .31943 .35445 .33185 .34292 .32398 .34003 Mtetra
.843 .895 .875 r
.32398 .34003 .33185 .34292 .34421 .33217 .33643 .32896 Mtetra
.804 .896 .909 r
.33643 .32896 .34421 .33217 .35624 .32784 .34877 .31992 Mtetra
.664 .741 .907 r
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.476 .658 .94 r
.58877 .23436 .59553 .24301 .60873 .2384 .60213 .23448 Mtetra
.12 .603 .913 r
.60213 .23448 .60873 .2384 .62219 .24035 .61565 .23667 Mtetra
.122 .612 .911 r
.61565 .23667 .62219 .24035 .63581 .2431 .62929 .23865 Mtetra
.403 .763 .994 r
.62929 .23865 .63581 .2431 .64951 .24473 .64295 .23781 Mtetra
.728 .817 .92 r
.64295 .23781 .64951 .24473 .66313 .24181 .65645 .23084 Mtetra
.82 .746 .782 r
.65645 .23084 .66313 .24181 .67645 .23115 .66963 .21639 Mtetra
.795 .685 .743 r
.66963 .21639 .67645 .23115 .68942 .2138 .68274 .20086 Mtetra
.652 .65 .835 r
.68274 .20086 .68942 .2138 .70284 .20497 .69643 .19599 Mtetra
.664 .741 .907 r
.69643 .19599 .70284 .20497 .71654 .20011 .71018 .19108 Mtetra
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.619 .721 .919 r
.73788 .18121 .74415 .19033 .75815 .18665 .75194 .1777 Mtetra
.677 .752 .907 r
.75194 .1777 .75815 .18665 .77213 .18171 .76593 .17225 Mtetra
.68 .741 .897 r
.76593 .17225 .77213 .18171 .78612 .17605 .77997 .16661 Mtetra
.669 .738 .902 r
.77997 .16661 .78612 .17605 .80021 .17079 .79412 .16136 Mtetra
.659 .737 .907 r
.16543 .37505 .17342 .38261 .18473 .37876 .17678 .37111 Mtetra
.648 .733 .911 r
.17678 .37111 .18473 .37876 .19605 .3753 .18814 .36749 Mtetra
.642 .728 .911 r
.18814 .36749 .19605 .3753 .20744 .37166 .19953 .36402 Mtetra
.676 .742 .9 r
.19953 .36402 .20744 .37166 .21906 .36616 .21108 .35951 Mtetra
.696 .775 .912 r
.21108 .35951 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.664 .741 .907 r
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25381 .35377 .24601 .34607 Mtetra
.24601 .34607 .25381 .35377 .26549 .34961 .25773 .34187 Mtetra
.535 .697 .944 r
.25773 .34187 .26549 .34961 .27642 .35581 .26925 .34074 Mtetra
.198 .342 .785 r
.26925 .34074 .27642 .35581 .28754 .361 .28018 .34826 Mtetra
.429 .524 .854 r
.28018 .34826 .28754 .361 .29931 .35892 .29162 .35057 Mtetra
.665 .729 .897 r
.29162 .35057 .29931 .35892 .31154 .35086 .30364 .3462 Mtetra
.795 .851 .893 r
.30364 .3462 .31154 .35086 .32398 .34003 .31601 .33727 Mtetra
.836 .902 .885 r
.31601 .33727 .32398 .34003 .33643 .32896 .3285 .3266 Mtetra
.835 .916 .891 r
.3285 .3266 .33643 .32896 .34877 .31992 .341 .31608 Mtetra
.789 .881 .913 r
.341 .31608 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.664 .741 .907 r
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.505 .672 .939 r
.56875 .23037 .57561 .23906 .58877 .23436 .58204 .22985 Mtetra
.214 .649 .952 r
.58204 .22985 .58877 .23436 .60213 .23448 .59547 .2314 Mtetra
.094 .609 .886 r
.59547 .2314 .60213 .23448 .61565 .23667 .60904 .23312 Mtetra
.286 .725 .965 r
.60904 .23312 .61565 .23667 .62929 .23865 .62267 .23308 Mtetra
.646 .835 .973 r
.62267 .23308 .62929 .23865 .64295 .23781 .63624 .22839 Mtetra
.799 .772 .828 r
.63624 .22839 .64295 .23781 .65645 .23084 .64959 .21685 Mtetra
.815 .702 .74 r
.64959 .21685 .65645 .23084 .66963 .21639 .66271 .19992 Mtetra
.692 .62 .772 r
.66271 .19992 .66963 .21639 .68274 .20086 .67623 .19184 Mtetra
.664 .741 .907 r
.67623 .19184 .68274 .20086 .69643 .19599 .68996 .18692 Mtetra
.68996 .18692 .69643 .19599 .71018 .19108 .70375 .18197 Mtetra
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.634 .728 .916 r
.71762 .177 .72399 .18616 .73788 .18121 .73162 .173 Mtetra
.652 .763 .931 r
.73162 .173 .73788 .18121 .75194 .1777 .74565 .16838 Mtetra
.682 .746 .9 r
.74565 .16838 .75194 .1777 .76593 .17225 .75968 .16267 Mtetra
.677 .739 .898 r
.75968 .16267 .76593 .17225 .77997 .16661 .77378 .15712 Mtetra
.667 .738 .903 r
.77378 .15712 .77997 .16661 .79412 .16136 .78797 .15189 Mtetra
.661 .739 .907 r
.15738 .36747 .16543 .37505 .17678 .37111 .16875 .36344 Mtetra
.653 .735 .91 r
.16875 .36344 .17678 .37111 .18814 .36749 .18016 .35964 Mtetra
.643 .728 .911 r
.18016 .35964 .18814 .36749 .19953 .36402 .19158 .35612 Mtetra
.653 .731 .906 r
.19158 .35612 .19953 .36402 .21108 .35951 .20309 .35228 Mtetra
.706 .762 .896 r
.20309 .35228 .21108 .35951 .22274 .35441 .21482 .34671 Mtetra
.664 .741 .907 r
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.23816 .3383 .24601 .34607 .25773 .34187 .24991 .33406 Mtetra
.24991 .33406 .25773 .34187 .26925 .34074 .26171 .32981 Mtetra
.356 .526 .886 r
.26171 .32981 .26925 .34074 .28018 .34826 .27298 .33275 Mtetra
.298 .399 .798 r
.27298 .33275 .28018 .34826 .29162 .35057 .28414 .33863 Mtetra
.506 .583 .866 r
.28414 .33863 .29162 .35057 .30364 .3462 .29584 .33891 Mtetra
.698 .769 .906 r
.29584 .33891 .30364 .3462 .31601 .33727 .30801 .33346 Mtetra
.799 .879 .905 r
.30801 .33346 .31601 .33727 .3285 .3266 .32046 .32445 Mtetra
.828 .925 .898 r
.32046 .32445 .3285 .3266 .341 .31608 .33301 .31423 Mtetra
.821 .935 .904 r
.33301 .31423 .341 .31608 .35339 .30757 .34555 .30425 Mtetra
.802 .898 .91 r
.34555 .30425 .35339 .30757 .36559 .3032 .35806 .29514 Mtetra
.666 .743 .908 r
.35806 .29514 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.664 .741 .907 r
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.662 .74 .908 r
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22643 Mtetra
.476 .661 .943 r
.54863 .22643 .5556 .23509 .56875 .23037 .56188 .22645 Mtetra
.226 .677 .951 r
.56188 .22645 .56875 .23037 .58204 .22985 .57525 .22736 Mtetra
.094 .624 .87 r
.57525 .22736 .58204 .22985 .59547 .2314 .58874 .22854 Mtetra
.236 .713 .936 r
.58874 .22854 .59547 .2314 .60904 .23312 .60232 .22849 Mtetra
.581 .843 .994 r
.60232 .22849 .60904 .23312 .62267 .23308 .61589 .22483 Mtetra
.777 .794 .867 r
.61589 .22483 .62267 .23308 .63624 .22839 .62934 .21529 Mtetra
.808 .712 .759 r
.62934 .21529 .63624 .22839 .64959 .21685 .6426 .19999 Mtetra
.745 .642 .747 r
.6426 .19999 .64959 .21685 .66271 .19992 .65595 .18768 Mtetra
.655 .666 .849 r
.65595 .18768 .66271 .19992 .67623 .19184 .66966 .18273 Mtetra
.664 .741 .907 r
.66966 .18273 .67623 .19184 .68996 .18692 .68343 .17777 Mtetra
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.619 .722 .919 r
.71119 .16776 .71762 .177 .73162 .173 .72526 .16417 Mtetra
.674 .757 .913 r
.72526 .16417 .73162 .173 .74565 .16838 .73929 .15877 Mtetra
.681 .741 .896 r
.73929 .15877 .74565 .16838 .75968 .16267 .75336 .15304 Mtetra
.673 .738 .899 r
.75336 .15304 .75968 .16267 .77378 .15712 .76753 .14759 Mtetra
.666 .739 .904 r
.76753 .14759 .77378 .15712 .78797 .15189 .78178 .14237 Mtetra
.663 .74 .907 r
.14925 .35985 .15738 .36747 .16875 .36344 .16066 .35575 Mtetra
.657 .737 .909 r
.16066 .35575 .16875 .36344 .18016 .35964 .17211 .35179 Mtetra
.648 .731 .91 r
.17211 .35179 .18016 .35964 .19158 .35612 .18357 .34809 Mtetra
.643 .726 .909 r
.18357 .34809 .19158 .35612 .20309 .35228 .19508 .3445 Mtetra
.674 .742 .902 r
.19508 .3445 .20309 .35228 .21482 .34671 .20674 .33998 Mtetra
.698 .777 .913 r
.20674 .33998 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.664 .741 .907 r
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24991 .33406 .24202 .32619 Mtetra
.24202 .32619 .24991 .33406 .26171 .32981 .25385 .3219 Mtetra
.25385 .3219 .26171 .32981 .27298 .33275 .26573 .31759 Mtetra
.313 .416 .807 r
.26573 .31759 .27298 .33275 .28414 .33863 .27691 .32293 Mtetra
.364 .438 .804 r
.27691 .32293 .28414 .33863 .29584 .33891 .28828 .32742 Mtetra
.541 .612 .873 r
.28828 .32742 .29584 .33891 .30801 .33346 .30014 .32669 Mtetra
.703 .787 .917 r
.30014 .32669 .30801 .33346 .32046 .32445 .31241 .32107 Mtetra
.788 .896 .92 r
.31241 .32107 .32046 .32445 .33301 .31423 .32491 .31253 Mtetra
.81 .942 .913 r
.32491 .31253 .33301 .31423 .34555 .30425 .3375 .30294 Mtetra
.802 .954 .916 r
.3375 .30294 .34555 .30425 .35806 .29514 .3501 .29351 Mtetra
.783 .949 .928 r
.3501 .29351 .35806 .29514 .37036 .29064 .36268 .28478 Mtetra
.739 .825 .918 r
.36268 .28478 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.664 .741 .907 r
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.581 .708 .93 r
.51534 .22709 .52244 .23581 .53551 .2311 .52845 .22475 Mtetra
.445 .721 .984 r
.52845 .22475 .53551 .2311 .54863 .22643 .54165 .2243 Mtetra
.149 .671 .882 r
.54165 .2243 .54863 .22643 .56188 .22645 .55496 .22456 Mtetra
.112 .649 .857 r
.55496 .22456 .56188 .22645 .57525 .22736 .56838 .225 Mtetra
.246 .732 .926 r
.56838 .225 .57525 .22736 .58874 .22854 .5819 .2244 Mtetra
.562 .852 .997 r
.5819 .2244 .58874 .22854 .60232 .22849 .59544 .22083 Mtetra
.762 .807 .889 r
.59544 .22083 .60232 .22849 .61589 .22483 .60893 .21226 Mtetra
.799 .717 .774 r
.60893 .21226 .61589 .22483 .62934 .21529 .62228 .19832 Mtetra
.77 .653 .733 r
.62228 .19832 .62934 .21529 .6426 .19999 .63558 .1835 Mtetra
.638 .595 .789 r
.63558 .1835 .6426 .19999 .65595 .18768 .64927 .17853 Mtetra
.664 .741 .907 r
.64927 .17853 .65595 .18768 .66966 .18273 .66303 .17355 Mtetra
.66303 .17355 .66966 .18273 .68343 .17777 .67685 .16854 Mtetra
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.632 .727 .917 r
.69074 .1635 .69727 .17278 .71119 .16776 .70476 .1595 Mtetra
.654 .766 .932 r
.70476 .1595 .71119 .16776 .72526 .16417 .71881 .15474 Mtetra
.681 .747 .901 r
.71881 .15474 .72526 .16417 .73929 .15877 .73287 .149 Mtetra
.677 .737 .896 r
.73287 .149 .73929 .15877 .75336 .15304 .747 .14337 Mtetra
.669 .738 .902 r
.747 .14337 .75336 .15304 .76753 .14759 .76122 .13801 Mtetra
.665 .74 .906 r
.76122 .13801 .76753 .14759 .78178 .14237 .77553 .13278 Mtetra
.663 .74 .907 r
.14106 .35218 .14925 .35985 .16066 .35575 .1525 .34803 Mtetra
.66 .739 .908 r
.1525 .34803 .16066 .35575 .17211 .35179 .16398 .34394 Mtetra
.654 .735 .909 r
.16398 .34394 .17211 .35179 .18357 .34809 .17549 .34003 Mtetra
.644 .727 .909 r
.17549 .34003 .18357 .34809 .19508 .3445 .18703 .33638 Mtetra
.65 .728 .906 r
.18703 .33638 .19508 .3445 .20674 .33998 .19864 .33254 Mtetra
.697 .759 .9 r
.19864 .33254 .20674 .33998 .21851 .33472 .21046 .32721 Mtetra
.676 .754 .909 r
.21046 .32721 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.664 .741 .907 r
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25385 .3219 .24592 .31393 Mtetra
.24592 .31393 .25385 .3219 .26573 .31759 .25784 .30959 Mtetra
.25784 .30959 .26573 .31759 .27691 .32293 .26981 .30522 Mtetra
.322 .384 .771 r
.26981 .30522 .27691 .32293 .28828 .32742 .28103 .31131 Mtetra
.402 .456 .802 r
.28103 .31131 .28828 .32742 .30014 .32669 .29255 .31499 Mtetra
.545 .612 .87 r
.29255 .31499 .30014 .32669 .31241 .32107 .30451 .3141 Mtetra
.684 .78 .924 r
.30451 .3141 .31241 .32107 .32491 .31253 .31683 .30904 Mtetra
.762 .896 .937 r
.31683 .30904 .32491 .31253 .3375 .30294 .32936 .30138 Mtetra
.781 .949 .929 r
.32936 .30138 .3375 .30294 .3501 .29351 .34199 .29266 Mtetra
.771 .966 .926 r
.34199 .29266 .3501 .29351 .36268 .28478 .35464 .28389 Mtetra
.752 .966 .933 r
.35464 .28389 .36268 .28478 .37519 .27791 .36729 .27561 Mtetra
.748 .934 .948 r
.36729 .27561 .37519 .27791 .38763 .2734 .37994 .26799 Mtetra
.739 .843 .929 r
.37994 .26799 .38763 .2734 .40013 .26886 .39259 .26108 Mtetra
.684 .764 .912 r
.39259 .26108 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.664 .741 .907 r
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.644 .734 .914 r
.4691 .23255 .47639 .24122 .48931 .23653 .48205 .22847 Mtetra
.577 .726 .944 r
.48205 .22847 .48931 .23653 .50229 .23182 .49506 .22608 Mtetra
.503 .769 .991 r
.49506 .22608 .50229 .23182 .51534 .22709 .50814 .2244 Mtetra
.308 .763 .954 r
.50814 .2244 .51534 .22709 .52845 .22475 .5213 .22342 Mtetra
.156 .689 .854 r
.5213 .22342 .52845 .22475 .54165 .2243 .53457 .22293 Mtetra
.161 .691 .857 r
.53457 .22293 .54165 .2243 .55496 .22456 .54794 .22242 Mtetra
.319 .782 .941 r
.54794 .22242 .55496 .22456 .56838 .225 .5614 .22083 Mtetra
.598 .865 .993 r
.5614 .22083 .56838 .225 .5819 .2244 .57491 .2166 Mtetra
.759 .803 .888 r
.57491 .2166 .5819 .2244 .59544 .22083 .5884 .20812 Mtetra
.789 .712 .779 r
.5884 .20812 .59544 .22083 .60893 .21226 .60181 .19495 Mtetra
.775 .653 .727 r
.60181 .19495 .60893 .21226 .62228 .19832 .61514 .1793 Mtetra
.629 .563 .761 r
.61514 .1793 .62228 .19832 .63558 .1835 .6288 .17432 Mtetra
.664 .741 .907 r
.6288 .17432 .63558 .1835 .64927 .17853 .64253 .16931 Mtetra
.64253 .16931 .64927 .17853 .66303 .17355 .65633 .16428 Mtetra
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.653 .736 .911 r
.6702 .15922 .67685 .16854 .69074 .1635 .68416 .15451 Mtetra
.63 .737 .924 r
.68416 .15451 .69074 .1635 .70476 .1595 .69823 .1505 Mtetra
.676 .756 .911 r
.69823 .1505 .70476 .1595 .71881 .15474 .71228 .14495 Mtetra
.68 .739 .895 r
.71228 .14495 .71881 .15474 .73287 .149 .72639 .13919 Mtetra
.672 .736 .899 r
.72639 .13919 .73287 .149 .747 .14337 .74059 .13369 Mtetra
.667 .739 .904 r
.74059 .13369 .747 .14337 .76122 .13801 .75486 .12838 Mtetra
.664 .74 .906 r
.75486 .12838 .76122 .13801 .77553 .13278 .76922 .12312 Mtetra
.664 .741 .907 r
.13279 .34446 .14106 .35218 .1525 .34803 .14426 .34025 Mtetra
.662 .74 .908 r
.14426 .34025 .1525 .34803 .16398 .34394 .15578 .33608 Mtetra
.659 .738 .908 r
.15578 .33608 .16398 .34394 .17549 .34003 .16734 .33199 Mtetra
.65 .731 .909 r
.16734 .33199 .17549 .34003 .18703 .33638 .17892 .32813 Mtetra
.644 .725 .908 r
.17892 .32813 .18703 .33638 .19864 .33254 .19054 .32445 Mtetra
.66 .735 .905 r
.19054 .32445 .19864 .33254 .21046 .32721 .20227 .32024 Mtetra
.706 .776 .907 r
.20227 .32024 .21046 .32721 .22225 .32256 .2142 .3146 Mtetra
.664 .741 .907 r
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .25784 .30959 .24988 .30151 Mtetra
.24988 .30151 .25784 .30959 .26981 .30522 .26189 .29711 Mtetra
.26189 .29711 .26981 .30522 .28103 .31131 .27395 .29269 Mtetra
.365 .401 .765 r
.27395 .29269 .28103 .31131 .29255 .31499 .28532 .29795 Mtetra
.421 .457 .791 r
.28532 .29795 .29255 .31499 .30451 .3141 .29696 .3013 Mtetra
.529 .584 .854 r
.29696 .3013 .30451 .3141 .31683 .30904 .30897 .30093 Mtetra
.644 .74 .919 r
.30897 .30093 .31683 .30904 .32936 .30138 .3213 .297 Mtetra
.721 .869 .951 r
.3213 .297 .32936 .30138 .34199 .29266 .33384 .29064 Mtetra
.743 .939 .949 r
.33384 .29064 .34199 .29266 .35464 .28389 .34649 .28309 Mtetra
.73 .965 .938 r
.34649 .28309 .35464 .28389 .36729 .27561 .35919 .27525 Mtetra
.703 .969 .933 r
.35919 .27525 .36729 .27561 .37994 .26799 .37192 .26764 Mtetra
.674 .963 .935 r
.37192 .26764 .37994 .26799 .39259 .26108 .38465 .26052 Mtetra
.645 .953 .942 r
.38465 .26052 .39259 .26108 .40522 .25585 .3974 .25401 Mtetra
.653 .933 .969 r
.3974 .25401 .40522 .25585 .41787 .25123 .41017 .2481 Mtetra
.652 .901 .982 r
.41017 .2481 .41787 .25123 .43059 .24659 .42296 .24281 Mtetra
.633 .878 .987 r
.42296 .24281 .43059 .24659 .44337 .24193 .4358 .23811 Mtetra
.6 .867 .993 r
.4358 .23811 .44337 .24193 .45621 .23725 .44868 .23402 Mtetra
.542 .864 .995 r
.44868 .23402 .45621 .23725 .4691 .23255 .46161 .23053 Mtetra
.434 .846 .966 r
.46161 .23053 .4691 .23255 .48205 .22847 .47461 .22767 Mtetra
.291 .784 .884 r
.47461 .22767 .48205 .22847 .49506 .22608 .48768 .22542 Mtetra
.228 .745 .854 r
.48768 .22542 .49506 .22608 .50814 .2244 .50083 .22367 Mtetra
.207 .73 .848 r
.50083 .22367 .50814 .2244 .5213 .22342 .51406 .22217 Mtetra
.273 .768 .895 r
.51406 .22217 .5213 .22342 .53457 .22293 .52739 .22038 Mtetra
.459 .85 .978 r
.52739 .22038 .53457 .22293 .54794 .22242 .54081 .21739 Mtetra
.669 .862 .973 r
.54081 .21739 .54794 .22242 .5614 .22083 .55428 .21194 Mtetra
.763 .777 .864 r
.55428 .21194 .5614 .22083 .57491 .2166 .56777 .20285 Mtetra
.776 .693 .772 r
.56777 .20285 .57491 .2166 .5884 .20812 .58121 .18996 Mtetra
.762 .639 .726 r
.58121 .18996 .5884 .20812 .60181 .19495 .5946 .17508 Mtetra
.626 .554 .753 r
.5946 .17508 .60181 .19495 .61514 .1793 .60825 .17008 Mtetra
.664 .741 .907 r
.60825 .17008 .61514 .1793 .6288 .17432 .62196 .16505 Mtetra
.62196 .16505 .6288 .17432 .64253 .16931 .63574 .16 Mtetra
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.622 .723 .919 r
.6635 .14982 .6702 .15922 .68416 .15451 .67755 .14605 Mtetra
.668 .769 .926 r
.67755 .14605 .68416 .15451 .69823 .1505 .6916 .1408 Mtetra
.68 .742 .898 r
.6916 .1408 .69823 .1505 .71228 .14495 .70569 .135 Mtetra
.675 .735 .896 r
.70569 .135 .71228 .14495 .72639 .13919 .71986 .12937 Mtetra
.668 .737 .902 r
.71986 .12937 .72639 .13919 .74059 .13369 .73412 .12398 Mtetra
.665 .739 .905 r
.73412 .12398 .74059 .13369 .75486 .12838 .74845 .11867 Mtetra
.664 .74 .907 r
.74845 .11867 .75486 .12838 .76922 .12312 .76286 .11338 Mtetra
.664 .741 .907 r
.12446 .33667 .13279 .34446 .14426 .34025 .13596 .33243 Mtetra
.663 .741 .907 r
.13596 .33243 .14426 .34025 .15578 .33608 .14751 .32819 Mtetra
.661 .739 .908 r
.14751 .32819 .15578 .33608 .16734 .33199 .15911 .32398 Mtetra
.656 .736 .908 r
.15911 .32398 .16734 .33199 .17892 .32813 .17074 .3199 Mtetra
.648 .728 .908 r
.17074 .3199 .17892 .32813 .19054 .32445 .1824 .31606 Mtetra
.645 .725 .906 r
.1824 .31606 .19054 .32445 .20227 .32024 .19411 .31227 Mtetra
.67 .743 .905 r
.19411 .31227 .20227 .32024 .2142 .3146 .20596 .30772 Mtetra
.702 .781 .913 r
.20596 .30772 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.664 .741 .907 r
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26189 .29711 .25389 .28893 Mtetra
.25389 .28893 .26189 .29711 .27395 .29269 .26599 .28447 Mtetra
.26599 .28447 .27395 .29269 .28532 .29795 .27813 .27998 Mtetra
.446 .459 .78 r
.27813 .27998 .28532 .29795 .29696 .3013 .28979 .28277 Mtetra
.435 .447 .773 r
.28979 .28277 .29696 .3013 .30897 .30093 .30152 .286 Mtetra
.505 .537 .823 r
.30152 .286 .30897 .30093 .3213 .297 .31356 .2865 Mtetra
.592 .665 .889 r
.31356 .2865 .3213 .297 .33384 .29064 .32588 .28408 Mtetra
.665 .794 .944 r
.32588 .28408 .33384 .29064 .34649 .28309 .3384 .27942 Mtetra
.698 .891 .968 r
.3384 .27942 .34649 .28309 .35919 .27525 .35106 .27343 Mtetra
.689 .94 .963 r
.35106 .27343 .35919 .27525 .37192 .26764 .3638 .26688 Mtetra
.656 .953 .948 r
.3638 .26688 .37192 .26764 .38465 .26052 .37658 .2603 Mtetra
.613 .948 .932 r
.37658 .2603 .38465 .26052 .3974 .25401 .38939 .254 Mtetra
.566 .933 .92 r
.38939 .254 .3974 .25401 .41017 .2481 .40223 .24816 Mtetra
.518 .913 .91 r
.40223 .24816 .41017 .2481 .42296 .24281 .4151 .24286 Mtetra
.467 .889 .899 r
.4151 .24286 .42296 .24281 .4358 .23811 .42801 .23813 Mtetra
.416 .863 .887 r
.42801 .23813 .4358 .23811 .44868 .23402 .44097 .23397 Mtetra
.367 .835 .875 r
.44097 .23397 .44868 .23402 .46161 .23053 .45398 .23036 Mtetra
.33 .812 .868 r
.45398 .23036 .46161 .23053 .47461 .22767 .46705 .22721 Mtetra
.32 .805 .878 r
.46705 .22721 .47461 .22767 .48768 .22542 .4802 .22435 Mtetra
.364 .826 .917 r
.4802 .22435 .48768 .22542 .50083 .22367 .49342 .22146 Mtetra
.478 .866 .973 r
.49342 .22146 .50083 .22367 .51406 .22217 .50674 .21802 Mtetra
.628 .875 .988 r
.50674 .21802 .51406 .22217 .52739 .22038 .52013 .21322 Mtetra
.728 .812 .917 r
.52013 .21322 .52739 .22038 .54081 .21739 .53358 .20616 Mtetra
.76 .727 .822 r
.53358 .20616 .54081 .21739 .55428 .21194 .54706 .19611 Mtetra
.758 .661 .754 r
.54706 .19611 .55428 .21194 .56777 .20285 .56052 .18326 Mtetra
.727 .611 .728 r
.56052 .18326 .56777 .20285 .58121 .18996 .57399 .17085 Mtetra
.628 .563 .762 r
.57399 .17085 .58121 .18996 .5946 .17508 .58761 .16583 Mtetra
.664 .741 .907 r
.58761 .16583 .5946 .17508 .60825 .17008 .6013 .16078 Mtetra
.6013 .16078 .60825 .17008 .62196 .16505 .61505 .1557 Mtetra
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.627 .726 .918 r
.64277 .14548 .64958 .15492 .6635 .14982 .65678 .14152 Mtetra
.658 .771 .932 r
.65678 .14152 .6635 .14982 .67755 .14605 .67083 .13654 Mtetra
.68 .748 .903 r
.67083 .13654 .67755 .14605 .6916 .1408 .6849 .13078 Mtetra
.676 .735 .895 r
.6849 .13078 .6916 .1408 .70569 .135 .69905 .12506 Mtetra
.67 .735 .899 r
.69905 .12506 .70569 .135 .71986 .12937 .71328 .11957 Mtetra
.666 .738 .904 r
.71328 .11957 .71986 .12937 .73412 .12398 .72759 .11421 Mtetra
.664 .74 .906 r
.72759 .11421 .73412 .12398 .74845 .11867 .74197 .10889 Mtetra
.664 .741 .907 r
.74197 .10889 .74845 .11867 .76286 .11338 .75643 .10355 Mtetra
.11606 .32883 .12446 .33667 .13596 .33243 .12759 .32455 Mtetra
.12759 .32455 .13596 .33243 .14751 .32819 .13917 .32026 Mtetra
.663 .74 .907 r
.13917 .32026 .14751 .32819 .15911 .32398 .1508 .31597 Mtetra
.66 .738 .908 r
.1508 .31597 .15911 .32398 .17074 .3199 .16248 .31173 Mtetra
.655 .734 .908 r
.16248 .31173 .17074 .3199 .1824 .31606 .17419 .30765 Mtetra
.647 .726 .907 r
.17419 .30765 .1824 .31606 .19411 .31227 .18593 .30378 Mtetra
.648 .725 .905 r
.18593 .30378 .19411 .31227 .20596 .30772 .19774 .29986 Mtetra
.675 .75 .907 r
.19774 .29986 .20596 .30772 .21795 .30219 .20968 .29508 Mtetra
.698 .777 .912 r
.20968 .29508 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.664 .741 .907 r
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26599 .28447 .25796 .27618 Mtetra
.25796 .27618 .26599 .28447 .27813 .27998 .27014 .27166 Mtetra
.27014 .27166 .27813 .27998 .28979 .28277 .28238 .26711 Mtetra
.563 .557 .805 r
.28238 .26711 .28979 .28277 .30152 .286 .29444 .2657 Mtetra
.455 .442 .754 r
.29444 .2657 .30152 .286 .31356 .2865 .30628 .26854 Mtetra
.492 .49 .783 r
.30628 .26854 .31356 .2865 .32588 .28408 .31835 .26978 Mtetra
.546 .572 .831 r
.31835 .26978 .32588 .28408 .3384 .27942 .33065 .26889 Mtetra
.602 .671 .889 r
.33065 .26889 .3384 .27942 .35106 .27343 .34315 .26609 Mtetra
.645 .77 .939 r
.34315 .26609 .35106 .27343 .3638 .26688 .3558 .26193 Mtetra
.662 .848 .971 r
.3558 .26193 .3638 .26688 .37658 .2603 .36855 .25699 Mtetra
.652 .896 .982 r
.36855 .25699 .37658 .2603 .38939 .254 .38138 .25173 Mtetra
.623 .916 .979 r
.38138 .25173 .38939 .254 .40223 .24816 .39426 .24648 Mtetra
.587 .918 .971 r
.39426 .24648 .40223 .24816 .4151 .24286 .40719 .24142 Mtetra
.553 .91 .963 r
.40719 .24142 .4151 .24286 .42801 .23813 .42017 .23665 Mtetra
.53 .901 .962 r
.42017 .23665 .42801 .23813 .44097 .23397 .4332 .23218 Mtetra
.528 .895 .97 r
.4332 .23218 .44097 .23397 .45398 .23036 .44629 .2279 Mtetra
.554 .892 .984 r
.44629 .2279 .45398 .23036 .46705 .22721 .45945 .22363 Mtetra
.608 .883 .991 r
.45945 .22363 .46705 .22721 .4802 .22435 .47268 .21904 Mtetra
.671 .851 .969 r
.47268 .21904 .4802 .22435 .49342 .22146 .486 .21367 Mtetra
.718 .792 .91 r
.486 .21367 .49342 .22146 .50674 .21802 .49938 .20691 Mtetra
.738 .722 .836 r
.49938 .20691 .50674 .21802 .52013 .21322 .51282 .19822 Mtetra
.741 .663 .774 r
.51282 .19822 .52013 .21322 .53358 .20616 .52629 .18734 Mtetra
.733 .62 .733 r
.52629 .18734 .53358 .20616 .54706 .19611 .53977 .17481 Mtetra
.667 .565 .731 r
.53977 .17481 .54706 .19611 .56052 .18326 .55328 .1666 Mtetra
.637 .595 .79 r
.55328 .1666 .56052 .18326 .57399 .17085 .56688 .16156 Mtetra
.664 .741 .907 r
.56688 .16156 .57399 .17085 .58761 .16583 .58055 .15649 Mtetra
.58055 .15649 .58761 .16583 .6013 .16078 .59428 .15139 Mtetra
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.632 .728 .917 r
.62195 .14112 .62887 .1506 .64277 .14548 .63593 .13701 Mtetra
.653 .765 .931 r
.63593 .13701 .64277 .14548 .65678 .14152 .64996 .13219 Mtetra
.678 .753 .907 r
.64996 .13219 .65678 .14152 .67083 .13654 .66402 .12648 Mtetra
.677 .735 .894 r
.66402 .12648 .67083 .13654 .6849 .13078 .67815 .12071 Mtetra
.671 .734 .897 r
.67815 .12071 .6849 .13078 .69905 .12506 .69235 .11515 Mtetra
.667 .737 .903 r
.69235 .11515 .69905 .12506 .71328 .11957 .70664 .10974 Mtetra
.665 .74 .906 r
.70664 .10974 .71328 .11957 .72759 .11421 .721 .10438 Mtetra
.664 .741 .907 r
.721 .10438 .72759 .11421 .74197 .10889 .73544 .09902 Mtetra
.73544 .09902 .74197 .10889 .75643 .10355 .74995 .09364 Mtetra
.10759 .32091 .11606 .32883 .12759 .32455 .11914 .3166 Mtetra
.11914 .3166 .12759 .32455 .13917 .32026 .13076 .31226 Mtetra
.663 .741 .907 r
.13076 .31226 .13917 .32026 .1508 .31597 .14242 .30792 Mtetra
.663 .74 .907 r
.14242 .30792 .1508 .31597 .16248 .31173 .15414 .30358 Mtetra
.66 .737 .907 r
.15414 .30358 .16248 .31173 .17419 .30765 .16589 .29932 Mtetra
.653 .732 .907 r
.16589 .29932 .17419 .30765 .18593 .30378 .17769 .29521 Mtetra
.647 .725 .905 r
.17769 .29521 .18593 .30378 .19774 .29986 .18951 .29128 Mtetra
.65 .726 .905 r
.18951 .29128 .19774 .29986 .20968 .29508 .20141 .28725 Mtetra
.676 .754 .91 r
.20141 .28725 .20968 .29508 .22175 .28961 .21344 .2824 Mtetra
.698 .777 .912 r
.21344 .2824 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.664 .741 .907 r
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .27014 .27166 .26207 .26326 Mtetra
.26207 .26326 .27014 .27166 .28238 .26711 .27435 .25868 Mtetra
.27435 .25868 .28238 .26711 .29444 .2657 .28668 .25407 Mtetra
.654 .667 .85 r
.28668 .25407 .29444 .2657 .30628 .26854 .29907 .24945 Mtetra
.543 .507 .766 r
.29907 .24945 .30628 .26854 .31835 .26978 .31124 .24877 Mtetra
.501 .465 .749 r
.31124 .24877 .31835 .26978 .33065 .26889 .32338 .24991 Mtetra
.528 .501 .77 r
.32338 .24991 .33065 .26889 .34315 .26609 .3357 .24985 Mtetra
.561 .553 .803 r
.3357 .24985 .34315 .26609 .3558 .26193 .3482 .24841 Mtetra
.594 .612 .839 r
.3482 .24841 .3558 .26193 .36855 .25699 .36084 .24578 Mtetra
.622 .669 .874 r
.36084 .24578 .36855 .25699 .38138 .25173 .37361 .24224 Mtetra
.642 .717 .902 r
.37361 .24224 .38138 .25173 .39426 .24648 .38648 .2381 Mtetra
.655 .751 .92 r
.38648 .2381 .39426 .24648 .40719 .24142 .39942 .23356 Mtetra
.663 .769 .928 r
.39942 .23356 .40719 .24142 .42017 .23665 .41245 .22876 Mtetra
.671 .771 .925 r
.41245 .22876 .42017 .23665 .4332 .23218 .42554 .22367 Mtetra
.682 .759 .91 r
.42554 .22367 .4332 .23218 .44629 .2279 .43871 .21819 Mtetra
.693 .734 .882 r
.43871 .21819 .44629 .2279 .45945 .22363 .45194 .21211 Mtetra
.703 .701 .845 r
.45194 .21211 .45945 .22363 .47268 .21904 .46525 .20511 Mtetra
.71 .663 .802 r
.46525 .20511 .47268 .21904 .486 .21367 .47863 .19688 Mtetra
.711 .629 .764 r
.47863 .19688 .486 .21367 .49938 .20691 .49206 .18726 Mtetra
.709 .601 .734 r
.49206 .18726 .49938 .20691 .51282 .19822 .50552 .1764 Mtetra
.675 .566 .725 r
.50552 .1764 .51282 .19822 .52629 .18734 .51898 .16738 Mtetra
.625 .553 .754 r
.51898 .16738 .52629 .18734 .53977 .17481 .53249 .16233 Mtetra
.654 .667 .85 r
.53249 .16233 .53977 .17481 .55328 .1666 .54607 .15727 Mtetra
.664 .741 .907 r
.54607 .15727 .55328 .1666 .56688 .16156 .55971 .15218 Mtetra
.55971 .15218 .56688 .16156 .58055 .15649 .57342 .14706 Mtetra
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.631 .728 .917 r
.60105 .13675 .60808 .14627 .62195 .14112 .615 .13262 Mtetra
.652 .765 .932 r
.615 .13262 .62195 .14112 .63593 .13701 .629 .12778 Mtetra
.677 .756 .91 r
.629 .12778 .63593 .13701 .64996 .13219 .64304 .1221 Mtetra
.677 .736 .895 r
.64304 .1221 .64996 .13219 .66402 .12648 .65715 .11632 Mtetra
.672 .733 .896 r
.65715 .11632 .66402 .12648 .67815 .12071 .67134 .1107 Mtetra
.667 .736 .901 r
.67134 .1107 .67815 .12071 .69235 .11515 .6856 .10524 Mtetra
.665 .739 .905 r
.6856 .10524 .69235 .11515 .70664 .10974 .69994 .09986 Mtetra
.664 .74 .907 r
.69994 .09986 .70664 .10974 .721 .10438 .71435 .09446 Mtetra
.664 .741 .907 r
.71435 .09446 .721 .10438 .73544 .09902 .72884 .08906 Mtetra
.72884 .08906 .73544 .09902 .74995 .09364 .7434 .08362 Mtetra
.09904 .31293 .10759 .32091 .11914 .3166 .11063 .30858 Mtetra
.11063 .30858 .11914 .3166 .13076 .31226 .12227 .30421 Mtetra
.12227 .30421 .13076 .31226 .14242 .30792 .13397 .29982 Mtetra
.664 .74 .907 r
.13397 .29982 .14242 .30792 .15414 .30358 .14571 .29542 Mtetra
.662 .74 .907 r
.14571 .29542 .15414 .30358 .16589 .29932 .15751 .29104 Mtetra
.659 .737 .907 r
.15751 .29104 .16589 .29932 .17769 .29521 .16935 .28672 Mtetra
.653 .731 .906 r
.16935 .28672 .17769 .29521 .18951 .29128 .18123 .28256 Mtetra
.647 .724 .904 r
.18123 .28256 .18951 .29128 .20141 .28725 .19315 .27855 Mtetra
.65 .726 .905 r
.19315 .27855 .20141 .28725 .21344 .2824 .20514 .27445 Mtetra
.672 .752 .911 r
.20514 .27445 .21344 .2824 .22559 .27687 .21724 .26968 Mtetra
.702 .781 .913 r
.21724 .26968 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.664 .741 .907 r
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .27435 .25868 .26625 .25016 Mtetra
.26625 .25016 .27435 .25868 .28668 .25407 .27861 .24552 Mtetra
.27861 .24552 .28668 .25407 .29907 .24945 .29104 .24086 Mtetra
.29104 .24086 .29907 .24945 .31124 .24877 .30352 .23617 Mtetra
.651 .651 .837 r
.30352 .23617 .31124 .24877 .32338 .24991 .31606 .23146 Mtetra
.614 .556 .765 r
.31606 .23146 .32338 .24991 .3357 .24985 .32862 .22745 Mtetra
.541 .479 .735 r
.32862 .22745 .3357 .24985 .3482 .24841 .34104 .22677 Mtetra
.557 .495 .742 r
.34104 .22677 .3482 .24841 .36084 .24578 .35359 .22534 Mtetra
.576 .517 .752 r
.35359 .22534 .36084 .24578 .37361 .24224 .36628 .22299 Mtetra
.596 .54 .763 r
.36628 .22299 .37361 .24224 .38648 .2381 .3791 .21976 Mtetra
.614 .56 .77 r
.3791 .21976 .38648 .2381 .39942 .23356 .39202 .21569 Mtetra
.63 .574 .773 r
.39202 .21569 .39942 .23356 .41245 .22876 .40505 .21083 Mtetra
.644 .581 .769 r
.40505 .21083 .41245 .22876 .42554 .22367 .41816 .20518 Mtetra
.656 .582 .761 r
.41816 .20518 .42554 .22367 .43871 .21819 .43136 .19869 Mtetra
.664 .578 .748 r
.43136 .19869 .43871 .21819 .45194 .21211 .44463 .1913 Mtetra
.671 .571 .734 r
.44463 .1913 .45194 .21211 .46525 .20511 .45796 .18298 Mtetra
.674 .563 .722 r
.45796 .18298 .46525 .20511 .47863 .19688 .47135 .17389 Mtetra
.625 .529 .725 r
.47135 .17389 .47863 .19688 .49206 .18726 .48471 .16815 Mtetra
.627 .563 .763 r
.48471 .16815 .49206 .18726 .50552 .1764 .49813 .16311 Mtetra
.651 .651 .837 r
.49813 .16311 .50552 .1764 .51898 .16738 .51162 .15805 Mtetra
.664 .741 .907 r
.51162 .15805 .51898 .16738 .53249 .16233 .52517 .15296 Mtetra
.52517 .15296 .53249 .16233 .54607 .15727 .53879 .14785 Mtetra
.53879 .14785 .54607 .15727 .55971 .15218 .55248 .14271 Mtetra
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.627 .726 .918 r
.58006 .13236 .5872 .14192 .60105 .13675 .59398 .12834 Mtetra
.657 .77 .932 r
.59398 .12834 .60105 .13675 .615 .13262 .60795 .12333 Mtetra
.677 .755 .91 r
.60795 .12333 .615 .13262 .629 .12778 .62198 .11765 Mtetra
.676 .735 .895 r
.62198 .11765 .629 .12778 .64304 .1221 .63607 .11186 Mtetra
.671 .732 .895 r
.63607 .11186 .64304 .1221 .65715 .11632 .65023 .10622 Mtetra
.667 .735 .901 r
.65023 .10622 .65715 .11632 .67134 .1107 .66447 .10073 Mtetra
.665 .738 .905 r
.66447 .10073 .67134 .1107 .6856 .10524 .67879 .09531 Mtetra
.664 .74 .907 r
.67879 .09531 .6856 .10524 .69994 .09986 .69318 .08989 Mtetra
.664 .741 .907 r
.69318 .08989 .69994 .09986 .71435 .09446 .70764 .08446 Mtetra
.70764 .08446 .71435 .09446 .72884 .08906 .72218 .079 Mtetra
.72218 .079 .72884 .08906 .7434 .08362 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13397 .29982 .12544 .29166 Mtetra
.12544 .29166 .13397 .29982 .14571 .29542 .13722 .28722 Mtetra
.663 .74 .907 r
.13722 .28722 .14571 .29542 .15751 .29104 .14905 .28276 Mtetra
.662 .739 .907 r
.14905 .28276 .15751 .29104 .16935 .28672 .16093 .27832 Mtetra
.659 .736 .907 r
.16093 .27832 .16935 .28672 .18123 .28256 .17286 .27394 Mtetra
.654 .73 .905 r
.17286 .27394 .18123 .28256 .19315 .27855 .18483 .2697 Mtetra
.649 .724 .903 r
.18483 .2697 .19315 .27855 .20514 .27445 .19684 .26559 Mtetra
.649 .725 .904 r
.19684 .26559 .20514 .27445 .21724 .26968 .20891 .26144 Mtetra
.665 .746 .911 r
.20891 .26144 .21724 .26968 .2295 .26396 .22109 .25683 Mtetra
.697 .784 .919 r
.22109 .25683 .2295 .26396 .24169 .25938 .23341 .25124 Mtetra
.676 .754 .909 r
.23341 .25124 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.664 .741 .907 r
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29104 .24086 .28293 .23219 Mtetra
.28293 .23219 .29104 .24086 .30352 .23617 .29545 .22746 Mtetra
.29545 .22746 .30352 .23617 .31606 .23146 .30803 .22271 Mtetra
.30803 .22271 .31606 .23146 .32862 .22745 .32067 .21794 Mtetra
.662 .722 .894 r
.32067 .21794 .32862 .22745 .34104 .22677 .33337 .21314 Mtetra
.647 .636 .825 r
.33337 .21314 .34104 .22677 .35359 .22534 .34613 .20832 Mtetra
.633 .584 .781 r
.34613 .20832 .35359 .22534 .36628 .22299 .35895 .20348 Mtetra
.624 .554 .755 r
.35895 .20348 .36628 .22299 .3791 .21976 .37184 .19862 Mtetra
.619 .537 .74 r
.37184 .19862 .3791 .21976 .39202 .21569 .38478 .19373 Mtetra
.616 .53 .734 r
.38478 .19373 .39202 .21569 .40505 .21083 .39779 .18881 Mtetra
.39779 .18881 .40505 .21083 .41816 .20518 .41086 .18388 Mtetra
.619 .537 .74 r
.41086 .18388 .41816 .20518 .43136 .19869 .424 .17892 Mtetra
.624 .554 .755 r
.424 .17892 .43136 .19869 .44463 .1913 .4372 .17393 Mtetra
.633 .584 .781 r
.4372 .17393 .44463 .1913 .45796 .18298 .45047 .16892 Mtetra
.647 .636 .825 r
.45047 .16892 .45796 .18298 .47135 .17389 .4638 .16389 Mtetra
.662 .722 .894 r
.4638 .16389 .47135 .17389 .48471 .16815 .47719 .15883 Mtetra
.664 .741 .907 r
.47719 .15883 .48471 .16815 .49813 .16311 .49065 .15375 Mtetra
.49065 .15375 .49813 .16311 .51162 .15805 .50418 .14864 Mtetra
.50418 .14864 .51162 .15805 .52517 .15296 .51778 .1435 Mtetra
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.653 .737 .911 r
.54517 .13316 .55248 .14271 .56623 .13755 .55898 .12832 Mtetra
.633 .738 .924 r
.55898 .12832 .56623 .13755 .58006 .13236 .57287 .12408 Mtetra
.664 .777 .933 r
.57287 .12408 .58006 .13236 .59398 .12834 .58681 .11883 Mtetra
.677 .751 .907 r
.58681 .11883 .59398 .12834 .60795 .12333 .60082 .1131 Mtetra
.675 .734 .894 r
.60082 .1131 .60795 .12333 .62198 .11765 .61489 .10733 Mtetra
.671 .731 .895 r
.61489 .10733 .62198 .11765 .63607 .11186 .62903 .1017 Mtetra
.667 .734 .9 r
.62903 .1017 .63607 .11186 .65023 .10622 .64325 .09619 Mtetra
.665 .738 .904 r
.64325 .09619 .65023 .10622 .66447 .10073 .65754 .09074 Mtetra
.664 .74 .906 r
.65754 .09074 .66447 .10073 .67879 .09531 .67191 .0853 Mtetra
.664 .741 .907 r
.67191 .0853 .67879 .09531 .69318 .08989 .68635 .07985 Mtetra
.68635 .07985 .69318 .08989 .70764 .08446 .70087 .07436 Mtetra
.70087 .07436 .70764 .08446 .72218 .079 .71546 .06885 Mtetra
.71546 .06885 .72218 .079 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29234 Mtetra
.09338 .29234 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29166 .11684 .28343 Mtetra
.11684 .28343 .12544 .29166 .13722 .28722 .12865 .27895 Mtetra
.12865 .27895 .13722 .28722 .14905 .28276 .14051 .27444 Mtetra
.663 .74 .907 r
.14051 .27444 .14905 .28276 .16093 .27832 .15243 .26993 Mtetra
.662 .739 .907 r
.15243 .26993 .16093 .27832 .17286 .27394 .1644 .26542 Mtetra
.66 .736 .906 r
.1644 .26542 .17286 .27394 .18483 .2697 .17642 .26097 Mtetra
.656 .731 .905 r
.17642 .26097 .18483 .2697 .19684 .26559 .18848 .25662 Mtetra
.651 .724 .903 r
.18848 .25662 .19684 .26559 .20891 .26144 .20059 .25239 Mtetra
.649 .723 .902 r
.20059 .25239 .20891 .26144 .22109 .25683 .21275 .24819 Mtetra
.657 .736 .908 r
.21275 .24819 .22109 .25683 .23341 .25124 .225 .24374 Mtetra
.678 .773 .922 r
.225 .24374 .23341 .25124 .24573 .24624 .23736 .23866 Mtetra
.698 .777 .913 r
.23736 .23866 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.664 .741 .907 r
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32067 .21794 .31261 .20907 Mtetra
.31261 .20907 .32067 .21794 .33337 .21314 .32534 .20423 Mtetra
.32534 .20423 .33337 .21314 .34613 .20832 .33814 .19937 Mtetra
.33814 .19937 .34613 .20832 .35895 .20348 .351 .19448 Mtetra
.351 .19448 .35895 .20348 .37184 .19862 .36392 .18957 Mtetra
.36392 .18957 .37184 .19862 .38478 .19373 .37691 .18464 Mtetra
.37691 .18464 .38478 .19373 .39779 .18881 .38996 .17968 Mtetra
.38996 .17968 .39779 .18881 .41086 .18388 .40307 .1747 Mtetra
.40307 .1747 .41086 .18388 .424 .17892 .41625 .16969 Mtetra
.41625 .16969 .424 .17892 .4372 .17393 .42949 .16466 Mtetra
.42949 .16466 .4372 .17393 .45047 .16892 .44279 .15961 Mtetra
.44279 .15961 .45047 .16892 .4638 .16389 .45616 .15453 Mtetra
.45616 .15453 .4638 .16389 .47719 .15883 .4696 .14942 Mtetra
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.631 .728 .918 r
.52403 .12875 .53144 .13834 .54517 .13316 .53781 .12458 Mtetra
.652 .764 .932 r
.53781 .12458 .54517 .13316 .55898 .12832 .55166 .11973 Mtetra
.671 .772 .926 r
.55166 .11973 .55898 .12832 .57287 .12408 .56558 .11424 Mtetra
.676 .743 .901 r
.56558 .11424 .57287 .12408 .58681 .11883 .57957 .10848 Mtetra
.673 .731 .893 r
.57957 .10848 .58681 .11883 .60082 .1131 .59362 .10275 Mtetra
.67 .731 .895 r
.59362 .10275 .60082 .1131 .61489 .10733 .60774 .09713 Mtetra
.667 .734 .9 r
.60774 .09713 .61489 .10733 .62903 .1017 .62194 .09162 Mtetra
.665 .738 .904 r
.62194 .09162 .62903 .1017 .64325 .09619 .63621 .08615 Mtetra
.664 .74 .906 r
.63621 .08615 .64325 .09619 .65754 .09074 .65055 .08069 Mtetra
.664 .741 .907 r
.65055 .08069 .65754 .09074 .67191 .0853 .66497 .07521 Mtetra
.66497 .07521 .67191 .0853 .68635 .07985 .67946 .0697 Mtetra
.67946 .0697 .68635 .07985 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .0586 Mtetra
.70868 .0586 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28859 .08174 .29677 .09338 .29234 .08465 .28412 Mtetra
.08465 .28412 .09338 .29234 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28343 .10817 .27513 Mtetra
.10817 .27513 .11684 .28343 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27444 .1319 .26606 Mtetra
.1319 .26606 .14051 .27444 .15243 .26993 .14385 .2615 Mtetra
.663 .74 .907 r
.14385 .2615 .15243 .26993 .1644 .26542 .15586 .25692 Mtetra
.663 .739 .907 r
.15586 .25692 .1644 .26542 .17642 .26097 .16792 .25235 Mtetra
.661 .737 .906 r
.16792 .25235 .17642 .26097 .18848 .25662 .18003 .2478 Mtetra
.658 .732 .904 r
.18003 .2478 .18848 .25662 .20059 .25239 .19219 .24333 Mtetra
.653 .726 .902 r
.19219 .24333 .20059 .25239 .21275 .24819 .20439 .23897 Mtetra
.65 .722 .901 r
.20439 .23897 .21275 .24819 .225 .24374 .21665 .23467 Mtetra
.652 .727 .904 r
.21665 .23467 .225 .24374 .23736 .23866 .22897 .23029 Mtetra
.663 .749 .914 r
.22897 .23029 .23736 .23866 .24983 .23291 .24138 .2256 Mtetra
.68 .783 .928 r
.24138 .2256 .24983 .23291 .26227 .22819 .2539 .22039 Mtetra
.696 .775 .912 r
.2539 .22039 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.664 .741 .907 r
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36392 .18957 .35594 .18045 Mtetra
.35594 .18045 .36392 .18957 .37691 .18464 .36896 .17547 Mtetra
.36896 .17547 .37691 .18464 .38996 .17968 .38205 .17047 Mtetra
.38205 .17047 .38996 .17968 .40307 .1747 .3952 .16544 Mtetra
.3952 .16544 .40307 .1747 .41625 .16969 .40842 .16039 Mtetra
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.633 .729 .917 r
.48911 .12955 .49668 .13914 .51032 .13396 .50278 .12532 Mtetra
.65 .762 .931 r
.50278 .12532 .51032 .13396 .52403 .12875 .51654 .12052 Mtetra
.667 .78 .934 r
.51654 .12052 .52403 .12875 .53781 .12458 .53037 .11518 Mtetra
.674 .753 .91 r
.53037 .11518 .53781 .12458 .55166 .11973 .54426 .10953 Mtetra
.674 .735 .896 r
.54426 .10953 .55166 .11973 .56558 .11424 .55823 .10379 Mtetra
.671 .729 .893 r
.55823 .10379 .56558 .11424 .57957 .10848 .57226 .09811 Mtetra
.668 .731 .897 r
.57226 .09811 .57957 .10848 .59362 .10275 .58636 .09253 Mtetra
.666 .735 .901 r
.58636 .09253 .59362 .10275 .60774 .09713 .60053 .08702 Mtetra
.665 .738 .905 r
.60053 .08702 .60774 .09713 .62194 .09162 .61478 .08154 Mtetra
.664 .74 .906 r
.61478 .08154 .62194 .09162 .63621 .08615 .6291 .07605 Mtetra
.664 .74 .907 r
.6291 .07605 .63621 .08615 .65055 .08069 .6435 .07055 Mtetra
.664 .741 .907 r
.6435 .07055 .65055 .08069 .66497 .07521 .65797 .06502 Mtetra
.65797 .06502 .66497 .07521 .67946 .0697 .67251 .05946 Mtetra
.67251 .05946 .67946 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .0586 .70182 .04826 Mtetra
.70182 .04826 .70868 .0586 .72339 .05301 .7166 .04262 Mtetra
.06413 .28033 .07297 .28859 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27513 .09942 .26677 Mtetra
.09942 .26677 .10817 .27513 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26606 .12322 .25762 Mtetra
.12322 .25762 .1319 .26606 .14385 .2615 .1352 .25301 Mtetra
.1352 .25301 .14385 .2615 .15586 .25692 .14724 .24838 Mtetra
.664 .74 .907 r
.14724 .24838 .15586 .25692 .16792 .25235 .15933 .24374 Mtetra
.663 .74 .907 r
.15933 .24374 .16792 .25235 .18003 .2478 .17148 .23909 Mtetra
.662 .738 .906 r
.17148 .23909 .18003 .2478 .19219 .24333 .18369 .23446 Mtetra
.659 .734 .905 r
.18369 .23446 .19219 .24333 .20439 .23897 .19594 .22986 Mtetra
.656 .728 .902 r
.19594 .22986 .20439 .23897 .21665 .23467 .20825 .22534 Mtetra
.653 .723 .9 r
.20825 .22534 .21665 .23467 .22897 .23029 .22061 .22089 Mtetra
.652 .722 .9 r
.22061 .22089 .22897 .23029 .24138 .2256 .23302 .21645 Mtetra
.654 .73 .905 r
.23302 .21645 .24138 .2256 .2539 .22039 .2455 .21193 Mtetra
.662 .75 .916 r
.2455 .21193 .2539 .22039 .26652 .21462 .25807 .20718 Mtetra
.672 .782 .932 r
.25807 .20718 .26652 .21462 .27911 .20981 .27072 .20211 Mtetra
.682 .779 .924 r
.27072 .20211 .27911 .20981 .29176 .20497 .28345 .19671 Mtetra
.687 .766 .911 r
.28345 .19671 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.664 .741 .907 r
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.641 .733 .915 r
.44069 .13555 .44846 .14509 .46194 .13993 .4542 .13109 Mtetra
.648 .754 .927 r
.4542 .13109 .46194 .13993 .47549 .13476 .46778 .12639 Mtetra
.658 .772 .933 r
.46778 .12639 .47549 .13476 .48911 .12955 .48144 .12136 Mtetra
.668 .781 .934 r
.48144 .12136 .48911 .12955 .50278 .12532 .49518 .116 Mtetra
.673 .754 .912 r
.49518 .116 .50278 .12532 .51654 .12052 .50899 .11041 Mtetra
.673 .736 .898 r
.50899 .11041 .51654 .12052 .53037 .11518 .52286 .10473 Mtetra
.671 .728 .893 r
.52286 .10473 .53037 .11518 .54426 .10953 .5368 .09905 Mtetra
.669 .728 .894 r
.5368 .09905 .54426 .10953 .55823 .10379 .55081 .09344 Mtetra
.666 .732 .898 r
.55081 .09344 .55823 .10379 .57226 .09811 .56489 .0879 Mtetra
.665 .736 .902 r
.56489 .0879 .57226 .09811 .58636 .09253 .57904 .0824 Mtetra
.664 .738 .905 r
.57904 .0824 .58636 .09253 .60053 .08702 .59326 .07691 Mtetra
.664 .74 .907 r
.59326 .07691 .60053 .08702 .61478 .08154 .60756 .0714 Mtetra
.664 .741 .907 r
.60756 .0714 .61478 .08154 .6291 .07605 .62193 .06587 Mtetra
.62193 .06587 .6291 .07605 .6435 .07055 .63637 .06032 Mtetra
.63637 .06032 .6435 .07055 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04262 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .26291 Mtetra
.07875 .26291 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12322 .25762 .11445 .24909 Mtetra
.11445 .24909 .12322 .25762 .1352 .25301 .12647 .24445 Mtetra
.12647 .24445 .1352 .25301 .14724 .24838 .13854 .23978 Mtetra
.13854 .23978 .14724 .24838 .15933 .24374 .15067 .23509 Mtetra
.664 .74 .907 r
.15067 .23509 .15933 .24374 .17148 .23909 .16285 .23038 Mtetra
.663 .74 .907 r
.16285 .23038 .17148 .23909 .18369 .23446 .17509 .22566 Mtetra
.663 .739 .906 r
.17509 .22566 .18369 .23446 .19594 .22986 .18739 .22093 Mtetra
.661 .736 .905 r
.18739 .22093 .19594 .22986 .20825 .22534 .19975 .21623 Mtetra
.659 .732 .903 r
.19975 .21623 .20825 .22534 .22061 .22089 .21215 .21155 Mtetra
.657 .727 .901 r
.21215 .21155 .22061 .22089 .23302 .21645 .22462 .20693 Mtetra
.655 .723 .899 r
.22462 .20693 .23302 .21645 .2455 .21193 .23713 .20234 Mtetra
.654 .722 .899 r
.23713 .20234 .2455 .21193 .25807 .20718 .24971 .19774 Mtetra
.655 .727 .902 r
.24971 .19774 .25807 .20718 .27072 .20211 .26236 .1931 Mtetra
.659 .74 .91 r
.26236 .1931 .27072 .20211 .28345 .19671 .27507 .18834 Mtetra
.663 .758 .921 r
.27507 .18834 .28345 .19671 .29626 .19108 .28786 .18346 Mtetra
.667 .781 .934 r
.28786 .18346 .29626 .19108 .30907 .18616 .30072 .17842 Mtetra
.67 .78 .932 r
.30072 .17842 .30907 .18616 .32194 .18121 .31365 .17329 Mtetra
.671 .776 .929 r
.31365 .17329 .32194 .18121 .33488 .17624 .32664 .1681 Mtetra
.67 .771 .926 r
.32664 .1681 .33488 .17624 .34788 .17124 .33969 .1629 Mtetra
.668 .767 .924 r
.33969 .1629 .34788 .17124 .36094 .16621 .3528 .15775 Mtetra
.665 .763 .923 r
.3528 .15775 .36094 .16621 .37407 .16117 .36597 .15265 Mtetra
.662 .763 .924 r
.36597 .15265 .37407 .16117 .38726 .1561 .37921 .14762 Mtetra
.66 .764 .927 r
.37921 .14762 .38726 .1561 .40052 .151 .3925 .14263 Mtetra
.659 .768 .93 r
.3925 .14263 .40052 .151 .41385 .14588 .40587 .13764 Mtetra
.661 .773 .933 r
.40587 .13764 .41385 .14588 .42724 .14073 .4193 .13259 Mtetra
.663 .778 .934 r
.4193 .13259 .42724 .14073 .44069 .13555 .4328 .12743 Mtetra
.667 .781 .934 r
.4328 .12743 .44069 .13555 .4542 .13109 .44638 .12213 Mtetra
.67 .761 .918 r
.44638 .12213 .4542 .13109 .46778 .12639 .46002 .11669 Mtetra
.671 .744 .905 r
.46002 .11669 .46778 .12639 .48144 .12136 .47373 .11113 Mtetra
.671 .732 .896 r
.47373 .11113 .48144 .12136 .49518 .116 .48752 .10552 Mtetra
.669 .727 .893 r
.48752 .10552 .49518 .116 .50899 .11041 .50136 .0999 Mtetra
.668 .727 .894 r
.50136 .0999 .50899 .11041 .52286 .10473 .51528 .09432 Mtetra
.666 .73 .897 r
.51528 .09432 .52286 .10473 .5368 .09905 .52926 .08877 Mtetra
.665 .734 .901 r
.52926 .08877 .5368 .09905 .55081 .09344 .54332 .08326 Mtetra
.665 .737 .904 r
.54332 .08326 .55081 .09344 .56489 .0879 .55745 .07776 Mtetra
.664 .739 .906 r
.55745 .07776 .56489 .0879 .57904 .0824 .57165 .07225 Mtetra
.664 .74 .907 r
.57165 .07225 .57904 .0824 .59326 .07691 .58592 .06673 Mtetra
.58592 .06673 .59326 .07691 .60756 .0714 .60027 .06118 Mtetra
.664 .741 .907 r
.60027 .06118 .60756 .0714 .62193 .06587 .61469 .0556 Mtetra
.61469 .0556 .62193 .06587 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04436 Mtetra
.64375 .04436 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .033 Mtetra
.67312 .033 .68016 .04348 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .26291 .06982 .25443 Mtetra
.06982 .25443 .07875 .26291 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15067 .23509 .14192 .22637 Mtetra
.14192 .22637 .15067 .23509 .16285 .23038 .15414 .22161 Mtetra
.15414 .22161 .16285 .23038 .17509 .22566 .16642 .21684 Mtetra
.664 .74 .907 r
.16642 .21684 .17509 .22566 .18739 .22093 .17876 .21204 Mtetra
.663 .739 .907 r
.17876 .21204 .18739 .22093 .19975 .21623 .19115 .20723 Mtetra
.662 .738 .906 r
.19115 .20723 .19975 .21623 .21215 .21155 .2036 .20243 Mtetra
.661 .735 .905 r
.2036 .20243 .21215 .21155 .22462 .20693 .21611 .19762 Mtetra
.66 .731 .903 r
.21611 .19762 .22462 .20693 .23713 .20234 .22868 .19284 Mtetra
.658 .727 .9 r
.22868 .19284 .23713 .20234 .24971 .19774 .2413 .18807 Mtetra
.657 .724 .898 r
.2413 .18807 .24971 .19774 .26236 .1931 .25398 .18332 Mtetra
.656 .722 .898 r
.25398 .18332 .26236 .1931 .27507 .18834 .26673 .17857 Mtetra
.656 .723 .898 r
.26673 .17857 .27507 .18834 .28786 .18346 .27954 .17379 Mtetra
.657 .727 .901 r
.27954 .17379 .28786 .18346 .30072 .17842 .29241 .16897 Mtetra
.659 .734 .905 r
.29241 .16897 .30072 .17842 .31365 .17329 .30536 .16408 Mtetra
.66 .742 .91 r
.30536 .16408 .31365 .17329 .32664 .1681 .31837 .15913 Mtetra
.662 .749 .915 r
.31837 .15913 .32664 .1681 .33969 .1629 .33145 .15411 Mtetra
.664 .755 .918 r
.33145 .15411 .33969 .1629 .3528 .15775 .34459 .14903 Mtetra
.665 .759 .92 r
.34459 .14903 .3528 .15775 .36597 .15265 .35781 .14389 Mtetra
.666 .759 .92 r
.35781 .14389 .36597 .15265 .37921 .14762 .37109 .13869 Mtetra
.667 .756 .917 r
.37109 .13869 .37921 .14762 .3925 .14263 .38444 .13343 Mtetra
.668 .751 .913 r
.38444 .13343 .3925 .14263 .40587 .13764 .39786 .1281 Mtetra
.668 .744 .907 r
.39786 .1281 .40587 .13764 .4193 .13259 .41134 .12271 Mtetra
.669 .737 .901 r
.41134 .12271 .4193 .13259 .4328 .12743 .4249 .11724 Mtetra
.668 .731 .897 r
.4249 .11724 .4328 .12743 .44638 .12213 .43852 .11174 Mtetra
.668 .728 .894 r
.43852 .11174 .44638 .12213 .46002 .11669 .4522 .1062 Mtetra
.667 .726 .893 r
.4522 .1062 .46002 .11669 .47373 .11113 .46596 .10066 Mtetra
.667 .727 .895 r
.46596 .10066 .47373 .11113 .48752 .10552 .47978 .09513 Mtetra
.666 .73 .897 r
.47978 .09513 .48752 .10552 .50136 .0999 .49367 .08961 Mtetra
.665 .733 .901 r
.49367 .08961 .50136 .0999 .51528 .09432 .50763 .08411 Mtetra
.665 .736 .903 r
.50763 .08411 .51528 .09432 .52926 .08877 .52166 .07861 Mtetra
.664 .738 .905 r
.52166 .07861 .52926 .08877 .54332 .08326 .53576 .0731 Mtetra
.664 .74 .906 r
.53576 .0731 .54332 .08326 .55745 .07776 .54994 .06758 Mtetra
.664 .74 .907 r
.54994 .06758 .55745 .07776 .57165 .07225 .56419 .06203 Mtetra
.664 .741 .907 r
.56419 .06203 .57165 .07225 .58592 .06673 .57851 .05646 Mtetra
.57851 .05646 .58592 .06673 .60027 .06118 .5929 .05086 Mtetra
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04523 Mtetra
.60737 .04523 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04436 .63654 .03387 Mtetra
.63654 .03387 .64375 .04436 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .033 .66602 .0224 Mtetra
.66602 .0224 .67312 .033 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22161 .14536 .21277 Mtetra
.14536 .21277 .15414 .22161 .16642 .21684 .15767 .20795 Mtetra
.15767 .20795 .16642 .21684 .17876 .21204 .17004 .20311 Mtetra
.17004 .20311 .17876 .21204 .19115 .20723 .18246 .19825 Mtetra
.663 .74 .907 r
.18246 .19825 .19115 .20723 .2036 .20243 .19495 .19337 Mtetra
.663 .739 .907 r
.19495 .19337 .2036 .20243 .21611 .19762 .2075 .18849 Mtetra
.662 .738 .907 r
.2075 .18849 .21611 .19762 .22868 .19284 .22011 .1836 Mtetra
.661 .737 .906 r
.22011 .1836 .22868 .19284 .2413 .18807 .23277 .17873 Mtetra
.66 .735 .905 r
.23277 .17873 .2413 .18807 .25398 .18332 .2455 .17387 Mtetra
.659 .733 .904 r
.2455 .17387 .25398 .18332 .26673 .17857 .25828 .16901 Mtetra
.657 .731 .904 r
.25828 .16901 .26673 .17857 .27954 .17379 .27113 .16416 Mtetra
.658 .73 .903 r
.27113 .16416 .27954 .17379 .29241 .16897 .28404 .15929 Mtetra
.28404 .15929 .29241 .16897 .30536 .16408 .29702 .15439 Mtetra
.659 .731 .903 r
.29702 .15439 .30536 .16408 .31837 .15913 .31006 .14942 Mtetra
.66 .733 .903 r
.31006 .14942 .31837 .15913 .33145 .15411 .32318 .14439 Mtetra
.662 .734 .903 r
.32318 .14439 .33145 .15411 .34459 .14903 .33636 .13929 Mtetra
.663 .735 .903 r
.33636 .13929 .34459 .14903 .35781 .14389 .34962 .1341 Mtetra
.665 .736 .903 r
.34962 .1341 .35781 .14389 .37109 .13869 .36294 .12883 Mtetra
.666 .736 .902 r
.36294 .12883 .37109 .13869 .38444 .13343 .37633 .12349 Mtetra
.667 .735 .901 r
.37633 .12349 .38444 .13343 .39786 .1281 .38979 .11808 Mtetra
.668 .735 .9 r
.38979 .11808 .39786 .1281 .41134 .12271 .40332 .1126 Mtetra
.668 .734 .899 r
.40332 .1126 .41134 .12271 .4249 .11724 .41692 .1071 Mtetra
.41692 .1071 .4249 .11724 .43852 .11174 .43058 .10156 Mtetra
.667 .734 .9 r
.43058 .10156 .43852 .11174 .4522 .1062 .44431 .09603 Mtetra
.667 .736 .901 r
.44431 .09603 .4522 .1062 .46596 .10066 .4581 .09051 Mtetra
.666 .737 .903 r
.4581 .09051 .46596 .10066 .47978 .09513 .47197 .08499 Mtetra
.665 .738 .904 r
.47197 .08499 .47978 .09513 .49367 .08961 .4859 .07948 Mtetra
.665 .739 .906 r
.4859 .07948 .49367 .08961 .50763 .08411 .49991 .07396 Mtetra
.664 .74 .906 r
.49991 .07396 .50763 .08411 .52166 .07861 .51399 .06844 Mtetra
.664 .74 .907 r
.51399 .06844 .52166 .07861 .53576 .0731 .52814 .06289 Mtetra
.664 .741 .907 r
.52814 .06289 .53576 .0731 .54994 .06758 .54236 .05732 Mtetra
.54236 .05732 .54994 .06758 .56419 .06203 .55666 .05172 Mtetra
.55666 .05172 .56419 .06203 .57851 .05646 .57103 .04609 Mtetra
.57103 .04609 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04523 .59999 .03475 Mtetra
.59999 .03475 .60737 .04523 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool3000002l0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000
oooo0?ooo`1N0?ooo`00^`3oool300000380ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000003D0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000000030:Vmi`2Y_NP0ZKgX00<0ZKgX1P2Y_NLZ0:Vmj0030000002Y_NP0
ZKgX00X0ZKgX00<000000?ooo`3oool0G03oool00;@0oooo0P0000040:Vmi`040000002Y_NL0ZKgX
0:Vmj0<0ZKcW1P2Y_NL20:Vmj0<0ZKgW902Y_NP00`000000ZKgX0:Vmj00:0:Vmj0030?ooo`000000
oooo05`0oooo002a0?ooo`<000000P2Z_NL60:Vmi`H0ZKcW2`2Y_NL>0:Vmj0<0ZKgW4P2Y_NP00`00
0000ZKgX0:Vmj00;0:Vmj0800000G03oool00:h0oooo0`0000000`2Z_>L0Z[gW0:Zmi`030:Zmi`<0
ZKgW0`2Z_>L60:Vli`D0Z[cW1P2Y_NL50:Vli`D0ZKgX1`2Y_NLA0:Vmj0030000002Y_NP0ZKgX00`0
ZKgX00<000000?ooo`3oool0FP3oool00:`0oooo100000030:Zli`D0Z[gW1P2Z_>L30:Vli`<0Z[_V
1@2Z_>L30:Vmi`<0Z[cV1@2Y_>L20:Vmj0<0Z[cW2`2Y_NL<0:Vmj0030000002Y_NP0ZKgX00`0ZKgX
00<0oooo0000003oool0FP3oool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`800000
202Z_>L50:ZkiPD0Z[cW1P2Z^nH50:Zli`L0Z[cV102Y_>L60:Zli`<0ZKgW0`2Z_>L50:Vmi`<0ZKgX
0`2Y_NL50:Vmj0030000002Y_NP0ZKgX00d0ZKgX00<0oooo0000003oool0F@3oool007X0oooo00H0
ooo405lD000DGl@0oooo0<AO5000=HlW0?ooo`<00000202Z_>L30:Zji@D0Z[_V0P2Z_>L30:Zji@H0
Z[_V0P2Z_>L30:Zki@/0Z[cV302Z_>L;0:Vmi`@0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000
oooo0?ooo`1H0?ooo`00NP3oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool20000
00<0Z[cV1@2Z_>L60:Zji@D0Z[_V1P2Z^^D50:ZkiPH0Z[_U0`2Z_>H30:^ki@D0Z[cV0`2Z_>L30:Zk
iPX0Z[cW1P2Y_NL50:Vmj0030000002Y_NP0ZKgX00d0ZKgX00<0oooo0000003oool0F03oool007X0
oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo0240oooo100000050:ZliP80Z[cW2@2Z^^D2
0:ZkiP<0Zk[T1P2Z^^D50:^ji0D0Z[_U1`2[^nD40:ZliPL0Z[_V0P2Z_>L30:ZkiPD0Z[cW0`2Y_NL3
0:Zli`@0ZKgX00<000000:Vmj02Y_NP03P2Y_NP00`000000oooo0?ooo`1G0?ooo`00NP3oool01`3o
ScD001AO0<Coo`3oool0oon?03D0501Oa?l07`3oool2000000D0Z[_V102Z_>H;0:Zji@H0Zk[T0`2Z
^^D80:^ji080Z[_U0`2[^^@;0:^ki@`0Z[_V2`2Z_>L30:Vmj0030000002Y_NP0ZKgX00l0ZKgX00<0
00000?ooo`3oool04P3oool01@3OW4P000000000000004P0W=oo03l0oooo001j0?ooo`070?o4G`0D
55l0a?oo0?ooo`3oohl0=@0D05o4o`0L0?ooo`<0000000<0Zk_V0:ZkiP2Z^nH0102Z^nH50:Zii0H0
Z[[U6`2[^^@30:^ki@<0[;_T1@2[^nD30:ZkiP<0Zk_U1@2Z^nH50:ZliPH0Z[cW0`2Z_NL00`000000
Z[gW0:Vmj00?0:Vmj0030?ooo`000000oooo0140oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0
_ooo03h0oooo001j0?ooo`070?ooS`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`<000001@2[
^nH30:ZkiP<0Zk[T1@2Z^N@30:Zji@<0Zk_U1`2[^^@30:bli@H0Zk[T1@2/_>D60:^ji0D0[;_T302[
^nD20:ZkiP<0Zk_U1@2Z_>H30:Zli`<0Z[cV0P2Z_NL00`000000Z[gW0:Zmi`030:Vmj0<0Z[gW2P2Y
_NP00`000000oooo0?ooo`0E0?ooo`030;md001d_ol0oooo03d0oooo001j0?ooo`060?ooa01O5000
=Hoo0?ooo`34Ga@003F?603oool2000000030:^kiP000000Zk_V00H0Zk_V1@2[^^@60:Zii0H0Zk_U
102[^^@60:bli@<0Zk[T0`2/`>P50:bli@<0Zk[T0`2]_^H50:bki080Zk_U0`2/^n@;0:^ki@`0Z[cV
00<0Z[gW0000002Z_NL0202Z_NL20:Vmj0<0ZKgW1@2Y_NP00`000000oooo0?ooo`070?ooo`030?oO
W0180000000000<0000000<0001d0;ooo`3oool0103oool00`2oM000M;oo0?ooo`0m0?ooo`00N`3o
ool01@3oohl0=@000000000055l0a?oo01D0oooo0`0000000`2[_>H0Zk_V0:^kiP060:^kiP<0Zk_U
1@2[^^@30:Zii0<0ZkkW1@2[^nD50:c1j@H0[;cU1@2/`>P50:bli@L0[KkV2P2/^n@30:^ki@<0[KcU
1@2[^nD30:ZliP<0[;_U1@2Z_>H00`2Z_>L000000:Zli`020:Zli`H0Z[gW1P2Y_NL40:Vmj0030?oo
o`000000oooo00l0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo03h0oooo002C0?ooo`80
00001@2[_>H50:^kiPH0Zk_U102[^^@70:^ni`80Zk_U0`2[anl50:c1j@<0[;cU0`2Zanl50:c0j080
[;cU0`2[aNd60:fniPD0[L3X1P2/^n@60:fli@@0Zk_U1`2/^nD20:ZliP<0Zk_U00<000000:Zli`2Z
_>L00P2Z_>L30:Zmi`<0Z[cW1@2Y_NL50:Vmj0030000003oool0oooo00h0oooo00<0oono07@00000
00000P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool300000080Z[cV2`2[_>H50:^ki@D0Zl;[
1P2[_^L60:_7k`D0[<7Y1P2Zanl40:c0j0H0ZlG]0`2]_^H30:W6kPD0[L3X0`2/^n@30:g1j0X0[KcU
1P2/^nD50:^ki@030000002Z_>L0Z[cW00T0Z[cW0P2Y_NL30:Zmi`D0ZKgX00<000000?ooo`3oool0
3@3oool00`3ooml0W4Q809cOo`120?ooo`00SP3oool2000000030:ZliP000000Z[cV00<0Z[cV0`2[
_>H30:^nj0D0ZkcV0P2[^nD30:[7k`D0Zl;[0`2[_^L30:S5kPD0ZlO_1P2V`nh50:[7k`D0Y/?^1P2[
aNd60:W6kP@0[L3X1`2]`NP20:fli@<0[L7X1@2]_>D30:bki@<0[KcT102[^nD00`000000ZkcV0:^l
iP030:^liPH0Z[cW1P2Z_NL40:Vmj0030?ooo`000000oooo00h0oooo00<0_g@007Boo`3oool0@@3o
ool008/0oooo0`0000080:ZliPL0ZkkX102[_>H60:[7k`D0Zl;[1P2XaNh20:_7k`<0X[[Z1P2V`nh5
0:6jj`D0Y/?^1P2R_>`50:W6kPD0Z<G^302]`NP40:fli@L0[KcT0P2[^nD00`2]_>D000000:fli@0;
0:^liPD0Z[gW1@2Y_NL00`000000oooo0?ooo`0=0?ooo`060=nLB000000000000000000007@0_ooo
?P3oool008T0oooo0P0000020:Zli`L0Z[cV0`2[`>T60:^nj0H0ZLO_1@2Zanl50:G1k@D0Z<G^1P2R
^^X30:K3kP<0ZKgX1@2Q^^/20:K3kP<0YkcY1P2R_>`50:2ij`D0Z<G^1P2V`nh50:g1j0D0[L3X1P2]
_>@30:fli@030000002]_>D0[KcU0080ZkcV0`2/_>D60:^liPD0Z[gW1@2Y_NL00`000000oooo0?oo
o`1@0?ooo`00QP3oool3000000D0Z[cW102Z_>H60:_0j@<0ZkkX0`2YaNh60:W7k`D0Y;_Z1@2U`Nd6
0:Vmj0D0X[[Z1P2Y_NP40:6jj`H0YkcY0`2R_>`30:Vmj0D0X;W[0P2XaNh30:6jjPH0Y/?^0P2]`NP3
0:O3kPD0[L3X0`2]_>@30:joi`80[KcU00<000000:fli@2]_>D01P2/_>D50:^liPH0Z[gW102Y_NL0
0`3oool000000?ooo`1@0?ooo`00Q03oool300000080ZKcW1@2Z_>L50:[1jPH0Zl3Y1P2YaNh30:W7
k`<0ZKgX1@2T^nX20:G1kAP0ZKgX1P2W_>T60:Vmj0@0X;W[1P2Q^^X50:K3kPH0Yl?^102]`>P70:jo
i`030:fli@000000[[gU0080[[gU1@2/_>D60:bliPX0Z[gW00<000000?ooo`3oool0C`3oool00840
oooo0`0000030:Vli`030000002Y_>L0ZKcW0080Z[cW0`2Z`^/50:[1jP<0Zl3Y0`2Xa>h50:W5kPL0
ZKgX102T^nXK0:Vmj0<0YkcY3@2Y_NP;0:6jjPD0Yl?^1@2XaNh60:joi`030:jmi@000000[[gU00<0
[[gU0P2/_>D30:jmi@H0[;cV0P2Z_NL30:^liPD0Z[gW00<000000?ooo`3oool0CP3oool007l0oooo
0P0000040:Vki`D0ZKcW1P2Z`^/50:[1jPH0Z<C^0P2YaNhi0:Vmj0<0XK[Z0`2Y_NP50:6jjPD0X;W[
1@2XaNh30:joi`<0ZlC]00<000000:jmi@2^_ND0202^_ND50:bliPH0ZkcV1@2Z_NL00`000000oooo
0?ooo`1=0?ooo`00O03oool300000080Z;_W1@2Y^nL;0:[2j`D0Z<?]1@2Xa>i20:Vmj080XK[Z0`2Y
_NP50:2ij`@0Z<G^1P2[a>d00`000000[[gU0:jmi@030:g1j@D0[[gU1P2]_>D50:^liPD0Z[gW00<0
00000?ooo`3oool0C@3oool004/0oooo00D0a5lD000000000000000D05o4o`0Y0?ooo`<0000000<0
Z;_W0000002X^nL00`2X^nL20:Vki`<0ZL7[202Z`^/30:W3k0D0Z<?]C02Y_NP40:2ij`D0WkW[1@2[
a>d00`000000[L7Y0:g1j@040:g1j@80[[gU0`2^_nH60:fli@80ZkcV0`2/_>H50:Zmi`030000003o
ool0oooo04`0oooo001:0?ooo`070?n?=@0055l0a?oo0?ooo`3ool@0Ga@e08ooo`0V0?ooo`800000
2@2X^nL60:W1j`D0Z/;[1P2Y`n`20:S3kE<0ZKgX1@2O^N/50:6lk0030000002]`NT0[L7Y00<0[L7Y
1P2^_nH50:fli@H0[;cV0P2Z_NL20:Zli`030000003oool0oooo04`0oooo001?0?ooo`0308le000e
Sol0oooo0280oooo0`0000020:Rji`L0Z;_W0`2Y_nX60:W1j`D0Z/?/1@2Y`naF0:Vmj080WkW[0`2W
_>T40:6lk0040000002Q_>`0[L7Y0:g1j@<0YlC^1@2^_nH60:jmi@D0[;cV1@2Z_>L00`000000oooo
0?ooo`1;0?ooo`00@P3oool00`3oa5l0500000000003000000030000=@2?ool0oooo00@0oooo00<0
ScD003F?o`3oool0803oool2000000H0Z;[W102X^nL60:VojP<0ZL7[0`2[a>`50:[3k1h0ZKgX0`2Y
^>@70:Vmj0<0YZKF202Y_NP30:NZfB@0ZKgX1P2W_>T30:6lk0030000002Q_>`0YlC^00D0YlC^0P2^
_nH30:c1j@D0[[gU0`2/_>H30:fmi@D0Z[cW00<000000?ooo`3oool0BP3oool004X0oooo00L0olAO
01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0oooo0`0000000`2X^^L000000:Rji`050:Rji`H0Z;gX
1@2Y_nX60:_4k080Z/?/7P2Y_NP60:Vhi0@0ZKgX1P2VY]H40:Vmj0L0Yj[I0P2Y_NP30:>HbQl0ZKgX
1@2W_>T30:6jjP030000002Q^^X0XK[Z00D0YlC^1P2/`NT40:jmi@L0[KgU0P2Z_>L20:^liP030000
003oool0oooo04X0oooo001:0?ooo`030?ooS`0e000000000080000000<0=Hoo0?ooo`3oool06`3o
ool200000080Z;_W1`2X^^L30:Rki`H0Z;gX1@2[aNd50:_4k1h0ZKgX0`2UX]<50:Vhi0D0X9331@2V
Y]H509n=`@H0Yj[I1P2SV<XT0:Vmj080XK[Z00@000000:6jjP2Q^^X0XK[Z1@2N^>/50:c1j@D0[[kV
1P2]_ND50:^liP030000003oool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`00
00050:Rki`@0Z;[W1P2X^nL30:Rmj0<0ZlK]1@2[aNdO0:Vmj0L0YJ;C0P2Y^>@309n7^@@0X933102V
Y]H20:b@^@D0Whg10`2WZ]T30:Z@^`D0XiS:1@2PT<<P0:Vmj0030:6jjP000000XK[Z00<0ZKgX1@2N
^>/20:c1j@<0Y/?^1@2^_^H30:fmi@<0[[gU1@2[_>H00`000000oooo0?ooo`180?ooo`00B`3oool0
0`2?=@00=Hoo0?ooo`0J0?ooo`8000002@2X^nL50:RjiPD0Z;_W1P2[a^d20:_5kAd0ZKgX1@2RULL6
0:FRd`D0WhNi1@2PT<<20:JVeP<0[92i1P2OSL450:Z@^`@0XiS:0P2jW;X50:2@``D0X8g06`2Y_NP0
0`000000ZKgX0:Vmj0030:Vmj0@0W[S[1P2V`nh40:jniPH0[[gU1@2[_>H00`000000oooo0?ooo`18
0?ooo`00B`3oool01P34Ga@00000000000000000000e08oooa<0oooo00L0Z;cW0000000000000000
0:Rli`2X^nL0000000@0Z;_W1@2W^ND50:RjiPD0ZlO^1@2[a^dM0:Vmj0<0Whg11@2RULL40:FRd`80
[92h102OQkT50:2@``H0[92i102OSL420;^N^`D0ZY2k0P2SV<X30;ZL^PD0X93300<0`j>i0:2=`02P
SL000`2PSL030:Vmj0<0XI32502Y_NP00`000000ZKgX0:Vmj0030:Vmj0D0X[[Z1@2V`nh50:g0j0D0
[[gU1P2[_>H00`000000oooo0?ooo`170?ooo`00HP3oool00`2Y_>L00000000000050:Rli`<0Z;_W
0`2W^>D50:Nii@80Z;[V0`2Zanl50:_7kQl0ZKgX1P2OSL450::Ea`80YJ;C0`2/T;P509n7^@<0X933
0P2eVK/50:b@^@<0Whg10`2kW[/50:Z@^`030:>HbP2jW;X0^Ybj0080^Ybj102PT<<20<>S^@H0X8g0
1P2QT<820:Vmj0<0XiS93P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0D0X[[Z1@2N^>/50:g0j0D0[[kU
1P2[_>H00`000000oooo0?ooo`160?ooo`00G`3oool4000000<0ZKcW1@2X_>L60:Nhi@@0YkWU1P2Z
anl30:_7kQ`0ZKgX1@2NRKd509n=`@D0XYG71@2/T;P509n7^@80X9330`2eVK/60:b@^@0309n=`@2k
W[/0^ijk0080^ijk1@2ZT;/60;ZL^P80X9330`33XkT50:2=`080aZNj1@2QT<860:>Hb@d0ZKgX00<0
00000:Vmj02Y_NP01@2Y_NP20::jjP<0ZKgX1@2N^>/20:g0j0<0ZL7[1@2^_^D30:^liP80[;gV00<0
00000?ooo`3oool0AP3oool005d0oooo00@0ZKcX00000000000000001P2Y_>L50:Rii@D0YkSU1P2Y
`^/50:[7ka`0ZKgX0`2MQk/409j9_@H0Whg10P2RULL30:^B^`D0[92h102OQkT50;FI^`H0[92i1P2k
W[/30:Z@^`80`ZW11@2jW;X00`2PT<<0`j>i0<>S^@030<>S^@<0X8g00`36YkX40:6@`P80aJNk1@2S
V<T50:NZf@P0ZKgX00<000000:Vmj02Y_NP02`2Y_NP409jhj`H0ZL7[102^_^D60:bmiP030000003o
ool0oooo04D0oooo001K0?ooo`<00000102Y_>P30:Vli`<0Z;[V1@2X^ND20:Nhi@<0Z;gX1P2Y`^/N
0:Vmj0D0WHNk1@2NRKd509n=`@D0Zi:k1@2/T;P309n7^@80]Z731@2eVK/40:b@^@80_JW61@2kW[/2
0:Z@^`<0`ZW11@2jW;X60<>S^@80X8g01@36YkX20:6@`P<0aJNk102SV<T20;jT_`D0Yj[I1`2Y_NP0
0`000000ZKgX0:Vmj00;0:Vmj0D0X;W[1@2Y`N/50:joiPD0[;gV00<0oooo0000003oool0A@3oool0
05P0oooo0`0000040:Vmj0@0ZKcX1P2X^^H40:Rii@H0Z;gX0`2Y`^/30:o4jAX0ZKgX2@2MQk/409j9
_@@0Whg10P2YTkl40:^B^`D0[92h0P2OQkT30;JQ``D0]IVk0P2/T;T40;fYaPD0^ijk00<0ZY2k0<:Y
`@32ZL400P32ZL440;ZL^P80a[751@33XkT70<JW^P030:6@`P35Yk/0aJNk00<0aJNk0P2SV<T30;jT
_`@0Yj[I0P2aW/D60:Vmj0030000002Y_NP0ZKgX00`0ZKgX1@2P^N/50:C0k@D0[[oV1@2/_NH00`00
0000oooo0?ooo`140?ooo`00E@3oool00`2Y_NP00000000000070:Vmj0D0Z;_W1@2X^^H50:NjiPH0
Z;gX1P2_a>TG0:Vmj0<0WXVm202MQk/509j9_@80Whg10`2YTkl50:^B^`@0[92h1@2fXL<50;FI^`H0
_JW61@2kW[/60<:Y`@80^Ybj0`36/LD40<>S^@80bKK71P36YkX60<FW^`030:>Hb@2nY;l0_ZBo00<0
_ZBo0P2WZ]T40;6Na@D0ZKgX00<000000:Vmj02Y_NP03@2Y_NP20:2ij`<0Y;_Y1@2T`>d20:joiP<0
[KoW1@2/_NH00`000000oooo0?ooo`130?ooo`00D`3oool3000000030:Vmj0000000ZKgX00@0ZKgX
0`2Y_>L50:Rki`<0Z;[V0P2W^>H50:NjiP<0Z;gX0`2^an`50:o4jAD0ZKgX1@2NRKd909f7^`@0WXVm
1@2YTkl50:^B^`80[92h0`2eZLd50;JQ``<0]IVk0P2l^=H60;fYaP<0^ijk0P32^]850<:Y`@030;ZL
^P36/LD0a[7500<0a[750P33XkT30<Vfa`H0aZNj00<0c;O60<FW^`35Yk/00`35Yk/60;jT_`H0/Ik5
1@2VY]D00`000000ZKgX0:Vmj00=0:Vmj0H0Y;_Y102T`>d60:foi`@0[;gV00<0oooo0000003oool0
@`3oool00540oooo0P0000080:Vmj0H0ZKcW1@2X^nL50:NhiPD0Yk[V1P2^an`E0:Vmj0D0Whg1102N
RKd909f7^`80WXVm0`2WU<850:VC_`@0Zi:k1@2eZLd50;JQ``80]IVk102l^=H50;fYaP80^ijk0`32
^]850<:Y`@H0a[7500<0`j>i0<Vfa`39]/L00`39]/L40<JW^P80c;O61@35Yk/00`3>]/80_ZBo0;jT
_`030;jT_`030=2c_@2aW/D0/Ik500<0/Ik500<0bjnn0:JVe@2VY]D00P2VY]D00`000000ZKgX0:Vm
j00>0:Vmj0D0Y;_Y1@2N^>/50:foi`D0[;gV00<000000?ooo`3oool0@P3oool004h0oooo0`000007
0:Vmj0X0ZKcW1@2W^NH50:NhiPD0[<S^0`2^an`C0:Vmj0D0XYG7102OSL4509j9_@P0WHNk1@2WU<85
0:VC_`<0Zi:k0P2c/mP50;FYc@@0]Z731P2l^=H50;fYaPH0`[[B0`32ZL420<?6g@D0a[751P39]/L3
0<JW^P<0c;O61035Yk/20<jf`P@0_ZBo0P3@/kd40;6Na@80bjnn102VY]D00`000000]jK80:Vmj00D
0:Vmj0D0W[S[0P2]_nL30:^oj0D0[;gV00<000000?ooo`3oool0@@3oool001T0oooo00<0omnL04P0
M02oool00P3oool01@3oohl0=@000000000055l0a?oo02T0oooo0P00000;0:Vmj0D0ZKcW1@2X^^H5
0:NiiP80YkSV102Y_nX40:c8kQ<0ZKgX0`2UX]<40::Ea`@0Whg11@2NRKd409f7^`D0Y9C41@2WU<84
0:VC_`80Zi:k0`2c/mP50;FYc@80]Z730`2gb^P60;bheP80_JW60`2jcnX50<:jdP80`ZW10`33a]d4
0<Jaa@80`/gS1P39]/L00`36YkX0c;O60<bgaP030<bgaP80aJNk103>]/820;jT_`@0d;>m0P2aW/D4
0<^__P80YZKE00@0]jK80000002gY/P0]jK85@2Y_NP409jhj`H0ZkoX1@2/_NH00`000000oooo0?oo
o`100?ooo`006@3oool02P3ogi`0B01d0;ooo`3oool0oooO05lD000DGl@0oooo0<AO5000=HlV0?oo
o`<000000P2Y_NP00`000000ZKgX0:Vmj0090:Vmj080ZKcW0`2X^nL50:RjiP@0YkWV1`2Y_nXD0:Vm
j0D0YJ;C102RULL509n=`@@0WXVm0P2MQk/30:6Ba@@0Y9C41@2WU<840:VC_`H0/k?H102eZLd60;O:
j0D0_;SF1P2jcnX40<:jdPH0`lKM0P36/LD40<;=h`D0bKK71P3<]lH00`35Yk/0c[K20<jf`P030<jf
`P030;jT_`3@/kd0d;>m00<0d;>m00<0/Ik50<^__P3;[kh00`3;[kh30;NVb0030000002gY/P0]jK8
00D0ZKST402Y_NP509jhj`D0ZkoX1@2/_NH00`000000oooo0?ooo`0:0?ooo`050?oo_`1d00000000
0018W03Oool0<@3oool001T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0
500e08ooo`0R0?ooo`030:Vmj000000000000140ZKgX1P2X^nL40:RjiPH0Yk[W0`2Y_nX30;;6j@l0
ZKgX1@2Y^>@40:FRd`D0XYG7102OSL4409j9_@D0XI;51@2TU<@40:ND`PD0/K_Q1@2c/mP20;FYc@@0
ZmWh1@2gb^P50:3Oo0D0^/oZ1@2[g?T50<?6g@L0`/gS0P39]/L30<?>h`D0c;O61P3>]/860=2c_@H0
bjnn00L0e;Vn0;NVb02gY/P0]jK80000002gY/P0c;?200D0ZKST402Y_NP509jhj`D0ZKkY1@2/_NH0
0`000000oooo0?ooo`080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0
omnL04P0000000000`0000000`0007@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0
51AO0<Coo`3oool0oon?03D0501Oa?l0803oool300000100ZKgX102Y_>L60:Rki`@0Y[SV1P2W^^L6
0;;6j@l0ZKgX102Y^>@50:FRd`@0XYG7102OSL4509f?a@@0XI;51@2TU<@20:ND`P<0[/;X1@2a^n44
0;>cf0L0ZmWh1@1jgOT50:3Oo0D0MMWj1@2[g?T509WMoPH0`/gS1P33c^<20<bgaP<0a/_M103>]/82
0<c5d`@0d;>m0P3A_/P40<^__P80e;Vn0`2gY/P010000000c;?20<bc`P3</l820:Vhi0<0ZjOC3`2Y
_NP609nij`D0ZKkY0P2/_NH20:bni`030000003oool0oooo00P0oooo00L0oono07@0M02oool0oooo
0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Coo`3oool0
oon?03D0501Oa?l07P3oool300000100ZKgX0`2Y_NL40:Vli`<0Z;_W0`2W^NH40:JhiP<0Yk[W0`2^
b>d50;;6jA00ZKgX102Y^>@40:FRd`@0XYG71@2HR/<409f?a@D0XI;5102TU<@60:k2j0@0/K_Q1`2K
h_d605gCjP@0N]gi1P15a>D407GInPD0DLS`1@2IgOh608oJo`D0`lkS1@36bmd30<jf`P<0c<GC0`3@
/kd30=6nb0<0bjnn103D^Kh20;NVb0040000003</l80c;?20<bc`PH0ZjOC3`2Y_NP509nij`D0ZKkY
1@2/_^L00`000000oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?oo
o`006@3oool02`3ogi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0oooo
0`00000A0:Vmj0H0ZKgW102Y_>L60:NiiP@0Y[SV1P2^b>d20;;6jA80ZKgX102Y^>@40:FRd`D0ThC0
102HR/<509f?a@@0XI;50P2TU<@30:_5k0D0[/;X1`2=i?/6057>h080>[kJ1P20a?d509BekPD0LKSk
100VZn4201bVf`D0?[_]1P2?f_l20<?>h`<0U=On1@36bmd00`3>]/80c<GC0<c5d`030<c5d`030=2c
_@3A_/P0dKk800<0dKk800<0bjnn0=Bi_P3D^Kh00`3D^Kh00`2gY/P0c;?2000000030<bc`P030=Rl
_@2[Ym<0ZjOC00<0ZjOC402Y_NP409nij`H0YkgY1@2/_^L00`000000oooo0?ooo`060?ooo`070?no
M000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool03@2oM000001809boW01807@0_ooo
0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool2000001D0ZKgX1@2Y_NL50:NjiPD0
YkWV1P2Y_nT40:k8kA<0ZKgX0P2MS/<408Yj_0@0SWjm102CQ<0409R:``D0WHo5102QT/D60:_5k080
[/;X1@27iOP205C?gPH0KmSg1@2C^O430834o@<0ZKgX1@2D]Nh50:Vmj0D0NJWa100i[O<201ROgPD0
Sm[o1P2Deoh40<K;g@H0c<GC1P3A_/P60=Bi_P80c;?200<000000<bc`P3</l800P3H_;d40:^Wd`80
_[??3`2Y_NP50:6ijPD0YkgY1@2[_^L00`000000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`0`0?ooo`00603oool02`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo
0?ooo`34Ga@003F?01L0oooo0`00000H0:Vmj0D0Z;_W1@2W^^H50:Jji`H0ZKoY502Y_NP409f>``@0
RWZl102>O[d409>4`0D0V8[3102MSlD50:W4k@D0ZlG/0`27iOP205gEg`H0R]gn1@2T^nT509>il@H0
ZKgX0P2D]Nh80:Vmj080NJWa0`2Y_NP5086/l0D0=ZKc0P0HVn8409CGoPD0YMGi0`3<aM<30;[Aj`@0
dKk80P3;bMP40=Bi_P80e<7700<0c;?20000003</l80103H_;d20:^Wd`@0_[??3`2Y_NP50:6ijP80
YkgY0`2U_>T50:^ni`030000003oool0oooo00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo0300oooo000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D
0?ooo`<0000000<0ZKgX0000002Y_NP05`2Y_NP20:Vli`D0Z;_W0`2W^^H20:JhiPD0Y[[W0`2Y_nT3
0;;6j@l0ZKgX1@2VY]H409f>``<0RWZl102>O[d509>4`0@0V8[30P2MSlD30:O0j`D0ZLC]1@27i_H2
06[Lh`@0VMgn1@2Y_NP50:BkjAX0ZKgX0P21[?030:Vmj0D0NJS`0`0NV^T304Vim`D0YMGi1@2jdN/3
0=6nb0<0blWH0`3D^Kh30=C1a`030<bc`P000000c;?200@0f;bm1P2n/ll@0:Vmj0@0XKWZ1P2U_>T5
0:^ni`030000003oool0oooo00@0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03o
ool00`2Y_NP000000000000K0:Vmj0D0ZKcW1@2X^nL50:JhiPD0Y[[W1P2ba^T?0:Vmj0@0YZKF102M
S/<408Yj_0@0SWjm102CQ<0409R:``H0Yl3[0P2Ya>d508gXmP80J]cS102IgOh/0:Vmj0D0NJS`100N
V^T201nLj@D0Il?n1@2jdN/00`3A_/P0blWH0<_9f0030<_9f0030=Bi_P3D`LL0e<7700<0e<7700<0
00000=Rl_@3H_;d00`3H_;d00`3J`L40_[??0;jcc`020;jcc`80cKc:3`2Y_NP50::jjPD0YKcY1@2[
_^L00`000000oooo0?ooo`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380oooo0`00
000N0:Vmj0D0ZKcW1@2W^NH50:JhiPD0[LG/1@2ba^T?0:Vmj0D0YZKF102MS/<308Yj_0@0SWjm102C
Q<050:BgiPD0Yl3[0`2=j?H207OSiPH0X^3l=02Y_NP4066Kl0<06iCY101W`oh40;[Aj`H0blWH1P3D
`LL00`000000f;bm0=Rl_@020=Rl_@80f/710`2n/ll40<flbPl0ZKgX1@2R^^X50:Bkj@D0ZkkW00<0
00000?ooo`3oool0>P3oool00300oooo0P0000000`2Y_NP000000:Vmj00O0:Vmj0D0Z;_W1@2W^NH2
0:JhiP<0Z;cX1@2]aN`D0:Vmj0@0YZKF102MS/<308Yj_0@0SWjm1@2OZml50:BgiPD0U^_h0P24jNP4
0:KVncT0ZKgX101QVo0401^Dj@80=JGc1@2AcO`30<_9f0<0^LgY103D`LL2000000<0f;bm103J`L40
0`2n/ll0cKc:0<flbP030<flbP030=K2a`2Y_NP0ZKgX00d0ZKgX1@2S^^X50:Bkj@D0ZkkW00<00000
0?ooo`3oool0>@3oool002`0oooo00@0ZKgX00000000000000008`2Y_NP20:Vli`D0Z;_W102W^NH6
0:Rlj0<0[LG/0P2]`NPC0:Vmj0@0YZKF102MS/<308Yj_0D0V9cF1@2OZml20:BgiPD0Wn[j0P24jNP5
0:KVnc/0ZKgX1@2E]Nd303^Hl`<08YC]102AcO`60;W=j@<000000P3@am400`000000f;bm0=[1`@04
0=[1`@D0cKc:0`3F`/L?0:Vmj0D0Xk[Z102T^nT50:^ni`030000003oool0oooo03T0oooo000[0?oo
o`800000902Y_NP50:Vli`D0Z;_W1@2V^NH50:Rlj0D0[L7X2`2Y_NP40:NZf@@0Rh741020Mkl408N0
a@<0Shg=1@2HW=H409n[g`<0Wn[j0P2@k^/70:O^n3h0ZKgX0P2E]Nd30:Vmj0<0JYo`0`0RU>d406:h
o@80^LgY0`0000050=37d@030000003J`L40f/7100@0f/7100@0fLG50<flbP3=_<X0cKc:103F`/L?
0:Vmj0D0Xk[Z1@2T^^T50:^ni`030000003oool0oooo03P0oooo000Y0?ooo`8000009`2Y_NP50:Vl
i`D0Y[WW1@2V^NH50;;8j`D0[L7X2`2Y_NP30:NZf@@0Rh741020Mkl408N0a@@0Shg=1@2HW=H40:KU
n`80W?;^1@2Ulo580:Vmj0@0JYo`0P0TT>d206:ho@<00000102Mb?H40=37d@030<O9g0000000f/71
00<0f/710`3IaLD00`3=_<X0e/;70=K2a`030=K2a`030=c7a@2Y_NP0ZKgX00`0ZKgX1P2S^^X50:Bj
j@D0ZkkX00<000000?ooo`3oool0=`3oool001d0oooo00D0oono07@00000000004RL0=ooo`070?oo
o`800000:02Y_NP50:Nki`D0Y[WW0P2V^NH30:Znj@D0//S[3`2Y_NP40:NZf@<0Rh741020Mkl508N0
a@@0Shg=0P2HW=H40:WIn080W?;^1@2Ulo430:o3jDL0ZKgX1@2?/^h00`0_T>l000000000000304:S
mPD0WLSf0P3@am430<O9g0030000003J`L40f/7100@0fLG51@3F`/L20=c7a@l0ZKgX1@2S^^X60:Fj
j0@0ZkkX00<000000?ooo`3oool0=`3oool001`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l7
0?ooo`030000003oool0000002H0ZKgX0P2X_>L50:Nki`@0Y[WW1P2Z_^TD0:Vmj0<0Yj[I102;PL@4
081g_`@0Qh35102?SLd40:WIn0<0Yo?b102/m^l60:o3jDL0ZKgX0P2?/^h300000080;i3_1012XoH4
09g8mPH0alWL00<000000=W5a@3IaLD00`3IaLD0103HalT0e/;70=K2a`3F`/L30=c7aA00ZKgX1@2R
^^X50:Fjj080ZkkX0`2/_nP00`000000oooo0?ooo`0f0?ooo`00703oool01`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y_NP08@2Y_NP50:Rli`@0Yk_W
1P2V^NL30:Znj@80/lOY4`2Y_NP40:NZf@<0Rh741020Mkl408N0a@H0YLG`0`2Wlo840:cfk`<0_MO]
0`2_`nU80:Vmj0<0000000@0Sk;^0:Bkj@2T^nT0Y;_Y0`19TNl203BEl@D0Ok_i1@37bM`00`000000
fLG50=W5a@020=W5a@<0f<O900<0e/;70=c7a@3LalD00P3LalD00`3Pbl@0ZKgX0:Vmj00>0:Vmj0D0
X[[Z102U^^P60:boj0030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3o
okl0M01809cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP08@2Y_NP50:Rl
i`X0Y[WW1@2canT?0:Vmj0@0T8k>0`1dLL4308^1a0@0P7No1@2JZn<30:G5l0@0/?3f0`2cn>h60;gG
kDL0ZKgX0`0000020:Vmj0D0Y;_Y1019TNl00`0cSnl0=9Ga07nkn@0407nkn@80alWL0`2kb>@00`00
0000fLG50=W5a@040=S7b@@0g<O50`3Pbl@@0:Vmj0@0X[[Z1@2W^nP50:boj0030000003oool0oooo
03D0oooo000L0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0
oooo00<0oooo902Y_NP50:Nji`L0Y[WW0`2/`>T50;?7j@l0ZKgX0`2@S/h407Aa`@<0OGg8102;T]@5
09Z[h`D0/?3f0P2cn>h40;o_lTP0ZKgX0`0000060:Vmj0@0Y;_Y1@19TNl203>?k`@0Ok_i1P2kb>@0
0`000000f<O90=S7b@020=S7b@80e/W=0`3LalD30>3;a0030>;@a@2Y_NP0ZKgX00d0ZKgX1@2Q^NX5
0:Nkj0D0[;oX00<000000?ooo`3oool0=03oool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d
04P0W=oo00D0oooo0P0000050?ooo`030000002Y_NP0ZKgX01l0ZKgX0P2X_>P50:Nji`@0Y[WW1P2/
`>TC0:Vmj0<0T8k>101dLL4407emb0@0Ri;D0P2JZn<50;;Tm`80/oS^1@2oko960:Vmj0<000003P2Y
_NP506:Kk`0303N<kP0cSnl0JZgh00<0JZgh1@2kb>@0103HalT000000=S7b@3HalT40=K9c@040=c7
a@3Pbl@0h<_40>3;a0<0h]353`2Y_NP50:6ijP80Yk_X0`2Y_>L50:boj0030000003oool0oooo03<0
oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000:Vmj02Y_NP0702Y_NP50:Rlj0@0Yk[W1@2V^NL30:c0j@<0//KY4`2Y_NP3092>
cP@0M771101mOLP308^Be0D0/^Cg0P2jmo050<3gkTD0ZKgX0`00000B0:Vmj0@0HY__0`0gS>h406Z]
n0D0[lCY00<000000=S7b@3FbLd0103FbLd30>3;a0@0h]35402Y_NP40:6ijPH0ZKcW0P2/_nP20:c0
j0030000003oool0oooo03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool0
0`000000oooo0?ooo`070?oooah0ZKgX1@2X_>P50:Fii`@0Y[WW1P2ba^T?0:Vmj0<0LWG70`2@S/h4
07Aa`@@0OGg81P2Zbo420;[gl0D0`?O^0`2mdn]10:Vmj0<000005P2Y_NP307>Tl0@0=hc^101NX_@5
0:o4j@030000003FbLd0e/W=0080e/W=0P3Fbll00`3Pbl@0h]350>;@a@030>;@a@030>?Db@2Y_NP0
ZKgX00d0ZKgX1@2O^N/50:Vli`D0[<3X00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@0
0000000004RL0=ooo`060?ooo`030000003oool0oooo00P0oooo7P2Y_NP50:Nki`D0YKWW1@2]`NP5
0;;6j@h0ZKgX101bMLL206mba@@0M7711@2GZ^<30:[;l@<0__3b1035mnd60;gCjch0ZKgX0P00000J
0:Vmj0<0LjC`100nR^`405jRm080[lCY0`2V_n/00`000000e/W=0=K9c@030=K;c`D0h]350`3Se<T?
0:Vmj0@0WkW[1P2[_NL40:c0j0030000003oool0oooo0380oooo000W0?ooo`030000003oool0oooo
00X0oooo6`2Y_NP30:Rlj0D0Yk_W0P2U^NL30:Jii`D0[L7X4P2Y_NP4079ea`<0Kg;51021RM8509NZ
h`@0__3b0`35mnd40<SbkCl0ZKgX0`00000L0:Vmj0@0LjC`100nR^`305VKl@D0Y[o[00<000000=K9
c@3Fbll00`3Fbll0103Fc=00h]350>;@a@3Rd<D40>?Db@030>7Kc`2Y_NP0ZKgX00`0ZKgX1@2N^>/5
0:^mi`D0[<3X00<000000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool02`3ooolH0:Vm
j0H0Z;cX102W^nL60:Jii`80[L7X0`2ba^TB0:Vmj0<0LWG70`1_L/D50869dP80Uj[S1@2hg_<20<Gg
k@@0b?;]0`2Z_^Pk0:Vmj0<00000802Y_NP407ZXl0<0AHW[101IVo450:Joj`040000003Fbll0e/_?
0=K;c`<0e/c@00<0h]350>?Db@3Se<T00P3Se<T30>7Kc`h0ZKgX1@2N^>/20:^mi`<0[KoW1@2/`>P0
0`000000oooo0?ooo`0`0?ooo`009`3oool00`000000oooo0?ooo`0<0?oooaT0ZKgX1@2X_>P50:Fi
i`@0Y[WW1P2ba^T?0:Vmj00305eV``2Y_NP0LWG700<0LWG70`1_L/D40869dPH0^=kc0P37l^d30<gd
jPH0Z[kX=`2Y_NP3000002@0ZKgX101jZ?0304F9j`@0FiO^1@2R^n/00`000000e/_?0=K<d0030=K<
d0@0hmC9103Qfll?0:Vmj0@0W[S[1P2]_nL40:c0j0030000003oool0oooo0300oooo000W0?ooo`80
00003P3ooolI0:Vmj0D0Yk_X1@2U^NL50:boj0@0//KY3`2Y_NP205eV``@0LWG70`1_L/D20869dP@0
Y;g[0`2hg_<20<Obk@<0cOCZ0`3=iNP40:Znj3@0ZKgX0`00000X0:Vmj0@0NZS`00<0BhSY04F9j`15
RN/0101KUnh50::kj`040000003Fc=00e/c@0=K<d080fLo?0P3Se<T40>7Kc`80g>;J3P2Y_NP509jc
i`D0[KoW1@2/`>P00`000000oooo0?ooo`0_0?ooo`009`3oool00`000000oooo0?ooo`0>0?oooa@0
ZKgX1@2X_>P50:Nkj0D0YKWW1@2/_nPB0:Vmj0<0GFK30`1[M<X306mba@L0Y;g[0P37l^d40<gdjPD0
cNGX=02Y_NP3000002`0ZKgX101jZ?0204^8j@@0FiO^1@2R^>T00`000000e/c@0=K<d0040=W?c`@0
hM_?0`3Lh]X?0:Vmj0D0W[?W1@2^`>L50:c0j0030000003oool0oooo02h0oooo000W0?ooo`030000
003oool0oooo00l0oooo502Y_NP50:Rlj0<0Yk_X0P2U^NP50:Fii`80[;oX0`2canTB0:Vmj080GFK3
101[M<X408NEfP<0Y;g[0`33iNl40<oaj@@0cNGX<`2Y_NP3000002l0ZKgX101jZ?0304^8j@@0GiG/
1@2R^>T00`000000fLo?0=W?c`020=W?c`<0gM;>103Lh]X20<cXjPl0ZKgX1@2T]nH40:k0i`D0ZkoX
00<000000?ooo`3oool0;P3oool002L0oooo0P00000A0?ooo`030000002Y_NP0ZKgX0140ZKgX1@2X
_>P50:Fij0@0YKWW1P2canT?0:Vmj003059Ra@2Y_NP0GFK30080GFK30`1[M<X508NEfP@0`nG_103?
lNT30=;_ic80ZKgX0`00000c0:Vmj0@0LjC`0`1AR>L405nEk0@0X[SY00@0fLo?0000003Icll0fLo?
103Md/h00`3Sf</0g>;J0=cRfP040<cXjPX0ZKgX1@2T^nT40:BgiP80[/3W0`2^`NP50:^oj0030000
003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000ZKgX0:Vmj00A0:Vmj0D0Yk_X1@2U
^NP50:^ni`<0/lOY402Y_NP2059Ra@<0GFK3101[M<X208NEfP@0[lO/1@3?lNT20=;_i`<0bN7Y;P2Y
_NP3000003L0ZKgX101cY?030568i`<0IiGY1@2V^NH00`3Icll000000=gBcP030=gBcP80hmS;1P3<
j>X;0:Vmj0@0Y;_Y102T]nH60:k1j0D0ZkoX00<000000?ooo`3oool0;03oool000T0oooo00X0oono
07@00000000004RL0=ooo`3oool0omnL04P0M02oool0gia81@0000000`1d_ol0oooo0=nLB0020000
00030000B02Lgol0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000ZKgX0:Vmj00<0:Vm
j0D0Z;cX1@2W^nP50:Fii`D0ZkkW4`2Y_NP2059Ra@80IWC=101[M<X50:o7k0@0bNG[0P3BknL60<WQ
jB/0ZKgX0P00000k0:Vmj0<0IiS/101AR>L306NEj@D0Y[WV00@000000=gBcP3Md/h0gM;>0`3Sf</2
0>WOb@D0[lGZ2P2Y_NP40:Bkj@D0ZKcW1P2^`NP40:^oj0030000003oool0oooo00X0oooo00D0gia8
000000000000001809cOo`0M0?ooo`00203oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo
00<0omnL04P0001d_ol0103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`00
0000oooo0?ooo`0D0?ooo`030000002Y_NP0ZKgX00`0ZKgX1@2X_>P50:Fjj0D0YKWW1@2da^PB0:Vm
j080DV;50`1VM<d508^LgP80[lO/1039iN/20=?/i@@0eN[T:`2Y_NP3000003h0ZKgX0`1WV>`305R7
i0@0IiGY0P2V^NH30:jli0030000003Md/h0hmS;0080hmS;0`3YglT00`3^i/H0[lGZ0:o5jP030:o5
jPT0ZKgX1@2P^N/50:Vli`H0[/7X0P2[_nP20:^nj0030000003oool0oooo00P0oooo00L0okmd0018
W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d
0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3oool01@3oool2000001H0oooo
3`2Y_NP30:Rlj080YkcX1@2U^^P30:Fii`80Z;cW1@2da^P>0:Vmj0<0D6[>0`1BH/D306Idc@D0RicN
1039iN/20=?/i@@0eN[T0P3=iNPW0:Vmj0<00000@@2Y_NP406NHk0<0F8OT0`1aUnL60:jli0040000
003Sf</0hmS;0>?Hb`80jMo90`3^i/H>0:Vmj0D0X;W[1@2]_nL50:k1j0D0ZkkX00<000000?ooo`3o
ool0303oool00`2oM000M;oo0?ooo`0K0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol01@3oool00`3ookl0M00004RLg`070?ooo`030;md001d_ol0oooo00D0oooo00<000000?oo
o`3oool05`3oool>0:Vmj0D0YkcX1@2U^^P50:Rli`<0]<KX0P2]`NP>0:Vmj0<0D6[>00<0GG3=059R
a@1VM<d00`1VM<d60;?9jP80dncU1@3Ej^@40<gUj2<0ZKgX0`0000100:Vmj0D0Y;_Y0`1RR^<405R7
i0<0LIOW0`2^_>@20;[2h0030000003Sf</0hmS;0080jMo9103^i/H00`3TlmD0ZKgX0:Vmj00<0:Vm
j0D0Wk;U1@2]_nL50:g1j0@0ZkkX00<000000?ooo`3oool0303oool00`2oM000M;oo0?ooo`0K0?oo
o`00203oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01P3oool02`3ooml0W4P004RLg`3o
ool0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0603oool>0:Vm
j0D0YkcX1@2T^NP50:Rli`D0[L7X3P2Y_NP2051ZcP80GG3=1@2:W=l30;?9jP@0c>7W0`3Fi^860<gU
j200ZKgX0`0000140:Vmj0D0Y;_Y0`1RR^<305n7hP@0LIOW1@2j`^000`000000jMo90>WOb@040>kV
aP80i??E3`2Y_NP509nbi@80[KoW0`2^`NP40:g1j0D0Z[kX00<000000?ooo`3oool01P3oool01`3o
gi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0oooo00@0
oooo0P00000K0?ooo`h0ZKgX1@2V^nP50:Bij0D0//;V1@2]`NP:0:Vmj0<0FhKR0`1@J/h205e`c@D0
RYcO1@3<hNL30=KVhP<0enGO1@2Z_^PL0:Vmj0<00000B02Y_NP40:Bkj@@0HX[S0`1OQn8407fLi@@0
^/;P00<0al_M0000003^i/H00`3^i/H30>CceA00ZKgX102O/^D50:k1j080[L7X0`2/`>P50:Znj003
0000003oool0oooo00D0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0K0?ooo`00
203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo0?ooo`020?oo
o`050;md001d_ol0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?ooo`X0ZKgX1@2X_>P4
0:Jkj0D0Y[[W1@2b`^H>0:Vmj0@0FhKR00<0C6K<051ZcP1ML<d00P1ML<d208ZLg`@0//CW0P3<hNL3
0=KVhP<0enGO0P3Eh=l50:Znj1P0ZKgX0`00001<0:Vmj0@0Sk;^0`1UQml405n7hP@0OIcU0P2j`^03
0<O;g@030000003^i/H0k^K600<0i??E0P37ind?0:Vmj0D0YkWV102^`NP60:c0j0@0Z[gX00<00000
0?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Boo`3oool0
gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool0
0`000000oooo0?ooo`0L0?ooo`X0ZKgX1@2X_>P40:Bjj0D0Y[[W1@2ba^T>0:Vmj0<0FhKR0P1<I/`3
05e`c@L0//CW0P3Fi^840=OUg`@0eN3O6@2Y_NP3000004l0ZKgX102?/^h406F7g`<0JH[P101mW>D4
0<O;g@030=KGf0000000e]OH0080i??E1@37ind:0:Vmj0D0X[[Z102W^NH50:k2j0<0[<3X0`2[_nP4
0:Zmj0030000003oool0oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0oono07@0
0000000004RL0=ooo`050?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P000000000
00000000001d0;ooo`D0oooo00<000000?ooo`3oool07@3oool:0:Vmj080Z;cX0`2W_>P40:Bjj0<0
Y[[W0P2/_NH50;;6j@d0ZKgX101KQ^8204aVc0@0PIGM0`2ba>L30<_Ii0<0eMoO1@3Eh=l20;gCjaH0
ZKgX0P00001B0:Vmj0@0Sk;^101UQml406V:h0@0SJCT0P37bmd30=KGf0040000003Ti=80i>CB0>g`
bPl0ZKgX102R^^X50:bni`D0[/;X1@2[_nP40:Zmj0030000003oool0oooo00D0oooo00H0gia80000
0000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo2@2Y_NP60:Nlj0@0Y;[X1@2/_NH3
0;;6j@`0ZKgX0`28/_400`0bElP0FhKR05^6hP0204aVc0D0PIGM103;fN@40=GOg`<0f=oL1@2mdn/B
0:Vmj0<00000E@2Y_NP407NFh`<0JHKL1@1YR^0408fTi0<0e]OH0P3Ti=8010000000kO3:0>g`bP3T
nld>0:Vmj0D0Wk7U1@2/_^L50:g1j0@0ZkoX1@2Y_NP00`000000oooo0?ooo`0V0?ooo`009@3oool0
0`000000oooo0?ooo`0O0?ooo`D0ZKgX1@2X_NP40:Nlj0D0Y;WX1@2/_NH?0:Vmj0<0R;;a0P0bElP3
04aVc080PIGM0`2Z^^D20<_Ii0@0eMoO0`3Hgm`20=OKfPD0_M?[3P2Y_NP3000005T0ZKgX0`1gU^<4
06V6g0@0MHoO1@2P/><01P3FemP0i>CB0>CTdP3Ti=8000000>g`bP<0i?_=3P2Y_NP509nai@80[;kW
0`2^`^P40:g1j0D0Z[kX1@2Y_NP00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?oo
o`0P0?ooo`D0ZKgX1@2X_NP50:Fkj0@0Y;WX1@2d`nD?0:Vmj00302QSeP28/_40R;;a0080<UO80P1]
Q]X60:Zji@@0eMoO0`3Hgm`40=OKfPl0ZKgX0`00001L0:Vmj0@0MiKS0`1YQ]`507F?g`@0X;3S0`3T
i=820>g`bP040000003Tnld0i?_=0>Ckc@l0ZKgX102O/ND50:k2j080[L7X0`2/`>P50:Znj0@0ZKgX
00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?ooo`D0ZKgX1@2X_>P50:Fkj0D0Yk_W102d
`nD?0:Vmj080:6?F0P0bElP406f6fP<0Z[[U1035cn830=SOg0@0em_J0P3Af=h;0:Vmj0<00000G02Y
_NP409Fdk@<0LHSJ101YQ]`407F?g`80X;3S102g`^<30>g`bP030>Ckc@000000`Mo^0080`Mo^3P2Y
_NP50:NiiP@0[/;X1P2/`>P50:Znj0@0ZKgX00<000000?ooo`3oool0903oool002@0oooo00<00000
0?ooo`3oool08`3oool50:Vmj0D0Z;cX1@2T^^T50:Nki`D0//KY3P2Y_NP202QSeP0304]^e00bElP0
KHKJ00<0KHKJ1@35cn830=;Gg@@0em_J103Af=h70:Vmj0<00000H02Y_NP409Fdk@<0LHSJ0`1`QmX4
07F?g`D0]l;S0`3?f=l0103Tnld0`Mo^0<7OkP0000030<7OkPT0ZKgX1@2R]nP50:NiiP@0[/;Y0`2/
`>P30:^nj0D0Z[kX102Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T
0?ooo`D0ZKgX0`2X_>P20:Nlj0D0Y;[Y0P2W^nL30:fmiPD0//KY3@2Y_NP202QSeP80BfkD1@2GZ^<3
0<G?hP<0d]OM0`3Gf=T50=7HgP80`M?X0`2Y_NP3000006<0ZKgX102E]>d40768fP<0L8OJ1025V]l3
0;O2h`<0cmSO0P3Sk]H20>SjaP030000002Y_NP0ZKgX00/0ZKgX1@2R]nP50:g0j0@0[/;Y1P2[_^P4
0:Znj0@0ZKgX00<000000?ooo`3oool08`3oool002@0oooo0P00000V0?ooo`D0ZKgX1@2W_>P40:Bj
j@H0[KgV3P2Y_NP407f]l`0401Y@b@0XHmH0BfkD04]^e0D0Uj[S103Bemd40=OHf@80f=KF0P3Af=h3
0<7Cj0<00000I`2Y_NP407Z:f0<0M8KG101`QmX408FJg`@0cmSO0P3Sk]H20>SjaP80dokJ00<00000
0:Vmj02Y_NP02`2Y_NP50::ci@@0[L3X1@2]`NP50:^nj0T0ZKgX00<000000?ooo`3oool08P3oool0
02<0oooo0P00000X0?ooo`D0ZKgX1@2W_>P50:Bjj@<0[KgV0P2d`N@>0:Vmj0<0OJgc0P0JD<T304]^
e080Uj[S102f`^<50=OHf@@0f=KF0P31dnP200000080`M?XJ@2Y_NP307Z:f0@0M8KG0`1kS]X509b/
hP80cmSO0P3Sk]H20>SjaP<0dokJ00<0ZKgX0000002Y_NP01`2Y_NP50:Nlj@@0X[?U0P2]`>P30:k2
j@D0[L7X1@2Z_^P90:Vmj0030000003oool0oooo0240oooo000=0?ooo`0;0?oo_`1d000000000018
W03Oool0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`070?ooo`030000
003oool0oooo02P0oooo102Y_NP50:Fkj@D0Y;[Y1@2d`N@>0:Vmj00300]Xg01m[O<0OJgc00806U39
0P1bT>050;K2h`<0b<cM0P3Gf=T40=SFeP<000001@2_`nUX0:Vmj0@0NX[H0`1dQ]L407^>fPD0W:cR
0P3Sk]H20>SjaP@0dokJ0P2Y_NP00`000000ZKgX0:Vmj0060:Vmj0@0YkcY102R/nD60:k2j@D0ZkoX
102Z_^P90:Vmj0030000003oool0oooo0240oooo000<0?ooo`060?oog`2LB000B9cO0?ooo`3OW4P0
07Bo103oool01`3o_g@004RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z
0?ooo`D0Z;cX102U^nT50:Jjj0D0]<7T3P2Y_NP200]Xg0806U39101bT>020;K2h`D0b<cM0P3He]H3
00000080em;E0P3Dcm@50:o3jF@0ZKgX1027U=T307Z7e0@0M8KG101kS]X209b/hP<0^LOU0P3Xn/H0
0`3Co]X0ZKgX0:Vmj0040:Vmj0030000002Y_NP0ZKgX00H0ZKgX102W_>T50:Zmi`<0[/;Y0`2]`^T4
0:^oj0D0Z[gX2@2Y_NP200000240oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`080?ooo`030;md001d_ol0oooo00D0oooo0P00000/0?ooo`D0Z;cX102T^nT50:Jjj0D0/l?V3P2Y
_NP200]Xg00303=VeP0JD<T0LY3P00<0LY3P1@38c=d3000000@0em;E103DcmAX0:Vmj0@0QiCI101j
Qm@307^9eP@0NhkJ102ianD20=OYhP80hOg<00<0bobi0:Vmj02Y_NP0102Y_NP00`000000ZKgX0:Vm
j0050:Vmj0D0X;7T1@2Z_NL50:g2j@80ZkoX0`2Z_^P50:Zmj0T0ZKgX00<000000?ooo`3oool07`3o
ool000`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00P0oooo00<0_g@007Boo`3oool0
1@3oool00`000000oooo0?ooo`0/0?ooo`D0Z;cX102T^nT30:Jjj080ZKcW1@2c`nH90:Vmj0D0Xk_Z
00<02fSL03=VeP0cI]H01@2H[>D01038c=d000000000000000020=3@f080e<oE0P3Gd]D40=C?e080
cl_FJ02Y_NP408NDf@<0NXOD101kRMH408fLg@80^LOU0P3GjN820>7mc0<0bobi1P2Y_NP00`000000
ZKgX0:Vmj0050:Vmj0D0X;7T1@2^`^T40:g2j@H0Z[kX0P2Z_NP;0:Vmj0030000003oool0oooo01l0
oooo000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0W=oo
0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02d0oooo1@2X_>P40:Bkj@D0ZKcW1@2_
a>T:0:Vmj0@0Xk_Z00<02fSL03=VeP0cI]H00P2H[>D3000000@0d=3H103DcmD40=C?e0@0cl_FI`2Y
_NP408NDf@@0NXOD101kRMH408fLg@80enWR0P3QoL`:0:Vmj0030000002Y_NP0ZKgX00H0ZKgX1@2X
^nL40:k2j@D0[<3X1@2Z_^P>0:Vmj0030000003oool0oooo01h0oooo000<0?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`030?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0^0?ooo`@0Z;cX1@2T^^T30:Vli`<0[kkU102_a>T:0:Vmj0<0Xk_Z
00<003Vn03=VeP0000000P000000102H[>D0/KgR0;6mhP2a_N820=3@f0@0e<oE0`3EcM850<o;eP80
bLOHGP2Y_NP50:Vmi`@0SICF1020R=4307j8d`@0NhWF1@2X^ND20>7mc0030=Soc`35mj`0ZKgX00T0
ZKgX00@000000:Vmj02Y_NP0ZKgX1@2Q/^@50:Rki`@0[L;Y1@2/`>P50:Zmj0h0ZKgX00<000000?oo
o`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00<0oooO
09a8B02Lgol02@3oool200000340oooo1@2W_>P40:Bjj@H0[kkU3P2Y_NP0101_Yo<0000000000000
000205N4hPH0/KgR103DcmD40=G=dP80e<[@0P3?bmH40<W7f5h0ZKgX1@2Y_NL308fDeP@0P8SA101n
R=<408REfP<0Z;WU0P3;i>T0103Holl0aON/0<Gg[035mj`:0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0
XK;T0P2X^nL70:g2j@D0ZkkX102Z_NP>0:Vmj0030000003oool0oooo01d0oooo000<0?ooo`060?oo
g`2LB000M;oo0?ooo`3OW4P007Bo1@3oool00`2oM000M;oo0?ooo`080?ooo`030000003oool0oooo
0340oooo1@2W_>P40:Bjj@<0[kkU0`2d`><<0:Vmj08000000`1_Yo<01000>Kh0EhCR05N4hP1GQ>83
0;6mhP@0`<CM103EcM840=C:d0H0bLOHGP2Y_NP40:Vmi`@0SICF1020R=4407j8d`@0R9GJ00<0Z;WU
0<_Tj@3;i>T00P3Holl30<Gg[0/0ZKgX00@000000:Vmj02Y_NP0ZKgX102Q/^@50:g2j@D0[<3Y102[
_^PC0:Vmj0030000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d000000000018W03Oool01@3o
ool01P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool0<P3oool50:Nkj0@0
Y;[Y1P2d`><80:Vmj0<000000`2Y_NP202R1j@030012a01GQ>80EhCR0080EhCR1@30a=d20<S7f@80
eLgB103Db]020=?7cP<0bLOH0`35`mQI0:Vmj0D0Z:gK102;S<l308F8c`@0P8SA101nR=<408REfP80
bnCY0P3Holl?0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0YkWV1@2]`^T40:c0j@D0Z[kX4`2Y_NP00`00
0000oooo0?ooo`0K0?ooo`008P3oool2000003@0oooo1@2W^nP50:Fkj0@0]<3S1@2Y_NP3000000L0
ZKgX0P0XPNT00`00@/@0NIgX07VMj00207VMj0<0`<CM1038amT40=C:d0@0dlO>1P35`mQI0:Vmj0@0
Z:gK102;S<l408F8c`@0PhW@1029TmL40:6ai080f?o?00<0bOk80<_l^@2Y_NP03@2Y_NP00`2R/n@0
00000::ci0020::ci0@0YkWV1P2]`^T40:^nj0D0Z[kX4P2Y_NP00`000000oooo0?ooo`0K0?ooo`00
8P3oool00`000000oooo0?ooo`0d0?ooo`D0Yk_X1@2U^nP40;C1h`040:Vmj00000000000000000X0
ZKgX0`0XPNT00`00@/@0NIgX07VMj00207VMj0D0b<OI0P3<amD20=C:d0@0dlO>0P3Ba<d40<G3f080
a;oFF@2Y_NP40:R]f`@0Rhc?0`25R<l408>9d0@0RI?G0P2Q/N@30<CTkP040<Wnb03;o;T0bobi0<_l
^@h0ZKgX00@0X[?T0000002R/n@0X[?T202]`^T30:c1j@@0ZkkX5`2Y_NP00`000000oooo0?ooo`0J
0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`D0Yk_X1@2X_>P0102d`N<0000000000000000>
0:Vmj08005G=00<0057>09:^j@2B[^T00`2B[^T30<S7f@@0c<OE103Calh40=;4c@80aL?H1034_mIH
0:Vmj0@0Z:gK102;S<l408F8c`@0PhW@0`29TmL40<CTkP030<Wnb02Y_NP0ZKgX0140ZKgX00@0YkWW
0000002W^NL0YkWW1@2]`^T50:c1j@80ZkkX0`2Z_^PF0:Vmj0030000003oool0oooo00`0oooo00<0
omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00@0oooo000R0?ooo`030000003o
ool0oooo03H0oooo0`2W^nP20:Jkj080Z;cX0`0000050;?1i0d0ZKgX0P00ELd00`0;H]P0057>09:^
j@0309:^j@D0c<OE0P3>aM820=?7cPD0d/C=1@34_mH20<FldU<0ZKgX1@2IU/l408j;c0<0RXW<1025
R<l408>9d0D0X;;U0P39o/P20=?nfPh0ZKgX1@2R/^<010000000YkWW0:Nii`2W^NL50:g3j@@0[<7Y
1P2Z_^PF0:Vmj0800000303oool02P3ogi`0B01d0;ooo`3oool0oooO09a80018W=l0oooo0=nLB000
M;l40?ooo`008@3oool2000003T0oooo0`2V^nP300000080Z;cX0P2Z_>L50;?1i0h0ZKgX00<005G=
00]Rf00;H]P0102S^>L30<c7e@@0c/GB1@3Ba<d20=31b`<0a;oF1035_=850:Vii4X0ZKgX102XZ]P4
09VFc`@0SX_<102:RL`408R;c`@0SIGG0`2P/^D20<;]l@@0dokJ3P2Y_NP40::bh`030:g2j@000000
[L;Y0080[L;Y102]`nT50:^nj0D0Z[kX5`2Y_NP00`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00240oooo00<000000?ooo`3o
ool0>03oool3000000<0Y[_X1@2Z_>L20;?1i0<0//3U3P2Y_NP00`00=K802f;H00]Rf0040:>hi`D0
c/GB0P3>a=430=;4c@@0d<7;1@35_=820<Nic@D0ZKWTA@2Y_NP50:Vii0<0Z:[H1@2IU/l408j;c0<0
RXW<1028Rll408fEe`80X;;U0P32kO430=?nfQ00ZKgX0P2R/^<30:Rki`030:g2j@000000[L;Y0080
[L;Y102/`NT50:^nj1/0ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;ooo`3oool0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo03H0oooo0P00
00020?ooo`D0Yk_X102Z_>L60;;0i@h0ZKgX00<002FT01A_g`0;H]P00P2S^>L30:bmiP80c/GB103>
a=460=31b`040<nnbP35_=80aKcB0<FldP@0akW=0P2Y^N@30:b_fTD0ZKgX1@2Y^N@30:RZf0@0VIK?
102>Rl`408Z9c0@0R8_?0`2=UML20<;]l@030:gc/@3Co]X0dokJ0180ZKgX1P2X^nL00`000000[L;Z
0:g2jP020:g2jP@0[<7Y1@2Z_^PK0:Vmj0030000003oool0oooo00T0oooo00/0omnL04P0M02oool0
oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool2000003@0oooo0`000005
0?ooo`D0Yk_X1@2/_NH30;;0i@80/KoU3P2Y_NP00`009J@056oO0:bmiP050:bmiPD0c/CA00<0cL;@
0=31b`3@`L/00P3@`L/30<nnbPH0akW=1P2/[mY50:Vmj0@0ZKWT0`2XZ]P409VFc`@0SX_<102:RL`4
08R;c`@0Y;_Y00<0^o[[08CFR@31gnh00P31gnh<0:Vmj0<0ZK[V0`2Q/><30:Rki`<0[L?Z00@00000
0:g2jP2]`^X0[L;Z2@2Z_^PL0:Vmj0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo
0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?oo
o`<000002@3oool50:Nlj0D0[;gV1@2a_nD>0:Vmj003000UY00DM>80[;gV0080[;gV0`2`_nD30<k4
d@<0cL;@0P3@`L/40<nnbP030<fkb@37^Ld0akW=0080akW=0P39]lP50:b_fT40ZKgX1@2RV</409V@
b0<0UHg8102BRlT408n;b`@0SXo@102CW=T20:Bkj@030;_jj`31gnh0`Mo^00@0`Mo^2@2Y_NP50:Vj
iP@0XK3S1@2]`nX00`2[`>T000000:_0j@020:_0j@@0Z[kX802Y_NP00`000000oooo0?ooo`060?oo
o`0=0;md000004P0W;nL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?oo
o`00103oool03@3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0oono07@0B02L
gol0103oool01@3OW4P000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0;@3oool30000
00h0oooo102W_>P50:jniP<0/KoU0P2`_nD>0:Vmj003000UY00DM>80/;oU00D0/;oU00<0c/CA0<g2
d03=`]000`3=`]040<nnbP<0cK_90P37^Ld40<Vgb080[:oJ0`2g[m4o0:Vmj080YYk>102RV</409V@
b0<0UHg8102BRlT408n;b`D0SXo@0`2CW=T20;_jj`<0XNfY3P2Y_NP40:VjiPD0ZKkX0`2]`nX20:c2
jP030:_0j@000000Zl3Y0080Zl3Y102Z_NPP0:Vmj0030000003oool0oooo00H0oooo00/0okmd0000
000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`040?ooo`000`3oool01P3ooml0W4P0
04RLg`3oool0gia8001d_`D0oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@004RL0=ooo`3oool0
oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z0?ooo`<000004P3oool40:Nlj0D0[[kV1@2`
_nD>0:Vmj08057CR1@2`_nD50<g2d080c<7@0P3?_/X40<fkb@H0bKO81P2g[m440:R^f`<0ZKgX0`2Y
_NLb0:Vmj0@0YYk>1@2RV</309V@b0@0UHg8102BRlT408n;b`@0SXo@102/dO<B0:Vmj0D0X[?T1@2Y
_^P50:c2jP030000002[`>T0Z[kX0080Z[kX102Z_NPK0:Vmj0<0000000<0oooo0000003oool0203o
ool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0103oool000<0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000
M;oo0?ooo`040?ooo`800000:@3oool3000001H0oooo102W_>P50:nni@@0/;oU3`2Y_NP200AagPD0
/<7V0`3=`]040<c1d0D0cK_900<0c;[90<Vgb039]lP00P39]lP20<VdaP@0]joA0P31/<T40:R^f`H0
ZKgW;@2Y_NP50:NQd0@0YYk>102RV</309V@b0@0UHg8102BRlT408n;b`D0VjcR0P2/dO<20<OWk@h0
ZKgX102W]><50::ci0D0[L?Z102/`^X00`2Z_^P000000:Znj0020:Znj1/0ZKgX0`0000050?ooo`03
0000003oool0oooo01D0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?oo
o`030?noM000B9`0gooo00L0oooo00<0_g@007Boo`3oool0103oool00`000000oooo0?ooo`0U0?oo
o`<000006P3oool50:Nmj@@0[kkU1@2`_^@>0:Vmj080177N1@2``NH50<c1d080bL3A0`3=^lT30<bj
b@80bKO81039]<H20;N_d@@0`K39102cZ<h50:VmibT0ZKgX2@2WXM040:JNcP@0XYS;102HS/L409J?
bP@0U97>102EVMD409^/hP030:[am@37ind0anO]0080anO]3P2Y_NP40:Ndh`D0Zl7Z102]`nX50:^o
j@030:Znj0000000Z[gX0080Z[gX5`2Y_NP3000000P0oooo00<000000?ooo`3oool05@3oool000<0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02Lgol00P3oool0
1`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R0?ooo`<00000
7P3oool50:Nmj@@0[koU1@2`_^@>0:Vmj003001Ec@00H<d0[<?Z00@0[<?Z0`3<`M040<W0d@030<fk
b@3<^/T0c;[900<0c;[91@39]<H50<6`b@80a:o5102cZ<h50:NRd@`0ZKgX0P2Y_NL>0:Vmj0@0ZKWT
1@2Y_NP40:JNcPP0Yj7@102VW/h509^?aP<0V8k7102FSlX409BAcPD0UIWE0`2ZlOD00`2LkkX0ZKgX
0:Vmj00@0:Vmj0D0Y[[W102[`NX50:c1j@@0ZkoY0P2Z_NP010000000Z[gX0:Zmj02Z_NPB0:Vmj0@0
0000303oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol01P3oool01P3OW4P007Bo0?ooo`3oool0oono07@000<0000000<0M;oo0?ooo`3oool0103o
ool00`000000oooo0?ooo`0O0?ooo`<000008P3oool50:Nmj@@0[koU1@2`_^@>0:Vmj00302R1j@00
ELd0063=00@0[<?Z1P39`=450<bjb@80b[[:0`39]<H20<RcaP<0`K390`34[lD30;>XcP80`:_41@2W
X]440:NTd`D0ZKgX1@2Y_NL20:Vmj0<0Z:kK102Y_NP50:RZf0@0ZKWT1@2UV/X40:JNcP@0Yj7@102Q
T/D409j@a@@0Vho6102HS/L409J?bP@0U97>0P2EVMD30:K>mA80ZKgX102R/>850:Jji`@0[<?Z1@2/
`NT40:Znj0030:Zmj0000000Z[gX0080Z[gX3P2Y_NP0103oool0000000000000000@0?ooo`030000
003oool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`07
0?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2000002H0oooo00<00000
0:Nmj@2W_NT00P2W_NT40:joiPD0/;kT3P2Y_NP202R1j@03000oZP2QaO80XLGb0080XLGb0`39`=43
0<K2eP<0c;[9103:^/X00`39]<H0b;?60<RcaP020<RcaP030<6`b@34[lD0a:o500<0a:o500<0/jS>
0<2[a030Zl@00P30Zl@20:NRd@<0^ZK6102WY=<50:JQd@@0ZKgW1P2X[]/40:FLc0D0Z:[H102WUlD4
0:FJbP@0YYk>1@2TTl@30:6Ba@@0WY351@2KSlH309R>a`@0UXo:102DTLh30:K>m@<0[lGZ3@2Y_NP5
0:VfhP@0X[3R1@2/`n/40:c3jPD0Z[oX102Z_^P00`2Y_NP000000:Vmj00;0:Vmj080oooo0`00000C
0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo203o
ool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:P3oool40:Nmj@@0
[[oV1@2a_^<=0:Vmj0@0:87Y102QaO860<K2ePH0b[[:1@38/lH60<B_a@D0`:_41P2jY/H20:NTd`80
]j?51@2VXM440:FJbP<0Z:kK0`2^W<D40:FLc080Z:[H0`2]V/<30:NGa@D0YI[:0P2VW/h20:JD``@0
Y9?4102QT/D409j@a@@0Vho60`2HS/L509bRf@@0W[7U00<0Qn_P0:o5jP2_aNX00P2_aNX>0:Vmj0@0
ZKKR0P2R/>830:[0jP@0[<?[1@2[`>T40:Zoj0H0ZKgX00<000000:Vmj02Y_NP01`2Y_NP4000001H0
oooo00<000000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL0=ooo`040?ooo`03
0=nLB0000000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo0?ooo`040?ooo`03
0000003oool0oooo01L0oooo0`00000^0?ooo`@0YkgY1@2/_nL40;6nh`h0ZKgX0`1_Yo<408K4o0@0
a/;F0P31a]h40<ZjbP80b;c>0`38/lH20<Ndb0H0a:o50`30Zl@20<6[a0D0^ZK61@2gXlD20:JQd@<0
]j;3102UV/X50:jLa@@0YIc<1@2]V/<40:NGa@@0YI[:102VU<<50:BCa0<0XI;5102NT<D509fGc@<0
W9[B1@2LX]T209jai@0308O[h036k^l0[lGZ00<0[lGZ3`2Y_NP30:VfhPH0Z/3Z102/`^X50:_0j@@0
Z[kX1@2Y_NP00`000000ZKgX0:Vmj0050:Vmj08000006P3oool00`000000oooo0?ooo`0D0?ooo`00
7`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3oool20:Nmj@80YkkZ1@2/_nL40;>nh`h0ZKgX
102S^nX308K4o080a/;F1031a]h20<ZjbP@0b;c>00<0b;?60<Ndb037]<P00P37]<P60<B_a@040<2[
a031Zl@0`J_40<6[a0@0^ZK60P2mYl<40;NSa@D0]j;30`2UV/X20;FO`PD0[Yc50P2UW<`20;2K`PD0
[I[30`2WUlD50:VF``@0YYC3102TTl@30:6Ba@D0WiK;102MUld409bJdP@0W:;I00<0Qn_P0<K^k`36
k^l00P36k^lB0:Vmj0@0Y[WW0`2Z`>X30:c3j`@0[<;Z2@2Z_^P50:Vmj0040000002Y_NP0ZKgX0:Vm
j08000007@3oool00`000000oooo0?ooo`0D0?ooo`007`3oool2000001<0oooo0`00000e0?ooo`D0
YkkZ0P2/_nL30:Znj0@0/kkS3P2Y_NP40:>kjP80A:og1P31a]h60<RlcPD0akC81P34[lD50<6[a080
^ZK60`2mYl<30;NSa@80^jC31@2gX/<0102UV/X0]Io20;FO`P2eWl850:jLa@@0/9_21@2]V/<20:NG
a@80ZiS3102YU/<40:JD``@0Y9?4102RUlT409nFb`@0WIO=102LV]8409gVo00309Scf@2Y_NP0ZKgX
00h0ZKgX0`2Y]>440::`hP@0Y[WW1@2/`n/50:^oj@@0Z[kX2@2Y_NP300000200oooo00<000000?oo
o`3oool0503oool001l0oooo00<000000?ooo`3oool03`3oool3000003T0oooo102W_^X60:Znj0@0
];oR4P2Y_NP304B_m`<0`LKN0P2cc^h40<RlcP80aL?H0`37]<P20<JicP@0a:o50P34/lT40<6[a0H0
_JO300@0]j?50;^T``2kY<<0^jC31@2gX/<50;FO`P<0[Yc50P2cW/<40;2K`P@0[I[3102[V<<50:VF
``<0YYC31@2UV<P30::Gb@D0WiK;0`2MUld60:?An140ZKgX1P2Y]>430::`hPD0[<?[1@2[`>T40:^o
j@T0ZKgX0`0000030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool001l0
oooo00<000000?ooo`3oool0303oool3000003d0oooo1@2W_^X30:Znj080Z;kZ102d_n850:Vhi0d0
ZKgX0`00IMT50;?>kP80b;c>1035`mP00`37]<P0a[W>0<JicP020<JicP80a:o50`34/lT30<6[a080
`Zk71@2mYl<50;^T``80]j;30`2hXl<40;FO`P80[Yc50`2cW/<40;2K`P80[I[30`2^Vl@40:^H``@0
ZIK3102WV/P40:FHb0@0XYO9102OU//50:C2ka80ZKgX102Y^>@50:Vdh@@0Z/7Z0`2/`n/20:_2jPD0
Zl3Y102Z_NP50:Vmj0<000001P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0
oooo000O0?ooo`030000003oool0oooo00T0oooo0`0000110?ooo`D0YkkZ1@2X_^X20;BohP<0]<3S
102Y^>@=0:Vmj0@0OJgc0`2cc^h60<G3f0D0a[W>1P34/lT01031Zl@0`Zk70<:^a`32[/L40;fW``80
_jc6102kY<<50;RS``@0]Io21@2cW/<40;2K`PD0[Y_4102[V<<20:VF``<0Zik90`2WV/P50:FHb0<0
XYO91@2U^NL30:C2ka@0ZKgX102Y^>@50:Rlj0@0Z/7Z1@2[`^X50:Znj0@0Z[gX1000000:0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool04`3oool001h0oooo0P0000090?ooo`800000
A@3oool60:JnjP<0Z;kZ1P2d`><40:nkha80ZKgX0P1od?l30<G3f0<0^=7]0`36^Lh20<;7g@D0a;?9
1@32[/L20;fW``<0_jc60`2kY<<20;b[b0D0^:?30P2eWl820;NSa@@0/ik30P2`Vl830;:PaP@0[Y_4
102[V<<50:^Nb@@0Yi[8102UV<P40:Nfi0D0YKWW5P2Y_NP50:Jgi@@0Z;cX1@2/`n/20:_2jPL0Z[kX
00@0oooo00000000000000003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0
oooo000N0?ooo`030000003oool0oooo00D0oooo0`0000190?ooo`D0Y[kZ0`2U_^/30;C0h`<0[koV
102_^n<B0:Vmj00308Rbl@00NK80^=7]00D0^=7]00<0a[W>0<;7g@32amd00P32amd20<Bcb@<0`koF
1032[/L60;n/aP040;^T``2lZlP0_:_80;b[b0D0^:?3102gXlD40;>N``D0/Z36102^Vl@50:jSc0@0
Zik9102WV/P50:Vgh`@0YkKT0P00000E0:Vmj0@0Y;7Q1@2V]nD40:_3j`@0[<?[1P2Z_^P0103oool0
000000000000000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0
oooo00<000000?ooo`3oool00P3oool3000004d0oooo00<000000:JnjP2V_^X00P2V_^X30:Fnj`H0
[koV102b_^8B0:Vmj0<0R;;a102hdNd50<;7g@H0`koF0P32[/L20<:le0D0_jc61@2lZlP20;RS``<0
^jg<102gXlD20;>N``80]ZS;1@2bX<H20:jKa080/Z_B102^Xl`40:^Nb@D0[;_U102Y]n<203^m[aD0
ZKgX1@2Y/n040:Bah@T0Zl?[102[_nP30:Znj0<000005P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01<0oooo000N0?ooo`030000003oool0000000800000D@3oool00`000000YkgZ
0:NmjP020:NmjP<0Y;g[0`2__nH30:Voj@@0/[kR102Y]^8B0:Vmj0<0J=7j0`32amd20:3Oo0D0`koF
1@32_=@20;n/aP<0`;cF102lZlP50;^]c0@0]j?5102fZ</50;:PaP@0/Z_B1@2^Xl`20:^Nb@80[LG[
1@2/^nD20:VghaD0ZKgX102Y]>440:Vch0D0Z/7[102[`n/50:_0j@@0ZkoX00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo000N0?ooo`800000E@3o
ool00`000000YkgZ0:NmjP020:NmjP<0Y;g[1P2Y_nT40;C0h`@0ZKKR5@2Y_NP50:3Oo080`koF0`2`
gOL40<:le0H0`;cF0P2lZlP20;k2g@@0^jg<0P2gXlD30;Zge`@0]ZS;0P2bX<H30;Fig0@0/Z_B102^
Xl`50:g5j`@0[;_U4`2Y_NP50:Veh@@0ZKCQ102Y_nT50:[1j`P0Zl3Y0P00000O0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool04`3oool001<0oooo00<0omnL04P0M02oool02@3oool0
0`000000oooo0?ooo`1D0?ooo`030000002W_NT0YkgY0080YkgY102T_N/50:Fnj`@0]<3S1@2`_>8H
0:Vmj0H0/=gg0P32_=@20;3Om`D0`;cF1@2n`]d30;^]c0H0^[OG0`2fZ</60;Fig0<0/Z_B1P2/e?D3
0:g5ja<0ZKgX1@2Y]^840:Veh@D0Z;cX102Y_nT90:_0j@030000003oool0oooo0240oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?oo
o`800000EP3oool40:Nmj@@0Y;g[1@2U_^/40:g0j0D0/;cR102Y]^8E0:Vmj0@0/=gg1@2`goL20<2l
eP<0XnGl102n`]d40;SCkPD0^[OG102ddNl50;Fig0D0V^Gl5`2Y_NP40:Vgh`D0ZKKR102X^^H40:Rl
j0D0Zl7Y102[`>T2000002L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?oo
o`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05@0oooo102X_NT40:Bmj`D0
Y;g/102]`>P50;C0h`@0ZKKR102Y^^HF0:Vmj0<0/=og1@2SiO`506_Kj`@0^=?^1@29i_P40;CAk`H0
D<gB5P2Y_NP90:Vgh`D0Z;WU102X^^H40:_0j@D0Zl7Y0P00000[0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`000000oooo
0?ooo`1D0?ooo`@0Z;gY1@2U_NX40:Bmk0@0Y[o[1@2d`><40;6lhP@0ZK[V:02Y_NP408WVn1`0ZKgX
102Y]^850:Vgh`@0ZKST102X^ND50:[0j@@0Zl3Y0P00000`0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03P3oool00`000000oooo0?oo
o`1D0?ooo`@0Z;gX1@2U_NX40:Bmj`@0Y[o[1@2/`>T40;6lhP@0[;OQ@`2Y_NP50:Veh@@0ZKKR0P2Y
]n<70:Vhi080Z;WU0P2Z_nT40:[0j@<00000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00l0oooo00<000000?ooo`3oool0E03oool4
0:Rmj0D0YkgY102T_N/40:Bnk0D0[<3Y102b`ND40:bgh@D0ZKGQ?02Y_NP20:Vdh@D0ZKGQ0`2Y]^89
0:Vhi0D0Z[oY0`00000g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool0
0140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@0?ooo`800000E@3oool40:Vmj0D0YkgY102U_NX4
0:Bnk0D0Y[o/102b`ND40;>oh`D0ZKGQ2@2Y]^8`0:Vmj0D0ZKCQ102Y]N440:Zii0@0ZKST1@2Z_nT3
000003`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`004P3oool0103o
_g@000000000M02ooolB0?ooo`030000003oool0oooo05<0oooo102Y_NP50:Rmj@@0YKgZ102T_N/5
0:Jok0@0Z<3[102c_n<50;:nh`<0ZKKR0P2a_>840:VfhPD0ZKGQ102Y_NP40:VjiQH0ZKgX102Y^>@4
0:Vmj0D0ZK?P102Y]>450:^ki@@0Z[WT102Y_nT30:Zoj@030000003oool0oooo03h0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?oo
o`030000003oool0oooo05<0oooo102Y_NP50:Rmj@@0YkgY102T_N/50:Bnk0@0Z<3[102[`NX50;:n
h`D0/KcR0P2Y]^820;6lhP@0ZKGQ1@2Y]>040:VjiP@0ZKKR1@2Y_NP40:VfhP@0ZKgX1@2Y]>440:Vh
i0@0ZK?O1@2Y/n040:^mi`@0Zk_U2@2Y_nU30?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool04@3oool002X0oooo00<000000?ooo`3oool0D`3oool90:Vmj0@0YkgY102V_NX50:Bnk0@0
Y;o/102[`NX50:c1j@T0/KcR0P2Y]N420;:nh`D0ZKCP102/]^440:VfhPD0ZK?P102Y]^840:Vcg`D0
ZKCQ102_^^840:Vcg`D0ZkoY102[_NL40:VojP@0ZKoYB03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0140oooo000[0?ooo`800000E03oool90:Vmj0@0Z;gX102V_NX50:Fmj`@0Y;o/
102U_n`40:c1j@D0[L7Y102a_>850;:nh`80ZKCP0`2a`>D40:bfh@@0/KgS1@2Y/n040;2lhP@0ZK?O
1@2]_^H40:njhP@0Z/7[102[_nT50:RojP@0ZKoZC03oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0140oooo000]0?ooo`030000003oool0oooo0580oooo2@2Y_NP40:Rmj0@0YkgY1@2U
_N/40:Fnj`@0YKo/102V`>`50:g1j@@0Zl7Z102b_^<60;70i@@0[L7Y102a_N<50:g1j0@0/;cR102[
`NX40:fniPD0ZL;/102Z`N/40:Roj`D0Z;oZC`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0140oooo000^0?ooo`030000003oool0oooo0580oooo3@2Y_NP90:Nmj@P0YKk[2@2V`>`4
0:_1jPD0ZL;[1@2W`^`40:g1j@@0ZL;/102]`NP50:S2k0@0Zl7Z102X`^d40:W2k0T0Z;o[E03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo
0580oooo3@2Y_NP40:Rmj0T0YkgY2@2U_^/40:K0k0T0YL3/102W`^`50:K1k@@0ZL;/102W`^d40:S2
k0D0Yl7/102X`^d90:RojeP0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`00<03oool00`000000oooo0?ooo`1B0?ooo`d0ZKgX2@2X_NP40:Nmj@D0YkgZ102W_NT90:Jnj`@0
YL3/102V_n`50:K1k@@0Y/3/102W`^d40:O0k0D0Yl7/102X_nX40:Roj`030000003oool0oooo05X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0oooo
5P2Y_NP90:Rmj0T0YkgY102V_^/40:NnjP@0Y[o/1@2W_n/40:K0k0@0Yko[102W`>`50:Rnj@@0Z;oZ
H03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000c0?ooo`030000003o
ool0oooo0540oooo6`2Y_NP80:Rmj0@0YkgY1@2X_NT40:NnjP@0Z;kY102W_n/50:RnjP@0Yko[202X
_^T00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool003@0oooo00<000000?ooo`3oool0D@3ooolO0:Vmj0@0Z;gX102Y_NP90:Rmj@P0Z;kY1@2X_^X5
0:Rmj@<00000J@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000e0?oo
o`030000003oool0oooo0540oooo;02Y_NP40:Rmj@@0ZKgX102X_^T50:Vmj0040?ooo`0000000000
000006`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=P3oool20000
0580oooo>@2Y_NP400000700oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?oo
o`00>03oool00`000000oooo0?ooo`1@0?ooocD0ZKgX0`00001e0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0403oool003T0oooo00<000000?ooo`3oool0D@3oool_0:Vmj0040?oo
o`0000000000000007T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00
>P3oool00`000000oooo0?ooo`1A0?ooob/0ZKgX1000001l0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0403oool003/0oooo00<000000?ooo`3oool0D@3ooolW0:Vmj0<00000P@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo000l0?ooo`800000DP3ooolR
0:Vmj0040?ooo`0000000000000008D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`00?P3oool00`000000oooo0?ooo`1@0?oooah0ZKgX100000290?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03`3oool003l0oooo00<000000?ooo`3oool0D03ooolJ0:Vm
j0<00000S@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00100?ooo`03
0000003oool0oooo0500oooo5P2Y_NP300000940oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0?0?ooo`00@@3oool200000540oooo4P2Y_NP3000009D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0?0?ooo`00@`3oool00`000000oooo0?ooo`1?0?ooo`d0ZKgX0`00
002I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool004@0oooo00<00000
0?ooo`3oool0D03oool80:Vmj0<00000W@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00l0oooo00150?ooo`030000003oool0oooo0500oooo102Y_NP300000:40oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00AP3oool200000540oooo0P00002V0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004P0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool004T0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03P3oool004X0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool0
04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03P3oool004`0oooo0P00001;0?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00CP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0=0?ooo`00C`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D03oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool2000004H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo001C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0[03oool01@000000oooo0?ooo`3oool0000000l0oooo001D0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0[P3oool010000000oooo0?ooo`00000?0?ooo`00E@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005H0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0000000l0
oooo001G0?ooo`800000?`3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0000000h0oooo
001I0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001J
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001K0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001L0?ooo`80
0000>P3oool00`000000oooo0?ooo`2]0?ooo`@00000403oool005h0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2Y0?ooo`@00000503oool005l0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`2U0?ooo`@00000603oool00600oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`2Q0?ooo`@00000703oool00640oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`2N0?ooo`<00000803oool00680oooo0P00000d0?ooo`030000003oool0oooo09X0
oooo1000000S0?ooo`00I03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09H0oooo
1000000W0?ooo`00I@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0980oooo1000
000[0?ooo`00IP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo08h0oooo1000000_
0?ooo`00I`3oool2000002l0oooo00<000000?ooo`3oool0RP3oool4000003<0oooo001Y0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0Q`3oool3000003L0oooo001Z0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0P`3oool4000003X0oooo001[0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0O`3oool4000003h0oooo001/0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0N`3oool400000480oooo001]0?ooo`800000:@3oool00`00
0000oooo0?ooo`1g0?ooo`@00000AP3oool006l0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`1e0?ooo`<00000BP3oool00700oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`1a0?ooo`@00000C@3oool00740oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1]0?ooo`@00000D@3oool00780oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000001E
0?ooo`00M03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06D0oooo1000001I0?oo
o`00M@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0680oooo0`00001M0?ooo`00
MP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo1000001P0?ooo`00M`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo1000001T0?ooo`00N03oool2
000001d0oooo00<000000?ooo`3oool0EP3oool4000006P0oooo001j0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0DP3oool4000006`0oooo001k0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0CP3oool400000700oooo001l0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0B`3oool3000007@0oooo001m0?ooo`800000603oool00`000000oooo0?oo
o`170?ooo`@00000M`3oool007l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`13
0?ooo`@00000N`3oool00800oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o0?oo
o`@00000O`3oool00840oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`@0
0000P`3oool00880oooo0P00000C0?ooo`030000003oool0oooo03P0oooo0`0000270?ooo`00Q03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo1000002:0?ooo`00Q@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo1000002>0?ooo`00QP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo02`0oooo1000002B0?ooo`00Q`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo1000002F0?ooo`00R03oool2000000d0oooo
00<000000?ooo`3oool09@3oool3000009X0oooo002:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool08P3oool4000009d0oooo002;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07P3oool400000:40oooo002<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06P3oool400000:D0oooo002=0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?ooo`@0
0000Z@3oool008l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000
[@3oool00900oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000/@3o
ool00940oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000]03oool0
0980oooo00D000000?ooo`3oool0oooo000000090?ooo`@00000^03oool009<0oooo0P0000000`3o
ool000000?ooo`040?ooo`@00000_03oool009D0oooo0P0000000`3oool000000000000200000<00
oooo002F0?ooo`800000a03oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0
ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .5868 Mtetra
.42004 .5868 .42621 .59265 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57397 Mtetra
.46248 .57397 .46854 .57992 .47922 .5767 .47319 .57074 Mtetra
.47319 .57074 .47922 .5767 .48995 .57348 .48394 .56748 Mtetra
.48394 .56748 .48995 .57348 .50072 .57024 .49474 .56423 Mtetra
.663 .741 .908 r
.49474 .56423 .50072 .57024 .51154 .567 .50558 .56097 Mtetra
.662 .741 .908 r
.50558 .56097 .51154 .567 .52239 .56374 .51647 .55772 Mtetra
.661 .741 .91 r
.51647 .55772 .52239 .56374 .53329 .56051 .5274 .5545 Mtetra
.659 .742 .911 r
.5274 .5545 .53329 .56051 .54424 .55729 .53837 .55133 Mtetra
.657 .743 .914 r
.53837 .55133 .54424 .55729 .55522 .55412 .54938 .5482 Mtetra
.655 .745 .916 r
.54938 .5482 .55522 .55412 .56626 .55101 .56045 .5451 Mtetra
.654 .746 .918 r
.56045 .5451 .56626 .55101 .57734 .54794 .57156 .54201 Mtetra
.655 .747 .917 r
.57156 .54201 .57734 .54794 .58846 .5449 .58271 .53887 Mtetra
.658 .745 .914 r
.58271 .53887 .58846 .5449 .59964 .54187 .59391 .53564 Mtetra
.662 .74 .908 r
.59391 .53564 .59964 .54187 .61086 .53878 .60516 .5323 Mtetra
.665 .735 .901 r
.60516 .5323 .61086 .53878 .62212 .53564 .61644 .52885 Mtetra
.667 .726 .894 r
.61644 .52885 .62212 .53564 .63343 .5324 .62777 .52533 Mtetra
.668 .719 .887 r
.62777 .52533 .63343 .5324 .64479 .5291 .63915 .52175 Mtetra
.667 .712 .881 r
.63915 .52175 .64479 .5291 .65619 .52572 .65057 .51819 Mtetra
.665 .707 .878 r
.65057 .51819 .65619 .52572 .66763 .52231 .66204 .51465 Mtetra
.663 .703 .877 r
.66204 .51465 .66763 .52231 .67912 .51886 .67356 .51117 Mtetra
.661 .703 .877 r
.67356 .51117 .67912 .51886 .69066 .51536 .68513 .50775 Mtetra
.66 .705 .88 r
.68513 .50775 .69066 .51536 .70224 .51183 .69675 .50435 Mtetra
.66 .709 .884 r
.69675 .50435 .70224 .51183 .71387 .50823 .70842 .50097 Mtetra
.661 .716 .89 r
.70842 .50097 .71387 .50823 .72554 .50456 .72013 .49753 Mtetra
.663 .725 .895 r
.72013 .49753 .72554 .50456 .73725 .50079 .73189 .49402 Mtetra
.666 .735 .901 r
.73189 .49402 .73725 .50079 .749 .49696 .7437 .49039 Mtetra
.669 .743 .906 r
.7437 .49039 .749 .49696 .7608 .49309 .75554 .48666 Mtetra
.671 .749 .909 r
.75554 .48666 .7608 .49309 .77265 .4892 .76743 .48283 Mtetra
.672 .752 .911 r
.76743 .48283 .77265 .4892 .78455 .48535 .77936 .47895 Mtetra
.77936 .47895 .78455 .48535 .79649 .48154 .79134 .47508 Mtetra
.67 .75 .911 r
.79134 .47508 .79649 .48154 .8085 .47779 .80338 .47123 Mtetra
.668 .747 .909 r
.80338 .47123 .8085 .47779 .82056 .47408 .81547 .46742 Mtetra
.666 .744 .909 r
.81547 .46742 .82056 .47408 .83267 .47039 .82761 .46367 Mtetra
.665 .743 .908 r
.82761 .46367 .83267 .47039 .84483 .46672 .83981 .45993 Mtetra
.664 .741 .907 r
.83981 .45993 .84483 .46672 .85705 .46303 .85206 .45621 Mtetra
.85206 .45621 .85705 .46303 .86931 .45934 .86437 .45248 Mtetra
.86437 .45248 .86931 .45934 .88163 .45563 .87672 .44875 Mtetra
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .44499 Mtetra
.88913 .44499 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44065 .92668 .43364 Mtetra
.92668 .43364 .93144 .44065 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .58411 Mtetra
.4033 .58411 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .5777 Mtetra
.4244 .5777 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57123 Mtetra
.44567 .57123 .4518 .5772 .46248 .57397 .45637 .56798 Mtetra
.45637 .56798 .46248 .57397 .47319 .57074 .46711 .56472 Mtetra
.663 .741 .908 r
.46711 .56472 .47319 .57074 .48394 .56748 .47789 .56146 Mtetra
.47789 .56146 .48394 .56748 .49474 .56423 .48872 .5582 Mtetra
.661 .741 .909 r
.48872 .5582 .49474 .56423 .50558 .56097 .49959 .55498 Mtetra
.659 .743 .912 r
.49959 .55498 .50558 .56097 .51647 .55772 .5105 .5518 Mtetra
.656 .745 .915 r
.5105 .5518 .51647 .55772 .5274 .5545 .52145 .54869 Mtetra
.654 .749 .919 r
.52145 .54869 .5274 .5545 .53837 .55133 .53246 .54562 Mtetra
.654 .753 .923 r
.53246 .54562 .53837 .55133 .54938 .5482 .5435 .54253 Mtetra
.657 .756 .923 r
.5435 .54253 .54938 .5482 .56045 .5451 .5546 .53932 Mtetra
.665 .755 .918 r
.5546 .53932 .56045 .5451 .57156 .54201 .56573 .53588 Mtetra
.674 .747 .906 r
.56573 .53588 .57156 .54201 .58271 .53887 .57691 .53217 Mtetra
.681 .732 .889 r
.57691 .53217 .58271 .53887 .59391 .53564 .58812 .5282 Mtetra
.67 .708 .877 r
.58812 .5282 .59391 .53564 .60516 .5323 .59939 .52454 Mtetra
.663 .698 .872 r
.59939 .52454 .60516 .5323 .61644 .52885 .6107 .52111 Mtetra
.663 .699 .873 r
.6107 .52111 .61644 .52885 .62777 .52533 .62206 .51766 Mtetra
.663 .702 .876 r
.62206 .51766 .62777 .52533 .63915 .52175 .63347 .51419 Mtetra
.663 .706 .879 r
.63347 .51419 .63915 .52175 .65057 .51819 .64492 .51071 Mtetra
.664 .709 .881 r
.64492 .51071 .65057 .51819 .66204 .51465 .65642 .50722 Mtetra
.664 .711 .883 r
.65642 .50722 .66204 .51465 .67356 .51117 .66797 .50371 Mtetra
.66797 .50371 .67356 .51117 .68513 .50775 .67956 .50019 Mtetra
.664 .709 .881 r
.67956 .50019 .68513 .50775 .69675 .50435 .6912 .49665 Mtetra
.663 .706 .879 r
.6912 .49665 .69675 .50435 .70842 .50097 .70289 .4931 Mtetra
.663 .702 .876 r
.70289 .4931 .70842 .50097 .72013 .49753 .71463 .48954 Mtetra
.663 .699 .873 r
.71463 .48954 .72013 .49753 .73189 .49402 .72642 .48596 Mtetra
.656 .696 .875 r
.72642 .48596 .73189 .49402 .7437 .49039 .73827 .4826 Mtetra
.647 .7 .885 r
.73827 .4826 .7437 .49039 .75554 .48666 .7502 .47956 Mtetra
.654 .723 .9 r
.7502 .47956 .75554 .48666 .76743 .48283 .76216 .47626 Mtetra
.662 .744 .911 r
.76216 .47626 .76743 .48283 .77936 .47895 .77415 .47268 Mtetra
.668 .757 .916 r
.77415 .47268 .77936 .47895 .79134 .47508 .78618 .46886 Mtetra
.672 .761 .917 r
.78618 .46886 .79134 .47508 .80338 .47123 .79825 .46492 Mtetra
.672 .759 .916 r
.79825 .46492 .80338 .47123 .81547 .46742 .81036 .46096 Mtetra
.67 .754 .913 r
.81036 .46096 .81547 .46742 .82761 .46367 .82253 .45703 Mtetra
.668 .748 .911 r
.82253 .45703 .82761 .46367 .83981 .45993 .83476 .45318 Mtetra
.666 .745 .909 r
.83476 .45318 .83981 .45993 .85206 .45621 .84704 .44937 Mtetra
.665 .742 .908 r
.84704 .44937 .85206 .45621 .86437 .45248 .85938 .44559 Mtetra
.664 .742 .908 r
.85938 .44559 .86437 .45248 .87672 .44875 .87177 .44181 Mtetra
.664 .741 .907 r
.87177 .44181 .87672 .44875 .88913 .44499 .88422 .43803 Mtetra
.88422 .43803 .88913 .44499 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .58411 .39701 .57819 Mtetra
.39701 .57819 .4033 .58411 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .5777 .41817 .57173 Mtetra
.41817 .57173 .4244 .5777 .43501 .57447 .42881 .56849 Mtetra
.42881 .56849 .43501 .57447 .44567 .57123 .43949 .56523 Mtetra
.43949 .56523 .44567 .57123 .45637 .56798 .45022 .56196 Mtetra
.663 .741 .908 r
.45022 .56196 .45637 .56798 .46711 .56472 .46098 .55869 Mtetra
.662 .741 .908 r
.46098 .55869 .46711 .56472 .47789 .56146 .47179 .55543 Mtetra
.66 .741 .91 r
.47179 .55543 .47789 .56146 .48872 .5582 .48265 .55223 Mtetra
.657 .743 .914 r
.48265 .55223 .48872 .5582 .49959 .55498 .49354 .5491 Mtetra
.653 .746 .918 r
.49354 .5491 .49959 .55498 .5105 .5518 .50448 .54606 Mtetra
.652 .751 .923 r
.50448 .54606 .5105 .5518 .52145 .54869 .51547 .54302 Mtetra
.656 .756 .923 r
.51547 .54302 .52145 .54869 .53246 .54562 .5265 .53983 Mtetra
.669 .756 .916 r
.5265 .53983 .53246 .54562 .5435 .54253 .53757 .5363 Mtetra
.684 .747 .899 r
.53757 .5363 .5435 .54253 .5546 .53932 .54869 .53227 Mtetra
.675 .72 .883 r
.54869 .53227 .5546 .53932 .56573 .53588 .55985 .52849 Mtetra
.663 .707 .88 r
.55985 .52849 .56573 .53588 .57691 .53217 .57106 .52507 Mtetra
.664 .716 .888 r
.57106 .52507 .57691 .53217 .58812 .5282 .58231 .52164 Mtetra
.664 .734 .901 r
.58231 .52164 .58812 .5282 .59939 .52454 .59361 .51819 Mtetra
.664 .741 .907 r
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73827 .4826 .73287 .47568 Mtetra
.664 .734 .901 r
.73287 .47568 .73827 .4826 .7502 .47956 .74479 .47205 Mtetra
.664 .716 .888 r
.74479 .47205 .7502 .47956 .76216 .47626 .75676 .46839 Mtetra
.653 .703 .884 r
.75676 .46839 .76216 .47626 .77415 .47268 .76881 .46511 Mtetra
.645 .709 .894 r
.76881 .46511 .77415 .47268 .78618 .46886 .78093 .46207 Mtetra
.659 .739 .909 r
.78093 .46207 .78618 .46886 .79825 .46492 .79307 .45853 Mtetra
.669 .757 .916 r
.79307 .45853 .79825 .46492 .81036 .46096 .80523 .45463 Mtetra
.673 .761 .917 r
.80523 .45463 .81036 .46096 .82253 .45703 .81743 .45058 Mtetra
.673 .758 .915 r
.81743 .45058 .82253 .45703 .83476 .45318 .82968 .44653 Mtetra
.67 .751 .912 r
.82968 .44653 .83476 .45318 .84704 .44937 .84199 .44257 Mtetra
.667 .746 .91 r
.84199 .44257 .84704 .44937 .85938 .44559 .85436 .43868 Mtetra
.665 .743 .908 r
.85436 .43868 .85938 .44559 .87177 .44181 .86679 .43484 Mtetra
.664 .742 .908 r
.86679 .43484 .87177 .44181 .88422 .43803 .87927 .43101 Mtetra
.664 .741 .907 r
.87927 .43101 .88422 .43803 .89672 .43423 .89181 .42718 Mtetra
.89181 .42718 .89672 .43423 .90928 .43041 .90441 .42333 Mtetra
.90441 .42333 .90928 .43041 .92189 .42659 .91705 .41947 Mtetra
.91705 .41947 .92189 .42659 .93455 .42274 .92976 .4156 Mtetra
.92976 .4156 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.41189 .56573 .41817 .57173 .42881 .56849 .42256 .56246 Mtetra
.42256 .56246 .42881 .56849 .43949 .56523 .43327 .55918 Mtetra
.663 .741 .908 r
.43327 .55918 .43949 .56523 .45022 .56196 .44402 .5559 Mtetra
.662 .741 .909 r
.44402 .5559 .45022 .56196 .46098 .55869 .45481 .55265 Mtetra
.659 .742 .911 r
.45481 .55265 .46098 .55869 .47179 .55543 .46565 .54947 Mtetra
.655 .744 .915 r
.46565 .54947 .47179 .55543 .48265 .55223 .47653 .54639 Mtetra
.651 .748 .92 r
.47653 .54639 .48265 .55223 .49354 .5491 .48745 .54339 Mtetra
.653 .753 .924 r
.48745 .54339 .49354 .5491 .50448 .54606 .49842 .54032 Mtetra
.665 .756 .918 r
.49842 .54032 .50448 .54606 .51547 .54302 .50944 .53688 Mtetra
.686 .75 .9 r
.50944 .53688 .51547 .54302 .5265 .53983 .5205 .53279 Mtetra
.675 .72 .883 r
.5205 .53279 .5265 .53983 .53757 .5363 .5316 .52902 Mtetra
.663 .71 .883 r
.5316 .52902 .53757 .5363 .54869 .53227 .54275 .5256 Mtetra
.664 .729 .898 r
.54275 .5256 .54869 .53227 .55985 .52849 .55394 .52216 Mtetra
.664 .741 .907 r
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50479 Mtetra
.61059 .50479 .61635 .51125 .62778 .50776 .62206 .50127 Mtetra
.62206 .50127 .62778 .50776 .63927 .50425 .63357 .49774 Mtetra
.63357 .49774 .63927 .50425 .6508 .50073 .64514 .4942 Mtetra
.64514 .4942 .6508 .50073 .66238 .4972 .65675 .49064 Mtetra
.65675 .49064 .66238 .4972 .67401 .49365 .66841 .48706 Mtetra
.66841 .48706 .67401 .49365 .68568 .49009 .68012 .48347 Mtetra
.68012 .48347 .68568 .49009 .69741 .48651 .69187 .47986 Mtetra
.69187 .47986 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76881 .46511 .76346 .45791 Mtetra
.664 .729 .898 r
.76346 .45791 .76881 .46511 .78093 .46207 .77556 .4542 Mtetra
.653 .706 .886 r
.77556 .4542 .78093 .46207 .79307 .45853 .78775 .45085 Mtetra
.643 .708 .895 r
.78775 .45085 .79307 .45853 .80523 .45463 .80002 .44782 Mtetra
.662 .743 .91 r
.80002 .44782 .80523 .45463 .81743 .45058 .81229 .44412 Mtetra
.673 .759 .916 r
.81229 .44412 .81743 .45058 .82968 .44653 .82458 .44006 Mtetra
.675 .76 .915 r
.82458 .44006 .82968 .44653 .84199 .44257 .83692 .4359 Mtetra
.672 .754 .912 r
.83692 .4359 .84199 .44257 .85436 .43868 .84931 .43183 Mtetra
.668 .748 .91 r
.84931 .43183 .85436 .43868 .86679 .43484 .86177 .42786 Mtetra
.666 .744 .908 r
.86177 .42786 .86679 .43484 .87927 .43101 .87429 .42395 Mtetra
.665 .742 .908 r
.87429 .42395 .87927 .43101 .89181 .42718 .88686 .42007 Mtetra
.664 .741 .907 r
.88686 .42007 .89181 .42718 .90441 .42333 .8995 .41619 Mtetra
.8995 .41619 .90441 .42333 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .4156 .92493 .40839 Mtetra
.92493 .40839 .92976 .4156 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55968 Mtetra
.40557 .55968 .41189 .56573 .42256 .56246 .41626 .55639 Mtetra
.663 .741 .908 r
.41626 .55639 .42256 .56246 .43327 .55918 .427 .5531 Mtetra
.661 .741 .909 r
.427 .5531 .43327 .55918 .44402 .5559 .43778 .54985 Mtetra
.658 .742 .912 r
.43778 .54985 .44402 .5559 .45481 .55265 .44859 .54669 Mtetra
.653 .744 .916 r
.44859 .54669 .45481 .55265 .46565 .54947 .45945 .54365 Mtetra
.65 .748 .922 r
.45945 .54365 .46565 .54947 .47653 .54639 .47036 .54067 Mtetra
.656 .754 .922 r
.47036 .54067 .47653 .54639 .48745 .54339 .48131 .53749 Mtetra
.677 .755 .909 r
.48131 .53749 .48745 .54339 .49842 .54032 .49232 .5337 Mtetra
.687 .736 .888 r
.49232 .5337 .49842 .54032 .50944 .53688 .50337 .52954 Mtetra
.663 .709 .882 r
.50337 .52954 .50944 .53688 .5205 .53279 .51445 .52612 Mtetra
.664 .729 .898 r
.51445 .52612 .5205 .53279 .5316 .52902 .52558 .52269 Mtetra
.664 .741 .907 r
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.55925 .51232 .56518 .51872 .57646 .51526 .57056 .50883 Mtetra
.57056 .50883 .57646 .51526 .58779 .51178 .58192 .50533 Mtetra
.58192 .50533 .58779 .51178 .59916 .5083 .59333 .50182 Mtetra
.59333 .50182 .59916 .5083 .61059 .50479 .60478 .49829 Mtetra
.60478 .49829 .61059 .50479 .62206 .50127 .61629 .49474 Mtetra
.644 .734 .914 r
.61629 .49474 .62206 .50127 .63357 .49774 .62785 .49177 Mtetra
.639 .752 .93 r
.62785 .49177 .63357 .49774 .64514 .4942 .63947 .48885 Mtetra
.66 .782 .939 r
.63947 .48885 .64514 .4942 .65675 .49064 .65112 .48527 Mtetra
.684 .789 .93 r
.65112 .48527 .65675 .49064 .66841 .48706 .66279 .481 Mtetra
.682 .766 .914 r
.66279 .481 .66841 .48706 .68012 .48347 .67451 .4768 Mtetra
.664 .741 .907 r
.67451 .4768 .68012 .48347 .69187 .47986 .6863 .47317 Mtetra
.6863 .47317 .69187 .47986 .70368 .47624 .69814 .46952 Mtetra
.69814 .46952 .70368 .47624 .71554 .47261 .71003 .46586 Mtetra
.71003 .46586 .71554 .47261 .72744 .46896 .72197 .46218 Mtetra
.72197 .46218 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78775 .45085 .78243 .44355 Mtetra
.664 .729 .898 r
.78243 .44355 .78775 .45085 .80002 .44782 .79467 .43977 Mtetra
.641 .7 .888 r
.79467 .43977 .80002 .44782 .81229 .44412 .80704 .43676 Mtetra
.651 .724 .902 r
.80704 .43676 .81229 .44412 .82458 .44006 .81943 .43337 Mtetra
.67 .754 .913 r
.81943 .43337 .82458 .44006 .83692 .4359 .83182 .42934 Mtetra
.676 .761 .915 r
.83182 .42934 .83692 .4359 .84931 .43183 .84424 .42511 Mtetra
.673 .756 .913 r
.84424 .42511 .84931 .43183 .86177 .42786 .85672 .42094 Mtetra
.669 .749 .91 r
.85672 .42094 .86177 .42786 .87429 .42395 .86927 .41689 Mtetra
.666 .744 .908 r
.86927 .41689 .87429 .42395 .88686 .42007 .88188 .41293 Mtetra
.665 .742 .908 r
.88188 .41293 .88686 .42007 .8995 .41619 .89455 .409 Mtetra
.664 .741 .907 r
.89455 .409 .8995 .41619 .91218 .4123 .90727 .40508 Mtetra
.90727 .40508 .91218 .4123 .92493 .40839 .92006 .40113 Mtetra
.92006 .40113 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56018 Mtetra
.37789 .56018 .38431 .56623 .39492 .56296 .38852 .55689 Mtetra
.38852 .55689 .39492 .56296 .40557 .55968 .3992 .55359 Mtetra
.663 .741 .908 r
.3992 .55359 .40557 .55968 .41626 .55639 .40992 .55029 Mtetra
.661 .741 .909 r
.40992 .55029 .41626 .55639 .427 .5531 .42068 .54703 Mtetra
.657 .741 .912 r
.42068 .54703 .427 .5531 .43778 .54985 .43148 .54387 Mtetra
.652 .744 .917 r
.43148 .54387 .43778 .54985 .44859 .54669 .44232 .54085 Mtetra
.649 .748 .922 r
.44232 .54085 .44859 .54669 .45945 .54365 .45321 .53788 Mtetra
.66 .754 .92 r
.45321 .53788 .45945 .54365 .47036 .54067 .46415 .53459 Mtetra
.688 .752 .901 r
.46415 .53459 .47036 .54067 .48131 .53749 .47515 .53043 Mtetra
.675 .72 .883 r
.47515 .53043 .48131 .53749 .49232 .5337 .48618 .52665 Mtetra
.664 .718 .889 r
.48618 .52665 .49232 .5337 .50337 .52954 .49725 .52322 Mtetra
.664 .741 .907 r
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51285 Mtetra
.53073 .51285 .53676 .51925 .54798 .51579 .54198 .50937 Mtetra
.54198 .50937 .54798 .51579 .55925 .51232 .55328 .50587 Mtetra
.55328 .50587 .55925 .51232 .57056 .50883 .56462 .50236 Mtetra
.49 .674 .946 r
.56462 .50236 .57056 .50883 .58192 .50533 .57608 .50277 Mtetra
.313 .743 .971 r
.57608 .50277 .58192 .50533 .59333 .50182 .58759 .50272 Mtetra
.014 0 0 r
.58759 .50272 .59333 .50182 .60478 .49829 .59917 .50191 Mtetra
.201 0 0 r
.59917 .50191 .60478 .49829 .61629 .49474 .61078 .50029 Mtetra
.268 0 0 r
.61078 .50029 .61629 .49474 .62785 .49177 .62244 .49795 Mtetra
.258 0 0 r
.62244 .49795 .62785 .49177 .63947 .48885 .63414 .49495 Mtetra
.216 0 0 r
.63414 .49495 .63947 .48885 .65112 .48527 .64587 .49134 Mtetra
.175 0 0 r
.64587 .49134 .65112 .48527 .66279 .481 .65762 .48714 Mtetra
.135 0 0 r
.65762 .48714 .66279 .481 .67451 .4768 .66939 .48227 Mtetra
.03 0 0 r
.66939 .48227 .67451 .4768 .6863 .47317 .68117 .47667 Mtetra
0 0 0 r
.68117 .47667 .6863 .47317 .69814 .46952 .69294 .47024 Mtetra
.634 .964 .864 r
.69294 .47024 .69814 .46952 .71003 .46586 .7047 .46303 Mtetra
.783 .912 .928 r
.7047 .46303 .71003 .46586 .72197 .46218 .71645 .45534 Mtetra
.664 .741 .907 r
.71645 .45534 .72197 .46218 .73396 .45848 .72848 .45162 Mtetra
.72848 .45162 .73396 .45848 .746 .45477 .74056 .44788 Mtetra
.74056 .44788 .746 .45477 .75809 .45105 .75268 .44413 Mtetra
.75268 .44413 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80704 .43676 .80171 .42894 Mtetra
.653 .713 .892 r
.80171 .42894 .80704 .43676 .81943 .43337 .81413 .42549 Mtetra
.641 .707 .895 r
.81413 .42549 .81943 .43337 .83182 .42934 .82665 .42241 Mtetra
.667 .747 .91 r
.82665 .42241 .83182 .42934 .84424 .42511 .83914 .41844 Mtetra
.676 .76 .914 r
.83914 .41844 .84424 .42511 .85672 .42094 .85165 .41415 Mtetra
.674 .757 .913 r
.85165 .41415 .85672 .42094 .86927 .41689 .86422 .40989 Mtetra
.67 .749 .91 r
.86422 .40989 .86927 .41689 .88188 .41293 .87685 .40578 Mtetra
.666 .744 .908 r
.87685 .40578 .88188 .41293 .89455 .409 .88956 .40177 Mtetra
.665 .742 .908 r
.88956 .40177 .89455 .409 .90727 .40508 .90233 .39779 Mtetra
.664 .741 .907 r
.90233 .39779 .90727 .40508 .92006 .40113 .91515 .39382 Mtetra
.91515 .39382 .92006 .40113 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56018 .37142 .5541 Mtetra
.37142 .5541 .37789 .56018 .38852 .55689 .38208 .55078 Mtetra
.663 .741 .908 r
.38208 .55078 .38852 .55689 .3992 .55359 .39278 .54747 Mtetra
.662 .741 .909 r
.39278 .54747 .3992 .55359 .40992 .55029 .40353 .54419 Mtetra
.657 .741 .912 r
.40353 .54419 .40992 .55029 .42068 .54703 .41431 .54101 Mtetra
.651 .743 .917 r
.41431 .54101 .42068 .54703 .43148 .54387 .42514 .538 Mtetra
.648 .748 .922 r
.42514 .538 .43148 .54387 .44232 .54085 .436 .53503 Mtetra
.662 .754 .919 r
.436 .53503 .44232 .54085 .45321 .53788 .44693 .53167 Mtetra
.696 .751 .894 r
.44693 .53167 .45321 .53788 .46415 .53459 .45792 .52724 Mtetra
.665 .71 .881 r
.45792 .52724 .46415 .53459 .47515 .53043 .46893 .52375 Mtetra
.664 .729 .898 r
.46893 .52375 .47515 .53043 .48618 .52665 .47998 .52031 Mtetra
.664 .741 .907 r
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.50223 .51339 .50836 .51978 .51952 .51632 .51342 .50991 Mtetra
.51342 .50991 .51952 .51632 .53073 .51285 .52465 .50641 Mtetra
.593 .717 .93 r
.52465 .50641 .53073 .51285 .54198 .50937 .53594 .50477 Mtetra
.267 .635 .963 r
.53594 .50477 .54198 .50937 .55328 .50587 .54731 .50682 Mtetra
.24 0 0 r
.54731 .50682 .55328 .50587 .56462 .50236 .55876 .50798 Mtetra
.402 0 0 r
.55876 .50798 .56462 .50236 .57608 .50277 .57027 .50789 Mtetra
.31 0 0 r
.57027 .50789 .57608 .50277 .58759 .50272 .58184 .50658 Mtetra
.157 0 0 r
.58184 .50658 .58759 .50272 .59917 .50191 .59344 .5043 Mtetra
0 0 0 r
.59344 .5043 .59917 .50191 .61078 .50029 .60509 .50137 Mtetra
.263 .768 .758 r
.60509 .50137 .61078 .50029 .62244 .49795 .61678 .49805 Mtetra
.4 .854 .88 r
.61678 .49805 .62244 .49795 .63414 .49495 .62852 .49453 Mtetra
.461 .881 .925 r
.62852 .49453 .63414 .49495 .64587 .49134 .6403 .49091 Mtetra
.47 .886 .926 r
.6403 .49091 .64587 .49134 .65762 .48714 .65213 .48718 Mtetra
.437 .874 .889 r
.65213 .48718 .65762 .48714 .66939 .48227 .664 .48325 Mtetra
.364 .833 .797 r
.664 .48325 .66939 .48227 .68117 .47667 .67591 .47893 Mtetra
0 0 0 r
.67591 .47893 .68117 .47667 .69294 .47024 .68782 .47394 Mtetra
.68782 .47394 .69294 .47024 .7047 .46303 .69973 .46797 Mtetra
.69973 .46797 .7047 .46303 .71645 .45534 .7116 .46076 Mtetra
.7116 .46076 .71645 .45534 .72848 .45162 .72342 .45225 Mtetra
.75 .994 .852 r
.72342 .45225 .72848 .45162 .74056 .44788 .73519 .44283 Mtetra
.723 .823 .927 r
.73519 .44283 .74056 .44788 .75268 .44413 .74723 .43715 Mtetra
.664 .741 .907 r
.74723 .43715 .75268 .44413 .76486 .44035 .75945 .43335 Mtetra
.75945 .43335 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .81413 .42549 .80883 .41798 Mtetra
.662 .729 .899 r
.80883 .41798 .81413 .42549 .82665 .42241 .82132 .41416 Mtetra
.633 .696 .891 r
.82132 .41416 .82665 .42241 .83914 .41844 .83395 .41132 Mtetra
.665 .743 .908 r
.83395 .41132 .83914 .41844 .85165 .41415 .84654 .40736 Mtetra
.677 .759 .913 r
.84654 .40736 .85165 .41415 .86422 .40989 .85914 .403 Mtetra
.675 .756 .912 r
.85914 .403 .86422 .40989 .87685 .40578 .8718 .39868 Mtetra
.669 .749 .91 r
.8718 .39868 .87685 .40578 .88956 .40177 .88454 .39452 Mtetra
.666 .744 .908 r
.88454 .39452 .88956 .40177 .90233 .39779 .89734 .39047 Mtetra
.665 .742 .908 r
.89734 .39047 .90233 .39779 .91515 .39382 .9102 .38644 Mtetra
.664 .741 .907 r
.9102 .38644 .91515 .39382 .92803 .38983 .92312 .38242 Mtetra
.92312 .38242 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.35426 .55129 .3608 .5574 .37142 .5541 .3649 .54796 Mtetra
.663 .741 .907 r
.3649 .54796 .37142 .5541 .38208 .55078 .37559 .54463 Mtetra
.662 .741 .908 r
.37559 .54463 .38208 .55078 .39278 .54747 .38632 .54133 Mtetra
.658 .741 .911 r
.38632 .54133 .39278 .54747 .40353 .54419 .39708 .53812 Mtetra
.651 .742 .916 r
.39708 .53812 .40353 .54419 .41431 .54101 .40789 .53509 Mtetra
.647 .747 .922 r
.40789 .53509 .41431 .54101 .42514 .538 .41874 .53214 Mtetra
.661 .753 .918 r
.41874 .53214 .42514 .538 .436 .53503 .42965 .52879 Mtetra
.698 .751 .893 r
.42965 .52879 .436 .53503 .44693 .53167 .44063 .52428 Mtetra
.663 .709 .882 r
.44063 .52428 .44693 .53167 .45792 .52724 .45162 .52084 Mtetra
.664 .739 .906 r
.45162 .52084 .45792 .52724 .46893 .52375 .46266 .51739 Mtetra
.664 .741 .907 r
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.47374 .51392 .47998 .52031 .49108 .51686 .48487 .51044 Mtetra
.48487 .51044 .49108 .51686 .50223 .51339 .49604 .50695 Mtetra
.646 .735 .914 r
.49604 .50695 .50223 .51339 .51342 .50991 .50726 .50397 Mtetra
.229 .561 .936 r
.50726 .50397 .51342 .50991 .52465 .50641 .51852 .50737 Mtetra
.36 0 0 r
.51852 .50737 .52465 .50641 .53594 .50477 .52986 .50978 Mtetra
.416 0 0 r
.52986 .50978 .53594 .50477 .54731 .50682 .54129 .51031 Mtetra
.2 0 0 r
.54129 .51031 .54731 .50682 .55876 .50798 .55277 .5089 Mtetra
.253 .764 .773 r
.55277 .5089 .55876 .50798 .57027 .50789 .5643 .50596 Mtetra
.606 .899 .987 r
.5643 .50596 .57027 .50789 .58184 .50658 .57587 .50203 Mtetra
.685 .82 .948 r
.57587 .50203 .58184 .50658 .59344 .5043 .58747 .49764 Mtetra
.689 .75 .897 r
.58747 .49764 .59344 .5043 .60509 .50137 .59912 .49315 Mtetra
.68 .705 .866 r
.59912 .49315 .60509 .50137 .61678 .49805 .61081 .48883 Mtetra
.669 .678 .85 r
.61081 .48883 .61678 .49805 .62852 .49453 .62256 .48481 Mtetra
.658 .664 .844 r
.62256 .48481 .62852 .49453 .6403 .49091 .63436 .48115 Mtetra
.648 .66 .847 r
.63436 .48115 .6403 .49091 .65213 .48718 .64623 .47787 Mtetra
.641 .667 .859 r
.64623 .47787 .65213 .48718 .664 .48325 .65817 .47488 Mtetra
.636 .688 .882 r
.65817 .47488 .664 .48325 .67591 .47893 .67017 .47207 Mtetra
.636 .732 .918 r
.67017 .47207 .67591 .47893 .68782 .47394 .68222 .46915 Mtetra
.637 .807 .964 r
.68222 .46915 .68782 .47394 .69973 .46797 .69431 .46578 Mtetra
.621 .905 .985 r
.69431 .46578 .69973 .46797 .7116 .46076 .7064 .46141 Mtetra
.529 .922 .855 r
.7064 .46141 .7116 .46076 .72342 .45225 .71844 .45548 Mtetra
.399 .807 .598 r
.71844 .45548 .72342 .45225 .73519 .44283 .7304 .44756 Mtetra
0 0 0 r
.7304 .44756 .73519 .44283 .74723 .43715 .74225 .43772 Mtetra
.804 .999 .835 r
.74225 .43772 .74723 .43715 .75945 .43335 .75403 .42683 Mtetra
.68 .764 .914 r
.75403 .42683 .75945 .43335 .77171 .42953 .76629 .42244 Mtetra
.664 .741 .907 r
.76629 .42244 .77171 .42953 .78403 .4257 .77865 .41858 Mtetra
.77865 .41858 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82132 .41416 .81604 .40689 Mtetra
.664 .739 .906 r
.81604 .40689 .82132 .41416 .83395 .41132 .82862 .40295 Mtetra
.631 .695 .891 r
.82862 .40295 .83395 .41132 .84654 .40736 .84135 .40013 Mtetra
.666 .743 .908 r
.84135 .40013 .84654 .40736 .85914 .403 .85403 .3961 Mtetra
.678 .759 .913 r
.85403 .3961 .85914 .403 .8718 .39868 .86673 .39166 Mtetra
.675 .755 .911 r
.86673 .39166 .8718 .39868 .88454 .39452 .87948 .3873 Mtetra
.669 .748 .909 r
.87948 .3873 .88454 .39452 .89734 .39047 .89231 .38311 Mtetra
.665 .743 .908 r
.89231 .38311 .89734 .39047 .9102 .38644 .90521 .37902 Mtetra
.664 .741 .908 r
.90521 .37902 .9102 .38644 .92312 .38242 .91818 .37495 Mtetra
.664 .741 .907 r
.91818 .37495 .92312 .38242 .9361 .37838 .9312 .37088 Mtetra
.34766 .54513 .35426 .55129 .3649 .54796 .35833 .54179 Mtetra
.663 .741 .908 r
.35833 .54179 .3649 .54796 .37559 .54463 .36905 .53846 Mtetra
.659 .741 .91 r
.36905 .53846 .37559 .54463 .38632 .54133 .3798 .53521 Mtetra
.653 .741 .915 r
.3798 .53521 .38632 .54133 .39708 .53812 .39059 .53213 Mtetra
.646 .745 .921 r
.39059 .53213 .39708 .53812 .40789 .53509 .40142 .52919 Mtetra
.658 .752 .919 r
.40142 .52919 .40789 .53509 .41874 .53214 .4123 .52593 Mtetra
.697 .752 .894 r
.4123 .52593 .41874 .53214 .42965 .52879 .42327 .52143 Mtetra
.665 .711 .882 r
.42327 .52143 .42965 .52879 .44063 .52428 .43425 .51792 Mtetra
.664 .741 .907 r
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.45634 .51098 .46266 .51739 .47374 .51392 .46745 .50749 Mtetra
.46745 .50749 .47374 .51392 .48487 .51044 .47861 .50398 Mtetra
.482 .673 .949 r
.47861 .50398 .48487 .51044 .49604 .50695 .48977 .50442 Mtetra
0 .367 .698 r
.48977 .50442 .49604 .50695 .50726 .50397 .50098 .50848 Mtetra
.478 0 0 r
.50098 .50848 .50726 .50397 .51852 .50737 .5123 .51046 Mtetra
.219 0 0 r
.5123 .51046 .51852 .50737 .52986 .50978 .5237 .50964 Mtetra
.421 .862 .909 r
.5237 .50964 .52986 .50978 .54129 .51031 .53515 .50638 Mtetra
.701 .845 .952 r
.53515 .50638 .54129 .51031 .55277 .5089 .54665 .50151 Mtetra
.717 .735 .865 r
.54665 .50151 .55277 .5089 .5643 .50596 .55818 .49582 Mtetra
.703 .671 .816 r
.55818 .49582 .5643 .50596 .57587 .50203 .56974 .48994 Mtetra
.688 .635 .791 r
.56974 .48994 .57587 .50203 .58747 .49764 .58134 .48424 Mtetra
.674 .612 .777 r
.58134 .48424 .58747 .49764 .59912 .49315 .59298 .47895 Mtetra
.663 .597 .771 r
.59298 .47895 .59912 .49315 .61081 .48883 .60467 .47415 Mtetra
.652 .586 .769 r
.60467 .47415 .61081 .48883 .62256 .48481 .61642 .4699 Mtetra
.641 .579 .769 r
.61642 .4699 .62256 .48481 .63436 .48115 .62823 .46621 Mtetra
.632 .574 .771 r
.62823 .46621 .63436 .48115 .64623 .47787 .64011 .46308 Mtetra
.622 .571 .776 r
.64011 .46308 .64623 .47787 .65817 .47488 .65206 .4605 Mtetra
.613 .571 .784 r
.65206 .4605 .65817 .47488 .67017 .47207 .6641 .45842 Mtetra
.604 .576 .796 r
.6641 .45842 .67017 .47207 .68222 .46915 .67622 .45676 Mtetra
.6 .593 .816 r
.67622 .45676 .68222 .46915 .69431 .46578 .68842 .45529 Mtetra
.603 .628 .849 r
.68842 .45529 .69431 .46578 .7064 .46141 .70068 .45363 Mtetra
.621 .703 .903 r
.70068 .45363 .7064 .46141 .71844 .45548 .71296 .45116 Mtetra
.658 .837 .969 r
.71296 .45116 .71844 .45548 .7304 .44756 .7252 .44704 Mtetra
.66 .964 .926 r
.7252 .44704 .7304 .44756 .74225 .43772 .73734 .44044 Mtetra
.564 .906 .68 r
.73734 .44044 .74225 .43772 .75403 .42683 .7493 .43097 Mtetra
.548 .857 .555 r
.7493 .43097 .75403 .42683 .76629 .42244 .76113 .41934 Mtetra
.783 .915 .928 r
.76113 .41934 .76629 .42244 .77865 .41858 .77323 .4114 Mtetra
.664 .741 .907 r
.77323 .4114 .77865 .41858 .79106 .4147 .78567 .40749 Mtetra
.78567 .40749 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.662 .74 .908 r
.82335 .39565 .82862 .40295 .84135 .40013 .83602 .39173 Mtetra
.632 .697 .892 r
.83602 .39173 .84135 .40013 .85403 .3961 .84885 .38884 Mtetra
.669 .746 .908 r
.84885 .38884 .85403 .3961 .86673 .39166 .86162 .38466 Mtetra
.678 .759 .912 r
.86162 .38466 .86673 .39166 .87948 .3873 .8744 .38014 Mtetra
.674 .753 .911 r
.8744 .38014 .87948 .3873 .89231 .38311 .88726 .37576 Mtetra
.668 .746 .909 r
.88726 .37576 .89231 .38311 .90521 .37902 .90019 .37155 Mtetra
.665 .742 .908 r
.90019 .37155 .90521 .37902 .91818 .37495 .91319 .36743 Mtetra
.664 .741 .907 r
.91319 .36743 .91818 .37495 .9312 .37088 .92625 .36332 Mtetra
.664 .741 .908 r
.34102 .53894 .34766 .54513 .35833 .54179 .35172 .53558 Mtetra
.66 .74 .909 r
.35172 .53558 .35833 .54179 .36905 .53846 .36246 .53228 Mtetra
.655 .741 .913 r
.36246 .53228 .36905 .53846 .3798 .53521 .37323 .52913 Mtetra
.647 .743 .919 r
.37323 .52913 .3798 .53521 .39059 .53213 .38404 .52618 Mtetra
.652 .749 .921 r
.38404 .52618 .39059 .53213 .40142 .52919 .3949 .52307 Mtetra
.689 .753 .9 r
.3949 .52307 .40142 .52919 .4123 .52593 .40585 .51882 Mtetra
.675 .721 .884 r
.40585 .51882 .4123 .52593 .42327 .52143 .41682 .51499 Mtetra
.664 .739 .906 r
.41682 .51499 .42327 .52143 .43425 .51792 .42783 .51152 Mtetra
.664 .741 .907 r
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.43888 .50803 .44527 .51446 .45634 .51098 .44998 .50452 Mtetra
.44998 .50452 .45634 .51098 .46745 .50749 .46112 .501 Mtetra
.327 .598 .944 r
.46112 .501 .46745 .50749 .47861 .50398 .47221 .50355 Mtetra
.441 0 0 r
.47221 .50355 .47861 .50398 .48977 .50442 .48336 .50794 Mtetra
.41 0 0 r
.48336 .50794 .48977 .50442 .50098 .50848 .49464 .50927 Mtetra
.193 .723 .758 r
.49464 .50927 .50098 .50848 .5123 .51046 .50603 .50704 Mtetra
.702 .864 .959 r
.50603 .50704 .5123 .51046 .5237 .50964 .51747 .50205 Mtetra
.734 .734 .851 r
.51747 .50205 .5237 .50964 .53515 .50638 .52896 .49551 Mtetra
.719 .665 .796 r
.52896 .49551 .53515 .50638 .54665 .50151 .54046 .48842 Mtetra
.702 .628 .771 r
.54046 .48842 .54665 .50151 .55818 .49582 .552 .48144 Mtetra
.689 .607 .76 r
.552 .48144 .55818 .49582 .56974 .48994 .56356 .47489 Mtetra
.677 .595 .756 r
.56356 .47489 .56974 .48994 .58134 .48424 .57516 .46892 Mtetra
.667 .587 .757 r
.57516 .46892 .58134 .48424 .59298 .47895 .5868 .46353 Mtetra
.658 .582 .759 r
.5868 .46353 .59298 .47895 .60467 .47415 .5985 .45873 Mtetra
.649 .578 .761 r
.5985 .45873 .60467 .47415 .61642 .4699 .61025 .45447 Mtetra
.64 .573 .764 r
.61025 .45447 .61642 .4699 .62823 .46621 .62206 .45074 Mtetra
.631 .568 .766 r
.62206 .45074 .62823 .46621 .64011 .46308 .63394 .44754 Mtetra
.621 .563 .768 r
.63394 .44754 .64011 .46308 .65206 .4605 .64589 .4449 Mtetra
.61 .557 .77 r
.64589 .4449 .65206 .4605 .6641 .45842 .65793 .44284 Mtetra
.598 .551 .772 r
.65793 .44284 .6641 .45842 .67622 .45676 .67006 .44138 Mtetra
.587 .547 .777 r
.67006 .44138 .67622 .45676 .68842 .45529 .68229 .44051 Mtetra
.577 .549 .787 r
.68229 .44051 .68842 .45529 .70068 .45363 .69462 .44009 Mtetra
.572 .563 .805 r
.69462 .44009 .70068 .45363 .71296 .45116 .70703 .43979 Mtetra
.581 .603 .84 r
.70703 .43979 .71296 .45116 .7252 .44704 .71949 .43894 Mtetra
.618 .695 .899 r
.71949 .43894 .7252 .44704 .73734 .44044 .73193 .43653 Mtetra
.695 .867 .963 r
.73193 .43653 .73734 .44044 .7493 .43097 .74425 .43131 Mtetra
.722 .989 .866 r
.74425 .43131 .7493 .43097 .76113 .41934 .75635 .42243 Mtetra
.668 .936 .658 r
.75635 .42243 .76113 .41934 .77323 .4114 .76823 .41039 Mtetra
.82 .982 .885 r
.76823 .41039 .77323 .4114 .78567 .40749 .78024 .40022 Mtetra
.664 .741 .907 r
.78024 .40022 .78567 .40749 .79818 .40356 .79279 .39626 Mtetra
.79279 .39626 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83602 .39173 .83074 .38428 Mtetra
.652 .734 .91 r
.83074 .38428 .83602 .39173 .84885 .38884 .84354 .38063 Mtetra
.64 .708 .896 r
.84354 .38063 .84885 .38884 .86162 .38466 .85644 .37741 Mtetra
.674 .751 .909 r
.85644 .37741 .86162 .38466 .8744 .38014 .86929 .37301 Mtetra
.678 .758 .911 r
.86929 .37301 .8744 .38014 .88726 .37576 .88217 .36844 Mtetra
.672 .75 .91 r
.88217 .36844 .88726 .37576 .90019 .37155 .89513 .36408 Mtetra
.667 .744 .908 r
.89513 .36408 .90019 .37155 .91319 .36743 .90816 .35985 Mtetra
.664 .741 .908 r
.90816 .35985 .91319 .36743 .92625 .36332 .92127 .3557 Mtetra
.662 .741 .908 r
.33433 .53271 .34102 .53894 .35172 .53558 .34505 .52935 Mtetra
.657 .741 .911 r
.34505 .52935 .35172 .53558 .36246 .53228 .35581 .52612 Mtetra
.649 .741 .917 r
.35581 .52612 .36246 .53228 .37323 .52913 .36661 .5231 Mtetra
.647 .746 .922 r
.36661 .5231 .37323 .52913 .38404 .52618 .37744 .52012 Mtetra
.676 .753 .909 r
.37744 .52012 .38404 .52618 .3949 .52307 .38836 .51628 Mtetra
.687 .735 .887 r
.38836 .51628 .3949 .52307 .40585 .51882 .39934 .51205 Mtetra
.664 .73 .898 r
.39934 .51205 .40585 .51882 .41682 .51499 .41032 .50856 Mtetra
.664 .741 .907 r
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.42136 .50506 .42783 .51152 .43888 .50803 .43244 .50155 Mtetra
.43244 .50155 .43888 .50803 .44998 .50452 .44356 .49802 Mtetra
.262 .563 .935 r
.44356 .49802 .44998 .50452 .46112 .501 .45459 .50126 Mtetra
.508 0 0 r
.45459 .50126 .46112 .501 .47221 .50355 .46568 .50604 Mtetra
.331 0 0 r
.46568 .50604 .47221 .50355 .48336 .50794 .47693 .50699 Mtetra
.506 .888 .965 r
.47693 .50699 .48336 .50794 .49464 .50927 .4883 .50367 Mtetra
.744 .791 .891 r
.4883 .50367 .49464 .50927 .50603 .50704 .49975 .49733 Mtetra
.739 .691 .805 r
.49975 .49733 .50603 .50704 .51747 .50205 .51123 .48952 Mtetra
.721 .643 .77 r
.51123 .48952 .51747 .50205 .52896 .49551 .52273 .48143 Mtetra
.706 .619 .757 r
.52273 .48143 .52896 .49551 .54046 .48842 .53425 .47372 Mtetra
.694 .607 .755 r
.53425 .47372 .54046 .48842 .552 .48144 .54579 .46667 Mtetra
.66 .589 .765 r
.54579 .46667 .552 .48144 .56356 .47489 .55738 .46189 Mtetra
.647 .605 .792 r
.55738 .46189 .56356 .47489 .57516 .46892 .56902 .4582 Mtetra
.655 .644 .827 r
.56902 .4582 .57516 .46892 .5868 .46353 .58072 .45449 Mtetra
.66 .681 .859 r
.58072 .45449 .5868 .46353 .5985 .45873 .59246 .45076 Mtetra
.663 .709 .882 r
.59246 .45076 .5985 .45873 .61025 .45447 .60425 .44702 Mtetra
.664 .724 .894 r
.60425 .44702 .61025 .45447 .62206 .45074 .6161 .44326 Mtetra
.6161 .44326 .62206 .45074 .63394 .44754 .62799 .43948 Mtetra
.663 .709 .882 r
.62799 .43948 .63394 .44754 .64589 .4449 .63994 .43569 Mtetra
.66 .681 .859 r
.63994 .43569 .64589 .4449 .65793 .44284 .65193 .43188 Mtetra
.655 .644 .827 r
.65193 .43188 .65793 .44284 .67006 .44138 .66398 .42806 Mtetra
.625 .594 .798 r
.66398 .42806 .67006 .44138 .68229 .44051 .67613 .42533 Mtetra
.576 .545 .782 r
.67613 .42533 .68229 .44051 .69462 .44009 .68846 .42491 Mtetra
.562 .537 .785 r
.68846 .42491 .69462 .44009 .70703 .43979 .7009 .42516 Mtetra
.551 .538 .794 r
.7009 .42516 .70703 .43979 .71949 .43894 .71346 .42582 Mtetra
.552 .561 .816 r
.71346 .42582 .71949 .43894 .73193 .43653 .72608 .42621 Mtetra
.583 .627 .861 r
.72608 .42621 .73193 .43653 .74425 .43131 .7387 .42511 Mtetra
.669 .777 .93 r
.7387 .42511 .74425 .43131 .75635 .42243 .75118 .42093 Mtetra
.777 .969 .921 r
.75118 .42093 .75635 .42243 .76823 .41039 .76339 .41238 Mtetra
.768 .984 .739 r
.76339 .41238 .76823 .41039 .78024 .40022 .77531 .39987 Mtetra
.823 .995 .858 r
.77531 .39987 .78024 .40022 .79279 .39626 .78735 .38891 Mtetra
.664 .741 .907 r
.78735 .38891 .79279 .39626 .80538 .39228 .79998 .3849 Mtetra
.79998 .3849 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .84354 .38063 .83822 .37276 Mtetra
.64 .72 .905 r
.83822 .37276 .84354 .38063 .85644 .37741 .85116 .36947 Mtetra
.652 .724 .901 r
.85116 .36947 .85644 .37741 .86929 .37301 .86412 .36576 Mtetra
.678 .756 .91 r
.86412 .36576 .86929 .37301 .88217 .36844 .87705 .36116 Mtetra
.677 .756 .91 r
.87705 .36116 .88217 .36844 .89513 .36408 .89003 .35659 Mtetra
.67 .747 .909 r
.89003 .35659 .89513 .36408 .90816 .35985 .9031 .35225 Mtetra
.665 .743 .908 r
.9031 .35225 .90816 .35985 .92127 .3557 .91624 .34803 Mtetra
.661 .742 .91 r
.32759 .52646 .33433 .53271 .34505 .52935 .33834 .52311 Mtetra
.652 .74 .914 r
.33834 .52311 .34505 .52935 .35581 .52612 .34911 .51999 Mtetra
.645 .743 .92 r
.34911 .51999 .35581 .52612 .36661 .5231 .35993 .51705 Mtetra
.661 .75 .916 r
.35993 .51705 .36661 .5231 .37744 .52012 .37081 .51366 Mtetra
.697 .747 .89 r
.37081 .51366 .37744 .52012 .38836 .51628 .38179 .5091 Mtetra
.663 .718 .889 r
.38179 .5091 .38836 .51628 .39934 .51205 .39276 .5056 Mtetra
.664 .741 .907 r
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.40378 .50209 .41032 .50856 .42136 .50506 .41484 .49856 Mtetra
.41484 .49856 .42136 .50506 .43244 .50155 .42595 .49502 Mtetra
.321 .596 .945 r
.42595 .49502 .43244 .50155 .44356 .49802 .43694 .49755 Mtetra
.524 0 0 r
.43694 .49755 .44356 .49802 .45459 .50126 .44795 .50303 Mtetra
.298 0 0 r
.44795 .50303 .45459 .50126 .46568 .50604 .45915 .50414 Mtetra
.606 .897 .988 r
.45915 .50414 .46568 .50604 .47693 .50699 .47052 .5003 Mtetra
.755 .761 .858 r
.47052 .5003 .47693 .50699 .4883 .50367 .48197 .49303 Mtetra
.744 .678 .786 r
.48197 .49303 .4883 .50367 .49975 .49733 .49346 .48427 Mtetra
.727 .639 .761 r
.49346 .48427 .49975 .49733 .51123 .48952 .50497 .47544 Mtetra
.712 .622 .755 r
.50497 .47544 .51123 .48952 .52273 .48143 .51648 .46724 Mtetra
.662 .597 .772 r
.51648 .46724 .52273 .48143 .53425 .47372 .52801 .46246 Mtetra
.653 .633 .818 r
.52801 .46246 .53425 .47372 .54579 .46667 .53959 .45877 Mtetra
.663 .709 .882 r
.53959 .45877 .54579 .46667 .55738 .46189 .55122 .45506 Mtetra
.664 .741 .907 r
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67613 .42533 .67026 .41709 Mtetra
.663 .709 .882 r
.67026 .41709 .67613 .42533 .68846 .42491 .68245 .4132 Mtetra
.628 .622 .825 r
.68245 .4132 .68846 .42491 .7009 .42516 .69475 .41041 Mtetra
.549 .536 .793 r
.69475 .41041 .7009 .42516 .71346 .42582 .7073 .41111 Mtetra
.533 .529 .796 r
.7073 .41111 .71346 .42582 .72608 .42621 .71999 .41247 Mtetra
.53 .541 .811 r
.71999 .41247 .72608 .42621 .7387 .42511 .73277 .41376 Mtetra
.56 .597 .847 r
.73277 .41376 .7387 .42511 .75118 .42093 .74555 .41356 Mtetra
.654 .737 .91 r
.74555 .41356 .75118 .42093 .76339 .41238 .75816 .40985 Mtetra
.798 .941 .921 r
.75816 .40985 .76339 .41238 .77531 .39987 .77044 .40106 Mtetra
.832 .997 .772 r
.77044 .40106 .77531 .39987 .78735 .38891 .78237 .38775 Mtetra
.82 .982 .885 r
.78237 .38775 .78735 .38891 .79998 .3849 .79454 .37745 Mtetra
.664 .741 .907 r
.79454 .37745 .79998 .3849 .81267 .38087 .80727 .37339 Mtetra
.80727 .37339 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85116 .36947 .8458 .3611 Mtetra
.631 .704 .899 r
.8458 .3611 .85116 .36947 .86412 .36576 .85888 .35808 Mtetra
.666 .74 .905 r
.85888 .35808 .86412 .36576 .87705 .36116 .87189 .35384 Mtetra
.68 .757 .91 r
.87189 .35384 .87705 .36116 .89003 .35659 .8849 .34914 Mtetra
.674 .752 .909 r
.8849 .34914 .89003 .35659 .9031 .35225 .898 .34462 Mtetra
.666 .744 .909 r
.898 .34462 .9031 .35225 .91624 .34803 .91118 .34032 Mtetra
.659 .742 .911 r
.3208 .5202 .32759 .52646 .33834 .52311 .33156 .51689 Mtetra
.647 .741 .918 r
.33156 .51689 .33834 .52311 .34911 .51999 .34236 .51387 Mtetra
.648 .746 .92 r
.34236 .51387 .34911 .51999 .35993 .51705 .35321 .51081 Mtetra
.69 .752 .9 r
.35321 .51081 .35993 .51705 .37081 .51366 .36416 .50651 Mtetra
.675 .723 .886 r
.36416 .50651 .37081 .51366 .38179 .5091 .37513 .50263 Mtetra
.664 .741 .907 r
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.39718 .49556 .40378 .50209 .41484 .49856 .40827 .49201 Mtetra
.477 .673 .95 r
.40827 .49201 .41484 .49856 .42595 .49502 .41928 .4924 Mtetra
.478 0 0 r
.41928 .4924 .42595 .49502 .43694 .49755 .43019 .49891 Mtetra
.354 0 0 r
.43019 .49891 .43694 .49755 .44795 .50303 .44132 .50094 Mtetra
.603 .889 .99 r
.44132 .50094 .44795 .50303 .45915 .50414 .45267 .49726 Mtetra
.762 .757 .848 r
.45267 .49726 .45915 .50414 .47052 .5003 .46413 .48952 Mtetra
.752 .679 .78 r
.46413 .48952 .47052 .5003 .48197 .49303 .47564 .48006 Mtetra
.735 .644 .758 r
.47564 .48006 .48197 .49303 .49346 .48427 .48716 .47061 Mtetra
.707 .624 .762 r
.48716 .47061 .49346 .48427 .50497 .47544 .49867 .46303 Mtetra
.649 .614 .801 r
.49867 .46303 .50497 .47544 .51648 .46724 .51018 .45934 Mtetra
.663 .709 .882 r
.51018 .45934 .51648 .46724 .52801 .46246 .52175 .45563 Mtetra
.664 .741 .907 r
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69475 .41041 .6889 .40204 Mtetra
.663 .709 .882 r
.6889 .40204 .69475 .41041 .7073 .41111 .70123 .39809 Mtetra
.559 .568 .819 r
.70123 .39809 .7073 .41111 .71999 .41247 .71384 .3981 Mtetra
.515 .524 .804 r
.71384 .3981 .71999 .41247 .73277 .41376 .72667 .40004 Mtetra
.51 .531 .814 r
.72667 .40004 .73277 .41376 .74555 .41356 .7396 .40199 Mtetra
.547 .588 .847 r
.7396 .40199 .74555 .41356 .75816 .40985 .75251 .40221 Mtetra
.66 .734 .904 r
.75251 .40221 .75816 .40985 .77044 .40106 .7652 .39828 Mtetra
.824 .935 .902 r
.7652 .39828 .77044 .40106 .78237 .38775 .77748 .38847 Mtetra
.872 .994 .774 r
.77748 .38847 .78237 .38775 .79454 .37745 .7894 .37402 Mtetra
.783 .915 .928 r
.7894 .37402 .79454 .37745 .80727 .37339 .80183 .36584 Mtetra
.664 .741 .907 r
.80183 .36584 .80727 .37339 .82006 .36931 .81465 .36173 Mtetra
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.652 .736 .911 r
.84048 .35345 .8458 .3611 .85888 .35808 .85352 .34967 Mtetra
.64 .71 .898 r
.85352 .34967 .85888 .35808 .87189 .35384 .86667 .34632 Mtetra
.677 .752 .908 r
.86667 .34632 .87189 .35384 .8849 .34914 .87974 .34168 Mtetra
.678 .755 .909 r
.87974 .34168 .8849 .34914 .898 .34462 .89286 .33698 Mtetra
.668 .747 .909 r
.89286 .33698 .898 .34462 .91118 .34032 .90608 .33259 Mtetra
.656 .743 .914 r
.31395 .51395 .3208 .5202 .33156 .51689 .32474 .51068 Mtetra
.645 .742 .92 r
.32474 .51068 .33156 .51689 .34236 .51387 .33556 .5077 Mtetra
.664 .749 .914 r
.33556 .5077 .34236 .51387 .35321 .51081 .34645 .50419 Mtetra
.695 .744 .889 r
.34645 .50419 .35321 .51081 .36416 .50651 .35745 .49965 Mtetra
.664 .73 .899 r
.35745 .49965 .36416 .50651 .37513 .50263 .36843 .49611 Mtetra
.664 .741 .907 r
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.37946 .49256 .38613 .4991 .39718 .49556 .39053 .48899 Mtetra
.645 .736 .915 r
.39053 .48899 .39718 .49556 .40827 .49201 .40163 .48594 Mtetra
0 .23 .708 r
.40163 .48594 .40827 .49201 .41928 .4924 .41242 .49341 Mtetra
.472 0 0 r
.41242 .49341 .41928 .4924 .43019 .49891 .42345 .49717 Mtetra
.499 .864 .986 r
.42345 .49717 .43019 .49891 .44132 .50094 .43474 .49455 Mtetra
.765 .771 .858 r
.43474 .49455 .44132 .50094 .45267 .49726 .44621 .4869 Mtetra
.762 .688 .781 r
.44621 .4869 .45267 .49726 .46413 .48952 .45775 .47698 Mtetra
.745 .653 .759 r
.45775 .47698 .46413 .48952 .47564 .48006 .46929 .46693 Mtetra
.702 .629 .771 r
.46929 .46693 .47564 .48006 .48716 .47061 .48079 .4599 Mtetra
.655 .645 .828 r
.48079 .4599 .48716 .47061 .49867 .46303 .49229 .4562 Mtetra
.664 .741 .907 r
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71384 .3981 .70785 .38675 Mtetra
.569 .603 .847 r
.70785 .38675 .71384 .3981 .72667 .40004 .72053 .38613 Mtetra
.495 .521 .813 r
.72053 .38613 .72667 .40004 .7396 .40199 .7335 .38862 Mtetra
.494 .529 .822 r
.7335 .38862 .7396 .40199 .75251 .40221 .74657 .391 Mtetra
.547 .597 .855 r
.74657 .391 .75251 .40221 .7652 .39828 .75958 .39107 Mtetra
.692 .762 .905 r
.75958 .39107 .7652 .39828 .77748 .38847 .77228 .38599 Mtetra
.862 .944 .87 r
.77228 .38599 .77748 .38847 .7894 .37402 .7845 .37432 Mtetra
.9 .986 .769 r
.7845 .37432 .7894 .37402 .80183 .36584 .79639 .35879 Mtetra
.68 .764 .914 r
.79639 .35879 .80183 .36584 .81465 .36173 .80921 .35409 Mtetra
.664 .741 .907 r
.80921 .35409 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85352 .34967 .84815 .34154 Mtetra
.632 .716 .907 r
.84815 .34154 .85352 .34967 .86667 .34632 .86137 .33838 Mtetra
.664 .736 .904 r
.86137 .33838 .86667 .34632 .87974 .34168 .87453 .33415 Mtetra
.68 .756 .909 r
.87453 .33415 .87974 .34168 .89286 .33698 .88769 .32935 Mtetra
.67 .75 .91 r
.88769 .32935 .89286 .33698 .90608 .33259 .90094 .32485 Mtetra
.655 .745 .916 r
.30704 .50772 .31395 .51395 .32474 .51068 .31785 .50447 Mtetra
.648 .745 .92 r
.31785 .50447 .32474 .51068 .33556 .5077 .32871 .50137 Mtetra
.69 .752 .899 r
.32871 .50137 .33556 .5077 .34645 .50419 .33968 .49703 Mtetra
.675 .725 .887 r
.33968 .49703 .34645 .50419 .35745 .49965 .35066 .4931 Mtetra
.664 .741 .907 r
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48596 Mtetra
.37273 .48596 .37946 .49256 .39053 .48899 .38383 .48236 Mtetra
.182 .52 .918 r
.38383 .48236 .39053 .48899 .40163 .48594 .39468 .48625 Mtetra
.587 .027 0 r
.39468 .48625 .40163 .48594 .41242 .49341 .40555 .49229 Mtetra
.194 .712 .878 r
.40555 .49229 .41242 .49341 .42345 .49717 .41675 .49182 Mtetra
.754 .801 .891 r
.41675 .49182 .42345 .49717 .43474 .49455 .4282 .48508 Mtetra
.772 .706 .79 r
.4282 .48508 .43474 .49455 .44621 .4869 .43976 .47501 Mtetra
.757 .666 .762 r
.43976 .47501 .44621 .4869 .45775 .47698 .45133 .46439 Mtetra
.714 .641 .774 r
.45133 .46439 .45775 .47698 .46929 .46693 .46285 .45677 Mtetra
.656 .656 .838 r
.46285 .45677 .46929 .46693 .48079 .4599 .47433 .45305 Mtetra
.664 .741 .907 r
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72053 .38613 .71455 .37526 Mtetra
.549 .604 .861 r
.71455 .37526 .72053 .38613 .7335 .38862 .72737 .37519 Mtetra
.473 .517 .823 r
.72737 .37519 .7335 .38862 .74657 .391 .74049 .37822 Mtetra
.484 .535 .834 r
.74049 .37822 .74657 .391 .75958 .39107 .75369 .3807 Mtetra
.571 .629 .87 r
.75369 .3807 .75958 .39107 .77228 .38599 .76674 .37979 Mtetra
.755 .814 .899 r
.76674 .37979 .77228 .38599 .7845 .37432 .77936 .37242 Mtetra
.899 .953 .827 r
.77936 .37242 .7845 .37432 .79639 .35879 .79145 .35831 Mtetra
.839 .995 .844 r
.79145 .35831 .79639 .35879 .80921 .35409 .80371 .34639 Mtetra
.664 .741 .907 r
.80371 .34639 .80921 .35409 .82213 .34993 .81668 .34219 Mtetra
.81668 .34219 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.652 .736 .911 r
.84278 .33374 .84815 .34154 .86137 .33838 .85597 .32988 Mtetra
.639 .711 .899 r
.85597 .32988 .86137 .33838 .87453 .33415 .86926 .32644 Mtetra
.677 .751 .907 r
.86926 .32644 .87453 .33415 .88769 .32935 .88248 .3217 Mtetra
.672 .752 .911 r
.88248 .3217 .88769 .32935 .90094 .32485 .89577 .31712 Mtetra
.655 .747 .918 r
.30007 .5015 .30704 .50772 .31785 .50447 .31092 .49822 Mtetra
.66 .748 .915 r
.31092 .49822 .31785 .50447 .32871 .50137 .32182 .49478 Mtetra
.698 .747 .889 r
.32182 .49478 .32871 .50137 .33968 .49703 .33283 .49009 Mtetra
.664 .73 .899 r
.33283 .49009 .33968 .49703 .35066 .4931 .34383 .48651 Mtetra
.664 .741 .907 r
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.35486 .48292 .36167 .48954 .37273 .48596 .36595 .47931 Mtetra
.59 .718 .933 r
.36595 .47931 .37273 .48596 .38383 .48236 .37699 .47757 Mtetra
.448 0 0 r
.37699 .47757 .38383 .48236 .39468 .48625 .3877 .48554 Mtetra
.277 0 0 r
.3877 .48554 .39468 .48625 .40555 .49229 .39872 .48834 Mtetra
.692 .842 .955 r
.39872 .48834 .40555 .49229 .41675 .49182 .41009 .48368 Mtetra
.778 .732 .811 r
.41009 .48368 .41675 .49182 .4282 .48508 .42166 .4741 Mtetra
.77 .683 .767 r
.42166 .4741 .4282 .48508 .43976 .47501 .43328 .463 Mtetra
.742 .66 .769 r
.43328 .463 .43976 .47501 .45133 .46439 .44485 .45363 Mtetra
.654 .645 .828 r
.44485 .45363 .45133 .46439 .46285 .45677 .45631 .4499 Mtetra
.664 .741 .907 r
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72737 .37519 .72134 .36363 Mtetra
.495 .564 .855 r
.72134 .36363 .72737 .37519 .74049 .37822 .73438 .3653 Mtetra
.451 .515 .833 r
.73438 .3653 .74049 .37822 .75369 .3807 .74766 .36877 Mtetra
.491 .556 .85 r
.74766 .36877 .75369 .3807 .76674 .37979 .76094 .3707 Mtetra
.632 .69 .886 r
.76094 .3707 .76674 .37979 .77936 .37242 .77394 .36758 Mtetra
.835 .873 .871 r
.77394 .36758 .77936 .37242 .79145 .35831 .78637 .35676 Mtetra
.924 .952 .79 r
.78637 .35676 .79145 .35831 .80371 .34639 .79834 .34057 Mtetra
.723 .823 .927 r
.79834 .34057 .80371 .34639 .81668 .34219 .81118 .33439 Mtetra
.664 .741 .907 r
.81118 .33439 .81668 .34219 .8297 .33797 .82424 .33014 Mtetra
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85597 .32988 .85055 .32157 Mtetra
.629 .714 .908 r
.85055 .32157 .85597 .32988 .86926 .32644 .86393 .31844 Mtetra
.667 .741 .905 r
.86393 .31844 .86926 .32644 .88248 .3217 .87722 .314 Mtetra
.672 .752 .911 r
.87722 .314 .88248 .3217 .89577 .31712 .89056 .30938 Mtetra
.657 .749 .917 r
.29305 .49527 .30007 .5015 .31092 .49822 .30393 .49189 Mtetra
.679 .751 .906 r
.30393 .49189 .31092 .49822 .32182 .49478 .31489 .48787 Mtetra
.688 .737 .888 r
.31489 .48787 .32182 .49478 .33283 .49009 .32592 .48347 Mtetra
.664 .741 .907 r
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
.348 .47624 .35486 .48292 .36595 .47931 .35912 .47261 Mtetra
.179 .518 .917 r
.35912 .47261 .36595 .47931 .37699 .47757 .36992 .47646 Mtetra
.566 0 0 r
.36992 .47646 .37699 .47757 .3877 .48554 .38071 .48291 Mtetra
.398 .792 .988 r
.38071 .48291 .3877 .48554 .39872 .48834 .39192 .48189 Mtetra
.769 .772 .855 r
.39192 .48189 .39872 .48834 .41009 .48368 .40344 .47393 Mtetra
.781 .705 .779 r
.40344 .47393 .41009 .48368 .42166 .4741 .4151 .46278 Mtetra
.768 .678 .764 r
.4151 .46278 .42166 .4741 .43328 .463 .42675 .45157 Mtetra
.675 .643 .81 r
.42675 .45157 .43328 .463 .44485 .45363 .43822 .44673 Mtetra
.664 .741 .907 r
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.627 .727 .918 r
.71551 .35601 .72134 .36363 .73438 .3653 .72829 .35298 Mtetra
.439 .52 .844 r
.72829 .35298 .73438 .3653 .74766 .36877 .74157 .35648 Mtetra
.44 .522 .846 r
.74157 .35648 .74766 .36877 .76094 .3707 .75498 .35995 Mtetra
.534 .606 .871 r
.75498 .35995 .76094 .3707 .77394 .36758 .76826 .36017 Mtetra
.736 .777 .886 r
.76826 .36017 .77394 .36758 .78637 .35676 .78106 .35323 Mtetra
.9 .91 .821 r
.78106 .35323 .78637 .35676 .79834 .34057 .79324 .33855 Mtetra
.862 .965 .865 r
.79324 .33855 .79834 .34057 .81118 .33439 .80563 .32652 Mtetra
.664 .741 .907 r
.80563 .32652 .81118 .33439 .82424 .33014 .81874 .32223 Mtetra
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.638 .73 .915 r
.84514 .3136 .85055 .32157 .86393 .31844 .85852 .3101 Mtetra
.65 .726 .904 r
.85852 .3101 .86393 .31844 .87722 .314 .87192 .3062 Mtetra
.669 .75 .911 r
.87192 .3062 .87722 .314 .89056 .30938 .88531 .30163 Mtetra
.664 .751 .915 r
.28597 .48902 .29305 .49527 .30393 .49189 .29689 .48543 Mtetra
.7 .753 .893 r
.29689 .48543 .30393 .49189 .31489 .48787 .30793 .48066 Mtetra
.671 .726 .891 r
.30793 .48066 .31489 .48787 .32592 .48347 .31895 .4768 Mtetra
.664 .741 .907 r
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.33 .47317 .33694 .47986 .348 .47624 .34109 .46952 Mtetra
.34109 .46952 .348 .47624 .35912 .47261 .35223 .46586 Mtetra
0 .146 .643 r
.35223 .46586 .35912 .47261 .36992 .47646 .36282 .47443 Mtetra
.28 0 0 r
.36282 .47443 .36992 .47646 .38071 .48291 .37375 .47828 Mtetra
.688 .819 .946 r
.37375 .47828 .38071 .48291 .39192 .48189 .38513 .47378 Mtetra
.786 .736 .806 r
.38513 .47378 .39192 .48189 .40344 .47393 .39678 .46359 Mtetra
.782 .697 .769 r
.39678 .46359 .40344 .47393 .4151 .46278 .40848 .45182 Mtetra
.735 .674 .79 r
.40848 .45182 .4151 .46278 .42675 .45157 .42007 .44355 Mtetra
.663 .71 .883 r
.42007 .44355 .42675 .45157 .43822 .44673 .43155 .43977 Mtetra
.664 .741 .907 r
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72829 .35298 .72238 .34413 Mtetra
.505 .637 .913 r
.72238 .34413 .72829 .35298 .74157 .35648 .73549 .34455 Mtetra
.411 .513 .852 r
.73549 .34455 .74157 .35648 .75498 .35995 .74895 .34859 Mtetra
.461 .555 .864 r
.74895 .34859 .75498 .35995 .76826 .36017 .76241 .35103 Mtetra
.638 .696 .887 r
.76241 .35103 .76826 .36017 .78106 .35323 .77554 .34762 Mtetra
.847 .854 .848 r
.77554 .34762 .78106 .35323 .79324 .33855 .78801 .33557 Mtetra
.927 .917 .786 r
.78801 .33557 .79324 .33855 .80563 .32652 .80004 .31859 Mtetra
.664 .741 .907 r
.80004 .31859 .80563 .32652 .81874 .32223 .81319 .31427 Mtetra
.81319 .31427 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.657 .738 .91 r
.83968 .30556 .84514 .3136 .85852 .3101 .85303 .30142 Mtetra
.628 .708 .904 r
.85303 .30142 .85852 .3101 .87192 .3062 .86656 .29824 Mtetra
.664 .746 .911 r
.86656 .29824 .87192 .3062 .88531 .30163 .88002 .29382 Mtetra
.671 .751 .911 r
.27884 .48267 .28597 .48902 .29689 .48543 .2898 .47883 Mtetra
.708 .752 .887 r
.2898 .47883 .29689 .48543 .30793 .48066 .30089 .47373 Mtetra
.664 .734 .902 r
.30089 .47373 .30793 .48066 .31895 .4768 .31192 .47008 Mtetra
.664 .741 .907 r
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.323 .46642 .33 .47317 .34109 .46952 .33412 .46274 Mtetra
.474 .674 .951 r
.33412 .46274 .34109 .46952 .35223 .46586 .34508 .46303 Mtetra
.596 .026 0 r
.34508 .46303 .35223 .46586 .36282 .47443 .3557 .47111 Mtetra
.222 .674 .95 r
.3557 .47111 .36282 .47443 .37375 .47828 .36679 .47208 Mtetra
.758 .779 .87 r
.36679 .47208 .37375 .47828 .38513 .47378 .37833 .46481 Mtetra
.792 .721 .785 r
.37833 .46481 .38513 .47378 .39678 .46359 .39007 .45331 Mtetra
.784 .699 .77 r
.39007 .45331 .39678 .46359 .40848 .45182 .40181 .44146 Mtetra
.681 .665 .828 r
.40181 .44146 .40848 .45182 .42007 .44355 .41331 .43657 Mtetra
.664 .741 .907 r
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.628 .726 .918 r
.7165 .33635 .72238 .34413 .73549 .34455 .72941 .33323 Mtetra
.396 .519 .864 r
.72941 .33323 .73549 .34455 .74895 .34859 .74288 .33728 Mtetra
.41 .528 .866 r
.74288 .33728 .74895 .34859 .76241 .35103 .75646 .34099 Mtetra
.553 .635 .887 r
.75646 .34099 .76241 .35103 .77554 .34762 .76984 .34037 Mtetra
.783 .8 .866 r
.76984 .34037 .77554 .34762 .78801 .33557 .7826 .33123 Mtetra
.912 .886 .793 r
.7826 .33123 .78801 .33557 .80004 .31859 .79476 .31472 Mtetra
.783 .912 .928 r
.79476 .31472 .80004 .31859 .81319 .31427 .8076 .30623 Mtetra
.664 .741 .907 r
.8076 .30623 .81319 .31427 .8264 .30992 .82085 .30185 Mtetra
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85303 .30142 .84754 .29303 Mtetra
.617 .713 .914 r
.84754 .29303 .85303 .30142 .86656 .29824 .86115 .29013 Mtetra
.657 .74 .911 r
.86115 .29013 .86656 .29824 .88002 .29382 .87468 .28589 Mtetra
.681 .752 .905 r
.27166 .47623 .27884 .48267 .2898 .47883 .28267 .47207 Mtetra
.706 .749 .885 r
.28267 .47207 .2898 .47883 .30089 .47373 .29379 .46698 Mtetra
.664 .741 .907 r
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
.31595 .45962 .323 .46642 .33412 .46274 .3271 .45591 Mtetra
.175 .517 .917 r
.3271 .45591 .33412 .46274 .34508 .46303 .33787 .45971 Mtetra
.477 0 0 r
.33787 .45971 .34508 .46303 .3557 .47111 .34858 .46652 Mtetra
.541 .783 .988 r
.34858 .46652 .3557 .47111 .36679 .47208 .35983 .46485 Mtetra
.782 .756 .83 r
.35983 .46485 .36679 .47208 .37833 .46481 .3715 .45561 Mtetra
.797 .719 .778 r
.3715 .45561 .37833 .46481 .39007 .45331 .3833 .44342 Mtetra
.768 .702 .789 r
.3833 .44342 .39007 .45331 .40181 .44146 .39501 .43335 Mtetra
.662 .71 .883 r
.39501 .43335 .40181 .44146 .41331 .43657 .4065 .42953 Mtetra
.664 .741 .907 r
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72941 .33323 .72344 .32422 Mtetra
.426 .594 .914 r
.72344 .32422 .72941 .33323 .74288 .33728 .73681 .32636 Mtetra
.371 .516 .872 r
.73681 .32636 .74288 .33728 .75646 .34099 .75046 .33071 Mtetra
.483 .595 .889 r
.75046 .33071 .75646 .34099 .76984 .34037 .76401 .33205 Mtetra
.718 .753 .88 r
.76401 .33205 .76984 .34037 .7826 .33123 .77704 .32557 Mtetra
.887 .855 .805 r
.77704 .32557 .7826 .33123 .79476 .31472 .78938 .31031 Mtetra
.86 .898 .861 r
.78938 .31031 .79476 .31472 .8076 .30623 .80196 .29813 Mtetra
.664 .741 .907 r
.80196 .29813 .8076 .30623 .82085 .30185 .81525 .29371 Mtetra
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.617 .72 .919 r
.84203 .28481 .84754 .29303 .86115 .29013 .85567 .28182 Mtetra
.648 .733 .911 r
.85567 .28182 .86115 .29013 .87468 .28589 .86928 .27786 Mtetra
.689 .751 .899 r
.26443 .46966 .27166 .47623 .28267 .47207 .27549 .46521 Mtetra
.703 .747 .886 r
.27549 .46521 .28267 .47207 .29379 .46698 .28663 .46019 Mtetra
.664 .741 .907 r
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.29771 .45649 .30485 .46331 .31595 .45962 .30885 .45277 Mtetra
.30885 .45277 .31595 .45962 .3271 .45591 .32003 .44903 Mtetra
0 .309 .783 r
.32003 .44903 .3271 .45591 .33787 .45971 .33064 .45559 Mtetra
0 .296 .69 r
.33064 .45559 .33787 .45971 .34858 .46652 .34144 .46092 Mtetra
.662 .783 .939 r
.34144 .46092 .34858 .46652 .35983 .46485 .35284 .45711 Mtetra
.794 .747 .809 r
.35284 .45711 .35983 .46485 .3715 .45561 .36461 .44654 Mtetra
.802 .723 .778 r
.36461 .44654 .3715 .45561 .3833 .44342 .37646 .43407 Mtetra
.741 .706 .818 r
.37646 .43407 .3833 .44342 .39501 .43335 .38811 .42629 Mtetra
.664 .741 .907 r
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.514 .674 .937 r
.7175 .31626 .72344 .32422 .73681 .32636 .73074 .31598 Mtetra
.344 .514 .881 r
.73074 .31598 .73681 .32636 .75046 .33071 .74442 .32055 Mtetra
.425 .568 .893 r
.74442 .32055 .75046 .33071 .76401 .33205 .75809 .32319 Mtetra
.661 .719 .892 r
.75809 .32319 .76401 .33205 .77704 .32557 .77134 .31886 Mtetra
.859 .829 .817 r
.77134 .31886 .77704 .32557 .78938 .31031 .78387 .30506 Mtetra
.89 .87 .811 r
.78387 .30506 .78938 .31031 .80196 .29813 .79627 .28995 Mtetra
.664 .741 .907 r
.79627 .28995 .80196 .29813 .81525 .29371 .80961 .2855 Mtetra
.80961 .2855 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.621 .722 .919 r
.83647 .27652 .84203 .28481 .85567 .28182 .85015 .2734 Mtetra
.64 .727 .912 r
.85015 .2734 .85567 .28182 .86928 .27786 .86383 .26967 Mtetra
.696 .751 .894 r
.25714 .46298 .26443 .46966 .27549 .46521 .26825 .45825 Mtetra
.699 .745 .887 r
.26825 .45825 .27549 .46521 .28663 .46019 .27941 .45334 Mtetra
.664 .741 .907 r
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.29052 .44961 .29771 .45649 .30885 .45277 .30169 .44586 Mtetra
.30169 .44586 .30885 .45277 .32003 .44903 .31289 .4421 Mtetra
0 .14 .637 r
.31289 .4421 .32003 .44903 .33064 .45559 .32339 .45061 Mtetra
0 .465 .858 r
.32339 .45061 .33064 .45559 .34144 .46092 .33429 .45461 Mtetra
.712 .773 .9 r
.33429 .45461 .34144 .46092 .35284 .45711 .34579 .44923 Mtetra
.802 .746 .8 r
.34579 .44923 .35284 .45711 .36461 .44654 .35765 .43784 Mtetra
.807 .731 .781 r
.35765 .43784 .36461 .44654 .37646 .43407 .36955 .42527 Mtetra
.714 .711 .846 r
.36955 .42527 .37646 .43407 .38811 .42629 .38116 .41917 Mtetra
.664 .741 .907 r
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.587 .709 .927 r
.71151 .30825 .7175 .31626 .73074 .31598 .72467 .30616 Mtetra
.322 .517 .891 r
.72467 .30616 .73074 .31598 .74442 .32055 .73837 .31076 Mtetra
.379 .553 .899 r
.73837 .31076 .74442 .32055 .75809 .32319 .75213 .31418 Mtetra
.613 .697 .903 r
.75213 .31418 .75809 .32319 .77134 .31886 .76554 .3114 Mtetra
.834 .81 .827 r
.76554 .3114 .77134 .31886 .78387 .30506 .77824 .29891 Mtetra
.9 .845 .78 r
.77824 .29891 .78387 .30506 .79627 .28995 .79053 .28171 Mtetra
.664 .741 .907 r
.79053 .28171 .79627 .28995 .80961 .2855 .80391 .27722 Mtetra
.80391 .27722 .80961 .2855 .82301 .28102 .81736 .2727 Mtetra
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.625 .724 .918 r
.83087 .26816 .83647 .27652 .85015 .2734 .84457 .26486 Mtetra
.631 .723 .913 r
.84457 .26486 .85015 .2734 .86383 .26967 .85833 .26136 Mtetra
.7 .75 .891 r
.2498 .45619 .25714 .46298 .26825 .45825 .26096 .45127 Mtetra
.696 .745 .889 r
.26096 .45127 .26825 .45825 .27941 .45334 .27214 .44644 Mtetra
.664 .741 .907 r
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.28328 .44268 .29052 .44961 .30169 .44586 .29447 .4389 Mtetra
.643 .735 .916 r
.29447 .4389 .30169 .44586 .31289 .4421 .30567 .4357 Mtetra
0 .057 .537 r
.30567 .4357 .31289 .4421 .32339 .45061 .31613 .44486 Mtetra
.166 .558 .931 r
.31613 .44486 .32339 .45061 .33429 .45461 .32709 .44787 Mtetra
.734 .766 .878 r
.32709 .44787 .33429 .45461 .34579 .44923 .33869 .44148 Mtetra
.809 .75 .797 r
.33869 .44148 .34579 .44923 .35765 .43784 .35061 .42959 Mtetra
.811 .741 .786 r
.35061 .42959 .35765 .43784 .36955 .42527 .36256 .41701 Mtetra
.692 .719 .87 r
.36256 .41701 .36955 .42527 .38116 .41917 .37415 .412 Mtetra
.664 .741 .907 r
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.628 .726 .918 r
.70546 .30016 .71151 .30825 .72467 .30616 .71859 .29689 Mtetra
.302 .522 .901 r
.71859 .29689 .72467 .30616 .73837 .31076 .73231 .30143 Mtetra
.341 .545 .906 r
.73231 .30143 .73837 .31076 .75213 .31418 .74613 .30528 Mtetra
.578 .685 .914 r
.74613 .30528 .75213 .31418 .76554 .3114 .75965 .30348 Mtetra
.816 .797 .835 r
.75965 .30348 .76554 .3114 .77824 .29891 .77249 .29195 Mtetra
.897 .826 .769 r
.77249 .29195 .77824 .29891 .79053 .28171 .78479 .27401 Mtetra
.682 .766 .914 r
.78479 .27401 .79053 .28171 .80391 .27722 .79817 .26886 Mtetra
.664 .741 .907 r
.79817 .26886 .80391 .27722 .81736 .2727 .81166 .26431 Mtetra
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.629 .726 .917 r
.82521 .25973 .83087 .26816 .84457 .26486 .83894 .25627 Mtetra
.626 .721 .915 r
.83894 .25627 .84457 .26486 .85833 .26136 .85277 .2529 Mtetra
.703 .75 .889 r
.24241 .44932 .2498 .45619 .26096 .45127 .2536 .44427 Mtetra
.695 .746 .891 r
.2536 .44427 .26096 .45127 .27214 .44644 .26481 .43948 Mtetra
.664 .741 .907 r
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.27598 .43569 .28328 .44268 .29447 .4389 .2872 .43188 Mtetra
.617 .728 .925 r
.2872 .43188 .29447 .4389 .30567 .4357 .29837 .42932 Mtetra
0 .06 .538 r
.29837 .42932 .30567 .4357 .31613 .44486 .30884 .4384 Mtetra
.264 .591 .948 r
.30884 .4384 .31613 .44486 .32709 .44787 .31985 .44089 Mtetra
.743 .762 .868 r
.31985 .44089 .32709 .44787 .33869 .44148 .33151 .43398 Mtetra
.814 .757 .799 r
.33151 .43398 .33869 .44148 .35061 .42959 .3435 .42186 Mtetra
.817 .753 .792 r
.3435 .42186 .35061 .42959 .36256 .41701 .3555 .40926 Mtetra
.68 .73 .888 r
.3555 .40926 .36256 .41701 .37415 .412 .36709 .40477 Mtetra
.664 .741 .907 r
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.646 .734 .913 r
.69937 .292 .70546 .30016 .71859 .29689 .7125 .28813 Mtetra
.281 .526 .909 r
.7125 .28813 .71859 .29689 .73231 .30143 .72625 .29262 Mtetra
.31 .543 .914 r
.72625 .29262 .73231 .30143 .74613 .30528 .7401 .29664 Mtetra
.557 .685 .924 r
.7401 .29664 .74613 .30528 .75965 .30348 .7537 .2953 Mtetra
.806 .79 .838 r
.7537 .2953 .75965 .30348 .77249 .29195 .76663 .28424 Mtetra
.889 .811 .766 r
.76663 .28424 .77249 .29195 .78479 .27401 .77901 .26632 Mtetra
.702 .775 .909 r
.77901 .26632 .78479 .27401 .79817 .26886 .79237 .26044 Mtetra
.664 .741 .907 r
.79237 .26044 .79817 .26886 .81166 .26431 .80591 .25585 Mtetra
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.632 .727 .916 r
.81951 .25123 .82521 .25973 .83894 .25627 .83328 .24765 Mtetra
.623 .721 .917 r
.83328 .24765 .83894 .25627 .85277 .2529 .84715 .24435 Mtetra
.703 .749 .888 r
.23496 .44238 .24241 .44932 .2536 .44427 .24618 .43729 Mtetra
.695 .748 .892 r
.24618 .43729 .2536 .44427 .26481 .43948 .25742 .43247 Mtetra
.664 .741 .907 r
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.26862 .42865 .27598 .43569 .2872 .43188 .27987 .42481 Mtetra
.617 .728 .925 r
.27987 .42481 .2872 .43188 .29837 .42932 .29107 .42222 Mtetra
0 .092 .59 r
.29107 .42222 .29837 .42932 .30884 .4384 .30153 .4313 Mtetra
.296 .588 .944 r
.30153 .4313 .30884 .4384 .31985 .44089 .31256 .43377 Mtetra
.743 .76 .867 r
.31256 .43377 .31985 .44089 .33151 .43398 .32426 .42682 Mtetra
.818 .765 .803 r
.32426 .42682 .33151 .43398 .3435 .42186 .33629 .41465 Mtetra
.823 .765 .798 r
.33629 .41465 .3435 .42186 .3555 .40926 .34834 .402 Mtetra
.681 .746 .9 r
.34834 .402 .3555 .40926 .36709 .40477 .35996 .39748 Mtetra
.664 .741 .907 r
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.646 .734 .913 r
.69322 .28378 .69937 .292 .7125 .28813 .7064 .27987 Mtetra
.257 .529 .916 r
.7064 .27987 .7125 .28813 .72625 .29262 .72017 .28433 Mtetra
.287 .547 .922 r
.72017 .28433 .72625 .29262 .7401 .29664 .73405 .28833 Mtetra
.553 .694 .933 r
.73405 .28833 .7401 .29664 .7537 .2953 .74769 .28696 Mtetra
.805 .788 .837 r
.74769 .28696 .7537 .2953 .76663 .28424 .76067 .27585 Mtetra
.882 .798 .762 r
.76067 .27585 .76663 .28424 .77901 .26632 .77312 .25786 Mtetra
.7 .755 .895 r
.77312 .25786 .77901 .26632 .79237 .26044 .78653 .25194 Mtetra
.664 .741 .907 r
.78653 .25194 .79237 .26044 .80591 .25585 .80011 .24731 Mtetra
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.632 .727 .916 r
.81375 .24265 .81951 .25123 .83328 .24765 .82757 .23904 Mtetra
.622 .723 .918 r
.82757 .23904 .83328 .24765 .84715 .24435 .84149 .23569 Mtetra
.7 .748 .889 r
.22745 .43535 .23496 .44238 .24618 .43729 .2387 .43033 Mtetra
.697 .75 .893 r
.2387 .43033 .24618 .43729 .25742 .43247 .24997 .4254 Mtetra
.664 .741 .907 r
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.2612 .42155 .26862 .42865 .27987 .42481 .27248 .41768 Mtetra
.643 .735 .916 r
.27248 .41768 .27987 .42481 .29107 .42222 .28376 .41439 Mtetra
0 .116 .628 r
.28376 .41439 .29107 .42222 .30153 .4313 .2942 .42354 Mtetra
.281 .559 .93 r
.2942 .42354 .30153 .4313 .31256 .43377 .30521 .42649 Mtetra
.732 .756 .872 r
.30521 .42649 .31256 .43377 .32426 .42682 .31692 .41999 Mtetra
.82 .774 .809 r
.31692 .41999 .32426 .42682 .33629 .41465 .32899 .40797 Mtetra
.829 .777 .803 r
.32899 .40797 .33629 .41465 .34834 .402 .3411 .39524 Mtetra
.699 .766 .903 r
.3411 .39524 .34834 .402 .35996 .39748 .35279 .39014 Mtetra
.664 .741 .907 r
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.628 .726 .918 r
.68702 .27548 .69322 .28378 .7064 .27987 .70027 .27211 Mtetra
.228 .529 .92 r
.70027 .27211 .7064 .27987 .72017 .28433 .71407 .27657 Mtetra
.273 .558 .931 r
.71407 .27657 .72017 .28433 .73405 .28833 .72797 .28035 Mtetra
.569 .714 .94 r
.72797 .28035 .73405 .28833 .74769 .28696 .74162 .27845 Mtetra
.812 .787 .83 r
.74162 .27845 .74769 .28696 .76067 .27585 .75462 .26676 Mtetra
.875 .785 .758 r
.75462 .26676 .76067 .27585 .77312 .25786 .76712 .24864 Mtetra
.679 .729 .887 r
.76712 .24864 .77312 .25786 .78653 .25194 .78063 .24337 Mtetra
.664 .741 .907 r
.78063 .24337 .78653 .25194 .80011 .24731 .79426 .2387 Mtetra
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.629 .726 .917 r
.80795 .234 .81375 .24265 .82757 .23904 .82182 .23042 Mtetra
.625 .726 .919 r
.82182 .23042 .82757 .23904 .84149 .23569 .83577 .22694 Mtetra
.695 .747 .891 r
.21989 .42824 .22745 .43535 .2387 .43033 .23115 .42335 Mtetra
.701 .752 .892 r
.23115 .42335 .2387 .43033 .24997 .4254 .24247 .41828 Mtetra
.664 .741 .907 r
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.25372 .4144 .2612 .42155 .27248 .41768 .26503 .4105 Mtetra
.26503 .4105 .27248 .41768 .28376 .41439 .27638 .40658 Mtetra
0 .166 .673 r
.27638 .40658 .28376 .41439 .2942 .42354 .28687 .41506 Mtetra
.228 .507 .907 r
.28687 .41506 .2942 .42354 .30521 .42649 .29782 .41897 Mtetra
.708 .746 .882 r
.29782 .41897 .30521 .42649 .31692 .41999 .30949 .41342 Mtetra
.819 .781 .818 r
.30949 .41342 .31692 .41999 .32899 .40797 .32159 .4018 Mtetra
.836 .79 .808 r
.32159 .4018 .32899 .40797 .3411 .39524 .33376 .389 Mtetra
.732 .788 .897 r
.33376 .389 .3411 .39524 .35279 .39014 .34555 .38273 Mtetra
.664 .741 .907 r
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.587 .709 .927 r
.68077 .26711 .68702 .27548 .70027 .27211 .69412 .26486 Mtetra
.195 .528 .921 r
.69412 .26486 .70027 .27211 .71407 .27657 .70796 .26934 Mtetra
.275 .579 .942 r
.70796 .26934 .71407 .27657 .72797 .28035 .72186 .27263 Mtetra
.605 .74 .94 r
.72186 .27263 .72797 .28035 .74162 .27845 .73548 .26967 Mtetra
.823 .785 .816 r
.73548 .26967 .74162 .27845 .75462 .26676 .74847 .25692 Mtetra
.862 .771 .76 r
.74847 .25692 .75462 .26676 .76712 .24864 .76108 .23942 Mtetra
.663 .724 .895 r
.76108 .23942 .76712 .24864 .78063 .24337 .77468 .23472 Mtetra
.664 .741 .907 r
.77468 .23472 .78063 .24337 .79426 .2387 .78836 .23001 Mtetra
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.625 .724 .918 r
.80209 .22527 .80795 .234 .82182 .23042 .81602 .22177 Mtetra
.631 .73 .919 r
.81602 .22177 .82182 .23042 .83577 .22694 .83 .21807 Mtetra
.688 .743 .894 r
.21227 .42101 .21989 .42824 .23115 .42335 .22354 .41635 Mtetra
.704 .754 .89 r
.22354 .41635 .23115 .42335 .24247 .41828 .2349 .4111 Mtetra
.664 .741 .907 r
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.24619 .40719 .25372 .4144 .26503 .4105 .25752 .40326 Mtetra
.25752 .40326 .26503 .4105 .27638 .40658 .2689 .39931 Mtetra
0 .309 .783 r
.2689 .39931 .27638 .40658 .28687 .41506 .27954 .40578 Mtetra
.148 .437 .873 r
.27954 .40578 .28687 .41506 .29782 .41897 .29039 .41101 Mtetra
.663 .725 .895 r
.29039 .41101 .29782 .41897 .30949 .41342 .302 .40699 Mtetra
.811 .786 .829 r
.302 .40699 .30949 .41342 .32159 .4018 .3141 .39611 Mtetra
.84 .802 .814 r
.3141 .39611 .32159 .4018 .33376 .389 .32632 .38331 Mtetra
.774 .809 .881 r
.32632 .38331 .33376 .389 .34555 .38273 .33825 .37526 Mtetra
.664 .741 .907 r
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.514 .674 .937 r
.67446 .25868 .68077 .26711 .69412 .26486 .68795 .25817 Mtetra
.164 .528 .921 r
.68795 .25817 .69412 .26486 .70796 .26934 .70182 .26257 Mtetra
.303 .615 .956 r
.70182 .26257 .70796 .26934 .72186 .27263 .71571 .26502 Mtetra
.661 .769 .929 r
.71571 .26502 .72186 .27263 .73548 .26967 .72926 .26042 Mtetra
.836 .779 .797 r
.72926 .26042 .73548 .26967 .74847 .25692 .74221 .24624 Mtetra
.835 .752 .772 r
.74221 .24624 .74847 .25692 .76108 .23942 .75503 .23073 Mtetra
.664 .741 .907 r
.75503 .23073 .76108 .23942 .77468 .23472 .76869 .226 Mtetra
.76869 .226 .77468 .23472 .78836 .23001 .7824 .22124 Mtetra
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.621 .722 .919 r
.79619 .21646 .80209 .22527 .81602 .22177 .81017 .21307 Mtetra
.639 .734 .917 r
.81017 .21307 .81602 .22177 .83 .21807 .82417 .20906 Mtetra
.68 .74 .896 r
.2046 .41368 .21227 .42101 .22354 .41635 .21587 .40924 Mtetra
.707 .753 .888 r
.21587 .40924 .22354 .41635 .2349 .4111 .22728 .40386 Mtetra
.664 .741 .907 r
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25752 .40326 .24995 .39596 Mtetra
.24995 .39596 .25752 .40326 .2689 .39931 .26136 .39198 Mtetra
.175 .517 .917 r
.26136 .39198 .2689 .39931 .27954 .40578 .27223 .39562 Mtetra
.06 .357 .829 r
.27223 .39562 .27954 .40578 .29039 .41101 .28296 .40232 Mtetra
.589 .683 .906 r
.28296 .40232 .29039 .41101 .302 .40699 .29444 .40041 Mtetra
.793 .785 .845 r
.29444 .40041 .302 .40699 .3141 .39611 .3065 .3908 Mtetra
.842 .813 .821 r
.3065 .3908 .3141 .39611 .32632 .38331 .31877 .37819 Mtetra
.819 .825 .853 r
.31877 .37819 .32632 .38331 .33825 .37526 .3309 .36773 Mtetra
.664 .741 .907 r
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.395 .612 .937 r
.6681 .25016 .67446 .25868 .68795 .25817 .68174 .25206 Mtetra
.142 .537 .921 r
.68174 .25206 .68795 .25817 .70182 .26257 .69564 .25619 Mtetra
.371 .671 .974 r
.69564 .25619 .70182 .26257 .71571 .26502 .70949 .25726 Mtetra
.724 .788 .903 r
.70949 .25726 .71571 .26502 .72926 .26042 .72295 .25041 Mtetra
.844 .767 .776 r
.72295 .25041 .72926 .26042 .74221 .24624 .73585 .23463 Mtetra
.794 .726 .789 r
.73585 .23463 .74221 .24624 .75503 .23073 .74893 .22198 Mtetra
.664 .741 .907 r
.74893 .22198 .75503 .23073 .76869 .226 .76263 .2172 Mtetra
.76263 .2172 .76869 .226 .7824 .22124 .7764 .2124 Mtetra
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.617 .72 .919 r
.79023 .20758 .79619 .21646 .81017 .21307 .80426 .20425 Mtetra
.648 .737 .914 r
.80426 .20425 .81017 .21307 .82417 .20906 .81829 .19993 Mtetra
.671 .736 .899 r
.19688 .40619 .2046 .41368 .21587 .40924 .20815 .40203 Mtetra
.708 .752 .886 r
.20815 .40203 .21587 .40924 .22728 .40386 .21959 .39657 Mtetra
.664 .741 .907 r
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.24232 .3886 .24995 .39596 .26136 .39198 .25376 .38459 Mtetra
.474 .674 .951 r
.25376 .38459 .26136 .39198 .27223 .39562 .26493 .38462 Mtetra
0 .289 .788 r
.26493 .38462 .27223 .39562 .28296 .40232 .27555 .39259 Mtetra
.476 .608 .903 r
.27555 .39259 .28296 .40232 .29444 .40041 .28685 .39332 Mtetra
.756 .771 .865 r
.28685 .39332 .29444 .40041 .3065 .3908 .29882 .38563 Mtetra
.837 .82 .832 r
.29882 .38563 .3065 .3908 .31877 .37819 .31111 .37363 Mtetra
.848 .835 .834 r
.31111 .37363 .31877 .37819 .3309 .36773 .32341 .36127 Mtetra
.701 .782 .914 r
.32341 .36127 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.664 .741 .907 r
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.628 .726 .918 r
.64838 .24624 .65485 .25478 .6681 .25016 .66173 .24273 Mtetra
.236 .554 .932 r
.66173 .24273 .6681 .25016 .68174 .25206 .67551 .2465 Mtetra
.154 .566 .93 r
.67551 .2465 .68174 .25206 .69564 .25619 .68941 .24994 Mtetra
.485 .739 .983 r
.68941 .24994 .69564 .25619 .70949 .25726 .70319 .24896 Mtetra
.78 .791 .862 r
.70319 .24896 .70949 .25726 .72295 .25041 .71653 .2393 Mtetra
.846 .749 .757 r
.71653 .2393 .72295 .25041 .73585 .23463 .72938 .22213 Mtetra
.734 .691 .809 r
.72938 .22213 .73585 .23463 .74893 .22198 .74278 .21314 Mtetra
.664 .741 .907 r
.74278 .21314 .74893 .22198 .76263 .2172 .75653 .20832 Mtetra
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.616 .72 .92 r
.78421 .19862 .79023 .20758 .80426 .20425 .7983 .19529 Mtetra
.657 .739 .911 r
.7983 .19529 .80426 .20425 .81829 .19993 .81234 .19062 Mtetra
.663 .733 .901 r
.1891 .39862 .19688 .40619 .20815 .40203 .20037 .39465 Mtetra
.699 .747 .889 r
.20037 .39465 .20815 .40203 .21959 .39657 .21182 .38945 Mtetra
.672 .75 .909 r
.21182 .38945 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.664 .741 .907 r
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.23463 .38118 .24232 .3886 .25376 .38459 .2461 .37713 Mtetra
.2461 .37713 .25376 .38459 .26493 .38462 .25762 .37307 Mtetra
0 .265 .772 r
.25762 .37307 .26493 .38462 .27555 .39259 .26819 .38154 Mtetra
.331 .502 .876 r
.26819 .38154 .27555 .39259 .28685 .39332 .27927 .38516 Mtetra
.686 .732 .886 r
.27927 .38516 .28685 .39332 .29882 .38563 .29108 .38024 Mtetra
.82 .818 .848 r
.29108 .38024 .29882 .38563 .31111 .37363 .30333 .36948 Mtetra
.851 .847 .839 r
.30333 .36948 .31111 .37363 .32341 .36127 .3157 .35711 Mtetra
.797 .86 .896 r
.3157 .35711 .32341 .36127 .33528 .35601 .32784 .34832 Mtetra
.664 .741 .907 r
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.485 .66 .939 r
.64187 .23761 .64838 .24624 .66173 .24273 .65541 .23764 Mtetra
.092 .541 .908 r
.65541 .23764 .66173 .24273 .67551 .2465 .66923 .24136 Mtetra
.227 .632 .956 r
.66923 .24136 .67551 .2465 .68941 .24994 .6831 .24345 Mtetra
.626 .795 .964 r
.6831 .24345 .68941 .24994 .70319 .24896 .69677 .23955 Mtetra
.816 .775 .814 r
.69677 .23955 .70319 .24896 .71653 .2393 .70998 .22682 Mtetra
.837 .728 .743 r
.70998 .22682 .71653 .2393 .72938 .22213 .72285 .20907 Mtetra
.652 .646 .831 r
.72285 .20907 .72938 .22213 .74278 .21314 .73657 .20423 Mtetra
.664 .741 .907 r
.73657 .20423 .74278 .21314 .75653 .20832 .75037 .19937 Mtetra
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.657 .738 .91 r
.76422 .19448 .77034 .20348 .78421 .19862 .77817 .18982 Mtetra
.625 .731 .923 r
.77817 .18982 .78421 .19862 .7983 .19529 .79227 .18614 Mtetra
.664 .739 .906 r
.79227 .18614 .7983 .19529 .81234 .19062 .80634 .18118 Mtetra
.657 .73 .903 r
.18126 .39093 .1891 .39862 .20037 .39465 .19254 .38711 Mtetra
.678 .74 .898 r
.19254 .38711 .20037 .39465 .21182 .38945 .20394 .38263 Mtetra
.691 .763 .907 r
.20394 .38263 .21182 .38945 .22321 .3852 .21543 .37776 Mtetra
.664 .741 .907 r
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .2461 .37713 .23838 .36962 Mtetra
.23838 .36962 .2461 .37713 .25762 .37307 .24993 .36553 Mtetra
.179 .518 .917 r
.24993 .36553 .25762 .37307 .26819 .38154 .26089 .36912 Mtetra
.193 .389 .828 r
.26089 .36912 .26819 .38154 .27927 .38516 .27175 .37538 Mtetra
.568 .653 .893 r
.27175 .37538 .27927 .38516 .29108 .38024 .28332 .37397 Mtetra
.778 .798 .87 r
.28332 .37397 .29108 .38024 .30333 .36948 .29547 .36541 Mtetra
.845 .853 .849 r
.29547 .36541 .30333 .36948 .3157 .35711 .30786 .35359 Mtetra
.851 .869 .854 r
.30786 .35359 .3157 .35711 .32784 .34832 .32026 .3417 Mtetra
.701 .782 .914 r
.32026 .3417 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.664 .741 .907 r
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.627 .727 .918 r
.62198 .23364 .62859 .24229 .64187 .23761 .63534 .23007 Mtetra
.273 .578 .941 r
.63534 .23007 .64187 .23761 .65541 .23764 .64904 .2332 Mtetra
.092 .565 .906 r
.64904 .2332 .65541 .23764 .66923 .24136 .66288 .23628 Mtetra
.392 .735 .991 r
.66288 .23628 .66923 .24136 .6831 .24345 .67669 .23603 Mtetra
.742 .807 .904 r
.67669 .23603 .6831 .24345 .69677 .23955 .69021 .22844 Mtetra
.831 .748 .772 r
.69021 .22844 .69677 .23955 .70998 .22682 .7033 .21292 Mtetra
.774 .688 .768 r
.7033 .21292 .70998 .22682 .72285 .20907 .71654 .20011 Mtetra
.664 .741 .907 r
.71654 .20011 .72285 .20907 .73657 .20423 .73031 .19523 Mtetra
.73031 .19523 .73657 .20423 .75037 .19937 .74415 .19033 Mtetra
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.638 .73 .915 r
.75805 .1854 .76422 .19448 .77817 .18982 .7721 .18131 Mtetra
.649 .752 .924 r
.7721 .18131 .77817 .18982 .79227 .18614 .78618 .17681 Mtetra
.669 .739 .903 r
.78618 .17681 .79227 .18614 .80634 .18118 .80028 .17162 Mtetra
.655 .73 .905 r
.17336 .38321 .18126 .39093 .19254 .38711 .18466 .37943 Mtetra
.66 .733 .904 r
.18466 .37943 .19254 .38711 .20394 .38263 .19603 .37549 Mtetra
.7 .758 .897 r
.19603 .37549 .20394 .38263 .21543 .37776 .20758 .37025 Mtetra
.664 .741 .907 r
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.23059 .36205 .23838 .36962 .24993 .36553 .24217 .35792 Mtetra
.59 .718 .933 r
.24217 .35792 .24993 .36553 .26089 .36912 .25364 .35571 Mtetra
.116 .32 .791 r
.25364 .35571 .26089 .36912 .27175 .37538 .26435 .36351 Mtetra
.409 .529 .867 r
.26435 .36351 .27175 .37538 .28332 .37397 .27562 .36598 Mtetra
.693 .742 .889 r
.27562 .36598 .28332 .37397 .29547 .36541 .28756 .36075 Mtetra
.819 .843 .867 r
.28756 .36075 .29547 .36541 .30786 .35359 .29991 .35045 Mtetra
.853 .88 .858 r
.29991 .35045 .30786 .35359 .32026 .3417 .31237 .33858 Mtetra
.826 .891 .889 r
.31237 .33858 .32026 .3417 .33225 .33635 .32471 .3285 Mtetra
.664 .741 .907 r
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.423 .629 .939 r
.6153 .2249 .62198 .23364 .63534 .23007 .62887 .2261 Mtetra
.054 .553 .885 r
.62887 .2261 .63534 .23007 .64904 .2332 .64262 .22913 Mtetra
.198 .652 .944 r
.64262 .22913 .64904 .2332 .66288 .23628 .65644 .23059 Mtetra
.606 .817 .981 r
.65644 .23059 .66288 .23628 .67669 .23603 .67013 .22685 Mtetra
.804 .779 .83 r
.67013 .22685 .67669 .23603 .69021 .22844 .68349 .21518 Mtetra
.825 .715 .744 r
.68349 .21518 .69021 .22844 .7033 .21292 .69654 .19798 Mtetra
.681 .634 .796 r
.69654 .19798 .7033 .21292 .71654 .20011 .71018 .19108 Mtetra
.664 .741 .907 r
.71018 .19108 .71654 .20011 .73031 .19523 .72399 .18616 Mtetra
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.627 .725 .917 r
.75183 .17624 .75805 .1854 .7721 .18131 .76595 .17245 Mtetra
.667 .752 .913 r
.76595 .17245 .7721 .18131 .78618 .17681 .78003 .16731 Mtetra
.671 .738 .9 r
.78003 .16731 .78618 .17681 .80028 .17162 .79417 .16199 Mtetra
.655 .731 .905 r
.16539 .37546 .17336 .38321 .18466 .37943 .17672 .37166 Mtetra
.649 .729 .908 r
.17672 .37166 .18466 .37943 .19603 .37549 .18808 .36801 Mtetra
.689 .748 .897 r
.18808 .36801 .19603 .37549 .20758 .37025 .19963 .36307 Mtetra
.677 .755 .91 r
.19963 .36307 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.664 .741 .907 r
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.22274 .35441 .23059 .36205 .24217 .35792 .23435 .35025 Mtetra
.23435 .35025 .24217 .35792 .25364 .35571 .24601 .34607 Mtetra
.275 .513 .901 r
.24601 .34607 .25364 .35571 .26435 .36351 .25708 .34962 Mtetra
.264 .405 .818 r
.25708 .34962 .26435 .36351 .27562 .36598 .26806 .35541 Mtetra
.55 .63 .884 r
.26806 .35541 .27562 .36598 .28756 .36075 .2797 .35445 Mtetra
.754 .801 .89 r
.2797 .35445 .28756 .36075 .29991 .35045 .29189 .34699 Mtetra
.836 .878 .873 r
.29189 .34699 .29991 .35045 .31237 .33858 .30434 .3361 Mtetra
.851 .903 .872 r
.30434 .3361 .31237 .33858 .32471 .3285 .31684 .32463 Mtetra
.786 .877 .913 r
.31684 .32463 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.664 .741 .907 r
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.511 .674 .938 r
.59523 .22088 .60201 .22964 .6153 .2249 .60868 .22022 Mtetra
.143 .596 .928 r
.60868 .22022 .6153 .2249 .62887 .2261 .62234 .22276 Mtetra
.095 .603 .893 r
.62234 .22276 .62887 .2261 .64262 .22913 .6361 .22473 Mtetra
.445 .789 .998 r
.6361 .22473 .64262 .22913 .65644 .23059 .64985 .22319 Mtetra
.755 .813 .898 r
.64985 .22319 .65644 .23059 .67013 .22685 .6634 .21498 Mtetra
.819 .734 .77 r
.6634 .21498 .67013 .22685 .68349 .21518 .67663 .19982 Mtetra
.763 .667 .756 r
.67663 .19982 .68349 .21518 .69654 .19798 .68996 .18692 Mtetra
.659 .691 .869 r
.68996 .18692 .69654 .19798 .71018 .19108 .70375 .18197 Mtetra
.664 .741 .907 r
.70375 .18197 .71018 .19108 .72399 .18616 .71762 .177 Mtetra
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.652 .736 .911 r
.73155 .17201 .73788 .18121 .75183 .17624 .74558 .1674 Mtetra
.638 .741 .923 r
.74558 .1674 .75183 .17624 .76595 .17245 .75972 .16321 Mtetra
.677 .748 .904 r
.75972 .16321 .76595 .17245 .78003 .16731 .77382 .15769 Mtetra
.671 .737 .899 r
.77382 .15769 .78003 .16731 .79417 .16199 .78801 .15232 Mtetra
.656 .733 .906 r
.15735 .36772 .16539 .37546 .17672 .37166 .16871 .36384 Mtetra
.646 .729 .91 r
.16871 .36384 .17672 .37166 .18808 .36801 .18009 .36025 Mtetra
.664 .736 .904 r
.18009 .36025 .18808 .36801 .19963 .36307 .19158 .35611 Mtetra
.698 .767 .905 r
.19158 .35611 .19963 .36307 .21118 .35856 .20323 .35089 Mtetra
.664 .741 .907 r
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35025 .22646 .34251 Mtetra
.22646 .34251 .23435 .35025 .24601 .34607 .23816 .3383 Mtetra
.645 .736 .915 r
.23816 .3383 .24601 .34607 .25708 .34962 .24986 .33461 Mtetra
.204 .348 .788 r
.24986 .33461 .25708 .34962 .26806 .35541 .2607 .34185 Mtetra
.385 .485 .839 r
.2607 .34185 .26806 .35541 .2797 .35445 .27199 .34523 Mtetra
.628 .696 .894 r
.27199 .34523 .2797 .35445 .29189 .34699 .28389 .34198 Mtetra
.783 .841 .896 r
.28389 .34198 .29189 .34699 .30434 .3361 .29623 .33351 Mtetra
.839 .905 .883 r
.29623 .33351 .30434 .3361 .31684 .32463 .30875 .32267 Mtetra
.843 .924 .885 r
.30875 .32267 .31684 .32463 .32915 .31626 .32129 .31171 Mtetra
.77 .859 .916 r
.32129 .31171 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.664 .741 .907 r
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.537 .687 .936 r
.57508 .21683 .58196 .22564 .59523 .22088 .58847 .21556 Mtetra
.23 .634 .957 r
.58847 .21556 .59523 .22088 .60868 .22022 .60204 .21748 Mtetra
.056 .59 .859 r
.60204 .21748 .60868 .22022 .62234 .22276 .61573 .2193 Mtetra
.321 .751 .971 r
.61573 .2193 .62234 .22276 .6361 .22473 .62946 .21872 Mtetra
.693 .839 .953 r
.62946 .21872 .6361 .22473 .64985 .22319 .64309 .21279 Mtetra
.807 .757 .807 r
.64309 .21279 .64985 .22319 .6634 .21498 .65649 .20004 Mtetra
.806 .69 .737 r
.65649 .20004 .6634 .21498 .67663 .19982 .66968 .1833 Mtetra
.649 .6 .786 r
.66968 .1833 .67663 .19982 .68996 .18692 .68343 .17777 Mtetra
.664 .741 .907 r
.68343 .17777 .68996 .18692 .70375 .18197 .69727 .17278 Mtetra
.69727 .17278 .70375 .18197 .71762 .177 .71119 .16776 Mtetra
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.631 .727 .917 r
.72516 .16272 .73155 .17201 .74558 .1674 .73929 .15876 Mtetra
.664 .76 .921 r
.73929 .15876 .74558 .1674 .75972 .16321 .75341 .15367 Mtetra
.679 .743 .899 r
.75341 .15367 .75972 .16321 .77382 .15769 .76756 .148 Mtetra
.67 .737 .9 r
.76756 .148 .77382 .15769 .78801 .15232 .7818 .14263 Mtetra
.659 .736 .907 r
.14924 .35999 .15735 .36772 .16871 .36384 .16063 .356 Mtetra
.648 .731 .91 r
.16063 .356 .16871 .36384 .18009 .36025 .17205 .35231 Mtetra
.649 .73 .908 r
.17205 .35231 .18009 .36025 .19158 .35611 .18352 .34858 Mtetra
.69 .751 .899 r
.18352 .34858 .19158 .35611 .20323 .35089 .19518 .34355 Mtetra
.677 .755 .91 r
.19518 .34355 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.664 .741 .907 r
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .23816 .3383 .23024 .33046 Mtetra
.23024 .33046 .23816 .3383 .24986 .33461 .24202 .32619 Mtetra
.487 .661 .938 r
.24202 .32619 .24986 .33461 .2607 .34185 .25349 .32603 Mtetra
.281 .385 .791 r
.25349 .32603 .2607 .34185 .27199 .34523 .26453 .33223 Mtetra
.46 .539 .851 r
.26453 .33223 .27199 .34523 .28389 .34198 .27606 .33377 Mtetra
.665 .736 .903 r
.27606 .33377 .28389 .34198 .29623 .33351 .28813 .32935 Mtetra
.79 .869 .907 r
.28813 .32935 .29623 .33351 .30875 .32267 .30056 .3207 Mtetra
.832 .927 .895 r
.30056 .3207 .30875 .32267 .32129 .31171 .31314 .31026 Mtetra
.831 .942 .898 r
.31314 .31026 .32129 .31171 .33364 .30387 .32572 .29982 Mtetra
.786 .877 .913 r
.32572 .29982 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.664 .741 .907 r
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.509 .675 .939 r
.55484 .21277 .56182 .22161 .57508 .21683 .5682 .21208 Mtetra
.241 .662 .961 r
.5682 .21208 .57508 .21683 .58847 .21556 .58169 .21339 Mtetra
.052 .599 .838 r
.58169 .21339 .58847 .21556 .60204 .21748 .5953 .21471 Mtetra
.264 .735 .942 r
.5953 .21471 .60204 .21748 .61573 .2193 .60899 .21423 Mtetra
.641 .853 .981 r
.60899 .21423 .61573 .2193 .62946 .21872 .62264 .20942 Mtetra
.791 .776 .839 r
.62264 .20942 .62946 .21872 .64309 .21279 .63614 .1985 Mtetra
.802 .696 .748 r
.63614 .1985 .64309 .21279 .65649 .20004 .64945 .18277 Mtetra
.703 .62 .761 r
.64945 .18277 .65649 .20004 .66968 .1833 .66303 .17355 Mtetra
.663 .726 .896 r
.66303 .17355 .66968 .1833 .68343 .17777 .67685 .16854 Mtetra
.664 .741 .907 r
.67685 .16854 .68343 .17777 .69727 .17278 .69074 .1635 Mtetra
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.652 .736 .911 r
.70469 .15844 .71119 .16776 .72516 .16272 .71875 .15376 Mtetra
.638 .741 .923 r
.71875 .15376 .72516 .16272 .73929 .15876 .7329 .14951 Mtetra
.677 .751 .907 r
.7329 .14951 .73929 .15876 .75341 .15367 .74704 .14392 Mtetra
.677 .739 .898 r
.74704 .14392 .75341 .15367 .76756 .148 .76124 .13827 Mtetra
.668 .737 .902 r
.76124 .13827 .76756 .148 .7818 .14263 .77554 .13292 Mtetra
.661 .738 .907 r
.14105 .35225 .14924 .35999 .16063 .356 .15248 .34816 Mtetra
.653 .734 .909 r
.15248 .34816 .16063 .356 .17205 .35231 .16394 .3443 Mtetra
.646 .728 .909 r
.16394 .3443 .17205 .35231 .18352 .34858 .17543 .34063 Mtetra
.661 .735 .905 r
.17543 .34063 .18352 .34858 .19518 .34355 .18702 .33649 Mtetra
.7 .769 .905 r
.18702 .33649 .19518 .34355 .20684 .33895 .19879 .33112 Mtetra
.664 .741 .907 r
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.22225 .32256 .23024 .33046 .24202 .32619 .23406 .31826 Mtetra
.23406 .31826 .24202 .32619 .25349 .32603 .24592 .31393 Mtetra
.423 .538 .869 r
.24592 .31393 .25349 .32603 .26453 .33223 .2573 .31595 Mtetra
.341 .416 .794 r
.2573 .31595 .26453 .33223 .27606 .33377 .26852 .32105 Mtetra
.497 .566 .856 r
.26852 .32105 .27606 .33377 .28813 .32935 .28023 .32157 Mtetra
.671 .752 .911 r
.28023 .32157 .28813 .32935 .30056 .3207 .29241 .31691 Mtetra
.78 .884 .921 r
.29241 .31691 .30056 .3207 .31314 .31026 .30489 .30867 Mtetra
.815 .943 .91 r
.30489 .30867 .31314 .31026 .32572 .29982 .3175 .29887 Mtetra
.812 .959 .908 r
.3175 .29887 .32572 .29982 .3382 .29132 .33014 .28898 Mtetra
.802 .928 .918 r
.33014 .28898 .3382 .29132 .35047 .28687 .34275 .27975 Mtetra
.701 .782 .914 r
.34275 .27975 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.664 .741 .907 r
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.627 .727 .919 r
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20986 Mtetra
.453 .683 .964 r
.53453 .20986 .54161 .21757 .55484 .21277 .54784 .20983 Mtetra
.172 .67 .914 r
.54784 .20983 .55484 .21277 .5682 .21208 .56127 .21048 Mtetra
.073 .624 .826 r
.56127 .21048 .5682 .21208 .58169 .21339 .57482 .21107 Mtetra
.274 .752 .933 r
.57482 .21107 .58169 .21339 .5953 .21471 .58844 .21008 Mtetra
.625 .863 .987 r
.58844 .21008 .5953 .21471 .60899 .21423 .60208 .20544 Mtetra
.779 .786 .858 r
.60208 .20544 .60899 .21423 .62264 .20942 .61562 .1955 Mtetra
.795 .699 .759 r
.61562 .1955 .62264 .20942 .63614 .1985 .62903 .18083 Mtetra
.73 .629 .747 r
.62903 .18083 .63614 .1985 .64945 .18277 .64253 .16931 Mtetra
.651 .646 .832 r
.64253 .16931 .64945 .18277 .66303 .17355 .65633 .16428 Mtetra
.664 .741 .907 r
.65633 .16428 .66303 .17355 .67685 .16854 .6702 .15922 Mtetra
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.629 .726 .917 r
.69814 .14903 .70469 .15844 .71875 .15376 .71229 .14506 Mtetra
.667 .762 .921 r
.71229 .14506 .71875 .15376 .7329 .14951 .72643 .13981 Mtetra
.679 .742 .899 r
.72643 .13981 .7329 .14951 .74704 .14392 .74061 .13407 Mtetra
.673 .737 .899 r
.74061 .13407 .74704 .14392 .76124 .13827 .75488 .12852 Mtetra
.666 .738 .904 r
.75488 .12852 .76124 .13827 .77554 .13292 .76923 .12319 Mtetra
.662 .739 .907 r
.13279 .34448 .14105 .35225 .15248 .34816 .14426 .34032 Mtetra
.657 .737 .908 r
.14426 .34032 .15248 .34816 .16394 .3443 .15576 .33629 Mtetra
.649 .731 .909 r
.15576 .33629 .16394 .3443 .17543 .34063 .16729 .33248 Mtetra
.647 .728 .907 r
.16729 .33248 .17543 .34063 .18702 .33649 .17886 .3287 Mtetra
.676 .746 .903 r
.17886 .3287 .18702 .33649 .19879 .33112 .19059 .32402 Mtetra
.69 .769 .911 r
.19059 .32402 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.664 .741 .907 r
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23406 .31826 .22604 .31026 Mtetra
.22604 .31026 .23406 .31826 .24592 .31393 .23793 .30589 Mtetra
.23793 .30589 .24592 .31393 .2573 .31595 .24988 .30151 Mtetra
.418 .492 .829 r
.24988 .30151 .2573 .31595 .26852 .32105 .26129 .30423 Mtetra
.379 .433 .791 r
.26129 .30423 .26852 .32105 .28023 .32157 .27267 .30856 Mtetra
.506 .567 .852 r
.27267 .30856 .28023 .32157 .29241 .31691 .28448 .30885 Mtetra
.654 .743 .915 r
.28448 .30885 .29241 .31691 .30489 .30867 .29671 .30467 Mtetra
.754 .88 .936 r
.29671 .30467 .30489 .30867 .3175 .29887 .30922 .29732 Mtetra
.787 .948 .926 r
.30922 .29732 .3175 .29887 .33014 .28898 .32186 .28841 Mtetra
.782 .97 .918 r
.32186 .28841 .33014 .28898 .34275 .27975 .33454 .27921 Mtetra
.766 .972 .923 r
.33454 .27921 .34275 .27975 .35518 .27409 .34722 .27041 Mtetra
.773 .896 .93 r
.34722 .27041 .35518 .27409 .3676 .26956 .35989 .26229 Mtetra
.701 .782 .914 r
.35989 .26229 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.664 .741 .907 r
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.627 .727 .919 r
.48781 .21425 .49509 .22308 .50817 .2183 .50093 .2106 Mtetra
.516 .714 .962 r
.50093 .2106 .50817 .2183 .52132 .21351 .51411 .20935 Mtetra
.355 .75 .985 r
.51411 .20935 .52132 .21351 .53453 .20986 .52738 .2088 Mtetra
.096 .648 .812 r
.52738 .2088 .53453 .20986 .54784 .20983 .54076 .20868 Mtetra
.131 .673 .833 r
.54076 .20868 .54784 .20983 .56127 .21048 .55425 .20827 Mtetra
.352 .801 .95 r
.55425 .20827 .56127 .21048 .57482 .21107 .56782 .20629 Mtetra
.653 .867 .98 r
.56782 .20629 .57482 .21107 .58844 .21008 .58142 .20108 Mtetra
.775 .78 .857 r
.58142 .20108 .58844 .21008 .60208 .20544 .59498 .19129 Mtetra
.785 .693 .763 r
.59498 .19129 .60208 .20544 .61562 .1955 .60845 .17737 Mtetra
.736 .628 .74 r
.60845 .17737 .61562 .1955 .62903 .18083 .62196 .16505 Mtetra
.641 .608 .8 r
.62196 .16505 .62903 .18083 .64253 .16931 .63574 .16 Mtetra
.664 .741 .907 r
.63574 .16 .64253 .16931 .65633 .16428 .64958 .15492 Mtetra
.64958 .15492 .65633 .16428 .6702 .15922 .6635 .14982 Mtetra
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.639 .731 .915 r
.67748 .14469 .68414 .15414 .69814 .14903 .69158 .14036 Mtetra
.652 .758 .927 r
.69158 .14036 .69814 .14903 .71229 .14506 .70573 .13559 Mtetra
.678 .748 .904 r
.70573 .13559 .71229 .14506 .72643 .13981 .7199 .12988 Mtetra
.676 .737 .897 r
.7199 .12988 .72643 .13981 .74061 .13407 .73413 .1242 Mtetra
.669 .737 .901 r
.73413 .1242 .74061 .13407 .75488 .12852 .74845 .11874 Mtetra
.665 .739 .905 r
.74845 .11874 .75488 .12852 .76923 .12319 .76286 .11341 Mtetra
.664 .74 .907 r
.12446 .33669 .13279 .34448 .14426 .34032 .13596 .33246 Mtetra
.66 .739 .908 r
.13596 .33246 .14426 .34032 .15576 .33629 .1475 .3283 Mtetra
.655 .735 .908 r
.1475 .3283 .15576 .33629 .16729 .33248 .15907 .32428 Mtetra
.647 .728 .908 r
.15907 .32428 .16729 .33248 .17886 .3287 .17068 .32048 Mtetra
.652 .73 .906 r
.17068 .32048 .17886 .3287 .19059 .32402 .18236 .31649 Mtetra
.69 .759 .904 r
.18236 .31649 .19059 .32402 .20241 .31892 .19421 .31132 Mtetra
.677 .755 .91 r
.19421 .31132 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.664 .741 .907 r
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23793 .30589 .22987 .29779 Mtetra
.22987 .29779 .23793 .30589 .24988 .30151 .24186 .29337 Mtetra
.24186 .29337 .24988 .30151 .26129 .30423 .25389 .28893 Mtetra
.456 .501 .817 r
.25389 .28893 .26129 .30423 .27267 .30856 .26545 .29086 Mtetra
.404 .438 .782 r
.26545 .29086 .27267 .30856 .28448 .30885 .27696 .29474 Mtetra
.496 .545 .836 r
.27696 .29474 .28448 .30885 .29671 .30467 .28883 .29538 Mtetra
.616 .701 .905 r
.28883 .29538 .29671 .30467 .30922 .29732 .30107 .29227 Mtetra
.711 .847 .947 r
.30107 .29227 .30922 .29732 .32186 .28841 .31357 .28625 Mtetra
.749 .935 .948 r
.31357 .28625 .32186 .28841 .33454 .27921 .32623 .2786 Mtetra
.743 .969 .932 r
.32623 .2786 .33454 .27921 .34722 .27041 .33895 .27036 Mtetra
.72 .975 .923 r
.33895 .27036 .34722 .27041 .35989 .26229 .35169 .26223 Mtetra
.695 .971 .925 r
.35169 .26223 .35989 .26229 .37246 .25655 .36444 .25456 Mtetra
.717 .941 .957 r
.36444 .25456 .37246 .25655 .38504 .25194 .3772 .24748 Mtetra
.719 .874 .954 r
.3772 .24748 .38504 .25194 .39767 .24731 .38996 .24102 Mtetra
.702 .816 .936 r
.38996 .24102 .39767 .24731 .41037 .24265 .40275 .23516 Mtetra
.683 .778 .923 r
.40275 .23516 .41037 .24265 .42312 .23797 .41557 .22986 Mtetra
.665 .757 .919 r
.41557 .22986 .42312 .23797 .43594 .23327 .42843 .22512 Mtetra
.646 .75 .925 r
.42843 .22512 .43594 .23327 .44881 .22855 .44133 .22093 Mtetra
.622 .759 .944 r
.44133 .22093 .44881 .22855 .46175 .22381 .45428 .21732 Mtetra
.586 .781 .973 r
.45428 .21732 .46175 .22381 .47475 .21904 .4673 .21431 Mtetra
.513 .81 .999 r
.4673 .21431 .47475 .21904 .48781 .21425 .48038 .21193 Mtetra
.35 .796 .955 r
.48038 .21193 .48781 .21425 .50093 .2106 .49354 .21016 Mtetra
.163 .701 .814 r
.49354 .21016 .50093 .2106 .51411 .20935 .50679 .20885 Mtetra
.154 .695 .813 r
.50679 .20885 .51411 .20935 .52738 .2088 .52014 .20766 Mtetra
.258 .76 .884 r
.52014 .20766 .52738 .2088 .54076 .20868 .53358 .2059 Mtetra
.496 .864 .985 r
.53358 .2059 .54076 .20868 .55425 .20827 .5471 .20248 Mtetra
.706 .851 .952 r
.5471 .20248 .55425 .20827 .56782 .20629 .56067 .19611 Mtetra
.772 .753 .837 r
.56067 .19611 .56782 .20629 .58142 .20108 .57423 .18589 Mtetra
.772 .675 .757 r
.57423 .18589 .58142 .20108 .59498 .19129 .58774 .17236 Mtetra
.722 .615 .737 r
.58774 .17236 .59498 .19129 .60845 .17737 .6013 .16078 Mtetra
.638 .597 .791 r
.6013 .16078 .60845 .17737 .62196 .16505 .61505 .1557 Mtetra
.664 .741 .907 r
.61505 .1557 .62196 .16505 .63574 .16 .62887 .1506 Mtetra
.62887 .1506 .63574 .16 .64958 .15492 .64277 .14548 Mtetra
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.652 .736 .911 r
.65673 .14033 .6635 .14982 .67748 .14469 .67078 .13556 Mtetra
.638 .741 .923 r
.67078 .13556 .67748 .14469 .69158 .14036 .68493 .13122 Mtetra
.674 .757 .913 r
.68493 .13122 .69158 .14036 .70573 .13559 .69908 .12565 Mtetra
.677 .739 .897 r
.69908 .12565 .70573 .13559 .7199 .12988 .7133 .11988 Mtetra
.671 .736 .899 r
.7133 .11988 .7199 .12988 .73413 .1242 .7276 .11433 Mtetra
.667 .738 .904 r
.7276 .11433 .73413 .1242 .74845 .11874 .74198 .10891 Mtetra
.664 .74 .906 r
.74198 .10891 .74845 .11874 .76286 .11341 .75643 .10357 Mtetra
.663 .74 .907 r
.11606 .32882 .12446 .33669 .13596 .33246 .12759 .32456 Mtetra
.663 .74 .908 r
.12759 .32456 .13596 .33246 .1475 .3283 .13917 .3203 Mtetra
.659 .738 .908 r
.13917 .3203 .1475 .3283 .15907 .32428 .15078 .31612 Mtetra
.653 .732 .908 r
.15078 .31612 .15907 .32428 .17068 .32048 .16243 .31212 Mtetra
.647 .727 .907 r
.16243 .31212 .17068 .32048 .18236 .31649 .17412 .30825 Mtetra
.658 .734 .906 r
.17412 .30825 .18236 .31649 .19421 .31132 .1859 .30405 Mtetra
.7 .77 .906 r
.1859 .30405 .19421 .31132 .20607 .30657 .19788 .29853 Mtetra
.666 .743 .908 r
.19788 .29853 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.664 .741 .907 r
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24186 .29337 .23376 .28515 Mtetra
.23376 .28515 .24186 .29337 .25389 .28893 .24583 .28068 Mtetra
.24583 .28068 .25389 .28893 .26545 .29086 .25796 .27618 Mtetra
.531 .554 .823 r
.25796 .27618 .26545 .29086 .27696 .29474 .2698 .27583 Mtetra
.426 .438 .769 r
.2698 .27583 .27696 .29474 .28883 .29538 .28142 .27931 Mtetra
.482 .508 .808 r
.28142 .27931 .28883 .29538 .30107 .29227 .29333 .28058 Mtetra
.568 .629 .872 r
.29333 .28058 .30107 .29227 .31357 .28625 .30555 .2789 Mtetra
.652 .769 .935 r
.30555 .2789 .31357 .28625 .32623 .2786 .31802 .27463 Mtetra
.7 .882 .965 r
.31802 .27463 .32623 .2786 .33895 .27036 .33066 .26865 Mtetra
.702 .943 .959 r
.33066 .26865 .33895 .27036 .35169 .26223 .3434 .2618 Mtetra
.672 .961 .939 r
.3434 .2618 .35169 .26223 .36444 .25456 .35619 .25475 Mtetra
.632 .958 .919 r
.35619 .25475 .36444 .25456 .3772 .24748 .36901 .24788 Mtetra
.59 .945 .908 r
.36901 .24788 .3772 .24748 .38996 .24102 .38186 .24144 Mtetra
.547 .928 .9 r
.38186 .24144 .38996 .24102 .40275 .23516 .39472 .2355 Mtetra
.503 .908 .895 r
.39472 .2355 .40275 .23516 .41557 .22986 .40762 .23015 Mtetra
.454 .884 .886 r
.40762 .23015 .41557 .22986 .42843 .22512 .42055 .22537 Mtetra
.401 .855 .872 r
.42055 .22537 .42843 .22512 .44133 .22093 .43353 .22118 Mtetra
.344 .822 .853 r
.43353 .22118 .44133 .22093 .45428 .21732 .44656 .21757 Mtetra
.29 .789 .833 r
.44656 .21757 .45428 .21732 .4673 .21431 .45965 .21447 Mtetra
.251 .764 .822 r
.45965 .21447 .4673 .21431 .48038 .21193 .47281 .21181 Mtetra
.253 .764 .836 r
.47281 .21181 .48038 .21193 .49354 .21016 .48605 .20934 Mtetra
.321 .803 .892 r
.48605 .20934 .49354 .21016 .50679 .20885 .49938 .20667 Mtetra
.478 .868 .972 r
.49938 .20667 .50679 .20885 .52014 .20766 .5128 .20312 Mtetra
.653 .874 .981 r
.5128 .20312 .52014 .20766 .53358 .2059 .5263 .19785 Mtetra
.743 .795 .894 r
.5263 .19785 .53358 .2059 .5471 .20248 .53984 .18994 Mtetra
.762 .708 .801 r
.53984 .18994 .5471 .20248 .56067 .19611 .5534 .17901 Mtetra
.753 .647 .744 r
.5534 .17901 .56067 .19611 .57423 .18589 .56694 .16581 Mtetra
.687 .587 .738 r
.56694 .16581 .57423 .18589 .58774 .17236 .58055 .15649 Mtetra
.641 .608 .801 r
.58055 .15649 .58774 .17236 .6013 .16078 .59428 .15139 Mtetra
.664 .741 .907 r
.59428 .15139 .6013 .16078 .61505 .1557 .60808 .14627 Mtetra
.60808 .14627 .61505 .1557 .62887 .1506 .62195 .14112 Mtetra
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.662 .74 .908 r
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13082 Mtetra
.629 .728 .919 r
.6499 .13082 .65673 .14033 .67078 .13556 .66403 .12676 Mtetra
.67 .765 .921 r
.66403 .12676 .67078 .13556 .68493 .13122 .67818 .12133 Mtetra
.677 .741 .899 r
.67818 .12133 .68493 .13122 .69908 .12565 .69238 .11554 Mtetra
.672 .735 .897 r
.69238 .11554 .69908 .12565 .7133 .11988 .70665 .1099 Mtetra
.668 .737 .902 r
.70665 .1099 .7133 .11988 .7276 .11433 .721 .10442 Mtetra
.665 .739 .905 r
.721 .10442 .7276 .11433 .74198 .10891 .73544 .09903 Mtetra
.664 .741 .907 r
.73544 .09903 .74198 .10891 .75643 .10357 .74995 .09363 Mtetra
.10759 .32091 .11606 .32882 .12759 .32456 .11915 .3166 Mtetra
.663 .74 .907 r
.11915 .3166 .12759 .32456 .13917 .3203 .13075 .31228 Mtetra
.662 .74 .907 r
.13075 .31228 .13917 .3203 .15078 .31612 .14241 .30798 Mtetra
.658 .736 .907 r
.14241 .30798 .15078 .31612 .16243 .31212 .15411 .30378 Mtetra
.651 .73 .907 r
.15411 .30378 .16243 .31212 .17412 .30825 .16584 .29976 Mtetra
.648 .726 .906 r
.16584 .29976 .17412 .30825 .1859 .30405 .17762 .29582 Mtetra
.662 .738 .906 r
.17762 .29582 .1859 .30405 .19788 .29853 .1895 .29145 Mtetra
.701 .779 .911 r
.1895 .29145 .19788 .29853 .20979 .29405 .20156 .28584 Mtetra
.664 .741 .907 r
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24583 .28068 .2377 .27235 Mtetra
.2377 .27235 .24583 .28068 .25796 .27618 .24986 .26781 Mtetra
.24986 .26781 .25796 .27618 .2698 .27583 .26207 .26326 Mtetra
.636 .641 .838 r
.26207 .26326 .2698 .27583 .28142 .27931 .2743 .25924 Mtetra
.454 .444 .757 r
.2743 .25924 .28142 .27931 .29333 .28058 .28607 .26197 Mtetra
.479 .475 .775 r
.28607 .26197 .29333 .28058 .30555 .2789 .29802 .26364 Mtetra
.529 .548 .819 r
.29802 .26364 .30555 .2789 .31802 .27463 .31023 .26332 Mtetra
.589 .649 .878 r
.31023 .26332 .31802 .27463 .33066 .26865 .32266 .26093 Mtetra
.64 .759 .934 r
.32266 .26093 .33066 .26865 .3434 .2618 .33527 .25691 Mtetra
.666 .852 .971 r
.33527 .25691 .3434 .2618 .35619 .25475 .348 .25185 Mtetra
.658 .908 .98 r
.348 .25185 .35619 .25475 .36901 .24788 .36082 .24629 Mtetra
.625 .931 .968 r
.36082 .24629 .36901 .24788 .38186 .24144 .37369 .24062 Mtetra
.58 .929 .948 r
.37369 .24062 .38186 .24144 .39472 .2355 .38661 .23512 Mtetra
.531 .916 .929 r
.38661 .23512 .39472 .2355 .40762 .23015 .39957 .22992 Mtetra
.488 .898 .915 r
.39957 .22992 .40762 .23015 .42055 .22537 .41258 .22511 Mtetra
.454 .881 .908 r
.41258 .22511 .42055 .22537 .43353 .22118 .42564 .22068 Mtetra
.439 .872 .914 r
.42564 .22068 .43353 .22118 .44656 .21757 .43875 .21657 Mtetra
.453 .874 .935 r
.43875 .21657 .44656 .21757 .45965 .21447 .45193 .21262 Mtetra
.506 .886 .967 r
.45193 .21262 .45965 .21447 .47281 .21181 .46519 .20857 Mtetra
.591 .889 .99 r
.46519 .20857 .47281 .21181 .48605 .20934 .47852 .20402 Mtetra
.677 .855 .967 r
.47852 .20402 .48605 .20934 .49938 .20667 .49194 .1984 Mtetra
.727 .785 .898 r
.49194 .1984 .49938 .20667 .5128 .20312 .50542 .19114 Mtetra
.743 .71 .821 r
.50542 .19114 .5128 .20312 .5263 .19785 .51896 .18177 Mtetra
.74 .652 .762 r
.51896 .18177 .5263 .19785 .53984 .18994 .53251 .17035 Mtetra
.728 .613 .729 r
.53251 .17035 .53984 .18994 .5534 .17901 .54607 .15784 Mtetra
.63 .547 .742 r
.54607 .15784 .5534 .17901 .56694 .16581 .55971 .15218 Mtetra
.65 .647 .833 r
.55971 .15218 .56694 .16581 .58055 .15649 .57342 .14706 Mtetra
.664 .741 .907 r
.57342 .14706 .58055 .15649 .59428 .15139 .5872 .14192 Mtetra
.5872 .14192 .59428 .15139 .60808 .14627 .60105 .13675 Mtetra
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.628 .726 .918 r
.62895 .12634 .63589 .13595 .6499 .13082 .64305 .12228 Mtetra
.667 .772 .928 r
.64305 .12228 .6499 .13082 .66403 .12676 .65718 .11694 Mtetra
.677 .744 .901 r
.65718 .11694 .66403 .12676 .67818 .12133 .67136 .11116 Mtetra
.673 .735 .896 r
.67136 .11116 .67818 .12133 .69238 .11554 .68561 .10545 Mtetra
.668 .736 .9 r
.68561 .10545 .69238 .11554 .70665 .1099 .69994 .09992 Mtetra
.665 .738 .905 r
.69994 .09992 .70665 .1099 .721 .10442 .71436 .09448 Mtetra
.664 .74 .907 r
.71436 .09448 .721 .10442 .73544 .09903 .72884 .08906 Mtetra
.72884 .08906 .73544 .09903 .74995 .09363 .7434 .08363 Mtetra
.664 .741 .907 r
.09904 .31293 .10759 .32091 .11915 .3166 .11063 .30858 Mtetra
.11063 .30858 .11915 .3166 .13075 .31228 .12227 .30421 Mtetra
.663 .74 .907 r
.12227 .30421 .13075 .31228 .14241 .30798 .13396 .29985 Mtetra
.662 .739 .907 r
.13396 .29985 .14241 .30798 .15411 .30378 .1457 .2955 Mtetra
.657 .735 .907 r
.1457 .2955 .15411 .30378 .16584 .29976 .15749 .29127 Mtetra
.651 .729 .906 r
.15749 .29127 .16584 .29976 .17762 .29582 .1693 .28719 Mtetra
.649 .726 .905 r
.1693 .28719 .17762 .29582 .1895 .29145 .18117 .28316 Mtetra
.662 .739 .907 r
.18117 .28316 .1895 .29145 .20156 .28584 .19313 .27872 Mtetra
.7 .78 .913 r
.19313 .27872 .20156 .28584 .21355 .28137 .20527 .27311 Mtetra
.666 .743 .908 r
.20527 .27311 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.664 .741 .907 r
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24986 .26781 .24169 .25938 Mtetra
.24169 .25938 .24986 .26781 .26207 .26326 .25394 .25478 Mtetra
.25394 .25478 .26207 .26326 .2743 .25924 .26625 .25016 Mtetra
.663 .726 .897 r
.26625 .25016 .2743 .25924 .28607 .26197 .27861 .24552 Mtetra
.592 .565 .793 r
.27861 .24552 .28607 .26197 .29802 .26364 .29089 .24284 Mtetra
.496 .464 .751 r
.29089 .24284 .29802 .26364 .31023 .26332 .30295 .24407 Mtetra
.517 .493 .769 r
.30295 .24407 .31023 .26332 .32266 .26093 .31518 .24436 Mtetra
.549 .543 .8 r
.31518 .24436 .32266 .26093 .33527 .25691 .3276 .24331 Mtetra
.585 .607 .84 r
.3276 .24331 .33527 .25691 .348 .25185 .34018 .24095 Mtetra
.618 .675 .882 r
.34018 .24095 .348 .25185 .36082 .24629 .35291 .23756 Mtetra
.64 .737 .918 r
.35291 .23756 .36082 .24629 .37369 .24062 .36574 .23347 Mtetra
.652 .785 .945 r
.36574 .23347 .37369 .24062 .38661 .23512 .37866 .22895 Mtetra
.655 .817 .961 r
.37866 .22895 .38661 .23512 .39957 .22992 .39165 .22422 Mtetra
.656 .832 .968 r
.39165 .22422 .39957 .22992 .41258 .22511 .40471 .21937 Mtetra
.66 .833 .967 r
.40471 .21937 .41258 .22511 .42564 .22068 .41783 .2144 Mtetra
.67 .821 .956 r
.41783 .2144 .42564 .22068 .43875 .21657 .43103 .20921 Mtetra
.686 .795 .932 r
.43103 .20921 .43875 .21657 .45193 .21262 .4443 .2036 Mtetra
.701 .756 .895 r
.4443 .2036 .45193 .21262 .46519 .20857 .45764 .19727 Mtetra
.712 .711 .847 r
.45764 .19727 .46519 .20857 .47852 .20402 .47106 .18989 Mtetra
.716 .666 .799 r
.47106 .18989 .47852 .20402 .49194 .1984 .48454 .18119 Mtetra
.715 .628 .759 r
.48454 .18119 .49194 .1984 .50542 .19114 .49806 .17111 Mtetra
.709 .599 .732 r
.49806 .17111 .50542 .19114 .51896 .18177 .51161 .16006 Mtetra
.649 .553 .733 r
.51161 .16006 .51896 .18177 .53251 .17035 .52517 .15296 Mtetra
.634 .587 .783 r
.52517 .15296 .53251 .17035 .54607 .15784 .53879 .14785 Mtetra
.663 .726 .897 r
.53879 .14785 .54607 .15784 .55971 .15218 .55248 .14271 Mtetra
.664 .741 .907 r
.55248 .14271 .55971 .15218 .57342 .14706 .56623 .13755 Mtetra
.56623 .13755 .57342 .14706 .5872 .14192 .58006 .13236 Mtetra
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.662 .74 .908 r
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .12197 Mtetra
.63 .729 .919 r
.60791 .12197 .61496 .13156 .62895 .12634 .62198 .11782 Mtetra
.666 .773 .929 r
.62198 .11782 .62895 .12634 .64305 .12228 .63609 .11248 Mtetra
.676 .745 .902 r
.63609 .11248 .64305 .12228 .65718 .11694 .65025 .1067 Mtetra
.674 .734 .896 r
.65025 .1067 .65718 .11694 .67136 .11116 .66448 .10096 Mtetra
.669 .734 .899 r
.66448 .10096 .67136 .11116 .68561 .10545 .67879 .09539 Mtetra
.666 .738 .904 r
.67879 .09539 .68561 .10545 .69994 .09992 .69318 .08992 Mtetra
.664 .74 .906 r
.69318 .08992 .69994 .09992 .71436 .09448 .70764 .08446 Mtetra
.664 .74 .907 r
.70764 .08446 .71436 .09448 .72884 .08906 .72218 .07901 Mtetra
.664 .741 .907 r
.72218 .07901 .72884 .08906 .7434 .08363 .7368 .07352 Mtetra
.09043 .30488 .09904 .31293 .11063 .30858 .10204 .3005 Mtetra
.10204 .3005 .11063 .30858 .12227 .30421 .11371 .29609 Mtetra
.11371 .29609 .12227 .30421 .13396 .29985 .12544 .29167 Mtetra
.663 .74 .907 r
.12544 .29167 .13396 .29985 .1457 .2955 .13722 .28724 Mtetra
.661 .738 .907 r
.13722 .28724 .1457 .2955 .15749 .29127 .14904 .28285 Mtetra
.657 .734 .907 r
.14904 .28285 .15749 .29127 .1693 .28719 .16091 .27856 Mtetra
.652 .728 .905 r
.16091 .27856 .1693 .28719 .18117 .28316 .17281 .27441 Mtetra
.649 .726 .904 r
.17281 .27441 .18117 .28316 .19313 .27872 .18477 .27031 Mtetra
.66 .738 .908 r
.18477 .27031 .19313 .27872 .20527 .27311 .19681 .26586 Mtetra
.691 .778 .917 r
.19681 .26586 .20527 .27311 .21736 .26851 .20901 .26048 Mtetra
.677 .755 .91 r
.20901 .26048 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.664 .741 .907 r
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26625 .25016 .25807 .24157 Mtetra
.25807 .24157 .26625 .25016 .27861 .24552 .27048 .23689 Mtetra
.27048 .23689 .27861 .24552 .29089 .24284 .28293 .23219 Mtetra
.658 .693 .871 r
.28293 .23219 .29089 .24284 .30295 .24407 .29545 .22746 Mtetra
.634 .587 .784 r
.29545 .22746 .30295 .24407 .31518 .24436 .30803 .22271 Mtetra
.537 .483 .743 r
.30803 .22271 .31518 .24436 .3276 .24331 .32039 .22213 Mtetra
.548 .494 .747 r
.32039 .22213 .3276 .24331 .34018 .24095 .33287 .22106 Mtetra
.566 .517 .76 r
.33287 .22106 .34018 .24095 .35291 .23756 .34549 .21916 Mtetra
.587 .545 .774 r
.34549 .21916 .35291 .23756 .36574 .23347 .35824 .2164 Mtetra
.606 .571 .788 r
.35824 .2164 .36574 .23347 .37866 .22895 .37111 .21286 Mtetra
.624 .593 .798 r
.37111 .21286 .37866 .22895 .39165 .22422 .38409 .2086 Mtetra
.639 .607 .801 r
.38409 .2086 .39165 .22422 .40471 .21937 .39716 .2037 Mtetra
.652 .613 .798 r
.39716 .2037 .40471 .21937 .41783 .2144 .41032 .19815 Mtetra
.662 .611 .788 r
.41032 .19815 .41783 .2144 .43103 .20921 .42356 .19189 Mtetra
.67 .603 .772 r
.42356 .19189 .43103 .20921 .4443 .2036 .43688 .18483 Mtetra
.676 .592 .754 r
.43688 .18483 .4443 .2036 .45764 .19727 .45027 .17689 Mtetra
.679 .58 .737 r
.45027 .17689 .45764 .19727 .47106 .18989 .46371 .16812 Mtetra
.678 .569 .725 r
.46371 .16812 .47106 .18989 .48454 .18119 .47719 .15883 Mtetra
.616 .53 .734 r
.47719 .15883 .48454 .18119 .49806 .17111 .49065 .15375 Mtetra
.634 .587 .784 r
.49065 .15375 .49806 .17111 .51161 .16006 .50418 .14864 Mtetra
.658 .693 .871 r
.50418 .14864 .51161 .16006 .52517 .15296 .51778 .1435 Mtetra
.664 .741 .907 r
.51778 .1435 .52517 .15296 .53879 .14785 .53144 .13834 Mtetra
.53144 .13834 .53879 .14785 .55248 .14271 .54517 .13316 Mtetra
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.652 .736 .911 r
.57284 .12271 .58006 .13236 .59395 .12714 .58679 .11785 Mtetra
.639 .741 .923 r
.58679 .11785 .59395 .12714 .60791 .12197 .60082 .11338 Mtetra
.668 .773 .928 r
.60082 .11338 .60791 .12197 .62198 .11782 .61491 .10796 Mtetra
.676 .744 .902 r
.61491 .10796 .62198 .11782 .63609 .11248 .62905 .10218 Mtetra
.673 .734 .896 r
.62905 .10218 .63609 .11248 .65025 .1067 .64326 .09644 Mtetra
.669 .734 .899 r
.64326 .09644 .65025 .1067 .66448 .10096 .65755 .09083 Mtetra
.666 .737 .903 r
.65755 .09083 .66448 .10096 .67879 .09539 .67191 .08533 Mtetra
.664 .739 .906 r
.67191 .08533 .67879 .09539 .69318 .08992 .68635 .07985 Mtetra
.664 .74 .907 r
.68635 .07985 .69318 .08992 .70764 .08446 .70087 .07436 Mtetra
.664 .741 .907 r
.70087 .07436 .70764 .08446 .72218 .07901 .71546 .06885 Mtetra
.71546 .06885 .72218 .07901 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29235 Mtetra
.09338 .29235 .10204 .3005 .11371 .29609 .10508 .2879 Mtetra
.10508 .2879 .11371 .29609 .12544 .29167 .11684 .28344 Mtetra
.11684 .28344 .12544 .29167 .13722 .28724 .12865 .27895 Mtetra
.663 .74 .907 r
.12865 .27895 .13722 .28724 .14904 .28285 .14051 .27447 Mtetra
.661 .738 .907 r
.14051 .27447 .14904 .28285 .16091 .27856 .15242 .27002 Mtetra
.658 .734 .906 r
.15242 .27002 .16091 .27856 .17281 .27441 .16438 .26565 Mtetra
.653 .728 .904 r
.16438 .26565 .17281 .27441 .18477 .27031 .17637 .26141 Mtetra
.65 .725 .904 r
.17637 .26141 .18477 .27031 .19681 .26586 .18842 .25723 Mtetra
.657 .734 .907 r
.18842 .25723 .19681 .26586 .20901 .26048 .20054 .25283 Mtetra
.679 .767 .917 r
.20054 .25283 .20901 .26048 .22122 .25549 .21279 .24776 Mtetra
.69 .769 .911 r
.21279 .24776 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.664 .741 .907 r
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27048 .23689 .26227 .22819 Mtetra
.26227 .22819 .27048 .23689 .28293 .23219 .27476 .22344 Mtetra
.27476 .22344 .28293 .23219 .29545 .22746 .28732 .21867 Mtetra
.28732 .21867 .29545 .22746 .30803 .22271 .29993 .21388 Mtetra
.29993 .21388 .30803 .22271 .32039 .22213 .31261 .20907 Mtetra
.649 .647 .835 r
.31261 .20907 .32039 .22213 .33287 .22106 .32534 .20423 Mtetra
.634 .587 .784 r
.32534 .20423 .33287 .22106 .34549 .21916 .33814 .19937 Mtetra
.623 .551 .753 r
.33814 .19937 .34549 .21916 .35824 .2164 .351 .19448 Mtetra
.606 .524 .736 r
.351 .19448 .35824 .2164 .37111 .21286 .36389 .19019 Mtetra
.602 .517 .73 r
.36389 .19019 .37111 .21286 .38409 .2086 .37684 .18596 Mtetra
.614 .524 .729 r
.37684 .18596 .38409 .2086 .39716 .2037 .3899 .18101 Mtetra
.625 .53 .727 r
.3899 .18101 .39716 .2037 .41032 .19815 .40304 .17532 Mtetra
.623 .529 .727 r
.40304 .17532 .41032 .19815 .42356 .19189 .41625 .16969 Mtetra
.616 .53 .734 r
.41625 .16969 .42356 .19189 .43688 .18483 .42949 .16466 Mtetra
.623 .551 .753 r
.42949 .16466 .43688 .18483 .45027 .17689 .44279 .15961 Mtetra
.634 .587 .784 r
.44279 .15961 .45027 .17689 .46371 .16812 .45616 .15453 Mtetra
.649 .647 .835 r
.45616 .15453 .46371 .16812 .47719 .15883 .4696 .14942 Mtetra
.664 .741 .907 r
.4696 .14942 .47719 .15883 .49065 .15375 .48311 .14429 Mtetra
.48311 .14429 .49065 .15375 .50418 .14864 .49668 .13914 Mtetra
.49668 .13914 .50418 .14864 .51778 .1435 .51032 .13396 Mtetra
.51032 .13396 .51778 .1435 .53144 .13834 .52403 .12875 Mtetra
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.639 .731 .915 r
.55165 .11826 .55897 .12795 .57284 .12271 .56558 .1138 Mtetra
.651 .757 .927 r
.56558 .1138 .57284 .12271 .58679 .11785 .57958 .10893 Mtetra
.672 .766 .921 r
.57958 .10893 .58679 .11785 .60082 .11338 .59363 .10337 Mtetra
.675 .741 .9 r
.59363 .10337 .60082 .11338 .61491 .10796 .60775 .09759 Mtetra
.672 .732 .895 r
.60775 .09759 .61491 .10796 .62905 .10218 .62195 .09185 Mtetra
.668 .733 .898 r
.62195 .09185 .62905 .10218 .64326 .09644 .63621 .08624 Mtetra
.666 .737 .903 r
.63621 .08624 .64326 .09644 .65755 .09083 .65055 .08072 Mtetra
.664 .739 .906 r
.65055 .08072 .65755 .09083 .67191 .08533 .66497 .07521 Mtetra
.664 .74 .907 r
.66497 .07521 .67191 .08533 .68635 .07985 .67947 .0697 Mtetra
.664 .741 .907 r
.67947 .0697 .68635 .07985 .70087 .07436 .69403 .06417 Mtetra
.69403 .06417 .70087 .07436 .71546 .06885 .70868 .05861 Mtetra
.70868 .05861 .71546 .06885 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29235 .08465 .28412 Mtetra
.08465 .28412 .09338 .29235 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28344 .10817 .27514 Mtetra
.10817 .27514 .11684 .28344 .12865 .27895 .12001 .27061 Mtetra
.12001 .27061 .12865 .27895 .14051 .27447 .1319 .26607 Mtetra
.663 .74 .907 r
.1319 .26607 .14051 .27447 .15242 .27002 .14385 .26153 Mtetra
.662 .738 .907 r
.14385 .26153 .15242 .27002 .16438 .26565 .15585 .257 Mtetra
.659 .734 .906 r
.15585 .257 .16438 .26565 .17637 .26141 .1679 .25255 Mtetra
.654 .729 .904 r
.1679 .25255 .17637 .26141 .18842 .25723 .17999 .24819 Mtetra
.651 .725 .903 r
.17999 .24819 .18842 .25723 .20054 .25283 .19212 .24392 Mtetra
.654 .729 .905 r
.19212 .24392 .20054 .25283 .21279 .24776 .20433 .23955 Mtetra
.667 .752 .914 r
.20433 .23955 .21279 .24776 .22514 .24229 .21664 .23478 Mtetra
.689 .777 .918 r
.21664 .23478 .22514 .24229 .23745 .23761 .22907 .22931 Mtetra
.677 .755 .91 r
.22907 .22931 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.664 .741 .907 r
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29993 .21388 .29176 .20497 Mtetra
.29176 .20497 .29993 .21388 .31261 .20907 .30447 .20011 Mtetra
.30447 .20011 .31261 .20907 .32534 .20423 .31724 .19523 Mtetra
.31724 .19523 .32534 .20423 .33814 .19937 .33008 .19033 Mtetra
.33008 .19033 .33814 .19937 .351 .19448 .34298 .1854 Mtetra
.34298 .1854 .351 .19448 .36389 .19019 .35594 .18045 Mtetra
.662 .725 .896 r
.35594 .18045 .36389 .19019 .37684 .18596 .36896 .17547 Mtetra
.66 .708 .883 r
.36896 .17547 .37684 .18596 .3899 .18101 .38205 .17047 Mtetra
.38205 .17047 .3899 .18101 .40304 .17532 .3952 .16544 Mtetra
.662 .725 .896 r
.3952 .16544 .40304 .17532 .41625 .16969 .40842 .16039 Mtetra
.664 .741 .907 r
.40842 .16039 .41625 .16969 .42949 .16466 .4217 .15531 Mtetra
.4217 .15531 .42949 .16466 .44279 .15961 .43505 .15021 Mtetra
.43505 .15021 .44279 .15961 .45616 .15453 .44846 .14509 Mtetra
.44846 .14509 .45616 .15453 .4696 .14942 .46194 .13993 Mtetra
.46194 .13993 .4696 .14942 .48311 .14429 .47549 .13476 Mtetra
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.652 .736 .911 r
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11419 Mtetra
.641 .742 .922 r
.53037 .11419 .5378 .12352 .55165 .11826 .54427 .10965 Mtetra
.663 .771 .93 r
.54427 .10965 .55165 .11826 .56558 .1138 .55823 .10438 Mtetra
.674 .755 .912 r
.55823 .10438 .56558 .1138 .57958 .10893 .57227 .0987 Mtetra
.674 .736 .897 r
.57227 .0987 .57958 .10893 .59363 .10337 .58637 .09293 Mtetra
.671 .731 .895 r
.58637 .09293 .59363 .10337 .60775 .09759 .60054 .08723 Mtetra
.667 .733 .899 r
.60054 .08723 .60775 .09759 .62195 .09185 .61478 .08162 Mtetra
.665 .737 .903 r
.61478 .08162 .62195 .09185 .63621 .08624 .6291 .07608 Mtetra
.664 .739 .906 r
.6291 .07608 .63621 .08624 .65055 .08072 .6435 .07056 Mtetra
.664 .74 .907 r
.6435 .07056 .65055 .08072 .66497 .07521 .65797 .06502 Mtetra
.664 .741 .907 r
.65797 .06502 .66497 .07521 .67947 .0697 .67251 .05946 Mtetra
.67251 .05946 .67947 .0697 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .05861 .70182 .04826 Mtetra
.70182 .04826 .70868 .05861 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27514 .09942 .26676 Mtetra
.09942 .26676 .10817 .27514 .12001 .27061 .11129 .2622 Mtetra
.11129 .2622 .12001 .27061 .1319 .26607 .12321 .25762 Mtetra
.12321 .25762 .1319 .26607 .14385 .26153 .1352 .25302 Mtetra
.663 .74 .907 r
.1352 .25302 .14385 .26153 .15585 .257 .14723 .24841 Mtetra
.662 .739 .907 r
.14723 .24841 .15585 .257 .1679 .25255 .15932 .2438 Mtetra
.66 .735 .906 r
.15932 .2438 .1679 .25255 .17999 .24819 .17146 .23925 Mtetra
.657 .73 .904 r
.17146 .23925 .17999 .24819 .19212 .24392 .18365 .23476 Mtetra
.653 .725 .902 r
.18365 .23476 .19212 .24392 .20433 .23955 .19589 .23037 Mtetra
.652 .725 .902 r
.19589 .23037 .20433 .23955 .21664 .23478 .20818 .22596 Mtetra
.658 .737 .908 r
.20818 .22596 .21664 .23478 .22907 .22931 .22056 .22139 Mtetra
.67 .765 .921 r
.22056 .22139 .22907 .22931 .24152 .22417 .23302 .21644 Mtetra
.687 .775 .918 r
.23302 .21644 .24152 .22417 .25399 .21941 .24559 .21095 Mtetra
.677 .755 .91 r
.24559 .21095 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.664 .741 .907 r
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33008 .19033 .32194 .18121 Mtetra
.32194 .18121 .33008 .19033 .34298 .1854 .33488 .17624 Mtetra
.33488 .17624 .34298 .1854 .35594 .18045 .34788 .17124 Mtetra
.34788 .17124 .35594 .18045 .36896 .17547 .36094 .16621 Mtetra
.36094 .16621 .36896 .17547 .38205 .17047 .37407 .16117 Mtetra
.37407 .16117 .38205 .17047 .3952 .16544 .38726 .1561 Mtetra
.38726 .1561 .3952 .16544 .40842 .16039 .40052 .151 Mtetra
.40052 .151 .40842 .16039 .4217 .15531 .41385 .14588 Mtetra
.41385 .14588 .4217 .15531 .43505 .15021 .42724 .14073 Mtetra
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.652 .736 .911 r
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .11501 Mtetra
.643 .743 .922 r
.49519 .11501 .50279 .12432 .51654 .11907 .50899 .1104 Mtetra
.66 .768 .93 r
.50899 .1104 .51654 .11907 .53037 .11419 .52286 .10524 Mtetra
.671 .766 .921 r
.52286 .10524 .53037 .11419 .54427 .10965 .5368 .09968 Mtetra
.673 .742 .902 r
.5368 .09968 .54427 .10965 .55823 .10438 .55081 .09396 Mtetra
.672 .732 .895 r
.55081 .09396 .55823 .10438 .57227 .0987 .56489 .08822 Mtetra
.669 .73 .896 r
.56489 .08822 .57227 .0987 .58637 .09293 .57904 .08256 Mtetra
.667 .734 .9 r
.57904 .08256 .58637 .09293 .60054 .08723 .59326 .07697 Mtetra
.665 .737 .904 r
.59326 .07697 .60054 .08723 .61478 .08162 .60756 .07143 Mtetra
.664 .739 .906 r
.60756 .07143 .61478 .08162 .6291 .07608 .62193 .06588 Mtetra
.664 .74 .907 r
.62193 .06588 .6291 .07608 .6435 .07056 .63637 .06032 Mtetra
.664 .741 .907 r
.63637 .06032 .6435 .07056 .65797 .06502 .65089 .05474 Mtetra
.65089 .05474 .65797 .06502 .67251 .05946 .66549 .04913 Mtetra
.66549 .04913 .67251 .05946 .68713 .05388 .68016 .04349 Mtetra
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03781 Mtetra
.69491 .03781 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26676 .09059 .25832 Mtetra
.09059 .25832 .09942 .26676 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12321 .25762 .11445 .24909 Mtetra
.11445 .24909 .12321 .25762 .1352 .25302 .12647 .24445 Mtetra
.12647 .24445 .1352 .25302 .14723 .24841 .13854 .23978 Mtetra
.663 .74 .907 r
.13854 .23978 .14723 .24841 .15932 .2438 .15066 .2351 Mtetra
.663 .739 .907 r
.15066 .2351 .15932 .2438 .17146 .23925 .16285 .23042 Mtetra
.661 .736 .906 r
.16285 .23042 .17146 .23925 .18365 .23476 .17508 .22577 Mtetra
.659 .733 .904 r
.17508 .22577 .18365 .23476 .19589 .23037 .18737 .22115 Mtetra
.656 .727 .902 r
.18737 .22115 .19589 .23037 .20818 .22596 .19971 .2166 Mtetra
.654 .724 .901 r
.19971 .2166 .20818 .22596 .22056 .22139 .2121 .21209 Mtetra
.654 .727 .903 r
.2121 .21209 .22056 .22139 .23302 .21644 .22455 .20755 Mtetra
.658 .739 .91 r
.22455 .20755 .23302 .21644 .24559 .21095 .23708 .20287 Mtetra
.667 .764 .923 r
.23708 .20287 .24559 .21095 .2582 .20572 .24969 .19794 Mtetra
.677 .776 .925 r
.24969 .19794 .2582 .20572 .27082 .20086 .26239 .1927 Mtetra
.684 .769 .915 r
.26239 .1927 .27082 .20086 .28351 .19599 .27517 .18717 Mtetra
.672 .75 .909 r
.27517 .18717 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.664 .741 .907 r
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.656 .738 .91 r
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12094 Mtetra
.645 .74 .918 r
.44641 .12094 .45422 .13035 .46781 .12513 .46003 .11629 Mtetra
.654 .76 .927 r
.46003 .11629 .46781 .12513 .48147 .11988 .47373 .11133 Mtetra
.663 .772 .93 r
.47373 .11133 .48147 .11988 .49519 .11501 .48751 .10606 Mtetra
.67 .765 .921 r
.48751 .10606 .49519 .11501 .50899 .1104 .50136 .10054 Mtetra
.672 .744 .905 r
.50136 .10054 .50899 .1104 .52286 .10524 .51528 .09487 Mtetra
.671 .733 .896 r
.51528 .09487 .52286 .10524 .5368 .09968 .52927 .08916 Mtetra
.669 .73 .895 r
.52927 .08916 .5368 .09968 .55081 .09396 .54332 .08348 Mtetra
.667 .731 .898 r
.54332 .08348 .55081 .09396 .56489 .08822 .55745 .07787 Mtetra
.666 .735 .902 r
.55745 .07787 .56489 .08822 .57904 .08256 .57165 .0723 Mtetra
.664 .738 .904 r
.57165 .0723 .57904 .08256 .59326 .07697 .58592 .06674 Mtetra
.664 .74 .906 r
.58592 .06674 .59326 .07697 .60756 .07143 .60027 .06118 Mtetra
.664 .74 .907 r
.60027 .06118 .60756 .07143 .62193 .06588 .61469 .0556 Mtetra
.664 .741 .907 r
.61469 .0556 .62193 .06588 .63637 .06032 .62918 .04999 Mtetra
.62918 .04999 .63637 .06032 .65089 .05474 .64375 .04435 Mtetra
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03781 .68792 .02727 Mtetra
.68792 .02727 .69491 .03781 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24445 .11766 .23581 Mtetra
.11766 .23581 .12647 .24445 .13854 .23978 .12976 .2311 Mtetra
.12976 .2311 .13854 .23978 .15066 .2351 .14192 .22637 Mtetra
.663 .74 .907 r
.14192 .22637 .15066 .2351 .16285 .23042 .15414 .22162 Mtetra
.15414 .22162 .16285 .23042 .17508 .22577 .16642 .21686 Mtetra
.662 .738 .906 r
.16642 .21686 .17508 .22577 .18737 .22115 .17875 .21211 Mtetra
.661 .735 .905 r
.17875 .21211 .18737 .22115 .19971 .2166 .19113 .20737 Mtetra
.658 .731 .903 r
.19113 .20737 .19971 .2166 .2121 .21209 .20357 .20268 Mtetra
.656 .727 .901 r
.20357 .20268 .2121 .21209 .22455 .20755 .21607 .19803 Mtetra
.654 .725 .9 r
.21607 .19803 .22455 .20755 .23708 .20287 .22862 .1934 Mtetra
.654 .727 .902 r
.22862 .1934 .23708 .20287 .24969 .19794 .24123 .18877 Mtetra
.656 .736 .908 r
.24123 .18877 .24969 .19794 .26239 .1927 .25391 .18408 Mtetra
.66 .752 .918 r
.25391 .18408 .26239 .1927 .27517 .18717 .26667 .17927 Mtetra
.663 .773 .931 r
.26667 .17927 .27517 .18717 .28798 .18197 .27949 .17435 Mtetra
.667 .783 .936 r
.27949 .17435 .28798 .18197 .30083 .177 .29239 .16929 Mtetra
.669 .782 .934 r
.29239 .16929 .30083 .177 .31374 .17201 .30535 .16414 Mtetra
.67 .78 .931 r
.30535 .16414 .31374 .17201 .32671 .16699 .31838 .15893 Mtetra
.669 .775 .929 r
.31838 .15893 .32671 .16699 .33975 .16195 .33147 .15372 Mtetra
.668 .772 .928 r
.33147 .15372 .33975 .16195 .35285 .15688 .34462 .14853 Mtetra
.665 .769 .927 r
.34462 .14853 .35285 .15688 .36602 .15178 .35784 .14339 Mtetra
.663 .768 .928 r
.35784 .14339 .36602 .15178 .37925 .14667 .37111 .1383 Mtetra
.661 .77 .93 r
.37111 .1383 .37925 .14667 .39255 .14152 .38445 .13323 Mtetra
.66 .773 .932 r
.38445 .13323 .39255 .14152 .40592 .13635 .39785 .12817 Mtetra
.662 .777 .935 r
.39785 .12817 .40592 .13635 .41935 .13116 .41133 .12303 Mtetra
.664 .781 .936 r
.41133 .12303 .41935 .13116 .43285 .12593 .42488 .11781 Mtetra
.668 .783 .935 r
.42488 .11781 .43285 .12593 .44641 .12094 .4385 .11245 Mtetra
.671 .775 .929 r
.4385 .11245 .44641 .12094 .46003 .11629 .45219 .10696 Mtetra
.672 .756 .914 r
.45219 .10696 .46003 .11629 .47373 .11133 .46594 .10136 Mtetra
.672 .741 .902 r
.46594 .10136 .47373 .11133 .48751 .10606 .47977 .0957 Mtetra
.67 .732 .896 r
.47977 .0957 .48751 .10606 .50136 .10054 .49367 .09002 Mtetra
.669 .729 .895 r
.49367 .09002 .50136 .10054 .51528 .09487 .50763 .08437 Mtetra
.667 .73 .897 r
.50763 .08437 .51528 .09487 .52927 .08916 .52166 .07875 Mtetra
.666 .733 .9 r
.52166 .07875 .52927 .08916 .54332 .08348 .53576 .07317 Mtetra
.665 .736 .903 r
.53576 .07317 .54332 .08348 .55745 .07787 .54994 .0676 Mtetra
.664 .738 .905 r
.54994 .0676 .55745 .07787 .57165 .0723 .56419 .06204 Mtetra
.664 .74 .907 r
.56419 .06204 .57165 .0723 .58592 .06674 .57851 .05646 Mtetra
.57851 .05646 .58592 .06674 .60027 .06118 .5929 .05086 Mtetra
.664 .741 .907 r
.5929 .05086 .60027 .06118 .61469 .0556 .60737 .04522 Mtetra
.60737 .04522 .61469 .0556 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .2311 .12091 .22234 Mtetra
.12091 .22234 .12976 .2311 .14192 .22637 .1331 .21757 Mtetra
.1331 .21757 .14192 .22637 .15414 .22162 .14536 .21277 Mtetra
.663 .74 .907 r
.14536 .21277 .15414 .22162 .16642 .21686 .15766 .20797 Mtetra
.15766 .20797 .16642 .21686 .17875 .21211 .17003 .20314 Mtetra
.662 .739 .907 r
.17003 .20314 .17875 .21211 .19113 .20737 .18246 .19832 Mtetra
.661 .738 .907 r
.18246 .19832 .19113 .20737 .20357 .20268 .19494 .19351 Mtetra
.659 .736 .906 r
.19494 .19351 .20357 .20268 .21607 .19803 .20747 .18875 Mtetra
.656 .733 .906 r
.20747 .18875 .21607 .19803 .22862 .1934 .22006 .18403 Mtetra
.654 .731 .906 r
.22006 .18403 .22862 .1934 .24123 .18877 .23271 .17935 Mtetra
.653 .731 .906 r
.23271 .17935 .24123 .18877 .25391 .18408 .24542 .1747 Mtetra
.653 .733 .908 r
.24542 .1747 .25391 .18408 .26667 .17927 .25819 .17004 Mtetra
.654 .738 .911 r
.25819 .17004 .26667 .17927 .27949 .17435 .27103 .16531 Mtetra
.656 .744 .915 r
.27103 .16531 .27949 .17435 .29239 .16929 .28394 .16051 Mtetra
.659 .753 .92 r
.28394 .16051 .29239 .16929 .30535 .16414 .29693 .1556 Mtetra
.661 .761 .924 r
.29693 .1556 .30535 .16414 .31838 .15893 .30998 .15061 Mtetra
.664 .769 .928 r
.30998 .15061 .31838 .15893 .33147 .15372 .3231 .14553 Mtetra
.664 .774 .931 r
.3231 .14553 .33147 .15372 .34462 .14853 .33629 .1404 Mtetra
.665 .777 .932 r
.33629 .1404 .34462 .14853 .35784 .14339 .34955 .13522 Mtetra
.666 .777 .932 r
.34955 .13522 .35784 .14339 .37111 .1383 .36288 .12998 Mtetra
.667 .775 .93 r
.36288 .12998 .37111 .1383 .38445 .13323 .37627 .12468 Mtetra
.669 .771 .926 r
.37627 .12468 .38445 .13323 .39785 .12817 .38974 .1193 Mtetra
.67 .764 .921 r
.38974 .1193 .39785 .12817 .41133 .12303 .40327 .11384 Mtetra
.673 .758 .915 r
.40327 .11384 .41133 .12303 .42488 .11781 .41687 .10825 Mtetra
.673 .75 .908 r
.41687 .10825 .42488 .11781 .4385 .11245 .43054 .1026 Mtetra
.674 .744 .904 r
.43054 .1026 .4385 .11245 .45219 .10696 .44428 .09687 Mtetra
.673 .74 .901 r
.44428 .09687 .45219 .10696 .46594 .10136 .45809 .09114 Mtetra
.671 .737 .899 r
.45809 .09114 .46594 .10136 .47977 .0957 .47196 .08542 Mtetra
.67 .736 .9 r
.47196 .08542 .47977 .0957 .49367 .09002 .4859 .07974 Mtetra
.668 .737 .902 r
.4859 .07974 .49367 .09002 .50763 .08437 .49991 .07411 Mtetra
.666 .738 .904 r
.49991 .07411 .50763 .08437 .52166 .07875 .51399 .06851 Mtetra
.665 .739 .905 r
.51399 .06851 .52166 .07875 .53576 .07317 .52814 .06292 Mtetra
.664 .74 .906 r
.52814 .06292 .53576 .07317 .54994 .0676 .54236 .05733 Mtetra
.664 .741 .907 r
.54236 .05733 .54994 .0676 .56419 .06204 .55666 .05172 Mtetra
.664 .74 .907 r
.55666 .05172 .56419 .06204 .57851 .05646 .57103 .0461 Mtetra
.664 .741 .907 r
.57103 .0461 .57851 .05646 .5929 .05086 .58547 .04044 Mtetra
.58547 .04044 .5929 .05086 .60737 .04522 .59999 .03475 Mtetra
.59999 .03475 .60737 .04522 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000002D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo
0?ooo`1P0?ooo`00aP3oool2000002P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP00`000000oooo0?oo
o`1P0?ooo`00``3oool3000002X0ZKgX00<000000:Vmj02Y_NP01`2Y_NP00`000000oooo0?ooo`1O
0?ooo`00`@3oool2000000030:Vmj0000000ZKgX02X0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`00
0000oooo0?ooo`1N0?ooo`00_P3oool300000080ZKgW;@2Y_NP00`000000ZKgX0:Vmj0080:Vmj003
0000003oool0oooo05h0oooo002k0?ooo`<0000000<0Z[gW0:Vmi`2Y_NL00`2Y_NL30:Vmj0<0ZKcW
1P2Y_NP50:Vmia/0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo0?ooo`1M0?ooo`00^@3o
ool2000000D0Z[gW1@2Y_NL60:Vli`<0ZKgX0`2Y_>L50:Vmi`<0ZKgX0`2Y_NLD0:Vmj0030000002Y
_NP0ZKgX00T0ZKgX00<0oooo0000003oool0G@3oool00;H0oooo100000000`2Z_>L0Z[gW0:Zmi`03
0:Zmi`H0Z[cW2`2Y_>L<0:Vmia<0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`000000oooo0?ooo`1L
0?ooo`00]03oool2000000@0Z[cW00@000000:Zli`2Z_NL0Z[gW0`2Z^nH60:Zli`80ZKcW0`2Z_>H6
0:Vli`80ZKgW0`2Z_>L;0:Vmi`h0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`3oool000000?ooo`1L
0?ooo`00/@3oool300000080ZkcV1P2Z_>L60:ZkiPD0Z[cW1P2Z_>H50:Vli`H0Z[cW0`2Y_NL30:Zl
i`D0ZKgW0`2Y_NP30:Vmi`L0ZKgX00<000000:Vmj02Y_NP02`2Y_NP2000005`0oooo002^0?ooo`<0
00001P2[_>H30:Zli`<0Z[[U1P2Z^nH20:Zli`<0Z[_U1P2Z_>H50:ZkiP`0Z[cW2`2Y_NL20:Vmj0<0
ZKgW00<0ZKgX0000002Y_NP03@2Y_NP00`000000oooo0?ooo`1J0?ooo`00[03oool4000000P0ZkcV
1P2Z^^D50:ZkiPH0Z[_U0`2Z_>H30:^ji@D0Z[_V0P2Z_>L30:ZkiP/0Z[cW2`2Y_NL00`2Y_NP00000
0:Vmj00=0:Vmj0030?ooo`000000oooo05X0oooo001k0?ooo`050?ooS`0e00000000000DG`34ool0
:P3oool2000000X0ZkcV0`2[^^D50:Zji@H0Zk[U1@2Z^nD70:^ji@X0Z[_V0`2Z_>L30:^ki@D0Z[cW
0`2Y_NL30:Zli`D0ZKgW00<000000:Vmj02Y_NP00`2Y_NL:0:Vmj0030?ooo`000000oooo05T0oooo
001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?9`3oool3000000X0ZkcV1P2[^^D20:Zji@<0
Zk_U1P2[^^D20:Zki@<0[;_U1P2[^^D50:^ki@H0Z[_V1P2[^nD;0:Zli`@0ZKgW00<000000:Vmi`2Y
_NL0102Y_NL:0:Vmj0030000003oool0oooo05P0oooo001j0?ooo`070?ooS`0e03D0Sooo0?ooo`3o
a5l0500e08ooo`0T0?ooo`8000000`2/_NH50:^liPH0Zk_U1@2[^^D60:^ki@D0Zk[U1P2/^nD30:^j
i@<0[;cU1@2[^nD30:ZkiP<0[;_U1@2[^nD50:^kiP/0Z[cW00<000000:Vmi`2Y_NL00`2Y_NL:0:Vm
j0030?ooo`000000oooo05P0oooo001j0?ooo`070?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4o`0Q
0?ooo`@000001@2/_NH20:^liP<0[;gV1P2[^nD20:^ji@<0[;kW1P2[^nD50:bmiPD0[;_U1P2/_>D5
0:^ki@L0[;_U0P2[^nD30:bki@D0Zk_V0`2Z_>L30:^kiP@0Z[cW00@000000:Vmi`2Y_NL0ZKgW0`2Z
_>L:0:Vmj0030000003oool0oooo05L0oooo001j0?ooo`070?n?=@0055l0a?oo0?ooo`3oohl0=@0D
05o4o`0O0?ooo`800000102/_^L;0:bmiPD0Zk_U1P2/_^L30:^ki@<0ZlC[1@2/_NH20:bki@<0[<7Y
1P2/_>D20:^ki@<0[;gV2`2/^nD<0:^kiP<0Z[cW00<000000:Zli`2Z_>L01@2Z_>L20:Vmj0<0Z[gW
1@2Y_NP00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3oool007X0oooo
00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`0000000`2/_nP0[;kW0:bni`040:bn
i`80[;gV0`2/`NT60:bmiPD0Zl?[1@2/_^L70:_4j`@0[;gV1P2/`NT50:bli@H0[;gV0`2/^nD30:fn
iPD0[;_U0P2[^nH30:bki@H0Zk_V0`2[_>H00`000000ZkcV0:Zli`050:Zli`H0Z[gW102Y_NP00`3o
ool000000?ooo`0A0?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0n0?ooo`00NP3oool0
1`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool3000000D0[;oX1@2/_^L60:c1j@<0[;gV
0`2YaNh50:_3j`80[;kW0`2Xa>h60:_4j`D0ZLG^1P2/`NT50:c4j`D0[;gV1`2]_^H:0:bki@<0Zk_V
0`2/_>D20:^liP030000002[_>H0ZkcV00<0Z[cW0`2[_>H50:Zmi`D0ZKgW00<000000?ooo`3oool0
5@3oool00`2oM000M;oo0?ooo`0m0?ooo`00NP3oool01P3ool@0Ga@003F?o`3oool0a5lD000eSaP0
oooo0P0000000`2/`^X000000:c2jP060:boj0D0ZlK]1P2/`NT60:W5kP@0Zl?[1P2Xa>h30:_4j`<0
Y;g/1@2YaNh30:c1j@<0Y/7]1@2/a>/20:bmiP<0ZlG]2`2]_^H60:bki@H0[;cU00<0ZkcV0000002[
_>H0202[_>H20:Zmi`<0Z[cW1@2Y_NL00`000000oooo0?ooo`070?ooo`030?oOW0180000000000<0
000000<0001d0;ooo`3oool0103oool00`2oM000M;oo0?ooo`0m0?ooo`00N`3oool01@3oohl0=@00
0000000055l0a?oo01D0oooo0`0000060:c2jP<0[;oX0`2[b>l50:_6k@<0[<7Y0`2W`^d50:W5kPH0
Y;k/1@2Xa>h60:Bmk0@0ZLG^1`2V`Nd40:c4j`H0ZlG]0`2]_^H30:[5k@D0[KkV0`2/^nD30:fniPH0
[;cU00@000000:bli@2/_>D0[;cU1P2[_>H60:Zli`@0ZKgW00<0oooo0000003oool03`3oool01`3o
gi`0B01809cOo`3oool0oooO09a8B02Lgol0?P3oool009<0oooo0P0000040:_3j`H0[<;Z1P2[b>l4
0:_6k@L0Yl;]0P2YaNh30:Jlj@H0Y;k/1@2V_>T50:Bmk0H0Xk_Z1@2V`Nd50:>mk0H0ZlG]1P2ZaNd;
0:fniP80[;cU0`2]_NH00`000000[;cU0:bli@020:bli@H0ZkcV1@2Z_>L50:Zmi`030000003oool0
oooo00h0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0m0?ooo`00T03oool30000
0080ZlG]1@2[`n/30:c2jP<0ZLO_1@2[b>l60:Fmj`D0Yl;]1P2V_>T30:Bnk0<0ZKgX1@2V_>T20:Bm
k0<0ZKgX1P2S^nX50:Jlj@D0Xkg/1P2Q^^/:0:[5k@H0[KkV1@2]_NH00`000000[;cU0:bli@020:bl
i@L0ZkcV0P2Z_>L30:^liPD0Z[gW00<000000?ooo`3oool03@3oool00`3ooml0W4Q809cOo`120?oo
o`00SP3oool2000000030:_5k@000000ZlG]00<0ZlG]1@2[`n/60:W7k`D0YkcX1P2U_N/50:Vmj0D0
Y[cY1`2Y_NP40:Jlj@H0ZKgX0`2S^nX30:Vmj0D0Y[cY0P2S_N`30:Vmj0H0XK[[0P2ZaNd30:2ij`D0
Z/G]0`2]_^H30:_3j`@0[KgV00<000000:fmi@2]_ND00`2]_ND<0:^liP@0Z[gW00<0oooo0000003o
ool03P3oool00`2oM000M;oo0?ooo`110?ooo`00R`3oool3000000<0Z/K^1@2[aNd60:W6k`<0ZLO_
0`2Y_NP50:Nlj0<0YKg[202Y_NP20:JljAX0ZKgX102V_>T60:Vmj0D0XK[[1P2P^N/40:[5k@L0Zl?[
0P2]_NH00`2/`NT000000:c1j@050:fmi@<0ZkcV0`2]_>D50:^liPD0Z[cW00<000000?ooo`3oool0
3@3oool01P3OW4P00000000000000000001d0;oooch0oooo00290?ooo`80000000<0oooo0:[6kP2Z
a^h0102Za^h20:_5k@<0Z<G^1P2Ya^l60:Vmj0D0YkcX=P2Y_NP50:2ij`D0XK[[1P2[`n/30:c1j@03
0000002/`NT0[<7Y00@0[KgU1`2]_>D20:^liP<0[;cV1@2Z_>L00`000000oooo0?ooo`1@0?ooo`00
QP3oool3000000T0Z/K^1P2XaNh30:W6kdT0ZKgX1@2Q^^/60:>mk080[<7Y00<000000:c1j@2/`NT0
1@2]_nL60:fli@H0[;cV102Z_>L00`3oool000000?ooo`1@0?ooo`00Q03oool3000000L0Z/K^1P2Y
aNh50:S5kT`0ZKgX0P2Q^^/30:Jlj@H0Xkg/00<0[<7Y0000002V`^d00P2V`^d50:foi`<0[KcU0`2]
_NH50:bliPD0ZkcV00<000000?ooo`3oool0C`3oool00840oooo0`0000030:[6kP030000002Za^h0
Z/K^0080Z/K^0`2Ya>d60:W5kU00ZKgX1P2V_>T50:>mk0030:K2k@000000Y/;]00<0Y/;]102]_nL7
0:fmiP80[;cV0`2]_ND50:^liP030000003oool0oooo04h0oooo001o0?ooo`800000102Ya^h50:[6
kPH0ZLC]0`2YaNiC0:Vmj0D0Y[cY1P2S^nX00`000000Y/;]0:K2k@020:K2k@D0Z/?[1P2]_NH60:fm
i@@0ZkcV00<0oooo0000003oool0CP3oool007`0oooo0`0000020:W4k@D0ZLK^1P2Za>d50:W4kBH0
ZKgX1@2X/Mh50:Vmj0H0ZKWU802Y_NP20:Jlj@<0ZKgX1@2S^nX00`000000XKWZ0:6ijP030:6ijPD0
Z/?[0`2]_NH30:g0j0D0[KgU1@2[_>H00`000000oooo0?ooo`1=0?ooo`00B`3oool01@34Ga@00000
0000000001@0GlCo02T0oooo0`0000000`2Ya>d000000:W4k@030:W4k@80ZLK^0`2[aNd60:[4kBP0
ZKgX0`2RU/P50:RagP80ZKgX0`2RU/P60:Vii@D0YZGE802Y_NP30:>kjP030:Vmj0000000ZKgX00D0
XKWZ102Z`n/70:g0j080[KgU0`2]_^H50:^liP030000003oool0oooo04`0oooo001:0?ooo`070?n?
=@0055l0a?oo0?ooo`3ool@0Ga@e08ooo`0V0?ooo`800000102Y`^`50:W4k@H0ZlG]0`2Za>dM0:Vm
j0H0YZGE1@2Y_NP50::Fb0D0Z;7N1P2RU/P30:Vii@<0XHbm1@2VYMD20:Vmj0<0Y9_=7`2Y_NP00`00
0000ZKgX0:6ijP030:6ijPD0Xkg/1P2]`>P60:fniP@0ZkcV00<000000?ooo`3oool0C03oool004l0
oooo00<0ScD003F?o`3oool08P3oool300000080Z<3[1@2Y`^`60:_6k@D0ZlG]7@2Y_NP30::Fb0H0
YZGE1@2MQk/50::Fb080Z;7N0`2VSK/60::Fb0D0XHbm1@2VYMD60:BKc@80ZKgX0`2SV<XI0:Vmj003
0000002Y_NP0Y[cY00@0Y[cY1@2S_N`60:W2j`D0[KkV1@2[_>H00`000000oooo0?ooo`1;0?ooo`00
@P3oool00`3oa5l0500000000003000000030000=@2?ool0oooo00@0oooo00<0ScD003F?o`3oool0
803oool2000000H0Z<3[0P2Y`^`30:_7kPH0ZlK]7`2Y_NP60::Fb0@0YZGE0P2]TKT409f7^`D0XYK8
1@2VSK/50::Fb080^Ybj1@2QS;d30:JUe@80[iJl1@2TVld60:>HbQP0ZKgX00<000000:Vmj02Y_NP0
1@2V_>T20:>mk0<0XK[Z1@2Y`^/30:fniP<0[KoW1@2[_>H00`000000oooo0?ooo`1:0?ooo`00BP3o
ool01`3oa5l0500D05o4o`3oool0ooo405lD501Oa?l07P3oool3000000030:NnjP000000YkkZ00D0
Z<3[1P2[anh30:_6kA<0ZKgX1@2Y^ND50:Vmj0D0Whg01P2RU/P20:JUe@<0[I6i1@2MQk/30::Fb080
]IVk1@2VSK/30::Fb0<0^Ybj1@2QS;d20:JUe@<0[iJl102TVld20;RM_0H0XiS:1@2TVl`B0:Vmj004
0000002Y_NP0ZKgX0:Vmj0@0Y[cY1P2Q^^X40:W2j`L0[KoW102[_>H00`000000oooo0?ooo`1:0?oo
o`00BP3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01/0oooo0P0000020:Nlj@D0
YkkZ0P2X`>/40:_8k`D0ZlO^4`2Y_NP30:RehPD0ZKWU0P2Y_NP309f7^`@0Whg01P2RU/P50:fA^@D0
WHNk0P2RU/P30;FI^`D0YXfk0P2RU/P40;ZL^PD0XHbm1P2_U[`20:BKc@<0^9fl1@2SV<X20;bP_@D0
Y9_<0P2Y_NP30:JUe0`0ZKgX00<000000:Vmj02Y_NP01P2Y_NP50:6jjPD0Xkg/1P2]_nL50:^liP03
0000003oool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`0000050:Nlj@@0YkkZ
1`2[b>lE0:Vmj0H0Z;GR102Y^ND509f7^`D0Whg0102RU/P20:fD_0D0[I6i102MQk/50;FI^`D0YXfk
1`2jW;X30:6<_@80`:Fn1@2_U[`00`2TVld0^9fl0;RM_0030;RM_0<0XiS:0`2lX;d50:BKc0H0YZGD
0P2Y_NP30:Vii@H0ZKgX00<000000:Vmj02Y_NP01`2Y_NP50:Jlj@D0Xkg/0`2]_nL30:[0j@D0ZkcV
00<000000?ooo`3oool0B03oool004/0oooo00<0ScD003F?o`3oool06P3oool2000000<0Yk_X1P2W
_>T50:[8k`<0ZlS_4`2Y_NP:0:RehPD0WhNj102MQk/509n=`080XYK8102]U;`50:fA^@<0WHNk0P2g
X<850;FI^`<0YXfk0P2mY/<60;ZL^P80XHbm0`30YKh50:nF_0H0^9fl0P2SV<X50;bP_@<0Y9_<0P2j
XKl50:JUe0H0ZKWU1@2Y_NP00`000000ZKgX0:Vmj0080:Vmj0D0Y[cY102S_N`60:[0j@<0ZkcV0P2[
_NL00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@00000000000000000000e08oooa@0oooo
0`0000000`2W^nL0Yk_X000000030:Nkj0<0YkcY0`2YaNh50:[8ka<0ZKgX0`2Y^ND70:RehPL0WhNj
1@2MQk/409n=`0H0[IBl1@2]TKT209f7^`<0]j321@2eVK/20:J=^`<0_JK31P2jW;X00`2QS;d0`:Fn
0<2U_P020<2U_P@0[iJl0P35[<450;RM_0L0_:2m0P2TVl`30;ZQ_`@0YZGD0P2cW/850:Vii@D0ZKgX
00<000000:Vmj02Y_NP02@2Y_NP40:Jlj@D0X;WZ1@2Z`>T60:^mi`030000003oool0oooo04L0oooo
001S0?ooo`8000001@2W^nL50:Nkj0H0ZLG^5@2Y_NP50:Vii@D0Z;GR2@2OQkX509f7^`80Whg00`2]
Ul460:fD_0@0[I6i1@2gX<850;FI^`H0_JK31@2jW;X60<2U_P80[iJl0`35[<440;RM_080b;731P2l
X;d60;ZQ_`80YZGD102cW/820:Vii@<0YYW9102Y_NP00`000000ZKgX0:Vmj00>0:Vmj0D0X;WZ1@2V
`>`60:^mi`030000003oool0oooo04H0oooo001O0?ooo`@00000202W^nL50:S0j`<0ZLG^0`2/_nPE
0:Vmj0D0ZKWU0P2X]N8309f6^PT0WhNj102MQk/50:fG`@H0[IBl0`2]TKT20;NZc0D0]j320`2eVK/2
0;jedPD0_JK3102jW;X20<>ec@D0`:Fn00<0[iJl0<F/`@35[<400`35[<420;RM_0<0b;731P2lX;d0
0`3;//80^Z6o0;ZQ_`030;ZQ_`H0/ik21P2VVLT20:Vmj0030:R`gP000000Z;3N0100ZKgX0P2P^NX3
0:>jjPD0Y/3/0`2[_NL20:Vmi`030000003oool0oooo04H0oooo001N0?ooo`<00000202W^nL30:Nl
j0D0Z<3[1P2/_nPE0:Vmj0@0ZKWU1@2MQ[X909n7^P80WHNk0`2[V/D50:fG`@D0[IBl0P2]TKT30;NZ
c0D0]j320P2eVK/40;jedPD0_JK30P2jW;X30<>ec@D0`:Fn1P35[<400`2hWK`0b;730<Ra``030<Ra
``@0_:2m0P3;//840;ZQ_`80cK:o1@2cW/800`3>/;`0YYW90:JIb@030:JIb@<0Z;3N00<000000:R`
gP2X/=h03`2Y_NP60:>jjP@0Y/3/1P2Y_NL00`000000oooo0?ooo`150?ooo`00F`3oool3000000T0
Yk_W1P2W_>P20:S0j`<0[lCZ1P2/_nPD0:Vmj0D0VXBj102MQ[X909n7^PD0Zi[51@2]Ul450:fD_0H0
]j[<102gX<860;jedPD0_JK31P33]Ld30<2U_P80aL3F1@35[<460<Ra``<0_:2m103;//820;ZQ_`<0
cK:o102cW/820<j`_0@0YYW90P33Z/420:R`gP030000002X/=h0Z;3N0100ZKgX1@2S^^X509nkk0D0
ZKgW00<0oooo0000003oool0A@3oool005P0oooo0`0000030:Rli`D0Yk_W1@2W^^H50:Nlj0H0[lCZ
0`2/_nPB0:Vmj0D0VhJl102JQ;X509f6^PH0WhNj0`2YW<T50:^Ja@D0[IO10P2]U;`30;Jff0D0]j[<
0P2gX<830;[8i@H0_[GB0P2mY/<30;k;i0D0`kG=0P30YKh30<G0eP@0aJc10P36am/60<Ra``030;bP
_@3;//80bk;200<0bk;200<0^Z6o0<fb_`3=/[l00`3=/[l20;>N`P@0c[2l0P2VVLT40<>Z`@030:R`
gP000000[Z;;0080[Z;;402Y_NP50:Rlj0D0Wk_/0P2Y_NL30:Rmj@030000003oool0oooo04@0oooo
001E0?ooo`030:Vlj000000000000080ZKcX1@2X_>L50:NiiPD0Yk[V1P2]a^`50:o4jQ80ZKgX0`2O
SL0409^6_0@0VXBj1@2MQ[X409n7^PD0ZIc91@2[V/D50:fG`@D0][KH1@2gZ/`50;[8i@H0_[GB1@2n
bn@50<>ec@H0aL3F0P35[<440<K7f`D0b;731P3;//860<fb_`030;>N`P3>/;`0c[2l00<0c[2l00<0
YYW90<>Z`@33Z/400`33Z/400`2^X//000000:jRb`030:jRba00ZKgX1@2X_>P409nkk0H0Z;gY00<0
00000?ooo`3oool0@`3oool005<0oooo0`0000000`2Y_>P000000:Vlj0020:Vlj080Z;cW0`2W^^H5
0:NiiP<0Yk[V0P2Z`n`60:g6k1@0ZKgX1@2OSL0409^6_0D0VXBj102MQ[X209n7^P<0YYc<1@2YW<T5
0:^Ja@80[IO10`2c`ND50;Jff080]j[<0`2]f_L50;[8i@<0_[GB0`2Wgo/50;k;i080`kG=0`2dfO<5
0<G0ePH0a/OK1038/L<20<O9f`@0bk;20P3:a]H50<fb_`H0c[2l1P33Z/400`3C]kh000000:jRb`03
0:jRba40ZKgX102X_>P509fhj`D0Z;gY00<0oooo0000003oool0@`3oool00540oooo0P0000040:Vm
j0@0ZKcX1P2W^^H50:NiiPD0Z/?/0`2]a^`B0:Vmj0D0XYK8102OSL0509^6_0@0VXBj102MQ[X60:JL
c0@0ZIc91@2[V/D50;?1i@D0][KH1P2]f_L40;[8i@L0Ymok102nbn@60;CIl`80aL3F0`2WgOX60<K7
f`80b;730`37bM/30<^b`P<0b/KF103=/[l20<k1cP@0c[2l0P3A^lD40<>Z`@80dkNn00@000000:jR
b`2^X//0[Z;;0P36/<@E0:Vmj0D0WKS[1@2U_>T00`000000oooo0?ooo`120?ooo`00CP3oool30000
00L0ZKgX102X^nL60:NjiPD0Z;gX1@2Z`n`C0:Vmj080YZGE102RU/P509n=`0@0VhJl102JQ;X209f6
^P<0Xi_=1@2VW<`50:VLb@80Zi[50`2_bnh50;?1i@80][KH0`2Ghod50:gJm`L0N]kh102Wgo/607kM
o0@0]=Wc1P2WgOX50<K7f`H0alWK00<0bk;20<[6eP3:a]H00`3:a]H20<fb_`<0c/7>0`3>/;`30=6k
a@<0`j[10`3C]kh00`000000[Z;;0:jRb`040<J`a080ZKgX0`2VYM@@0:Vmj0D0WKS[1@2U_>T00`00
0000oooo0?ooo`110?ooo`006@3oool00`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e00000000000D
G`34ool0:@3oool2000000P0ZKgX0`2Y_>L40:Rki`<0Yk[V0`2W^^L50:Rmj0H0[L7X3`2Y_NP50:JU
e@@0XYK8102OSL0409^6_0@0VXBj1P2SVld50:JLc0@0ZIc91P2_bnh40;?1i@H0Un?m1`1BcN@602Na
d0@0@/;R1P0Q[=D405[=l`@0Ymgj1P2Og?`50<O9f`H0b/KF00<0cK:o0<k1cP3>`Lh00`3>`Lh00`3>
/;`0dK_50=6ka@030=6ka@80`j[10`3C]kh00`000000[Z;;0<J`a0040<J`a0H0YZGD402Y_NP509fh
j`@0YKcY00<0oooo0000003oool0@@3oool001T0oooo00X0omnL04P0M02oool0oooo0?oog`1O5000
55o40?ooo`34Ga@003F?9P3oool300000080ZKgX00<000000:Vmj02Y_NP00`2Y_NP60:Vli`@0Z;_W
1P2W^^L20:Rmj0<0[lK[1P2]`NP?0:Vmj0@0YZGE102RU/P409n=`0@0VhJl1@2OUl`50:>Kc@D0YYc<
1@2[d_@50:o;kPH0PN;g0`10`mH00`10`m80FL_d0:2jj`040:2jj`D0Q;Kf1@2P^^/507>^mP@0;:_Y
100BWm<404K0kPD0Wmcl1@2Tf_/50<[6ePH0c/7>1P3A^lD00`33Z/40dkNn0=>g_P020=>g_P030000
0036/<@0a[3400@0a[3400<0e[Zn0:JUe02VYM@00`2VYM@A0:Vmj0@0WKS[1@2S^nX00`000000oooo
0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool001T0oooo00/0omnL04P0M02oool0
oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`030:Vmj0000000000000L0ZKgX2P2Y
_>L60:NiiP@0Yk[W1P2_a^/30:g1j140ZKgX1@2VYMD40::Fb0<0Whg01@2KT/T509nGc0D0Xi_=0P2V
W<`30:SEm`D0Zm;d0P1cgnl304[9e@D0U/Oi0`23col30:Vmj0D0X;[[0P24]_H30:Vmj0D0X;[[1@2Y
_NP508:/l0@0?JWf1@0=VMH304>ll@D0Y=[k0P3:a]H30;7Fl`@0c/7>0P31d>D50=6ka@H0dkNn00<0
00000<J`a036/<@00P36/<@20=Jj_P@0YZGD0P2k/<l@0:Vmj0D0W[S[1@2S^nX00`000000oooo0?oo
o`080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P000000000
0`0000000`0007@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0
oon?03D0501Oa?l0803oool3000000X0ZKgX1P2Y_>L40:NjiPH0YkWV1@2[`n/50:o6ja@0ZKgX102V
YMD40::Fb0@0UX_61@2KT/T509nGc0@0Xi_=1P2XeOL2073Oj@<0F=;J1@2O`_4509K7n@H0ZKgX102P
^^/60:Vmj080X;[[202Y_NP208:/l0<0ZKgX1@29[nl503ZRm0803YOK102Tf_/60;7Fl`80c/7>0`31
d>D40=6ka@80cLOD103C]kh00`3D_lD000000<J`a0020<J`a0@0e[Zn0P2VYM@40;^`ca00ZKgX1@2N
^>/20:>kjP80XK[[00<000000?ooo`3oool0203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02o
ool0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?noM00055l0a?oo0?ooo`3oohl0=@0D05o4
o`0N0?ooo`<000003@2Y_NP30:Vli`<0Z;_W102W^^H30:NiiP<0Z;cX1@2[`n/H0:Vmj0D0S7jo102@
Q<8409J;aP@0Vi;91@2OUl`50:ODm`<0Z=Gg0P1dhNP306KJg`<0YKo/1@2O`_4T0:Vmj080RJo_0`2Y
_NP508:/l0<099S]101B`?P40;7Fl`H0`M3U0P3A^lD30<g7e0<0dkNn0P3D_lD00`000000e;o50<J`
a0050=Jj_PH0^k3?402Y_NP509jhj`D0XK[[00<000000?ooo`3oool01`3oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0a?oo
0?ooo`3oohl0=@0D05o4o`0K0?ooo`<000004@2Y_NP60:Rki`@0Yk[V1P2X_>P20:_3j`<0[L7X3`2Y
_NP50::Fb0@0RG^n102<O[l40924`P@0UX_61@2KT/T209nGc0<0Ym7f1@2We?L207CQj0<0I][O1P2U
_n`209o2lB`0ZKgX1@22[?0402BHk@<069[T101abOl50<7@i@H0cLOD00H0dkNn0=Boa@3D_lD0e;o5
0000003D_lD60=Jj_P030=Ro`@2k/<l0^k3?0080^k3?0P3;^LT?0:Vmj0H0WkW[1@2Q^^/00`000000
oooo0?ooo`060?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool03@2o
M000001809boW01807@0_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool20000
0100ZKgX1@2Y_>L50:Rki`D0Y[WV1@2X_>P60:g1j0d0ZKgX0P2X/Mh40::Fb0@0RG^n102<O[l50924
`P@0UX_6102KT/T60:OAmP80O>GZ0`1dh^850:[1j`D0YKo/=02Y_NP506bQl0803HgR101abOl509_A
n`D0cLOD103D_lD00`000000d<K@0=36d0040=Jj_P<0f;o10P2k/<l40<^ib@l0ZKgX2P2O^N/00`00
0000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`00603oool0
2`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo0?ooo`34Ga@003F?01L0oooo0`00000C0:Vm
j0D0ZKcW0P2X^nL30:NiiPD0Y[WV0P2X_>P40;36j`D0[L7X2P2Y_NP50:RagP<0XYK81029Nkh508an
_`@0T8C2102FRlH50:K8l@<0Ym7f0`27j^d2083Xi@<0[/O/1@2Z`N/i0:Vmj0D0X;[[0`15To0303:V
l@D0Vm7k0P3=am@30;g>i`<0e;o500<000000=36d03@a]000`3F^[h40=Ro`@H0bkW900<0eL350:Vm
j02Y_NP03@2Y_NP50:6ijPD0WkW[00<000000?ooo`3oool01@3oool01`3ookl0M01d0;ooo`3oool0
omnL04P0M02oool0<03oool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@0000000000
55l0a?oo01@0oooo0`0000000`2Y_NP000000:Vmj00D0:Vmj0@0ZKcW1P2W^NH40:JiiPL0/<K[3`2Y
_NP40:RagP@0XYK81029Nkh408an_`@0T8C21@2S_>/50:K8l@<0Qn[]0P20j>D60:k7k3h0ZKgX1@2P
^^/404FCl0805i3W102KdO/60;g>i`030=Boa@3@a]00000000<0d<K@00<0e[Zn0=Ro`@3H_l400`3H
_l400`3Ha<H0bkW90<^ib@020<^ib@<0eL350P2Y_NP30:Vii@X0ZKgX1@2Q^NX409nij`030?ooo`00
0000oooo00D0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y_NP00000
0000000K0:Vmj0D0Z;[W1@2W^NH50:[0j@<0/<K[4P2Y_NP40:RagP<0XYK81029Nkh408an_`D0WZcQ
1@2S_>/509C]lPD0/m3_0`2^ana10:Vmj080X;[[0`2Y_NP407bXl00301N:j00GT>L0I;cm00<0I;cm
1@2mc^L20=36d0040000003@a]00d<K@0=36d0D0f;o10P3Ha<H30<^ib@@0eL351P2Y^ND:0:Vmj0@0
XKWZ1@2O^N/00`000000oooo0?ooo`050?ooo`050?oo_`1d000000000018W03Oool0<@3oool00380
oooo0`00000I0:Vmj0D0Z;cW1@2X^^L50:Nji`D0Z/3Y502Y_NP40:RagP<0XYK81029Nkh509FKe`D0
WZcQ0P2S_>/509o^m`<0^=od1@2cd>m90:Vmj0@0O:S`0P0GR^P406Blo@D0X<_f00@0d<K@0000003@
a]00d<K@0P37b]`30=Ro`@@0f<C600<0bkW90=G0a@3E`<D00`3E`<D00`3LaL80ZKWU0:Vii@030:Vi
i@X0ZKgX1@2Q^^X509nij`030000003oool0oooo03X0oooo000`0?ooo`80000000<0ZKgX0000002Y
_NP06P2Y_NP50:Rli`80Z;[W0`2V^NL50:Nji`H0/<CY3P2Y_NP509N@b`@0OWK00`24O/@408b;c0@0
UI_G1@2N[>4309o^m`80Uo7X1P2hgoA=0:Vmj0D0X;W[0`0lSNh303ZQm0@0X<_f0P0000000`3@a]00
al[L0<O:g0020<O:g0030=Ro`@3Ha<H0f<C600<0f<C61@3E`<D30=c5`P80ZKWU0`2]^^<:0:Vmj0D0
XK[Z1@2O^>X00`000000oooo0?ooo`0i0?ooo`00;03oool0102Y_NP0000000000000000P0:Vmj0@0
Z;cW1P2V^NL30:Nji`80[LCZ1P2`a>T:0:Vmj0@0ZKWU102GT</407if`0@0Q7k40`2<Rl`509FKe`80
WZcQ102Xj?X20:7ej`<0]o3d0`2hgoA?0:Vmj0D0X;W[0`0lSNh302N@kP<0000000<0X<_f0<O:g000
00001037b]`50=S4aP80e/O<0`3E`<D40=c5`PH0[K[S2P2Y_NP50:6jjP@0WkSZ00<000000?ooo`3o
ool0>@3oool002/0oooo0P00000T0:Vmj0D0Yk[W1@2V^NL50:g4jP<0/<CY3@2Y_NP40:Vii@<0Ui3;
101nM/0408Ana0@0S8_<102EVmL50:SXnP80XOG[1@2gl?AB0:Vmj080X;W[0`2Y_NP206FLk`<00000
00<09i3^07bmn`1l_O/00P1l_O/00`000000al[L0<O:g0030;W9i`<0f<C6103Fal`00`3E`<D0g<G2
0=c5`P030=c5`P030=o8`P2]^^<0[K[S00<0[K[S2P2Y_NP60:6jjP@0WkSZ00<000000?ooo`3oool0
>03oool002T0oooo0P00000R0:Vmj0D0Z;_W1@2W^^L50:Rkj0D0[LCZ402Y_NP30:Vii@@0Ui3;101n
M/0408Ana0<0S8_<1`2Zf_P20:7ej`<0]o3dFP2Y_NP300000080IIc_0`0TRN/407bmn`030000002i
bNL0^LWW00<0^LWW00<0f<C60=K7c03Fal`00`3Fal`50=c5`P<0glS20P2]^^<30;?1i@X0ZKgX1@2Q
^^X50:2hjP030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3o
ool200000200ZKgX0`2Y_>P50:Rki`80Yk[W0`2V^NL50:Rkj0D0[L7X3`2Y_NP40:Vii@<0Ui3;101n
M/0408Ana0D0Xl;_0`2Zf_P20:cfl0<0/OS/0`2cb>UG0:Vmj08000000P2Y_NP406FLk`<098W[101N
ZoT00`000000^LWW0;W9i`020;W9i`D0e/O<0P3Bb=030=c5`P@0glS21@2c`ND:0:Vmj0H0XKWZ102P
^>X00`000000oooo0?ooo`0g0?ooo`00703oool01P3ooml0W4P004RLg`3oool0gia8001d_`L0oooo
00<000000?ooo`0000007@2Y_NP60:Vlj0@0Z;_W1P2V^NL20:Rkj0<0/<OZ1@2]`NP:0:Vmj0D0XZCF
0`1dLL4309N@b`@0OWK01@2FY^050:?2k`80[?K`0`2an>`60;?8jE<0ZKgX0`0000050:Vmj0@0Pjc_
0`0YQn/405j[n@030000002ibNL0ZLC]0080ZLC]0`3Fal`40=;8d0030=c5`P3Ob<80glS200<0glS2
00<0hLc30;?1i@2c`ND00`2ca^P:0:Vmj0D0XKWZ102P^>X00`3oool000000?ooo`0g0?ooo`00703o
ool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool200000080oooo00<000000:Vmj02Y
_NP0702Y_NP50:Vlj0D0Yk[W102V^NL60;37jP<0[L7X302Y_NP40::TeP@0M7710`1jNLH408N<d@D0
UZKP0P2S`^l30;?am@80^?W/0`35iNh50;?8jE00ZKgX0`0000080:Vmj0D0Pjc_0`0YQn/304fMm003
0000002Ya>d0ZLC]00<0ZLC]00<0e/O<0=;8d03Bb=000`3Bb=050=o8`P80hLc31P2ca^P:0:Vmj0@0
XKWZ1@2Q^NT00`3oool000000?ooo`0f0?ooo`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol01@3oool00`000000oooo0?ooo`020?ooo`030000002Y_NP0ZKgX01`0ZKgX1@2X^nL50:Nj
i`D0Z;cX1@2`anX?0:Vmj0<0XZCF101dLL4307YiaP@0QhcA1@2FY^030;?am@80^?W/1P35iNiA0:Vm
j0<00000302Y_NP509Jek@<0<HO[0`1=WO@00`000000ZLC]0:W4k@020:W4k@D0d/S@0P3?bM@30=o8
`P<0hLc300<0hlo40;?6j02ca^P00`2ca^P:0:Vmj0D0WkW[1@2Q^NT00`000000oooo0?ooo`0e0?oo
o`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`03
0?oooa`0ZKgX0`2Y_>P50:Rki`80Yk[W0`2V^NL50:Rlj0D0Z[kX3`2Y_NP30::TeP@0M7710`1jNLH4
08N<d@80UZKP102chOL20;khkP@0a?S/D@2Y_NP300000100ZKgX102F]Nd40367j`<0AYCa00<00000
09Zml02J_O000P2J_O030=;8d0@0clWD00@0glS20>7<``3Qc<<0hLc30`3Scl@50:k4j@X0ZKgX1@2O
^N/50:>jj@030000003oool0oooo03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vmj00F0:Vmj0H0ZKcX102X^nL60:Jii`80Z;cX
0`2canT50:Znj0h0ZKgX0`2RY=H407Aa`@<0NWW61027S=450;?Qm`80__S^0`34n>`30;?8jDd0ZKgX
0`00000C0:Vmj0D0X;W[100jQn/304JDl@030000002J_O00V[g`0080V[g`00<0d/S@0<o9e03?bM@0
0`3?bM@40>7<``<0hlo400<0iM?40:k4j@2^a>T00`2^a>T:0:Vmj0D0W[S[1@2S^^T00`000000oooo
0?ooo`0c0?ooo`00703oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01@3oool00`000000
oooo0?ooo`050?ooo`030000002Y_NP0ZKgX01L0ZKgX1@2Y_>P50:Jji`@0Y[WW1P2canT20:Znj0d0
ZKgX1027SM8206e`a0@0M7710`1jNLH70:K4k`80__S^0`34n>`60;?8jDT0ZKgX0`00000G0:Vmj0D0
X;W[100jQn/204F>kP030000002J_O00V[g`0080V[g`1@3?bM@20<k9eP80hLc30`3Scl@30>GCa080
[/CY3@2Y_NP509jhj`@0Xk[Y00<000000?ooo`3oool0<`3oool001`0oooo00H0oooO09a8001d_ol0
oooo0=nLB000M;l60?ooo`030000003oool0oooo00L0oooo6@2Y_NP50:Rkj0D0Y[[W1@2Y_NP40;?7
j@l0ZKgX1027SM8306e`a0@0Nh;>102AXMl30:K4k`<0_nob0`38n>/20<g]j`D0/lSYAP2Y_NP30000
01/0ZKgX1@2U^nT00`11QnX0>XO[03Z7j`0304F>kP030000002A]_00TKK`0080TKK`0`3?bM@40<k9
eP030>7<``3Scl@0hlo400@0iM?43`2Y_NP509jhj`D0YK_Y00<000000?ooo`3oool0<P3oool001d0
oooo00D0oono07@00000000004RL0=ooo`060?ooo`030000003oool0oooo00P0oooo502Y_NP50:Vl
j0D0Z;_X1@2V^NLH0:Vmj0<0QhgB0`1]L<@407^2cPD0TJ7O102oko830<Shj`@0cNg[B02Y_NP20000
01l0ZKgX1@2U^nT20467jP@0AHk^00<00000096fl02A]_000P2A]_060<k9eP<0hlo4103Udl@00`3V
f<L0ZKgX0:Vmj00<0:Vmj0H0WKS[102U^nT00`000000oooo0?ooo`0b0?ooo`009`3oool00`000000
oooo0?ooo`0:0?oooa@0ZKgX1@2Y_>P20:Rkj0<0Y[[W1@2V^NL20:Vmj0<0/lOY4P2Y_NP408N=dP<0
KG34101kP/h2096Qg`@0]]Sb0`38n>/40<g]jdL0ZKgX0`00000R0:Vmj0@0YK_Y0`11QnX304V<k003
0000002=/Nh0SK7^00<0SK7^103>bMH20<k:eP030>??a03Udl@0iM?40080iM?40`3Vf<L>0:Vmj0D0
WKS[1@2X_NT00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`0;0?oooa@0ZKgX
102Y_>P60:Jji`@0Y[WW1P2canT?0:Vmj080M83A1027SM8306e`a0@0Nh;>1@2ff?830<Wbk@<0coGX
AP2Y_NP3000002D0ZKgX1@2U^nT304N6j0<0BHc/00<0000008fakP2=/Nh00`2=/Nh20<k9eP<0c/[F
103Udl@40>KHa`030>?Nc`2Y_NP0ZKgX00`0ZKgX1@2M]^T50:Rmj@030000003oool0oooo0300oooo
000W0?ooo`030000003oool0oooo00`0oooo502Y_NP50:Rlj0D0Y[[W1@2Y_>L40;?7j@l0ZKgX0`1d
P=4306M`b0<0KG341P2M/nL20;KHlP<0bO;]0`3?mNP30<WPjD40ZKgX0`00000Y0:Vmj0D0YK_Y0`17
Q^P304n;j@030000002=/Nh0SK7^0080SK7^103>b]H20=3<e@80iM?4103Vf<L20>?Nc`l0ZKgX1@2M
]^T20:Rmj@80ZKkY00<000000?ooo`3oool0<03oool002L0oooo0P00000>0?oooa@0ZKgX1@2X_>P5
0:Fii`D0ZKcW1@2Z_^P>0:Vmj080M83A101WL<P307j;ePH0WK?W0P39l^d30<oej0H0bN3Y?@2Y_NP3
000002d0ZKgX1@2P^N/00`1=QNH0AhKX04N6j00304n;j@030000002>[n`0SZo/0080SZo/0P3>b]H4
0=3<e@@0i]S70`3Sg/l@0:Vmj0@0WKKY1@2Y_^T00`000000oooo0?ooo`0_0?ooo`009`3oool00`00
0000oooo0?ooo`0>0?oooa@0ZKgX1@2V^^P50:Fii`80ZKcW0`2caNL50:Znj0d0ZKgX0`1dP=4306M`
b0@0OX_F0`2M/nL30<7Qk`<0d?7X0P3DlND30<WPjC`0ZKgX0`00000a0:Vmj0D0X;W[0P1=QNH304n;
j@030000002>[n`0SZo/0080SZo/1@3@c=D20=G?d`80i]S70`3Sg/l20=cUg0l0ZKgX1@2P]NL50:Vn
j@030000003oool0oooo02h0oooo000W0?ooo`030000003oool0oooo00l0oooo4P2Y_NP20:Rlj0D0
Y[[X102U^NL60;?5i`l0ZKgX0P1[OM@307B0d@@0Ig38101nRmH40<7Qk`<0d?7X103DlNDk0:Vmj0<0
0000=@2Y_NP40:2ij`<0CHGV0`1GRnL00`000000TjoY09>_j@0209>_j@<0d<cE103Ecm<30>?Nc`@0
g>GL2P2Y_NP50:Rlj0D0X;GW102[_nT00`000000oooo0?ooo`0^0?ooo`009`3oool200000140oooo
00<000000:Vmj02Y_NP0302Y_NP50:Rlj0D0Y[[X1@2X^nL30;?5i`80[L7X3P2Y_NP306]me080HFk:
101WL<P60:NnjP<0d?7X103DlND30<GKjSL0ZKgX0`00000h0:Vmj0D0U[G]00<0DXCT04f5iP1=QNH0
0`1GRnL00`000000TjoY09>_j@0209>_j@030=3<e@3Ecm<0eLoC0080eLoC0P3Ke=450=cUg080b>W]
2P2Y_NP40:Rlj0H0Y[WW102[_nT00`000000oooo0?ooo`0]0?ooo`009P3oool2000001<0oooo00<0
00000:Vmj02Y_NP0302Y_NP50:Rlj0D0YK[X1@2X^nL50:g1j0h0ZKgX0P1[OM@3065^bP@0PI7J0`2W
_^X40<ORj`<0e>gU1P35fnXc0:Vmj0<00000?02Y_NP509Jek@80DXCT101GRnL010000000TjoY09>_
j@2C[nT40=G?d`<0fmCA00@0hm[>0=cUg03LiM`0g>GL1038jNd90:Vmj0D0Xk[Z1@2V^NL20:^oj@<0
[<3Y00<000000?ooo`3oool0;03oool000T0oooo00X0oono07@00000000004RL0=ooo`3oool0omnL
04P0M02oool0gia81@0000000`1d_ol0oooo0=nLB002000000030000B02Lgol0oooo00H0oooo00<0
00000?ooo`3oool04`3oool00`000000ZKgX0:Vmj00<0:Vmj0D0Yk_X1@2U^^P50;32i`D0[L7X3@2Y
_NP306]me0<0HFk:1021TMX50<ORj`<0e>gU103Gk>8d0:Vmj0800000@02Y_NP409Jek@<0DXCT0`1Q
SNH00`000000W;;W09bbi`0209bbi`80eLoC0`3Ke=430>?JcPH0b>W]2P2Y_NP50:>jjP@0Y[WW1@2/
`>T00`000000oooo0?ooo`0:0?ooo`050=nLB000000000000000B02Lgol07@3oool000P0oooo00H0
oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0okmd0018W03O
ool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0503oool00`000000ZKgX0:Vmj008
0:Vmj0@0Z;cX1@2W^nP20:Fjj0<0Y[[W1@2``^L>0:Vmj0@0K8WN00<0Ef[;06]me01QK/X00`1QK/X2
086AfP<0Zl3Y0P37h^/30=C]i@@0encR0P39h>T`0:Vmj0<00000@`2Y_NP408>/k`0305R3h@1BQ>@0
DXCT00<0HHgV00<0000009bbi`2L/^L00P2L/^L40=_Dd@<0hm[>0P3Yh//?0:Vmj0@0Xk[Z1@2Z_NL5
0:c0j@030000003oool0oooo00P0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo
00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0
oooo00<0_g@007Boo`3oool01@3oool2000001H0oooo2`2Y_NP40:Rlj0@0Yk_X1P2V^^L30;32i`<0
/<CY3@2Y_NP306b9gP80Ef[;101QK/X60:_0j@80e>gU1@3Gk>840<WPjB`0ZKgX0`0000160:Vmj0@0
Pjc_0`1HPn44066=iP030000002Y^>@0ZKST0080ZKST0P3Ke=430>?JcP<0jN;;00<0kN[90:Vmj02Y
_NP0302Y_NP50:6fj0D0Z[gW1@2/`>T00`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0
oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO
00L0oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`X0ZKgX102X_>P50:Fj
j0D0Y[[W1P2`a>T=0:Vmj0<0K8WN0P1GJ//407n@f`<0Zl3Y103:g^P30=KWhPH0bN3Y:@2Y_NP30000
04T0ZKgX1023[>l405R3h@<0K97T00<000000:Vhi02Y^>@00`2Y^>@30>?JcP<0jN;;0P3]j/T?0:Vm
j0D0XKKX1@2]`>P40:c0j@030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0
oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018W=l0oooo0?oO
W01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo01P0oooo2@2Y_NP50:Nl
j0D0YK[X1@2]_^L30;34j@`0ZKgX101lZO001017H/X0K8WN05MZb`1GJ//507n@f`D0b]kX0`3Fin83
0=WWgbX0ZKgX0`00001=0:Vmj0@0KISY0P1NQ=l205R3h@<0K97T00<000000:Vhi02Y^>@00`2g`>40
103Sf/h0jN;;0>WRb`3Yh//30>gZb@030=cgg@2Y_NP0ZKgX00d0ZKgX1@2S]^H40:g0j0D0ZkoX00<0
00000?ooo`3oool01P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo
00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo00D0oono07@0B02Lgol0oono07@00003
0000000307Boo`3oool0oooo00@0oooo0P00000K0?ooo`D0ZKgX1@2X_NP40:Nlj0D0YK[X1@2]_^L?
0:Vmj0<0O:W`0P17H/X305MZb`80Oi3K102Z_>L20<[Nj0<0e^OR0`3Iiml30=?ThbD0ZKgX0`00001A
0:Vmj0<0KISY101NQ=l406bAi0030000002g`>40]l3Q0080]l3Q0`3Yh//30>gZb@<0g?OM302Y_NP3
0:Jlj@@0XkKV0P2]`>P30:k1j0D0ZkoX00<000000?ooo`3oool01@3oool00`3ookl0M00000000002
0000000307Boo`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;oo
o`030?ooo`030?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000
003oool0oooo01/0oooo1@2Y_NP50:Rmj0@0Y[_X1@2U^^P50;?4i`l0ZKgX0`1lZO0204MRbP80MHWI
1`2Z_>L20=KWhP@0fNOO1@3Ci><Q0:Vmj0<00000D02Y_NP50:2ij`0306F4g@1]V>T0KISY00@0GXCO
101kV><00`000000]l3Q0;O0h@030<S<g@<0kN[9103Lmmd:0:Vmj0D0Y[cY102S]^H60:k1j0@0ZkoX
00<000000?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Bo
o`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo
2@3oool00`000000oooo0?ooo`0L0?ooo`D0ZKgX0P2X_NP30:Rlj0@0Y[_X0`2U^^P20:Vli`D0/lCW
2P2Y_NP50:FljP0403AIb@1lZO00Af;:04MRbP@0MHWI0`2Z_>L30<SGi@@0e^3O103Ci><30;?8jAd0
ZKgX0`00001D0:Vmj0@0X;W[0`1UQ=d405j4g`@0NiSS00<000000;O0h@38c=d00P38c=d30=SJf@<0
g?OM0`2id^d:0:Vmj0@0Y[cY1@2Y_>L50:k1j0D0ZkoX00<000000?ooo`3oool01@3oool00`2oM000
M;oo0?ooo`0O0?ooo`002@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00D0omnL04P00000
0000000007Boo`020?ooo`060=nLB000000000000000000007@0_ooo1@3oool00`000000oooo0?oo
o`0M0?ooo`@0ZKgX1P2X_>P40:Jkj0D0ZKcW0`2ca>L20:g1j0X0ZKgX102U_>X203AIb@<0Af;:101e
RMT40<SGi@@0e^3O0`3JhM/60;?8jAX0ZKgX0P00001H0:Vmj0@0X;W[0`1UQ=d306R7g@D0NiSS00<0
00000<S<g@38c=d00`3Hf]T20>KXdPH0^M;]2@2Y_NP50:6gj0D0ZKcW1@2]`NP40:^oj0030000003o
ool0oooo00D0oooo00H0gia800000000000000000000M02ooolL0?ooo`009@3oool2000001l0oooo
1@2Y_NP40:Rlj0D0YK[X1@2Y_>L50:g1j0X0ZKgX102U_>X203AIb@80HWcF1@2P/^@20<SGi@@0e^3O
0`3JhM/20=WNfPD0/lSY5`2Y_NP3000005X0ZKgX102P^N/406F4g@<0J8OM1@2=X^<010000000f=[I
0=SJf@3Hf]T30>KXdP80k??:3P2Y_NP50:6gj0D0[L3X102]`NP50:Znj0030000003oool0oooo02H0
oooo000U0?ooo`030000003oool0oooo01l0oooo1@2Y_NP50:Nkj0@0YK[X1@2``>H50:g1j0X0ZKgX
0`16PnH203AIb@<0HWcF1@2P/^@40=KPg`<0f^7K103Ig]XH0:Vmj0<00000GP2Y_NP4086Sj@<0JH?J
101XQmd408fRh`030000003Hf]T0f=[I00<0i^SB0P3/llX20=Knf0h0ZKgX1@2S]ND40:g0j0D0[<3X
1@2Z_^P00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P0?ooo`D0ZKcX1@2W
^nP50:Jjj0@0/<3V3`2Y_NP304J3iP0304=Wd@0dFLT0HWcF0080HWcF0`2P/^@40<7=h`<0f^7K103I
g]X20<cLiA@0ZKgX0`00001R0:Vmj0@0PJ?Y0`1YPmX307J>g@D0Xk;S00<000000>KXdP3Vj=800P3V
j=80103/llX0e_kH0=Knf03Fo]P<0:Vmj0<0Y[cY1@2S]ND20:g0j080[/7X1@2/`>P40:Znj0030000
003oool0oooo02D0oooo000T0?ooo`8000008`3oool50:Vlj0D0YK_X1@2V^^P50;;4i`h0ZKgX0P16
PnH204=Wd@@0HWcF1@31cN<30=7Gg@@0fMkJ103<g>D@0:Vmj0<00000H@2Y_NP50:2jj`<0L8GH0`1Y
PmX407J>g@@0Xk;S00D0_<KR0000003Vj=80i^SB0>ccbP040=Knf0X0ZKgX1P2V_>T40:>ei@D0[/7X
0P2/`>P30:^oj0@0Z[kX00<000000?ooo`3oool0903oool002@0oooo00<000000?ooo`3oool08`3o
ool30:Vlj080Z;cX1@2U^nP20:Jjj0<0ZKcW1@2ba>L90:Vmj0D0UkO^0P16PnH204=Wd@@0S:7R0`31
cN<30=7Gg@@0f=[I103<g>D20;?8j@`0ZKgX0`00001U0:Vmj0@0X;[[1@1`QMP206V3fP@0MXkM0P2S
/^<30;c6hP040000003/llX0e_kH0=Knf0@0[/?Y2P2Y_NP50:Jlj@D0Z[gW102^`NP60:^oj080Z[kX
0P2Y_NP00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`D0Z;cX102U
^nP60:Vli`D0[L7X2P2Y_NP309NgkP0301eAbP16PnH0@fOA0080@fOA102<XN840=7Gg@@0f=[I0`3I
f=H50;?8j@P0ZKgX0`00001Y0:Vmj0@0X;[[1P1`QMP407J>g@D0_<KR00D000000>Kcd`3Vlm<0i_?C
0>Kla0040:k3j@X0ZKgX1@2Q]>H40:Zmi`D0[L7X1@2[_nP40:Vmj0030000003oool0oooo02<0oooo
000T0?ooo`8000009P3oool50:Rlj0D0YK[X0`2Y_>L20;2oi@D0[L7X2P2Y_NP309NgkP0401eAbP13
Im40@fOA04=Wd@H0/KgS1@3Hf]T30=WHeP80fMGE1@2cb>T40:Vmj0<00000K02Y_NP40:2jj`L0L8GH
1028Vmh30;c6hP040=GOgP3Vlm<000000>Kcd`80i_c43`2Y_NP40:6diPX0[L7X1@2Z_^P40:Vmj003
0000003oool0oooo0280oooo000S0?ooo`800000:03oool50:Nki`D0YK[X1@2`_nD30:g1j0`0ZKgX
0P0]Q>X201eAbP<0J8OM102a_N<40<O<gP@0fMSF103IeMD60:Vmj0800000L02Y_NP407j@fP<0Lh?E
101`QMP408RKgP80eMoN0`3Vlm<010000000i_c40<SZk@38j^d>0:Vmj0D0Y[WV1@2]`NP50:boj0@0
Z[kX1@2Y_NP00`000000oooo0?ooo`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?oo
o`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3oool00`000000oooo0?oo
o`0X0?ooo`@0Yk_W1@2V^^P50;2oi@l0ZKgX0P0]Q>X00`0aHm<07E7:06R7g@0206R7g@80/KgS1037
c=h20=7Af@80fMSF103IeMD20=7CfP80ZKgX0`00001c0:Vmj0<0OY3J101cPmD307f>f@D0XK3R0`3V
lm<20>Kla00400000038j^d0b>[]0<SZk@T0ZKgX1@2S^>L50:JiiP80[L7X0`2]`^T40:boj0D0Z[gX
102Y_NP00`000000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0
oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool5
0:Nki`@0Y[[X1@2c`^D>0:Vmj080;HCZ0P0aHm<406R7g@@0alcN103AdMT40=WEe@80dM?J0`00001f
0:Vmj0@0OY3J0`1cPmD407f>f@<0XK3R0`31d>H0103Vo<@0b>[]0<SZk@0000030<SZk@X0ZKgX1@2S
^>L40:JiiPD0[L;Y1@2[_^P50:Zmj0@0ZKgX0P00000Q0?ooo`00303oool01`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool0203oool00`2oM000M;oo0?ooo`050?ooo`800000;03oool50:Nki`D0Z;_W
102c`^D>0:Vmj0040013a@0]Q>X0<F?C035Sd`@0TJOT0P37c=h40=7Af@<0e]7D00D0dM?J00000000
000000000=7CfP030<K?hG80ZKgX102<V]`307V4dP@0Lh?E101mS]T0102Q/>80`M3V0<7@iP31d>H2
0=cagP80gok600<0ZKgX0000002Y_NP0302Y_NP40:>hi`D0[<3X0P2]`^T30:c0j@D0ZkkX2@2Y_NP0
0`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0203o
ool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02`0oooo0P2W^nL30:Nji`D0Z;_W102`
`nP>0:Vmj0040013a@0aHm<0<F?C035Sd`@0TJOT103AdMT20=KAe0<0000000<0em3B0=7CfP3AdmX0
1@36cn5b0:Vmj0<0S9[L101iQ=8307^8e@@0OHkI0`31d>H20=cagP80gok60P3Ann800`2Y_NP00000
0:Vmj00;0:Vmj0D0XkGU102/`>P60:c0j@80ZkkX0`2Z_^P80:Vmj0030000003oool0oooo01l0oooo
000<0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`070?oOW01804P0W=oo0?oo
o`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo02`0oooo1P2W^^L20:Rki`<0[KgU102``nP=
0:Vmj08004?50P1DP>060:nkhP050=KAe000000000000000003FdM@0103Gd=840<K?h@<0^lWUL@2Y
_NP308bJg0@0NHCB101kR=D409:QgP<0g?7N0P3Oo/H40=7khP030000002Y_NP0ZKgX00H0ZKgX1@2V
^nP40:>ei@D0[L;Y1@2/`>T50:Znj0T0ZKgX00<000000?ooo`3oool07P3oool000`0oooo00L0omnL
04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P0000000`1d_ol0oooo
0?ooo`050?ooo`030000003oool0oooo02h0oooo102W^^L60:fmi@80/<?X0`2/_nP90:Vmj0<0NJcc
00@004W90013a@1DP>00E83P0`2_^n83000000030<75g@3FdM@0e]7D00@0em3B0`3GcM060;_9iF`0
ZKgX1@2AV]P207j5d0@0NHCB101kR=D209:QgP@0/L?W00<0gok60=7khP3Ann801@2Y_NP00`000000
ZKgX0:Vmj0060:Vmj0D0Y[_X102[_^P50:g2j@D0ZkoX102Z_^P:0:Vmj0030000003oool0oooo01d0
oooo000<0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`030?oog`2LB4P0W=oo
00T0oooo0P00000a0?ooo`@0Z;[W1@2]_ND60:boj0T0ZKgX0`1i[?<00`00BLT0E83P05B0h0030000
00D0`LGM103Gd=830=O=d080e/[>1@2kbNE]0:Vmj0@0TI[H0`1nQM0307j7dP@0NhSE1@2a`nL20=;_
iP030=Coa@3Bo]/0d_kK00D0ZKgX00<000000:Vmj02Y_NP01P2Y_NP50:6bi0@0ZkkX1@2/`NT40:^o
j0D0Z[gX2@2Y_NP00`000000oooo0?ooo`0M0?ooo`00303oool01P3ooml0W4P007Boo`3oool0gia8
001d_`D0oooo00<0_g@007Boo`3oool0203oool00`000000oooo0?ooo`0a0?ooo`@0Z;[W1@2b_n<3
0:boj0`0ZKgX0P0/Q>X00`00BLT000000000000207VKi`D0`LGM0P3;b=P20=O@dP<0elg@103Fb/h5
0;;4if`0ZKgX102AV]P307j5d0@0OXOB102<V=X30;73i`80d^oV00@0e?o50=;nf`3Bo]/0d_kK1P2Y
_NP00`000000ZKgX0:Vmj0060:Vmj0@0XK;T0P2[_^P30:g2j@@0[<7Y1@2Z_^P50:Zmj0T0ZKgX00<0
00000?ooo`3oool0703oool000d0oooo00D0oono07@00000000004RL0=ooo`050?ooo`060=nLB000
000000000000000007@0_ooo1@3oool00`000000oooo0?ooo`0b0?ooo`D0ZK_V102b_n<>0:Vmj0<0
000000<03e_D0019b@1iVnL00P1iVnL30<75g@@0blSH0`3GcM050=K:cP030=C6c@2ba>L0//CW00<0
//CWJ`2Y_NP4096Jf0@0OXG@101nQm8408bHfP<0d^oV00<0e?o50=;nf`3Bo]/00P3Bo]/60:Vmj003
0000002Y_NP0ZKgX00H0ZKgX102Q/^@50:g2j@D0ZkoX1@2Z_^P>0:Vmj0030000003oool0oooo01/0
oooo000R0?ooo`800000=03oool50:VkiPD0]L3R2@2Y_NP300000080ZKgX00@004o802b4jP0?Fm@0
3e_D0`1iVnL50<_8f0<0clWD1@3Fb/h30=C6c@D0[[kVH`2Y_NP50:Veh@<0Si7A0`23Q/d407j5d0@0
OXOB1P2X^nL00`3DolD0d_kK0=;nf`0:0:Vmj0030000002Y_NP0ZKgX00D0ZKgX1@2Z_^P30:g2j@80
[<7Y1@2[_nP50:Zmj0d0ZKgX00<000000?ooo`3oool06`3oool00280oooo00<000000?ooo`3oool0
=03oool20:VkiP<0ZkcV1@2e`>850:Vmj0<000001P2Y_NP2001?b0803e_D0`2F[^L30<_8f0@0clWD
0P3Aam420=K:cP@0e<K=00<0d/?<0:jniP2^_^H00`2^_^IS0:Vmj0@0ZKGQ0`2?TM4408>6c@@0PXO@
102<U]P40:Rki`030<c`j`34nkd0a?^m0080dO_R2P2Y_NP00`000000ZKgX0:Vmj0050:6ai0D0Z[kX
1@2/`NT50:Znj0@0Z[gX3P2Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?oo
o`0d0?ooo`H0ZkcV0P2e`>830;C0h`040:Vmj00000000000000000X0ZKgX0P00ClP00`0UKml03e_D
09J^i`0209J^i`D0clWD103Aam440=C6c@<0d/?<0`2^_^H20:jjhf<0ZKgX102Y]N4308nAd@<0PhK=
1022Qm0508bFf080Z;_W00<0c?3[0<Ck_@34nkd00`3Ann8:0:Vmj0040:Vmi`000000ZKgW0:Vmi`D0
XK7T1@2]`^T20:c1j@<0ZkoX102Z_^PB0:Vmj0030000003oool0oooo00`0oooo00<0omnL04P0M02o
ool00P3oool01@3ookl0M00000000000B9`0gooo00@0oooo000R0?ooo`030000003oool0oooo03H0
oooo102[_>H30;C0h`<000003P2Y_NP00`00:Z`004o802E_g`050:Vii@80clWD103Aam420=76c`80
e<K=1@3B`l`50:jjhf80ZKgX102Y]N4308nAd@@0PhK=1022Qm0408bFf080c?3[00<0a?^m0=7khP3A
nn803P2Y_NP010000000ZKgW0:Vmi`2Y_NL50:Znj0@0[L;Y1P2[_nP20:Znj080Z[gX4P2Y_NP20000
00`0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO0?ooo`3OW4P007Bo103oool00240oooo
0P00000i0?ooo`<0[[gU0`0000020;C0h`80]<7S3P2Y_NP00`00:Z`09FoO02E_g`050:Vii@@0dLOA
103Aa/l50=;3c080dL3:0`2^^^<20;6hgUd0ZKgX1@2PWm<408b9b`<0R8O;0`27R/l408:7d0D0YkcX
00<0a_S[0:__Z02[kjP00P38j^d=0:Vmj0030::bi0000000X[;T0080X[;T102Z_^P50:c1j@D0ZkoX
1@2Z_NPB0:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo
0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h0?ooo`<000000`2^_ND5
0;C1h`T0ZKgX1@2T_>X00`00:Z`0>X7X03Z1j0050;Fnh@80dLOA103Aa/l20=73c@<0d/?<103A`<X5
0;6hgUP0ZKgX1@2Y]N440:2Od`@0S8W;0`28Ql/408N:c`@0SiSH0`2W_>P00`36n>/0ZnnX0:__Z003
0<SZk@T0ZKgX1@2Y^^H00`2R/^@000000::bi0020::bi0@0[L;Y1@2/`NT50:Znj0@0Z[gX4P2Y_NP0
0`000000oooo0?ooo`0:0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0
B02Lgol00`3oool00240oooo00<000000?ooo`3oool0=P3oool200000080oooo1@2`_^@30;C1h`<0
/l3T2@2Y_NP40:BljP03000Z[00jPNP0>X7X00D0]KkQ103Aa/l40=73c@D0dL3:0P3?_LT40;6hgUT0
ZKgX1@2Y]N440:2Od`<0S8W;1028Ql/408N:c`@0SiSH0P36n>/0102[kjP0b>[]0<SZk@38j^d<0:Vm
j0D0ZK[V00<000000::bi02Z_nP00P2Z_nP40:g2j@D0ZkoX102Z_^PG0:Vmj0030000003oool0oooo
00T0oooo00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`00
8@3oool2000003@0oooo0`0000050?ooo`D0/;kT1P2c`>@90:Vmj0@0WK[/0`0jPNP20;Fnh@<0^l7O
0P3Aa/l40=73c@80d<7<0`3A`<X40<nmb@D0][KHF02Y_NP40:Veh@@0X9oC0`2<RL/408R7b`@0Qh[?
1@2[a^h00`2hoMd0S=^>08cKSP0?0:Vmj0@0ZK[V00<0Z[oX0000002Z_nP00P2Z_nP50:c1j@@0ZkoX
1@2Z_NPG0:Vmj0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo
0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3oool5
0;6oi0<0/l3T0`2b_n@90:Vmj0@0WK[/0P17Snh60;_1g`@0dL?=103@`L`00`3A`<X0ckg90<nmb@02
0<nmb@80c[_71@2f]]QC0:Vmj0D0WiS<102CRlP408n9b080SHW;1028Ql/509FPg0<0ZlK^00<0^?gM
0:k3j@2^`nT00P2^`nT<0:Vmj0<0YkKT102T]>D00`2Z_nP000000:g2jP020:g2jP@0[<7Y1@2Z_^P5
0:Zmj1H0ZKgX00<000000?ooo`3oool01P3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool00`3oool000@0oooo00d0oono07@00000000004RL0=ooo`3o
ool0omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0oooo00D0gia8000000000000001809cOo`07
0?ooo`030000003oool0oooo02d0oooo0`00000>0?ooo`@0/KoT1P2b_n@90:Vmj0<0WK[/00@001NG
04N?kP17Snh0Aho^0`2k`Ml20;k2g@80dL?=1@3@`L`40<nmb@@0c[_70P2f]]P30;fddDl0ZKgX102W
Y=<409nHc0@0Th_8102?RLP308f9b`@0SHo@1@2EX=`0102hoMd0T>N^0<goe@3=omD40:k3j@T0ZKgX
1P2W]^@30:Bdi@80[L;Z00@000000:g2jP2]`^X0[L;Z102[_nP50:Znj1/0ZKgX00<000000?ooo`3o
ool01P3oool02`3o_g@000000000M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00@0oooo
00030?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo1@3oool00`3ooml0W4Q809cOo`030?ooo`07
0?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo02X0oooo0`00000B
0?ooo`@0/koS1@2b_n@:0:Vmj0<0WK[/00@000n904^Fl@1;U_40BiKa1@2n`]d50=31c080cko<0P3?
_LT50<jka`H0_KCA102Y]N980:Vmj0<0Z:kK0`2WY=<509nHc0@0Th_80`2?RLP308f9b`D0SHo@0P2E
X=`20;7MmP04093W[P3=omD0cOoE0<goe@h0ZKgX1@2W]^@40:_1j@030:g2jP000000[L;Z00<0[<7Y
102[_nPK0:Vmj0<0000000<0oooo0000003oool0203oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0103oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo
00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`800000:@3oool30000
01H0oooo102c_n<50;6oi0X0ZKgX0`2M^^`010003hT0BiKa04^Fl@1;U_430;k2g@<0_/?N0P3@`L`4
0<noc0D0c[_70P3=^LL40;fdd@80a;?9102Y]N950:Vmj0D0Z:kK102WY=<409nHc0@0Th_80`2?RLP4
08f9b`@0SHo@0`2agOH20<goeA80ZKgX1@2V^NH40:_1j@030:c1j@000000[<7Y0080[<7Y1@2Z_^PF
0:Vmj0<000001@3oool00`000000oooo0?ooo`0E0?ooo`000`3oool01`3ogi`0B4RL0=ooo`3oool0
oono07@0B02Lgol01@3oool00`3o_g@004RL0=ooo`070?ooo`030;md001d_ol0oooo00@0oooo00<0
00000?ooo`3oool09@3oool3000001X0oooo1@2c_n<40;6oi0T0ZKgX1@2T_>X00`003hT0@iOb04>G
lP060;k3gPD0cko<00@0cKk<0<jka`3>^lL0c[_7103=^LL20;fdd@@0a;?9102^Z]=00:Vmj0D0ZKGQ
1@2X[]/30:NTd`@0WiS<102CRlP308n9b0@0SHW;1P2N/NH010000000^M;]0;WBk@2id^d=0:Vmj0D0
Y;?S102V^NH50:c2jP030:c1j@000000Z[kX00H0Z[kX4`2Y_NP3000000P0oooo00<000000?ooo`3o
ool05@3oool000<0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0
B02Lgol00P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?oo
o`0R0?ooo`<000007@3oool60;>oh`@0/KkT2@2Y_NP30:BljP<0ZKgX0P13Uo830;k3gP<0^lCP0`3?
_l`30<fnc0030<jka`3=^LL0cKW700<0cKW71@34/lT20<Rba@@0[Z[C1@2Y]N8g0:Vmj0@0ZKWT1@2Y
]N440:R^f`@0VHg5102FS<H409><b@<0TY3>102DV]L309jaiP030:Sfk@2id^d0^M;]00<0^M;]2@2Y
_NP50:Vji@@0Y;?S2@2/`^X20:Znj0030000002Z_^P0Z[kX00<0Z[kX402Y_NP4000000`0oooo00<0
00000?ooo`3oool0503oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo
00H0gia8001d_`3oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo00<000000?oo
o`3oool07`3oool300000240oooo1P2c_n<40;6ni0l0ZKgX0P0ZS^h60;_4h0030<noc03=_/`0cKk<
0080cKk<1@3=^LL20<bha`<0a;?91038//D20:jZd`80_:c:1@2Y]N8b0:Vmj0T0ZKWT1@2NT<@409b>
a@<0VHg5102FS<H409><b@@0TY3>102DV]L20:Sfk@<0_okJ3@2Y_NP50:Vji@@0ZKkX1@2/`^X40:_0
j@030:Znj0000000Z[kX0080Z[kX3P2Y_NP0103oool0000000000000000@0?ooo`030000003oool0
oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d
04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`8000007P3oool2000002D0oooo1P2c_n<50;:nh`d0
ZKgX00<002>S02Z>kP0ZS^h01@2ka>040<fnc080bko?0`3=^LL40<bha`030<Bcb@38//D0b;;500<0
b;;51@2l[<X50:bTcbh0ZKgX102Y]N450:Vii0@0XI74102NT<@409b>a@@0VHg5102FS<H309><b@@0
TY3>1@2Xe_PB0:Vmj0D0Y;GU102Y_^P50:c2jP@0Zl3Y00<0Z[gX0000002Z_NP00P2Z_NP90:Vmj080
oooo0`00000C0?ooo`030000003oool0oooo01@0oooo00030?ooo`060?oog`2LB000M;oo0?ooo`3O
W4P007Bo203oool01P3o_g@004RL0=ooo`3oool0_g@007Boo`P0oooo0P00000L0?ooo`<00000:@3o
ool30;>oh`80/koT1@2b_^<=0:Vmj003001?b000Mm/007OK00D0]/GV0P3=_/`40<^oc`030<fia`3<
^<L0c;S700<0c;S71@38//D20<Rba0@0_:c:00<0a:g30:bTc`2/Y<l00`2/Y<l40:NUdbD0ZKgX1@2X
[]/40:Veh@D0Xi;30`2QTL@509j@a0<0W8k5102ISLD409J<aP<0Thc91@2N/nL30:SFn0l0ZKgX1@2W
]>840:Bei@T0[<;Z1@2Z_^P0102Z_NP000000:Zmj02Z_NP70:Vmj0@000005P3oool00`000000oooo
0?ooo`0D0?ooo`00103oool01@3ookl0M00000000000B9`0gooo00@0oooo00<0gia8000000000000
0`0000000`1d_ol0oooo0=nLB003000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool0
5`3oool3000002d0oooo1@2c_n@50;:nh`d0ZKgX00<004o8001gf`00Mm/01@2faNH50<^oc`D0c;S7
0P3:^<P30<Rba@<0b;;40`2l[<X20<B]``@0[:C?0P2mZ<@40:NUd`D0YjOF5@2Y_NP20:Veh@@0ZKgX
1@2WY=<40:R^f`80ZKGQ0`2VTl840:>B``@0XI74102NT<@309b>a@@0VHg5102FS<H409ZPf@D0W[?W
3P2Y_NP40:Vji@D0YkCR102[`NX50:c2jP@0ZkoY102Z_^P00`2Y_NP000000:Vmj0060:Vmj0800000
6P3oool00`000000oooo0?ooo`0D0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`<00000<@3o
ool30;>oi080//3T1@2b_^<=0:Vmj080;8CZ00<004^`0:W8l02Yb?000`2Yb?030<^oc`<0b<7D0P3<
^<L40<Zhb0030<Rba@38//@0b;;400<0b;;400<0_:c:0<B]``34[L<00P34[L<20:bTc`@0_JS40P2W
YM<20;JTaPD0YjOF102WYM<50:Vmj0@0ZKGQ1@2Y_NP50:Veh@80ZKgX0P2UV/X50:NTd`<0Z:kK1@2V
Tl840:>B``@0XI74102NT<@409bBb0@0VY?;102IUm0409ZPf@80QncJ0P38jNd?0:Vmj0@0ZK[U0P2W
]>830:Rmj0@0Zl7Z1@2[`NT40:^oj@D0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00000M0?ooo`030000
003oool0oooo01@0oooo000O0?ooo`8000004`3oool3000003D0oooo1@2b`>@20;:nh`<0/koR3@2Y
_NP302b4jP03001;/02Yb?00ZLS`0080ZLS`1P38`M@50<Zhb0H0b;;41@34[L<60;fXa0D0]ZC60P2W
YmH30;>Qa@@0YjGC1@2VWLd40:Veh@D0Yj;A102Y]N440:FJbPD0YjCC102XU<850:JC`P<0Xi;3102Q
TL@509nBaP<0W9;8102JTl/509VGd080VZ3I00<0W^Ol0<SYk@38jNd00`38jNd>0:Vmj0@0ZK[U1@2X
_NP50:c2jP@0Zl7Y1@2Z_^P40:Vmj0<00000803oool00`000000oooo0?ooo`0D0?ooo`007`3oool0
0`000000oooo0?ooo`0?0?ooo`<00000>@3oool40;;0i0H0/koR3@2Y_NP407V/l`@0R/Sl1038`M@2
0<;7gP<0b[S80P39_<h40<Rba080akC70`34[L<20<F^a0@0_JS40P31Z/<40;JTaPH0/j750P2WYM<2
0;BO``D0YYg=102YV<D40:NRd@D0Z9K3102UV/X20:NTd`<0ZYK10`2XU<850:JC`P<0Xi;31@2QT/D4
09nBaP@0W9;8102JTl/409VGd00409kWo02Rm]d0X_KM0:;fg@l0ZKgX102W/n840:Fei080Z;gX1`2/
`^X90:Znj0<000000`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo000O
0?ooo`030000003oool0oooo00`0oooo0`00000m0?ooo`@0/<3V0`2c_n830;BohQ80ZKgX0`2:b?`2
0<S1e0@0`/ON00<0b[S80<VlcP39_<h00P39_<h20<Rba0@0akC700<0a:g30<F^a035[/@00P35[/@2
0;fXa0<0`J[30`2fY<H20;jW`PD0/j75102dWl<40:JMc@80]Yo1102YV<D20:NRd@80/I_11@2XU/<3
0:FJbPD0ZYK1102XU<840:JC`P@0Y9C4102QT/D509nBaP<0W9;8102JTl/40:?>mP030:;fg@2Y_NP0
ZKgX00h0ZKgX0`2Y]n<40:NchP<0YKGT1P2/`^X40:^oj0D0Z[kX0`0000060?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3oool30000
0440oooo102``>H60;BohPD0ZK_V3@2Y_NP00`009J@0>:cc0<;7gP050<;7gPD0bKc>1P37]<L50<F^
a0H0`J[300@0]ZC60;jW`P2nYl80_ZO2102cXLD20;bT`P@0]9o30P2VWLd30;JO`@@0ZIS5102aVl45
0:RF``@0[IS11@2ZU/430:RD`PD0YYK40`2TU<@50:6Ba@@0Wi;60`2LT/P60::kja40ZKgX1@2Y]n<4
0:NchP@0Zl7Z0`2/`^X30:^oj@@0ZkoX1000000:0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool04`3oool001h0oooo0P0000090?ooo`800000A@3oool50:k0i`<0];oR0P2e`><50:Vk
iPd0ZKgX0P0]Q>X00`170000/=7b0;3AlP030;3AlP<0bKc>0P34aMX40<Nda`80ak_?1035[/@00`35
]<X0`J[30<6Z``030<6Z``D0_ZO20P2cXLD30;bT`P@0]9o31@2fWl420:VHa@<0]9k1102aVl420:RF
``<0/9_20`2]V<450:ZF`@80Z9C20P2YV<D40:JFa0@0Y9C4102QT/D50:BZf`<0X[3Q0`2R^n/?0:Vm
j0D0ZK_V102Y]n<50:Vnj@@0Zl7Z1@2[_nT0103oool0000000000000000?0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3oool30000
04P0oooo1@2^`>L50;G0h`D0ZkWT3@2Y_NP309NgkPD0/=7b00<0bKc>0<C5fP34aMX00P34aMX20<Nd
a`<0ak_?0`35[/@20<FdbP@0`J[30P33/<L40;jW`PH0_:C20P2dWl<20;ZS`P@0]Yo11@2dW/440;6K
`@D0/9_2102]V<440:ZF`@@0ZIS51@2VU/@30:BDa0D0YJSH102TZ]/40::`h@030:k4j@2Y_NP0ZKgX
00l0ZKgX1@2Y^nH40:NiiP@0ZKkY1P2/`>T0103oool0000000000000000C0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool00P3oool30000
04`0oooo1@2[`>T30;G0h`80/l3T1@2[^N@=0:Vmj0<0UkO^102`dO850<C5fPH0ak_?00<0aJk40<Fd
bP35]<X00P35]<X20<6Z``<0`k370`2nYl820<2]a`D0_:C2102jXl830;JO`@80^:C51@2dW/420;6K
`@80/j351@2`Vl830:fH`@D0[9c6102YV<D40:JFa0@0Z:WH1@2UZ=P30:BZf`80GMG<0`2^a>TB0:Vm
j0D0YK?R102W^NH70:c0j@<000005P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01<0oooo000N0?ooo`030000003oool0000000800000D@3oool40:_0j@D0/l3T1@2`_><A0:Vmj0<0
IL[l0`34aMX20;7Gm0D0ak_?1@35]<X60<>`a`040;jW`P30[LL0`:g70<2]a`@0_:C20P2n[LT40;ZS
`P040;JO`@2hY<D0^:C50;RTa@D0]9k100@0/I_10;>Pa@2cX<D0/j351@2`Vl820:fH`@80/:;:102/
W<H40:VHa@80YYK40`2[[MT40:RYf0@0YJSH00<0KmoS0:o9kP2_bNh00P2_bNhA0:Vmj0D0Yk;O102U
/n850:^oj0@0[<3Y00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01<0oooo000N0?ooo`800000E@3oool40:W0jP<0/l3T0P2]`>L50;2lh`@0ZK[V3@2Y_NP3
0:FljPD0/MOd0P37^ll30<7=i0<0aKC:0P33aM/50<>`a`D0`:g70P2lY<830;j]b@@0^Z?21@2hY<D4
0;BN`@D0/j35102`Vl840;2RbPD0[9c60`2YV<D60:^]f@<0Z:WH0P1hh^d30:S8l180ZKgX102Y/]l5
0:Nbg`@0ZkkW102[_nP2000001l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003oool0oooo05@0oooo102Y`>X50:g0
i`80/;cS0`2b_n<40:VjiPd0ZKgX102U_>X30;7Gm0H0`LgT1@33aM/20<>`a`<0`l7I1030[LL50;j]
b@80^Z?20`2m/<h40;RTa@80]9k10`2hZ//40;>Pa@80/9_20`2cZm040;2RbP@0[9c6102^]=d50:^]
f@<0M^7/0P2S`>hA0:Vmj0D0ZK?P102Y/]l50:ZliP@0ZkkW00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00X0
oooo0P00001E0?ooo`@0Z;oZ102]`>L60;:oh`@0[;WS4P2Y_NP307Z/l`D0Omgl1033aM/60<?1f@80
`:g70P31`]/40;j]b@D0_K3>102hY<D50;RZb`@0/j351@2cZm040;2RbPD0/;oU102^]=d506KJhA80
ZKgX102Y]>440:Vch0D0ZKWU102Z_>H2000002L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0<0?ooo`030000003oool0oooo05<0oooo
202X_nX30;:oh`<0/<3V102/^N<50:VjiQ40ZKgX101ogO`409[So@D0`l7I1@31`]/20;j]b@80_/[T
1@2m/<h20;RTa@80^k_I1@2hZ//20;>Pa@80]kcM1@2cZm020;2RbP80[m7b102`_nD20:jdgAD0ZKgX
1@2Y]N440:Vdh@@0ZKOS1@2Y^ND2000002/0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05<0oooo1@2W
_n/30:RojPH0/<3V102a_^<50:VjiQH0ZKgX0`2Jhod509_Uo0@0`L;K1@2nb^@40;f`cPD0^k_I102h
Z//50;Nlg@@0/j_@1@2_dO830;2oiA@0ZKgX102Y]^840:Veh@D0Z;GR102Y]n<200000300oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0>
0?ooo`030000003oool0oooo05@0oooo102W_^X50:Fnj`@0ZKoY102a_^<50:bihQX0ZKgX102KiO`4
087Sm`@0_/[T1@2cgOD40;^kf@D0/mSc102g_=d509_Vo1L0ZKgX2@2Y]^840:Rdh@D0Z;GR0P2Y]n<c
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0
M02oool03`3oool00`000000oooo0?ooo`1D0?ooo`@0YkkZ1@2U_N/40:Voj@@0/<3V1@2/^N840:Vg
haX0ZKgX1021hoL5036i`P@0/mge1@1[g>P40;?Hl`030433a@2Y_NP0ZKgX01T0ZKgX102Y]N440:Vf
hPD0ZK?P102X]>440:RehSH0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?oo
o`004@3oool01@2oM000001809boW01807@0_ooo0100oooo0P00001E0?ooo`@0YkkY1@2U_N/40:Fn
j`@0/<3V1@2b_n<40:Vgh`@0ZK[U@`2Y_NP50:Vdh@@0ZKGQ0P2Y]^860:Vch0@0Z;CQ>`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oo
oa80oooo00<000000?ooo`3oool0D`3oool40:Nnj@D0YKg[102U_^/40:VojPD0/[oS102__><40:Vj
i@D0ZKgW>P2Y_NP40:Vch0@0ZKCQ102Y]N480:Vch400oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0C0?ooo`030000003oool0oooo05<0
oooo102X_NT50:Fmj`@0YKk[102Y_nX50:g0j0@0[kcS102/^>850:Vmi`D0ZKgX102Y_NL^0:Vmj0<0
ZK;O102Y/n030:Vdh@D0Z[CP102Y/n130?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04@3oool002X0oooo00<000000?ooo`3oool0D`3oool40:Rmj@D0Y[gY102U_^/40:Fnk0D0[L3X
102``>H40:bhhPD0Z[KQ1@2Y]N440:Vmi`@0ZK[U7`2Y_NP40:VkiP@0ZKgX1@2Y/]l40:Vch0@0Z[KQ
102Z]>180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool002/0oooo0P00
001D0?ooo`@0ZKgX1@2V_NT40:JmjP@0YKk/1@2V_n/40;30iP@0//3T0`2Z]^420;;0i0D0ZKGQ102Z
]N440:Vji@D0ZKOS102Y_NP40:Vji@D0ZKgX102Y^^D40:Vmj0D0ZKOS102Y^nH80:Vbg`D0ZkSS102Z
]^5<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool002d0oooo00<00000
0?ooo`3oool0DP3oool40:Vmj0D0Z;gY102V_NX40:Fnj`D0Y[o[102X`>/90;;0i080ZKGQ0`2b`>@4
0:Zeh@@0[;SR1@2Y]n<40:Veh@@0ZK[U1@2Y]N840:Vji@@0ZKCQ102Y]n<50:^eh0@0ZK;O102Z^N@5
0:^hhdl0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`00;P3oool00`00
0000oooo0?ooo`1B0?ooo`@0ZKgX1@2X_NT40:Nmj@T0YKk[102X`>/40:W0j`X0//3T0P2Z]N420;30
iP@0[;SR1@2__><40:Veh@@0[;SR102Y]N850:bhhP@0ZKCQ102^^n<40:^eh0D0Z[cV102Z^NAD0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool002l0oooo00<000000?ooo`3o
ool0DP3oool40:Vmj0D0Z;gX102W_NT40:NmjPD0YKk[102U_n`40:W0j`@0ZL7[1@2b`>@50;30iP@0
[L7X102__><50:noiP@0[;SR102__nH40:bhhPD0[;oW102^^n<40:Vmj0D0Z[cVF03oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000`0?ooo`030000003oool0oooo0580oooo
102Y_NP90:Rmj0@0YkgZ1@2V_NX80:Fok0@0ZL7[1P2X`N/40:O1k0@0[L7X102Z`N/50:noiP@0Zl7Z
102__nH40:[1j`D0[;oW102X_^T40:Vmj0030000003oool0oooo05X0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0oooo2@2Y_NP40:Rmj0@0Z;gY102V
_NX60:JnjP<0YKo/2P2V_n`40:O1k0@0Yl3/102Z`N/50:O1k0@0Zl7Z102X`N`40:[1j`D0YkoZ102X
_^UP0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool003<0oooo00<00000
0?ooo`3oool0D@3oool=0:Vmj0h0Z;gY102V_^X40:NnjP@0Y[o/1@2V_n/40:O0k0@0Y/3/102W`N`5
0:O0k0@0Z<7/102W_^/40:NojP030000003oool0oooo0680oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`00=03oool00`000000oooo0?ooo`1A0?oooaH0ZKgX2@2X_NT80:Nn
jPD0Y[o[102W_^/40:K0k0@0Yko[1@2W`>`40:NnjP@0Ykk[J@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo000e0?ooo`030000003oool0oooo0540oooo6`2Y_NP80:Rmj@@0
YkkZ1@2X_^T40:Nnj`@0YkkZ102W_n/50:Rnj@@0YkkZK03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo000f0?ooo`800000DP3ooolO0:Vmj0@0Z;gY102X_NP90:Rnj@@0YkkZ
1@2X_NT30:Rnj@030000003oool0oooo06h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`00>03oool00`000000oooo0?ooo`1@0?ooob<0ZKgX102X_NP40:Vmj0D0Z;kY1@2Y
_NP3000007D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`00>@3oool0
0`000000oooo0?ooo`1A0?ooobl0ZKgX00@0oooo0000000000000000N@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo000j0?ooo`030000003oool0oooo0540oooo:`2Y_NP4
000007`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>`3oool00`00
0000oooo0?ooo`1A0?ooobL0ZKgX0`0000210?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03`3oool003`0oooo0P00001B0?ooob80ZKgX00@0oooo0000000000000000Q@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo000n0?ooo`030000003oool0oooo0500
oooo7P2Y_NP4000008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00
?`3oool00`000000oooo0?ooo`1@0?oooaX0ZKgX0`00002=0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool00400oooo00<000000?ooo`3oool0D03ooolF0:Vmj0<00000T@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00110?ooo`800000D@3ooolB
0:Vmj0<00000U@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00130?oo
o`030000003oool0oooo04l0oooo3@2Y_NP3000009T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0?0?ooo`00A03oool00`000000oooo0?ooo`1@0?ooo`P0ZKgX0`00002M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0
D03oool40:Vmj0<00000X@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
00160?ooo`800000D@3oool200000:H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`00B03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00B@3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`00BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0>0?ooo`00B`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00C03o
ool2000004/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00h0oooo001>0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo001?0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo001@0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo001A0?ooo`800000AP3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool005<0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`2/0?ooo`050000003oool0oooo0?ooo`000000
3`3oool005@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2^0?ooo`040000003o
ool0oooo000000l0oooo001E0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0[P3o
ool010000000oooo0?ooo`00000?0?ooo`00EP3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`0000003`3oool005L0oooo0P00000o0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`0000003P3oool005T0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`2a0?ooo`8000003P3oool005X0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`2a0?ooo`8000003P3oool005/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`2a0?ooo`8000003P3oool005`0oooo0P00000j0?ooo`030000003oool0oooo0:d0oooo1000
000@0?ooo`00GP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:T0oooo1000000D
0?ooo`00G`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0:D0oooo1000000H0?oo
o`00H03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:40oooo1000000L0?ooo`00
H@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo09h0oooo0`00000P0?ooo`00HP3o
ool2000003@0oooo00<000000?ooo`3oool0VP3oool4000002<0oooo001T0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0UP3oool4000002L0oooo001U0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0TP3oool4000002/0oooo001V0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0SP3oool4000002l0oooo001W0?ooo`800000;`3oool00`000000oooo
0?ooo`2:0?ooo`@00000<`3oool006T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`270?ooo`<00000=`3oool006X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`23
0?ooo`@00000>P3oool006/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1o0?oo
o`@00000?P3oool006`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1k0?ooo`@0
0000@P3oool006d0oooo0P00000Y0?ooo`030000003oool0oooo07L0oooo100000160?ooo`00K`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo0`00001:0?ooo`00L03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0740oooo1000001=0?ooo`00L@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001A0?ooo`00LP3oool2000002<0
oooo00<000000?ooo`3oool0J@3oool4000005D0oooo001d0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0I@3oool4000005T0oooo001e0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0HP3oool3000005d0oooo001f0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0GP3oool400000600oooo001g0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0FP3oool4000006@0oooo001h0?ooo`8000007@3oool00`000000oooo0?ooo`1F0?ooo`@0
0000J03oool007X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`@00000
K03oool007/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1>0?ooo`@00000L03o
ool007`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`<00000M03oool0
07d0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000001g0?ooo`00O`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000001k0?ooo`00P03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000001o0?ooo`00P@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo03/0oooo100000230?ooo`00PP3oool2000001<0oooo00<00000
0?ooo`3oool0>03oool3000008L0oooo00240?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0=03oool4000008X0oooo00250?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0<03oool4000008h0oooo00260?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
;03oool400000980oooo00270?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03o
ool4000009H0oooo00280?ooo`8000003@3oool00`000000oooo0?ooo`0U0?ooo`<00000VP3oool0
08X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`@00000W@3oool008/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000X@3oool008`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000Y@3oool008d0oooo0P00
00070?ooo`030000003oool0oooo01H0oooo1000002Y0?ooo`00S`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0180oooo1000002]0?ooo`00T03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00l0oooo0`00002a0?ooo`00T@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo1000002d0?ooo`00TP3oool01@000000oooo0?ooo`3oool0000000T0
oooo1000002h0?ooo`00T`3oool2000000030?ooo`000000oooo00@0oooo1000002l0?ooo`00U@3o
ool2000000030?ooo`000000000000800000`03oool009H0oooo0P0000340?ooo`00o`3ooomM0?oo
o`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?oo
o`00o`3ooomM0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.4518 .5772 .45789 .58312 .46854 .57992 .46248 .57398 Mtetra
.46248 .57398 .46854 .57992 .47922 .57671 .47319 .57074 Mtetra
.663 .741 .908 r
.47319 .57074 .47922 .57671 .48995 .57348 .48394 .56751 Mtetra
.662 .741 .908 r
.48394 .56751 .48995 .57348 .50072 .57027 .49474 .56428 Mtetra
.661 .741 .91 r
.49474 .56428 .50072 .57027 .51154 .56706 .50558 .5611 Mtetra
.658 .742 .912 r
.50558 .5611 .51154 .56706 .52239 .5639 .51647 .55797 Mtetra
.655 .743 .914 r
.51647 .55797 .52239 .5639 .53329 .5608 .5274 .55491 Mtetra
.654 .745 .917 r
.5274 .55491 .53329 .5608 .54424 .55778 .53837 .55188 Mtetra
.654 .745 .916 r
.53837 .55188 .54424 .55778 .55523 .55484 .54939 .54881 Mtetra
.659 .743 .912 r
.54939 .54881 .55523 .55484 .56627 .55191 .56045 .54562 Mtetra
.666 .737 .903 r
.56045 .54562 .56627 .55191 .57735 .54892 .57156 .5422 Mtetra
.673 .727 .89 r
.57156 .5422 .57735 .54892 .58848 .54579 .58271 .53854 Mtetra
.678 .714 .876 r
.58271 .53854 .58848 .54579 .59965 .54245 .59389 .53464 Mtetra
.673 .699 .865 r
.59389 .53464 .59965 .54245 .61086 .5389 .60512 .53085 Mtetra
.662 .689 .865 r
.60512 .53085 .61086 .5389 .62211 .53516 .6164 .52744 Mtetra
.663 .699 .873 r
.6164 .52744 .62211 .53516 .6334 .53133 .62773 .52401 Mtetra
.664 .71 .883 r
.62773 .52401 .6334 .53133 .64473 .52748 .63911 .52058 Mtetra
.664 .723 .893 r
.63911 .52058 .64473 .52748 .65611 .52372 .65053 .51712 Mtetra
.664 .734 .902 r
.65053 .51712 .65611 .52372 .66754 .52009 .662 .51366 Mtetra
.664 .74 .906 r
.662 .51366 .66754 .52009 .67902 .51663 .67351 .51018 Mtetra
.67351 .51018 .67902 .51663 .69056 .51335 .68508 .50668 Mtetra
.664 .734 .902 r
.68508 .50668 .69056 .51335 .70215 .51021 .69669 .50317 Mtetra
.664 .723 .893 r
.69669 .50317 .70215 .51021 .71381 .50715 .70834 .49965 Mtetra
.664 .71 .883 r
.70834 .49965 .71381 .50715 .72551 .50407 .72005 .49611 Mtetra
.663 .699 .873 r
.72005 .49611 .72551 .50407 .73726 .50091 .7318 .49256 Mtetra
.652 .685 .868 r
.7318 .49256 .73726 .50091 .74904 .49755 .74363 .48938 Mtetra
.648 .689 .874 r
.74363 .48938 .74904 .49755 .76087 .49398 .75552 .48633 Mtetra
.655 .706 .885 r
.75552 .48633 .76087 .49398 .77272 .4902 .76744 .48303 Mtetra
.662 .724 .895 r
.76744 .48303 .77272 .4902 .78462 .48627 .7794 .47948 Mtetra
.669 .738 .902 r
.7794 .47948 .78462 .48627 .79655 .48227 .7914 .4757 Mtetra
.672 .747 .907 r
.7914 .4757 .79655 .48227 .80854 .47829 .80343 .47179 Mtetra
.673 .751 .909 r
.80343 .47179 .80854 .47829 .82058 .47438 .8155 .46784 Mtetra
.671 .75 .91 r
.8155 .46784 .82058 .47438 .83268 .47055 .82763 .46392 Mtetra
.669 .747 .909 r
.82763 .46392 .83268 .47055 .84484 .46678 .83982 .46007 Mtetra
.667 .745 .908 r
.83982 .46007 .84484 .46678 .85705 .46306 .85207 .45627 Mtetra
.665 .742 .908 r
.85207 .45627 .85705 .46306 .86931 .45935 .86437 .45251 Mtetra
.664 .742 .908 r
.86437 .45251 .86931 .45935 .88163 .45563 .87672 .44875 Mtetra
.664 .741 .907 r
.87672 .44875 .88163 .45563 .89401 .45191 .88913 .445 Mtetra
.88913 .445 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57447 Mtetra
.43501 .57447 .44117 .58041 .4518 .5772 .44567 .57124 Mtetra
.44567 .57124 .4518 .5772 .46248 .57398 .45637 .56799 Mtetra
.663 .741 .908 r
.45637 .56799 .46248 .57398 .47319 .57074 .46711 .56476 Mtetra
.662 .741 .909 r
.46711 .56476 .47319 .57074 .48394 .56751 .47789 .56155 Mtetra
.659 .742 .911 r
.47789 .56155 .48394 .56751 .49474 .56428 .48871 .55839 Mtetra
.656 .744 .915 r
.48871 .55839 .49474 .56428 .50558 .5611 .49958 .5553 Mtetra
.653 .747 .919 r
.49958 .5553 .50558 .5611 .51647 .55797 .5105 .55227 Mtetra
.655 .752 .921 r
.5105 .55227 .51647 .55797 .5274 .55491 .52145 .54917 Mtetra
.662 .753 .918 r
.52145 .54917 .5274 .55491 .53837 .55188 .53246 .54586 Mtetra
.675 .749 .906 r
.53246 .54586 .53837 .55188 .54939 .54881 .5435 .54218 Mtetra
.684 .733 .887 r
.5435 .54218 .54939 .54881 .56045 .54562 .55459 .53815 Mtetra
.663 .703 .877 r
.55459 .53815 .56045 .54562 .57156 .5422 .56572 .53477 Mtetra
.663 .705 .878 r
.56572 .53477 .57156 .5422 .58271 .53854 .5769 .53137 Mtetra
.664 .713 .885 r
.5769 .53137 .58271 .53854 .59389 .53464 .58812 .52797 Mtetra
.664 .729 .897 r
.58812 .52797 .59389 .53464 .60512 .53085 .59939 .52454 Mtetra
.664 .741 .907 r
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .74363 .48938 .73826 .48236 Mtetra
.664 .729 .897 r
.73826 .48236 .74363 .48938 .75552 .48633 .75014 .47875 Mtetra
.664 .713 .885 r
.75014 .47875 .75552 .48633 .76744 .48303 .76208 .47513 Mtetra
.663 .705 .878 r
.76208 .47513 .76744 .48303 .7794 .47948 .77406 .47149 Mtetra
.644 .696 .883 r
.77406 .47149 .7794 .47948 .7914 .4757 .78615 .4685 Mtetra
.654 .723 .899 r
.78615 .4685 .7914 .4757 .80343 .47179 .79827 .46517 Mtetra
.665 .746 .911 r
.79827 .46517 .80343 .47179 .8155 .46784 .8104 .46145 Mtetra
.671 .757 .915 r
.8104 .46145 .8155 .46784 .82763 .46392 .82257 .45752 Mtetra
.672 .758 .915 r
.82257 .45752 .82763 .46392 .83982 .46007 .83479 .45351 Mtetra
.67 .753 .912 r
.83479 .45351 .83982 .46007 .85207 .45627 .84706 .44956 Mtetra
.668 .748 .91 r
.84706 .44956 .85207 .45627 .86437 .45251 .85939 .44567 Mtetra
.666 .744 .909 r
.85939 .44567 .86437 .45251 .87672 .44875 .87178 .44184 Mtetra
.665 .742 .908 r
.87178 .44184 .87672 .44875 .88913 .445 .88422 .43804 Mtetra
.664 .741 .907 r
.88422 .43804 .88913 .445 .9016 .44123 .89672 .43423 Mtetra
.89672 .43423 .9016 .44123 .91411 .43744 .90928 .43041 Mtetra
.90928 .43041 .91411 .43744 .92668 .43364 .92189 .42658 Mtetra
.92189 .42658 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57173 Mtetra
.41817 .57173 .4244 .57769 .43501 .57447 .42881 .56849 Mtetra
.664 .741 .908 r
.42881 .56849 .43501 .57447 .44567 .57124 .43949 .56524 Mtetra
.663 .741 .908 r
.43949 .56524 .44567 .57124 .45637 .56799 .45022 .562 Mtetra
.661 .741 .909 r
.45022 .562 .45637 .56799 .46711 .56476 .46098 .5588 Mtetra
.658 .742 .912 r
.46098 .5588 .46711 .56476 .47789 .56155 .47179 .55567 Mtetra
.654 .745 .917 r
.47179 .55567 .47789 .56155 .48871 .55839 .48264 .55263 Mtetra
.653 .749 .921 r
.48264 .55263 .48871 .55839 .49958 .5553 .49354 .5496 Mtetra
.659 .754 .92 r
.49354 .5496 .49958 .5553 .5105 .55227 .50448 .54638 Mtetra
.674 .753 .91 r
.50448 .54638 .5105 .55227 .52145 .54917 .51547 .54271 Mtetra
.685 .738 .891 r
.51547 .54271 .52145 .54917 .53246 .54586 .5265 .53867 Mtetra
.664 .711 .883 r
.5265 .53867 .53246 .54586 .5435 .54218 .53757 .53529 Mtetra
.664 .721 .891 r
.53757 .53529 .5435 .54218 .55459 .53815 .54869 .5319 Mtetra
.664 .741 .907 r
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.59361 .51819 .59939 .52454 .6107 .52111 .60495 .51472 Mtetra
.60495 .51472 .6107 .52111 .62206 .51766 .61635 .51125 Mtetra
.61635 .51125 .62206 .51766 .63347 .51419 .62778 .50776 Mtetra
.62778 .50776 .63347 .51419 .64492 .51071 .63927 .50425 Mtetra
.63927 .50425 .64492 .51071 .65642 .50722 .6508 .50073 Mtetra
.6508 .50073 .65642 .50722 .66797 .50371 .66238 .4972 Mtetra
.66238 .4972 .66797 .50371 .67956 .50019 .67401 .49365 Mtetra
.67401 .49365 .67956 .50019 .6912 .49665 .68568 .49009 Mtetra
.68568 .49009 .6912 .49665 .70289 .4931 .69741 .48651 Mtetra
.69741 .48651 .70289 .4931 .71463 .48954 .70918 .48292 Mtetra
.70918 .48292 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .78615 .4685 .78085 .46104 Mtetra
.664 .721 .891 r
.78085 .46104 .78615 .4685 .79827 .46517 .79297 .45734 Mtetra
.644 .703 .889 r
.79297 .45734 .79827 .46517 .8104 .46145 .8052 .45432 Mtetra
.654 .728 .904 r
.8052 .45432 .8104 .46145 .82257 .45752 .81746 .45092 Mtetra
.667 .751 .913 r
.81746 .45092 .82257 .45752 .83479 .45351 .82973 .44705 Mtetra
.673 .759 .915 r
.82973 .44705 .83479 .45351 .84706 .44956 .84203 .44298 Mtetra
.672 .755 .913 r
.84203 .44298 .84706 .44956 .85939 .44567 .85438 .43892 Mtetra
.669 .75 .911 r
.85438 .43892 .85939 .44567 .87178 .44184 .8668 .43495 Mtetra
.666 .745 .909 r
.8668 .43495 .87178 .44184 .88422 .43804 .87928 .43105 Mtetra
.665 .742 .908 r
.87928 .43105 .88422 .43804 .89672 .43423 .89181 .42719 Mtetra
.664 .741 .908 r
.89181 .42719 .89672 .43423 .90928 .43041 .90441 .42334 Mtetra
.664 .741 .907 r
.90441 .42334 .90928 .43041 .92189 .42658 .91705 .41947 Mtetra
.91705 .41947 .92189 .42658 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.40127 .56899 .40757 .57497 .41817 .57173 .41189 .56573 Mtetra
.664 .741 .908 r
.41189 .56573 .41817 .57173 .42881 .56849 .42256 .56247 Mtetra
.663 .741 .908 r
.42256 .56247 .42881 .56849 .43949 .56524 .43327 .55922 Mtetra
.66 .741 .91 r
.43327 .55922 .43949 .56524 .45022 .562 .44402 .55603 Mtetra
.656 .742 .913 r
.44402 .55603 .45022 .562 .46098 .5588 .45481 .55293 Mtetra
.652 .745 .918 r
.45481 .55293 .46098 .5588 .47179 .55567 .46564 .54992 Mtetra
.653 .75 .921 r
.46564 .54992 .47179 .55567 .48264 .55263 .47652 .54686 Mtetra
.666 .754 .916 r
.47652 .54686 .48264 .55263 .49354 .5496 .48745 .54345 Mtetra
.689 .748 .897 r
.48745 .54345 .49354 .5496 .50448 .54638 .49843 .53929 Mtetra
.667 .715 .884 r
.49843 .53929 .50448 .54638 .51547 .54271 .50944 .53581 Mtetra
.664 .72 .891 r
.50944 .53581 .51547 .54271 .5265 .53867 .5205 .53242 Mtetra
.664 .741 .907 r
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.55394 .52216 .55985 .52849 .57106 .52507 .56518 .51872 Mtetra
.56518 .51872 .57106 .52507 .58231 .52164 .57646 .51526 Mtetra
.57646 .51526 .58231 .52164 .59361 .51819 .58779 .51178 Mtetra
.58779 .51178 .59361 .51819 .60495 .51472 .59916 .5083 Mtetra
.661 .74 .909 r
.59916 .5083 .60495 .51472 .61635 .51125 .61059 .50489 Mtetra
.598 .721 .93 r
.61059 .50489 .61635 .51125 .62778 .50776 .62211 .50313 Mtetra
.598 .787 .971 r
.62211 .50313 .62778 .50776 .63927 .50425 .63367 .50082 Mtetra
.602 .839 .989 r
.63367 .50082 .63927 .50425 .6508 .50073 .64527 .49789 Mtetra
.619 .869 .99 r
.64527 .49789 .6508 .50073 .66238 .4972 .6569 .49433 Mtetra
.653 .879 .982 r
.6569 .49433 .66238 .4972 .67401 .49365 .66854 .49014 Mtetra
.693 .864 .963 r
.66854 .49014 .67401 .49365 .68568 .49009 .6802 .48533 Mtetra
.719 .821 .928 r
.6802 .48533 .68568 .49009 .69741 .48651 .69188 .47996 Mtetra
.667 .745 .909 r
.69188 .47996 .69741 .48651 .70918 .48292 .70368 .47624 Mtetra
.664 .741 .907 r
.70368 .47624 .70918 .48292 .721 .47931 .71554 .47261 Mtetra
.71554 .47261 .721 .47931 .73287 .47568 .72744 .46896 Mtetra
.72744 .46896 .73287 .47568 .74479 .47205 .73939 .46529 Mtetra
.73939 .46529 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .8052 .45432 .79993 .44673 Mtetra
.661 .719 .892 r
.79993 .44673 .8052 .45432 .81746 .45092 .8122 .44307 Mtetra
.64 .704 .893 r
.8122 .44307 .81746 .45092 .82973 .44705 .82459 .44011 Mtetra
.662 .741 .909 r
.82459 .44011 .82973 .44705 .84203 .44298 .83696 .43639 Mtetra
.672 .757 .914 r
.83696 .43639 .84203 .44298 .85438 .43892 .84936 .43229 Mtetra
.674 .757 .914 r
.84936 .43229 .85438 .43892 .8668 .43495 .8618 .42814 Mtetra
.67 .751 .911 r
.8618 .42814 .8668 .43495 .87928 .43105 .8743 .42408 Mtetra
.667 .746 .909 r
.8743 .42408 .87928 .43105 .89181 .42719 .88687 .42012 Mtetra
.665 .743 .908 r
.88687 .42012 .89181 .42719 .90441 .42334 .8995 .41621 Mtetra
.664 .741 .907 r
.8995 .41621 .90441 .42334 .91705 .41947 .91218 .4123 Mtetra
.91218 .4123 .91705 .41947 .92976 .41559 .92493 .40839 Mtetra
.92493 .40839 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56296 Mtetra
.663 .741 .908 r
.39492 .56296 .40127 .56899 .41189 .56573 .40557 .55969 Mtetra
.40557 .55969 .41189 .56573 .42256 .56247 .41626 .55643 Mtetra
.66 .741 .91 r
.41626 .55643 .42256 .56247 .43327 .55922 .42699 .55324 Mtetra
.655 .742 .914 r
.42699 .55324 .43327 .55922 .44402 .55603 .43777 .55015 Mtetra
.651 .745 .919 r
.43777 .55015 .44402 .55603 .45481 .55293 .44858 .54716 Mtetra
.654 .751 .921 r
.44858 .54716 .45481 .55293 .46564 .54992 .45945 .54406 Mtetra
.673 .753 .911 r
.45945 .54406 .46564 .54992 .47652 .54686 .47036 .54042 Mtetra
.686 .739 .891 r
.47036 .54042 .47652 .54686 .48745 .54345 .48133 .53633 Mtetra
.664 .714 .885 r
.48133 .53633 .48745 .54345 .49843 .53929 .49232 .53294 Mtetra
.664 .738 .905 r
.49232 .53294 .49843 .53929 .50944 .53581 .50337 .52954 Mtetra
.664 .741 .907 r
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.52558 .52269 .5316 .52902 .54275 .5256 .53676 .51925 Mtetra
.53676 .51925 .54275 .5256 .55394 .52216 .54798 .51579 Mtetra
.54798 .51579 .55394 .52216 .56518 .51872 .55925 .51232 Mtetra
.539 .696 .941 r
.55925 .51232 .56518 .51872 .57646 .51526 .57061 .51184 Mtetra
.361 .734 .988 r
.57061 .51184 .57646 .51526 .58779 .51178 .58204 .51208 Mtetra
0 0 0 r
.58204 .51208 .58779 .51178 .59916 .5083 .59353 .51163 Mtetra
.217 0 0 r
.59353 .51163 .59916 .5083 .61059 .50489 .60508 .51042 Mtetra
.296 0 0 r
.60508 .51042 .61059 .50489 .62211 .50313 .61666 .50847 Mtetra
.245 0 0 r
.61666 .50847 .62211 .50313 .63367 .50082 .62829 .5059 Mtetra
.191 0 0 r
.62829 .5059 .63367 .50082 .64527 .49789 .63996 .5028 Mtetra
.144 0 0 r
.63996 .5028 .64527 .49789 .6569 .49433 .65166 .49923 Mtetra
.107 0 0 r
.65166 .49923 .6569 .49433 .66854 .49014 .66338 .49518 Mtetra
.077 0 0 r
.66338 .49518 .66854 .49014 .6802 .48533 .67514 .4906 Mtetra
.049 0 0 r
.67514 .4906 .6802 .48533 .69188 .47996 .6869 .48539 Mtetra
.005 0 0 r
.6869 .48539 .69188 .47996 .70368 .47624 .69866 .47942 Mtetra
0 0 0 r
.69866 .47942 .70368 .47624 .71554 .47261 .71041 .47267 Mtetra
.694 .979 .899 r
.71041 .47267 .71554 .47261 .72744 .46896 .72215 .46522 Mtetra
.758 .874 .932 r
.72215 .46522 .72744 .46896 .73939 .46529 .73396 .45848 Mtetra
.664 .741 .907 r
.73396 .45848 .73939 .46529 .7514 .46161 .746 .45477 Mtetra
.746 .45477 .7514 .46161 .76346 .45791 .75809 .45105 Mtetra
.75809 .45105 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .8122 .44307 .80697 .43598 Mtetra
.664 .738 .905 r
.80697 .43598 .8122 .44307 .82459 .44011 .81932 .43218 Mtetra
.642 .705 .892 r
.81932 .43218 .82459 .44011 .83696 .43639 .83179 .42909 Mtetra
.655 .73 .904 r
.83179 .42909 .83696 .43639 .84936 .43229 .84428 .42554 Mtetra
.672 .754 .913 r
.84428 .42554 .84936 .43229 .8618 .42814 .85677 .42143 Mtetra
.674 .757 .913 r
.85677 .42143 .8618 .42814 .8743 .42408 .8693 .4172 Mtetra
.671 .752 .911 r
.8693 .4172 .8743 .42408 .88687 .42012 .88189 .41307 Mtetra
.667 .746 .909 r
.88189 .41307 .88687 .42012 .8995 .41621 .89455 .40905 Mtetra
.665 .743 .908 r
.89455 .40905 .8995 .41621 .91218 .4123 .90728 .40509 Mtetra
.664 .741 .907 r
.90728 .40509 .91218 .4123 .92493 .40839 .92006 .40114 Mtetra
.92006 .40114 .92493 .40839 .93772 .40447 .9329 .39718 Mtetra
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .3932 Mtetra
.36729 .56346 .37374 .56949 .38431 .56623 .37789 .56019 Mtetra
.37789 .56019 .38431 .56623 .39492 .56296 .38852 .5569 Mtetra
.663 .741 .908 r
.38852 .5569 .39492 .56296 .40557 .55969 .3992 .55363 Mtetra
.66 .741 .91 r
.3992 .55363 .40557 .55969 .41626 .55643 .40991 .55042 Mtetra
.655 .742 .914 r
.40991 .55042 .41626 .55643 .42699 .55324 .42067 .54733 Mtetra
.65 .745 .919 r
.42067 .54733 .42699 .55324 .43777 .55015 .43147 .54435 Mtetra
.655 .751 .92 r
.43147 .54435 .43777 .55015 .44858 .54716 .44231 .54122 Mtetra
.678 .753 .907 r
.44231 .54122 .44858 .54716 .45945 .54406 .45322 .53741 Mtetra
.681 .732 .889 r
.45322 .53741 .45945 .54406 .47036 .54042 .46417 .53347 Mtetra
.664 .719 .89 r
.46417 .53347 .47036 .54042 .48133 .53633 .47515 .53006 Mtetra
.664 .741 .907 r
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.49725 .52322 .50337 .52954 .51445 .52612 .50836 .51978 Mtetra
.50836 .51978 .51445 .52612 .52558 .52269 .51952 .51632 Mtetra
.663 .741 .908 r
.51952 .51632 .52558 .52269 .53676 .51925 .53073 .51287 Mtetra
.384 .625 .948 r
.53073 .51287 .53676 .51925 .54798 .51579 .54201 .51484 Mtetra
0 .519 .73 r
.54201 .51484 .54798 .51579 .55925 .51232 .55337 .51628 Mtetra
.368 0 0 r
.55337 .51628 .55925 .51232 .57061 .51184 .56479 .51658 Mtetra
.318 0 0 r
.56479 .51658 .57061 .51184 .58204 .51208 .57627 .51561 Mtetra
.152 0 0 r
.57627 .51561 .58204 .51208 .59353 .51163 .5878 .51355 Mtetra
0 0 0 r
.5878 .51355 .59353 .51163 .60508 .51042 .59936 .5107 Mtetra
.368 .837 .861 r
.59936 .5107 .60508 .51042 .61666 .50847 .61097 .50737 Mtetra
.525 .895 .967 r
.61097 .50737 .61666 .50847 .62829 .5059 .62262 .5038 Mtetra
.588 .89 .99 r
.62262 .5038 .62829 .5059 .63996 .5028 .63431 .50018 Mtetra
.607 .877 .991 r
.63431 .50018 .63996 .5028 .65166 .49923 .64606 .49659 Mtetra
.605 .877 .992 r
.64606 .49659 .65166 .49923 .66338 .49518 .65786 .49301 Mtetra
.586 .889 .99 r
.65786 .49301 .66338 .49518 .67514 .4906 .6697 .48938 Mtetra
.543 .903 .968 r
.6697 .48938 .67514 .4906 .6869 .48539 .68159 .48552 Mtetra
.461 .888 .885 r
.68159 .48552 .6869 .48539 .69866 .47942 .6935 .48117 Mtetra
.342 .809 .717 r
.6935 .48117 .69866 .47942 .71041 .47267 .70541 .47602 Mtetra
0 0 0 r
.70541 .47602 .71041 .47267 .72215 .46522 .7173 .46975 Mtetra
.7173 .46975 .72215 .46522 .73396 .45848 .72914 .46218 Mtetra
.72914 .46218 .73396 .45848 .746 .45477 .74092 .45345 Mtetra
.813 .968 .903 r
.74092 .45345 .746 .45477 .75809 .45105 .75268 .44414 Mtetra
.664 .742 .908 r
.75268 .44414 .75809 .45105 .77023 .4473 .76486 .44035 Mtetra
.664 .741 .907 r
.76486 .44035 .77023 .4473 .78243 .44355 .77709 .43657 Mtetra
.77709 .43657 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83179 .42909 .82654 .42126 Mtetra
.647 .712 .895 r
.82654 .42126 .83179 .42909 .84428 .42554 .83909 .41796 Mtetra
.65 .722 .901 r
.83909 .41796 .84428 .42554 .85677 .42143 .85169 .41453 Mtetra
.671 .752 .911 r
.85169 .41453 .85677 .42143 .8693 .4172 .86427 .41039 Mtetra
.675 .757 .913 r
.86427 .41039 .8693 .4172 .88189 .41307 .87689 .40609 Mtetra
.671 .752 .911 r
.87689 .40609 .88189 .41307 .89455 .40905 .88957 .4019 Mtetra
.667 .745 .909 r
.88957 .4019 .89455 .40905 .90728 .40509 .90233 .39784 Mtetra
.665 .742 .908 r
.90233 .39784 .90728 .40509 .92006 .40114 .91515 .39383 Mtetra
.664 .741 .907 r
.91515 .39383 .92006 .40114 .9329 .39718 .92803 .38983 Mtetra
.92803 .38983 .9329 .39718 .94579 .3932 .94096 .38582 Mtetra
.3608 .5574 .36729 .56346 .37789 .56019 .37142 .5541 Mtetra
.663 .741 .908 r
.37142 .5541 .37789 .56019 .38852 .5569 .38208 .55081 Mtetra
.661 .741 .909 r
.38208 .55081 .38852 .5569 .3992 .55363 .39278 .54758 Mtetra
.656 .741 .913 r
.39278 .54758 .3992 .55363 .40991 .55042 .40352 .54447 Mtetra
.65 .744 .918 r
.40352 .54447 .40991 .55042 .42067 .54733 .4143 .54149 Mtetra
.654 .75 .92 r
.4143 .54149 .42067 .54733 .43147 .54435 .42512 .53837 Mtetra
.681 .752 .906 r
.42512 .53837 .43147 .54435 .44231 .54122 .43602 .53448 Mtetra
.679 .73 .888 r
.43602 .53448 .44231 .54122 .45322 .53741 .44695 .53059 Mtetra
.664 .724 .894 r
.44695 .53059 .45322 .53741 .46417 .53347 .45792 .52718 Mtetra
.664 .741 .907 r
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.47998 .52031 .48618 .52665 .49725 .52322 .49108 .51686 Mtetra
.49108 .51686 .49725 .52322 .50836 .51978 .50223 .51339 Mtetra
.424 .646 .95 r
.50223 .51339 .50836 .51978 .51952 .51632 .5134 .51476 Mtetra
0 .439 .705 r
.5134 .51476 .51952 .51632 .53073 .51287 .52465 .51742 Mtetra
.437 0 0 r
.52465 .51742 .53073 .51287 .54201 .51484 .53599 .51852 Mtetra
.262 0 0 r
.53599 .51852 .54201 .51484 .55337 .51628 .54739 .51765 Mtetra
.159 .693 .69 r
.54739 .51765 .55337 .51628 .56479 .51658 .55883 .51502 Mtetra
.587 .904 .983 r
.55883 .51502 .56479 .51658 .57627 .51561 .57032 .51116 Mtetra
.692 .823 .945 r
.57032 .51116 .57627 .51561 .5878 .51355 .58184 .50662 Mtetra
.698 .741 .885 r
.58184 .50662 .5878 .51355 .59936 .5107 .59339 .50184 Mtetra
.687 .69 .847 r
.59339 .50184 .59936 .5107 .61097 .50737 .60499 .49713 Mtetra
.674 .658 .826 r
.60499 .49713 .61097 .50737 .62262 .5038 .61663 .4927 Mtetra
.663 .638 .815 r
.61663 .4927 .62262 .5038 .63431 .50018 .62833 .48864 Mtetra
.652 .626 .811 r
.62833 .48864 .63431 .50018 .64606 .49659 .6401 .48501 Mtetra
.643 .622 .814 r
.6401 .48501 .64606 .49659 .65786 .49301 .65193 .48181 Mtetra
.635 .625 .823 r
.65193 .48181 .65786 .49301 .6697 .48938 .66382 .47899 Mtetra
.629 .638 .84 r
.66382 .47899 .6697 .48938 .68159 .48552 .67579 .47645 Mtetra
.627 .666 .868 r
.67579 .47645 .68159 .48552 .6935 .48117 .68782 .47398 Mtetra
.63 .719 .911 r
.68782 .47398 .6935 .48117 .70541 .47602 .6999 .47128 Mtetra
.638 .809 .965 r
.6999 .47128 .70541 .47602 .7173 .46975 .712 .46789 Mtetra
.623 .917 .979 r
.712 .46789 .7173 .46975 .72914 .46218 .72408 .46325 Mtetra
.523 .917 .818 r
.72408 .46325 .72914 .46218 .74092 .45345 .73609 .45682 Mtetra
.416 .81 .583 r
.73609 .45682 .74092 .45345 .75268 .44414 .748 .44837 Mtetra
0 0 0 r
.748 .44837 .75268 .44414 .76486 .44035 .7598 .4383 Mtetra
.803 .949 .917 r
.7598 .4383 .76486 .44035 .77709 .43657 .77171 .42953 Mtetra
.664 .741 .907 r
.77171 .42953 .77709 .43657 .78937 .43276 .78403 .4257 Mtetra
.78403 .4257 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83909 .41796 .83385 .4102 Mtetra
.649 .718 .898 r
.83385 .4102 .83909 .41796 .85169 .41453 .84648 .40679 Mtetra
.648 .719 .9 r
.84648 .40679 .85169 .41453 .86427 .41039 .85918 .40338 Mtetra
.672 .751 .911 r
.85918 .40338 .86427 .41039 .87689 .40609 .87186 .39917 Mtetra
.676 .757 .912 r
.87186 .39917 .87689 .40609 .88957 .4019 .88457 .39481 Mtetra
.671 .751 .91 r
.88457 .39481 .88957 .4019 .90233 .39784 .89735 .39058 Mtetra
.667 .745 .908 r
.89735 .39058 .90233 .39784 .91515 .39383 .9102 .38648 Mtetra
.665 .742 .908 r
.9102 .38648 .91515 .39383 .92803 .38983 .92312 .38243 Mtetra
.664 .741 .907 r
.92312 .38243 .92803 .38983 .94096 .38582 .9361 .37838 Mtetra
.663 .741 .908 r
.35425 .5513 .3608 .5574 .37142 .5541 .3649 .54798 Mtetra
.661 .741 .909 r
.3649 .54798 .37142 .5541 .38208 .55081 .37558 .54472 Mtetra
.657 .741 .912 r
.37558 .54472 .38208 .55081 .39278 .54758 .38631 .54157 Mtetra
.65 .743 .917 r
.38631 .54157 .39278 .54758 .40352 .54447 .39707 .53857 Mtetra
.652 .748 .92 r
.39707 .53857 .40352 .54447 .4143 .54149 .40788 .53551 Mtetra
.679 .753 .907 r
.40788 .53551 .4143 .54149 .42512 .53837 .41875 .53167 Mtetra
.681 .732 .889 r
.41875 .53167 .42512 .53837 .43602 .53448 .42968 .5277 Mtetra
.664 .726 .895 r
.42968 .5277 .43602 .53448 .44695 .53059 .44063 .52428 Mtetra
.664 .741 .907 r
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.45162 .52084 .45792 .52718 .46893 .52375 .46266 .51739 Mtetra
.46266 .51739 .46893 .52375 .47998 .52031 .47374 .51392 Mtetra
.621 .728 .923 r
.47374 .51392 .47998 .52031 .49108 .51686 .48486 .51161 Mtetra
.108 .514 .909 r
.48486 .51161 .49108 .51686 .50223 .51339 .49597 .51557 Mtetra
.446 0 0 r
.49597 .51557 .50223 .51339 .5134 .51476 .50719 .51819 Mtetra
.316 0 0 r
.50719 .51819 .5134 .51476 .52465 .51742 .51849 .51821 Mtetra
.242 .757 .781 r
.51849 .51821 .52465 .51742 .53599 .51852 .52987 .51557 Mtetra
.681 .877 .972 r
.52987 .51557 .53599 .51852 .54739 .51765 .54129 .51096 Mtetra
.724 .754 .876 r
.54129 .51096 .54739 .51765 .55883 .51502 .55274 .50521 Mtetra
.711 .678 .817 r
.55274 .50521 .55883 .51502 .57032 .51116 .56422 .49904 Mtetra
.695 .636 .786 r
.56422 .49904 .57032 .51116 .58184 .50662 .57573 .49295 Mtetra
.681 .61 .77 r
.57573 .49295 .58184 .50662 .59339 .50184 .58727 .48718 Mtetra
.669 .594 .762 r
.58727 .48718 .59339 .50184 .60499 .49713 .59886 .4819 Mtetra
.658 .583 .759 r
.59886 .4819 .60499 .49713 .61663 .4927 .61051 .47713 Mtetra
.649 .575 .758 r
.61051 .47713 .61663 .4927 .62833 .48864 .62221 .47292 Mtetra
.639 .569 .759 r
.62221 .47292 .62833 .48864 .6401 .48501 .63397 .46925 Mtetra
.63 .564 .761 r
.63397 .46925 .6401 .48501 .65193 .48181 .6458 .46613 Mtetra
.62 .56 .765 r
.6458 .46613 .65193 .48181 .66382 .47899 .65771 .46357 Mtetra
.611 .558 .77 r
.65771 .46357 .66382 .47899 .67579 .47645 .6697 .46153 Mtetra
.602 .559 .778 r
.6697 .46153 .67579 .47645 .68782 .47398 .68178 .45999 Mtetra
.595 .567 .792 r
.68178 .45999 .68782 .47398 .6999 .47128 .69395 .45879 Mtetra
.593 .587 .815 r
.69395 .45879 .6999 .47128 .712 .46789 .70619 .45767 Mtetra
.6 .632 .854 r
.70619 .45767 .712 .46789 .72408 .46325 .71848 .45613 Mtetra
.627 .723 .917 r
.71848 .45613 .72408 .46325 .73609 .45682 .73077 .45345 Mtetra
.669 .878 .976 r
.73077 .45345 .73609 .45682 .748 .44837 .74298 .44876 Mtetra
.645 .968 .873 r
.74298 .44876 .748 .44837 .7598 .4383 .75505 .44135 Mtetra
.562 .894 .645 r
.75505 .44135 .7598 .4383 .77171 .42953 .76695 .43126 Mtetra
.752 .986 .76 r
.76695 .43126 .77171 .42953 .78403 .4257 .77875 .41977 Mtetra
.701 .793 .922 r
.77875 .41977 .78403 .4257 .79641 .42185 .79106 .4147 Mtetra
.664 .741 .907 r
.79106 .4147 .79641 .42185 .80883 .41798 .80353 .4108 Mtetra
.80353 .4108 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84648 .40679 .84124 .39901 Mtetra
.647 .719 .901 r
.84124 .39901 .84648 .40679 .85918 .40338 .85398 .39562 Mtetra
.65 .722 .901 r
.85398 .39562 .85918 .40338 .87186 .39917 .86677 .39209 Mtetra
.673 .753 .91 r
.86677 .39209 .87186 .39917 .88457 .39481 .87954 .38777 Mtetra
.676 .756 .911 r
.87954 .38777 .88457 .39481 .89735 .39058 .89234 .38336 Mtetra
.67 .749 .91 r
.89234 .38336 .89735 .39058 .9102 .38648 .90522 .37911 Mtetra
.666 .744 .908 r
.90522 .37911 .9102 .38648 .92312 .38243 .91818 .37498 Mtetra
.664 .742 .908 r
.91818 .37498 .92312 .38243 .9361 .37838 .9312 .37089 Mtetra
.663 .741 .908 r
.34766 .54516 .35425 .5513 .3649 .54798 .35833 .54184 Mtetra
.658 .741 .911 r
.35833 .54184 .3649 .54798 .37558 .54472 .36904 .53865 Mtetra
.651 .742 .916 r
.36904 .53865 .37558 .54472 .38631 .54157 .37978 .53561 Mtetra
.65 .746 .92 r
.37978 .53561 .38631 .54157 .39707 .53857 .39057 .5326 Mtetra
.672 .752 .911 r
.39057 .5326 .39707 .53857 .40788 .53551 .40143 .52894 Mtetra
.686 .738 .89 r
.40143 .52894 .40788 .53551 .41875 .53167 .41234 .52481 Mtetra
.664 .724 .894 r
.41234 .52481 .41875 .53167 .42968 .5277 .42327 .52137 Mtetra
.664 .741 .907 r
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.43425 .51792 .44063 .52428 .45162 .52084 .44527 .51446 Mtetra
.44527 .51446 .45162 .52084 .46266 .51739 .45634 .51098 Mtetra
.535 .696 .943 r
.45634 .51098 .46266 .51739 .47374 .51392 .4674 .51049 Mtetra
0 .375 .75 r
.4674 .51049 .47374 .51392 .48486 .51161 .47846 .51504 Mtetra
.468 0 0 r
.47846 .51504 .48486 .51161 .49597 .51557 .48964 .5173 Mtetra
.048 0 0 r
.48964 .5173 .49597 .51557 .50719 .51819 .50093 .51608 Mtetra
.649 .901 .983 r
.50093 .51608 .50719 .51819 .51849 .51821 .51229 .51172 Mtetra
.739 .762 .871 r
.51229 .51172 .51849 .51821 .52987 .51557 .5237 .50536 Mtetra
.726 .676 .801 r
.5237 .50536 .52987 .51557 .54129 .51096 .53513 .4981 Mtetra
.709 .632 .77 r
.53513 .4981 .54129 .51096 .55274 .50521 .54658 .49077 Mtetra
.694 .608 .756 r
.54658 .49077 .55274 .50521 .56422 .49904 .55806 .48382 Mtetra
.682 .595 .751 r
.55806 .48382 .56422 .49904 .57573 .49295 .56957 .47742 Mtetra
.67 .586 .752 r
.56957 .47742 .57573 .49295 .58727 .48718 .58113 .47177 Mtetra
.64 .572 .762 r
.58113 .47177 .58727 .48718 .59886 .4819 .59276 .46811 Mtetra
.645 .592 .781 r
.59276 .46811 .59886 .4819 .61051 .47713 .60443 .46444 Mtetra
.649 .609 .796 r
.60443 .46444 .61051 .47713 .62221 .47292 .61616 .46076 Mtetra
.65 .618 .804 r
.61616 .46076 .62221 .47292 .63397 .46925 .62794 .45706 Mtetra
.62794 .45706 .63397 .46925 .6458 .46613 .63976 .45334 Mtetra
.649 .609 .796 r
.63976 .45334 .6458 .46613 .65771 .46357 .65164 .44961 Mtetra
.645 .592 .781 r
.65164 .44961 .65771 .46357 .6697 .46153 .66357 .44586 Mtetra
.605 .552 .769 r
.66357 .44586 .6697 .46153 .68178 .45999 .67564 .44413 Mtetra
.59 .543 .77 r
.67564 .44413 .68178 .45999 .69395 .45879 .68781 .44315 Mtetra
.578 .539 .775 r
.68781 .44315 .69395 .45879 .70619 .45767 .70009 .44276 Mtetra
.569 .543 .786 r
.70009 .44276 .70619 .45767 .71848 .45613 .71248 .44276 Mtetra
.567 .562 .808 r
.71248 .44276 .71848 .45613 .73077 .45345 .72494 .44269 Mtetra
.584 .615 .849 r
.72494 .44269 .73077 .45345 .74298 .44876 .73742 .44173 Mtetra
.635 .733 .919 r
.73742 .44173 .74298 .44876 .75505 .44135 .74984 .43873 Mtetra
.715 .921 .962 r
.74984 .43873 .75505 .44135 .76695 .43126 .76209 .43253 Mtetra
.704 .981 .801 r
.76209 .43253 .76695 .43126 .77875 .41977 .7741 .42273 Mtetra
.678 .94 .661 r
.7741 .42273 .77875 .41977 .79106 .4147 .78592 .41057 Mtetra
.757 .876 .933 r
.78592 .41057 .79106 .4147 .80353 .4108 .79818 .40356 Mtetra
.664 .741 .907 r
.79818 .40356 .80353 .4108 .81604 .40689 .81073 .39961 Mtetra
.81073 .39961 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85398 .39562 .84873 .38767 Mtetra
.642 .715 .9 r
.84873 .38767 .85398 .39562 .86677 .39209 .86159 .3844 Mtetra
.656 .729 .903 r
.86159 .3844 .86677 .39209 .87954 .38777 .87445 .38063 Mtetra
.676 .755 .91 r
.87445 .38063 .87954 .38777 .89234 .38336 .8873 .37618 Mtetra
.675 .754 .911 r
.8873 .37618 .89234 .38336 .90522 .37911 .90021 .37175 Mtetra
.669 .747 .909 r
.90021 .37175 .90522 .37911 .91818 .37498 .9132 .36749 Mtetra
.665 .743 .908 r
.9132 .36749 .91818 .37498 .9312 .37089 .92625 .36335 Mtetra
.661 .741 .91 r
.34102 .53901 .34766 .54516 .35833 .54184 .35171 .53571 Mtetra
.654 .741 .914 r
.35171 .53571 .35833 .54184 .36904 .53865 .36244 .53261 Mtetra
.648 .744 .919 r
.36244 .53261 .36904 .53865 .37978 .53561 .37321 .52963 Mtetra
.663 .75 .915 r
.37321 .52963 .37978 .53561 .39057 .5326 .38404 .52623 Mtetra
.692 .746 .893 r
.38404 .52623 .39057 .5326 .40143 .52894 .39495 .5219 Mtetra
.664 .719 .89 r
.39495 .5219 .40143 .52894 .41234 .52481 .40586 .51845 Mtetra
.664 .741 .907 r
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.41682 .51499 .42327 .52137 .43425 .51792 .42783 .51152 Mtetra
.42783 .51152 .43425 .51792 .44527 .51446 .43888 .50803 Mtetra
.498 .682 .948 r
.43888 .50803 .44527 .51446 .45634 .51098 .44989 .50815 Mtetra
.311 0 0 r
.44989 .50815 .45634 .51098 .4674 .51049 .46088 .51321 Mtetra
.43 0 0 r
.46088 .51321 .4674 .51049 .47846 .51504 .47202 .51527 Mtetra
.262 .771 .832 r
.47202 .51527 .47846 .51504 .48964 .5173 .4833 .51308 Mtetra
.733 .835 .928 r
.4833 .51308 .48964 .5173 .50093 .51608 .49466 .50736 Mtetra
.746 .71 .818 r
.49466 .50736 .50093 .51608 .51229 .51172 .50607 .49965 Mtetra
.728 .65 .772 r
.50607 .49965 .51229 .51172 .5237 .50536 .5175 .49132 Mtetra
.711 .62 .754 r
.5175 .49132 .5237 .50536 .53513 .4981 .52894 .48325 Mtetra
.696 .605 .751 r
.52894 .48325 .53513 .4981 .54658 .49077 .54041 .47596 Mtetra
.641 .578 .768 r
.54041 .47596 .54658 .49077 .55806 .48382 .55192 .47233 Mtetra
.652 .628 .812 r
.55192 .47233 .55806 .48382 .56957 .47742 .56349 .46868 Mtetra
.661 .685 .862 r
.56349 .46868 .56957 .47742 .58113 .47177 .5751 .46501 Mtetra
.664 .741 .907 r
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67564 .44413 .66979 .43511 Mtetra
.661 .685 .862 r
.66979 .43511 .67564 .44413 .68781 .44315 .68185 .4313 Mtetra
.652 .628 .812 r
.68185 .4313 .68781 .44315 .70009 .44276 .69396 .42747 Mtetra
.571 .54 .781 r
.69396 .42747 .70009 .44276 .71248 .44276 .70634 .42735 Mtetra
.554 .529 .782 r
.70634 .42735 .71248 .44276 .72494 .44269 .71884 .42804 Mtetra
.545 .534 .794 r
.71884 .42804 .72494 .44269 .73742 .44173 .73145 .429 Mtetra
.553 .566 .821 r
.73145 .429 .73742 .44173 .74984 .43873 .74412 .42935 Mtetra
.598 .655 .877 r
.74412 .42935 .74984 .43873 .76209 .43253 .75672 .42769 Mtetra
.703 .836 .946 r
.75672 .42769 .76209 .43253 .7741 .42273 .76913 .42241 Mtetra
.78 .993 .879 r
.76913 .42241 .7741 .42273 .78592 .41057 .78124 .41276 Mtetra
.759 .977 .717 r
.78124 .41276 .78592 .41057 .79818 .40356 .7931 .39999 Mtetra
.774 .903 .931 r
.7931 .39999 .79818 .40356 .81073 .39961 .80538 .39228 Mtetra
.664 .741 .907 r
.80538 .39228 .81073 .39961 .82335 .39565 .81803 .38829 Mtetra
.81803 .38829 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86159 .3844 .85632 .3762 Mtetra
.636 .708 .898 r
.85632 .3762 .86159 .3844 .87445 .38063 .86929 .37307 Mtetra
.664 .739 .906 r
.86929 .37307 .87445 .38063 .8873 .37618 .88223 .36897 Mtetra
.677 .756 .91 r
.88223 .36897 .8873 .37618 .90021 .37175 .89517 .36442 Mtetra
.673 .751 .91 r
.89517 .36442 .90021 .37175 .9132 .36749 .90818 .36 Mtetra
.667 .745 .909 r
.90818 .36 .9132 .36749 .92625 .36335 .92127 .35577 Mtetra
.659 .743 .912 r
.33432 .53287 .34102 .53901 .35171 .53571 .34504 .5296 Mtetra
.649 .742 .917 r
.34504 .5296 .35171 .53571 .36244 .53261 .35579 .52659 Mtetra
.654 .747 .918 r
.35579 .52659 .36244 .53261 .37321 .52963 .36659 .52343 Mtetra
.692 .751 .897 r
.36659 .52343 .37321 .52963 .38404 .52623 .37749 .51909 Mtetra
.667 .718 .887 r
.37749 .51909 .38404 .52623 .39495 .5219 .38839 .51553 Mtetra
.664 .741 .907 r
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.41032 .50856 .41682 .51499 .42783 .51152 .42136 .50506 Mtetra
.533 .697 .944 r
.42136 .50506 .42783 .51152 .43888 .50803 .43235 .50455 Mtetra
0 .251 .636 r
.43235 .50455 .43888 .50803 .44989 .50815 .44326 .51024 Mtetra
.42 0 0 r
.44326 .51024 .44989 .50815 .46088 .51321 .45435 .51255 Mtetra
.417 .852 .938 r
.45435 .51255 .46088 .51321 .47202 .51527 .46561 .50991 Mtetra
.752 .798 .889 r
.46561 .50991 .47202 .51527 .4833 .51308 .47698 .50329 Mtetra
.751 .692 .795 r
.47698 .50329 .4833 .51308 .49466 .50736 .4884 .4946 Mtetra
.732 .644 .76 r
.4884 .4946 .49466 .50736 .50607 .49965 .49984 .48549 Mtetra
.716 .622 .751 r
.49984 .48549 .50607 .49965 .5175 .49132 .51128 .47692 Mtetra
.649 .587 .771 r
.51128 .47692 .5175 .49132 .52894 .48325 .52273 .47289 Mtetra
.656 .649 .831 r
.52273 .47289 .52894 .48325 .54041 .47596 .53423 .46924 Mtetra
.664 .741 .907 r
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70634 .42735 .70043 .41649 Mtetra
.647 .645 .834 r
.70043 .41649 .70634 .42735 .71884 .42804 .71271 .41301 Mtetra
.541 .528 .79 r
.71271 .41301 .71884 .42804 .73145 .429 .72533 .41414 Mtetra
.527 .522 .794 r
.72533 .41414 .73145 .429 .74412 .42935 .73809 .41585 Mtetra
.53 .543 .813 r
.73809 .41585 .74412 .42935 .75672 .42769 .75091 .41715 Mtetra
.575 .62 .859 r
.75091 .41715 .75672 .42769 .76913 .42241 .76368 .41635 Mtetra
.691 .791 .927 r
.76368 .41635 .76913 .42241 .78124 .41276 .77621 .41147 Mtetra
.816 .978 .893 r
.77621 .41147 .78124 .41276 .7931 .39999 .78838 .40148 Mtetra
.82 .994 .751 r
.78838 .40148 .7931 .39999 .80538 .39228 .80025 .38799 Mtetra
.757 .876 .933 r
.80025 .38799 .80538 .39228 .81803 .38829 .81267 .38087 Mtetra
.664 .741 .907 r
.81267 .38087 .81803 .38829 .83074 .38428 .82542 .37682 Mtetra
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.661 .739 .908 r
.85108 .36868 .85632 .3762 .86929 .37307 .86401 .36469 Mtetra
.637 .705 .896 r
.86401 .36469 .86929 .37307 .88223 .36897 .87709 .36151 Mtetra
.672 .748 .908 r
.87709 .36151 .88223 .36897 .89517 .36442 .89009 .35709 Mtetra
.676 .755 .91 r
.89009 .35709 .89517 .36442 .90818 .36 .90313 .35251 Mtetra
.668 .748 .91 r
.90313 .35251 .90818 .36 .92127 .35577 .91626 .34819 Mtetra
.657 .745 .915 r
.32757 .52675 .33432 .53287 .34504 .5296 .33831 .52353 Mtetra
.649 .745 .919 r
.33831 .52353 .34504 .5296 .35579 .52659 .34909 .52048 Mtetra
.673 .75 .909 r
.34909 .52048 .35579 .52659 .36659 .52343 .35994 .51674 Mtetra
.685 .736 .89 r
.35994 .51674 .36659 .52343 .37749 .51909 .37086 .51259 Mtetra
.664 .738 .905 r
.37086 .51259 .37749 .51909 .38839 .51553 .38179 .5091 Mtetra
.664 .741 .907 r
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.39276 .5056 .39934 .51205 .41032 .50856 .40378 .50209 Mtetra
.621 .728 .923 r
.40378 .50209 .41032 .50856 .42136 .50506 .4148 .49973 Mtetra
0 .295 .746 r
.4148 .49973 .42136 .50506 .43235 .50455 .42562 .5061 Mtetra
.459 0 0 r
.42562 .5061 .43235 .50455 .44326 .51024 .43663 .50929 Mtetra
.417 .846 .95 r
.43663 .50929 .44326 .51024 .45435 .51255 .44786 .50691 Mtetra
.759 .789 .878 r
.44786 .50691 .45435 .51255 .46561 .50991 .45924 .49987 Mtetra
.758 .69 .787 r
.45924 .49987 .46561 .50991 .47698 .50329 .47068 .49049 Mtetra
.74 .646 .757 r
.47068 .49049 .47698 .50329 .4884 .4946 .48213 .48075 Mtetra
.702 .619 .761 r
.48213 .48075 .4884 .4946 .49984 .48549 .49357 .47345 Mtetra
.65 .618 .804 r
.49357 .47345 .49984 .48549 .51128 .47692 .505 .4698 Mtetra
.664 .729 .898 r
.505 .4698 .51128 .47692 .52273 .47289 .51648 .46614 Mtetra
.664 .741 .907 r
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71271 .41301 .70698 .40538 Mtetra
.664 .729 .898 r
.70698 .40538 .71271 .41301 .72533 .41414 .71933 .40144 Mtetra
.565 .575 .822 r
.71933 .40144 .72533 .41414 .73809 .41585 .73197 .40123 Mtetra
.509 .517 .8 r
.73197 .40123 .73809 .41585 .75091 .41715 .74486 .40352 Mtetra
.512 .533 .815 r
.74486 .40352 .75091 .41715 .76368 .41635 .75784 .40548 Mtetra
.564 .609 .857 r
.75784 .40548 .76368 .41635 .77621 .41147 .77074 .40504 Mtetra
.699 .785 .917 r
.77074 .40504 .77621 .41147 .78838 .40148 .78334 .39984 Mtetra
.844 .97 .879 r
.78334 .39984 .78838 .40148 .80025 .38799 .79551 .38887 Mtetra
.862 .995 .766 r
.79551 .38887 .80025 .38799 .81267 .38087 .80738 .37459 Mtetra
.701 .793 .922 r
.80738 .37459 .81267 .38087 .82542 .37682 .82006 .36931 Mtetra
.664 .741 .907 r
.82006 .36931 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .86401 .36469 .85876 .35696 Mtetra
.642 .729 .911 r
.85876 .35696 .86401 .36469 .87709 .36151 .87185 .35352 Mtetra
.655 .727 .902 r
.87185 .35352 .87709 .36151 .89009 .35709 .88496 .34965 Mtetra
.676 .753 .909 r
.88496 .34965 .89009 .35709 .90313 .35251 .89805 .34505 Mtetra
.67 .751 .911 r
.89805 .34505 .90313 .35251 .91626 .34819 .91122 .34063 Mtetra
.656 .748 .917 r
.32077 .52069 .32757 .52675 .33831 .52353 .33153 .51744 Mtetra
.658 .749 .917 r
.33153 .51744 .33831 .52353 .34909 .52048 .34235 .51412 Mtetra
.695 .749 .893 r
.34235 .51412 .34909 .52048 .35994 .51674 .35327 .50964 Mtetra
.663 .721 .891 r
.35327 .50964 .35994 .51674 .37086 .51259 .36418 .50614 Mtetra
.664 .741 .907 r
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.37513 .50263 .38179 .5091 .39276 .5056 .38613 .4991 Mtetra
.38613 .4991 .39276 .5056 .40378 .50209 .39718 .49556 Mtetra
.055 .44 .875 r
.39718 .49556 .40378 .50209 .4148 .49973 .40796 .50067 Mtetra
.532 0 0 r
.40796 .50067 .4148 .49973 .42562 .5061 .41887 .50534 Mtetra
.264 .763 .893 r
.41887 .50534 .42562 .5061 .43663 .50929 .43004 .50406 Mtetra
.757 .802 .889 r
.43004 .50406 .43663 .50929 .44786 .50691 .44142 .49723 Mtetra
.766 .699 .788 r
.44142 .49723 .44786 .50691 .45924 .49987 .45288 .48744 Mtetra
.749 .655 .757 r
.45288 .48744 .45924 .49987 .47068 .49049 .46436 .47713 Mtetra
.697 .622 .769 r
.46436 .47713 .47068 .49049 .48213 .48075 .47579 .47036 Mtetra
.656 .649 .832 r
.47579 .47036 .48213 .48075 .49357 .47345 .4872 .4667 Mtetra
.664 .741 .907 r
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73197 .40123 .72605 .39014 Mtetra
.575 .61 .85 r
.72605 .39014 .73197 .40123 .74486 .40352 .73875 .38932 Mtetra
.49 .513 .808 r
.73875 .38932 .74486 .40352 .75784 .40548 .75179 .39215 Mtetra
.497 .531 .822 r
.75179 .39215 .75784 .40548 .77074 .40504 .76491 .39447 Mtetra
.569 .62 .864 r
.76491 .39447 .77074 .40504 .78334 .39984 .7779 .39377 Mtetra
.733 .809 .912 r
.7779 .39377 .78334 .39984 .79551 .38887 .7905 .38735 Mtetra
.874 .97 .849 r
.7905 .38735 .79551 .38887 .80738 .37459 .80261 .37478 Mtetra
.851 .998 .806 r
.80261 .37478 .80738 .37459 .82006 .36931 .81465 .36173 Mtetra
.664 .741 .907 r
.81465 .36173 .82006 .36931 .8329 .36521 .82754 .3576 Mtetra
.82754 .3576 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87185 .35352 .86653 .3451 Mtetra
.633 .707 .9 r
.86653 .3451 .87185 .35352 .88496 .34965 .87977 .34194 Mtetra
.668 .744 .907 r
.87977 .34194 .88496 .34965 .89805 .34505 .89293 .33756 Mtetra
.67 .752 .912 r
.89293 .33756 .89805 .34505 .91122 .34063 .90614 .33311 Mtetra
.66 .751 .918 r
.3139 .51467 .32077 .52069 .33153 .51744 .3247 .5113 Mtetra
.679 .753 .907 r
.3247 .5113 .33153 .51744 .34235 .51412 .33558 .50734 Mtetra
.684 .736 .89 r
.33558 .50734 .34235 .51412 .35327 .50964 .34651 .50317 Mtetra
.664 .741 .907 r
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.36843 .49611 .37513 .50263 .38613 .4991 .37946 .49256 Mtetra
.411 .644 .953 r
.37946 .49256 .38613 .4991 .39718 .49556 .39033 .49386 Mtetra
.535 0 0 r
.39033 .49386 .39718 .49556 .40796 .50067 .4011 .50023 Mtetra
.059 0 0 r
.4011 .50023 .40796 .50067 .41887 .50534 .41216 .50104 Mtetra
.734 .832 .925 r
.41216 .50104 .41887 .50534 .43004 .50406 .4235 .49525 Mtetra
.774 .716 .798 r
.4235 .49525 .43004 .50406 .44142 .49723 .43499 .48544 Mtetra
.76 .667 .76 r
.43499 .48544 .44142 .49723 .45288 .48744 .4465 .4746 Mtetra
.709 .634 .772 r
.4465 .4746 .45288 .48744 .46436 .47713 .45794 .46727 Mtetra
.657 .661 .842 r
.45794 .46727 .46436 .47713 .47579 .47036 .46934 .46359 Mtetra
.664 .741 .907 r
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73875 .38932 .73285 .37869 Mtetra
.556 .612 .864 r
.73285 .37869 .73875 .38932 .75179 .39215 .7457 .3784 Mtetra
.47 .51 .817 r
.7457 .3784 .75179 .39215 .76491 .39447 .75889 .38173 Mtetra
.492 .539 .833 r
.75889 .38173 .76491 .39447 .7779 .39377 .77213 .38402 Mtetra
.598 .655 .877 r
.77213 .38402 .7779 .39377 .7905 .38735 .78514 .38219 Mtetra
.791 .855 .899 r
.78514 .38219 .7905 .38735 .80261 .37478 .79764 .37354 Mtetra
.901 .969 .815 r
.79764 .37354 .80261 .37478 .81465 .36173 .80966 .35914 Mtetra
.803 .949 .917 r
.80966 .35914 .81465 .36173 .82754 .3576 .82213 .34993 Mtetra
.664 .741 .907 r
.82213 .34993 .82754 .3576 .84048 .35345 .83511 .34574 Mtetra
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.643 .732 .913 r
.86125 .33732 .86653 .3451 .87977 .34194 .87449 .33378 Mtetra
.65 .725 .903 r
.87449 .33378 .87977 .34194 .89293 .33756 .88776 .33 Mtetra
.667 .751 .913 r
.88776 .33 .89293 .33756 .90614 .33311 .90103 .32561 Mtetra
.668 .754 .915 r
.30698 .50863 .3139 .51467 .3247 .5113 .31782 .50498 Mtetra
.703 .754 .891 r
.31782 .50498 .3247 .5113 .33558 .50734 .32878 .50019 Mtetra
.663 .721 .892 r
.32878 .50019 .33558 .50734 .34651 .50317 .3397 .49665 Mtetra
.664 .741 .907 r
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.35066 .4931 .35745 .49965 .36843 .49611 .36167 .48954 Mtetra
.663 .741 .908 r
.36167 .48954 .36843 .49611 .37946 .49256 .37273 .48598 Mtetra
0 .241 .728 r
.37273 .48598 .37946 .49256 .39033 .49386 .38336 .49345 Mtetra
.396 0 0 r
.38336 .49345 .39033 .49386 .4011 .50023 .39425 .49715 Mtetra
.63 .86 .986 r
.39425 .49715 .4011 .50023 .41216 .50104 .40551 .49356 Mtetra
.779 .745 .822 r
.40551 .49356 .41216 .50104 .4235 .49525 .41699 .48441 Mtetra
.772 .683 .766 r
.41699 .48441 .4235 .49525 .43499 .48544 .42855 .47319 Mtetra
.735 .653 .767 r
.42855 .47319 .43499 .48544 .4465 .4746 .44004 .46416 Mtetra
.655 .649 .832 r
.44004 .46416 .4465 .4746 .45794 .46727 .45142 .46047 Mtetra
.664 .741 .907 r
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .7457 .3784 .73974 .3671 Mtetra
.504 .573 .858 r
.73974 .3671 .7457 .3784 .75889 .38173 .75282 .3685 Mtetra
.452 .509 .827 r
.75282 .3685 .75889 .38173 .77213 .38402 .76616 .37216 Mtetra
.504 .563 .85 r
.76616 .37216 .77213 .38402 .78514 .38219 .77947 .37373 Mtetra
.663 .719 .89 r
.77947 .37373 .78514 .38219 .79764 .37354 .7924 .36956 Mtetra
.857 .902 .865 r
.7924 .36956 .79764 .37354 .80966 .35914 .80472 .35785 Mtetra
.917 .963 .794 r
.80472 .35785 .80966 .35914 .82213 .34993 .81668 .34221 Mtetra
.664 .742 .908 r
.81668 .34221 .82213 .34993 .83511 .34574 .8297 .33797 Mtetra
.664 .741 .907 r
.8297 .33797 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87449 .33378 .86913 .32521 Mtetra
.625 .704 .902 r
.86913 .32521 .87449 .33378 .88776 .33 .88254 .32224 Mtetra
.66 .744 .912 r
.88254 .32224 .88776 .33 .90103 .32561 .89588 .31807 Mtetra
.682 .756 .907 r
.30001 .50249 .30698 .50863 .31782 .50498 .3109 .49842 Mtetra
.701 .748 .888 r
.3109 .49842 .31782 .50498 .32878 .50019 .32189 .49365 Mtetra
.664 .741 .907 r
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.34383 .48651 .35066 .4931 .36167 .48954 .35486 .48292 Mtetra
.359 .619 .95 r
.35486 .48292 .36167 .48954 .37273 .48598 .36568 .48483 Mtetra
.578 .003 0 r
.36568 .48483 .37273 .48598 .38336 .49345 .37637 .49143 Mtetra
.236 .72 .93 r
.37637 .49143 .38336 .49345 .39425 .49715 .38745 .49137 Mtetra
.764 .787 .873 r
.38745 .49137 .39425 .49715 .40551 .49356 .39888 .48403 Mtetra
.783 .706 .78 r
.39888 .48403 .40551 .49356 .41699 .48441 .41047 .4729 Mtetra
.769 .674 .759 r
.41047 .4729 .41699 .48441 .42855 .47319 .42206 .46144 Mtetra
.659 .629 .809 r
.42206 .46144 .42855 .47319 .44004 .46416 .43343 .45734 Mtetra
.664 .741 .907 r
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.651 .736 .911 r
.734 .35951 .73974 .3671 .75282 .3685 .74675 .35578 Mtetra
.437 .51 .836 r
.74675 .35578 .75282 .3685 .76616 .37216 .76012 .35961 Mtetra
.445 .519 .84 r
.76012 .35961 .76616 .37216 .77947 .37373 .77359 .36314 Mtetra
.553 .618 .871 r
.77359 .36314 .77947 .37373 .7924 .36956 .78686 .36278 Mtetra
.762 .803 .886 r
.78686 .36278 .7924 .36956 .80472 .35785 .79958 .3549 Mtetra
.906 .927 .819 r
.79958 .3549 .80472 .35785 .81668 .34221 .8117 .34011 Mtetra
.814 .967 .903 r
.8117 .34011 .81668 .34221 .8297 .33797 .82424 .33014 Mtetra
.664 .741 .907 r
.82424 .33014 .8297 .33797 .84278 .33374 .83737 .32586 Mtetra
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.624 .724 .918 r
.8638 .31726 .86913 .32521 .88254 .32224 .87725 .31421 Mtetra
.647 .732 .911 r
.87725 .31421 .88254 .32224 .89588 .31807 .89068 .31042 Mtetra
.697 .755 .896 r
.29299 .49617 .30001 .50249 .3109 .49842 .30395 .49156 Mtetra
.692 .739 .887 r
.30395 .49156 .3109 .49842 .32189 .49365 .31494 .48706 Mtetra
.664 .741 .907 r
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.32592 .48347 .33283 .49009 .34383 .48651 .33694 .47986 Mtetra
.33694 .47986 .34383 .48651 .35486 .48292 .348 .47624 Mtetra
0 .286 .764 r
.348 .47624 .35486 .48292 .36568 .48483 .35859 .48311 Mtetra
.357 0 0 r
.35859 .48311 .36568 .48483 .37637 .49143 .36941 .48738 Mtetra
.657 .832 .967 r
.36941 .48738 .37637 .49143 .38745 .49137 .38068 .48356 Mtetra
.786 .74 .81 r
.38068 .48356 .38745 .49137 .39888 .48403 .39225 .47356 Mtetra
.783 .693 .765 r
.39225 .47356 .39888 .48403 .41047 .4729 .4039 .4616 Mtetra
.72 .661 .791 r
.4039 .4616 .41047 .4729 .42206 .46144 .41538 .4542 Mtetra
.664 .729 .898 r
.41538 .4542 .42206 .46144 .43343 .45734 .42678 .45047 Mtetra
.664 .741 .907 r
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74675 .35578 .74097 .34768 Mtetra
.531 .67 .926 r
.74097 .34768 .74675 .35578 .76012 .35961 .75406 .34727 Mtetra
.412 .504 .844 r
.75406 .34727 .76012 .35961 .77359 .36314 .76761 .35158 Mtetra
.472 .555 .86 r
.76761 .35158 .77359 .36314 .78686 .36278 .78112 .3539 Mtetra
.657 .709 .887 r
.78112 .3539 .78686 .36278 .79958 .3549 .7942 .34985 Mtetra
.859 .872 .847 r
.7942 .34985 .79958 .3549 .8117 .34011 .8066 .33741 Mtetra
.911 .935 .813 r
.8066 .33741 .8117 .34011 .82424 .33014 .81874 .32223 Mtetra
.664 .741 .907 r
.81874 .32223 .82424 .33014 .83737 .32586 .83191 .31793 Mtetra
.83191 .31793 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.634 .728 .916 r
.85843 .30925 .8638 .31726 .87725 .31421 .87188 .30585 Mtetra
.631 .718 .909 r
.87188 .30585 .87725 .31421 .89068 .31042 .88542 .30256 Mtetra
.711 .751 .884 r
.28593 .4896 .29299 .49617 .30395 .49156 .29696 .48442 Mtetra
.676 .729 .89 r
.29696 .48442 .30395 .49156 .31494 .48706 .30794 .48042 Mtetra
.664 .741 .907 r
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.31895 .4768 .32592 .48347 .33694 .47986 .33 .47317 Mtetra
.53 .697 .945 r
.33 .47317 .33694 .47986 .348 .47624 .34092 .47256 Mtetra
.526 0 0 r
.34092 .47256 .348 .47624 .35859 .48311 .35148 .48022 Mtetra
.139 .634 .912 r
.35148 .48022 .35859 .48311 .36941 .48738 .36247 .48154 Mtetra
.755 .786 .879 r
.36247 .48154 .36941 .48738 .38068 .48356 .37392 .47457 Mtetra
.793 .719 .782 r
.37392 .47457 .38068 .48356 .39225 .47356 .38559 .46297 Mtetra
.781 .692 .765 r
.38559 .46297 .39225 .47356 .4039 .4616 .39727 .45105 Mtetra
.655 .65 .833 r
.39727 .45105 .4039 .4616 .41538 .4542 .40865 .4473 Mtetra
.664 .741 .907 r
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75406 .34727 .74803 .33569 Mtetra
.399 .513 .858 r
.74803 .33569 .75406 .34727 .76761 .35158 .76158 .33989 Mtetra
.414 .52 .857 r
.76158 .33989 .76761 .35158 .78112 .3539 .77523 .34378 Mtetra
.563 .637 .883 r
.77523 .34378 .78112 .3539 .7942 .34985 .78862 .34292 Mtetra
.792 .81 .867 r
.78862 .34292 .7942 .34985 .8066 .33741 .80135 .33347 Mtetra
.912 .899 .8 r
.80135 .33347 .8066 .33741 .81874 .32223 .81348 .31742 Mtetra
.758 .874 .932 r
.81348 .31742 .81874 .32223 .83191 .31793 .8264 .30992 Mtetra
.664 .741 .907 r
.8264 .30992 .83191 .31793 .84514 .3136 .83968 .30556 Mtetra
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.651 .736 .911 r
.85301 .30117 .85843 .30925 .87188 .30585 .86645 .29718 Mtetra
.614 .703 .908 r
.86645 .29718 .87188 .30585 .88542 .30256 .88009 .29443 Mtetra
.715 .747 .877 r
.27884 .48279 .28593 .4896 .29696 .48442 .28991 .47736 Mtetra
.664 .729 .898 r
.28991 .47736 .29696 .48442 .30794 .48042 .30089 .47373 Mtetra
.664 .741 .907 r
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
.31192 .47008 .31895 .4768 .33 .47317 .323 .46642 Mtetra
.239 .555 .933 r
.323 .46642 .33 .47317 .34092 .47256 .33373 .46957 Mtetra
.475 0 0 r
.33373 .46957 .34092 .47256 .35148 .48022 .34436 .47602 Mtetra
.527 .79 .993 r
.34436 .47602 .35148 .48022 .36247 .48154 .35553 .47442 Mtetra
.784 .756 .828 r
.35553 .47442 .36247 .48154 .37392 .47457 .36713 .4651 Mtetra
.796 .713 .772 r
.36713 .4651 .37392 .47457 .38559 .46297 .37887 .45271 Mtetra
.745 .688 .796 r
.37887 .45271 .38559 .46297 .39727 .45105 .39045 .44413 Mtetra
.664 .741 .907 r
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.472 .652 .938 r
.74223 .32784 .74803 .33569 .76158 .33989 .75555 .32852 Mtetra
.374 .506 .862 r
.75555 .32852 .76158 .33989 .77523 .34378 .76928 .33317 Mtetra
.484 .586 .881 r
.76928 .33317 .77523 .34378 .78862 .34292 .78288 .33465 Mtetra
.719 .755 .88 r
.78288 .33465 .78862 .34292 .80135 .33347 .79592 .32816 Mtetra
.887 .866 .813 r
.79592 .32816 .80135 .33347 .81348 .31742 .80824 .31331 Mtetra
.85 .91 .875 r
.80824 .31331 .81348 .31742 .8264 .30992 .82085 .30185 Mtetra
.664 .741 .907 r
.82085 .30185 .8264 .30992 .83968 .30556 .83417 .29745 Mtetra
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .86645 .29718 .86098 .28858 Mtetra
.606 .703 .912 r
.86098 .28858 .86645 .29718 .88009 .29443 .87469 .28602 Mtetra
.705 .74 .878 r
.2717 .47574 .27884 .48279 .28991 .47736 .28278 .47064 Mtetra
.664 .741 .907 r
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.29379 .46698 .30089 .47373 .31192 .47008 .30485 .46331 Mtetra
.30485 .46331 .31192 .47008 .323 .46642 .31595 .45962 Mtetra
0 .332 .8 r
.31595 .45962 .323 .46642 .33373 .46957 .3265 .46585 Mtetra
0 .321 .695 r
.3265 .46585 .33373 .46957 .34436 .47602 .33725 .47067 Mtetra
.675 .792 .937 r
.33725 .47067 .34436 .47602 .35553 .47442 .34858 .46656 Mtetra
.796 .742 .803 r
.34858 .46656 .35553 .47442 .36713 .4651 .36029 .45568 Mtetra
.8 .715 .771 r
.36029 .45568 .36713 .4651 .37887 .45271 .37209 .44296 Mtetra
.703 .685 .83 r
.37209 .44296 .37887 .45271 .39045 .44413 .38357 .43715 Mtetra
.664 .741 .907 r
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.594 .712 .926 r
.73638 .31992 .74223 .32784 .75555 .32852 .74952 .31769 Mtetra
.347 .503 .871 r
.74952 .31769 .75555 .32852 .76928 .33317 .76329 .32258 Mtetra
.421 .553 .883 r
.76329 .32258 .76928 .33317 .78288 .33465 .77704 .32561 Mtetra
.65 .709 .891 r
.77704 .32561 .78288 .33465 .79592 .32816 .79034 .32166 Mtetra
.855 .836 .826 r
.79034 .32166 .79592 .32816 .80824 .31331 .80287 .30844 Mtetra
.891 .883 .819 r
.80287 .30844 .80824 .31331 .82085 .30185 .81525 .29371 Mtetra
.664 .741 .907 r
.81525 .29371 .82085 .30185 .83417 .29745 .82861 .28927 Mtetra
.82861 .28927 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.617 .72 .919 r
.85551 .28033 .86098 .28858 .87469 .28602 .86923 .27735 Mtetra
.694 .736 .883 r
.26451 .46857 .2717 .47574 .28278 .47064 .27559 .46388 Mtetra
.664 .741 .907 r
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.28663 .46019 .29379 .46698 .30485 .46331 .29771 .45649 Mtetra
.66 .74 .909 r
.29771 .45649 .30485 .46331 .31595 .45962 .30884 .45287 Mtetra
0 .133 .625 r
.30884 .45287 .31595 .45962 .3265 .46585 .31926 .46133 Mtetra
.049 .523 .889 r
.31926 .46133 .3265 .46585 .33725 .47067 .33012 .46449 Mtetra
.731 .777 .89 r
.33012 .46449 .33725 .47067 .34858 .46656 .34158 .45842 Mtetra
.805 .738 .791 r
.34158 .45842 .34858 .46656 .36029 .45568 .35339 .44653 Mtetra
.802 .721 .775 r
.35339 .44653 .36029 .45568 .37209 .44296 .36522 .43394 Mtetra
.66 .687 .864 r
.36522 .43394 .37209 .44296 .38357 .43715 .37664 .43012 Mtetra
.664 .741 .907 r
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .379 Mtetra
.52968 .379 .53618 .38644 .54828 .38242 .54181 .37495 Mtetra
.54181 .37495 .54828 .38242 .56044 .37838 .554 .37088 Mtetra
.554 .37088 .56044 .37838 .57264 .37432 .56624 .36679 Mtetra
.56624 .36679 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74952 .31769 .74351 .30757 Mtetra
.331 .513 .885 r
.74351 .30757 .74952 .31769 .76329 .32258 .75728 .31227 Mtetra
.37 .532 .886 r
.75728 .31227 .76329 .32258 .77704 .32561 .77114 .31628 Mtetra
.59 .676 .9 r
.77114 .31628 .77704 .32561 .79034 .32166 .78463 .31428 Mtetra
.822 .81 .839 r
.78463 .31428 .79034 .32166 .80287 .30844 .79738 .30271 Mtetra
.905 .856 .783 r
.79738 .30271 .80287 .30844 .81525 .29371 .80962 .2856 Mtetra
.667 .745 .909 r
.80962 .2856 .81525 .29371 .82861 .28927 .82301 .28102 Mtetra
.664 .741 .907 r
.82301 .28102 .82861 .28927 .84203 .28481 .83647 .27652 Mtetra
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.631 .727 .916 r
.85 .272 .85551 .28033 .86923 .27735 .86371 .26853 Mtetra
.681 .732 .889 r
.25728 .46133 .26451 .46857 .27559 .46388 .26834 .45706 Mtetra
.664 .741 .907 r
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.27941 .45334 .28663 .46019 .29771 .45649 .29052 .44961 Mtetra
.59 .719 .933 r
.29052 .44961 .29771 .45649 .30884 .45287 .30156 .44774 Mtetra
.489 0 0 r
.30156 .44774 .30884 .45287 .31926 .46133 .31199 .45602 Mtetra
.274 .635 .964 r
.31199 .45602 .31926 .46133 .33012 .46449 .32295 .45778 Mtetra
.757 .767 .861 r
.32295 .45778 .33012 .46449 .34158 .45842 .33454 .45032 Mtetra
.811 .741 .786 r
.33454 .45032 .34158 .45842 .35339 .44653 .34642 .43784 Mtetra
.79 .728 .795 r
.34642 .43784 .35339 .44653 .36522 .43394 .35821 .42688 Mtetra
.664 .741 .907 r
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37557 Mtetra
.511 .37557 .51759 .38304 .52968 .379 .52312 .37151 Mtetra
.52312 .37151 .52968 .379 .54181 .37495 .53529 .36742 Mtetra
.53529 .36742 .54181 .37495 .554 .37088 .54751 .36331 Mtetra
.54751 .36331 .554 .37088 .56624 .36679 .55979 .35919 Mtetra
.55979 .35919 .56624 .36679 .57854 .36268 .57212 .35505 Mtetra
.57212 .35505 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.352 .585 .931 r
.7376 .29948 .74351 .30757 .75728 .31227 .75128 .30242 Mtetra
.328 .521 .892 r
.75128 .30242 .75728 .31227 .77114 .31628 .7652 .30696 Mtetra
.541 .654 .909 r
.7652 .30696 .77114 .31628 .78463 .31428 .77884 .30634 Mtetra
.794 .792 .85 r
.77884 .30634 .78463 .31428 .79738 .30271 .79176 .29615 Mtetra
.895 .838 .782 r
.79176 .29615 .79738 .30271 .80962 .2856 .80409 .27917 Mtetra
.722 .818 .925 r
.80409 .27917 .80962 .2856 .82301 .28102 .81736 .2727 Mtetra
.664 .741 .907 r
.81736 .2727 .82301 .28102 .83647 .27652 .83087 .26816 Mtetra
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.646 .733 .912 r
.84444 .26361 .85 .272 .86371 .26853 .85814 .25963 Mtetra
.671 .733 .896 r
.24997 .45415 .25728 .46133 .26834 .45706 .26104 .45018 Mtetra
.664 .741 .907 r
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.27214 .44644 .27941 .45334 .29052 .44961 .28328 .44268 Mtetra
.526 .696 .946 r
.28328 .44268 .29052 .44961 .30156 .44774 .29425 .44202 Mtetra
0 .112 .57 r
.29425 .44202 .30156 .44774 .31199 .45602 .3047 .45005 Mtetra
.4 .677 .972 r
.3047 .45005 .31199 .45602 .32295 .45778 .31575 .4508 Mtetra
.77 .763 .846 r
.31575 .4508 .32295 .45778 .33454 .45032 .32742 .44245 Mtetra
.816 .746 .786 r
.32742 .44245 .33454 .45032 .34642 .43784 .33937 .42963 Mtetra
.781 .737 .813 r
.33937 .42963 .34642 .43784 .35821 .42688 .35114 .41977 Mtetra
.664 .741 .907 r
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37213 Mtetra
.49225 .37213 .49894 .37962 .511 .37557 .50435 .36805 Mtetra
.50435 .36805 .511 .37557 .52312 .37151 .5165 .36395 Mtetra
.5165 .36395 .52312 .37151 .53529 .36742 .52871 .35983 Mtetra
.52871 .35983 .53529 .36742 .54751 .36331 .54097 .35569 Mtetra
.54097 .35569 .54751 .36331 .55979 .35919 .55328 .35153 Mtetra
.55328 .35153 .55979 .35919 .57212 .35505 .56565 .34736 Mtetra
.56565 .34736 .57212 .35505 .58451 .35089 .57808 .34316 Mtetra
.57808 .34316 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.415 .621 .937 r
.73164 .29132 .7376 .29948 .75128 .30242 .74526 .29306 Mtetra
.294 .515 .898 r
.74526 .29306 .75128 .30242 .7652 .30696 .75923 .29787 Mtetra
.503 .643 .919 r
.75923 .29787 .7652 .30696 .77884 .30634 .77298 .2981 Mtetra
.774 .781 .859 r
.77298 .2981 .77884 .30634 .79176 .29615 .78604 .28889 Mtetra
.885 .822 .781 r
.78604 .28889 .79176 .29615 .80409 .27917 .79845 .27211 Mtetra
.754 .81 .897 r
.79845 .27211 .80409 .27917 .81736 .2727 .81166 .26431 Mtetra
.664 .741 .907 r
.81166 .26431 .81736 .2727 .83087 .26816 .82521 .25973 Mtetra
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.657 .738 .909 r
.83883 .25514 .84444 .26361 .85814 .25963 .85254 .25076 Mtetra
.665 .736 .902 r
.24261 .44706 .24997 .45415 .26104 .45018 .25368 .44326 Mtetra
.664 .741 .907 r
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.26481 .43948 .27214 .44644 .28328 .44268 .27598 .43569 Mtetra
.489 .681 .951 r
.27598 .43569 .28328 .44268 .29425 .44202 .28692 .43564 Mtetra
0 .158 .635 r
.28692 .43564 .29425 .44202 .3047 .45005 .29739 .44349 Mtetra
.457 .684 .963 r
.29739 .44349 .3047 .45005 .31575 .4508 .30849 .44372 Mtetra
.776 .762 .84 r
.30849 .44372 .31575 .4508 .32742 .44245 .32023 .43492 Mtetra
.822 .754 .789 r
.32023 .43492 .32742 .44245 .33937 .42963 .33223 .42193 Mtetra
.779 .75 .826 r
.33223 .42193 .33937 .42963 .35114 .41977 .34401 .4126 Mtetra
.664 .741 .907 r
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.47344 .36868 .48021 .3762 .49225 .37213 .48551 .36458 Mtetra
.48551 .36458 .49225 .37213 .50435 .36805 .49765 .36046 Mtetra
.49765 .36046 .50435 .36805 .5165 .36395 .50983 .35633 Mtetra
.50983 .35633 .5165 .36395 .52871 .35983 .52207 .35217 Mtetra
.52207 .35217 .52871 .35983 .54097 .35569 .53437 .348 Mtetra
.53437 .348 .54097 .35569 .55328 .35153 .54672 .34381 Mtetra
.54672 .34381 .55328 .35153 .56565 .34736 .55913 .3396 Mtetra
.55913 .3396 .56565 .34736 .57808 .34316 .57159 .33537 Mtetra
.57159 .33537 .57808 .34316 .59056 .33895 .58411 .33112 Mtetra
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.445 .637 .938 r
.72563 .28309 .73164 .29132 .74526 .29306 .73924 .28421 Mtetra
.264 .513 .904 r
.73924 .28421 .74526 .29306 .75923 .29787 .75324 .28913 Mtetra
.478 .642 .928 r
.75324 .28913 .75923 .29787 .77298 .2981 .76706 .28975 Mtetra
.764 .777 .864 r
.76706 .28975 .77298 .2981 .78604 .28889 .78022 .28101 Mtetra
.877 .81 .779 r
.78022 .28101 .78604 .28889 .79845 .27211 .79271 .26434 Mtetra
.764 .794 .878 r
.79271 .26434 .79845 .27211 .81166 .26431 .80591 .25585 Mtetra
.664 .741 .907 r
.80591 .25585 .81166 .26431 .82521 .25973 .81951 .25123 Mtetra
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.663 .74 .908 r
.83317 .24659 .83883 .25514 .85254 .25076 .8469 .24198 Mtetra
.665 .741 .907 r
.23516 .4401 .24261 .44706 .25368 .44326 .24627 .43627 Mtetra
.664 .741 .907 r
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.25742 .43247 .26481 .43948 .27598 .43569 .26862 .42865 Mtetra
.489 .681 .951 r
.26862 .42865 .27598 .43569 .28692 .43564 .27958 .42857 Mtetra
0 .188 .679 r
.27958 .42857 .28692 .43564 .29739 .44349 .29005 .43642 Mtetra
.47 .673 .953 r
.29005 .43642 .29739 .44349 .30849 .44372 .30116 .43662 Mtetra
.777 .763 .841 r
.30116 .43662 .30849 .44372 .32023 .43492 .31295 .42778 Mtetra
.826 .764 .793 r
.31295 .42778 .32023 .43492 .33223 .42193 .325 .41475 Mtetra
.784 .763 .834 r
.325 .41475 .33223 .42193 .34401 .4126 .33683 .40538 Mtetra
.664 .741 .907 r
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.46661 .3611 .47344 .36868 .48551 .36458 .47872 .35696 Mtetra
.47872 .35696 .48551 .36458 .49765 .36046 .49089 .35281 Mtetra
.49089 .35281 .49765 .36046 .50983 .35633 .50311 .34864 Mtetra
.50311 .34864 .50983 .35633 .52207 .35217 .51539 .34445 Mtetra
.51539 .34445 .52207 .35217 .53437 .348 .52772 .34025 Mtetra
.52772 .34025 .53437 .348 .54672 .34381 .5401 .33602 Mtetra
.5401 .33602 .54672 .34381 .55913 .3396 .55255 .33177 Mtetra
.55255 .33177 .55913 .3396 .57159 .33537 .56505 .32751 Mtetra
.56505 .32751 .57159 .33537 .58411 .33112 .5776 .32323 Mtetra
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.445 .637 .938 r
.71957 .27479 .72563 .28309 .73924 .28421 .73321 .27588 Mtetra
.238 .515 .91 r
.73321 .27588 .73924 .28421 .75324 .28913 .74724 .28077 Mtetra
.469 .651 .938 r
.74724 .28077 .75324 .28913 .76706 .28975 .76109 .28136 Mtetra
.764 .778 .865 r
.76109 .28136 .76706 .28975 .78022 .28101 .7743 .27258 Mtetra
.872 .799 .776 r
.7743 .27258 .78022 .28101 .79271 .26434 .78686 .25585 Mtetra
.759 .776 .867 r
.78686 .25585 .79271 .26434 .80591 .25585 .80011 .24731 Mtetra
.664 .741 .907 r
.80011 .24731 .80591 .25585 .81951 .25123 .81375 .24265 Mtetra
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.663 .74 .908 r
.82746 .23797 .83317 .24659 .8469 .24198 .84124 .23332 Mtetra
.672 .748 .908 r
.22764 .43329 .23516 .4401 .24627 .43627 .23879 .42924 Mtetra
.664 .741 .907 r
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.24997 .4254 .25742 .43247 .26862 .42865 .2612 .42155 Mtetra
.526 .696 .946 r
.2612 .42155 .26862 .42865 .27958 .42857 .27223 .42082 Mtetra
0 .201 .703 r
.27223 .42082 .27958 .42857 .29005 .43642 .28268 .42882 Mtetra
.448 .649 .944 r
.28268 .42882 .29005 .43642 .30116 .43662 .29378 .42951 Mtetra
.77 .764 .847 r
.29378 .42951 .30116 .43662 .31295 .42778 .30558 .42104 Mtetra
.83 .773 .798 r
.30558 .42104 .31295 .42778 .325 .41475 .31768 .40808 Mtetra
.798 .778 .834 r
.31768 .40808 .325 .41475 .33683 .40538 .32959 .39809 Mtetra
.664 .741 .907 r
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.45972 .35345 .46661 .3611 .47872 .35696 .47187 .34928 Mtetra
.47187 .34928 .47872 .35696 .49089 .35281 .48407 .3451 Mtetra
.48407 .3451 .49089 .35281 .50311 .34864 .49633 .34089 Mtetra
.49633 .34089 .50311 .34864 .51539 .34445 .50864 .33667 Mtetra
.50864 .33667 .51539 .34445 .52772 .34025 .52101 .33243 Mtetra
.52101 .33243 .52772 .34025 .5401 .33602 .53343 .32817 Mtetra
.53343 .32817 .5401 .33602 .55255 .33177 .54591 .32389 Mtetra
.54591 .32389 .55255 .33177 .56505 .32751 .55845 .31959 Mtetra
.55845 .31959 .56505 .32751 .5776 .32323 .57104 .31527 Mtetra
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.415 .621 .937 r
.71345 .26641 .71957 .27479 .73321 .27588 .72717 .26806 Mtetra
.217 .521 .916 r
.72717 .26806 .73321 .27588 .74724 .28077 .74122 .27281 Mtetra
.48 .671 .948 r
.74122 .27281 .74724 .28077 .76109 .28136 .75508 .27294 Mtetra
.775 .782 .859 r
.75508 .27294 .76109 .28136 .7743 .27258 .7683 .26359 Mtetra
.868 .788 .77 r
.7683 .26359 .7743 .27258 .78686 .25585 .7809 .24663 Mtetra
.741 .754 .863 r
.7809 .24663 .78686 .25585 .80011 .24731 .79426 .2387 Mtetra
.664 .741 .907 r
.79426 .2387 .80011 .24731 .81375 .24265 .80795 .234 Mtetra
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.657 .738 .909 r
.82171 .22928 .82746 .23797 .84124 .23332 .83555 .22478 Mtetra
.683 .755 .906 r
.22005 .42658 .22764 .43329 .23879 .42924 .23126 .42215 Mtetra
.664 .741 .907 r
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.24247 .41828 .24997 .4254 .2612 .42155 .25372 .4144 Mtetra
.59 .719 .933 r
.25372 .4144 .2612 .42155 .27223 .42082 .26488 .4124 Mtetra
0 .203 .715 r
.26488 .4124 .27223 .42082 .28268 .42882 .2753 .42063 Mtetra
.395 .607 .933 r
.2753 .42063 .28268 .42882 .29378 .42951 .28634 .42229 Mtetra
.755 .761 .857 r
.28634 .42229 .29378 .42951 .30558 .42104 .29812 .41464 Mtetra
.831 .782 .806 r
.29812 .41464 .30558 .42104 .31768 .40808 .31026 .40193 Mtetra
.818 .791 .827 r
.31026 .40193 .31768 .40808 .32959 .39809 .32229 .39075 Mtetra
.664 .741 .907 r
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34928 .46497 .34154 Mtetra
.46497 .34154 .47187 .34928 .48407 .3451 .4772 .33732 Mtetra
.4772 .33732 .48407 .3451 .49633 .34089 .4895 .33308 Mtetra
.4895 .33308 .49633 .34089 .50864 .33667 .50184 .32882 Mtetra
.50184 .32882 .50864 .33667 .52101 .33243 .51425 .32455 Mtetra
.51425 .32455 .52101 .33243 .53343 .32817 .52671 .32025 Mtetra
.52671 .32025 .53343 .32817 .54591 .32389 .53922 .31593 Mtetra
.53922 .31593 .54591 .32389 .55845 .31959 .5518 .31159 Mtetra
.5518 .31159 .55845 .31959 .57104 .31527 .56443 .30724 Mtetra
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.352 .585 .931 r
.70729 .25797 .71345 .26641 .72717 .26806 .72111 .26078 Mtetra
.207 .534 .924 r
.72111 .26078 .72717 .26806 .74122 .27281 .73518 .26519 Mtetra
.513 .701 .955 r
.73518 .26519 .74122 .27281 .75508 .27294 .74901 .2644 Mtetra
.792 .785 .847 r
.74901 .2644 .75508 .27294 .7683 .26359 .7622 .25398 Mtetra
.864 .777 .764 r
.7622 .25398 .7683 .26359 .7809 .24663 .77485 .23669 Mtetra
.709 .727 .864 r
.77485 .23669 .7809 .24663 .79426 .2387 .78836 .23001 Mtetra
.664 .741 .907 r
.78836 .23001 .79426 .2387 .80795 .234 .80209 .22527 Mtetra
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.646 .733 .912 r
.8159 .22051 .82171 .22928 .83555 .22478 .82983 .21633 Mtetra
.697 .761 .901 r
.21238 .41991 .22005 .42658 .23126 .42215 .22367 .415 Mtetra
.664 .741 .907 r
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.2349 .4111 .24247 .41828 .25372 .4144 .24619 .40719 Mtetra
.66 .74 .909 r
.24619 .40719 .25372 .4144 .26488 .4124 .25751 .40336 Mtetra
0 .208 .725 r
.25751 .40336 .26488 .4124 .2753 .42063 .26791 .41176 Mtetra
.313 .544 .914 r
.26791 .41176 .2753 .42063 .28634 .42229 .27886 .41479 Mtetra
.726 .751 .872 r
.27886 .41479 .28634 .42229 .29812 .41464 .29058 .40848 Mtetra
.829 .79 .815 r
.29058 .40848 .29812 .41464 .31026 .40193 .30273 .39627 Mtetra
.842 .801 .812 r
.30273 .39627 .31026 .40193 .32229 .39075 .31493 .38335 Mtetra
.664 .741 .907 r
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33732 .47027 .32948 Mtetra
.47027 .32948 .4772 .33732 .4895 .33308 .4826 .32521 Mtetra
.4826 .32521 .4895 .33308 .50184 .32882 .49499 .32091 Mtetra
.49499 .32091 .50184 .32882 .51425 .32455 .50743 .3166 Mtetra
.50743 .3166 .51425 .32455 .52671 .32025 .51992 .31226 Mtetra
.51992 .31226 .52671 .32025 .53922 .31593 .53248 .30791 Mtetra
.53248 .30791 .53922 .31593 .5518 .31159 .54509 .30354 Mtetra
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.252 .524 .914 r
.70106 .24945 .70729 .25797 .72111 .26078 .71503 .25398 Mtetra
.214 .558 .935 r
.71503 .25398 .72111 .26078 .73518 .26519 .72909 .25781 Mtetra
.572 .739 .955 r
.72909 .25781 .73518 .26519 .74901 .2644 .74287 .25556 Mtetra
.812 .785 .827 r
.74287 .25556 .74901 .2644 .7622 .25398 .756 .24363 Mtetra
.858 .764 .758 r
.756 .24363 .7622 .25398 .77485 .23669 .76869 .22611 Mtetra
.663 .695 .87 r
.76869 .22611 .77485 .23669 .78836 .23001 .7824 .22124 Mtetra
.664 .741 .907 r
.7824 .22124 .78836 .23001 .80209 .22527 .79619 .21646 Mtetra
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.631 .727 .916 r
.81004 .21166 .8159 .22051 .82983 .21633 .82406 .20791 Mtetra
.709 .763 .894 r
.20465 .41318 .21238 .41991 .22367 .415 .21601 .40779 Mtetra
.664 .741 .907 r
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.22728 .40386 .2349 .4111 .24619 .40719 .23859 .39992 Mtetra
.23859 .39992 .24619 .40719 .25751 .40336 .24995 .39596 Mtetra
0 .335 .804 r
.24995 .39596 .25751 .40336 .26791 .41176 .26054 .40208 Mtetra
.209 .463 .881 r
.26054 .40208 .26791 .41176 .27886 .41479 .27135 .40676 Mtetra
.674 .727 .889 r
.27135 .40676 .27886 .41479 .29058 .40848 .28296 .40236 Mtetra
.819 .793 .828 r
.28296 .40236 .29058 .40848 .30273 .39627 .2951 .39108 Mtetra
.848 .813 .815 r
.2951 .39108 .30273 .39627 .31493 .38335 .30737 .37795 Mtetra
.73 .815 .917 r
.30737 .37795 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.664 .741 .907 r
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32521 .47565 .31726 Mtetra
.47565 .31726 .4826 .32521 .49499 .32091 .48807 .31293 Mtetra
.48807 .31293 .49499 .32091 .50743 .3166 .50055 .30858 Mtetra
.50055 .30858 .50743 .3166 .51992 .31226 .51308 .30421 Mtetra
.51308 .30421 .51992 .31226 .53248 .30791 .52568 .29982 Mtetra
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.594 .712 .926 r
.68141 .24552 .68773 .25407 .70106 .24945 .69491 .24298 Mtetra
.128 .514 .912 r
.69491 .24298 .70106 .24945 .71503 .25398 .70892 .24765 Mtetra
.255 .603 .953 r
.70892 .24765 .71503 .25398 .72909 .25781 .72296 .25045 Mtetra
.648 .774 .94 r
.72296 .25045 .72909 .25781 .74287 .25556 .73664 .24615 Mtetra
.829 .777 .803 r
.73664 .24615 .74287 .25556 .756 .24363 .7497 .23244 Mtetra
.828 .745 .772 r
.7497 .23244 .756 .24363 .76869 .22611 .76263 .2172 Mtetra
.664 .738 .905 r
.76263 .2172 .76869 .22611 .7824 .22124 .7764 .2124 Mtetra
.664 .741 .907 r
.7764 .2124 .7824 .22124 .79619 .21646 .79023 .20758 Mtetra
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.617 .72 .919 r
.80412 .20273 .81004 .21166 .82406 .20791 .81824 .19941 Mtetra
.718 .762 .887 r
.19687 .40632 .20465 .41318 .21601 .40779 .2083 .40053 Mtetra
.664 .741 .907 r
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23859 .39992 .23093 .39259 Mtetra
.23093 .39259 .23859 .39992 .24995 .39596 .24232 .3886 Mtetra
.239 .555 .933 r
.24232 .3886 .24995 .39596 .26054 .40208 .25318 .39154 Mtetra
.105 .377 .838 r
.25318 .39154 .26054 .40208 .27135 .40676 .26385 .39786 Mtetra
.588 .678 .902 r
.26385 .39786 .27135 .40676 .28296 .40236 .27529 .39596 Mtetra
.796 .789 .846 r
.27529 .39596 .28296 .40236 .2951 .39108 .28737 .3862 Mtetra
.849 .822 .822 r
.28737 .3862 .2951 .39108 .30737 .37795 .29969 .37328 Mtetra
.799 .84 .882 r
.29969 .37328 .30737 .37795 .31918 .37182 .31173 .36426 Mtetra
.664 .741 .907 r
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.472 .652 .938 r
.67504 .23689 .68141 .24552 .69491 .24298 .68873 .23724 Mtetra
.096 .52 .907 r
.68873 .23724 .69491 .24298 .70892 .24765 .70276 .24162 Mtetra
.347 .672 .976 r
.70276 .24162 .70892 .24765 .72296 .25045 .71675 .24278 Mtetra
.726 .794 .906 r
.71675 .24278 .72296 .25045 .73664 .24615 .7303 .23582 Mtetra
.839 .763 .778 r
.7303 .23582 .73664 .24615 .7497 .23244 .7433 .22034 Mtetra
.781 .717 .791 r
.7433 .22034 .7497 .23244 .76263 .2172 .75653 .20832 Mtetra
.664 .741 .907 r
.75653 .20832 .76263 .2172 .7764 .2124 .77034 .20348 Mtetra
.77034 .20348 .7764 .2124 .79023 .20758 .78421 .19862 Mtetra
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.604 .714 .922 r
.79816 .19373 .80412 .20273 .81824 .19941 .81236 .19074 Mtetra
.712 .756 .887 r
.18903 .39922 .19687 .40632 .2083 .40053 .20048 .39361 Mtetra
.678 .756 .91 r
.20048 .39361 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.664 .741 .907 r
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.22321 .3852 .23093 .39259 .24232 .3886 .23463 .38118 Mtetra
.53 .697 .945 r
.23463 .38118 .24232 .3886 .25318 .39154 .24583 .38024 Mtetra
.035 .313 .801 r
.24583 .38024 .25318 .39154 .26385 .39786 .25639 .38778 Mtetra
.462 .594 .898 r
.25639 .38778 .26385 .39786 .27529 .39596 .26761 .38881 Mtetra
.751 .769 .868 r
.26761 .38881 .27529 .39596 .28737 .3862 .27956 .38136 Mtetra
.842 .827 .833 r
.27956 .38136 .28737 .3862 .29969 .37328 .29188 .36916 Mtetra
.853 .845 .836 r
.29188 .36916 .29969 .37328 .31173 .36426 .30422 .35664 Mtetra
.664 .741 .907 r
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.283 .545 .921 r
.66861 .22819 .67504 .23689 .68873 .23724 .68251 .23206 Mtetra
.116 .555 .918 r
.68251 .23206 .68873 .23724 .70276 .24162 .69655 .23563 Mtetra
.492 .754 .988 r
.69655 .23563 .70276 .24162 .71675 .24278 .71043 .23433 Mtetra
.786 .792 .857 r
.71043 .23433 .71675 .24278 .7303 .23582 .72384 .22426 Mtetra
.839 .743 .758 r
.72384 .22426 .7303 .23582 .7433 .22034 .7368 .20744 Mtetra
.715 .678 .813 r
.7368 .20744 .7433 .22034 .75653 .20832 .75037 .19937 Mtetra
.664 .741 .907 r
.75037 .19937 .75653 .20832 .77034 .20348 .76422 .19448 Mtetra
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.651 .736 .911 r
.77815 .18957 .78421 .19862 .79816 .19373 .79218 .18506 Mtetra
.61 .729 .93 r
.79218 .18506 .79816 .19373 .81236 .19074 .8064 .18181 Mtetra
.696 .748 .891 r
.18116 .39185 .18903 .39922 .20048 .39361 .19258 .38677 Mtetra
.695 .763 .904 r
.19258 .38677 .20048 .39361 .21184 .38921 .20403 .3818 Mtetra
.664 .741 .907 r
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.21543 .37776 .22321 .3852 .23463 .38118 .22688 .3737 Mtetra
.22688 .3737 .23463 .38118 .24583 .38024 .23838 .36962 Mtetra
.062 .35 .824 r
.23838 .36962 .24583 .38024 .25639 .38778 .249 .37632 Mtetra
.311 .482 .867 r
.249 .37632 .25639 .38778 .26761 .38881 .25997 .38034 Mtetra
.667 .719 .888 r
.25997 .38034 .26761 .38881 .27956 .38136 .2717 .37604 Mtetra
.818 .82 .851 r
.2717 .37604 .27956 .38136 .29188 .36916 .28397 .3654 Mtetra
.857 .855 .838 r
.28397 .3654 .29188 .36916 .30422 .35664 .29638 .35275 Mtetra
.78 .869 .914 r
.29638 .35275 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.664 .741 .907 r
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.524 .679 .936 r
.64867 .22417 .6552 .23291 .66861 .22819 .66229 .22329 Mtetra
.058 .525 .893 r
.66229 .22329 .66861 .22819 .68251 .23206 .67625 .22723 Mtetra
.22 .64 .955 r
.67625 .22723 .68251 .23206 .69655 .23563 .69025 .22913 Mtetra
.651 .808 .958 r
.69025 .22913 .69655 .23563 .71043 .23433 .70399 .2245 Mtetra
.819 .77 .807 r
.70399 .2245 .71043 .23433 .72384 .22426 .71725 .21126 Mtetra
.818 .717 .754 r
.71725 .21126 .72384 .22426 .7368 .20744 .73031 .19523 Mtetra
.655 .665 .847 r
.73031 .19523 .7368 .20744 .75037 .19937 .74415 .19033 Mtetra
.664 .741 .907 r
.74415 .19033 .75037 .19937 .76422 .19448 .75805 .1854 Mtetra
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.634 .728 .916 r
.77203 .18045 .77815 .18957 .79218 .18506 .78615 .17646 Mtetra
.629 .741 .928 r
.78615 .17646 .79218 .18506 .8064 .18181 .80037 .17258 Mtetra
.681 .739 .895 r
.17325 .38423 .18116 .39185 .19258 .38677 .18464 .37964 Mtetra
.702 .758 .895 r
.18464 .37964 .19258 .38677 .20403 .3818 .19615 .37432 Mtetra
.664 .741 .907 r
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22688 .3737 .21906 .36616 Mtetra
.21906 .36616 .22688 .3737 .23838 .36962 .23059 .36205 Mtetra
.359 .619 .95 r
.23059 .36205 .23838 .36962 .249 .37632 .24167 .36361 Mtetra
.186 .379 .822 r
.24167 .36361 .249 .37632 .25997 .38034 .25242 .37 Mtetra
.532 .624 .889 r
.25242 .37 .25997 .38034 .2717 .37604 .26386 .36952 Mtetra
.765 .791 .875 r
.26386 .36952 .2717 .37604 .28397 .3654 .27597 .36154 Mtetra
.847 .857 .85 r
.27597 .36154 .28397 .3654 .29638 .35275 .28839 .34964 Mtetra
.858 .877 .852 r
.28839 .34964 .29638 .35275 .30846 .34478 .30083 .33741 Mtetra
.677 .756 .91 r
.30083 .33741 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.664 .741 .907 r
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.651 .736 .911 r
.62866 .22014 .63529 .22892 .64867 .22417 .6421 .21578 Mtetra
.288 .562 .93 r
.6421 .21578 .64867 .22417 .66229 .22329 .65594 .21919 Mtetra
.064 .557 .891 r
.65594 .21919 .66229 .22329 .67625 .22723 .66991 .22228 Mtetra
.427 .76 .996 r
.66991 .22228 .67625 .22723 .69025 .22913 .68381 .22137 Mtetra
.763 .807 .888 r
.68381 .22137 .69025 .22913 .70399 .2245 .69738 .21272 Mtetra
.827 .739 .767 r
.69738 .21272 .70399 .2245 .71725 .21126 .71054 .19696 Mtetra
.746 .673 .78 r
.71054 .19696 .71725 .21126 .73031 .19523 .72399 .18616 Mtetra
.664 .741 .907 r
.72399 .18616 .73031 .19523 .74415 .19033 .73788 .18121 Mtetra
.73788 .18121 .74415 .19033 .75805 .1854 .75183 .17624 Mtetra
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.624 .724 .918 r
.76585 .17124 .77203 .18045 .78615 .17646 .78005 .16752 Mtetra
.647 .742 .919 r
.78005 .16752 .78615 .17646 .80037 .17258 .79427 .16306 Mtetra
.668 .732 .898 r
.16528 .37641 .17325 .38423 .18464 .37964 .17666 .3722 Mtetra
.703 .751 .889 r
.17666 .3722 .18464 .37964 .19615 .37432 .18821 .36679 Mtetra
.664 .741 .907 r
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.21118 .35856 .21906 .36616 .23059 .36205 .22274 .35441 Mtetra
.663 .741 .908 r
.22274 .35441 .23059 .36205 .24167 .36361 .23435 .35027 Mtetra
.141 .339 .8 r
.23435 .35027 .24167 .36361 .25242 .37 .24501 .35753 Mtetra
.368 .495 .856 r
.24501 .35753 .25242 .37 .26386 .36952 .25612 .3609 Mtetra
.66 .718 .891 r
.25612 .3609 .26386 .36952 .27597 .36154 .26796 .35672 Mtetra
.812 .84 .871 r
.26796 .35672 .27597 .36154 .28839 .34964 .28029 .34677 Mtetra
.857 .885 .857 r
.28029 .34677 .28839 .34964 .30083 .33741 .29279 .3347 Mtetra
.822 .903 .897 r
.29279 .3347 .30083 .33741 .31276 .33276 .30513 .32488 Mtetra
.664 .741 .907 r
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.44 .637 .939 r
.62197 .21129 .62866 .22014 .6421 .21578 .63565 .21214 Mtetra
.015 .534 .86 r
.63565 .21214 .6421 .21578 .65594 .21919 .64953 .21531 Mtetra
.218 .673 .948 r
.64953 .21531 .65594 .21919 .66991 .22228 .66346 .21633 Mtetra
.655 .83 .967 r
.66346 .21633 .66991 .22228 .68381 .22137 .67721 .21143 Mtetra
.811 .768 .813 r
.67721 .21143 .68381 .22137 .69738 .21272 .69061 .19874 Mtetra
.815 .705 .743 r
.69061 .19874 .69738 .21272 .71054 .19696 .70376 .18199 Mtetra
.645 .618 .808 r
.70376 .18199 .71054 .19696 .72399 .18616 .71762 .177 Mtetra
.664 .741 .907 r
.71762 .177 .72399 .18616 .73788 .18121 .73155 .17201 Mtetra
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.622 .723 .918 r
.75962 .16195 .76585 .17124 .78005 .16752 .77387 .15825 Mtetra
.66 .741 .91 r
.77387 .15825 .78005 .16752 .79427 .16306 .7881 .1533 Mtetra
.66 .729 .901 r
.15726 .36847 .16528 .37641 .17666 .3722 .16864 .36448 Mtetra
.678 .74 .897 r
.16864 .36448 .17666 .3722 .18821 .36679 .18013 .35988 Mtetra
.687 .765 .911 r
.18013 .35988 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.664 .741 .907 r
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22274 .35441 .21482 .34671 Mtetra
.21482 .34671 .22274 .35441 .23435 .35027 .22646 .34251 Mtetra
.411 .644 .952 r
.22646 .34251 .23435 .35027 .24501 .35753 .2377 .34336 Mtetra
.246 .39 .811 r
.2377 .34336 .24501 .35753 .25612 .3609 .24857 .34945 Mtetra
.501 .589 .875 r
.24857 .34945 .25612 .3609 .26796 .35672 .26004 .34977 Mtetra
.73 .78 .893 r
.26004 .34977 .26796 .35672 .28029 .34677 .27215 .34324 Mtetra
.833 .876 .875 r
.27215 .34324 .28029 .34677 .29279 .3347 .28461 .33253 Mtetra
.856 .909 .869 r
.28461 .33253 .29279 .3347 .30513 .32488 .29715 .32074 Mtetra
.78 .869 .914 r
.29715 .32074 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.664 .741 .907 r
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.523 .68 .937 r
.60178 .20721 .60857 .21609 .62197 .21129 .61534 .20626 Mtetra
.144 .587 .929 r
.61534 .20626 .62197 .21129 .63565 .21214 .62913 .20904 Mtetra
.097 .612 .888 r
.62913 .20904 .63565 .21214 .64953 .21531 .64301 .21075 Mtetra
.512 .818 1 r
.64301 .21075 .64953 .21531 .66346 .21633 .65684 .20819 Mtetra
.779 .802 .872 r
.65684 .20819 .66346 .21633 .67721 .21143 .67042 .19856 Mtetra
.815 .72 .761 r
.67042 .19856 .67721 .21143 .69061 .19874 .68371 .18298 Mtetra
.727 .648 .771 r
.68371 .18298 .69061 .19874 .70376 .18199 .69727 .17278 Mtetra
.664 .74 .907 r
.69727 .17278 .70376 .18199 .71762 .177 .71119 .16776 Mtetra
.664 .741 .907 r
.71119 .16776 .71762 .177 .73155 .17201 .72516 .16272 Mtetra
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.643 .732 .913 r
.73921 .15766 .74555 .16699 .75962 .16195 .75338 .15329 Mtetra
.649 .754 .926 r
.75338 .15329 .75962 .16195 .77387 .15825 .76761 .14867 Mtetra
.667 .738 .903 r
.76761 .14867 .77387 .15825 .7881 .1533 .78187 .14341 Mtetra
.656 .729 .903 r
.14917 .3605 .15726 .36847 .16864 .36448 .16057 .35658 Mtetra
.658 .732 .904 r
.16057 .35658 .16864 .36448 .18013 .35988 .17202 .35257 Mtetra
.696 .758 .899 r
.17202 .35257 .18013 .35988 .19169 .35505 .18365 .34736 Mtetra
.664 .741 .907 r
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.20684 .33895 .21482 .34671 .22646 .34251 .21851 .33472 Mtetra
.21851 .33472 .22646 .34251 .2377 .34336 .23024 .33046 Mtetra
.287 .442 .842 r
.23024 .33046 .2377 .34336 .24857 .34945 .24121 .33521 Mtetra
.345 .451 .825 r
.24121 .33521 .24857 .34945 .26004 .34977 .25233 .33951 Mtetra
.582 .655 .887 r
.25233 .33951 .26004 .34977 .27215 .34324 .26408 .3376 Mtetra
.763 .823 .9 r
.26408 .3376 .27215 .34324 .28461 .33253 .27636 .32991 Mtetra
.838 .903 .884 r
.27636 .32991 .28461 .33253 .29715 .32074 .2889 .31912 Mtetra
.849 .929 .881 r
.2889 .31912 .29715 .32074 .30945 .3126 .30149 .30779 Mtetra
.764 .851 .916 r
.30149 .30779 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.664 .741 .907 r
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.547 .692 .934 r
.5815 .20311 .58839 .21203 .60178 .20721 .595 .20155 Mtetra
.222 .619 .954 r
.595 .20155 .60178 .20721 .61534 .20626 .6087 .20377 Mtetra
.046 .588 .846 r
.6087 .20377 .61534 .20626 .62913 .20904 .62251 .20547 Mtetra
.391 .789 .986 r
.62251 .20547 .62913 .20904 .64301 .21075 .63634 .20401 Mtetra
.736 .832 .924 r
.63634 .20401 .64301 .21075 .65684 .20819 .65002 .19661 Mtetra
.808 .739 .787 r
.65002 .19661 .65684 .20819 .67042 .19856 .66345 .18283 Mtetra
.776 .671 .747 r
.66345 .18283 .67042 .19856 .68371 .18298 .67685 .16854 Mtetra
.647 .629 .818 r
.67685 .16854 .68371 .18298 .69727 .17278 .69074 .1635 Mtetra
.664 .741 .907 r
.69074 .1635 .69727 .17278 .71119 .16776 .70469 .15844 Mtetra
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.631 .727 .916 r
.73282 .14824 .73921 .15766 .75338 .15329 .74706 .14419 Mtetra
.669 .753 .913 r
.74706 .14419 .75338 .15329 .76761 .14867 .76129 .13887 Mtetra
.669 .736 .9 r
.76129 .13887 .76761 .14867 .78187 .14341 .77559 .13346 Mtetra
.656 .731 .904 r
.14101 .35255 .14917 .3605 .16057 .35658 .15243 .34859 Mtetra
.65 .729 .907 r
.15243 .34859 .16057 .35658 .17202 .35257 .16388 .34482 Mtetra
.673 .742 .902 r
.16388 .34482 .17202 .35257 .18365 .34736 .17546 .34031 Mtetra
.688 .766 .911 r
.17546 .34031 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.664 .741 .907 r
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21851 .33472 .21049 .32685 Mtetra
.21049 .32685 .21851 .33472 .23024 .33046 .22225 .32256 Mtetra
.621 .728 .923 r
.22225 .32256 .23024 .33046 .24121 .33521 .23395 .31948 Mtetra
.28 .387 .793 r
.23395 .31948 .24121 .33521 .25233 .33951 .24489 .32551 Mtetra
.416 .498 .835 r
.24489 .32551 .25233 .33951 .26408 .3376 .25625 .32823 Mtetra
.622 .694 .896 r
.25625 .32823 .26408 .3376 .27636 .32991 .26819 .3251 Mtetra
.772 .85 .91 r
.26819 .3251 .27636 .32991 .2889 .31912 .28057 .31711 Mtetra
.831 .925 .895 r
.28057 .31711 .2889 .31912 .30149 .30779 .29317 .30666 Mtetra
.838 .947 .892 r
.29317 .30666 .30149 .30779 .31382 .30016 .30579 .29584 Mtetra
.78 .869 .914 r
.30579 .29584 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.664 .741 .907 r
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.521 .68 .938 r
.56114 .19899 .56814 .20795 .5815 .20311 .5746 .19801 Mtetra
.233 .647 .959 r
.5746 .19801 .5815 .20311 .595 .20155 .58822 .19962 Mtetra
.038 .593 .821 r
.58822 .19962 .595 .20155 .6087 .20377 .60196 .20088 Mtetra
.332 .774 .962 r
.60196 .20088 .6087 .20377 .62251 .20547 .61575 .19964 Mtetra
.699 .85 .955 r
.61575 .19964 .62251 .20547 .63634 .20401 .62946 .19343 Mtetra
.798 .754 .813 r
.62946 .19343 .63634 .20401 .65002 .19661 .643 .1812 Mtetra
.792 .682 .742 r
.643 .1812 .65002 .19661 .66345 .18283 .65639 .16553 Mtetra
.658 .598 .776 r
.65639 .16553 .66345 .18283 .67685 .16854 .6702 .15922 Mtetra
.664 .741 .907 r
.6702 .15922 .67685 .16854 .69074 .1635 .68414 .15414 Mtetra
.68414 .15414 .69074 .1635 .70469 .15844 .69814 .14903 Mtetra
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.642 .732 .914 r
.71222 .1439 .71872 .15335 .73282 .14824 .72641 .13948 Mtetra
.655 .757 .925 r
.72641 .13948 .73282 .14824 .74706 .14419 .74065 .1346 Mtetra
.676 .745 .903 r
.74065 .1346 .74706 .14419 .76129 .13887 .75491 .12896 Mtetra
.669 .735 .9 r
.75491 .12896 .76129 .13887 .77559 .13346 .76925 .12351 Mtetra
.659 .735 .906 r
.13277 .34465 .14101 .35255 .15243 .34859 .14422 .34058 Mtetra
.649 .73 .908 r
.14422 .34058 .15243 .34859 .16388 .34482 .1557 .33679 Mtetra
.654 .732 .906 r
.1557 .33679 .16388 .34482 .17546 .34031 .16725 .33283 Mtetra
.693 .757 .9 r
.16725 .33283 .17546 .34031 .18714 .33537 .17898 .32762 Mtetra
.668 .745 .908 r
.17898 .32762 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.664 .741 .907 r
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22225 .32256 .2142 .3146 Mtetra
.2142 .3146 .22225 .32256 .23395 .31948 .22604 .31026 Mtetra
.545 .667 .917 r
.22604 .31026 .23395 .31948 .24489 .32551 .23764 .30905 Mtetra
.329 .407 .791 r
.23764 .30905 .24489 .32551 .25625 .32823 .24875 .31433 Mtetra
.454 .523 .839 r
.24875 .31433 .25625 .32823 .26819 .3251 .26029 .31607 Mtetra
.631 .708 .902 r
.26029 .31607 .26819 .3251 .28057 .31711 .27234 .31262 Mtetra
.763 .863 .923 r
.27234 .31262 .28057 .31711 .29317 .30666 .28478 .30497 Mtetra
.815 .939 .909 r
.28478 .30497 .29317 .30666 .30579 .29584 .2974 .29515 Mtetra
.819 .963 .902 r
.2974 .29515 .30579 .29584 .31826 .28756 .31008 .2849 Mtetra
.813 .917 .908 r
.31008 .2849 .31826 .28756 .33051 .28309 .32272 .27521 Mtetra
.677 .756 .91 r
.32272 .27521 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.664 .741 .907 r
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.651 .736 .912 r
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19528 Mtetra
.446 .656 .949 r
.54069 .19528 .5478 .20385 .56114 .19899 .55413 .19564 Mtetra
.171 .66 .922 r
.55413 .19564 .56114 .19899 .5746 .19801 .56768 .19659 Mtetra
.062 .619 .812 r
.56768 .19659 .5746 .19801 .58822 .19962 .58135 .19712 Mtetra
.342 .79 .955 r
.58135 .19712 .58822 .19962 .60196 .20088 .59508 .19544 Mtetra
.687 .859 .964 r
.59508 .19544 .60196 .20088 .61575 .19964 .60879 .18949 Mtetra
.789 .761 .827 r
.60879 .18949 .61575 .19964 .62946 .19343 .62238 .17819 Mtetra
.787 .682 .748 r
.62238 .17819 .62946 .19343 .643 .1812 .63586 .16323 Mtetra
.685 .606 .761 r
.63586 .16323 .643 .1812 .65639 .16553 .64958 .15492 Mtetra
.661 .709 .883 r
.64958 .15492 .65639 .16553 .6702 .15922 .6635 .14982 Mtetra
.664 .741 .907 r
.6635 .14982 .6702 .15922 .68414 .15414 .67748 .14469 Mtetra
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.661 .739 .908 r
.69153 .13954 .69814 .14903 .71222 .1439 .70566 .13447 Mtetra
.635 .731 .918 r
.70566 .13447 .71222 .1439 .72641 .13948 .71992 .13024 Mtetra
.673 .754 .912 r
.71992 .13024 .72641 .13948 .74065 .1346 .73417 .12472 Mtetra
.676 .739 .899 r
.73417 .12472 .74065 .1346 .75491 .12896 .74847 .11901 Mtetra
.668 .736 .901 r
.74847 .11901 .75491 .12896 .76925 .12351 .76287 .11358 Mtetra
.661 .737 .906 r
.12445 .33675 .13277 .34465 .14422 .34058 .13594 .3326 Mtetra
.654 .734 .908 r
.13594 .3326 .14422 .34058 .1557 .33679 .14746 .32864 Mtetra
.648 .729 .908 r
.14746 .32864 .1557 .33679 .16725 .33283 .15901 .32481 Mtetra
.663 .737 .905 r
.15901 .32481 .16725 .33283 .17898 .32762 .17067 .32053 Mtetra
.695 .771 .91 r
.17067 .32053 .17898 .32762 .19067 .32323 .18249 .31527 Mtetra
.664 .741 .907 r
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.20607 .30657 .2142 .3146 .22604 .31026 .21795 .30219 Mtetra
.21795 .30219 .22604 .31026 .23764 .30905 .22987 .29779 Mtetra
.53 .614 .881 r
.22987 .29779 .23764 .30905 .24875 .31433 .24151 .29718 Mtetra
.367 .422 .786 r
.24151 .29718 .24875 .31433 .26029 .31607 .25277 .30178 Mtetra
.468 .525 .833 r
.25277 .30178 .26029 .31607 .27234 .31262 .26442 .3032 Mtetra
.615 .696 .901 r
.26442 .3032 .27234 .31262 .28478 .30497 .27653 .30015 Mtetra
.737 .854 .935 r
.27653 .30015 .28478 .30497 .2974 .29515 .28899 .29337 Mtetra
.788 .942 .927 r
.28899 .29337 .2974 .29515 .31008 .2849 .30163 .28449 Mtetra
.791 .972 .912 r
.30163 .28449 .31008 .2849 .32272 .27521 .31434 .27496 Mtetra
.778 .976 .914 r
.31434 .27496 .32272 .27521 .33509 .27026 .32705 .2657 Mtetra
.78 .869 .914 r
.32705 .2657 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.664 .741 .907 r
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.519 .68 .939 r
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .1946 Mtetra
.367 .727 .989 r
.52016 .1946 .52738 .19974 .54069 .19528 .53355 .19445 Mtetra
.052 .616 .779 r
.53355 .19445 .54069 .19528 .55413 .19564 .54704 .19458 Mtetra
.132 .675 .829 r
.54704 .19458 .55413 .19564 .56768 .19659 .56065 .19405 Mtetra
.421 .833 .971 r
.56065 .19405 .56768 .19659 .58135 .19712 .57432 .19141 Mtetra
.705 .856 .954 r
.57432 .19141 .58135 .19712 .59508 .19544 .58801 .18496 Mtetra
.782 .753 .827 r
.58801 .18496 .59508 .19544 .60879 .18949 .60163 .17392 Mtetra
.777 .675 .75 r
.60163 .17392 .60879 .18949 .62238 .17819 .61517 .15961 Mtetra
.692 .603 .753 r
.61517 .15961 .62238 .17819 .63586 .16323 .62887 .1506 Mtetra
.654 .666 .849 r
.62887 .1506 .63586 .16323 .64958 .15492 .64277 .14548 Mtetra
.664 .741 .907 r
.64277 .14548 .64958 .15492 .6635 .14982 .65673 .14033 Mtetra
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.635 .728 .916 r
.68486 .12995 .69153 .13954 .70566 .13447 .69909 .12571 Mtetra
.665 .764 .924 r
.69909 .12571 .70566 .13447 .71992 .13024 .71333 .12043 Mtetra
.677 .743 .901 r
.71333 .12043 .71992 .13024 .73417 .12472 .72762 .11468 Mtetra
.672 .737 .899 r
.72762 .11468 .73417 .12472 .74847 .11901 .74199 .10906 Mtetra
.666 .737 .903 r
.74199 .10906 .74847 .11901 .76287 .11358 .75644 .10364 Mtetra
.663 .739 .907 r
.11605 .32886 .12445 .33675 .13594 .3326 .12758 .32462 Mtetra
.658 .737 .908 r
.12758 .32462 .13594 .3326 .14746 .32864 .13914 .3205 Mtetra
.652 .732 .908 r
.13914 .3205 .14746 .32864 .15901 .32481 .15073 .31654 Mtetra
.65 .729 .907 r
.15073 .31654 .15901 .32481 .17067 .32053 .16238 .31261 Mtetra
.672 .745 .905 r
.16238 .31261 .17067 .32053 .18249 .31527 .17415 .30799 Mtetra
.689 .767 .911 r
.17415 .30799 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.664 .741 .907 r
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21795 .30219 .20979 .29405 Mtetra
.20979 .29405 .21795 .30219 .22987 .29779 .22175 .28961 Mtetra
.22175 .28961 .22987 .29779 .24151 .29718 .23376 .28515 Mtetra
.557 .613 .864 r
.23376 .28515 .24151 .29718 .25277 .30178 .24554 .28384 Mtetra
.397 .431 .779 r
.24554 .28384 .25277 .30178 .26442 .3032 .25695 .28785 Mtetra
.466 .509 .818 r
.25695 .28785 .26442 .3032 .27653 .30015 .26867 .28944 Mtetra
.581 .655 .887 r
.26867 .28944 .27653 .30015 .28899 .29337 .28079 .28734 Mtetra
.692 .815 .941 r
.28079 .28734 .28899 .29337 .30163 .28449 .29323 .28192 Mtetra
.749 .924 .948 r
.29323 .28192 .30163 .28449 .31434 .27496 .30587 .27437 Mtetra
.753 .969 .929 r
.30587 .27437 .31434 .27496 .32705 .2657 .31861 .26589 Mtetra
.735 .98 .915 r
.31861 .26589 .32705 .2657 .33974 .25726 .33137 .25732 Mtetra
.718 .976 .92 r
.33137 .25732 .33974 .25726 .35223 .25265 .34415 .24913 Mtetra
.753 .903 .944 r
.34415 .24913 .35223 .25265 .36478 .24802 .35692 .24154 Mtetra
.73 .815 .917 r
.35692 .24154 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.664 .741 .907 r
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.591 .713 .928 r
.45993 .20124 .46737 .21018 .48048 .20535 .47304 .1985 Mtetra
.533 .752 .977 r
.47304 .1985 .48048 .20535 .49364 .20049 .48622 .19655 Mtetra
.401 .784 .991 r
.48622 .19655 .49364 .20049 .50687 .19561 .49948 .19521 Mtetra
.121 .671 .792 r
.49948 .19521 .50687 .19561 .52016 .1946 .51284 .19427 Mtetra
.122 .672 .788 r
.51284 .19427 .52016 .1946 .53355 .19445 .52629 .19326 Mtetra
.276 .772 .891 r
.52629 .19326 .53355 .19445 .54704 .19458 .53985 .1913 Mtetra
.557 .879 .992 r
.53985 .1913 .54704 .19458 .56065 .19405 .55348 .18718 Mtetra
.737 .829 .922 r
.55348 .18718 .56065 .19405 .57432 .19141 .56714 .17968 Mtetra
.774 .728 .81 r
.56714 .17968 .57432 .19141 .58801 .18496 .58077 .1684 Mtetra
.764 .658 .746 r
.58077 .1684 .58801 .18496 .60163 .17392 .59436 .15463 Mtetra
.678 .59 .75 r
.59436 .15463 .60163 .17392 .61517 .15961 .60808 .14627 Mtetra
.651 .653 .839 r
.60808 .14627 .61517 .15961 .62887 .1506 .62195 .14112 Mtetra
.664 .741 .907 r
.62195 .14112 .62887 .1506 .64277 .14548 .63589 .13595 Mtetra
.63589 .13595 .64277 .14548 .65673 .14033 .6499 .13076 Mtetra
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.641 .731 .914 r
.66398 .12553 .67076 .13515 .68486 .12995 .67817 .12106 Mtetra
.656 .758 .925 r
.67817 .12106 .68486 .12995 .69909 .12571 .69241 .11606 Mtetra
.676 .748 .905 r
.69241 .11606 .69909 .12571 .71333 .12043 .70668 .11034 Mtetra
.674 .737 .898 r
.70668 .11034 .71333 .12043 .72762 .11468 .72102 .10463 Mtetra
.669 .737 .901 r
.72102 .10463 .72762 .11468 .74199 .10906 .73544 .09909 Mtetra
.665 .739 .905 r
.73544 .09909 .74199 .10906 .75644 .10364 .74995 .09367 Mtetra
.663 .74 .907 r
.10758 .32092 .11605 .32886 .12758 .32462 .11914 .31662 Mtetra
.661 .739 .908 r
.11914 .31662 .12758 .32462 .13914 .3205 .13074 .31237 Mtetra
.656 .735 .908 r
.13074 .31237 .13914 .3205 .15073 .31654 .14238 .30824 Mtetra
.65 .73 .907 r
.14238 .30824 .15073 .31654 .16238 .31261 .15405 .30426 Mtetra
.653 .73 .906 r
.15405 .30426 .16238 .31261 .17415 .30799 .16579 .3002 Mtetra
.679 .753 .907 r
.16579 .3002 .17415 .30799 .18603 .30286 .17767 .29532 Mtetra
.683 .761 .91 r
.17767 .29532 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.664 .741 .907 r
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22175 .28961 .21355 .28137 Mtetra
.21355 .28137 .22175 .28961 .23376 .28515 .22559 .27687 Mtetra
.22559 .27687 .23376 .28515 .24554 .28384 .2377 .27235 Mtetra
.62 .653 .861 r
.2377 .27235 .24554 .28384 .25695 .28785 .24975 .26905 Mtetra
.426 .44 .771 r
.24975 .26905 .25695 .28785 .26867 .28944 .2613 .27239 Mtetra
.463 .485 .795 r
.2613 .27239 .26867 .28944 .28079 .28734 .27308 .2743 Mtetra
.54 .59 .853 r
.27308 .2743 .28079 .28734 .29323 .28192 .28518 .27345 Mtetra
.631 .732 .92 r
.28518 .27345 .29323 .28192 .30587 .27437 .29757 .26978 Mtetra
.697 .863 .961 r
.29757 .26978 .30587 .27437 .31861 .26589 .31018 .264 Mtetra
.712 .94 .959 r
.31018 .264 .31861 .26589 .33137 .25732 .32291 .25703 Mtetra
.69 .967 .934 r
.32291 .25703 .33137 .25732 .34415 .24913 .33572 .24959 Mtetra
.653 .966 .912 r
.33572 .24959 .34415 .24913 .35692 .24154 .34855 .24223 Mtetra
.617 .956 .9 r
.34855 .24223 .35692 .24154 .36968 .23472 .36141 .23521 Mtetra
.589 .945 .904 r
.36141 .23521 .36968 .23472 .38239 .23001 .37428 .2287 Mtetra
.632 .939 .96 r
.37428 .2287 .38239 .23001 .39516 .22527 .38717 .22273 Mtetra
.635 .915 .98 r
.38717 .22273 .39516 .22527 .40799 .22051 .40009 .21734 Mtetra
.618 .894 .988 r
.40009 .21734 .40799 .22051 .42088 .21573 .41304 .21252 Mtetra
.584 .883 .992 r
.41304 .21252 .42088 .21573 .43384 .21092 .42604 .20827 Mtetra
.522 .874 .987 r
.42604 .20827 .43384 .21092 .44685 .20609 .43909 .2046 Mtetra
.415 .847 .945 r
.43909 .2046 .44685 .20609 .45993 .20124 .4522 .20148 Mtetra
.239 .756 .813 r
.4522 .20148 .45993 .20124 .47304 .1985 .46538 .19888 Mtetra
.191 .723 .784 r
.46538 .19888 .47304 .1985 .48622 .19655 .47863 .19662 Mtetra
.205 .732 .806 r
.47863 .19662 .48622 .19655 .49948 .19521 .49198 .19446 Mtetra
.308 .796 .884 r
.49198 .19446 .49948 .19521 .51284 .19427 .50542 .19183 Mtetra
.507 .877 .979 r
.50542 .19183 .51284 .19427 .52629 .19326 .51894 .18799 Mtetra
.686 .864 .966 r
.51894 .18799 .52629 .19326 .53985 .1913 .53254 .18202 Mtetra
.754 .771 .867 r
.53254 .18202 .53985 .1913 .55348 .18718 .54618 .17316 Mtetra
.76 .687 .782 r
.54618 .17316 .55348 .18718 .56714 .17968 .55982 .16148 Mtetra
.745 .634 .737 r
.55982 .16148 .56714 .17968 .58077 .1684 .57344 .14832 Mtetra
.645 .566 .751 r
.57344 .14832 .58077 .1684 .59436 .15463 .5872 .14192 Mtetra
.654 .666 .85 r
.5872 .14192 .59436 .15463 .60808 .14627 .60105 .13675 Mtetra
.664 .741 .907 r
.60105 .13675 .60808 .14627 .62195 .14112 .61496 .13156 Mtetra
.61496 .13156 .62195 .14112 .63589 .13595 .62895 .12634 Mtetra
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.646 .734 .913 r
.643 .12109 .6499 .13076 .66398 .12553 .65716 .11643 Mtetra
.65 .751 .923 r
.65716 .11643 .66398 .12553 .67817 .12106 .67138 .11161 Mtetra
.674 .753 .91 r
.67138 .11161 .67817 .12106 .69241 .11606 .68564 .10594 Mtetra
.675 .738 .898 r
.68564 .10594 .69241 .11606 .70668 .11034 .69996 .10018 Mtetra
.67 .736 .9 r
.69996 .10018 .70668 .11034 .72102 .10463 .71436 .09457 Mtetra
.666 .738 .904 r
.71436 .09457 .72102 .10463 .73544 .09909 .72884 .08908 Mtetra
.664 .74 .906 r
.72884 .08908 .73544 .09909 .74995 .09367 .7434 .08363 Mtetra
.664 .741 .907 r
.09904 .31293 .10758 .32092 .11914 .31662 .11063 .30859 Mtetra
.663 .74 .907 r
.11063 .30859 .11914 .31662 .13074 .31237 .12227 .30425 Mtetra
.661 .738 .907 r
.12227 .30425 .13074 .31237 .14238 .30824 .13395 .29996 Mtetra
.655 .734 .907 r
.13395 .29996 .14238 .30824 .15405 .30426 .14567 .2958 Mtetra
.65 .728 .906 r
.14567 .2958 .15405 .30426 .16579 .3002 .15743 .29177 Mtetra
.655 .732 .906 r
.15743 .29177 .16579 .3002 .17767 .29532 .16926 .28759 Mtetra
.682 .758 .909 r
.16926 .28759 .17767 .29532 .18962 .2903 .18123 .28258 Mtetra
.681 .759 .91 r
.18123 .28258 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.664 .741 .907 r
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22559 .27687 .21736 .26851 Mtetra
.21736 .26851 .22559 .27687 .2377 .27235 .2295 .26396 Mtetra
.2295 .26396 .2377 .27235 .24975 .26905 .24169 .25938 Mtetra
.661 .71 .884 r
.24169 .25938 .24975 .26905 .2613 .27239 .25394 .25478 Mtetra
.507 .503 .787 r
.25394 .25478 .2613 .27239 .27308 .2743 .26581 .25531 Mtetra
.471 .467 .772 r
.26581 .25531 .27308 .2743 .28518 .27345 .27767 .25722 Mtetra
.512 .526 .807 r
.27767 .25722 .28518 .27345 .29757 .26978 .28977 .25746 Mtetra
.571 .622 .864 r
.28977 .25746 .29757 .26978 .31018 .264 .30211 .25559 Mtetra
.631 .737 .925 r
.30211 .25559 .31018 .264 .32291 .25703 .31467 .25184 Mtetra
.668 .843 .967 r
.31467 .25184 .32291 .25703 .33572 .24959 .32737 .24679 Mtetra
.668 .913 .977 r
.32737 .24679 .33572 .24959 .34855 .24223 .34018 .24099 Mtetra
.636 .94 .96 r
.34018 .24099 .34855 .24223 .36141 .23521 .35305 .23495 Mtetra
.588 .939 .932 r
.35305 .23495 .36141 .23521 .37428 .2287 .36597 .22896 Mtetra
.535 .922 .905 r
.36597 .22896 .37428 .2287 .38717 .22273 .37893 .22327 Mtetra
.482 .899 .883 r
.37893 .22327 .38717 .22273 .40009 .21734 .39192 .21796 Mtetra
.434 .874 .865 r
.39192 .21796 .40009 .21734 .41304 .21252 .40496 .21311 Mtetra
.392 .851 .854 r
.40496 .21311 .41304 .21252 .42604 .20827 .41804 .2087 Mtetra
.364 .835 .851 r
.41804 .2087 .42604 .20827 .43909 .2046 .43117 .20469 Mtetra
.359 .831 .865 r
.43117 .20469 .43909 .2046 .4522 .20148 .44437 .20096 Mtetra
.391 .846 .9 r
.44437 .20096 .4522 .20148 .46538 .19888 .45764 .19731 Mtetra
.474 .877 .955 r
.45764 .19731 .46538 .19888 .47863 .19662 .471 .1934 Mtetra
.591 .891 .989 r
.471 .1934 .47863 .19662 .49198 .19446 .48444 .18875 Mtetra
.69 .85 .959 r
.48444 .18875 .49198 .19446 .50542 .19183 .49796 .18277 Mtetra
.736 .77 .881 r
.49796 .18277 .50542 .19183 .51894 .18799 .51154 .17488 Mtetra
.744 .695 .804 r
.51154 .17488 .51894 .18799 .53254 .18202 .52517 .16484 Mtetra
.736 .64 .753 r
.52517 .16484 .53254 .18202 .54618 .17316 .53881 .15309 Mtetra
.7 .596 .736 r
.53881 .15309 .54618 .17316 .55982 .16148 .55248 .14271 Mtetra
.63 .57 .769 r
.55248 .14271 .55982 .16148 .57344 .14832 .56623 .13755 Mtetra
.661 .71 .884 r
.56623 .13755 .57344 .14832 .5872 .14192 .58006 .13236 Mtetra
.664 .741 .907 r
.58006 .13236 .5872 .14192 .60105 .13675 .59395 .12714 Mtetra
.59395 .12714 .60105 .13675 .61496 .13156 .60791 .1219 Mtetra
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.648 .734 .912 r
.62194 .11663 .62895 .12634 .643 .12109 .63607 .11188 Mtetra
.648 .748 .923 r
.63607 .11188 .643 .12109 .65716 .11643 .65027 .10711 Mtetra
.673 .757 .914 r
.65027 .10711 .65716 .11643 .67138 .11161 .66451 .10148 Mtetra
.675 .738 .898 r
.66451 .10148 .67138 .11161 .68564 .10594 .67881 .09569 Mtetra
.67 .735 .899 r
.67881 .09569 .68564 .10594 .69996 .10018 .69319 .09003 Mtetra
.666 .737 .903 r
.69319 .09003 .69996 .10018 .71436 .09457 .70765 .0845 Mtetra
.665 .739 .906 r
.70765 .0845 .71436 .09457 .72884 .08908 .72218 .07901 Mtetra
.664 .74 .907 r
.72218 .07901 .72884 .08908 .7434 .08363 .7368 .07352 Mtetra
.664 .741 .907 r
.09043 .30488 .09904 .31293 .11063 .30859 .10204 .3005 Mtetra
.10204 .3005 .11063 .30859 .12227 .30425 .11371 .2961 Mtetra
.663 .74 .907 r
.11371 .2961 .12227 .30425 .13395 .29996 .12543 .29171 Mtetra
.66 .737 .907 r
.12543 .29171 .13395 .29996 .14567 .2958 .1372 .28738 Mtetra
.655 .733 .907 r
.1372 .28738 .14567 .2958 .15743 .29177 .149 .28317 Mtetra
.651 .728 .905 r
.149 .28317 .15743 .29177 .16926 .28759 .16085 .27907 Mtetra
.655 .732 .906 r
.16085 .27907 .16926 .28759 .18123 .28258 .17276 .27481 Mtetra
.68 .759 .911 r
.17276 .27481 .18123 .28258 .19326 .27756 .18482 .2698 Mtetra
.683 .761 .91 r
.18482 .2698 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.664 .741 .907 r
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24169 .25938 .23345 .25087 Mtetra
.23345 .25087 .24169 .25938 .25394 .25478 .24573 .24624 Mtetra
.24573 .24624 .25394 .25478 .26581 .25531 .25807 .24157 Mtetra
.645 .629 .82 r
.25807 .24157 .26581 .25531 .27767 .25722 .27047 .23691 Mtetra
.495 .469 .757 r
.27047 .23691 .27767 .25722 .28977 .25746 .28247 .23802 Mtetra
.509 .486 .767 r
.28247 .23802 .28977 .25746 .30211 .25559 .29462 .23855 Mtetra
.538 .532 .796 r
.29462 .23855 .30211 .25559 .31467 .25184 .30695 .23787 Mtetra
.575 .597 .837 r
.30695 .23787 .31467 .25184 .32737 .24679 .31947 .23582 Mtetra
.611 .672 .883 r
.31947 .23582 .32737 .24679 .34018 .24099 .33214 .2326 Mtetra
.639 .746 .926 r
.33214 .2326 .34018 .24099 .35305 .23495 .34494 .22853 Mtetra
.651 .807 .958 r
.34494 .22853 .35305 .23495 .36597 .22896 .35783 .22394 Mtetra
.65 .85 .977 r
.35783 .22394 .36597 .22896 .37893 .22327 .3708 .2191 Mtetra
.64 .874 .985 r
.3708 .2191 .37893 .22327 .39192 .21796 .38383 .21419 Mtetra
.63 .883 .988 r
.38383 .21419 .39192 .21796 .40496 .21311 .39693 .20929 Mtetra
.628 .883 .988 r
.39693 .20929 .40496 .21311 .41804 .2087 .41009 .20441 Mtetra
.638 .873 .985 r
.41009 .20441 .41804 .2087 .43117 .20469 .42331 .19946 Mtetra
.66 .853 .974 r
.42331 .19946 .43117 .20469 .44437 .20096 .43661 .19426 Mtetra
.687 .817 .945 r
.43661 .19426 .44437 .20096 .45764 .19731 .44998 .18853 Mtetra
.707 .767 .899 r
.44998 .18853 .45764 .19731 .471 .1934 .46343 .18193 Mtetra
.718 .712 .844 r
.46343 .18193 .471 .1934 .48444 .18875 .47695 .17415 Mtetra
.72 .663 .793 r
.47695 .17415 .48444 .18875 .49796 .18277 .49053 .16498 Mtetra
.715 .624 .754 r
.49053 .16498 .49796 .18277 .51154 .17488 .50414 .15455 Mtetra
.707 .597 .731 r
.50414 .15455 .51154 .17488 .52517 .16484 .51778 .14352 Mtetra
.621 .542 .744 r
.51778 .14352 .52517 .16484 .53881 .15309 .53144 .13834 Mtetra
.645 .629 .82 r
.53144 .13834 .53881 .15309 .55248 .14271 .54517 .13316 Mtetra
.664 .741 .907 r
.54517 .13316 .55248 .14271 .56623 .13755 .55897 .12795 Mtetra
.55897 .12795 .56623 .13755 .58006 .13236 .57284 .12271 Mtetra
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.646 .734 .913 r
.60079 .11215 .60791 .1219 .62194 .11663 .61489 .10744 Mtetra
.65 .751 .923 r
.61489 .10744 .62194 .11663 .63607 .11188 .62906 .10259 Mtetra
.672 .758 .915 r
.62906 .10259 .63607 .11188 .65027 .10711 .64328 .09696 Mtetra
.674 .739 .899 r
.64328 .09696 .65027 .10711 .66451 .10148 .65756 .09116 Mtetra
.67 .734 .898 r
.65756 .09116 .66451 .10148 .67881 .09569 .67192 .08547 Mtetra
.667 .736 .902 r
.67192 .08547 .67881 .09569 .69319 .09003 .68636 .0799 Mtetra
.665 .739 .905 r
.68636 .0799 .69319 .09003 .70765 .0845 .70087 .07437 Mtetra
.664 .74 .907 r
.70087 .07437 .70765 .0845 .72218 .07901 .71546 .06886 Mtetra
.664 .741 .907 r
.71546 .06886 .72218 .07901 .7368 .07352 .73013 .06331 Mtetra
.08174 .29677 .09043 .30488 .10204 .3005 .09338 .29235 Mtetra
.09338 .29235 .10204 .3005 .11371 .2961 .10508 .2879 Mtetra
.663 .74 .907 r
.10508 .2879 .11371 .2961 .12543 .29171 .11684 .28345 Mtetra
.11684 .28345 .12543 .29171 .1372 .28738 .12864 .279 Mtetra
.66 .737 .907 r
.12864 .279 .1372 .28738 .149 .28317 .14049 .27461 Mtetra
.655 .732 .906 r
.14049 .27461 .149 .28317 .16085 .27907 .15238 .27034 Mtetra
.651 .727 .905 r
.15238 .27034 .16085 .27907 .17276 .27481 .16432 .26616 Mtetra
.655 .731 .906 r
.16432 .26616 .17276 .27481 .18482 .2698 .17632 .26186 Mtetra
.674 .756 .912 r
.17632 .26186 .18482 .2698 .19694 .26466 .18845 .25696 Mtetra
.689 .767 .911 r
.18845 .25696 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.664 .741 .907 r
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .24573 .24624 .23745 .23761 Mtetra
.23745 .23761 .24573 .24624 .25807 .24157 .24983 .23291 Mtetra
.24983 .23291 .25807 .24157 .27047 .23691 .26227 .22819 Mtetra
.664 .74 .907 r
.26227 .22819 .27047 .23691 .28247 .23802 .27476 .22344 Mtetra
.642 .618 .811 r
.27476 .22344 .28247 .23802 .29462 .23855 .28732 .21867 Mtetra
.558 .512 .76 r
.28732 .21867 .29462 .23855 .30695 .23787 .29969 .21709 Mtetra
.541 .494 .753 r
.29969 .21709 .30695 .23787 .31947 .23582 .3121 .21627 Mtetra
.558 .516 .765 r
.3121 .21627 .31947 .23582 .33214 .2326 .32465 .21472 Mtetra
.578 .546 .783 r
.32465 .21472 .33214 .2326 .34494 .22853 .33734 .21233 Mtetra
.599 .579 .802 r
.33734 .21233 .34494 .22853 .35783 .22394 .35015 .20915 Mtetra
.619 .609 .819 r
.35015 .20915 .35783 .22394 .3708 .2191 .36308 .2053 Mtetra
.635 .633 .831 r
.36308 .2053 .3708 .2191 .38383 .21419 .37611 .20087 Mtetra
.649 .648 .836 r
.37611 .20087 .38383 .21419 .39693 .20929 .38923 .19592 Mtetra
.66 .653 .832 r
.38923 .19592 .39693 .20929 .41009 .20441 .40243 .19046 Mtetra
.669 .648 .82 r
.40243 .19046 .41009 .20441 .42331 .19946 .41571 .18443 Mtetra
.676 .636 .802 r
.41571 .18443 .42331 .19946 .43661 .19426 .42907 .1777 Mtetra
.681 .62 .78 r
.42907 .1777 .43661 .19426 .44998 .18853 .4425 .17018 Mtetra
.684 .602 .758 r
.4425 .17018 .44998 .18853 .46343 .18193 .456 .1618 Mtetra
.684 .586 .74 r
.456 .1618 .46343 .18193 .47695 .17415 .46954 .15267 Mtetra
.667 .566 .732 r
.46954 .15267 .47695 .17415 .49053 .16498 .48311 .14429 Mtetra
.622 .548 .75 r
.48311 .14429 .49053 .16498 .50414 .15455 .49668 .13914 Mtetra
.642 .618 .811 r
.49668 .13914 .50414 .15455 .51778 .14352 .51032 .13396 Mtetra
.664 .74 .907 r
.51032 .13396 .51778 .14352 .53144 .13834 .52403 .12875 Mtetra
.664 .741 .907 r
.52403 .12875 .53144 .13834 .54517 .13316 .5378 .12352 Mtetra
.5378 .12352 .54517 .13316 .55897 .12795 .55165 .11826 Mtetra
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.64 .731 .915 r
.57955 .10766 .58678 .11744 .60079 .11215 .59363 .1031 Mtetra
.655 .758 .925 r
.59363 .1031 .60079 .11215 .61489 .10744 .60777 .09804 Mtetra
.673 .756 .914 r
.60777 .09804 .61489 .10744 .62906 .10259 .62196 .09237 Mtetra
.674 .738 .899 r
.62196 .09237 .62906 .10259 .64328 .09696 .63623 .08657 Mtetra
.67 .734 .898 r
.63623 .08657 .64328 .09696 .65756 .09116 .65056 .08086 Mtetra
.667 .736 .901 r
.65056 .08086 .65756 .09116 .67192 .08547 .66497 .07526 Mtetra
.665 .738 .905 r
.66497 .07526 .67192 .08547 .68636 .0799 .67947 .06972 Mtetra
.664 .74 .907 r
.67947 .06972 .68636 .0799 .70087 .07437 .69403 .06417 Mtetra
.664 .741 .907 r
.69403 .06417 .70087 .07437 .71546 .06886 .70868 .05861 Mtetra
.70868 .05861 .71546 .06886 .73013 .06331 .72339 .05301 Mtetra
.07297 .28858 .08174 .29677 .09338 .29235 .08465 .28412 Mtetra
.08465 .28412 .09338 .29235 .10508 .2879 .09638 .27964 Mtetra
.09638 .27964 .10508 .2879 .11684 .28345 .10817 .27514 Mtetra
.664 .74 .907 r
.10817 .27514 .11684 .28345 .12864 .279 .12 .27062 Mtetra
.663 .739 .907 r
.12 .27062 .12864 .279 .14049 .27461 .13189 .26612 Mtetra
.66 .737 .907 r
.13189 .26612 .14049 .27461 .15238 .27034 .14383 .26166 Mtetra
.656 .732 .905 r
.14383 .26166 .15238 .27034 .16432 .26616 .15581 .2573 Mtetra
.652 .727 .904 r
.15581 .2573 .16432 .26616 .17632 .26186 .16784 .25303 Mtetra
.654 .73 .905 r
.16784 .25303 .17632 .26186 .18845 .25696 .17993 .2487 Mtetra
.667 .749 .912 r
.17993 .2487 .18845 .25696 .20067 .25159 .19212 .24397 Mtetra
.692 .773 .913 r
.19212 .24397 .20067 .25159 .21288 .24695 .20445 .23845 Mtetra
.668 .745 .908 r
.20445 .23845 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.664 .741 .907 r
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26227 .22819 .25399 .21941 Mtetra
.25399 .21941 .26227 .22819 .27476 .22344 .26652 .21462 Mtetra
.26652 .21462 .27476 .22344 .28732 .21867 .27911 .20981 Mtetra
.27911 .20981 .28732 .21867 .29969 .21709 .29176 .20497 Mtetra
.653 .667 .85 r
.29176 .20497 .29969 .21709 .3121 .21627 .30447 .20011 Mtetra
.637 .597 .793 r
.30447 .20011 .3121 .21627 .32465 .21472 .31724 .19523 Mtetra
.622 .554 .757 r
.31724 .19523 .32465 .21472 .33734 .21233 .33007 .19044 Mtetra
.583 .511 .74 r
.33007 .19044 .33734 .21233 .35015 .20915 .34286 .18738 Mtetra
.594 .519 .74 r
.34286 .18738 .35015 .20915 .36308 .2053 .35575 .18374 Mtetra
.606 .528 .741 r
.35575 .18374 .36308 .2053 .37611 .20087 .36876 .17942 Mtetra
.618 .536 .74 r
.36876 .17942 .37611 .20087 .38923 .19592 .38186 .17442 Mtetra
.628 .543 .738 r
.38186 .17442 .38923 .19592 .40243 .19046 .39506 .16874 Mtetra
.638 .546 .735 r
.39506 .16874 .40243 .19046 .41571 .18443 .40834 .16238 Mtetra
.645 .549 .731 r
.40834 .16238 .41571 .18443 .42907 .1777 .4217 .15542 Mtetra
.617 .531 .734 r
.4217 .15542 .42907 .1777 .4425 .17018 .43505 .15021 Mtetra
.624 .555 .756 r
.43505 .15021 .4425 .17018 .456 .1618 .44846 .14509 Mtetra
.637 .597 .793 r
.44846 .14509 .456 .1618 .46954 .15267 .46194 .13993 Mtetra
.653 .667 .85 r
.46194 .13993 .46954 .15267 .48311 .14429 .47549 .13476 Mtetra
.664 .741 .907 r
.47549 .13476 .48311 .14429 .49668 .13914 .48911 .12955 Mtetra
.48911 .12955 .49668 .13914 .51032 .13396 .50279 .12432 Mtetra
.50279 .12432 .51032 .13396 .52403 .12875 .51654 .11907 Mtetra
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.661 .74 .908 r
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10325 Mtetra
.638 .733 .918 r
.55822 .10325 .56557 .11297 .57955 .10766 .57227 .09876 Mtetra
.663 .766 .926 r
.57227 .09876 .57955 .10766 .59363 .1031 .58638 .09345 Mtetra
.673 .751 .909 r
.58638 .09345 .59363 .1031 .60777 .09804 .60055 .08772 Mtetra
.673 .736 .898 r
.60055 .08772 .60777 .09804 .62196 .09237 .61479 .08193 Mtetra
.669 .733 .898 r
.61479 .08193 .62196 .09237 .63623 .08657 .62911 .07622 Mtetra
.666 .735 .901 r
.62911 .07622 .63623 .08657 .65056 .08086 .6435 .07061 Mtetra
.665 .738 .905 r
.6435 .07061 .65056 .08086 .66497 .07526 .65797 .06504 Mtetra
.664 .74 .906 r
.65797 .06504 .66497 .07526 .67947 .06972 .67251 .05947 Mtetra
.664 .741 .907 r
.67251 .05947 .67947 .06972 .69403 .06417 .68713 .05388 Mtetra
.68713 .05388 .69403 .06417 .70868 .05861 .70182 .04826 Mtetra
.70182 .04826 .70868 .05861 .72339 .05301 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10817 .27514 .09942 .26677 Mtetra
.09942 .26677 .10817 .27514 .12 .27062 .11129 .2622 Mtetra
.664 .74 .907 r
.11129 .2622 .12 .27062 .13189 .26612 .12321 .25763 Mtetra
.663 .739 .907 r
.12321 .25763 .13189 .26612 .14383 .26166 .13519 .25306 Mtetra
.661 .737 .906 r
.13519 .25306 .14383 .26166 .15581 .2573 .14722 .24852 Mtetra
.657 .733 .905 r
.14722 .24852 .15581 .2573 .16784 .25303 .15929 .24406 Mtetra
.654 .728 .904 r
.15929 .24406 .16784 .25303 .17993 .2487 .17141 .23968 Mtetra
.653 .727 .904 r
.17141 .23968 .17993 .2487 .19212 .24397 .18359 .2353 Mtetra
.66 .739 .909 r
.18359 .2353 .19212 .24397 .20445 .23845 .19585 .23072 Mtetra
.677 .769 .921 r
.19585 .23072 .20445 .23845 .21675 .23364 .20822 .22563 Mtetra
.688 .766 .911 r
.20822 .22563 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.664 .741 .907 r
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27911 .20981 .27082 .20086 Mtetra
.27082 .20086 .27911 .20981 .29176 .20497 .28351 .19599 Mtetra
.28351 .19599 .29176 .20497 .30447 .20011 .29626 .19108 Mtetra
.29626 .19108 .30447 .20011 .31724 .19523 .30907 .18616 Mtetra
.30907 .18616 .31724 .19523 .33007 .19044 .32194 .18121 Mtetra
.664 .738 .905 r
.32194 .18121 .33007 .19044 .34286 .18738 .33488 .17624 Mtetra
.658 .693 .872 r
.33488 .17624 .34286 .18738 .35575 .18374 .34788 .17124 Mtetra
.653 .666 .85 r
.34788 .17124 .35575 .18374 .36876 .17942 .36094 .16621 Mtetra
.65 .653 .839 r
.36094 .16621 .36876 .17942 .38186 .17442 .37407 .16117 Mtetra
.37407 .16117 .38186 .17442 .39506 .16874 .38726 .1561 Mtetra
.653 .666 .85 r
.38726 .1561 .39506 .16874 .40834 .16238 .40052 .151 Mtetra
.658 .693 .872 r
.40052 .151 .40834 .16238 .4217 .15542 .41385 .14588 Mtetra
.664 .738 .905 r
.41385 .14588 .4217 .15542 .43505 .15021 .42724 .14073 Mtetra
.664 .741 .907 r
.42724 .14073 .43505 .15021 .44846 .14509 .44069 .13555 Mtetra
.44069 .13555 .44846 .14509 .46194 .13993 .45422 .13035 Mtetra
.45422 .13035 .46194 .13993 .47549 .13476 .46781 .12513 Mtetra
.46781 .12513 .47549 .13476 .48911 .12955 .48147 .11988 Mtetra
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.642 .732 .914 r
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .09934 Mtetra
.654 .756 .925 r
.5368 .09934 .54426 .10848 .55822 .10325 .55081 .09431 Mtetra
.669 .768 .924 r
.55081 .09431 .55822 .10325 .57227 .09876 .5649 .08877 Mtetra
.673 .744 .904 r
.5649 .08877 .57227 .09876 .58638 .09345 .57905 .083 Mtetra
.671 .734 .897 r
.57905 .083 .58638 .09345 .60055 .08772 .59327 .07723 Mtetra
.668 .733 .898 r
.59327 .07723 .60055 .08772 .61479 .08193 .60756 .07154 Mtetra
.666 .735 .902 r
.60756 .07154 .61479 .08193 .62911 .07622 .62193 .06592 Mtetra
.665 .738 .905 r
.62193 .06592 .62911 .07622 .6435 .07061 .63637 .06034 Mtetra
.664 .74 .906 r
.63637 .06034 .6435 .07061 .65797 .06504 .65089 .05474 Mtetra
.664 .741 .907 r
.65089 .05474 .65797 .06504 .67251 .05947 .66549 .04913 Mtetra
.66549 .04913 .67251 .05947 .68713 .05388 .68016 .04348 Mtetra
.68016 .04348 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .26291 Mtetra
.07875 .26291 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11129 .2622 .10249 .25372 Mtetra
.10249 .25372 .11129 .2622 .12321 .25763 .11445 .24909 Mtetra
.664 .74 .907 r
.11445 .24909 .12321 .25763 .13519 .25306 .12647 .24446 Mtetra
.663 .74 .907 r
.12647 .24446 .13519 .25306 .14722 .24852 .13853 .23982 Mtetra
.662 .738 .906 r
.13853 .23982 .14722 .24852 .15929 .24406 .15065 .23519 Mtetra
.659 .734 .905 r
.15065 .23519 .15929 .24406 .17141 .23968 .16282 .23062 Mtetra
.656 .729 .903 r
.16282 .23062 .17141 .23968 .18359 .2353 .17504 .22612 Mtetra
.653 .726 .903 r
.17504 .22612 .18359 .2353 .19585 .23072 .18731 .22166 Mtetra
.655 .731 .905 r
.18731 .22166 .19585 .23072 .20822 .22563 .19965 .21713 Mtetra
.663 .749 .914 r
.19965 .21713 .20822 .22563 .22068 .22014 .21207 .21236 Mtetra
.677 .772 .922 r
.21207 .21236 .22068 .22014 .23313 .21536 .22459 .20717 Mtetra
.687 .765 .911 r
.22459 .20717 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.664 .741 .907 r
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30907 .18616 .30083 .177 Mtetra
.30083 .177 .30907 .18616 .32194 .18121 .31374 .17201 Mtetra
.31374 .17201 .32194 .18121 .33488 .17624 .32671 .16699 Mtetra
.32671 .16699 .33488 .17624 .34788 .17124 .33975 .16195 Mtetra
.33975 .16195 .34788 .17124 .36094 .16621 .35285 .15688 Mtetra
.35285 .15688 .36094 .16621 .37407 .16117 .36602 .15178 Mtetra
.36602 .15178 .37407 .16117 .38726 .1561 .37925 .14667 Mtetra
.37925 .14667 .38726 .1561 .40052 .151 .39255 .14152 Mtetra
.39255 .14152 .40052 .151 .41385 .14588 .40592 .13635 Mtetra
.40592 .13635 .41385 .14588 .42724 .14073 .41935 .13116 Mtetra
.41935 .13116 .42724 .14073 .44069 .13555 .43285 .12593 Mtetra
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.642 .733 .914 r
.48753 .10478 .49519 .1146 .50899 .10929 .50136 .10015 Mtetra
.653 .755 .924 r
.50136 .10015 .50899 .10929 .52286 .10396 .51528 .09514 Mtetra
.666 .77 .927 r
.51528 .09514 .52286 .10396 .5368 .09934 .52927 .08969 Mtetra
.672 .752 .911 r
.52927 .08969 .5368 .09934 .55081 .09431 .54332 .084 Mtetra
.672 .737 .899 r
.54332 .084 .55081 .09431 .5649 .08877 .55745 .07823 Mtetra
.669 .732 .897 r
.55745 .07823 .5649 .08877 .57905 .083 .57165 .0725 Mtetra
.667 .733 .899 r
.57165 .0725 .57905 .083 .59327 .07723 .58592 .06684 Mtetra
.665 .736 .903 r
.58592 .06684 .59327 .07723 .60756 .07154 .60027 .06122 Mtetra
.665 .739 .905 r
.60027 .06122 .60756 .07154 .62193 .06592 .61469 .05561 Mtetra
.664 .74 .906 r
.61469 .05561 .62193 .06592 .63637 .06034 .62918 .04999 Mtetra
.664 .74 .907 r
.62918 .04999 .63637 .06034 .65089 .05474 .64375 .04435 Mtetra
.664 .741 .907 r
.64375 .04435 .65089 .05474 .66549 .04913 .6584 .03869 Mtetra
.6584 .03869 .66549 .04913 .68016 .04348 .67312 .033 Mtetra
.67312 .033 .68016 .04348 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .26291 .06982 .25443 Mtetra
.06982 .25443 .07875 .26291 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24909 .10561 .2405 Mtetra
.10561 .2405 .11445 .24909 .12647 .24446 .11766 .23581 Mtetra
.11766 .23581 .12647 .24446 .13853 .23982 .12976 .23111 Mtetra
.663 .74 .907 r
.12976 .23111 .13853 .23982 .15065 .23519 .14192 .22639 Mtetra
.662 .738 .906 r
.14192 .22639 .15065 .23519 .16282 .23062 .15413 .22168 Mtetra
.66 .735 .905 r
.15413 .22168 .16282 .23062 .17504 .22612 .1664 .21701 Mtetra
.658 .732 .904 r
.1664 .21701 .17504 .22612 .18731 .22166 .17872 .21238 Mtetra
.655 .727 .903 r
.17872 .21238 .18731 .22166 .19965 .21713 .19108 .20782 Mtetra
.653 .727 .903 r
.19108 .20782 .19965 .21713 .21207 .21236 .20351 .20328 Mtetra
.655 .734 .908 r
.20351 .20328 .21207 .21236 .22459 .20717 .216 .19869 Mtetra
.66 .752 .919 r
.216 .19869 .22459 .20717 .2372 .20161 .22857 .19396 Mtetra
.667 .777 .932 r
.22857 .19396 .2372 .20161 .2498 .19674 .24121 .18898 Mtetra
.676 .778 .927 r
.24121 .18898 .2498 .19674 .26247 .19184 .25395 .18372 Mtetra
.683 .771 .918 r
.25395 .18372 .26247 .19184 .27519 .18692 .26676 .17819 Mtetra
.678 .756 .91 r
.26676 .17819 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.664 .741 .907 r
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.651 .736 .912 r
.42493 .11623 .43285 .12593 .44641 .12069 .43853 .11136 Mtetra
.647 .745 .921 r
.43853 .11136 .44641 .12069 .46005 .11541 .45219 .1066 Mtetra
.655 .763 .929 r
.45219 .1066 .46005 .11541 .47375 .11011 .46594 .10158 Mtetra
.663 .775 .932 r
.46594 .10158 .47375 .11011 .48753 .10478 .47976 .09626 Mtetra
.671 .779 .931 r
.47976 .09626 .48753 .10478 .50136 .10015 .49366 .09069 Mtetra
.673 .757 .913 r
.49366 .09069 .50136 .10015 .51528 .09514 .50763 .08497 Mtetra
.672 .74 .901 r
.50763 .08497 .51528 .09514 .52927 .08969 .52166 .0792 Mtetra
.67 .733 .897 r
.52166 .0792 .52927 .08969 .54332 .084 .53577 .07345 Mtetra
.668 .732 .898 r
.53577 .07345 .54332 .084 .55745 .07823 .54994 .06776 Mtetra
.666 .734 .901 r
.54994 .06776 .55745 .07823 .57165 .0725 .56419 .0621 Mtetra
.665 .737 .904 r
.56419 .0621 .57165 .0725 .58592 .06684 .57851 .05649 Mtetra
.664 .739 .906 r
.57851 .05649 .58592 .06684 .60027 .06122 .5929 .05086 Mtetra
.664 .74 .907 r
.5929 .05086 .60027 .06122 .61469 .05561 .60737 .04523 Mtetra
.664 .741 .907 r
.60737 .04523 .61469 .05561 .62918 .04999 .62192 .03956 Mtetra
.62192 .03956 .62918 .04999 .64375 .04435 .63654 .03387 Mtetra
.63654 .03387 .64375 .04435 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .033 .66602 .0224 Mtetra
.66602 .0224 .67312 .033 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23182 Mtetra
.0967 .23182 .10561 .2405 .11766 .23581 .10878 .22709 Mtetra
.10878 .22709 .11766 .23581 .12976 .23111 .12091 .22235 Mtetra
.12091 .22235 .12976 .23111 .14192 .22639 .1331 .21758 Mtetra
.663 .74 .907 r
.1331 .21758 .14192 .22639 .15413 .22168 .14535 .21281 Mtetra
.662 .739 .907 r
.14535 .21281 .15413 .22168 .1664 .21701 .15766 .20803 Mtetra
.66 .737 .907 r
.15766 .20803 .1664 .21701 .17872 .21238 .17001 .20331 Mtetra
.658 .735 .907 r
.17001 .20331 .17872 .21238 .19108 .20782 .18242 .19863 Mtetra
.654 .733 .907 r
.18242 .19863 .19108 .20782 .20351 .20328 .19488 .19405 Mtetra
.651 .732 .908 r
.19488 .19405 .20351 .20328 .216 .19869 .20739 .18952 Mtetra
.65 .734 .91 r
.20739 .18952 .216 .19869 .22857 .19396 .21997 .18501 Mtetra
.652 .741 .915 r
.21997 .18501 .22857 .19396 .24121 .18898 .23261 .18042 Mtetra
.658 .754 .921 r
.23261 .18042 .24121 .18898 .25395 .18372 .24533 .17566 Mtetra
.665 .77 .928 r
.24533 .17566 .25395 .18372 .26676 .17819 .25814 .17067 Mtetra
.672 .788 .936 r
.25814 .17067 .26676 .17819 .27962 .17278 .27102 .16544 Mtetra
.678 .796 .937 r
.27102 .16544 .27962 .17278 .29251 .16776 .28398 .15999 Mtetra
.681 .786 .929 r
.28398 .15999 .29251 .16776 .30546 .16272 .29701 .15444 Mtetra
.68 .773 .921 r
.29701 .15444 .30546 .16272 .31847 .15766 .31011 .14886 Mtetra
.676 .76 .914 r
.31011 .14886 .31847 .15766 .33155 .15257 .32325 .14336 Mtetra
.671 .749 .909 r
.32325 .14336 .33155 .15257 .34469 .14745 .33645 .13799 Mtetra
.664 .742 .908 r
.33645 .13799 .34469 .14745 .3579 .14231 .34969 .1328 Mtetra
.658 .74 .91 r
.34969 .1328 .3579 .14231 .37117 .13715 .363 .12779 Mtetra
.653 .743 .916 r
.363 .12779 .37117 .13715 .38451 .13196 .37636 .12292 Mtetra
.65 .751 .924 r
.37636 .12292 .38451 .13196 .39792 .12674 .38979 .11813 Mtetra
.65 .764 .933 r
.38979 .11813 .39792 .12674 .41139 .1215 .40329 .11331 Mtetra
.652 .777 .94 r
.40329 .11331 .41139 .1215 .42493 .11623 .41687 .10838 Mtetra
.658 .79 .945 r
.41687 .10838 .42493 .11623 .43853 .11136 .43052 .10323 Mtetra
.666 .786 .938 r
.43052 .10323 .43853 .11136 .45219 .1066 .44426 .09784 Mtetra
.672 .773 .925 r
.44426 .09784 .45219 .1066 .46594 .10158 .45806 .09222 Mtetra
.676 .76 .914 r
.45806 .09222 .46594 .10158 .47976 .09626 .47194 .08641 Mtetra
.676 .749 .906 r
.47194 .08641 .47976 .09626 .49366 .09069 .48589 .08053 Mtetra
.675 .742 .901 r
.48589 .08053 .49366 .09069 .50763 .08497 .4999 .07465 Mtetra
.672 .739 .9 r
.4999 .07465 .50763 .08497 .52166 .0792 .51398 .06883 Mtetra
.669 .737 .901 r
.51398 .06883 .52166 .0792 .53577 .07345 .52814 .06309 Mtetra
.667 .738 .903 r
.52814 .06309 .53577 .07345 .54994 .06776 .54236 .0574 Mtetra
.665 .739 .905 r
.54236 .0574 .54994 .06776 .56419 .0621 .55666 .05176 Mtetra
.665 .74 .906 r
.55666 .05176 .56419 .0621 .57851 .05649 .57103 .0461 Mtetra
.664 .74 .907 r
.57103 .0461 .57851 .05649 .5929 .05086 .58547 .04044 Mtetra
.664 .741 .907 r
.58547 .04044 .5929 .05086 .60737 .04523 .59999 .03475 Mtetra
.59999 .03475 .60737 .04523 .62192 .03956 .61459 .02903 Mtetra
.61459 .02903 .62192 .03956 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`00000P0:Vmj0030000002Y_NP0ZKgX00@0ZKgX00<000000?ooo`3oool0
HP3oool00:l0oooo00<0ScD003F?o`3oool06@3oool200000080ZKgX00<000000:Vmj02Y_NP07P2Y
_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0oooo0640oooo002_0?ooo`060<AO50000000
00000000000003D0Sooo4`3oool3000000030:Zmi`2Y_NP0ZKgX0280ZKgX00<000000:Vmj02Y_NP0
1P2Y_NP00`000000oooo0?ooo`1P0?ooo`00aP3oool2000000D0Z[gW3P2Y_NP30:Vmia80ZKgX00<0
00000:Vmj02Y_NP01P2Y_NP00`000000oooo0?ooo`1P0?ooo`00``3oool3000000L0Z[gW1P2Y_NL5
0:Vmj0H0ZKgW4P2Y_NP00`000000ZKgX0:Vmj0070:Vmj0030000003oool0oooo05l0oooo00310?oo
o`80000000<0Z[gW0000002Z_NL01@2Z_NL30:Zli`H0ZKgW0P2Y_NP30:Zmi`H0ZKgW0P2Y_NP30:Vm
i``0ZKgX00<000000:Vmj02Y_NP0202Y_NP00`000000oooo0?ooo`1N0?ooo`00_P3oool300000080
Z[cW1P2Z_NL60:Zli`D0ZKgW1P2Z_NL;0:Vmi`<0ZKgX0`2Y_NL50:Vmj0030000002Y_NP0ZKgX00P0
ZKgX00<000000?ooo`3oool0GP3oool00;/0oooo0`0000000`2[_>H0Z[cW0:Zli`030:Zli`<0Z[gW
0`2Z^nH;0:Zli`H0Z[gW1@2Z_>L<0:Vmi`@0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`000000oooo
0?ooo`1M0?ooo`00^@3oool2000000D0ZkcV1@2Z_>L60:ZkiP<0Z[cW0`2Z^nH50:Zli`<0Z[gW0`2Z
_>H50:Zli`<0ZKgW0`2Z_>L50:Vmi`@0ZKgX00<000000:Vmj02Y_NP02@2Y_NP00`3oool000000?oo
o`1M0?ooo`00]P3oool4000000030:bmiP2[_>H0ZkcV00<0ZkcV1P2[^nD;0:ZkiPD0Z[cW1`2Z_>H;
0:Zli`80ZKgW0`2Z_>L30:Vmj0030000002Y_NP0ZKgX00X0ZKgX00<000000?ooo`3oool0G03oool0
0;@0oooo0P0000040:bmiP040000002/_NH0ZkcV0:^liPT0Zk_U0P2Z^nH30:^ki@H0Z[_V0P2Z_>L3
0:^ki@/0Z[cV302Z_>L20:Vmj0030000002Y_NP0ZKgX00X0ZKgX00<0oooo0000003oool0G03oool0
0;40oooo0`0000080:bmiQ40Zk_U1@2Z^nH60:^ki@<0Z[cV0`2[^nD50:ZliP<0Z[cW0`2Z_>H50:Zl
i`80Z[gW00@000000:Zmi`2Z_NL0Z[gW2P2Y_NP2000005`0oooo002^0?ooo`<00000302/_NH80:^k
i@<0[;cV5`2[^nD;0:ZliP80Z[cW0`2Z_>H00`2Z_NL000000:Zmi`030:Zmi`80ZKgX0`2Z_NL50:Vm
j0030000003oool0oooo05X0oooo002/0?ooo`@000000P2]_nL<0:bmiPD0Zk_U1P2/_>H30:^ki@<0
[;kW1`2[^nD30:bli@/0Zk_U2`2Z_>H00`2Z_NL000000:Zmi`090:Zmi`@0ZKgX00<0oooo0000003o
ool0FP3oool007/0oooo00D0oon?03D00000000001AO0<Coo`0Z0?ooo`8000000P2]`^T50:foi`<0
[;gV0`2/`NT50:bmiPH0[<3Y1@2/_>H60:bni`D0Zk_U1P2/_>D30:^ki@<0[;cV1@2[^nD30:ZliP<0
Zk_U1@2Z_>H00`000000Z[gW0:Zmi`030:Zli`D0Z[gW1@2Y_NL00`3oool000000?ooo`1I0?ooo`00
NP3oool01P3ool@0Ga@001AOa03oool0a5lD000eSbL0oooo0`0000050:g2j@D0[KoW1P2/`NT20:bm
iP<0Z/G]1P2/`>T20:bliP<0ZlC/1P2/_^L20:^ki@<0[<3X1P2/_>D50:bliP`0Zk_U102Z_>H00`00
0000Z[cW0:Zli`040:Zli`80Z[gW0`2Z_>L50:Vmi`030000003oool0oooo05P0oooo001j0?ooo`07
0?ooS`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0T0?ooo`8000000`2/aN`50:g2j@H0ZlO^1@2/`NT6
0:[5k@D0[<3Y1P2[a>`50:bni`H0[<3X0`2/_>D30:c1j@D0[;cV0P2[^nD30:bmiPH0Zk_U1@2[_>H0
0`000000Z[cW0:Zli`090:Zli`@0ZKgW00<0oooo0000003oool0F03oool007X0oooo00L0olAO01@D
G`34ool0oooo0?ooS`0e01@0GlCo0240oooo100000050:c5k080[L;Y0`2Ya^h60:_7kP80[<7Y0`2W
`N`60:[5k@D0Yl7/1@2[a>`60:W4k@D0[<3X1`2/`NT40:bliPH0[;gV0`2[^nD30:bli@@0ZkcV00@0
00000:Zli`2Z_>L0Z[cW0`2[_>H50:Zli`D0Z[gW00<000000?ooo`3oool0E`3oool007X0oooo00L0
ohle000DG`34ool0oooo0?ooS`0e01@0GlCo01l0oooo0P000000103oool0Z/W`0:[9l02ZbO050:c5
k0H0ZLK^1@2[anh60:O1k0<0Z/G]0`2T^nT50:O1k080ZlC/0`2S^n/60:W4k@80[<3X0`2W`^`60:c1
j@D0[<;Z1P2/_NH60:bli@<0ZkcV00<000000:^liP2[_>H01@2[_>H20:Zli`<0ZkcV1@2Z_NL00`00
0000oooo0?ooo`0B0?ooo`050=nLB000000000000000B02Lgol0?`3oool007X0oooo00L0olAO01@D
G`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`0000070:[9l080[<G/0`2W`nd60:W6kPD0Y;_Y1@2W
`N`70:Bkj@@0Yl7/1P2S^n/50:W4k@H0Yl;/0`2/`NT30:K0k0D0[<;Z0`2/_NH30:c1j@P0[;cU00<0
00000:bli@2[_>H02`2[_>H40:Zmi`030?ooo`000000oooo0140oooo00L0okmd0018W03Oool0oooo
0?oog`2LB7@0_ooo03h0oooo001j0?ooo`070?ooS`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?oo
o`<000001@2Xb_450:[9l0H0Yl?]0`2Ya^h30:Vmj0D0Y;_Y1@2Y_NP60:Bkj@D0ZKgX1P2S^n/50:>k
jPD0Yl;/1`2V`>`40:c2jPL0[<7Y0P2/_>D30:c0j080[;cU00<000000:bli@2/_>D00`2[_>H30:bl
i@D0ZkcV1@2Z_>L00`000000oooo0?ooo`0E0?ooo`030;md001d_ol0oooo03d0oooo001j0?ooo`06
0?ooa01O5000=Hoo0?ooo`34Ga@003F?603oool2000000040:K6l0000000Y/K`0:K6l0D0Z<[a1@2U
_^/60:O3k@H0ZKgX0P2T^nT80:Vmj0<0Y;_Y202Y_NP30:>kj`<0ZKgX1@2S^nX50:Fkj@H0Y/3/1@2U
_n`60:c1j@H0[<3X00<0[;cU0000002/_>D0202/_>D20:^liP<0[;cV1@2Z_>L00`000000oooo0?oo
o`070?ooo`030?oOW0180000000000<0000000<0001d0;ooo`3oool0103oool00`2oM000M;oo0?oo
o`0m0?ooo`00N`3oool01@3oohl0=@000000000055l0a?oo01D0oooo0`0000070:K6l0D0Y[cY1@2U
_^/W0:Vmj080Xk_Z0`2Y_NP50:Fkj@<0Y/3/0`2U^nT50:Fok0<0[<7Y0`2V`>`50:c0j0030:foi`00
0000[KoW0080[KoW1P2/_>D60:bliP@0Z[cW00<0oooo0000003oool03`3oool01`3ogi`0B01809cO
o`3oool0oooO09a8B02Lgol0?P3oool009<0oooo0P0000050:K3kP<0Y/K`0`2Y_NP50:Jlj@80YKk[
;`2Y_NP;0:Fkj@@0YKo/1`2V`>`20:c0j0<0Yl;/00<000000:foi`2]_nL00P2]_nL30:bli@<0[KkV
1@2/_>H50:^liP030000003oool0oooo00h0oooo00<0oono07@0000000000P0000000`1d_ol0oooo
0?ooo`0m0?ooo`00T03oool300000080Y/3/1P2V`nh60:Vmj0@0Y[cY=`2Y_NP:0:Fkj@H0Y/3/1@2W
`^`00`000000[KoW0:foi`020:foi`L0[KkV0P2/_>H30:fmiPD0ZkcV00<000000?ooo`3oool03@3o
ool00`3ooml0W4Q809cOo`120?ooo`00SP3oool2000000030:K0k0000000Y/3/00<0Y/3/0`2V`ni4
0:Vmj080YK_Y0`2Y_NP50:Fkj@H0Y;_Y102W`^`00`000000Z/?/0:[3k0030:[3k0H0[KkV1P2]_NH4
0:^liP030?ooo`000000oooo00h0oooo00<0_g@007Boo`3oool0@@3oool008/0oooo0`0000030:Nn
jPH0Y/3/C02Y_NP20:Fkj@<0ZKgX1P2T^nT20:O2k0030::jjP000000X[[Z00D0Z/?/0`2]_^H30:c1
j@D0[KgV1@2[_>H00`000000oooo0?ooo`0=0?ooo`060=nLB000000000000000000007@0_ooo?P3o
ool008T0oooo0P0000020:Rmj0D0YkkZE`2Y_NP50:Bkj@<0X[[Z00<000000::jjP2R^^X0102Z`n`7
0:c1j@80[KgV0`2]_^L50:^liP030000003oool0oooo0500oooo00260?ooo`<000001@2X_NP20:Nn
jS`0ZKgX0`2Y]N8P0:Vmj080X[[Z00<000000::jjP2R^^X01@2R^n/60:c1j@H0[KkW102[_>H00`3o
ool000000?ooo`1@0?ooo`00Q03oool300000080ZKgX1@2X_NPN0:Vmj0<0Yj[I1P2Y_NP50:BNc`D0
ZKgX1@2UXM460:Vmj0H0ZKGR802Y_NP00`2R^^X000000:Vmj0020:Vmj0D0X[_[0`2/`NT30:O1k0D0
[KkW1@2[_>H00`000000oooo0?ooo`1?0?ooo`00P@3oool3000000040:^oj02Y_NP0ZKgX00000280
ZKgX1P2WZ]T30:Vmj0<0Whbo1@2TW/l20:Vmj0<0WXZn1@2UXM430:Vmj0<0XI741@2Y]N850:NZfA`0
ZKgX00<000000:Vmj02Y_NP00P2Y_NP40::kj`L0Yl7/0P2]_^L30:_0j@D0ZkcV00<000000?ooo`3o
ool0CP3oool007l0oooo0P0000050:^oj1L0ZKgX0`2Y_>L60:Vmj0D0XiS;1@2WZ]T609n<_`D0Y9k?
1@2NR[h50:FQd@L0XI740P2Y]N830:F@`0D0Yj[I0`2Y_NP30:JWeQD0ZKgX00<000000:Vmj02Y_NP0
0P2Y_NP50:Bkj@H0Yl7/1P2[`>T40:^liP030?ooo`000000oooo04h0oooo001l0?ooo`<000000P2]
`^T50:^oj1D0ZKgX1P2Y_>L30:Vmj0<0Whk1102SV</40:NZf@80ZY2k1P2OS;l30:BNc`80]9Rk1@2N
R[h30:FQd@80/iRl1P2QTL@50:F@`0D0Yj[I1`2VYmH20:Vmj0<0Yj[I3`2Y_NP00`000000ZKgX0:Vm
j0030:Vmj0D0Y;_Y1P2Q^^X50:_0j@D0Z[cW00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD
000000000000000D05o4o`0Y0?ooo`<0000000<0[/G[0000002]`^T00`2]`^T20:^oj1<0ZKgX1P2X
/Ml50:Vli`D0Whk11@2SV</20:NZf@<0ZY2k1P2OS;l20:BNc`<0]9Rk1@2NR[h20:FQd@@0/iRl102Q
TL@20;jR_0D0YI300P2WZ]T30:fG_`H0YZOF1P2WZ]T>0:Vmj0030000002Y_NP0ZKgX00@0ZKgX0P2T
^nT30:Vmj0H0XK[Z0P2[`>T30:K1k@D0Z[cW00<000000?ooo`3oool0C03oool004X0oooo00L0ohle
000DG`34ool0oooo0?ooa01O53D0Sooo02H0oooo0P0000050:k5j`@0[L;Y4`2Y_NP30:NZf@H0Z;7O
1@2MQk/509n>`@@0XiS;1P2ZT;/509n<_`D0]9Rk1@2NR[h60;>H_0<0XI740`2nX[`50:F@`0H0[INo
102VYmH20;6J`0D0Yj[I1@2Y]N8:0:Vmj0030000002Y_NP0ZKgX00T0ZKgX1@2Q^^X60:K1k@@0Z[cW
00<000000?ooo`3oool0C03oool004l0oooo00<0ScD003F?o`3oool08P3oool300000080[/W]1@2^
aN/E0:Vmj0H0Yj[I102X/Ml20:F<^`@0WHNk1@2OS/420:>Hb`<0[iJm1@2ZT;/409n<_`80]io11@2d
V;/309j:_P80_:?01P2cV;`00`2QTL@0_Z:l0;jR_0020;jR_0@0YI300P33Z;h60:fG_`80YZOF0`2a
V/040:NZf@80[i_21@2Y]N890:Vmj0030000002Y_NP0ZKgX00T0ZKgX1P2T^nT50:K1k@D0Z;gX00<0
00000?ooo`3oool0B`3oool00480oooo00<0olAO01@0000000000`0000000`0003D0Sooo0?ooo`04
0?ooo`0308le000eSol0oooo0200oooo0P0000060:k9k@80[/G[4`2Y_NP50:JWePH0Yj[I0P2X/Ml3
0:F<^`@0WHNk1@2OS/450:nF_@H0ZY2k0P2OS;l30;NO`@D0]9Rk0P2NR[h30;bS`0H0/iRl1P2nX[`2
0:F@`0<0`jRn1P2]Ukl60;6J`080Yj[I102_Vl840:VehPT0ZKgX00<000000:Vmj02Y_NP02P2Y_NP5
0:Bkj@H0WkW[1@2X_NP00`000000oooo0?ooo`1:0?ooo`00BP3oool01`3oa5l0500D05o4o`3oool0
ooo405lD501Oa?l07P3oool3000000030:g;k`000000[L__00D0[/W]4`2Y_NP80:JWePD0Yj[I1@2U
S;/509f7^`<0Whk10P2_V/850:nF_@D0ZY2k1@2gWl450;BH^`H0_:?0102cV;`20<:_b0D0_Z:l00<0
YI300<>X_P33Z;h00P33Z;h50:fG_`80aZbo1@2aV/060:nK`PD0Z9W6202Y_NP00`000000ZKgX0:Vm
j00;0:Vmj080Y;_Y0`2Y_NP609nij`@0Z;gX00<000000?ooo`3oool0BP3oool004X0oooo00<0oon?
03D0000000000P0000000`0eSol0oooo0?ooo`0K0?ooo`8000000P2/bNl50:g;kaD0ZKgX2`2VYmH5
0:>;_0D0YHbk102MQk/209n>`@<0[i[21@2_U[d40:Z@^`80^:W;1@2gWl430;BH^`80_[7=1@2lXl03
0;>H_0<0`Zo81@2nX[`60<>X_P<0[INo0`36[;l40;6J`080bJjo1@2_Vl800`3:[[d0Z9W60:RIaP03
0:RIaPD0YJ7A0P2Y_NP00`000000ZKgX0:Vmj00A0:Vmj0D0WkW[1@2U_N/00`000000oooo0?ooo`19
0?ooo`00BP3oool00`3ool@0Ga@D05o4o`0M0?ooo`<000001@2/bNl30:g;ka80ZKgX1@2WZ]T80:JW
eP<0X8^l102SRk`50:F<^`@0WHNk1@2_V/860:nF_@80ZY2k0`2hZL/50;NO`@80]9Rk0`2n/Ld60;bS
`0030;>H_032[lP0`Zo80080`Zo8102nX[`20<Jjc`D0`jRn0P2]Ukl50<J/_`80/I[00`39[[l40:nK
`P80bZjm1@2XVLH00`36Zkl0YJ7A0:FQd@030:FQd@030:Vmj0000000ZKgX0180ZKgX1P2O^N/50:Fm
j`030000003oool0oooo04P0oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P0000040:[5k@D0
[<W_4P2Y_NP30:Rag`D0Yj[I1@2VYmH50:2;_0@0Xh^l1@2US;/209f7^`<0[Yk71@2_V/850:nF_@D0
^:W;1@2gWl460;jac@D0_:?01P32[lP20;jR_0<0a[[?1@33Z;h70<J/_`030;6J`039[[l0bJjo00<0
bJjo0P2_Vl830<Z^_@@0Z9W60P36Zkl50:FQd@030:Vmj0000000ZKgX01<0ZKgX1@2O^N/50:Fmj`03
0000003oool0oooo04P0oooo001;0?ooo`060<AO5000000000000000000003D0Sooo503oool30000
0080Z/G]00<000000:[5k@2ZaNd00P2ZaNd50:g1j0l0ZKgX1P2X/Ml50:NZf@80YZOF0`2NRKd40:2;
_0D0Xh^l102US;/50:jNa`D0[i[20`2_U[d30;Nff0D0^:W;0`2gWl420;c5h@D0_[7=0`2lXl030<75
g@D0`Zo800<0_Z:l0<Jjc`36^/l00`36^/l30<>X_P80b<3C1P36[;l60<V^_`030:nK`P3:[[d0bZjm
00<0bZjm0P2XVLH40<J[_`<0YJ7A0P2jYLD00`000000ZKgX0:Vmj00C0:Vmj0@0WkW[1P2Q_Nd00`00
0000oooo0?ooo`170?ooo`00H`3oool2000000D0Z<7[0`2ZaNd30:k5j`D0[L7X2P2Y_NP50:Vli`H0
Z;7O102WZ]T509j9_@D0X8^l102SRk`20:F<^`<0[J;=1@2^W/L40:nJ`PH0]kKH1@2hZL/20;NO`@<0
_<GQ1@2n/Ld60<75g@D0`Zo81P36^/l20<>X_P@0b<3C1036[;l20<W2d`D0bJjo1P3:[[d00`2XVLH0
aZ^o0<J[_`030<J[_`80YJ7A0`2jYLD00`000000YIk>0:FNcP040:FNcPl0ZKgX1@2R^^X60:6mk@03
0000003oool0oooo04H0oooo001O0?ooo`@000000P2V_NX60:S1j`H0[/G[0P2]`NP=0:Vmj0D0ZKcW
1@2X/Ml509^7_@@0WXVm1@2PRk`40:>;_0D0[J;=1@2^W/L20:nJ`P<0]<CV1P2g]]P40;RYb`H0_<GQ
0P2n/Ld30:oMm`H0`LGM0P32[lP30;cDk0D0a[[?1P38`=<30<J/_`<0bL;C1039[[l20<c1d0D0bZjm
1P36Zkl50;ZUa@030000003@];h0YIk>00D0YIk>3`2Y_NP50::jjPD0W;[^00<000000?ooo`3oool0
AP3oool005h0oooo0`0000050:JmjP<0Z<7[0`2]and50:k5ja00ZKgX1@2Y_>L509R4_@@0VhNm1@2N
RKd40:2;_080Xh^l0`2[YM450:fRc@@0[Yk71P2da>H50;Nff080^:W;0`2`fOD50;c5h@H0[mgg1@31
aMd60;cDk080a[[?0`2dfo@60<S0d`030<J/_`39`]<0bL;C00<0bL;C0P39[[l30<c1d0@0bZjm0P3>
_LT50<J[_`030=2h`P2jYLD0^ZG50080^ZG500<000000=2d_P2UW/h01@2UW/h@0:Vmj080X[[Z0`2V
_>T509bjkP030000003oool0oooo04D0oooo001K0?ooo`<00000102V^nP50:JmjPH0[LO]5@2Y_NP5
09F2_@@0V8Bm102KQkd509j9_@@0X8^l1@2[YM450:fRc@80[Yk70`2_dO460;C4iP@0]kKH1P2`fOD6
087PnPD0[mgg1@2>hOd50;cDk0D0]=_d1P38`=<60<W2d`030<V^_`3<`M00c<7@00<0c<7@0P3:[[d3
0<jmb@@0aZ^o0P3@^<830;ZUa@040=2d_P000000d;Bn0=2d_P@0YIk>0P2n[<L?0:Vmj0H0Y[cY102L
^^h00`3oool000000?ooo`150?ooo`00F03oool3000000P0Y[_X1P2Za^h30:g7kA80ZKgX1@2OSL44
09F2_@@0V8Bm1@2KQkd409j9_@80X8^l0`2XYm@50:^Ud@@0[J;=1P2_dO450;C4iPH0UnCm1P1>bn85
087PnPH0A/GT102>hOd506_En0D0]=_d0`38`=<30:oKmPD0bL;C1P3<`M000`3:[[d0c[g90<jmb@03
0<jmb@80aZ^o103@^<820;ZUa@040=2d_P000000d;Bn0=2d_P80YIk>102n[<L60:NZf0X0ZKgX1@2V
_>T509Zfk0030000003oool0oooo04@0oooo001F0?ooo`8000000P2W^nP70:Jkj0@0Z<3[1@2Za^hB
0:Vmj0<0XiS;102OSL4409F2_@D0V8Bm102KQkd409j9_@D0Z:OD1@2[YM420:fRc@@0Z=[i1@2_dO46
07WPm080=;_>1`1Vb?d508B^l0D0GK[m100=WLL4026/e0@0JmGh102dfo@70:oKmP80bL;C0`2bfO@5
0<c1d0H0c[g900<0aZ^o0=2h`P3@^<800`3@^<80102jYLD0d;Bn0=2d_P0000020=2d_PH0_Zc700<0
dKO10:NZf02WZ]P0102WZ]P:0:Vmj080Y[cY0`2Y_NP509Zfk0030000003oool0oooo04<0oooo001C
0?ooo`<0000000<0Yk_X0000002W^nP00P2W^nP40:Jkj0L0Z<3[502Y_NP50:>Hb`@0Whg11@2EP[d4
09R4_@@0VhNm1@2VYMH50:RWe0@0ZjGA1`2Xf_T606CHiP<0UkK]1P28`?X50:Vmj0D0Q:k`1@2V_>T5
07:WlPD0QJk`0`0kYOD505O:m0@0[m_f1P2bfO@20<c1d0<0_=C/1@3>_LT60=2h`P<0d;Bn00@00000
0=2d_P3@];h0dkg4102n[<L20=6g`@H0Yj[H402Y_NP409Zfk0030?ooo`000000oooo04<0oooo001A
0?ooo`800000102X_>P:0:Nkj0<0Z<3[0`2_`nT?0:Vmj0D0Yj[I102SV</509n=`@@0UH:m102HQ;d2
09^7_@<0XZ;D102VYMH50:RWe0L0Xmol0P1Ke=d406[Hl@<0ZKgX1@2G]^d308S0nPd0ZKgX1@2V_>T5
0:Vmj0D0QJk`1@2</Nl403RNm0<0E<Kf1@2bfO@60;cDk080c[g90`37cMl40=2h`P80clC@0P3@];h0
0`000000d;Bn0=>ma0020=>ma0<0_Zc70`3A]l430:NZf0<0]jg@3`2Y_NP509fhj`030000003oool0
oooo0480oooo001>0?ooo`<000001`2X_>P40:Nji`H0Yk_X1P2_`nT?0:Vmj0@0Yj[I1@2SV</409n=
`@@0UH:m102HQ;d50::Re0D0YZGF0P2XYm@40:3Ro0<0Xmol1P25go`60:Vmj0D0UkK]402Y_NP20:Jl
j@d0ZKgX1@2</Nl503RNm0802iKH1@1TbO`50;cDk0H0algO0P3@^<830<o4d080d;Bn00<000000=>m
a03C_L@00`3C_L@00`2n[<L0dKO10=6g`@020=6g`@H0]jg@402Y_NP509fhj`030000003oool0oooo
0440oooo000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?oo
o`80000000<0ZKgX0:Rlj02X_>P01@2X_>P70:Nji`<0Yk_X0`2]aN`50:o3jA00ZKgX102WZ]T40:>H
b`@0Whg1102EP[d509jKd@D0XZ;D102VYMH70:3Ro0@0UN;m;`2Y_NP208bak`<0ZKgX1P25[^l202BF
k@@0I<Wl1@23dOl50<O=g`H0clC@00<0d;Bn0000003C_L@0103C_L@50=6g`@030=Jn`P2g[M00]jg@
0080]jg@0P37]lX@0:Vmj0D0XK[Z00<000000?ooo`3oool0@03oool001T0oooo00X0omnL04P0M02o
ool0oooo0?oog`1O500055o40?ooo`34Ga@003F?9P3oool300000080ZKgX00<000000:Vmj02X_>P0
0`2X_>P:0:Nji`H0[LG/0P2_`nTC0:Vmj0<0Yj[I102SV</409n=`@D0VIC=102NVm450::Re0L0XN;l
0P1TfMX409GRoCL0ZKgX0`25[^l30:Vmj0<0L:?`0`0HW><508?Ao`80algO0`2We?L50<o4d0030=>m
a0000000dkg400<0dkg40P3AaLh30=6g`@80e[k20`2g[M040<NgbQ00ZKgX102Q^^X00`000000oooo
0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool001T0oooo00/0omnL04P0M02oool0
oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`030:Vmj0000000000000L0ZKgX1@2X
^nL50:Nji`H0ZKoY102]aN`E0:Vmj0<0Yj[I1@2>Q<<409>;b0@0VIC=1@2NVm420::Re0D0Xmol0P1_
gmd609kTo400ZKgX101`Xo0200>8g0@0Pm7o1P2We?L20<o4d0<0`lkS00@0dkg40000003C_L@0dkg4
0`3AaLh30=6g`@<0e[k200<0]jg@0<NgbP37]lX00`37]lX60:Vli`/0ZKgX102Q^^X00`000000oooo
0?ooo`080?ooo`060?oog`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3o
ool0oon?03D0501Oa?l0803oool3000000L0ZKgX0`2X_>L50:Rki`<0Yk[W0P2W^nL60:VojA@0ZKgX
1@2>Pl8308Yn`0@0SXC3102CRlP509VDc@@0WY_A1@2Sgo`207_VhPD0X^[j@`2Y_NP50:Jlj@<0BHo^
0`0g[?850:ODm`H0`lkS00<000000=>ma03AaLh0103AaLh00`3A]l40e[k20=Jn`P020=Jn`PH0akO:
00<0dkk50:Vli`2Y_>L00`2Y_>L;0:Vmj0@0YK_Y00<000000?ooo`3oool0203oool01`3ookl0M01d
0;ooo`3oool0omnL04P0M02oool0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?noM00055l0
a?oo0?ooo`3oohl0=@0D05o4o`0N0?ooo`<000001`2Y_NP60:Rli`D0Z;_W1@2W^nL30:Voj@<0/<CY
3`2Y_NP50:BNc`@0SX?20`2:O/0508j4``@0Th_8102IU<d70:KInP80NnKR1@2Rj_Y60:Vmj0D0Y[cY
1019Snh2012>i0D0KL;n1@33c^<00`000000dLG>0=75cP040=75cPD0e[k200<0e/?70<NgbP37]lX0
0P37]lX30=>na@80ZKcW0`2Y/Mh;0:Vmj0@0YK_Y00<000000?ooo`3oool01`3oool01`3ogi`0B4RL
0=ooo`3oool0oono07@0B02Lgol0<03oool001T0oooo00/0omnL04P0M02oool0oooo0?oOW00D55l0
a?oo0?ooo`3oohl0=@0D05o4o`0K0?ooo`<000001`2Y_NP50:Vli`D0Z;cW1@2W^NL50:Nki`H0/<CY
3`2Y_NP40:BNc`@0SX?2102:O/0408j4``@0Th_80P2IU<d40:K>m@<0Y]Wj0P28k>L50:7`mDT0ZKgX
0P2V_>T30:Vmj0@0QZg_0`0>Q^@406g2oP<0`lkS00<0Y/ke0000002Vc_D0103AaLh20<W:f`<0e[k2
0P3F`lL30<NgbP@0dkk51P2Y/Mh:0:Vmj080YK_Y0`2X_>P00`000000oooo0?ooo`060?ooo`070?no
M000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool03@2oM000001809boW01807@0_ooo
0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool2000000/0ZKgX1@2Y_>L50:Nji`D0
YkWW1@2]a>/50;34j@l0ZKgX102TW/l508j3`P<0RWk01@2>Q<<309>;b0L0Y/ke0P28k>L30:7`mE<0
ZKgX1026[Nl300j6i0<0>:?d102Vc_D010000000Y/ke0=75cP3AaLh40<W:f`80e[k2103F`lL00`37
]lX0dkk50=>na@030=>na@030=_3`P2Y/Mh0ZK7N00<0ZK7N2P2Y_NP50:Rlj0030000003oool0oooo
00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000H0?ooo`0;0?noM0000000
001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool3000000h0ZKgX0P2Y_>L30:Rk
i`D0Yk[W0P2W^NL30:Rmj0D0[LC[502Y_NP40:BNc`@0SX?2102:O/0408j4``D0Xkk]0`2Vc_D209K`
kP0309Kai`2Y_NP0ZKgX05X0ZKgX0`18Rn/303RSm0<0Y/ke00<000000:K>m@39b]/01@39b]/00`3F
_/80e/?70=K3a`030=K3a`D0dkk50`3K`l820:VagP<0]K[M2P2Y_NP50:Rlj0030000003oool0oooo
00D0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`030?oOW01807@0
_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0D0?ooo`<0000000<0ZKgX0000002Y_NP03P2Y
_NP60:Rki`@0Yk[W1P2X_NP30:g4j`80ZkkX4`2Y_NP40:BNc`@0SX?2102:O/0509b/hPD0Xkk]0P2F
l>h209gdiP80^]3ZG02Y_NP404R;j`807Hk[0P1m`O`00`000000OL7l07g1o0050<W:f`D0e/?70P3D
a/d30=>na@@0fl?21P2e^]d?0:Vmj0030000003oool0oooo00@0oooo00H0oooO09a8001d_ol0oooo
0=nLB000M;la0?ooo`00=03oool00`2Y_NP000000000000A0:Vmj0D0ZKcW1@2X^nL50:Nji`D0Z;gX
1@2[_^P=0:Vmj0<0YJ7A0`1nN<43089la0D0RHS;102CV=H509b/hPD0X_3e0P2Mm>H40;[@jU`0ZKgX
101hY_00100HQNP07Hk[07g1o000000307g1o080bL[K0`2ibnL30=K3a`@0e<K=00<0dkk50=_3`P3K
`l800`3K`l800`3Ma/<0]K[M0;Fjg@030;Fjg@l0ZKgX00<000000?ooo`3oool01@3oool01@3ookl0
M00000000000B9`0gooo0340oooo000b0?ooo`<00000502Y_NP50:Vli`X0Yk[W1@2aaNT50:^nj0X0
ZKgX1@2UXM4307ih`@@0PWc41029R</509>HeP80W:cR1@2[jOX209gdiPH0^]3ZG@2Y_NP407RVl080
68GX00@0000007g1o01m`O`0OL7l1P2ibnL00`3F`lL0e<K=0=C6c@030=C6c@D0fl?20`3Ma/<20;Fj
g@<0_L7L3`2Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX01D0
ZKgX0P2Y_>L30:Rki`L0Yk[W0`2Z_nT50;75j@l0ZKgX102UXM4407ih`@<0PWc41@29R</409>HePD0
ZnWj0P2WmnT30<3Wl@<0^]3ZG`2Y_NP509Rfk@80000000@088?Y05R/n@1H[?T0F:ci1@2ibnL50=C6
c@80clSC0`3K`l840=g6``H0_L7L3`2Y_NP00`000000oooo0?ooo`0i0?ooo`00;03oool0102Y_NP0
000000000000000J0:Vmj0H0Z;_W102W^^L60:Zoj@<0/LGY402Y_NP50:FQd@<0OWS11022O<@408V8
b`80TiSF1@2[eoL20:Ogj@H0`>OaHP2Y_NP0202H]^d00000000000000000V;K]0223j@00000088?Y
0`11V_<50:G6l0<0e<K=103?b=<00`3K`l80gLK30=g6``030=g6``030=k9a@2m`M`0_L7L0080_L7L
0P32a]d>0:Vmj0030000003oool0oooo03T0oooo000[0?ooo`8000006P2Y_NP50:Vli`D0Z;_W1@2W
^^L50:ZojA<0ZKgX102UXM4407ih`@<0PWc41029R</50:_Gm`80/?O_1@2gnN]S0:Vmj0<000001@2Y
_NP00`000000@8KY0426j@03046Jl`D0YLK`00<0e<K=0<o8d`3?b=<00`3?b=<50=g6``<0g/W50P2m
`M`30<;6g@d0ZKgX0P2X_>P00`000000oooo0?ooo`0h0?ooo`00:@3oool2000001d0ZKgX1@2Y_>L5
0:Jji`D0Yk[W1@2`a>TB0:Vmj0@0YJ7A101nN<43089la0L0XKc/0P2`mnl30;Oijf@0ZKgX0`000009
0:Vmj00400000010Q^T0@8KY03J>k`80@I[c102Ua_050<o8d`80b/SH0`3Ma/<40=k9a@D0`/KM2P2Y
_NP60:Rlj0030000003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3o
ool2000001h0ZKgX0P2Y_>L30:Nki`D0Y[[W0P2W^^L30:c1j@D0/<CY2P2Y_NP50:VehP<0PH39101h
MlD408>6cP@0TYoM0`2Q_>`30;K`m@<0_?[Z0P37g^UQ0:Vmj0800000302Y_NP01010Q^T000000426
j@10Q^T203J>k`D0T[gd0`3?b=<40<[8f0030=g6``3NbLD0g/W500<0g/W500<0glc60<;6g@32a]d0
0`33bn0:0:Vmj0D0Z;cX00<000000?ooo`3oool0=`3oool001`0oooo00H0oooO09a80018W=l0oooo
0=nLB000M;l70?ooo`030000003oool0000001d0ZKgX1P2W^nL40:Jji`H0[<7Y0P2`a>T=0:Vmj0@0
ZKGR0`21P<T407Qga@@0PhK>1@2BWmd40;K`m@<0_?[Z1037g^UM0:Vmj0<000003`2Y_NP01P1JUNh0
000005ZEkP1JUNh0=8S/03J>k`D0T[gd00<0clSC0<[8f03:b=P00`3:b=P50=k9a@80glc61P33bn0:
0:Vmj0D0YK_Y00<000000?ooo`3oool0=P3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00D0oooo0P0000020?ooo`030000002Y_NP0ZKgX01L0ZKgX1@2X_>P:0:Nki`@0[<7Y402Y
_NP40:VehP<0PH39101hMlD408>6cP80TYoM102bg?H30;cjjPH0amkYFP2Y_NP300000180ZKgX00<0
FYG^0000001JUNh00P1JUNh203B8k0@0T[gd1@3:b=P20<K8f`<0g/W50`3Oc<H00`3PclL0`l_P0<?;
h0020<?;h080`LoU2P2Y_NP50:Fkj@030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP0
5`2Y_NP50:Rlj0D0Y[[W1@2W^nL50:k2j0h0ZKgX102Y]N830860b@@0N7O51023Q/h50;;LmP<0`?S]
0`37nNUK0:Vmj0<000005P2Y_NP0101ZW^l0000006ZNk`1ZW^l303B8k0@0Pk?d0`3:b=P40<K8f`04
0=k9a@3Oc<H0glc60=o<aP<0h<o70P33bn040<7?i@X0ZKgX102U^nT00`000000oooo0?ooo`0e0?oo
o`00703oool01`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`03
0?oooaX0ZKgX0P2X_>P30:Nki`D0Y[[W0P2W^nL30:k2j@D0[/;X2P2Y_NP409jWg0<0KG351021P<T3
07Qga@H0XK_[0P2bg?H30<3hk@<0aoWY0P2]`NQG0:Vmj0<000006P2Y_NP0101ZW^l0000006ZNk`1Z
W^l303N5jP@0Pk?d1P36b=/40=o<aP<0h<o71P31cnD:0:Vmj0D0XK[Z00<000000?ooo`3oool0=03o
ool001`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo0P0000050?ooo`030000
002Y_NP0ZKgX01H0ZKgX1P2W^nL40:Jji`H0[/;Y0P2^`^P=0:Vmj0<0WZOL101]L<D307Ilb`@0RYOJ
1P2Q^n/20<3hk@<0aoWY1@2]`NQC0:Vmj0<000007@2Y_NP206ZNk`030000001ZW^l0=hGZ00<0=hGZ
101jZo840<K8f`80`lOM0P3Oc<H40>3?a`040>;Ba`31cnD0`LoU0<7?i@<0^=7/2P2Y_NP50:6jjP03
0000003oool0oooo03<0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000:Vmj02Y_NP04P2Y_NP50:Rlj0X0Yk_W102^`^T@0:Vm
j0<0WZOL0`1]L<D407Ilb`@0RYOJ0`2Q^n/30;o/lP<0b_SY0P3@j^P50:g1j4l0ZKgX0`00000Q0:Vm
j004076Sl0000000LJ?`076Sl0@0?8?X101jZo820<K8f`@0`lOM00@0glc60>3?a`3PclL0h<o70`3R
d/L60;SAk0X0ZKgX102M^>/00`000000oooo0?ooo`0c0?ooo`00703oool01P3ooml0W4P007Boo`3o
ool0gia8001d_`H0oooo00<000000?ooo`3oool01`3ooolD0:Vmj0D0Z;cX102V^^L60:Nki`D0[/;X
3P2Y_NP309jWg0@0KG35101fO</408ZGfP@0_ncb0`3:n>T40=3Zj500ZKgX0`00000U0:Vmj004076S
l0000000LJ?`076Sl0@0?8?X0`1hY_060<?7g@<0h<o7103Rd/L00`3Ue/P0^=7/0;SAk0030;SAk0/0
ZKgX102M^>/00`000000oooo0?ooo`0b0?ooo`007@3oool01@3ookl0M00000000000B9`0gooo00H0
oooo00<000000?ooo`3oool0203ooolD0:Vmj0D0Yk_X102V^^L30:Nki`P0[/;X2P2Y_NP408jLg@03
06E^a`2NYm`0WZOL00<0KG35101fO</60;7@l0<0b_SY103@j^Q@0:Vmj0800000:@2Y_NP00`1aXo00
0000076Sl00403b3j0@0N:K`0`33amd30<?6g@030>3?a`3Rd/L0h];70080h];70`3Ue/P50:Znj0X0
ZKgX102M^>/00`000000oooo0?ooo`0b0?ooo`009`3oool00`000000oooo0?ooo`0:0?oooa80ZKgX
0P2X_>P50:Nkj0@0Y[[W1P2^`^P?0:Vmj0<0SYcM0`1UK/L306e`a@D0U:OS0`2ad?040<Wak@<0dOKV
C`2Y_NP3000002`0ZKgX00<00000076Sl01aXo000`13PnL507RVl0D0`lKM103Rd/L40>GFb0030>OK
b02Z_^P0Z[kX0080Z[kX2P2Y_NP509^cj@030000003oool0oooo0340oooo000W0?ooo`030000003o
ool0oooo00/0oooo3`2Y_NP50:Rlj0@0Yk_X1P2W^nL50:k2j0l0ZKgX0P2>W=d406E^a`<0Mh;A1@2D
Yn<50<Wak@<0dOKV0`37g^U:0:Vmj0<00000;`2Y_NP0101aXo000000076Sl01aXo0304>3i`D0NZC]
0`33a]d20<K7f`80h];7103Ue/P20>OKb0l0ZKgX1@2K/nT00`000000oooo0?ooo`0`0?ooo`009`3o
ool00`000000oooo0?ooo`0<0?ooo`l0ZKgX1@2X_>P50:Jji`D0Yk_W1@2^`^P>0:Vmj0<0SYcM0`1U
K/L407N2d@<0U:OS102lf^l30=7fiPH0amkYAP2Y_NP3000003<0ZKgX00D0JYk_0000001ZW^l0JYk_
04^3i@0204>3i`@0NZC]0P33a]d40<K7f`@0iMK80`3WflP00`3Th]40ZKgX0:Vmj00=0:Vmj0@0Vk?Y
00<000000?ooo`3oool0<03oool002L0oooo0P00000>0?ooo`l0ZKgX1@2W^nP50:Jji`D0[L3X1@2^
`^P90:Vmj0D0QigQ00<0GFc908jLg@1UK/L00`1UK/L407N2d@D0_=[_0`3@l>P30=Kbi4L0ZKgX0`00
000g0:Vmj00406ZNk`000000JYk_06ZNk`80Bh?U101jY>d50<K7f`80bl[I0P3Ue/P30>OKb0<0i>;A
302Y_NP30:Jlj@@0WK?X00<000000?ooo`3oool0;`3oool002L0oooo00<000000?ooo`3oool03P3o
ool=0:Vmj080ZKcX1@2W^nP20:Jji`<0Yk[W1@2]`>P>0:Vmj0@0QigQ0P1MK<T406E^a`D0WK;V0`2l
f^l30=3`j0<0e_;T0P33fNY30:Vmj0<00000>`2Y_NP00`000000FYG^05ZEkP0304^3i@@0P:C[0`36
am/40<_:f@@0im_80`3Th]4:0:Vmj0H0Y[cY102M/nP00`000000oooo0?ooo`0^0?ooo`009`3oool0
0`000000oooo0?ooo`0?0?ooo`X0ZKgX1@2Y_>P40:Nkj0H0Yk[W0`2]`>P20;34j@h0ZKgX0`27WN43
05e/b@@0MhKE1@2M/^H30=3`j0@0e_;T1033fNXo0:Vmj0<00000?`2Y_NP00`000000FYG^05ZEkP03
05>5i0@0P:C[1@3;b]T20=;?eP80im_80`3Th]420=WXg`X0ZKgX1@2V_>T40:6gj0030000003oool0
oooo02h0oooo000W0?ooo`8000004@3oool00`000000ZKgX0:Vmj0070:Vmj0D0ZKcX1@2V^^P50:Nj
i`D0/<CY3P2Y_NP308NMh@<0GFc9101gQ]D209fbiP@0`mc/0`3Dk>D60<?IjS`0ZKgX0`0000120:Vm
j00405ZEkP000000FYG^05ZEkP<0DhGT102:YnP30<_:f@@0d/oF0`3Th]440=WXg`T0ZKgX1P2R^^X4
0:6gj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000ZKgX0:Vmj0070:Vm
j0D0YkcX1@2V^^P50:bni`D0/<CY2P2Y_NP408^ZjP0305AXbP27WN40GFc900<0GFc90`1gQ]D50<?L
k0<0e>cU103IkN4l0:Vmj0<00000AP2Y_NP00`1DPn80000005B3hP0405>5i0@0RZOX00<0bl[I0=;?
eP3BcmH00P3BcmH20=[Fd`D0fNSO0P32gnh90:Vmj0D0X[[Z0P2Q]nP30:Fkj@030000003oool0oooo
02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0=nLB0D00000
00<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`030000003oool0oooo01<0oooo
00<000000:Vmj02Y_NP01`2Y_NP50:Nlj0D0Y[[X1@2/_^L?0:Vmj0<0Rj[Z0P1DJ<X405e/b@D0XKGV
0P33g>`30=C/i@@0fNgQ0P37g^Ti0:Vmj0800000B@2Y_NP0101DPn80000005B3hP1DPn8305j8hP@0
RZOX103BcmH30=[Fd`040>?Md03Ij=l0fNSO0=WXg`<0`]o^2P2Y_NP40::jjPD0YK_Y00<000000?oo
o`3oool02P3oool01@3OW4P000000000000004P0W=oo01d0oooo00080?ooo`060?oog`2LB000B9cO
0?ooo`3OW4P007Bo103oool00`3ogi`0B00007Boo`040?ooo`070?noM000B9`0gooo0?ooo`3ooml0
W4Qd0;ooo`060?ooo`030000003oool0oooo01@0oooo00<000000:Vmj02Y_NP01`2Y_NP30:Nlj080
Y[_X1@2V^^P20:bni`@0/LGX3P2Y_NP308^ZjP80E6S:101dQMH50:6eiP80e>cU1@3IkN440<ONjCD0
ZKgX0`00001;0:Vmj080E8?R00<0000005B3hP1DPn800`1NR>8409N]iP80d/oF0`3Je]<30>?Md0D0
`]o^2P2Y_NP509nij`D0YK_Y00<000000?ooo`3oool0203oool01`3o_g@004RL0=ooo`3oool0oooO
09a8M02oool0703oool000P0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00@0oooo00<0
omnL04P0001d_ol0203oool00`2oM000M;oo0?ooo`050?ooo`8000005P3oool:0:Vmj0D0Y[_X102V
^^P70;75j0T0ZKgX1@2N^^`01017Hl/0Rj[Z05AXbP1DJ<X507B5eP80XKGV0`35fNP40=KWhPH0amkY
<P2Y_NP3000004/0ZKgX102H]^d205R0gP030000001HP=h0GXSR00<0GXSR102G[NH30=[Fd`<0hmg@
0P3Yi/`?0:Vmj0D0WkW[1@2X_^T00`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo
00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0
oooo00<0_g@007Boo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`@0ZKgX1@2X_>P50:Jkj0D0
ZKcW0`2aaNP30:^nj0T0ZKgX102N^^`204MSb`<0E6S:101dQMH40<GIj0@0e^OR0`3Kj=hc0:Vmj0<0
0000C`2Y_NP409Rfk@0405R0gP000000F83N05R0gP<0JhgR1@2V]N@0103Je]<0hmg@0>?Md03SgM03
0>WVc0030>W_d02Y_NP0ZKgX00d0ZKgX1@2O]>H40:Rnj@030000003oool0oooo00`0oooo00<0_g@0
07Boo`3oool06`3oool000P0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0
oooO09a80018W=l0oooo0?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0
oooo01P0oooo1@2Y_NP40:Rlj0D0YK[X1@2Y_>L60:^nj0T0ZKgX102N^^`204MSb`80JWoE1`2O/ND4
0=KWhP<0fnSN0`3BinD^0:Vmj0<00000DP2Y_NP409Rfk@80F83N00<0000005R0gP1[SN800`1[SN84
0:Jei0<0hmg@0`3Yi/`30>W_d0l0ZKgX102O]>H50:[0j@030000003oool0oooo00H0oooo00L0omnL
04P0B02Lgol0oooo0?oog`2LB4P0W=oo01`0oooo00080?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`070?ooo`050?oo_`1d04P0W=oo0?oo_`1d00000`0000000`1d_ol0oooo0?ooo`040?oo
o`8000006`3oool50:Vmj0@0Yk_X1@2U^^P50;71iPD0ZkkX2P2Y_NP309jjk080Af?;0`1ZOmD509na
i@<0`m;V103Kj=h50=;WiBX0ZKgX0`00001F0:Vmj0@0N:K`0P1OPM`00`000000JhgR06^=hP0206^=
hP80Y[GT102h`N440>WVc080jNo@0P3@mnL>0:Vmj080WkCV0`2V^NL50:[0j@030000003oool0oooo
00D0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0K0?ooo`00203oool01`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md001d_ol0
oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?ooo`D0ZKcW102W^nP30:Fjj080Yk_W1@2a
`NH?0:Vmj080BG7G0`17Hl/306Yoe@<0Wk7U0`33d^H40=GPg`@0d^OU0`2]`NPV0:Vmj0<00000FP2Y
_NP407RVl080Gh7L00@0000007^Fh@1kU^40NiKQ1@2h`N420<[?g@80jNK<0P3Ykm040=3gi`d0ZKgX
1P2V^NL20:[0j@80Zl3Y00<000000?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203o
ool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0
W=oo0?ooo`2oM000M;oo2@3oool00`000000oooo0?ooo`0L0?ooo`D0ZKcW102W^nP50:Nki`<0/L7V
0`2`a>T=0:Vmj0<0BG7G0P1HLm<406Yoe@@0`m;V103Eh=l30=_Rf`H0[L7X8P2Y_NP3000005h0ZKgX
0`1VPm/205n1g0030000001kU^40NiKQ0080NiKQ0`2h`N440<[?g@80jNo@1@3@mnL90:Vmj0D0Y;_Y
1@2V^NL50:_0j@030000003oool0oooo00D0oooo00<0_g@007Boo`3oool07`3oool000T0oooo00D0
oono07@00000000004RL0=ooo`050?ooo`050?oOW018000000000000001d_ol00P3oool01P3OW4P0
0000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool07@3oool40:Vli`D0Y[[X1@2W^nL6
0;34j@d0ZKgX0P19LML305Qcd`D0U:OS1@3Eh=l30=_Rf`80fn3J1@2]`NPP0:Vmj0800000H@2Y_NP4
06J3f`0306V5f`1OPM`0000000@0NiKQ1@3:cmd20=_Of080d?OW3P2Y_NP50:Bkj@D0ZkkX102[`>T0
0`000000oooo0?ooo`050?ooo`060=nLB000000000000000000007@0_ooo703oool002D0oooo0P00
000O0?ooo`D0Z;cW102V^^P50:bmiP<0/<CY302Y_NP306VTl`<0BG7G0`1HLm<309BWh`<0^/OT0P3E
h=l30=_Rf`@0fn3J8@2Y_NP3000006@0ZKgX0`1VPm/306V5f`030000002@Xn80T:?R0080T:?R0`3:
cmd30=_Of080ingA00<0j_K;0:Vmj02Y_NP0302Y_NP50::diP@0ZkkX1@2[`>T00`000000oooo0?oo
o`0V0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`D0Z;cW1@2V^^P40:bmiPl0ZKgX0`1YY?<2
03iSc`@0F7?C1P2jan@20=_Rf`D0fn3J0`37g^TL0:Vmj0<00000I`2Y_NP406J3f`80JHGK00<00000
092ShP2@Xn800`2@Xn840=_Of080ingA0P3Zm//?0:Vmj0@0X[CV1@2]`>P50:_0j@030000003oool0
oooo02D0oooo000U0?ooo`030000003oool0oooo0200oooo1@2W^nL50:Jjj0D0//;V3P2Y_NP206VT
l`<0?V??1020U]l40;[7i080cmON103HfmT60<ONjAP0ZKgX0`00001W0:Vmj0@0Qj_]0`1YPMP306V5
f`030000002@Xn80T:?R00<0Z;GS0P3KgmP20>O]d@80j_K;0P3=l^X?0:Vmj080X[CV0P2W^^H50:g0
j0@0ZkoX00<000000?ooo`3oool09@3oool002@0oooo0P00000S0?ooo`D0Yk_W0P2V^^P30:Rki`D0
//;V3P2Y_NP0100TE/`0JJCc03iSc`0nHll5082Fg`80^/OT0P3?emh40=SKf@80fm[F0`37g^TG0:Vm
j0<00000JP2Y_NP508N[k@<0JH7H0`1hS]`00`000000Z;GS0:Reh`030:Reh`80ingA0P3Zm//40<gb
jPh0ZKgX1@2W^^H20:g0j0<0[L7X102[_nP00`000000oooo0?ooo`0T0?ooo`00903oool00`000000
oooo0?ooo`0S0?ooo`@0Yk_W1P2X^nL20;;2iP<0[l?Y3@2Y_NP202AFc0<0?V??1020U]l30<oGgP@0
f=_I103Kf]HF0:Vmj0<00000JP2Y_NP40:Jlj@@0Kh;F0`1YPMP407R>g0030000002X]N<0Z;GS00<0
`lgR0P3Zm//50<gbjPX0ZKgX1@2T^^T40:NjiPH0[L7X0P2[_nP20:Znj0030000003oool0oooo02<0
oooo000T0?ooo`030000003oool0oooo02@0oooo1@2W^^L40:Rki`H0[l?Y3@2Y_NP202AFc080GWkK
1P2X]n@40=SKf@@0fm[F0P3Jf=HB0:Vmj0<00000KP2Y_NP30:Jlj@D0Kh;F00<0LHCG06V1f01YPMP0
0`1hS]`00`000000`lgR0<?=hP020<?=hP<0fnKM00<0i_S@0:Vmj02Y_NP03@2Y_NP40:Bjj@D0[;oX
1@2]`NP40:Znj0030000003oool0oooo02<0oooo000T0?ooo`8000009P3oool50:Nji`D0[KgU0`2_
`nT<0:Vmj080Fikc0P0TE/`405inf`<0Z;OT1033b]l40=_JeP@0f]SF3P2Y_NP300000740ZKgX102V
_>T406n2eP<0LHCG102=W]h00`000000`lgR0<?=hP030=_Vg@030>Khd03Iolh0fOo>00h0ZKgX1@2S
]>D50:boj0D0[<3X102Z_^P00`000000oooo0?ooo`0R0?ooo`008`3oool2000002P0oooo1@2X^^H5
0:fmi@l0ZKgX0P1KW_<00`0_HM8095K<05inf`0305inf`D0`l[O0`3AdMT50=[HeP<0c=OQ2P2Y_NP2
000007@0ZKgX102V_>T406n2eP@0LHCG102=W]h01@000000fnKM0=_Vg@3Ki]d0i_S@00@0fOo>3P2Y
_NP50:>di@D0[L7X102/`>P50:Znj0030000003oool0oooo0240oooo000=0?ooo`0;0?oo_`1d0000
00000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`070?oo
o`030000003oool0oooo02L0oooo1@2X^^H50;?0h`l0ZKgX00<0Fikc02mQdP0_HM801@28Wn<30<?:
g`@0dM7I0P3GdmD20=[HePD0c=OQ1P2Y_NP3000007L0ZKgX1021T]/307>2d`@0LHCG0P2=W]h30:Vh
h`030000003Ki]d0i_S@00<0fOo>0`2cbn`>0:Vmj080XkCU0`2Y_NL40:g1j0D0ZkoX102Z_^P00`00
0000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd
0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:@3oool30:RjiP80Zk_U
1@2c`><>0:Vmj00400mIdP1KW_<0;f7B02mQdPD0R9oS1@3AdMT40=OCe@@0c=OQ0`2jd>X20:Vmj0<0
0000N`2Y_NP3086Bf`@0Lh;C0`21T=T50:Vhh`040000003Vn=00fOo>0=WocPD0/l_/3P2Y_NP50:Vm
i`D0[<7Y1@2[_nP40:Vmj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00P0oooo00<0_g@007Boo`3oool01@3oool2000002/0oooo1@2[^nD30;?0h`<0/l;U3@2Y_NP0
100?FM80;f7B02mQdP0_HM8308ROh`<0Z[SS0P3AdMT40=OCe@<0fM;B102jd>X3000007h0ZKgX1021
T]/307>2d`@0PI3I0`2Y^><20<[JiP040000003On=T0g?k40=cna0@0/l_/2`2Y_NP40::ei@80ZKgW
0`2]`NP50:c1j@D0Z[kX102Y_NP00`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02/0
oooo1@2[^nD60;?2i@`0ZKgX0P0?FM8304mkg@H0Z[SS103GdmD30=WBdP80fM3@0`00001n0:Vmj0@0
SYcM0`1hP]4407>2d`@0PI3I103:f^H00`3On=T000000=cna0020=cna0h0ZKgX102R]ND60:g1j080
[<7Y0`2[_nP40:Znj0@0ZKgX00<000000?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0
oooo0?oo_`1d04P0W=oo00<0oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<0
00000?ooo`3oool0;03oool50:jmi@<0/l;U0`2a`nL90:Vmj0<0Qk;a00<0253=00mIdP1?Nmd00P1?
Nmd30:Zhh`<0`<CN0P3GdmD30=WBdP<0000000<0fM3@0:Vmj02Y_NP0O`2Y_NP308jLg@@0N8;A0`1m
RMD509VWh080b][V00@0goSI0=cna0000000g?k40`31h>h=0:Vmj0D0Yk[W1@2]`NP50:^oj080Z[kX
0`2Z_NP40:Vmj0030000003oool0oooo01h0oooo000<0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`030?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool01@3oool00`000000
oooo0?ooo`0^0?ooo`@0[[gU1P2a`nL90:Vmj0<0Qk;a0P08D<d304mkg@H0`<CN00@0fM;B00000000
00000000103Id=020=O=cgl0ZKgX102>W=d307R2d@@0OHWE1@2IYn001@3On=T0g?k40=cna031h>h0
000000<0`N3^2@2Y_NP50:BgiPD0Yk[W1@2]`NT40:^oj0H0Z[gX102Y_NP00`000000oooo0?ooo`0M
0?ooo`00303oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3ooml0W4Q809cO
o`090?ooo`800000<@3oool50;:oi0<0/L?W0P2]`NP:0:Vmj080?Hk^0P08D<d307JHi@<0`<CN0`00
00000`3;bMP0fM3@0=W@d0030=W@d0@0elg?NP2Y_NP509>Lf@<0OH?>101hP]4407f9e@80VJOP0`2k
cnT01@3Hn>40dOk00=7n`02Y_NP0000000`0ZKgX1@2T]nH50:c0j0@0[L7Y1@2Z_^P50:Zmj0@0ZKgX
00<000000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l50?ooo`03
0;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3oool50;:oi0D0[L7X2P2Y_NP203f>kP03
01YPeP08D<d0MYSU0080MYSU0P0000030<_9f0<0dL_C0P3Id=040=O=c`80dL[CNP2Y_NP409>Lf@@0
OH?>0`1oQm8407f9e@@0^loY00<0f?SQ0=7n`03Ao/000P36inh00`2Y_NP000000:Vmj00;0:Vmj0D0
Y[SV102/`>P50:_0j0D0Z[kX2@2Y_NP00`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M000
00000000B9`0gooo00D0oooo00H0gia800000000000000000000M02oool50?ooo`030000003oool0
oooo0380oooo1@2f`N<40:g1j0/0ZKgX00<005G=03f>kP0JH=H00`00000209J]iP80blWH1@3Abm<4
0=O=c`@0dL[CNP2Y_NP409>Lf@<0OH?>101oQm84096Ng@80^loY00<0f?SQ0=7n`03Ao/001036inh0
0`000000ZKgX0:Vmj0060:Vmj0D0YKSV1@2V^>H40:g1j@D0Zl3X1@2Z_NP90:Vmj0030000003oool0
oooo01/0oooo000R0?ooo`800000=03oool50;K1h`h0ZKgX0`0000000`0JH=H0UZgV09J]iP0309J]
iPD0dL_C0`3Db]050=7:d`80c<OEN@2Y_NP409>Lf@@0OH?>101oQm84096Ng@030=Shh@3Ao/00dOk0
00D0a^O^00<0ZKgX0000002Y_NP01`2Y_NP50:FhiP80Y[SV0`2/`>T40:g1j@D0Z[kX102Z_NP90:Vm
j0030000003oool0oooo01/0oooo000R0?ooo`030000003oool0oooo03@0oooo0P2f`N<30;O3h`X0
ZKgX0`0000001@2Y_NP005G=001Ec@0eM^406V3F0080UZgV0`2/^^<30=7;d`<0e<[@0P3Db<h30=7:
d`@0c<OEL02Y_NP50:Vji@@0T9?B0`22Q<`407f3cP@0OhOB102bb>X20=3ji080`_Zg1P2Y_NP00`00
0000ZKgX0:Vmj0060:Vmj0@0YKSV1@2/`>T20:g1j@<0Zl3Y102Z_^P>0:Vmj0030000003oool0oooo
01X0oooo000R0?ooo`030000003oool0oooo03@0oooo1P2g`n<60:Vmj0<000001@2X_NP00`00=KT0
05G=03Efh@060:bjh`@0e<[@103Db<h50<c7e@80b<?EL02Y_NP40:Vji@@0T9?B1022Q<`408>8d0@0
T9_K0P2bb>X20=3ji0040<;j]`31h>h0`N3^0<7PkPH0ZKgX00<000000:Vmj02Y_NP01@2Y_NP50:Fh
iP@0[<3Y1@2[`>T50:Znj0d0ZKgX00<000000?ooo`3oool0303oool00`3ogi`0B01d0;ooo`020?oo
o`050?oo_`1d000000000018W03Oool0103oool00280oooo00<000000?ooo`3oool0=P3oool30;O3
h`<0]L?T00@0ZKgX00000000000000001@2Y_NP40:Rmj003000e^@0eM^40=GKQ00<0[;[S0`2i`=l2
0=C:d0@0e<S>0P3DaL`30<c7e@@0b<?EL02Y_NP40:Vji@@0T9?B0`22Q<`408>8d0@0T9_K0`3@n^@6
0<7PkPD0ZKgX00@000000:Vmj02Y_NP0ZKgX1@2V]nD40:FhiPD0[<7Y0`2[`>T70:Znj0d0ZKgX0P00
000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_`@0oooo000Q0?oo
o`800000>@3oool30;G3i0<000002@2Y_NP409NhkP03000e^@1@RnT0D8_Y00H0^L3O103Db<h40=C5
c0H0b<?EL02Y_NP40:Vji@@0T9?B1022Q<`408>8d080T9_K0`2`b^d00`37o^40[O2Y0:g`Z@0:0:Vm
j0040000002Y_NP0ZKgX0:Vmj0@0Y[OU1@2[`>T50:c1j@L0Z[kX402Y_NP00`000000oooo0?ooo`0:
0?ooo`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00240
oooo00<000000?ooo`3oool0>03oool3000000040;G3i02b`^H0//;V0;;2iPT0ZKgX102G^>h01000
=KT0D8_Y052;j@1@RnT30;W0g`80`L;K0P3Db<h50=C5c080dl?;0`38`mD20<Nodf/0ZKgX1@2UYMD4
08Z7bP<0QXG;1022Q<`408>8d0@0/<[]00<0aokQ0:g`Z@2cbn`00P2cbn`:0:Vmj0040000002Y_NP0
ZKgX0:Vmj0@0Y[SV2P2[`>T40:Znj180ZKgX00<000000?ooo`3oool02P3oool02`3ogi`0B01d0;oo
o`3oool0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo000Q0?ooo`030000003oool0oooo
03H0oooo0P0000020?ooo`H0//;V2@2Y_NP309NhkP03000c]`1@RnT0D8_Y0080D8_Y1@31`]/50=C5
c0@0dl?;1@37_m=[0:Vmj0@0YJGE102:QlX408J5b`@0Qh_@102CW]/20;3:k@030<Onh@2cbn`0/l_/
00@0/l_/2@2Y_NP00`000000YKKU0:Ffi@020:Ffi@@0Y[SV1@2/`NT40:_0j@D0Z[kX4P2Y_NP00`00
0000oooo0?ooo`090?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02L
gol00`3oool00240oooo0P00000d0?ooo`<000001@3oool30;;2iP<0[/7W2@2Y_NP408JblP04000c
]`1UVnh0II_^06FKkP<0`L;K0`35`mP20=C5c0@0dl?;0P3B`LT30<Nod`80akc@J`2Y_NP40:FUe@@0
RXO:0`26QL/508N;d0<0TikK0P37o^420<3l`P<0/l_/302Y_NP010000000YKKU0:Ffi@2U]^D90:c1
j@T0Z[kX4`2Y_NP00`000000oooo0?ooo`080?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=oo
o`3oool0oono07@0B02Lgol00`3oool00240oooo00<000000?ooo`3oool0<03oool3000000T0oooo
1P2^`NL90:Vmj0@0Q[;b00D003>c06FKkP1UVnh0II_^0<72f`050<G3f0@0dl?;103B`LT00`37_m<0
akc@0<Nld0020<Nld6X0ZKgX102UYMD408Z7bP@0QXG;1027Rm040;?FlP@0`?c23P2Y_NP00`2U]^D0
00000:Nji`020:Nji`@0[<7Y1@2[`>T50:Znj1H0ZKgX00<000000?ooo`3oool01P3oool03@2oM000
001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool000@0oooo
00d0oono07@00000000004RL0=ooo`3oool0omnL04P0M02oool0oooo0?oo_`1d04P0W=oo00@0oooo
00D0gia8000000000000001809cOo`070?ooo`030000003oool0oooo02d0oooo0`00000>0?ooo`@0
[/7W2P2Y_NP407f^l`03000c/`1bY_40LZKa00D0aL?H0P36`mL20=?3b`D0d/791037_=030<Zjbf40
ZKgX102VX<l409::a`@0SHO80`2;R</408J5b`D0VJOP0P2ce_800`30o<80ZKgX0:Vmj00@0:Vmj080
Yk[W00@000000:Nji`2W^^L0Yk[W102/`NT50:_0j@D0Z[gX5P2Y_NP00`000000oooo0?ooo`060?oo
o`0;0?noM0000000001d0;ooo`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0103oool000<0oooo
00H0oooO09a80018W=l0oooo0=nLB000M;l50?ooo`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018
W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0:P3oool300000180oooo102/
_nP:0:Vmj0@0OJkc00<003>c07:Vl@1bY_400`35`mP40<K3e`D0d/790P3@_/T20<Nld0D0b[[;102X
[meH0:Vmj0D0ZJoL0`2VX<l409::a`@0SHO8102;R</408f@dP@0VJOP00@0]n_f0<gbjP3=l^X0cO;Z
302Y_NP30:Vli`<0Y;CT00<0Yk[W0000002W^^L00P2W^^L50:c1j@D0Z[kX102Z_NPB0:Vmj0<00000
00<0oooo0000003oool0203oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0103oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<0_g@004RL
g`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`800000:@3oool3000001H0oooo102/_nP90:Vm
j0@0OJkc00@0032]07:Vl@1bY_40LZKa1`36`mL30=;1b@@0d;k91@3:^//20<fhaP@0Z:oMF02Y_NP4
0:V_g0@0YZ3?102BR/L408f7b0@0RhS;0`2=T=840;O[mPD0cO;Z2@2Y_NP50:Vli`@0Y;CT00<0[<7Y
0000002/`NT0102/`NT30:^oj@@0Z[kX4P2Y_NP3000000D0oooo00<000000?ooo`3oool05@3oool0
00<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03Oool01`3o
ool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?ooo`D0Z[gX2@2Y
_NP407f^l`<0N:cc1`36`mL00`3B`LT0d;k90=2nb@020=2nb@80ckg90`3:^//40<fhaP80Z:oM0P2c
[mAH0:Vmj0@0ZJoL0`2VX<l409::a`@0SHO8102;R</50::kj`<000003P2Y_NP40:Vli`D0ZKgX00@0
[<7Y0000002/`NT0[<7Y1@2[_nT50:Zmj0h0ZKgX0`0000080?ooo`030000003oool0oooo01D0oooo
00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo0080
oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool08P3oool3
000001h0oooo1@2Z_NP90:Vmj0@0Q[;b0`1h[?<60<K3e`@0d;k9103?_LT00`3:^//0cKS60<fhaP03
0<fhaPD0/joDE`2Y_NP40:V_g0<0YZ3?102BR/L408f7b0D0UIgI0`2R^n/B0:Vmj0D0XkCT102Y_NP2
0:c1j@030000002/`NT0[<7Y00<0ZkoY0P2Z_^P50:Zmj0T0ZKgX1000000<0?ooo`030000003oool0
oooo01@0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`060=nLB000
M;l0oooo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0oooo01l0
oooo0`00000R0?ooo`D0Z[cV2@2Y_NP408JblP@0M:of0`36`mL20<G3f080d;k91@3?_LT50<fhaP80
c;O50`2c[m@20;j`be80ZKgX1@2JSL@409N;a@<0ThW6102ARlT4096?cP@0UIgI0P2R^n/20=3gi`h0
ZKgX102Y^>@50:>di0@0[<;Z00<0[<7Y0000002/`NT00P2/`NT50:Znj080Z[gX1`2Y_NP0103oool0
000000000000000@0?ooo`030000003oool0oooo01@0oooo00030?ooo`070?oo_`1d07@0_ooo0?oo
o`3ogi`0B01d0;ooo`060?ooo`070?oo_`1d04P0W=oo0?ooo`3ooml0W4Q809cOo`090?ooo`800000
7P3oool2000002H0oooo00<000000:ZliP2Z_>H00P2Z_>H90:Vmj0@0UkS^101d[oH50<G3f0D0ckg9
0P3>_<X30<fhaP@0c;O500<0/joD0;j`b`2n/</00P2n/</50:NVeDT0ZKgX102UUlL409Z=a0@0Uh_5
0`2CRLH4096;b@D0THo>0`2EWMT00`2[h?T0d?OW0=3gi`020=3gi`h0ZKgX102Y^>@50:[0j@@0[<;Z
00<0ZkoX0000002[_nP00P2[_nP40:Znj0D0ZKgX0P3oool3000001<0oooo00<000000?ooo`3oool0
503oool000<0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0gooo0?oo
o`2oM000M;oo203oool2000001`0oooo0`00000Z0?ooo`@0Zk_U2@2Y_NP409NhkP@0IZgh0`35`mP2
0<74g0<0ckg9103>_<X00`3=^<H0c;O50<bga@030<bga@D0_[3;00<0ak730:NVe@2WY]D00`2WY]D4
0:VjiD00ZKgX1@2VVl/30:FGa`D0VXg40`2GRlD409>9aP@0TH_9102ASlh30:_Pn@030=3gi`2Y_NP0
ZKgX0100ZKgX1@2W^^L40:[0j@D0Zl3Y00@0ZkoX0000002[_nP0ZkoX1`2Y_NP4000001H0oooo00<0
00000?ooo`3oool0503oool000@0oooo00D0oono07@00000000004RL0=ooo`040?ooo`030=nLB000
0000000000<0000000<0M;oo0?ooo`3OW4P00`0000000`0007@0_ooo0?ooo`040?ooo`030000003o
ool0oooo01L0oooo0`00000^0?ooo`@0Zk_U2@2Y_NP40:Rmj0@0IZgh1@31a=`60<jlbPD0c;O50P3;
]/D30;j`b`<0ak730P2WY]D30;RYbP@0ZK[U>`2Y_NP50:JNc@@0YY_;102UUlL409Z=a0<0Uh_5102C
RLH4096;b@D0X;WZ00<0QN[A0:Vmj02Y_NP03`2Y_NP40:Bch`D0Yk[W102/`^X40:_0j@030:Zmj000
0000Z[gX0080Z[gX102Y_NP2000001X0oooo00<000000?ooo`3oool0503oool001l0oooo00<00000
0?ooo`3oool05@3oool300000380oooo102^^n<90:Vmj0D0Z;gX00<002:O04JRmP16X_H00`31a=`2
0;_6h`@0c[c:0P3;_Ld30<bga@@0bkK500<0_[3;0<Na``37/L<00P37/L<60;RYbP@0Z:7?=`2Y_NP8
0:JNc@@0YY_;102UUlL409Z=a0<0Uh_51@2GU]0409VQfP<0X;WZ00<0QN[A0<;OkP2Y_NP0302Y_NP5
0:Vhi0@0Y;?S1@2[`NX40:c2jP@0Z[kX00<0Z[gX0000002Z_NP00P2Z_NP2000001d0oooo00<00000
0?ooo`3oool0503oool001l0oooo0P00000C0?ooo`<00000=P3oool40:jkh`h0ZKgX00<005C<00b5
h`0<QN<01@2ka^<20<jlbP@0bkg=1P3;]/D50<Na``030<Ra``2hZLX0^:W:0080^:W:0P34[<840:RQ
c`D0YjKD;@2Y_NP50:JKb`P0YYk=0`2VVl/509b>a@@0VXo70`2HTLX509NFd0@0VJ7J00@0QN[A0<;O
kP32gnh0`]o^3P2Y_NP40:Vhi080Y;?S0`2Z_^T40:_1jPD0ZkoX102Z_^P300000200oooo00<00000
0?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool03`3oool3000003X0oooo0P2^^n<30;6l
hPd0ZKgX00<005C<00b5h`0<QN<01@2ka^<40<^mc@80b<7C103;]/D20<^hb0<0ak730P38/L<30;RY
bP<0a:c20`2XXLl20;bWa0D0YjKD102XZMLN0:Vmj080ZJoL1@2Y_NP40:FGa`@0YY_;202VW/d409j?
``@0W8k5102JSlL409RAbP@0UiK@102Oj_X40<;OkPh0ZKgX102Y^>@50:Znj@T0ZkoX0`0000030?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3o
ool0303oool3000003d0oooo1P2a_>8=0:Vmj080?Hk^00<005:a0:c:k`2/b^l00`2/b^l20<^mc@@0
b<7C0P3;]/D40<^hb0030<Na``38/L<0b;730080b;7300<0^:W:0<B/`P34[<800`34[<800`2XXLl0
_:O40;bWa0020;bWa080YjKD0`2eX/D40:RYe`D0YjKD102Y_NP50:Vji@d0ZKgX1@2Y[m`20:Vmj0<0
Xi;30`2UUlL50:JKb`<0YYk=1@2QT<8309j?``D0W8k5102JSlL309RAbPH0Xlog0`2an^HA0:Vmj0D0
YkWV0`2Z_^T20:c0j0D0ZkoX0`0000060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool04`3oool001l0oooo00<000000?ooo`3oool02@3oool300000440oooo0`2a_>830;Bmh0d0ZKgX
0`0mS^h50:c:k`D0b<7C1P3;^<P50<Ra``H0a:c21@2lYl@60;FRa@80Z:WG0P2bWl@50:NVe0@0YYk=
102Y^^D50:NVe0@0ZKgX1@2VX<l40:V_g0D0Xi;3102UUlL40:JKb`@0Xi72102QT<8409j?``@0W8k5
102JSlL40:6hj@<0Xlog00<0/O[V0:Vmj02Y_NP03P2Y_NP30:Vdh0<0Y;;R1@2W^NH50:c0j0@00000
2P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo000N0?ooo`8000002@3o
ool2000004D0oooo1P2d_N040:Vji@T0ZKgX0`27/_4508K:oP<0b<7C0P31bN440<^hb080bKg?0`38
/L<20<Rda`@0a:c20P35[/@40;bWa0030<:Z`P2eX/D0]J;500<0]J;51@2bWl@20:NVe0<0/ik2102V
W/d40:JFa@D0YjKD102TTl@50:JPc`@0ZiK01@2ST/<30:FGa`D0YY?20`2STL850:6@`P<0WXo3102L
S/D50:2ZgP@0XKSY4@2Y_NP50:Vdh0@0Y;;R1@2/_nP0103oool0000000000000000?0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool01@3o
ool3000004P0oooo0`2d_N030;Noh0@0ZK[U3@2Y_NP408K:oPD0`LWQ0P3;^<P40<Vmc`030<Ra``38
]<L0b;C70080b;C70P34[<830<F^a0<0_:O40P32Z/840;FRa@80_jO1102bWl@50;>N`P<0YYk=0P2g
Wl040:JFa@80YjKD0`2bV/040:BCa080YZ3?0`2^V<030:^F`0D0Xi;30P2UUlL20:RE`P@0YY?2102S
TL840:6@`P<0WXo31@2QXmL40:2ZgP80Elng0P2Z_^P>0:Vmj0@0ZKKR102Y]>050:^liP<0[;oX0P00
000C0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<00000
0?ooo`3oool00P3oool3000004`0oooo1P2g_n040:fjh`d0ZKgX0P00BL<202>Rj@@0`LWQ1P39_Ll5
0<Rda`H0aJk400<0_:O40<:Z`P32Z/800P32Z/820;FRa@<0_jO10`2bWl@20;fU`@@0/ik20P2VW/d3
0;NO`0@0YYK51@2bV/040:BCa0D0[YS0102[U/040:>B``@0Z9G21@2VTl830:>A`P@0XI32102RWm85
0:6Se`80X:[N00<0M^?R0;SBk@2Z_^P00`2Z_^P90:Vmj0D0ZK[U102Y]^840:Vii@D0ZkcV00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo000N0?oo
o`030000003oool0000000800000D03oool30;Noh0<0]/3R102]^^<=0:Vmj0@0Fikc102Xe?L30<Vm
c`<0`lWO0`38]<L20<NndPD0aJk41@32Z/860;nW`@040;:Oa02mYL40_JG10;fU`@@0/ik21P2gWl02
0:JFa@80]Yk11@2bV/020:BCa080/I_11@2^V<030:^F`0D0ZiS3102XUL840:JC`P<0Xi721@2TWm04
0::OdP@0XJ?G00<0M^?R0;SBk@2hd^d00P2hd^d=0:Vmj0@0ZK[U1@2W]>840:Vii@030000003oool0
oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool20000
05@0oooo1P2f`>820:fjh`80/KgS4P2Y_NP30:SDm`H0`lWO00@0b;C70<NndP37_]80akkB1035[/@2
0<Jgc0<0`Z[20P34//T50;nW`@D0_JG10P2cW/820;^T`PD0]io0102fW/450;:J`0@0/I_11@2^V<02
0:^F`080[Yc5102[V<<40:RE`P@0YY?2102VX<l40:BOd0@0XYoB0P2;ioL30;7MmQ80ZKgX102U/=l4
0:NdhP8000007`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo000C0?oo
o`030?oOW01807@0_ooo00T0oooo00<000000?ooo`3oool0E03oool40;K0hPD0/KgS4P2Y_NP00`00
?KX0?;S^03bhkP050<?9g`D0akkB0P35[/@40<Jgc0040<:Z`P34//T0a;;90<Bbb@@0_jO10P32/<T4
0;fU`@@0^jC2102gWl020;ZVa@@0]Yk10`2bV/020;FQa@@0/I_1102^V<040:jLa@@0ZiS3102XUL85
0:VSd0@0YZ3?0`2TWm0409KSo@030:OQn`2Y_NP0ZKgX0100ZKgX1@2V[mh40:F`g`030000003oool0
oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3o
gi`0B01d0;ooo`0:0?ooo`800000E@3oool40;;1i@<0/KgS0`2c_n<A0:Vmj0<0JJCc1@2Qg?`40<Nn
dPH0a[O<1@34//T20;nW`@<0`[390`2mYL420<2ab`@0^jC20P2gWl030;ZVa@@0]Yk10P2bV/030;FQ
a@@0/I_10P2^V<030;6Rb@@0[Yc50`2[V<<50:bXd`@0ZJ?@102VX<l509[PoA40ZKgX1@2Y/]l40:J_
gP8000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0D`3oool40;;1i@H0/koS102Y^>@A0:Vmj0@0
XMcl102ke>`30<Jgc0<0`LgS1034//T60<:`b@040;fU`@30/L/0`;7;0<2ab`@0^jC21P2jY/D30;JN
`@H0]J750`2aVl450;6Rb@@0[Yc50P2[V<<20:n`f0D0[:SC0`2YXm0609_PoA40ZKgX102Y]N850:Vb
g`800000:`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo000C0?ooo`03
0?oOW01807@0_ooo00d0oooo00<000000?ooo`3oool0D`3oool40:k1j0<0/koS0`2c`N@40:Vhi140
ZKgX102N^^`40;_Dk0H0`LgS0P34//T20<;9h0D0`[391@30/L/20;^T`P80_[GA1@2jY/D20;JN`@80
^Jg=1@2eXLD20;6K`@80]ZgA102aX/T40:jLa@D0[k3H102/Z=<509KSoA40ZKgX1@2Y^N@40:VehP80
0000<03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oO
W01807@0_ooo00h0oooo00<000000?ooo`3oool0D`3oool40:k1j0H0/l7T102__><A0:Vmj0@0W[[/
1013`n@50<7=h`D0`/WP0P32/<T30<3<h`@0`;7;102n]M450;ZVa@D0^Jg=102eXLD50;J]d@<0/J;9
1@2b_N840:n`f0H0Q^Gg4@2Y_NP40:VkiP@0ZKWT0`00000c0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?oo
o`1C0?ooo`@0Zl7Z0`2c`N@30:g0j0@0[kcS102Y^>@B0:Vmj0<0R;;a1@1Zf?<40<;9h0D0`<cS0P30
/L/30;_Ek@@0_[GA0P2jY/D30;g3gP@0^Jg=1@2i`N040;J]d@@0/M;a1@2b_N8505kFg080VKS^3`2Y
_NP50:Vmi`@0ZK_V0`00000g0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3o
ool00140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@0?ooo`800000E03oool40:_1jPH0[L3X102a
_n@40:Vhi0D0ZKcW5@2Y_NP406[Jl0@0`<cS1P2keNd30;jed@H0_L?N0P2i[Ld20:kPn0@0^L7P0P2f
[M4309KWn`@0/M;a0P00000E0:Vmj0P0ZKgW0`00000l0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool04P3oool00180oooo00@0okmd0000000007@0_ooo4P3oool00`000000oooo0?oo
o`1B0?ooo`D0Z<3[1@2X_nX40;6oi0@0[kcS1@2Y_>LI0:Vmj0D0@lGD102keNd40:KVn`D0_L?N1@2^
h?P30;W1h0H0U^Ok5P2Y_NP50:VkiP@0ZKgW0`0000100?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool04`3oool00`000000oooo0?ooo`1C
0?ooo`@0YkoZ1@2X_nX40:boj0@0[kcS1@2Z]n<S0:Vmj0<0Y^Kk9@2Y_NP40:Vii0@0ZK_V10000013
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool002X0oooo00<000000?oo
o`3oool0D`3oool40:NojPD0Y[k[102/_nP40;70i@D0Z[OS102Y^>=20:Vmj0D0ZKGR102Y^N@30000
04P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0
oooo102X_^X50:Jnj`@0Yko[102a`>D50;6ni0@0ZKSS102Y^N@30:Vmj080ZKWU=@2Y_NP40:Vbg`@0
ZKGR00@0oooo0000000000000000C03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0140oooo000]0?ooo`030000003oool0oooo0580oooo102X_^X50:JmjP@0Yko[102Y_nX50;6ni0@0
[kcS102Y^N@50:Vii@D0ZKWT9P2Y_NP50:Vji@D0ZK3M102Y/]l20:VehP800000C`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000^0?ooo`030000003oool0oooo0580oooo
102X_^T50:JmjP@0YKk[102Y_nX50:c0j@@0[kcS102^^n<30:Vii@80[K[S1@2Y^N@40:Vhh`@0ZKgX
1@2Y_>LE0:Vmj0@0ZKKR0`2Y^^D20:bbg@D0ZK3M0`2Y/]mD0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04@3oool002l0oooo00<000000?ooo`3oool0DP3oool40:Rnj@D0YkgY102U
_^/40:Jnj`D0[<3Y102]`>P40:jkh`D0[K[S1@2^^n<40:Vhh`@0ZKKR102Y_>L50:Vhi0@0ZKgX102Y
^>@40:Vmj0D0ZKCP102Y]^850:bbg@@0ZK3MF03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0140oooo000`0?ooo`030000003oool0oooo0580oooo102Y_NP50:Nmj@@0Y[gZ102V_^/5
0:Joj`@0[L3X102^`>L30:fjh`80[L3X1@2^^n<40:nmi0@0ZKKR102Z]n850:Vhi0@0ZKKR102Y^>@4
0:Vch0D0ZKCP102]]^040:bbg@030000003oool0oooo05X0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0oooo102Y_NP50:Rmj@@0Y[gZ102V_^X40:Jo
j`D0Yko[102^`>L50:g0j0D0[<3Y102__N@40;2oi@@0Z[OR1@2__>@40:VfhP@0[k_S102Y/n050:bj
h`@0[KKPH03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo000c0?ooo`03
0000003oool0oooo0540oooo102Y_NP90:Rmj@@0Y[kZ1@2V_^/40:Noj`T0Yl3[102/`>T50:[1jP@0
/;oU102/`>P40:nli0D0[;oW102_^n<40:Zli`@0[;[S00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo000d0?ooo`030000003oool0oooo0540oooo
2@2Y_NP40:Rmj@T0YkgY2@2V_^/40:O0j`@0Yko[1@2Z`NX40:S1j`@0[<3X102Y`>/50:boi`@0Z;kY
102Z_>MY0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool003D0oooo00<0
00000?ooo`3oool0D@3oool>0:Vmj0@0Z;gX2@2W_NT80:Jnj`T0Yko[102X`N/40:O0j`@0ZL3[1@2W
_^X40:RnjF`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=P3oool2
00000580oooo3P2Y_NP80:Rmj0T0YkgY102V_^/40:NnjPT0Yko[102W`>/80:NnjP030000003oool0
oooo06h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`00>03oool00`00
0000oooo0?ooo`1@0?oooa80ZKgX2@2X_NP40:Nmj@@0Z;gY202W_^X50:Noj`@0YkkY102W_^Ye0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool003T0oooo00<000000?ooo`3o
ool0D@3ooolE0:Vmj0@0Z;gX1@2Y_NP80:Rmj@@0YkkZ1@2X_NT40:NnjGT0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A0?ooob80ZKgX
102X_NT50:Vmj0<0Z;gY00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0100oooo000k0?ooo`030000003oool0oooo0540oooo9`2Y_NP300000840oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`00?03oool200000580oooo8P2Y_NP0
103oool000000000000000250?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3o
ool003h0oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo0500oooo6P2Y_NP30000
08d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00@03oool00`000000
oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00140?ooo`030000003oool0
oooo0500oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?
0?ooo`00A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`800000YP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00190?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001;0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool004l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool0
0540oooo0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0:`0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001F0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0000000?0?ooo`00
E`3oool2000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo0000000>0?ooo`00F@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0
oooo00<000000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0WP3oool300000200oooo001R0?ooo`800000=03oool00`000000oooo0?ooo`2J0?ooo`@0
00008`3oool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F0?ooo`@00000
9`3oool006D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3o
ool006H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool0
06L0oooo0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?ooo`00J@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo07/0oooo100000120?ooo`00K@3oool2000002T0oooo00<000000?oo
o`3oool0M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0M@3oool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
L@3oool4000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3o
ool400000540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool0
07@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M
0?ooo`030000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<000000?ooo`3oool0A`3o
ool4000007L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4
000007/0oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3oool40000
07l0oooo00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool4000008<0
oooo00220?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo0P00000=0?ooo`030000
003oool0oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01h0oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3oool05P3oool400000:T0
oooo002?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool400000:d0oooo
002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool300000;40oooo002A
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000;@0oooo002B0?oo
o`050000003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?ooo`80000000<0oooo0000
003oool0103oool400000;`0oooo002E0?ooo`80000000<0oooo0000000000000P0000300?ooo`00
UP3oool200000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0
oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59266 .42004 .5868 Mtetra
.42004 .5868 .42621 .59266 .43673 .58949 .43059 .58361 Mtetra
.43059 .58361 .43673 .58949 .44729 .58631 .44117 .58041 Mtetra
.44117 .58041 .44729 .58631 .45789 .58312 .4518 .5772 Mtetra
.663 .741 .908 r
.4518 .5772 .45789 .58312 .46854 .57993 .46247 .57399 Mtetra
.46247 .57399 .46854 .57993 .47922 .57673 .47319 .57079 Mtetra
.661 .741 .909 r
.47319 .57079 .47922 .57673 .48995 .57355 .48394 .56762 Mtetra
.658 .741 .911 r
.48394 .56762 .48995 .57355 .50072 .57042 .49474 .56452 Mtetra
.655 .742 .914 r
.49474 .56452 .50072 .57042 .51154 .56737 .50558 .56149 Mtetra
.653 .743 .916 r
.50558 .56149 .51154 .56737 .52239 .56442 .51647 .5585 Mtetra
.656 .743 .914 r
.51647 .5585 .52239 .56442 .53329 .56154 .5274 .55541 Mtetra
.664 .739 .906 r
.5274 .55541 .53329 .56154 .54424 .55863 .53837 .55211 Mtetra
.675 .731 .892 r
.53837 .55211 .54424 .55863 .55524 .55554 .54939 .54842 Mtetra
.684 .717 .874 r
.54939 .54842 .55524 .55554 .56627 .55209 .56044 .54436 Mtetra
.663 .695 .87 r
.56044 .54436 .56627 .55209 .57734 .54816 .57154 .541 Mtetra
.664 .711 .883 r
.57154 .541 .57734 .54816 .58844 .54384 .58269 .53763 Mtetra
.664 .741 .907 r
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77267 .48943 .76735 .48181 Mtetra
.664 .711 .883 r
.76735 .48181 .77267 .48943 .78463 .48645 .7793 .47819 Mtetra
.643 .686 .876 r
.7793 .47819 .78463 .48645 .79661 .48299 .79136 .4753 Mtetra
.653 .707 .886 r
.79136 .4753 .79661 .48299 .80862 .47916 .80345 .47202 Mtetra
.664 .728 .897 r
.80345 .47202 .80862 .47916 .82065 .47514 .81555 .46836 Mtetra
.671 .742 .904 r
.81555 .46836 .82065 .47514 .83273 .47108 .82768 .46446 Mtetra
.673 .749 .908 r
.82768 .46446 .83273 .47108 .84487 .4671 .83986 .46047 Mtetra
.672 .749 .909 r
.83986 .46047 .84487 .4671 .85706 .46321 .85209 .45652 Mtetra
.669 .747 .909 r
.85209 .45652 .85706 .46321 .86932 .45941 .86438 .45263 Mtetra
.667 .744 .908 r
.86438 .45263 .86932 .45941 .88164 .45566 .87673 .4488 Mtetra
.665 .742 .908 r
.87673 .4488 .88164 .45566 .89401 .45191 .88913 .44501 Mtetra
.664 .741 .907 r
.88913 .44501 .89401 .45191 .90643 .44817 .9016 .44123 Mtetra
.9016 .44123 .90643 .44817 .91891 .44441 .91411 .43744 Mtetra
.91411 .43744 .91891 .44441 .93144 .44064 .92668 .43364 Mtetra
.92668 .43364 .93144 .44064 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .5841 Mtetra
.4033 .5841 .40953 .58998 .42004 .5868 .41383 .58091 Mtetra
.41383 .58091 .42004 .5868 .43059 .58361 .4244 .57769 Mtetra
.4244 .57769 .43059 .58361 .44117 .58041 .43501 .57448 Mtetra
.663 .741 .908 r
.43501 .57448 .44117 .58041 .4518 .5772 .44567 .57126 Mtetra
.662 .741 .908 r
.44567 .57126 .4518 .5772 .46247 .57399 .45637 .56806 Mtetra
.66 .742 .91 r
.45637 .56806 .46247 .57399 .47319 .57079 .46711 .56491 Mtetra
.657 .743 .914 r
.46711 .56491 .47319 .57079 .48394 .56762 .47789 .56183 Mtetra
.654 .746 .917 r
.47789 .56183 .48394 .56762 .49474 .56452 .48871 .5588 Mtetra
.656 .75 .919 r
.48871 .5588 .49474 .56452 .50558 .56149 .49958 .55571 Mtetra
.666 .751 .914 r
.49958 .55571 .50558 .56149 .51647 .5585 .5105 .55234 Mtetra
.681 .744 .898 r
.5105 .55234 .51647 .5585 .5274 .55541 .52145 .54846 Mtetra
.671 .718 .884 r
.52145 .54846 .5274 .55541 .53837 .55211 .53245 .54487 Mtetra
.663 .708 .881 r
.53245 .54487 .53837 .55211 .54939 .54842 .5435 .54152 Mtetra
.664 .719 .889 r
.5435 .54152 .54939 .54842 .56044 .54436 .55459 .53815 Mtetra
.664 .741 .907 r
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.58812 .52797 .59388 .53425 .60512 .53085 .59939 .52454 Mtetra
.59939 .52454 .60512 .53085 .6164 .52744 .6107 .52111 Mtetra
.6107 .52111 .6164 .52744 .62773 .52401 .62206 .51766 Mtetra
.62206 .51766 .62773 .52401 .63911 .52058 .63347 .51419 Mtetra
.63347 .51419 .63911 .52058 .65053 .51712 .64492 .51071 Mtetra
.64492 .51071 .65053 .51712 .662 .51366 .65642 .50722 Mtetra
.65642 .50722 .662 .51366 .67351 .51018 .66797 .50371 Mtetra
.66797 .50371 .67351 .51018 .68508 .50668 .67956 .50019 Mtetra
.67956 .50019 .68508 .50668 .69669 .50317 .6912 .49665 Mtetra
.6912 .49665 .69669 .50317 .70834 .49965 .70289 .4931 Mtetra
.70289 .4931 .70834 .49965 .72005 .49611 .71463 .48954 Mtetra
.71463 .48954 .72005 .49611 .7318 .49256 .72642 .48596 Mtetra
.72642 .48596 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .79136 .4753 .7861 .46783 Mtetra
.664 .719 .889 r
.7861 .46783 .79136 .4753 .80345 .47202 .79818 .46416 Mtetra
.656 .705 .883 r
.79818 .46416 .80345 .47202 .81555 .46836 .81034 .46073 Mtetra
.647 .709 .892 r
.81034 .46073 .81555 .46836 .82768 .46446 .82258 .45759 Mtetra
.662 .738 .907 r
.82258 .45759 .82768 .46446 .83986 .46047 .83483 .45393 Mtetra
.67 .753 .913 r
.83483 .45393 .83986 .46047 .85209 .45652 .8471 .44998 Mtetra
.672 .755 .913 r
.8471 .44998 .85209 .45652 .86438 .45263 .85942 .44597 Mtetra
.67 .751 .911 r
.85942 .44597 .86438 .45263 .87673 .4488 .87179 .442 Mtetra
.667 .746 .909 r
.87179 .442 .87673 .4488 .88913 .44501 .88423 .4381 Mtetra
.665 .743 .908 r
.88423 .4381 .88913 .44501 .9016 .44123 .89673 .43425 Mtetra
.664 .742 .908 r
.89673 .43425 .9016 .44123 .91411 .43744 .90928 .43042 Mtetra
.664 .741 .907 r
.90928 .43042 .91411 .43744 .92668 .43364 .92189 .42659 Mtetra
.92189 .42659 .92668 .43364 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .5841 .39701 .57819 Mtetra
.39701 .57819 .4033 .5841 .41383 .58091 .40757 .57497 Mtetra
.40757 .57497 .41383 .58091 .4244 .57769 .41817 .57174 Mtetra
.663 .741 .908 r
.41817 .57174 .4244 .57769 .43501 .57448 .42881 .56851 Mtetra
.662 .741 .909 r
.42881 .56851 .43501 .57448 .44567 .57126 .43949 .56531 Mtetra
.659 .742 .911 r
.43949 .56531 .44567 .57126 .45637 .56806 .45021 .56217 Mtetra
.655 .743 .915 r
.45021 .56217 .45637 .56806 .46711 .56491 .46098 .55912 Mtetra
.653 .747 .918 r
.46098 .55912 .46711 .56491 .47789 .56183 .47178 .5561 Mtetra
.659 .751 .918 r
.47178 .5561 .47789 .56183 .48871 .5588 .48264 .55291 Mtetra
.676 .751 .907 r
.48264 .55291 .48871 .5588 .49958 .55571 .49354 .54922 Mtetra
.679 .734 .892 r
.49354 .54922 .49958 .55571 .5105 .55234 .50449 .54539 Mtetra
.664 .716 .888 r
.50449 .54539 .5105 .55234 .52145 .54846 .51547 .54204 Mtetra
.664 .733 .901 r
.51547 .54204 .52145 .54846 .53245 .54487 .5265 .53867 Mtetra
.664 .741 .907 r
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.54869 .5319 .55459 .53815 .56572 .53477 .55985 .52849 Mtetra
.55985 .52849 .56572 .53477 .5769 .53137 .57106 .52507 Mtetra
.57106 .52507 .5769 .53137 .58812 .52797 .58231 .52164 Mtetra
.58231 .52164 .58812 .52797 .59939 .52454 .59361 .51819 Mtetra
.639 .733 .916 r
.59361 .51819 .59939 .52454 .6107 .52111 .60497 .51545 Mtetra
.57 .733 .952 r
.60497 .51545 .6107 .52111 .62206 .51766 .61643 .51415 Mtetra
.537 .809 .996 r
.61643 .51415 .62206 .51766 .63347 .51419 .62793 .51236 Mtetra
.482 .854 .986 r
.62793 .51236 .63347 .51419 .64492 .51071 .63947 .51002 Mtetra
.434 .862 .936 r
.63947 .51002 .64492 .51071 .65642 .50722 .65104 .50708 Mtetra
.431 .869 .902 r
.65104 .50708 .65642 .50722 .66797 .50371 .66264 .50355 Mtetra
.488 .898 .914 r
.66264 .50355 .66797 .50371 .67956 .50019 .67427 .49943 Mtetra
.587 .93 .953 r
.67427 .49943 .67956 .50019 .6912 .49665 .68591 .49471 Mtetra
.682 .924 .971 r
.68591 .49471 .6912 .49665 .70289 .4931 .69756 .48943 Mtetra
.731 .866 .944 r
.69756 .48943 .70289 .4931 .71463 .48954 .70922 .48364 Mtetra
.687 .772 .916 r
.70922 .48364 .71463 .48954 .72642 .48596 .721 .47931 Mtetra
.664 .741 .907 r
.721 .47931 .72642 .48596 .73826 .48236 .73287 .47568 Mtetra
.73287 .47568 .73826 .48236 .75014 .47875 .74479 .47205 Mtetra
.74479 .47205 .75014 .47875 .76208 .47513 .75676 .46839 Mtetra
.75676 .46839 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81034 .46073 .80514 .45363 Mtetra
.664 .733 .901 r
.80514 .45363 .81034 .46073 .82258 .45759 .81737 .4499 Mtetra
.649 .711 .892 r
.81737 .4499 .82258 .45759 .83483 .45393 .82969 .44666 Mtetra
.653 .725 .902 r
.82969 .44666 .83483 .45393 .8471 .44998 .84206 .44327 Mtetra
.667 .749 .912 r
.84206 .44327 .8471 .44998 .85942 .44597 .85443 .43937 Mtetra
.673 .756 .913 r
.85443 .43937 .85942 .44597 .87179 .442 .86683 .43528 Mtetra
.671 .753 .912 r
.86683 .43528 .87179 .442 .88423 .4381 .8793 .43123 Mtetra
.668 .747 .91 r
.8793 .43123 .88423 .4381 .89673 .43425 .89182 .42726 Mtetra
.666 .744 .908 r
.89182 .42726 .89673 .43425 .90928 .43042 .90441 .42336 Mtetra
.664 .742 .908 r
.90441 .42336 .90928 .43042 .92189 .42659 .91705 .41948 Mtetra
.664 .741 .907 r
.91705 .41948 .92189 .42659 .93455 .42274 .92976 .41559 Mtetra
.92976 .41559 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.38014 .57546 .3865 .5814 .39701 .57819 .39068 .57223 Mtetra
.39068 .57223 .39701 .57819 .40757 .57497 .40127 .56899 Mtetra
.663 .741 .908 r
.40127 .56899 .40757 .57497 .41817 .57174 .41189 .56575 Mtetra
.662 .741 .909 r
.41189 .56575 .41817 .57174 .42881 .56851 .42256 .56254 Mtetra
.658 .741 .911 r
.42256 .56254 .42881 .56851 .43949 .56531 .43326 .55941 Mtetra
.654 .743 .915 r
.43326 .55941 .43949 .56531 .45021 .56217 .44401 .55638 Mtetra
.653 .747 .919 r
.44401 .55638 .45021 .56217 .46098 .55912 .4548 .55336 Mtetra
.663 .752 .916 r
.4548 .55336 .46098 .55912 .47178 .5561 .46564 .55005 Mtetra
.686 .749 .899 r
.46564 .55005 .47178 .5561 .48264 .55291 .47653 .54601 Mtetra
.667 .719 .888 r
.47653 .54601 .48264 .55291 .49354 .54922 .48746 .54255 Mtetra
.664 .726 .895 r
.48746 .54255 .49354 .54922 .50449 .54539 .49843 .53919 Mtetra
.664 .741 .907 r
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .52902 Mtetra
.5316 .52902 .53757 .53529 .54869 .5319 .54275 .5256 Mtetra
.54275 .5256 .54869 .5319 .55985 .52849 .55394 .52216 Mtetra
.591 .716 .93 r
.55394 .52216 .55985 .52849 .57106 .52507 .5652 .52061 Mtetra
.416 .715 .986 r
.5652 .52061 .57106 .52507 .58231 .52164 .57655 .52104 Mtetra
.094 .648 .804 r
.57655 .52104 .58231 .52164 .59361 .51819 .58796 .52092 Mtetra
.204 0 0 r
.58796 .52092 .59361 .51819 .60497 .51545 .59943 .52007 Mtetra
.275 0 0 r
.59943 .52007 .60497 .51545 .61643 .51415 .61094 .51847 Mtetra
.206 0 0 r
.61094 .51847 .61643 .51415 .62793 .51236 .62249 .51622 Mtetra
.127 0 0 r
.62249 .51622 .62793 .51236 .63947 .51002 .63409 .51345 Mtetra
.049 0 0 r
.63409 .51345 .63947 .51002 .65104 .50708 .64572 .51027 Mtetra
0 0 0 r
.64572 .51027 .65104 .50708 .66264 .50355 .65739 .50672 Mtetra
.65739 .50672 .66264 .50355 .67427 .49943 .66909 .50282 Mtetra
.66909 .50282 .67427 .49943 .68591 .49471 .68082 .49849 Mtetra
.68082 .49849 .68591 .49471 .69756 .48943 .69257 .49364 Mtetra
.69257 .49364 .69756 .48943 .70922 .48364 .70432 .48812 Mtetra
.70432 .48812 .70922 .48364 .721 .47931 .71607 .48185 Mtetra
.416 .834 .662 r
.71607 .48185 .721 .47931 .73287 .47568 .7278 .47481 Mtetra
.746 .973 .926 r
.7278 .47481 .73287 .47568 .74479 .47205 .73952 .46721 Mtetra
.724 .826 .928 r
.73952 .46721 .74479 .47205 .75676 .46839 .7514 .46161 Mtetra
.664 .741 .907 r
.7514 .46161 .75676 .46839 .76878 .46473 .76346 .45791 Mtetra
.76346 .45791 .76878 .46473 .78085 .46104 .77556 .4542 Mtetra
.77556 .4542 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82969 .44666 .8245 .43919 Mtetra
.661 .724 .896 r
.8245 .43919 .82969 .44666 .84206 .44327 .83688 .43551 Mtetra
.643 .709 .895 r
.83688 .43551 .84206 .44327 .85443 .43937 .84937 .43242 Mtetra
.664 .743 .909 r
.84937 .43242 .85443 .43937 .86683 .43528 .86184 .42859 Mtetra
.673 .755 .913 r
.86184 .42859 .86683 .43528 .8793 .43123 .87434 .42445 Mtetra
.672 .754 .912 r
.87434 .42445 .8793 .43123 .89182 .42726 .88689 .42032 Mtetra
.669 .748 .91 r
.88689 .42032 .89182 .42726 .90441 .42336 .89951 .41628 Mtetra
.666 .744 .908 r
.89951 .41628 .90441 .42336 .91705 .41948 .91219 .41233 Mtetra
.665 .742 .908 r
.91219 .41233 .91705 .41948 .92976 .41559 .92493 .4084 Mtetra
.664 .741 .907 r
.92493 .4084 .92976 .41559 .94251 .4117 .93772 .40447 Mtetra
.93772 .40447 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.37374 .56949 .38014 .57546 .39068 .57223 .38431 .56623 Mtetra
.663 .741 .908 r
.38431 .56623 .39068 .57223 .40127 .56899 .39492 .56298 Mtetra
.662 .741 .909 r
.39492 .56298 .40127 .56899 .41189 .56575 .40557 .55976 Mtetra
.658 .741 .911 r
.40557 .55976 .41189 .56575 .42256 .56254 .41625 .55662 Mtetra
.654 .743 .915 r
.41625 .55662 .42256 .56254 .43326 .55941 .42698 .5536 Mtetra
.653 .747 .919 r
.42698 .5536 .43326 .55941 .44401 .55638 .43776 .55057 Mtetra
.666 .752 .914 r
.43776 .55057 .44401 .55638 .4548 .55336 .44858 .54716 Mtetra
.687 .745 .895 r
.44858 .54716 .4548 .55336 .46564 .55005 .45947 .54307 Mtetra
.664 .716 .888 r
.45947 .54307 .46564 .55005 .47653 .54601 .47037 .53971 Mtetra
.664 .737 .905 r
.47037 .53971 .47653 .54601 .48746 .54255 .48133 .53633 Mtetra
.664 .741 .907 r
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52954 Mtetra
.50337 .52954 .50944 .53581 .5205 .53242 .51445 .52612 Mtetra
.51445 .52612 .5205 .53242 .5316 .52902 .52558 .52269 Mtetra
.512 .685 .945 r
.52558 .52269 .5316 .52902 .54275 .5256 .53677 .52271 Mtetra
.16 .637 .927 r
.53677 .52271 .54275 .5256 .55394 .52216 .54804 .52429 Mtetra
.293 0 0 r
.54804 .52429 .55394 .52216 .5652 .52061 .55938 .52495 Mtetra
.327 0 0 r
.55938 .52495 .5652 .52061 .57655 .52104 .57078 .52435 Mtetra
.159 0 0 r
.57078 .52435 .57655 .52104 .58796 .52092 .58222 .52255 Mtetra
0 0 0 r
.58222 .52255 .58796 .52092 .59943 .52007 .5937 .51981 Mtetra
.435 .869 .915 r
.5937 .51981 .59943 .52007 .61094 .51847 .60522 .51646 Mtetra
.594 .892 .989 r
.60522 .51646 .61094 .51847 .62249 .51622 .61678 .5128 Mtetra
.645 .853 .979 r
.61678 .5128 .62249 .51622 .63409 .51345 .62839 .50904 Mtetra
.657 .817 .96 r
.62839 .50904 .63409 .51345 .64572 .51027 .64004 .50534 Mtetra
.656 .798 .951 r
.64004 .50534 .64572 .51027 .65739 .50672 .65175 .50177 Mtetra
.65 .796 .953 r
.65175 .50177 .65739 .50672 .66909 .50282 .66352 .49833 Mtetra
.641 .813 .965 r
.66352 .49833 .66909 .50282 .68082 .49849 .67533 .49494 Mtetra
.627 .848 .984 r
.67533 .49494 .68082 .49849 .69257 .49364 .6872 .49147 Mtetra
.595 .893 .989 r
.6872 .49147 .69257 .49364 .70432 .48812 .6991 .48768 Mtetra
.521 .911 .929 r
.6991 .48768 .70432 .48812 .71607 .48185 .71101 .48326 Mtetra
.4 .848 .761 r
.71101 .48326 .71607 .48185 .7278 .47481 .72291 .47789 Mtetra
0 0 0 r
.72291 .47789 .7278 .47481 .73952 .46721 .73477 .4713 Mtetra
.73477 .4713 .73952 .46721 .7514 .46161 .74658 .46341 Mtetra
.623 .949 .764 r
.74658 .46341 .7514 .46161 .76346 .45791 .75834 .45458 Mtetra
.77 .897 .932 r
.75834 .45458 .76346 .45791 .77556 .4542 .77023 .4473 Mtetra
.664 .741 .907 r
.77023 .4473 .77556 .4542 .78772 .45047 .78243 .44355 Mtetra
.78243 .44355 .78772 .45047 .79993 .44673 .79467 .43977 Mtetra
.79467 .43977 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83688 .43551 .83172 .42835 Mtetra
.664 .737 .905 r
.83172 .42835 .83688 .43551 .84937 .43242 .84418 .42452 Mtetra
.641 .707 .894 r
.84418 .42452 .84937 .43242 .86184 .42859 .85677 .42143 Mtetra
.662 .738 .907 r
.85677 .42143 .86184 .42859 .87434 .42445 .86934 .41764 Mtetra
.673 .755 .912 r
.86934 .41764 .87434 .42445 .88689 .42032 .88193 .41344 Mtetra
.673 .754 .912 r
.88193 .41344 .88689 .42032 .89951 .41628 .89457 .40925 Mtetra
.669 .748 .91 r
.89457 .40925 .89951 .41628 .91219 .41233 .90728 .40516 Mtetra
.666 .743 .908 r
.90728 .40516 .91219 .41233 .92493 .4084 .92006 .40116 Mtetra
.664 .742 .908 r
.92006 .40116 .92493 .4084 .93772 .40447 .9329 .39718 Mtetra
.664 .741 .907 r
.9329 .39718 .93772 .40447 .95058 .40053 .94579 .39321 Mtetra
.663 .741 .908 r
.36729 .56347 .37374 .56949 .38431 .56623 .37789 .5602 Mtetra
.662 .741 .908 r
.37789 .5602 .38431 .56623 .39492 .56298 .38852 .55696 Mtetra
.659 .741 .911 r
.38852 .55696 .39492 .56298 .40557 .55976 .39919 .5538 Mtetra
.654 .743 .915 r
.39919 .5538 .40557 .55976 .41625 .55662 .4099 .55077 Mtetra
.652 .747 .919 r
.4099 .55077 .41625 .55662 .42698 .5536 .42066 .54775 Mtetra
.667 .751 .913 r
.42066 .54775 .42698 .5536 .43776 .55057 .43147 .5443 Mtetra
.687 .743 .894 r
.43147 .5443 .43776 .55057 .44858 .54716 .44234 .54023 Mtetra
.664 .718 .889 r
.44234 .54023 .44858 .54716 .45947 .54307 .45323 .53685 Mtetra
.664 .741 .907 r
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.47515 .53006 .48133 .53633 .49232 .53294 .48618 .52665 Mtetra
.48618 .52665 .49232 .53294 .50337 .52954 .49725 .52322 Mtetra
.569 .709 .936 r
.49725 .52322 .50337 .52954 .51445 .52612 .50835 .52214 Mtetra
.139 .582 .927 r
.50835 .52214 .51445 .52612 .52558 .52269 .51951 .52482 Mtetra
.371 0 0 r
.51951 .52482 .52558 .52269 .53677 .52271 .53075 .5264 Mtetra
.313 0 0 r
.53075 .5264 .53677 .52271 .54804 .52429 .54207 .52611 Mtetra
0 0 0 r
.54207 .52611 .54804 .52429 .55938 .52495 .55343 .52393 Mtetra
.541 .902 .969 r
.55343 .52393 .55938 .52495 .57078 .52435 .56484 .52027 Mtetra
.694 .835 .951 r
.56484 .52027 .57078 .52435 .58222 .52255 .57627 .51568 Mtetra
.705 .743 .881 r
.57627 .51568 .58222 .52255 .5937 .51981 .58774 .51067 Mtetra
.694 .684 .836 r
.58774 .51067 .5937 .51981 .60522 .51646 .59925 .50562 Mtetra
.68 .648 .811 r
.59925 .50562 .60522 .51646 .61678 .5128 .6108 .50077 Mtetra
.668 .624 .796 r
.6108 .50077 .61678 .5128 .62839 .50904 .6224 .49627 Mtetra
.657 .609 .789 r
.6224 .49627 .62839 .50904 .64004 .50534 .63405 .4922 Mtetra
.647 .6 .788 r
.63405 .4922 .64004 .50534 .65175 .50177 .64577 .4886 Mtetra
.638 .596 .79 r
.64577 .4886 .65175 .50177 .66352 .49833 .65755 .48546 Mtetra
.63 .596 .797 r
.65755 .48546 .66352 .49833 .67533 .49494 .66941 .48275 Mtetra
.623 .603 .809 r
.66941 .48275 .67533 .49494 .6872 .49147 .68135 .4804 Mtetra
.619 .62 .83 r
.68135 .4804 .6872 .49147 .6991 .48768 .69335 .47826 Mtetra
.62 .654 .862 r
.69335 .47826 .6991 .48768 .71101 .48326 .70541 .47608 Mtetra
.627 .717 .911 r
.70541 .47608 .71101 .48326 .72291 .47789 .71752 .47349 Mtetra
.64 .822 .97 r
.71752 .47349 .72291 .47789 .73477 .4713 .72962 .46995 Mtetra
.621 .932 .965 r
.72962 .46995 .73477 .4713 .74658 .46341 .74168 .46491 Mtetra
.516 .908 .776 r
.74168 .46491 .74658 .46341 .75834 .45458 .75364 .45793 Mtetra
.445 .825 .587 r
.75364 .45793 .75834 .45458 .77023 .4473 .7655 .44903 Mtetra
.69 .971 .767 r
.7655 .44903 .77023 .4473 .78243 .44355 .77728 .43898 Mtetra
.738 .848 .931 r
.77728 .43898 .78243 .44355 .79467 .43977 .78937 .43276 Mtetra
.664 .741 .907 r
.78937 .43276 .79467 .43977 .80697 .43598 .80171 .42894 Mtetra
.80171 .42894 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85677 .42143 .85158 .4135 Mtetra
.642 .709 .896 r
.85158 .4135 .85677 .42143 .86934 .41764 .86426 .41034 Mtetra
.661 .736 .906 r
.86426 .41034 .86934 .41764 .88193 .41344 .87694 .40653 Mtetra
.673 .754 .912 r
.87694 .40653 .88193 .41344 .89457 .40925 .88962 .40227 Mtetra
.673 .753 .911 r
.88962 .40227 .89457 .40925 .90728 .40516 .90235 .39802 Mtetra
.668 .747 .909 r
.90235 .39802 .90728 .40516 .92006 .40116 .91516 .39389 Mtetra
.666 .743 .908 r
.91516 .39389 .92006 .40116 .9329 .39718 .92803 .38985 Mtetra
.664 .741 .908 r
.92803 .38985 .9329 .39718 .94579 .39321 .94097 .38583 Mtetra
.663 .741 .908 r
.3608 .55742 .36729 .56347 .37789 .5602 .37141 .55415 Mtetra
.659 .741 .91 r
.37141 .55415 .37789 .5602 .38852 .55696 .38207 .55096 Mtetra
.654 .742 .914 r
.38207 .55096 .38852 .55696 .39919 .5538 .39277 .5479 Mtetra
.651 .745 .918 r
.39277 .5479 .39919 .5538 .4099 .55077 .4035 .54489 Mtetra
.665 .751 .914 r
.4035 .54489 .4099 .55077 .42066 .54775 .4143 .54149 Mtetra
.687 .744 .895 r
.4143 .54149 .42066 .54775 .43147 .5443 .42515 .53737 Mtetra
.664 .719 .89 r
.42515 .53737 .43147 .5443 .44234 .54023 .43603 .53399 Mtetra
.664 .741 .907 r
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.45792 .52718 .46417 .53347 .47515 .53006 .46893 .52375 Mtetra
.46893 .52375 .47515 .53006 .48618 .52665 .47998 .52031 Mtetra
.355 .613 .947 r
.47998 .52031 .48618 .52665 .49725 .52322 .49102 .52256 Mtetra
.294 0 0 r
.49102 .52256 .49725 .52322 .50835 .52214 .50214 .52556 Mtetra
.381 0 0 r
.50214 .52556 .50835 .52214 .51951 .52482 .51336 .5264 Mtetra
0 0 0 r
.51336 .5264 .51951 .52482 .53075 .5264 .52465 .52454 Mtetra
.629 .904 .984 r
.52465 .52454 .53075 .5264 .54207 .52611 .53599 .52037 Mtetra
.727 .781 .895 r
.53599 .52037 .54207 .52611 .55343 .52393 .54737 .51473 Mtetra
.719 .691 .822 r
.54737 .51473 .55343 .52393 .56484 .52027 .55877 .5084 Mtetra
.702 .641 .785 r
.55877 .5084 .56484 .52027 .57627 .51568 .57019 .50197 Mtetra
.687 .611 .766 r
.57019 .50197 .57627 .51568 .58774 .51067 .58165 .4958 Mtetra
.675 .594 .757 r
.58165 .4958 .58774 .51067 .59925 .50562 .59315 .49007 Mtetra
.664 .582 .753 r
.59315 .49007 .59925 .50562 .6108 .50077 .60469 .48486 Mtetra
.655 .574 .752 r
.60469 .48486 .6108 .50077 .6224 .49627 .61629 .48017 Mtetra
.646 .568 .752 r
.61629 .48017 .6224 .49627 .63405 .4922 .62794 .47601 Mtetra
.638 .563 .754 r
.62794 .47601 .63405 .4922 .64577 .4886 .63966 .47237 Mtetra
.63 .558 .755 r
.63966 .47237 .64577 .4886 .65755 .48546 .65144 .46925 Mtetra
.621 .554 .758 r
.65144 .46925 .65755 .48546 .66941 .48275 .6633 .46665 Mtetra
.612 .55 .761 r
.6633 .46665 .66941 .48275 .68135 .4804 .67525 .46459 Mtetra
.602 .548 .767 r
.67525 .46459 .68135 .4804 .69335 .47826 .68728 .46307 Mtetra
.594 .551 .776 r
.68728 .46307 .69335 .47826 .70541 .47608 .69941 .46198 Mtetra
.588 .56 .791 r
.69941 .46198 .70541 .47608 .71752 .47349 .71162 .46118 Mtetra
.588 .586 .818 r
.71162 .46118 .71752 .47349 .72962 .46995 .7239 .46029 Mtetra
.601 .643 .864 r
.7239 .46029 .72962 .46995 .74168 .46491 .73621 .45871 Mtetra
.637 .756 .935 r
.73621 .45871 .74168 .46491 .75364 .45793 .74849 .45562 Mtetra
.677 .921 .973 r
.74849 .45562 .75364 .45793 .7655 .44903 .76066 .45019 Mtetra
.627 .958 .811 r
.76066 .45019 .7655 .44903 .77728 .43898 .77266 .44199 Mtetra
.581 .901 .643 r
.77266 .44199 .77728 .43898 .78937 .43276 .7845 .43154 Mtetra
.814 .977 .895 r
.7845 .43154 .78937 .43276 .80171 .42894 .79641 .42185 Mtetra
.664 .741 .907 r
.79641 .42185 .80171 .42894 .8141 .42511 .80883 .41798 Mtetra
.80883 .41798 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86426 .41034 .85908 .40235 Mtetra
.641 .709 .897 r
.85908 .40235 .86426 .41034 .87694 .40653 .87186 .39917 Mtetra
.662 .738 .906 r
.87186 .39917 .87694 .40653 .88962 .40227 .88462 .39526 Mtetra
.674 .754 .911 r
.88462 .39526 .88962 .40227 .90235 .39802 .89739 .39092 Mtetra
.672 .752 .911 r
.89739 .39092 .90235 .39802 .91516 .39389 .91022 .38663 Mtetra
.668 .746 .909 r
.91022 .38663 .91516 .39389 .92803 .38985 .92313 .38248 Mtetra
.665 .742 .908 r
.92313 .38248 .92803 .38985 .94097 .38583 .9361 .37841 Mtetra
.661 .742 .91 r
.35425 .55136 .3608 .55742 .37141 .55415 .36489 .5481 Mtetra
.655 .741 .913 r
.36489 .5481 .37141 .55415 .38207 .55096 .37557 .545 Mtetra
.651 .744 .918 r
.37557 .545 .38207 .55096 .39277 .5479 .38629 .542 Mtetra
.661 .749 .916 r
.38629 .542 .39277 .5479 .4035 .54489 .39706 .5387 Mtetra
.69 .748 .896 r
.39706 .5387 .4035 .54489 .4143 .54149 .40791 .53451 Mtetra
.664 .718 .889 r
.40791 .53451 .4143 .54149 .42515 .53737 .41877 .53111 Mtetra
.664 .741 .907 r
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.44063 .52428 .44695 .53059 .45792 .52718 .45162 .52084 Mtetra
.656 .739 .911 r
.45162 .52084 .45792 .52718 .46893 .52375 .46265 .51762 Mtetra
.148 .504 .91 r
.46265 .51762 .46893 .52375 .47998 .52031 .47362 .5219 Mtetra
.449 0 0 r
.47362 .5219 .47998 .52031 .49102 .52256 .4847 .52488 Mtetra
.227 0 0 r
.4847 .52488 .49102 .52256 .50214 .52556 .49589 .52474 Mtetra
.52 .896 .963 r
.49589 .52474 .50214 .52556 .51336 .5264 .50717 .52123 Mtetra
.738 .801 .902 r
.50717 .52123 .51336 .5264 .52465 .52454 .5185 .51526 Mtetra
.734 .694 .812 r
.5185 .51526 .52465 .52454 .53599 .52037 .52986 .50801 Mtetra
.716 .64 .772 r
.52986 .50801 .53599 .52037 .54737 .51473 .54124 .50042 Mtetra
.7 .611 .754 r
.54124 .50042 .54737 .51473 .55877 .5084 .55264 .49311 Mtetra
.687 .596 .748 r
.55264 .49311 .55877 .5084 .57019 .50197 .56407 .48634 Mtetra
.65 .573 .756 r
.56407 .48634 .57019 .50197 .58165 .4958 .57556 .48208 Mtetra
.645 .591 .78 r
.57556 .48208 .58165 .4958 .59315 .49007 .58711 .47847 Mtetra
.652 .625 .809 r
.58711 .47847 .59315 .49007 .60469 .48486 .59871 .47485 Mtetra
.657 .655 .836 r
.59871 .47485 .60469 .48486 .61629 .48017 .61035 .47121 Mtetra
.661 .679 .857 r
.61035 .47121 .61629 .48017 .62794 .47601 .62205 .46755 Mtetra
.662 .692 .868 r
.62205 .46755 .62794 .47601 .63966 .47237 .63379 .46388 Mtetra
.63379 .46388 .63966 .47237 .65144 .46925 .64558 .46019 Mtetra
.661 .679 .857 r
.64558 .46019 .65144 .46925 .6633 .46665 .65742 .45649 Mtetra
.657 .655 .836 r
.65742 .45649 .6633 .46665 .67525 .46459 .66932 .45277 Mtetra
.652 .625 .809 r
.66932 .45277 .67525 .46459 .68728 .46307 .68126 .44903 Mtetra
.633 .585 .783 r
.68126 .44903 .68728 .46307 .69941 .46198 .69329 .44595 Mtetra
.582 .536 .769 r
.69329 .44595 .69941 .46198 .71162 .46118 .70551 .44541 Mtetra
.571 .533 .774 r
.70551 .44541 .71162 .46118 .7239 .46029 .71785 .44544 Mtetra
.563 .54 .787 r
.71785 .44544 .7239 .46029 .73621 .45871 .73028 .44576 Mtetra
.566 .567 .813 r
.73028 .44576 .73621 .45871 .74849 .45562 .74278 .44576 Mtetra
.592 .637 .864 r
.74278 .44576 .74849 .45562 .76066 .45019 .75527 .44446 Mtetra
.658 .784 .941 r
.75527 .44446 .76066 .45019 .77266 .44199 .76765 .44064 Mtetra
.726 .965 .939 r
.76765 .44064 .77266 .44199 .7845 .43154 .77981 .43337 Mtetra
.689 .968 .751 r
.77981 .43337 .7845 .43154 .79641 .42185 .79174 .42289 Mtetra
.798 .998 .791 r
.79174 .42289 .79641 .42185 .80883 .41798 .80355 .41104 Mtetra
.671 .751 .911 r
.80355 .41104 .80883 .41798 .82131 .4141 .81604 .40689 Mtetra
.664 .741 .907 r
.81604 .40689 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87186 .39917 .86666 .39106 Mtetra
.639 .708 .896 r
.86666 .39106 .87186 .39917 .88462 .39526 .87955 .3879 Mtetra
.666 .742 .907 r
.87955 .3879 .88462 .39526 .89739 .39092 .89239 .38381 Mtetra
.675 .754 .911 r
.89239 .38381 .89739 .39092 .91022 .38663 .90526 .3794 Mtetra
.671 .75 .91 r
.90526 .3794 .91022 .38663 .92313 .38248 .91819 .3751 Mtetra
.666 .744 .909 r
.91819 .3751 .92313 .38248 .9361 .37841 .93121 .37096 Mtetra
.659 .743 .912 r
.34765 .54531 .35425 .55136 .36489 .5481 .35832 .54208 Mtetra
.652 .743 .917 r
.35832 .54208 .36489 .5481 .37557 .545 .36902 .53906 Mtetra
.656 .747 .917 r
.36902 .53906 .37557 .545 .38629 .542 .37977 .53589 Mtetra
.688 .75 .899 r
.37977 .53589 .38629 .542 .39706 .5387 .3906 .53175 Mtetra
.667 .721 .889 r
.3906 .53175 .39706 .5387 .40791 .53451 .40145 .52823 Mtetra
.664 .741 .907 r
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.42327 .52137 .42968 .5277 .44063 .52428 .43425 .51792 Mtetra
.637 .733 .918 r
.43425 .51792 .44063 .52428 .45162 .52084 .44526 .51521 Mtetra
.026 .447 .872 r
.44526 .51521 .45162 .52084 .46265 .51762 .45615 .52008 Mtetra
.484 0 0 r
.45615 .52008 .46265 .51762 .47362 .5219 .46718 .52308 Mtetra
.018 0 0 r
.46718 .52308 .47362 .5219 .4847 .52488 .47836 .52213 Mtetra
.692 .883 .969 r
.47836 .52213 .4847 .52488 .49589 .52474 .48964 .51729 Mtetra
.752 .737 .839 r
.48964 .51729 .49589 .52474 .50717 .52123 .50097 .50991 Mtetra
.734 .661 .777 r
.50097 .50991 .50717 .52123 .5185 .51526 .51233 .50149 Mtetra
.717 .624 .753 r
.51233 .50149 .5185 .51526 .52986 .50801 .5237 .49311 Mtetra
.691 .601 .751 r
.5237 .49311 .52986 .50801 .54124 .50042 .53509 .48623 Mtetra
.643 .585 .774 r
.53509 .48623 .54124 .50042 .55264 .49311 .54653 .48264 Mtetra
.656 .645 .827 r
.54653 .48264 .55264 .49311 .56407 .48634 .55801 .47903 Mtetra
.664 .721 .892 r
.55801 .47903 .56407 .48634 .57556 .48208 .56955 .47541 Mtetra
.664 .741 .907 r
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69329 .44595 .68757 .43832 Mtetra
.664 .721 .892 r
.68757 .43832 .69329 .44595 .70551 .44541 .69965 .43452 Mtetra
.656 .645 .827 r
.69965 .43452 .70551 .44541 .71785 .44544 .71178 .43071 Mtetra
.579 .55 .786 r
.71178 .43071 .71785 .44544 .73028 .44576 .72417 .43024 Mtetra
.547 .524 .781 r
.72417 .43024 .73028 .44576 .74278 .44576 .73674 .4313 Mtetra
.542 .534 .796 r
.73674 .4313 .74278 .44576 .75527 .44446 .74941 .43243 Mtetra
.559 .58 .831 r
.74941 .43243 .75527 .44446 .76765 .44064 .76209 .43252 Mtetra
.621 .696 .898 r
.76209 .43252 .76765 .44064 .77981 .43337 .77466 .43001 Mtetra
.736 .9 .952 r
.77466 .43001 .77981 .43337 .79174 .42289 .78697 .4235 Mtetra
.771 .997 .827 r
.78697 .4235 .79174 .42289 .80355 .41104 .79897 .41293 Mtetra
.765 .982 .731 r
.79897 .41293 .80355 .41104 .81604 .40689 .8108 .40039 Mtetra
.687 .774 .917 r
.8108 .40039 .81604 .40689 .82862 .40295 .82335 .39565 Mtetra
.664 .741 .907 r
.82335 .39565 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.66 .739 .908 r
.86151 .38366 .86666 .39106 .87955 .3879 .87436 .37974 Mtetra
.641 .71 .897 r
.87436 .37974 .87955 .3879 .89239 .38381 .88734 .37647 Mtetra
.67 .747 .908 r
.88734 .37647 .89239 .38381 .90526 .3794 .90026 .37218 Mtetra
.674 .754 .91 r
.90026 .37218 .90526 .3794 .91819 .3751 .91323 .36774 Mtetra
.668 .748 .91 r
.91323 .36774 .91819 .3751 .93121 .37096 .92627 .36351 Mtetra
.658 .746 .915 r
.341 .53932 .34765 .54531 .35832 .54208 .35169 .53611 Mtetra
.653 .746 .918 r
.35169 .53611 .35832 .54208 .36902 .53906 .36242 .53302 Mtetra
.676 .75 .907 r
.36242 .53302 .36902 .53906 .37977 .53589 .37322 .52925 Mtetra
.679 .734 .891 r
.37322 .52925 .37977 .53589 .3906 .53175 .38407 .52533 Mtetra
.664 .737 .905 r
.38407 .52533 .3906 .53175 .40145 .52823 .39495 .5219 Mtetra
.664 .741 .907 r
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.40586 .51845 .41234 .52481 .42327 .52137 .41682 .51499 Mtetra
.656 .739 .911 r
.41682 .51499 .42327 .52137 .43425 .51792 .42782 .51175 Mtetra
.012 .418 .86 r
.42782 .51175 .43425 .51792 .44526 .51521 .43864 .51714 Mtetra
.487 0 0 r
.43864 .51714 .44526 .51521 .45615 .52008 .44962 .52047 Mtetra
.127 .676 .756 r
.44962 .52047 .45615 .52008 .46718 .52308 .46077 .51919 Mtetra
.734 .845 .932 r
.46077 .51919 .46718 .52308 .47836 .52213 .47205 .51347 Mtetra
.757 .712 .81 r
.47205 .51347 .47836 .52213 .48964 .51729 .4834 .50507 Mtetra
.738 .651 .763 r
.4834 .50507 .48964 .51729 .50097 .50991 .49477 .49582 Mtetra
.721 .623 .748 r
.49477 .49582 .50097 .50991 .51233 .50149 .50614 .48692 Mtetra
.644 .581 .769 r
.50614 .48692 .51233 .50149 .5237 .49311 .51752 .48319 Mtetra
.657 .656 .837 r
.51752 .48319 .5237 .49311 .53509 .48623 .52894 .47959 Mtetra
.664 .741 .907 r
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72417 .43024 .71835 .41977 Mtetra
.654 .654 .838 r
.71835 .41977 .72417 .43024 .73674 .4313 .73063 .41603 Mtetra
.534 .52 .787 r
.73063 .41603 .73674 .4313 .74941 .43243 .74332 .41757 Mtetra
.523 .52 .793 r
.74332 .41757 .74941 .43243 .76209 .43252 .75614 .41949 Mtetra
.536 .553 .82 r
.75614 .41949 .76209 .43252 .77466 .43001 .76899 .42056 Mtetra
.598 .654 .876 r
.76899 .42056 .77466 .43001 .78697 .4235 .78172 .4189 Mtetra
.732 .855 .939 r
.78172 .4189 .78697 .4235 .79897 .41293 .79415 .41267 Mtetra
.818 .996 .854 r
.79415 .41267 .79897 .41293 .8108 .40039 .8062 .40168 Mtetra
.816 .995 .759 r
.8062 .40168 .8108 .40039 .82335 .39565 .81805 .38853 Mtetra
.671 .751 .911 r
.81805 .38853 .82335 .39565 .83601 .39167 .83074 .38428 Mtetra
.664 .741 .907 r
.83074 .38428 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87436 .37974 .86919 .37213 Mtetra
.648 .731 .909 r
.86919 .37213 .87436 .37974 .88734 .37647 .88218 .36856 Mtetra
.653 .725 .902 r
.88218 .36856 .88734 .37647 .90026 .37218 .89522 .36484 Mtetra
.673 .751 .91 r
.89522 .36484 .90026 .37218 .91323 .36774 .90823 .36041 Mtetra
.669 .751 .912 r
.90823 .36041 .91323 .36774 .92627 .36351 .92132 .3561 Mtetra
.658 .75 .917 r
.33429 .53339 .341 .53932 .35169 .53611 .34501 .53013 Mtetra
.666 .751 .914 r
.34501 .53013 .35169 .53611 .36242 .53302 .35579 .52666 Mtetra
.689 .745 .894 r
.35579 .52666 .36242 .53302 .37322 .52925 .36664 .52243 Mtetra
.664 .726 .895 r
.36664 .52243 .37322 .52925 .38407 .52533 .37749 .51898 Mtetra
.664 .741 .907 r
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.38839 .51553 .39495 .5219 .40586 .51845 .39934 .51205 Mtetra
.39934 .51205 .40586 .51845 .41682 .51499 .41032 .50856 Mtetra
.125 .484 .9 r
.41032 .50856 .41682 .51499 .42782 .51175 .42111 .51306 Mtetra
.514 0 0 r
.42111 .51306 .42782 .51175 .43864 .51714 .432 .51717 Mtetra
.127 .676 .782 r
.432 .51717 .43864 .51714 .44962 .52047 .44312 .51622 Mtetra
.744 .832 .919 r
.44312 .51622 .44962 .52047 .46077 .51919 .4544 .51017 Mtetra
.763 .707 .799 r
.4544 .51017 .46077 .51919 .47205 .51347 .46577 .50109 Mtetra
.744 .652 .758 r
.46577 .50109 .47205 .51347 .4834 .50507 .47716 .49118 Mtetra
.704 .618 .758 r
.47716 .49118 .4834 .50507 .49477 .49582 .48852 .48375 Mtetra
.65 .616 .802 r
.48852 .48375 .49477 .49582 .50614 .48692 .49988 .48014 Mtetra
.664 .737 .904 r
.49988 .48014 .50614 .48692 .51752 .48319 .51128 .47652 Mtetra
.664 .741 .907 r
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73063 .41603 .725 .40869 Mtetra
.664 .737 .904 r
.725 .40869 .73063 .41603 .74332 .41757 .73736 .40477 Mtetra
.561 .571 .82 r
.73736 .40477 .74332 .41757 .75614 .41949 .75005 .40477 Mtetra
.506 .513 .798 r
.75005 .40477 .75614 .41949 .76899 .42056 .76301 .4073 Mtetra
.518 .541 .819 r
.76301 .4073 .76899 .42056 .78172 .4189 .77602 .40902 Mtetra
.589 .642 .871 r
.77602 .40902 .78172 .4189 .79415 .41267 .78888 .40763 Mtetra
.743 .844 .927 r
.78888 .40763 .79415 .41267 .8062 .40168 .80136 .401 Mtetra
.85 .99 .849 r
.80136 .401 .8062 .40168 .81805 .38853 .81342 .38912 Mtetra
.817 .999 .799 r
.81342 .38912 .81805 .38853 .83074 .38428 .82542 .37682 Mtetra
.664 .741 .907 r
.82542 .37682 .83074 .38428 .8435 .38025 .83822 .37276 Mtetra
.83822 .37276 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88218 .36856 .87697 .36046 Mtetra
.639 .715 .902 r
.87697 .36046 .88218 .36856 .89522 .36484 .8901 .35716 Mtetra
.662 .738 .906 r
.8901 .35716 .89522 .36484 .90823 .36041 .9032 .35306 Mtetra
.668 .752 .913 r
.9032 .35306 .90823 .36041 .92132 .3561 .91633 .34874 Mtetra
.665 .754 .917 r
.32753 .5275 .33429 .53339 .34501 .53013 .33829 .52403 Mtetra
.691 .754 .9 r
.33829 .52403 .34501 .53013 .35579 .52666 .34913 .51976 Mtetra
.671 .726 .891 r
.34913 .51976 .35579 .52666 .36664 .52243 .35998 .51606 Mtetra
.664 .741 .907 r
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.37086 .51259 .37749 .51898 .38839 .51553 .38179 .5091 Mtetra
.38179 .5091 .38839 .51553 .39934 .51205 .39276 .5056 Mtetra
.341 .609 .948 r
.39276 .5056 .39934 .51205 .41032 .50856 .40357 .50781 Mtetra
.505 0 0 r
.40357 .50781 .41032 .50856 .42111 .51306 .41436 .51304 Mtetra
.022 0 0 r
.41436 .51304 .42111 .51306 .432 .51717 .4254 .51321 Mtetra
.734 .842 .931 r
.4254 .51321 .432 .51717 .44312 .51622 .43668 .50748 Mtetra
.77 .714 .8 r
.43668 .50748 .44312 .51622 .4544 .51017 .44806 .49807 Mtetra
.753 .659 .757 r
.44806 .49807 .4544 .51017 .46577 .50109 .45948 .48761 Mtetra
.699 .62 .765 r
.45948 .48761 .46577 .50109 .47716 .49118 .47084 .4807 Mtetra
.655 .645 .828 r
.47084 .4807 .47716 .49118 .48852 .48375 .48218 .47708 Mtetra
.664 .741 .907 r
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .75005 .40477 .74418 .39351 Mtetra
.571 .604 .847 r
.74418 .39351 .75005 .40477 .76301 .4073 .75693 .39291 Mtetra
.488 .508 .805 r
.75693 .39291 .76301 .4073 .77602 .40902 .77005 .39597 Mtetra
.507 .54 .825 r
.77005 .39597 .77602 .40902 .78888 .40763 .78319 .39797 Mtetra
.598 .654 .876 r
.78319 .39797 .78888 .40763 .80136 .401 .79612 .3962 Mtetra
.775 .863 .915 r
.79612 .3962 .80136 .401 .81342 .38912 .80859 .38834 Mtetra
.876 .985 .829 r
.80859 .38834 .81342 .38912 .82542 .37682 .82061 .37523 Mtetra
.814 .977 .895 r
.82061 .37523 .82542 .37682 .83822 .37276 .8329 .36521 Mtetra
.664 .741 .907 r
.8329 .36521 .83822 .37276 .85108 .36868 .8458 .3611 Mtetra
.8458 .3611 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.656 .738 .91 r
.87177 .35281 .87697 .36046 .8901 .35716 .88488 .3489 Mtetra
.639 .713 .901 r
.88488 .3489 .8901 .35716 .9032 .35306 .89811 .34558 Mtetra
.662 .747 .913 r
.89811 .34558 .9032 .35306 .91633 .34874 .91131 .34142 Mtetra
.678 .756 .91 r
.32071 .52155 .32753 .5275 .33829 .52403 .33152 .51768 Mtetra
.698 .749 .891 r
.33152 .51768 .33829 .52403 .34913 .51976 .3424 .51312 Mtetra
.664 .733 .901 r
.3424 .51312 .34913 .51976 .35998 .51606 .35327 .50964 Mtetra
.664 .741 .907 r
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.36418 .50614 .37086 .51259 .38179 .5091 .37513 .50263 Mtetra
.566 .71 .939 r
.37513 .50263 .38179 .5091 .39276 .5056 .38603 .50147 Mtetra
0 .212 .624 r
.38603 .50147 .39276 .5056 .40357 .50781 .39671 .5078 Mtetra
.262 0 0 r
.39671 .5078 .40357 .50781 .41436 .51304 .40764 .50987 Mtetra
.684 .865 .968 r
.40764 .50987 .41436 .51304 .4254 .51321 .41887 .50533 Mtetra
.776 .733 .812 r
.41887 .50533 .4254 .51321 .43668 .50748 .43027 .49603 Mtetra
.763 .671 .76 r
.43027 .49603 .43668 .50748 .44806 .49807 .44172 .48511 Mtetra
.71 .632 .768 r
.44172 .48511 .44806 .49807 .45948 .48761 .45309 .47764 Mtetra
.657 .656 .838 r
.45309 .47764 .45948 .48761 .47084 .4807 .46442 .47401 Mtetra
.664 .741 .907 r
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75693 .39291 .75109 .38211 Mtetra
.552 .605 .86 r
.75109 .38211 .75693 .39291 .77005 .39597 .76398 .38203 Mtetra
.47 .506 .813 r
.76398 .38203 .77005 .39597 .78319 .39797 .77725 .38551 Mtetra
.505 .55 .836 r
.77725 .38551 .78319 .39797 .79612 .3962 .7905 .38734 Mtetra
.633 .692 .887 r
.7905 .38734 .79612 .3962 .80859 .38834 .80343 .38429 Mtetra
.824 .898 .893 r
.80343 .38429 .80859 .38834 .82061 .37523 .81581 .37439 Mtetra
.896 .979 .808 r
.81581 .37439 .82061 .37523 .8329 .36521 .82777 .36006 Mtetra
.738 .848 .931 r
.82777 .36006 .8329 .36521 .8458 .3611 .84048 .35345 Mtetra
.664 .741 .907 r
.84048 .35345 .8458 .3611 .85876 .35696 .85348 .34928 Mtetra
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88488 .3489 .87965 .34089 Mtetra
.629 .718 .911 r
.87965 .34089 .88488 .3489 .89811 .34558 .89296 .33781 Mtetra
.651 .736 .911 r
.89296 .33781 .89811 .34558 .91131 .34142 .90625 .33401 Mtetra
.696 .754 .897 r
.31385 .51538 .32071 .52155 .33152 .51768 .32472 .5109 Mtetra
.686 .735 .888 r
.32472 .5109 .33152 .51768 .3424 .51312 .33562 .50668 Mtetra
.664 .741 .907 r
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.34651 .50317 .35327 .50964 .36418 .50614 .35745 .49965 Mtetra
.35745 .49965 .36418 .50614 .37513 .50263 .36843 .49611 Mtetra
.052 .44 .875 r
.36843 .49611 .37513 .50263 .38603 .50147 .37908 .50111 Mtetra
.469 0 0 r
.37908 .50111 .38603 .50147 .39671 .5078 .38986 .50558 Mtetra
.505 .849 .995 r
.38986 .50558 .39671 .5078 .40764 .50987 .40098 .50329 Mtetra
.776 .764 .841 r
.40098 .50329 .40764 .50987 .41887 .50533 .41237 .49485 Mtetra
.774 .688 .768 r
.41237 .49485 .41887 .50533 .43027 .49603 .42386 .48367 Mtetra
.735 .65 .764 r
.42386 .48367 .43027 .49603 .44172 .48511 .43528 .47457 Mtetra
.655 .645 .829 r
.43528 .47457 .44172 .48511 .45309 .47764 .44659 .47092 Mtetra
.664 .741 .907 r
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76398 .38203 .75808 .37056 Mtetra
.503 .568 .854 r
.75808 .37056 .76398 .38203 .77725 .38551 .77121 .3721 Mtetra
.456 .507 .823 r
.77121 .3721 .77725 .38551 .7905 .38734 .78462 .3758 Mtetra
.524 .579 .853 r
.78462 .3758 .7905 .38734 .80343 .38429 .79791 .3767 Mtetra
.7 .756 .896 r
.79791 .3767 .80343 .38429 .81581 .37439 .81074 .37126 Mtetra
.874 .929 .856 r
.81074 .37126 .81581 .37439 .82777 .36006 .82296 .35879 Mtetra
.877 .98 .837 r
.82296 .35879 .82777 .36006 .84048 .35345 .83511 .34574 Mtetra
.664 .741 .907 r
.83511 .34574 .84048 .35345 .85348 .34928 .84815 .34154 Mtetra
.84815 .34154 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.641 .731 .914 r
.87441 .33308 .87965 .34089 .89296 .33781 .88772 .32958 Mtetra
.633 .716 .907 r
.88772 .32958 .89296 .33781 .90625 .33401 .90112 .32635 Mtetra
.71 .747 .881 r
.30697 .5088 .31385 .51538 .32472 .5109 .3179 .50371 Mtetra
.663 .719 .89 r
.3179 .50371 .32472 .5109 .33562 .50668 .32878 .50019 Mtetra
.664 .741 .907 r
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.3397 .49665 .34651 .50317 .35745 .49965 .35066 .4931 Mtetra
.502 .686 .949 r
.35066 .4931 .35745 .49965 .36843 .49611 .3615 .49303 Mtetra
.475 0 0 r
.3615 .49303 .36843 .49611 .37908 .50111 .3721 .4996 Mtetra
.035 .592 .814 r
.3721 .4996 .37908 .50111 .38986 .50558 .38305 .50061 Mtetra
.749 .809 .9 r
.38305 .50061 .38986 .50558 .40098 .50329 .39437 .49419 Mtetra
.784 .712 .784 r
.39437 .49419 .40098 .50329 .41237 .49485 .40588 .48328 Mtetra
.77 .673 .756 r
.40588 .48328 .41237 .49485 .42386 .48367 .41741 .47162 Mtetra
.652 .62 .804 r
.41741 .47162 .42386 .48367 .43528 .47457 .4287 .46783 Mtetra
.664 .741 .907 r
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.66 .739 .909 r
.75242 .363 .75808 .37056 .77121 .3721 .76517 .35901 Mtetra
.436 .502 .829 r
.76517 .35901 .77121 .3721 .78462 .3758 .77862 .36313 Mtetra
.455 .521 .837 r
.77862 .36313 .78462 .3758 .79791 .3767 .79214 .36651 Mtetra
.579 .639 .874 r
.79214 .36651 .79791 .3767 .81074 .37126 .80537 .36527 Mtetra
.79 .833 .885 r
.80537 .36527 .81074 .37126 .82296 .35879 .81798 .35633 Mtetra
.907 .942 .818 r
.81798 .35633 .82296 .35879 .83511 .34574 .83005 .3416 Mtetra
.77 .897 .932 r
.83005 .3416 .83511 .34574 .84815 .34154 .84278 .33374 Mtetra
.664 .741 .907 r
.84278 .33374 .84815 .34154 .86125 .33732 .85593 .32948 Mtetra
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88772 .32958 .88239 .32091 Mtetra
.615 .697 .903 r
.88239 .32091 .88772 .32958 .90112 .32635 .89591 .31826 Mtetra
.692 .73 .88 r
.30006 .50172 .30697 .5088 .3179 .50371 .31098 .4972 Mtetra
.664 .741 .907 r
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.32189 .49365 .32878 .50019 .3397 .49665 .33283 .49009 Mtetra
.33283 .49009 .3397 .49665 .35066 .4931 .34383 .48651 Mtetra
.045 .437 .872 r
.34383 .48651 .35066 .4931 .3615 .49303 .35442 .49149 Mtetra
.418 0 0 r
.35442 .49149 .3615 .49303 .3721 .4996 .36514 .49619 Mtetra
.598 .839 .99 r
.36514 .49619 .3721 .4996 .38305 .50061 .37629 .49329 Mtetra
.785 .748 .819 r
.37629 .49329 .38305 .50061 .39437 .49419 .38777 .48375 Mtetra
.783 .692 .763 r
.38777 .48375 .39437 .49419 .40588 .48328 .39935 .47171 Mtetra
.712 .653 .789 r
.39935 .47171 .40588 .48328 .41741 .47162 .41075 .46473 Mtetra
.664 .737 .904 r
.41075 .46473 .41741 .47162 .4287 .46783 .42207 .46104 Mtetra
.664 .741 .907 r
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76517 .35901 .7595 .35121 Mtetra
.543 .684 .93 r
.7595 .35121 .76517 .35901 .77862 .36313 .7726 .35045 Mtetra
.416 .499 .837 r
.7726 .35045 .77862 .36313 .79214 .36651 .78622 .35492 Mtetra
.488 .562 .857 r
.78622 .35492 .79214 .36651 .80537 .36527 .79975 .35683 Mtetra
.682 .731 .887 r
.79975 .35683 .80537 .36527 .81798 .35633 .81277 .35189 Mtetra
.871 .891 .846 r
.81277 .35189 .81798 .35633 .83005 .3416 .82509 .33904 Mtetra
.884 .95 .846 r
.82509 .33904 .83005 .3416 .84278 .33374 .83737 .32586 Mtetra
.664 .741 .907 r
.83737 .32586 .84278 .33374 .85593 .32948 .85055 .32157 Mtetra
.85055 .32157 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.632 .727 .916 r
.8771 .31293 .88239 .32091 .89591 .31826 .89059 .30961 Mtetra
.663 .712 .885 r
.29313 .4942 .30006 .50172 .31098 .4972 .30401 .49064 Mtetra
.664 .741 .907 r
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.31494 .48706 .32189 .49365 .33283 .49009 .32592 .48347 Mtetra
.587 .718 .934 r
.32592 .48347 .33283 .49009 .34383 .48651 .33683 .48178 Mtetra
.408 0 0 r
.33683 .48178 .34383 .48651 .35442 .49149 .34732 .489 Mtetra
.026 .566 .846 r
.34732 .489 .35442 .49149 .36514 .49619 .3582 .49084 Mtetra
.746 .798 .894 r
.3582 .49084 .36514 .49619 .37629 .49329 .36955 .48444 Mtetra
.793 .719 .783 r
.36955 .48444 .37629 .49329 .38777 .48375 .38115 .47294 Mtetra
.773 .685 .766 r
.38115 .47294 .38777 .48375 .39935 .47171 .39273 .46161 Mtetra
.656 .657 .839 r
.39273 .46161 .39935 .47171 .41075 .46473 .40403 .45791 Mtetra
.664 .741 .907 r
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .4123 Mtetra
.54345 .4123 .54978 .41947 .56169 .41559 .55539 .40839 Mtetra
.55539 .40839 .56169 .41559 .57366 .4117 .56739 .40447 Mtetra
.56739 .40447 .57366 .4117 .58567 .40779 .57944 .40053 Mtetra
.57944 .40053 .58567 .40779 .59774 .40386 .59154 .39657 Mtetra
.59154 .39657 .59774 .40386 .60985 .39992 .60369 .39259 Mtetra
.60369 .39259 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .7726 .35045 .76666 .33927 Mtetra
.416 .53 .865 r
.76666 .33927 .7726 .35045 .78622 .35492 .78023 .34294 Mtetra
.423 .519 .851 r
.78023 .34294 .78622 .35492 .79975 .35683 .79395 .3468 Mtetra
.58 .647 .881 r
.79395 .3468 .79975 .35683 .81277 .35189 .80732 .34541 Mtetra
.805 .826 .867 r
.80732 .34541 .81277 .35189 .82509 .33904 .81998 .33547 Mtetra
.911 .913 .808 r
.81998 .33547 .82509 .33904 .83737 .32586 .8321 .31992 Mtetra
.724 .826 .928 r
.8321 .31992 .83737 .32586 .85055 .32157 .84514 .3136 Mtetra
.664 .741 .907 r
.84514 .3136 .85055 .32157 .8638 .31726 .85843 .30925 Mtetra
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89059 .30961 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.30794 .48042 .31494 .48706 .32592 .48347 .31895 .4768 Mtetra
.325 .604 .948 r
.31895 .4768 .32592 .48347 .33683 .48178 .32965 .47901 Mtetra
.473 0 0 r
.32965 .47901 .33683 .48178 .34732 .489 .34021 .4852 Mtetra
.489 .789 .998 r
.34021 .4852 .34732 .489 .3582 .49084 .35128 .48395 Mtetra
.783 .759 .832 r
.35128 .48395 .3582 .49084 .36955 .48444 .3628 .47486 Mtetra
.796 .708 .769 r
.3628 .47486 .36955 .48444 .38115 .47294 .37448 .46236 Mtetra
.728 .675 .798 r
.37448 .46236 .38115 .47294 .39273 .46161 .38594 .45477 Mtetra
.664 .741 .907 r
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .4129 Mtetra
.51326 .4129 .51971 .42007 .53155 .41619 .52513 .409 Mtetra
.52513 .409 .53155 .41619 .54345 .4123 .53706 .40507 Mtetra
.53706 .40507 .54345 .4123 .55539 .40839 .54904 .40113 Mtetra
.54904 .40113 .55539 .40839 .56739 .40447 .56107 .39718 Mtetra
.56107 .39718 .56739 .40447 .57944 .40053 .57315 .3932 Mtetra
.57315 .3932 .57944 .40053 .59154 .39657 .58529 .38921 Mtetra
.58529 .38921 .59154 .39657 .60369 .39259 .59748 .3852 Mtetra
.59748 .3852 .60369 .39259 .6159 .3886 .60972 .38118 Mtetra
.60972 .38118 .6159 .3886 .62816 .38459 .62202 .37713 Mtetra
.62202 .37713 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.517 .675 .936 r
.76095 .33145 .76666 .33927 .78023 .34294 .77424 .33118 Mtetra
.38 .499 .854 r
.77424 .33118 .78023 .34294 .79395 .3468 .78805 .33601 Mtetra
.495 .586 .876 r
.78805 .33601 .79395 .3468 .80732 .34541 .80169 .33733 Mtetra
.727 .762 .88 r
.80169 .33733 .80732 .34541 .81998 .33547 .81469 .33055 Mtetra
.888 .879 .819 r
.81469 .33055 .81998 .33547 .8321 .31992 .82699 .316 Mtetra
.831 .917 .894 r
.82699 .316 .8321 .31992 .84514 .3136 .83968 .30556 Mtetra
.664 .741 .907 r
.83968 .30556 .84514 .3136 .85843 .30925 .85301 .30117 Mtetra
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.28991 .47736 .29699 .48402 .30794 .48042 .30089 .47373 Mtetra
.30089 .47373 .30794 .48042 .31895 .4768 .31192 .47008 Mtetra
0 .382 .836 r
.31192 .47008 .31895 .4768 .32965 .47901 .32243 .47568 Mtetra
0 .329 .685 r
.32243 .47568 .32965 .47901 .34021 .4852 .33311 .48016 Mtetra
.674 .8 .942 r
.33311 .48016 .34021 .4852 .35128 .48395 .34436 .47608 Mtetra
.797 .74 .8 r
.34436 .47608 .35128 .48395 .3628 .47486 .35601 .46513 Mtetra
.797 .707 .765 r
.35601 .46513 .3628 .47486 .37448 .46236 .36774 .45229 Mtetra
.672 .666 .835 r
.36774 .45229 .37448 .46236 .38594 .45477 .37909 .44788 Mtetra
.664 .741 .907 r
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.48309 .4135 .48966 .42066 .50144 .41679 .4949 .4096 Mtetra
.4949 .4096 .50144 .41679 .51326 .4129 .50676 .40568 Mtetra
.50676 .40568 .51326 .4129 .52513 .409 .51866 .40174 Mtetra
.51866 .40174 .52513 .409 .53706 .40507 .53062 .39779 Mtetra
.53062 .39779 .53706 .40507 .54904 .40113 .54264 .39382 Mtetra
.54264 .39382 .54904 .40113 .56107 .39718 .5547 .38983 Mtetra
.5547 .38983 .56107 .39718 .57315 .3932 .56682 .38582 Mtetra
.56682 .38582 .57315 .3932 .58529 .38921 .57899 .3818 Mtetra
.57899 .3818 .58529 .38921 .59748 .3852 .59122 .37776 Mtetra
.59122 .37776 .59748 .3852 .60972 .38118 .6035 .3737 Mtetra
.6035 .3737 .60972 .38118 .62202 .37713 .61583 .36962 Mtetra
.61583 .36962 .62202 .37713 .63437 .37307 .62822 .36553 Mtetra
.62822 .36553 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.643 .732 .914 r
.75519 .32356 .76095 .33145 .77424 .33118 .76825 .31994 Mtetra
.353 .496 .862 r
.76825 .31994 .77424 .33118 .78805 .33601 .7821 .32504 Mtetra
.426 .546 .874 r
.7821 .32504 .78805 .33601 .80169 .33733 .79592 .32823 Mtetra
.65 .707 .889 r
.79592 .32823 .80169 .33733 .81469 .33055 .80923 .32431 Mtetra
.853 .844 .834 r
.80923 .32431 .81469 .33055 .82699 .316 .82176 .31147 Mtetra
.886 .895 .831 r
.82176 .31147 .82699 .316 .83968 .30556 .83417 .29745 Mtetra
.664 .741 .907 r
.83417 .29745 .83968 .30556 .85301 .30117 .84754 .29303 Mtetra
.84754 .29303 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.28278 .47064 .28991 .47736 .30089 .47373 .29379 .46698 Mtetra
.638 .734 .918 r
.29379 .46698 .30089 .47373 .31192 .47008 .3048 .46404 Mtetra
0 .177 .649 r
.3048 .46404 .31192 .47008 .32243 .47568 .31519 .47155 Mtetra
.085 .561 .903 r
.31519 .47155 .32243 .47568 .33311 .48016 .326 .47414 Mtetra
.74 .78 .885 r
.326 .47414 .33311 .48016 .34436 .47608 .33741 .46776 Mtetra
.804 .732 .785 r
.33741 .46776 .34436 .47608 .35601 .46513 .34916 .45562 Mtetra
.781 .709 .784 r
.34916 .45562 .35601 .46513 .36774 .45229 .36084 .4447 Mtetra
.663 .722 .892 r
.36084 .4447 .36774 .45229 .37909 .44788 .37218 .44094 Mtetra
.664 .741 .907 r
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.46468 .4102 .47134 .41739 .48309 .4135 .47647 .40628 Mtetra
.47647 .40628 .48309 .4135 .4949 .4096 .48831 .40235 Mtetra
.48831 .40235 .4949 .4096 .50676 .40568 .5002 .3984 Mtetra
.5002 .3984 .50676 .40568 .51866 .40174 .51214 .39443 Mtetra
.51214 .39443 .51866 .40174 .53062 .39779 .52414 .39044 Mtetra
.52414 .39044 .53062 .39779 .54264 .39382 .53618 .38644 Mtetra
.53618 .38644 .54264 .39382 .5547 .38983 .54828 .38242 Mtetra
.54828 .38242 .5547 .38983 .56682 .38582 .56044 .37838 Mtetra
.56044 .37838 .56682 .38582 .57899 .3818 .57264 .37432 Mtetra
.57264 .37432 .57899 .3818 .59122 .37776 .5849 .37025 Mtetra
.5849 .37025 .59122 .37776 .6035 .3737 .59722 .36616 Mtetra
.59722 .36616 .6035 .3737 .61583 .36962 .60959 .36205 Mtetra
.60959 .36205 .61583 .36962 .62822 .36553 .62201 .35792 Mtetra
.62201 .35792 .62822 .36553 .64066 .36141 .63449 .35377 Mtetra
.63449 .35377 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .76825 .31994 .76243 .31126 Mtetra
.374 .576 .918 r
.76243 .31126 .76825 .31994 .7821 .32504 .77614 .31431 Mtetra
.371 .52 .876 r
.77614 .31431 .7821 .32504 .79592 .32823 .79008 .31864 Mtetra
.58 .664 .895 r
.79008 .31864 .79592 .32823 .80923 .32431 .80363 .31703 Mtetra
.814 .812 .848 r
.80363 .31703 .80923 .32431 .82176 .31147 .81641 .30611 Mtetra
.901 .869 .798 r
.81641 .30611 .82176 .31147 .83417 .29745 .82869 .29003 Mtetra
.687 .772 .916 r
.82869 .29003 .83417 .29745 .84754 .29303 .84203 .28481 Mtetra
.664 .741 .907 r
.84203 .28481 .84754 .29303 .86098 .28858 .85551 .28033 Mtetra
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.27559 .46388 .28278 .47064 .29379 .46698 .28663 .46019 Mtetra
.535 .7 .945 r
.28663 .46019 .29379 .46698 .3048 .46404 .29751 .45943 Mtetra
.438 0 0 r
.29751 .45943 .3048 .46404 .31519 .47155 .30793 .46664 Mtetra
.349 .688 .981 r
.30793 .46664 .31519 .47155 .326 .47414 .31887 .46745 Mtetra
.769 .766 .85 r
.31887 .46745 .326 .47414 .33741 .46776 .33042 .45934 Mtetra
.81 .732 .778 r
.33042 .45934 .33741 .46776 .34916 .45562 .34225 .44651 Mtetra
.758 .712 .809 r
.34225 .44651 .34916 .45562 .36084 .4447 .35385 .43773 Mtetra
.664 .741 .907 r
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.45797 .40295 .46468 .4102 .47647 .40628 .46979 .39901 Mtetra
.46979 .39901 .47647 .40628 .48831 .40235 .48166 .39504 Mtetra
.48166 .39504 .48831 .40235 .5002 .3984 .49359 .39106 Mtetra
.49359 .39106 .5002 .3984 .51214 .39443 .50556 .38706 Mtetra
.50556 .38706 .51214 .39443 .52414 .39044 .51759 .38304 Mtetra
.655 .738 .911 r
.51759 .38304 .52414 .39044 .53618 .38644 .52968 .37929 Mtetra
.657 .747 .916 r
.52968 .37929 .53618 .38644 .54828 .38242 .54181 .37544 Mtetra
.664 .755 .918 r
.54181 .37544 .54828 .38242 .56044 .37838 .554 .37137 Mtetra
.671 .758 .916 r
.554 .37137 .56044 .37838 .57264 .37432 .56625 .36707 Mtetra
.673 .752 .91 r
.56625 .36707 .57264 .37432 .5849 .37025 .57854 .36268 Mtetra
.664 .741 .907 r
.57854 .36268 .5849 .37025 .59722 .36616 .59089 .35856 Mtetra
.59089 .35856 .59722 .36616 .60959 .36205 .6033 .35441 Mtetra
.6033 .35441 .60959 .36205 .62201 .35792 .61576 .35025 Mtetra
.61576 .35025 .62201 .35792 .63449 .35377 .62828 .34607 Mtetra
.62828 .34607 .63449 .35377 .64703 .34961 .64085 .34187 Mtetra
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.467 .648 .937 r
.75661 .3032 .76243 .31126 .77614 .31431 .77017 .30397 Mtetra
.328 .506 .88 r
.77017 .30397 .77614 .31431 .79008 .31864 .78419 .30895 Mtetra
.519 .632 .902 r
.78419 .30895 .79008 .31864 .80363 .31703 .79793 .30906 Mtetra
.776 .786 .861 r
.79793 .30906 .80363 .31703 .81641 .30611 .81093 .29992 Mtetra
.889 .849 .798 r
.81093 .29992 .81641 .30611 .82869 .29003 .8233 .28408 Mtetra
.754 .843 .919 r
.8233 .28408 .82869 .29003 .84203 .28481 .83647 .27652 Mtetra
.664 .741 .907 r
.83647 .27652 .84203 .28481 .85551 .28033 .85 .272 Mtetra
.85 .272 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.26834 .45706 .27559 .46388 .28663 .46019 .27941 .45334 Mtetra
.422 .652 .954 r
.27941 .45334 .28663 .46019 .29751 .45943 .29019 .45428 Mtetra
0 .195 .632 r
.29019 .45428 .29751 .45943 .30793 .46664 .30065 .46103 Mtetra
.496 .729 .976 r
.30065 .46103 .30793 .46664 .31887 .46745 .31171 .46041 Mtetra
.784 .759 .831 r
.31171 .46041 .31887 .46745 .33042 .45934 .32336 .45109 Mtetra
.815 .737 .777 r
.32336 .45109 .33042 .45934 .34225 .44651 .33526 .43789 Mtetra
.737 .718 .834 r
.33526 .43789 .34225 .44651 .35385 .43773 .34681 .43071 Mtetra
.664 .741 .907 r
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.43941 .39961 .4462 .40689 .45797 .40295 .45121 .39565 Mtetra
.45121 .39565 .45797 .40295 .46979 .39901 .46306 .39167 Mtetra
.46306 .39167 .46979 .39901 .48166 .39504 .47497 .38767 Mtetra
.47497 .38767 .48166 .39504 .49359 .39106 .48693 .38366 Mtetra
.48693 .38366 .49359 .39106 .50556 .38706 .49894 .37962 Mtetra
.648 .736 .913 r
.49894 .37962 .50556 .38706 .51759 .38304 .511 .37606 Mtetra
.65 .751 .923 r
.511 .37606 .51759 .38304 .52968 .37929 .52311 .37241 Mtetra
.657 .757 .924 r
.52311 .37241 .52968 .37929 .54181 .37544 .53529 .36852 Mtetra
.664 .759 .921 r
.53529 .36852 .54181 .37544 .554 .37137 .54752 .36441 Mtetra
.67 .761 .918 r
.54752 .36441 .554 .37137 .56625 .36707 .5598 .36009 Mtetra
.677 .763 .916 r
.5598 .36009 .56625 .36707 .57854 .36268 .57213 .35554 Mtetra
.679 .76 .912 r
.57213 .35554 .57854 .36268 .59089 .35856 .58451 .35089 Mtetra
.664 .741 .907 r
.58451 .35089 .59089 .35856 .6033 .35441 .59695 .34671 Mtetra
.59695 .34671 .6033 .35441 .61576 .35025 .60945 .34251 Mtetra
.60945 .34251 .61576 .35025 .62828 .34607 .62201 .3383 Mtetra
.62201 .3383 .62828 .34607 .64085 .34187 .63462 .33406 Mtetra
.63462 .33406 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.541 .686 .933 r
.75074 .29507 .75661 .3032 .77017 .30397 .76421 .29412 Mtetra
.293 .499 .886 r
.76421 .29412 .77017 .30397 .78419 .30895 .77828 .29941 Mtetra
.468 .611 .909 r
.77828 .29941 .78419 .30895 .79793 .30906 .79215 .30071 Mtetra
.744 .768 .873 r
.79215 .30071 .79793 .30906 .81093 .29992 .80533 .29298 Mtetra
.877 .832 .799 r
.80533 .29298 .81093 .29992 .8233 .28408 .81782 .27757 Mtetra
.793 .836 .885 r
.81782 .27757 .8233 .28408 .83647 .27652 .83087 .26816 Mtetra
.664 .741 .907 r
.83087 .26816 .83647 .27652 .85 .272 .84444 .26361 Mtetra
.84444 .26361 .85 .272 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.26104 .45018 .26834 .45706 .27941 .45334 .27214 .44644 Mtetra
.325 .604 .948 r
.27214 .44644 .27941 .45334 .29019 .45428 .28285 .44854 Mtetra
0 .266 .717 r
.28285 .44854 .29019 .45428 .30065 .46103 .29334 .45486 Mtetra
.567 .737 .956 r
.29334 .45486 .30065 .46103 .31171 .46041 .30449 .45323 Mtetra
.793 .758 .821 r
.30449 .45323 .31171 .46041 .32336 .45109 .31623 .44316 Mtetra
.821 .744 .779 r
.31623 .44316 .32336 .45109 .33526 .43789 .32819 .42975 Mtetra
.72 .726 .856 r
.32819 .42975 .33526 .43789 .34681 .43071 .33971 .42363 Mtetra
.664 .741 .907 r
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.43256 .39228 .43941 .39961 .45121 .39565 .44439 .38829 Mtetra
.44439 .38829 .45121 .39565 .46306 .39167 .45628 .38428 Mtetra
.45628 .38428 .46306 .39167 .47497 .38767 .46822 .38025 Mtetra
.46822 .38025 .47497 .38767 .48693 .38366 .48021 .3762 Mtetra
.655 .738 .911 r
.48021 .3762 .48693 .38366 .49894 .37962 .49225 .37242 Mtetra
.643 .742 .921 r
.49225 .37242 .49894 .37962 .511 .37606 .50434 .36895 Mtetra
.65 .749 .921 r
.50434 .36895 .511 .37606 .52311 .37241 .5165 .36525 Mtetra
.657 .75 .919 r
.5165 .36525 .52311 .37241 .53529 .36852 .52871 .36133 Mtetra
.664 .753 .916 r
.52871 .36133 .53529 .36852 .54752 .36441 .54097 .35719 Mtetra
.67 .755 .914 r
.54097 .35719 .54752 .36441 .5598 .36009 .55329 .35284 Mtetra
.676 .757 .911 r
.55329 .35284 .5598 .36009 .57213 .35554 .56566 .34826 Mtetra
.683 .759 .909 r
.56566 .34826 .57213 .35554 .58451 .35089 .57808 .34345 Mtetra
.673 .752 .91 r
.57808 .34345 .58451 .35089 .59695 .34671 .59056 .33895 Mtetra
.664 .741 .907 r
.59056 .33895 .59695 .34671 .60945 .34251 .60309 .33472 Mtetra
.60309 .33472 .60945 .34251 .62201 .3383 .61569 .33046 Mtetra
.61569 .33046 .62201 .3383 .63462 .33406 .62834 .32619 Mtetra
.62834 .32619 .63462 .33406 .64729 .32981 .64105 .3219 Mtetra
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.585 .707 .927 r
.74482 .28687 .75074 .29507 .76421 .29412 .75824 .28476 Mtetra
.263 .496 .892 r
.75824 .28476 .76421 .29412 .77828 .29941 .77235 .29019 Mtetra
.429 .599 .916 r
.77235 .29019 .77828 .29941 .79215 .30071 .78632 .2922 Mtetra
.721 .759 .882 r
.78632 .2922 .79215 .30071 .80533 .29298 .79963 .28545 Mtetra
.866 .818 .8 r
.79963 .28545 .80533 .29298 .81782 .27757 .81222 .27041 Mtetra
.811 .823 .859 r
.81222 .27041 .81782 .27757 .83087 .26816 .82521 .25973 Mtetra
.664 .741 .907 r
.82521 .25973 .83087 .26816 .84444 .26361 .83883 .25514 Mtetra
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.25368 .44326 .26104 .45018 .27214 .44644 .26481 .43948 Mtetra
.27 .575 .94 r
.26481 .43948 .27214 .44644 .28285 .44854 .27548 .44215 Mtetra
0 .315 .774 r
.27548 .44215 .28285 .44854 .29334 .45486 .286 .44822 Mtetra
.596 .734 .94 r
.286 .44822 .29334 .45486 .30449 .45323 .29721 .44608 Mtetra
.798 .76 .818 r
.29721 .44608 .30449 .45323 .31623 .44316 .30902 .43562 Mtetra
.826 .753 .783 r
.30902 .43562 .31623 .44316 .32819 .42975 .32103 .42211 Mtetra
.711 .738 .872 r
.32103 .42211 .32819 .42975 .33971 .42363 .33255 .41649 Mtetra
.664 .741 .907 r
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.42565 .3849 .43256 .39228 .44439 .38829 .43752 .38087 Mtetra
.43752 .38087 .44439 .38829 .45628 .38428 .44944 .37682 Mtetra
.44944 .37682 .45628 .38428 .46822 .38025 .46141 .37276 Mtetra
.46141 .37276 .46822 .38025 .48021 .3762 .47344 .36868 Mtetra
.648 .736 .913 r
.47344 .36868 .48021 .3762 .49225 .37242 .48551 .36507 Mtetra
.644 .74 .919 r
.48551 .36507 .49225 .37242 .50434 .36895 .49764 .36156 Mtetra
.651 .742 .917 r
.49764 .36156 .50434 .36895 .5165 .36525 .50983 .35783 Mtetra
.658 .745 .914 r
.50983 .35783 .5165 .36525 .52871 .36133 .52207 .35387 Mtetra
.664 .747 .912 r
.52207 .35387 .52871 .36133 .54097 .35719 .53437 .3497 Mtetra
.67 .749 .909 r
.53437 .3497 .54097 .35719 .55329 .35284 .54673 .34531 Mtetra
.676 .751 .907 r
.54673 .34531 .55329 .35284 .56566 .34826 .55914 .3407 Mtetra
.682 .753 .905 r
.55914 .3407 .56566 .34826 .57808 .34345 .5716 .33587 Mtetra
.679 .752 .906 r
.5716 .33587 .57808 .34345 .59056 .33895 .58411 .33112 Mtetra
.664 .741 .907 r
.58411 .33112 .59056 .33895 .60309 .33472 .59668 .32685 Mtetra
.59668 .32685 .60309 .33472 .61569 .33046 .60931 .32256 Mtetra
.60931 .32256 .61569 .33046 .62834 .32619 .622 .31826 Mtetra
.622 .31826 .62834 .32619 .64105 .3219 .63475 .31393 Mtetra
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.606 .716 .923 r
.73886 .2786 .74482 .28687 .75824 .28476 .75227 .2759 Mtetra
.236 .495 .898 r
.75227 .2759 .75824 .28476 .77235 .29019 .76641 .28136 Mtetra
.401 .597 .925 r
.76641 .28136 .77235 .29019 .78632 .2922 .78044 .28369 Mtetra
.709 .756 .889 r
.78044 .28369 .78632 .2922 .79963 .28545 .79384 .27741 Mtetra
.858 .807 .799 r
.79384 .27741 .79963 .28545 .81222 .27041 .80652 .26257 Mtetra
.815 .807 .843 r
.80652 .26257 .81222 .27041 .82521 .25973 .81951 .25123 Mtetra
.664 .741 .907 r
.81951 .25123 .82521 .25973 .83883 .25514 .83317 .24659 Mtetra
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.24627 .43627 .25368 .44326 .26481 .43948 .25742 .43247 Mtetra
.27 .575 .94 r
.25742 .43247 .26481 .43948 .27548 .44215 .26811 .43512 Mtetra
0 .337 .803 r
.26811 .43512 .27548 .44215 .286 .44822 .27863 .44118 Mtetra
.599 .724 .932 r
.27863 .44118 .286 .44822 .29721 .44608 .28986 .43901 Mtetra
.8 .763 .82 r
.28986 .43901 .29721 .44608 .30902 .43562 .30172 .42851 Mtetra
.831 .762 .787 r
.30172 .42851 .30902 .43562 .32103 .42211 .31378 .41495 Mtetra
.714 .753 .883 r
.31378 .41495 .32103 .42211 .33255 .41649 .32534 .4093 Mtetra
.664 .741 .907 r
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.41869 .37745 .42565 .3849 .43752 .38087 .43059 .37339 Mtetra
.43059 .37339 .43752 .38087 .44944 .37682 .44254 .36931 Mtetra
.44254 .36931 .44944 .37682 .46141 .37276 .45455 .36521 Mtetra
.45455 .36521 .46141 .37276 .47344 .36868 .46661 .3611 Mtetra
.648 .736 .913 r
.46661 .3611 .47344 .36868 .48551 .36507 .47871 .35746 Mtetra
.644 .734 .915 r
.47871 .35746 .48551 .36507 .49764 .36156 .49088 .35392 Mtetra
.651 .737 .912 r
.49088 .35392 .49764 .36156 .50983 .35783 .5031 .35015 Mtetra
.658 .739 .91 r
.5031 .35015 .50983 .35783 .52207 .35387 .51538 .34615 Mtetra
.664 .741 .908 r
.51538 .34615 .52207 .35387 .53437 .3497 .52772 .34195 Mtetra
.67 .743 .905 r
.52772 .34195 .53437 .3497 .54673 .34531 .54011 .33753 Mtetra
.676 .745 .903 r
.54011 .33753 .54673 .34531 .55914 .3407 .55256 .33288 Mtetra
.682 .747 .9 r
.55256 .33288 .55914 .3407 .5716 .33587 .56505 .32801 Mtetra
.679 .746 .902 r
.56505 .32801 .5716 .33587 .58411 .33112 .5776 .32323 Mtetra
.664 .741 .907 r
.5776 .32323 .58411 .33112 .59668 .32685 .59022 .31892 Mtetra
.59022 .31892 .59668 .32685 .60931 .32256 .60289 .3146 Mtetra
.60289 .3146 .60931 .32256 .622 .31826 .61561 .31026 Mtetra
.61561 .31026 .622 .31826 .63475 .31393 .6284 .30589 Mtetra
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.606 .716 .923 r
.73284 .27026 .73886 .2786 .75227 .2759 .74629 .26752 Mtetra
.211 .496 .902 r
.74629 .26752 .75227 .2759 .76641 .28136 .76045 .27296 Mtetra
.387 .604 .934 r
.76045 .27296 .76641 .28136 .78044 .28369 .77452 .27526 Mtetra
.709 .761 .892 r
.77452 .27526 .78044 .28369 .79384 .27741 .78797 .26894 Mtetra
.854 .798 .796 r
.78797 .26894 .79384 .27741 .80652 .26257 .80071 .25404 Mtetra
.809 .79 .835 r
.80071 .25404 .80652 .26257 .81951 .25123 .81375 .24265 Mtetra
.664 .741 .907 r
.81375 .24265 .81951 .25123 .83317 .24659 .82746 .23797 Mtetra
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.23879 .42924 .24627 .43627 .25742 .43247 .24997 .4254 Mtetra
.325 .604 .948 r
.24997 .4254 .25742 .43247 .26811 .43512 .26072 .42744 Mtetra
0 .335 .809 r
.26072 .42744 .26811 .43512 .27863 .44118 .27123 .43373 Mtetra
.579 .706 .929 r
.27123 .43373 .27863 .44118 .28986 .43901 .28244 .43203 Mtetra
.797 .767 .826 r
.28244 .43203 .28986 .43901 .30172 .42851 .29433 .42182 Mtetra
.835 .772 .792 r
.29433 .42182 .30172 .42851 .31378 .41495 .30644 .40828 Mtetra
.73 .77 .885 r
.30644 .40828 .31378 .41495 .32534 .4093 .31807 .40204 Mtetra
.664 .741 .907 r
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.41167 .36994 .41869 .37745 .43059 .37339 .4236 .36584 Mtetra
.4236 .36584 .43059 .37339 .44254 .36931 .43559 .36173 Mtetra
.43559 .36173 .44254 .36931 .45455 .36521 .44763 .3576 Mtetra
.44763 .3576 .45455 .36521 .46661 .3611 .45972 .35345 Mtetra
.655 .738 .911 r
.45972 .35345 .46661 .3611 .47871 .35746 .47187 .34957 Mtetra
.644 .728 .91 r
.47187 .34957 .47871 .35746 .49088 .35392 .48406 .34601 Mtetra
.651 .731 .908 r
.48406 .34601 .49088 .35392 .5031 .35015 .49632 .3422 Mtetra
.657 .733 .906 r
.49632 .3422 .5031 .35015 .51538 .34615 .50864 .33818 Mtetra
.664 .735 .903 r
.50864 .33818 .51538 .34615 .52772 .34195 .52101 .33394 Mtetra
.67 .737 .901 r
.52101 .33394 .52772 .34195 .54011 .33753 .53344 .32948 Mtetra
.675 .739 .899 r
.53344 .32948 .54011 .33753 .55256 .33288 .54592 .3248 Mtetra
.682 .741 .896 r
.54592 .3248 .55256 .33288 .56505 .32801 .55845 .31987 Mtetra
.672 .738 .9 r
.55845 .31987 .56505 .32801 .5776 .32323 .57104 .31527 Mtetra
.664 .741 .907 r
.57104 .31527 .5776 .32323 .59022 .31892 .58369 .31093 Mtetra
.58369 .31093 .59022 .31892 .60289 .3146 .5964 .30657 Mtetra
.5964 .30657 .60289 .3146 .61561 .31026 .60917 .30219 Mtetra
.60917 .30219 .61561 .31026 .6284 .30589 .622 .29779 Mtetra
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.585 .707 .927 r
.72676 .26185 .73284 .27026 .74629 .26752 .7403 .25963 Mtetra
.186 .497 .906 r
.7403 .25963 .74629 .26752 .76045 .27296 .75449 .26499 Mtetra
.39 .622 .945 r
.75449 .26499 .76045 .27296 .77452 .27526 .76856 .26691 Mtetra
.723 .769 .89 r
.76856 .26691 .77452 .27526 .78797 .26894 .78202 .26003 Mtetra
.852 .79 .79 r
.78202 .26003 .78797 .26894 .80071 .25404 .7948 .24482 Mtetra
.793 .772 .834 r
.7948 .24482 .80071 .25404 .81375 .24265 .80795 .234 Mtetra
.664 .741 .907 r
.80795 .234 .81375 .24265 .82746 .23797 .82171 .22928 Mtetra
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.23126 .42215 .23879 .42924 .24997 .4254 .24247 .41828 Mtetra
.422 .652 .954 r
.24247 .41828 .24997 .4254 .26072 .42744 .25333 .41911 Mtetra
0 .318 .802 r
.25333 .41911 .26072 .42744 .27123 .43373 .2638 .42581 Mtetra
.536 .678 .929 r
.2638 .42581 .27123 .43373 .28244 .43203 .27496 .42506 Mtetra
.788 .768 .835 r
.27496 .42506 .28244 .43203 .29433 .42182 .28684 .41554 Mtetra
.838 .782 .798 r
.28684 .41554 .29433 .42182 .30644 .40828 .299 .4021 Mtetra
.758 .789 .878 r
.299 .4021 .30644 .40828 .31807 .40204 .31074 .39473 Mtetra
.664 .741 .907 r
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.40459 .36236 .41167 .36994 .4236 .36584 .41656 .35824 Mtetra
.41656 .35824 .4236 .36584 .43559 .36173 .42858 .35409 Mtetra
.42858 .35409 .43559 .36173 .44763 .3576 .44066 .34993 Mtetra
.44066 .34993 .44763 .3576 .45972 .35345 .45278 .34574 Mtetra
.45278 .34574 .45972 .35345 .47187 .34957 .46497 .34154 Mtetra
.648 .728 .907 r
.46497 .34154 .47187 .34957 .48406 .34601 .4772 .33781 Mtetra
.651 .725 .903 r
.4772 .33781 .48406 .34601 .49632 .3422 .48949 .33399 Mtetra
.657 .728 .901 r
.48949 .33399 .49632 .3422 .50864 .33818 .50184 .32993 Mtetra
.663 .73 .899 r
.50184 .32993 .50864 .33818 .52101 .33394 .51424 .32566 Mtetra
.669 .732 .897 r
.51424 .32566 .52101 .33394 .53344 .32948 .52671 .32116 Mtetra
.675 .734 .894 r
.52671 .32116 .53344 .32948 .54592 .3248 .53923 .31643 Mtetra
.678 .734 .893 r
.53923 .31643 .54592 .3248 .55845 .31987 .5518 .31159 Mtetra
.664 .733 .901 r
.5518 .31159 .55845 .31987 .57104 .31527 .56443 .30724 Mtetra
.664 .741 .907 r
.56443 .30724 .57104 .31527 .58369 .31093 .57712 .30286 Mtetra
.57712 .30286 .58369 .31093 .5964 .30657 .58987 .29847 Mtetra
.58987 .29847 .5964 .30657 .60917 .30219 .60267 .29405 Mtetra
.60267 .29405 .60917 .30219 .622 .29779 .61554 .28961 Mtetra
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.541 .686 .933 r
.72064 .25336 .72676 .26185 .7403 .25963 .73429 .25224 Mtetra
.165 .502 .909 r
.73429 .25224 .7403 .25963 .75449 .26499 .7485 .25742 Mtetra
.416 .652 .956 r
.7485 .25742 .75449 .26499 .76856 .26691 .76255 .25856 Mtetra
.746 .779 .879 r
.76255 .25856 .76856 .26691 .78202 .26003 .77598 .25062 Mtetra
.852 .781 .782 r
.77598 .25062 .78202 .26003 .7948 .24482 .78878 .23491 Mtetra
.767 .75 .838 r
.78878 .23491 .7948 .24482 .80795 .234 .80209 .22527 Mtetra
.664 .741 .907 r
.80209 .22527 .80795 .234 .82171 .22928 .8159 .22051 Mtetra
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.22367 .415 .23126 .42215 .24247 .41828 .2349 .4111 Mtetra
.535 .7 .945 r
.2349 .4111 .24247 .41828 .25333 .41911 .24593 .41017 Mtetra
0 .296 .791 r
.24593 .41017 .25333 .41911 .2638 .42581 .25636 .41731 Mtetra
.465 .632 .926 r
.25636 .41731 .2638 .42581 .27496 .42506 .26742 .41796 Mtetra
.769 .765 .85 r
.26742 .41796 .27496 .42506 .28684 .41554 .27925 .40958 Mtetra
.839 .791 .805 r
.27925 .40958 .28684 .41554 .299 .4021 .29145 .39642 Mtetra
.793 .805 .862 r
.29145 .39642 .299 .4021 .31074 .39473 .30335 .38737 Mtetra
.664 .741 .907 r
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41656 .35824 .40946 .35057 Mtetra
.40946 .35057 .41656 .35824 .42858 .35409 .42151 .34639 Mtetra
.42151 .34639 .42858 .35409 .44066 .34993 .43362 .34219 Mtetra
.43362 .34219 .44066 .34993 .45278 .34574 .44578 .33797 Mtetra
.44578 .33797 .45278 .34574 .46497 .34154 .458 .33374 Mtetra
.458 .33374 .46497 .34154 .4772 .33781 .47027 .32948 Mtetra
.655 .724 .9 r
.47027 .32948 .4772 .33781 .48949 .33399 .4826 .32549 Mtetra
.657 .722 .897 r
.4826 .32549 .48949 .33399 .50184 .32993 .49498 .32141 Mtetra
.663 .724 .895 r
.49498 .32141 .50184 .32993 .51424 .32566 .50742 .3171 Mtetra
.669 .726 .892 r
.50742 .3171 .51424 .32566 .52671 .32116 .51992 .31255 Mtetra
.671 .727 .891 r
.51992 .31255 .52671 .32116 .53923 .31643 .53248 .30791 Mtetra
.663 .727 .897 r
.53248 .30791 .53923 .31643 .5518 .31159 .54509 .30354 Mtetra
.664 .741 .907 r
.54509 .30354 .5518 .31159 .56443 .30724 .55776 .29914 Mtetra
.55776 .29914 .56443 .30724 .57712 .30286 .57049 .29473 Mtetra
.57049 .29473 .57712 .30286 .58987 .29847 .58327 .2903 Mtetra
.58327 .2903 .58987 .29847 .60267 .29405 .59612 .28584 Mtetra
.59612 .28584 .60267 .29405 .61554 .28961 .60903 .28137 Mtetra
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.467 .648 .937 r
.71446 .2448 .72064 .25336 .73429 .25224 .72827 .24536 Mtetra
.155 .515 .915 r
.72827 .24536 .73429 .25224 .7485 .25742 .74249 .25017 Mtetra
.469 .693 .965 r
.74249 .25017 .7485 .25742 .76255 .25856 .75649 .25006 Mtetra
.776 .786 .861 r
.75649 .25006 .76255 .25856 .77598 .25062 .76985 .24058 Mtetra
.851 .77 .773 r
.76985 .24058 .77598 .25062 .78878 .23491 .78267 .22434 Mtetra
.729 .724 .846 r
.78267 .22434 .78878 .23491 .80209 .22527 .79619 .21646 Mtetra
.664 .741 .907 r
.79619 .21646 .80209 .22527 .8159 .22051 .81004 .21166 Mtetra
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.21601 .40779 .22367 .415 .2349 .4111 .22728 .40386 Mtetra
.638 .734 .918 r
.22728 .40386 .2349 .4111 .24593 .41017 .23852 .40066 Mtetra
0 .286 .786 r
.23852 .40066 .24593 .41017 .25636 .41731 .24892 .40808 Mtetra
.365 .564 .913 r
.24892 .40808 .25636 .41731 .26742 .41796 .25985 .4105 Mtetra
.734 .753 .868 r
.25985 .4105 .26742 .41796 .27925 .40958 .27158 .4038 Mtetra
.835 .797 .815 r
.27158 .4038 .27925 .40958 .29145 .39642 .28379 .39125 Mtetra
.829 .816 .837 r
.28379 .39125 .29145 .39642 .30335 .38737 .2959 .37994 Mtetra
.664 .741 .907 r
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.4023 .34284 .40946 .35057 .42151 .34639 .41439 .33862 Mtetra
.41439 .33862 .42151 .34639 .43362 .34219 .42653 .33439 Mtetra
.42653 .33439 .43362 .34219 .44578 .33797 .43873 .33014 Mtetra
.43873 .33014 .44578 .33797 .458 .33374 .45098 .32586 Mtetra
.45098 .32586 .458 .33374 .47027 .32948 .46329 .32157 Mtetra
.46329 .32157 .47027 .32948 .4826 .32549 .47565 .31726 Mtetra
.664 .733 .901 r
.47565 .31726 .4826 .32549 .49498 .32141 .48807 .31293 Mtetra
.663 .727 .897 r
.48807 .31293 .49498 .32141 .50742 .3171 .50055 .30858 Mtetra
.50055 .30858 .50742 .3171 .51992 .31255 .51308 .30421 Mtetra
.664 .733 .901 r
.51308 .30421 .51992 .31255 .53248 .30791 .52568 .29982 Mtetra
.664 .741 .907 r
.52568 .29982 .53248 .30791 .54509 .30354 .53833 .29541 Mtetra
.53833 .29541 .54509 .30354 .55776 .29914 .55103 .29098 Mtetra
.55103 .29098 .55776 .29914 .57049 .29473 .5638 .28653 Mtetra
.5638 .28653 .57049 .29473 .58327 .2903 .57663 .28206 Mtetra
.57663 .28206 .58327 .2903 .59612 .28584 .58951 .27756 Mtetra
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.352 .584 .93 r
.70823 .23617 .71446 .2448 .72827 .24536 .72222 .23897 Mtetra
.169 .544 .927 r
.72222 .23897 .72827 .24536 .74249 .25017 .73643 .24308 Mtetra
.55 .742 .965 r
.73643 .24308 .74249 .25017 .75649 .25006 .75035 .24116 Mtetra
.804 .785 .835 r
.75035 .24116 .75649 .25006 .76985 .24058 .76362 .22978 Mtetra
.846 .757 .764 r
.76362 .22978 .76985 .24058 .78267 .22434 .77646 .21317 Mtetra
.677 .692 .857 r
.77646 .21317 .78267 .22434 .79619 .21646 .79023 .20758 Mtetra
.664 .741 .907 r
.79023 .20758 .79619 .21646 .81004 .21166 .80412 .20273 Mtetra
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.2083 .40053 .21601 .40779 .22728 .40386 .21959 .39657 Mtetra
.21959 .39657 .22728 .40386 .23852 .40066 .23093 .39259 Mtetra
.021 .397 .852 r
.23093 .39259 .23852 .40066 .24892 .40808 .24149 .39804 Mtetra
.247 .477 .882 r
.24149 .39804 .24892 .40808 .25985 .4105 .25226 .40235 Mtetra
.674 .725 .888 r
.25226 .40235 .25985 .4105 .27158 .4038 .26385 .39793 Mtetra
.823 .799 .829 r
.26385 .39793 .27158 .4038 .28379 .39125 .27602 .38649 Mtetra
.854 .821 .816 r
.27602 .38649 .28379 .39125 .2959 .37994 .28834 .37313 Mtetra
.686 .766 .912 r
.28834 .37313 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.664 .741 .907 r
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41439 .33862 .4072 .33079 Mtetra
.4072 .33079 .41439 .33862 .42653 .33439 .41938 .32652 Mtetra
.41938 .32652 .42653 .33439 .43873 .33014 .43161 .32223 Mtetra
.43161 .32223 .43873 .33014 .45098 .32586 .4439 .31793 Mtetra
.4439 .31793 .45098 .32586 .46329 .32157 .45624 .3136 Mtetra
.45624 .3136 .46329 .32157 .47565 .31726 .46864 .30925 Mtetra
.46864 .30925 .47565 .31726 .48807 .31293 .4811 .30488 Mtetra
.4811 .30488 .48807 .31293 .50055 .30858 .49361 .3005 Mtetra
.49361 .3005 .50055 .30858 .51308 .30421 .50619 .29609 Mtetra
.50619 .29609 .51308 .30421 .52568 .29982 .51881 .29166 Mtetra
.51881 .29166 .52568 .29982 .53833 .29541 .5315 .28721 Mtetra
.5315 .28721 .53833 .29541 .55103 .29098 .54425 .28274 Mtetra
.54425 .28274 .55103 .29098 .5638 .28653 .55705 .27826 Mtetra
.55705 .27826 .5638 .28653 .57663 .28206 .56992 .27374 Mtetra
.56992 .27374 .57663 .28206 .58951 .27756 .58284 .26921 Mtetra
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.643 .732 .914 r
.68846 .23219 .69479 .24086 .70823 .23617 .70198 .22816 Mtetra
.202 .513 .913 r
.70198 .22816 .70823 .23617 .72222 .23897 .71613 .233 Mtetra
.226 .599 .95 r
.71613 .233 .72222 .23897 .73643 .24308 .73031 .23589 Mtetra
.646 .782 .946 r
.73031 .23589 .73643 .24308 .75035 .24116 .7441 .23154 Mtetra
.825 .775 .806 r
.7441 .23154 .75035 .24116 .76362 .22978 .75727 .21811 Mtetra
.817 .737 .775 r
.75727 .21811 .76362 .22978 .77646 .21317 .77034 .20348 Mtetra
.663 .72 .892 r
.77034 .20348 .77646 .21317 .79023 .20758 .78421 .19862 Mtetra
.664 .741 .907 r
.78421 .19862 .79023 .20758 .80412 .20273 .79816 .19373 Mtetra
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21959 .39657 .21184 .38921 Mtetra
.21184 .38921 .21959 .39657 .23093 .39259 .22321 .3852 Mtetra
.325 .604 .948 r
.22321 .3852 .23093 .39259 .24149 .39804 .23409 .38716 Mtetra
.138 .39 .842 r
.23409 .38716 .24149 .39804 .25226 .40235 .2447 .39319 Mtetra
.576 .667 .901 r
.2447 .39319 .25226 .40235 .26385 .39793 .25607 .39159 Mtetra
.795 .791 .849 r
.25607 .39159 .26385 .39793 .27602 .38649 .26816 .38197 Mtetra
.854 .829 .822 r
.26816 .38197 .27602 .38649 .28834 .37313 .28052 .36886 Mtetra
.783 .853 .904 r
.28052 .36886 .28834 .37313 .30004 .36836 .2925 .36078 Mtetra
.664 .741 .907 r
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41938 .32652 .41217 .31859 Mtetra
.41217 .31859 .41938 .32652 .43161 .32223 .42444 .31427 Mtetra
.42444 .31427 .43161 .32223 .4439 .31793 .43676 .30992 Mtetra
.43676 .30992 .4439 .31793 .45624 .3136 .44914 .30556 Mtetra
.44914 .30556 .45624 .3136 .46864 .30925 .46157 .30117 Mtetra
.46157 .30117 .46864 .30925 .4811 .30488 .47407 .29677 Mtetra
.47407 .29677 .4811 .30488 .49361 .3005 .48662 .29234 Mtetra
.48662 .29234 .49361 .3005 .50619 .29609 .49923 .2879 Mtetra
.49923 .2879 .50619 .29609 .51881 .29166 .5119 .28343 Mtetra
.5119 .28343 .51881 .29166 .5315 .28721 .52462 .27895 Mtetra
.52462 .27895 .5315 .28721 .54425 .28274 .53741 .27444 Mtetra
.53741 .27444 .54425 .28274 .55705 .27826 .55025 .26991 Mtetra
.55025 .26991 .55705 .27826 .56992 .27374 .56316 .26536 Mtetra
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.517 .675 .936 r
.68207 .22344 .68846 .23219 .70198 .22816 .69583 .22276 Mtetra
.061 .508 .894 r
.69583 .22276 .70198 .22816 .71613 .233 .71 .22727 Mtetra
.344 .683 .979 r
.71 .22727 .71613 .233 .73031 .23589 .7241 .22821 Mtetra
.734 .8 .904 r
.7241 .22821 .73031 .23589 .7441 .23154 .73774 .22085 Mtetra
.834 .758 .779 r
.73774 .22085 .7441 .23154 .75727 .21811 .75083 .20557 Mtetra
.765 .706 .796 r
.75083 .20557 .75727 .21811 .77034 .20348 .76422 .19448 Mtetra
.664 .741 .907 r
.76422 .19448 .77034 .20348 .78421 .19862 .77815 .18957 Mtetra
.77815 .18957 .78421 .19862 .79816 .19373 .79214 .18464 Mtetra
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.20403 .3818 .21184 .38921 .22321 .3852 .21543 .37776 Mtetra
.587 .718 .934 r
.21543 .37776 .22321 .3852 .23409 .38716 .22669 .37567 Mtetra
.075 .336 .812 r
.22669 .37567 .23409 .38716 .2447 .39319 .2372 .38272 Mtetra
.438 .574 .892 r
.2372 .38272 .2447 .39319 .25607 .39159 .24831 .38425 Mtetra
.738 .763 .873 r
.24831 .38425 .25607 .39159 .26816 .38197 .26022 .37732 Mtetra
.843 .831 .835 r
.26022 .37732 .26816 .38197 .28052 .36886 .27256 .36514 Mtetra
.85 .857 .847 r
.27256 .36514 .28052 .36886 .2925 .36078 .28489 .35313 Mtetra
.664 .741 .907 r
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42444 .31427 .4172 .30623 Mtetra
.4172 .30623 .42444 .31427 .43676 .30992 .42956 .30185 Mtetra
.42956 .30185 .43676 .30992 .44914 .30556 .44197 .29745 Mtetra
.44197 .29745 .44914 .30556 .46157 .30117 .45445 .29303 Mtetra
.45445 .29303 .46157 .30117 .47407 .29677 .46698 .28858 Mtetra
.46698 .28858 .47407 .29677 .48662 .29234 .47956 .28412 Mtetra
.47956 .28412 .48662 .29234 .49923 .2879 .49221 .27964 Mtetra
.49221 .27964 .49923 .2879 .5119 .28343 .50492 .27513 Mtetra
.50492 .27513 .5119 .28343 .52462 .27895 .51768 .27061 Mtetra
.51768 .27061 .52462 .27895 .53741 .27444 .5305 .26606 Mtetra
.5305 .26606 .53741 .27444 .55025 .26991 .54339 .2615 Mtetra
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.318 .565 .926 r
.67563 .21462 .68207 .22344 .69583 .22276 .68964 .2179 Mtetra
.098 .555 .911 r
.68964 .2179 .69583 .22276 .71 .22727 .7038 .22138 Mtetra
.519 .773 .989 r
.7038 .22138 .71 .22727 .7241 .22821 .71777 .21946 Mtetra
.794 .79 .849 r
.71777 .21946 .7241 .22821 .73774 .22085 .73124 .20879 Mtetra
.832 .736 .759 r
.73124 .20879 .73774 .22085 .75083 .20557 .7443 .19237 Mtetra
.693 .666 .819 r
.7443 .19237 .75083 .20557 .76422 .19448 .75805 .1854 Mtetra
.664 .741 .907 r
.75805 .1854 .76422 .19448 .77815 .18957 .77203 .18045 Mtetra
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.698 .777 .912 r
.17333 .38344 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.664 .741 .907 r
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.19615 .37432 .20403 .3818 .21543 .37776 .20758 .37025 Mtetra
.20758 .37025 .21543 .37776 .22669 .37567 .21906 .36616 Mtetra
.168 .452 .88 r
.21906 .36616 .22669 .37567 .2372 .38272 .22977 .37089 Mtetra
.288 .461 .858 r
.22977 .37089 .2372 .38272 .24831 .38425 .24062 .37533 Mtetra
.638 .7 .891 r
.24062 .37533 .24831 .38425 .26022 .37732 .25226 .37192 Mtetra
.812 .819 .855 r
.25226 .37192 .26022 .37732 .27256 .36514 .2645 .36167 Mtetra
.861 .861 .838 r
.2645 .36167 .27256 .36514 .28489 .35313 .27696 .34884 Mtetra
.77 .857 .915 r
.27696 .34884 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.664 .741 .907 r
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44197 .29745 .43475 .28927 Mtetra
.43475 .28927 .44197 .29745 .45445 .29303 .44726 .28481 Mtetra
.44726 .28481 .45445 .29303 .46698 .28858 .45982 .28033 Mtetra
.45982 .28033 .46698 .28858 .47956 .28412 .47245 .27583 Mtetra
.47245 .27583 .47956 .28412 .49221 .27964 .48513 .27131 Mtetra
.48513 .27131 .49221 .27964 .50492 .27513 .49788 .26676 Mtetra
.49788 .26676 .50492 .27513 .51768 .27061 .51068 .2622 Mtetra
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.541 .687 .934 r
.65557 .21055 .66212 .21941 .67563 .21462 .66929 .20923 Mtetra
.083 .528 .904 r
.66929 .20923 .67563 .21462 .68964 .2179 .68339 .21328 Mtetra
.24 .662 .96 r
.68339 .21328 .68964 .2179 .7038 .22138 .69749 .2147 Mtetra
.685 .817 .946 r
.69749 .2147 .7038 .22138 .71777 .21946 .71128 .20907 Mtetra
.821 .763 .798 r
.71128 .20907 .71777 .21946 .73124 .20879 .7246 .1953 Mtetra
.794 .705 .766 r
.7246 .1953 .73124 .20879 .7443 .19237 .73788 .18121 Mtetra
.659 .69 .868 r
.73788 .18121 .7443 .19237 .75805 .1854 .75183 .17624 Mtetra
.664 .741 .907 r
.75183 .17624 .75805 .1854 .77203 .18045 .76585 .17124 Mtetra
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.632 .727 .916 r
.77994 .16621 .78607 .17547 .80018 .17047 .79419 .16223 Mtetra
.714 .768 .895 r
.16526 .37659 .17333 .38344 .18477 .37838 .1768 .37088 Mtetra
.664 .741 .907 r
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20758 .37025 .19967 .36268 Mtetra
.19967 .36268 .20758 .37025 .21906 .36616 .21118 .35856 Mtetra
.502 .686 .949 r
.21118 .35856 .21906 .36616 .22977 .37089 .22239 .35803 Mtetra
.185 .377 .82 r
.22239 .35803 .22977 .37089 .24062 .37533 .23306 .36437 Mtetra
.487 .591 .883 r
.23306 .36437 .24062 .37533 .25226 .37192 .24435 .36495 Mtetra
.744 .777 .88 r
.24435 .36495 .25226 .37192 .2645 .36167 .25638 .35783 Mtetra
.845 .858 .852 r
.25638 .35783 .2645 .36167 .27696 .34884 .26882 .34608 Mtetra
.863 .883 .85 r
.26882 .34608 .27696 .34884 .28902 .34122 .28131 .33355 Mtetra
.669 .746 .908 r
.28131 .33355 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.664 .741 .907 r
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.66 .739 .909 r
.63544 .20646 .64209 .21536 .65557 .21055 .64898 .20176 Mtetra
.285 .551 .924 r
.64898 .20176 .65557 .21055 .66929 .20923 .66296 .2054 Mtetra
.061 .563 .886 r
.66296 .2054 .66929 .20923 .68339 .21328 .67705 .20827 Mtetra
.486 .791 .999 r
.67705 .20827 .68339 .21328 .69749 .2147 .69103 .20638 Mtetra
.782 .8 .867 r
.69103 .20638 .69749 .2147 .71128 .20907 .70462 .19655 Mtetra
.821 .728 .762 r
.70462 .19655 .71128 .20907 .7246 .1953 .71786 .18074 Mtetra
.713 .657 .793 r
.71786 .18074 .7246 .1953 .73788 .18121 .73155 .17201 Mtetra
.664 .741 .907 r
.73155 .17201 .73788 .18121 .75183 .17624 .74555 .16699 Mtetra
.74555 .16699 .75183 .17624 .76585 .17124 .75962 .16195 Mtetra
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.611 .717 .921 r
.77376 .15688 .77994 .16621 .79419 .16223 .78812 .1535 Mtetra
.695 .752 .895 r
.15718 .36921 .16526 .37659 .1768 .37088 .16868 .36407 Mtetra
.689 .767 .911 r
.16868 .36407 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.664 .741 .907 r
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.19169 .35505 .19967 .36268 .21118 .35856 .20323 .35089 Mtetra
.20323 .35089 .21118 .35856 .22239 .35803 .21482 .34671 Mtetra
.243 .45 .863 r
.21482 .34671 .22239 .35803 .23306 .36437 .22563 .35139 Mtetra
.33 .464 .844 r
.22563 .35139 .23306 .36437 .24435 .36495 .2366 .35552 Mtetra
.618 .685 .891 r
.2366 .35552 .24435 .36495 .25638 .35783 .24829 .35263 Mtetra
.798 .83 .876 r
.24829 .35263 .25638 .35783 .26882 .34608 .26058 .34334 Mtetra
.858 .887 .857 r
.26058 .34334 .26882 .34608 .28131 .33355 .27311 .33121 Mtetra
.825 .912 .897 r
.27311 .33121 .28131 .33355 .2932 .32915 .28547 .32124 Mtetra
.664 .741 .907 r
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.435 .634 .939 r
.62873 .19749 .63544 .20646 .64898 .20176 .64253 .19842 Mtetra
0 .525 .842 r
.64253 .19842 .64898 .20176 .66296 .2054 .65655 .20158 Mtetra
.273 .711 .964 r
.65655 .20158 .66296 .2054 .67705 .20827 .67058 .20184 Mtetra
.704 .833 .944 r
.67058 .20184 .67705 .20827 .69103 .20638 .68437 .19552 Mtetra
.814 .754 .797 r
.68437 .19552 .69103 .20638 .70462 .19655 .6978 .18194 Mtetra
.785 .688 .758 r
.6978 .18194 .70462 .19655 .71786 .18074 .71119 .16776 Mtetra
.653 .655 .84 r
.71119 .16776 .71786 .18074 .73155 .17201 .72516 .16272 Mtetra
.664 .741 .907 r
.72516 .16272 .73155 .17201 .74555 .16699 .73921 .15766 Mtetra
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.641 .731 .914 r
.75333 .15257 .75962 .16195 .77376 .15688 .76758 .14824 Mtetra
.63 .748 .932 r
.76758 .14824 .77376 .15688 .78812 .1535 .78193 .14418 Mtetra
.677 .738 .897 r
.14907 .36139 .15718 .36921 .16868 .36407 .16054 .35682 Mtetra
.699 .759 .898 r
.16054 .35682 .16868 .36407 .18021 .35919 .17213 .35153 Mtetra
.664 .741 .907 r
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20323 .35089 .19522 .34316 Mtetra
.19522 .34316 .20323 .35089 .21482 .34671 .20684 .33895 Mtetra
.566 .71 .939 r
.20684 .33895 .21482 .34671 .22563 .35139 .21827 .33718 Mtetra
.242 .388 .811 r
.21827 .33718 .22563 .35139 .2366 .35552 .22905 .34321 Mtetra
.449 .546 .863 r
.22905 .34321 .2366 .35552 .24829 .35263 .24034 .3448 Mtetra
.693 .751 .896 r
.24034 .3448 .24829 .35263 .26058 .34334 .25233 .3395 Mtetra
.823 .868 .879 r
.25233 .3395 .26058 .34334 .27311 .33121 .26477 .32923 Mtetra
.859 .911 .867 r
.26477 .32923 .27311 .33121 .28547 .32124 .27736 .31728 Mtetra
.785 .873 .912 r
.27736 .31728 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.664 .741 .907 r
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.515 .675 .937 r
.60841 .19335 .61522 .20236 .62873 .19749 .6221 .19254 Mtetra
.127 .58 .922 r
.6221 .19254 .62873 .19749 .64253 .19842 .63602 .19543 Mtetra
.134 .642 .9 r
.63602 .19543 .64253 .19842 .65655 .20158 .65002 .1966 Mtetra
.592 .842 .992 r
.65002 .1966 .65655 .20158 .67058 .20184 .66391 .19269 Mtetra
.795 .785 .844 r
.66391 .19269 .67058 .20184 .68437 .19552 .67751 .18167 Mtetra
.807 .706 .755 r
.67751 .18167 .68437 .19552 .6978 .18194 .69088 .16605 Mtetra
.687 .629 .786 r
.69088 .16605 .6978 .18194 .71119 .16776 .70469 .15844 Mtetra
.664 .741 .907 r
.70469 .15844 .71119 .16776 .72516 .16272 .71872 .15335 Mtetra
.71872 .15335 .72516 .16272 .73921 .15766 .73282 .14824 Mtetra
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.629 .725 .917 r
.74698 .14311 .75333 .15257 .76758 .14824 .76131 .13912 Mtetra
.651 .746 .919 r
.76131 .13912 .76758 .14824 .78193 .14418 .77566 .13439 Mtetra
.665 .73 .899 r
.14092 .35334 .14907 .36139 .16054 .35682 .15237 .34912 Mtetra
.69 .747 .895 r
.15237 .34912 .16054 .35682 .17213 .35153 .16397 .34407 Mtetra
.673 .75 .909 r
.16397 .34407 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.664 .741 .907 r
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.18714 .33537 .19522 .34316 .20684 .33895 .19879 .33112 Mtetra
.19879 .33112 .20684 .33895 .21827 .33718 .21049 .32685 Mtetra
.409 .572 .903 r
.21049 .32685 .21827 .33718 .22905 .34321 .22167 .32855 Mtetra
.319 .428 .816 r
.22167 .32855 .22905 .34321 .24034 .3448 .23266 .3334 Mtetra
.528 .607 .875 r
.23266 .3334 .24034 .3448 .25233 .3395 .24423 .33296 Mtetra
.732 .795 .902 r
.24423 .33296 .25233 .3395 .26477 .32923 .25641 .32634 Mtetra
.831 .896 .887 r
.25641 .32634 .26477 .32923 .27736 .31728 .26895 .31587 Mtetra
.853 .931 .877 r
.26895 .31587 .27736 .31728 .28967 .30892 .28157 .3043 Mtetra
.77 .857 .915 r
.28157 .3043 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.664 .741 .907 r
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.539 .687 .935 r
.58801 .18919 .59492 .19824 .60841 .19335 .60163 .18779 Mtetra
.199 .61 .947 r
.60163 .18779 .60841 .19335 .6221 .19254 .61546 .19019 Mtetra
.07 .61 .852 r
.61546 .19019 .6221 .19254 .63602 .19543 .6294 .19149 Mtetra
.487 .829 .998 r
.6294 .19149 .63602 .19543 .65002 .1966 .6433 .18884 Mtetra
.768 .814 .889 r
.6433 .18884 .65002 .1966 .66391 .19269 .65702 .17985 Mtetra
.804 .72 .772 r
.65702 .17985 .66391 .19269 .67751 .18167 .6705 .16538 Mtetra
.736 .649 .762 r
.6705 .16538 .67751 .18167 .69088 .16605 .68414 .15414 Mtetra
.657 .68 .86 r
.68414 .15414 .69088 .16605 .70469 .15844 .69814 .14903 Mtetra
.664 .741 .907 r
.69814 .14903 .70469 .15844 .71872 .15335 .71222 .1439 Mtetra
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.656 .738 .91 r
.72636 .13874 .73282 .14824 .74698 .14311 .7406 .13383 Mtetra
.637 .736 .92 r
.7406 .13383 .74698 .14311 .76131 .13912 .75495 .12952 Mtetra
.662 .74 .908 r
.75495 .12952 .76131 .13912 .77566 .13439 .76932 .12433 Mtetra
.658 .728 .901 r
.1327 .34519 .14092 .35334 .15237 .34912 .14416 .34114 Mtetra
.665 .735 .902 r
.14416 .34114 .15237 .34912 .16397 .34407 .15569 .33686 Mtetra
.691 .763 .906 r
.15569 .33686 .16397 .34407 .17554 .3396 .16737 .33177 Mtetra
.664 .741 .907 r
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19879 .33112 .19067 .32323 Mtetra
.19067 .32323 .19879 .33112 .21049 .32685 .20241 .31892 Mtetra
.20241 .31892 .21049 .32685 .22167 .32855 .2142 .3146 Mtetra
.343 .457 .832 r
.2142 .3146 .22167 .32855 .23266 .3334 .22524 .31864 Mtetra
.379 .464 .822 r
.22524 .31864 .23266 .3334 .24423 .33296 .23643 .32228 Mtetra
.571 .644 .884 r
.23643 .32228 .24423 .33296 .25641 .32634 .2482 .3206 Mtetra
.745 .822 .912 r
.2482 .3206 .25641 .32634 .26895 .31587 .2605 .31357 Mtetra
.826 .917 .898 r
.2605 .31357 .26895 .31587 .28157 .3043 .27309 .30336 Mtetra
.842 .949 .888 r
.27309 .30336 .28157 .3043 .29392 .29643 .28575 .29227 Mtetra
.785 .873 .912 r
.28575 .29227 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.664 .741 .907 r
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.513 .675 .938 r
.56752 .18502 .57454 .1941 .58801 .18919 .5811 .18417 Mtetra
.209 .636 .951 r
.5811 .18417 .58801 .18919 .60163 .18779 .59486 .18598 Mtetra
.056 .609 .825 r
.59486 .18598 .60163 .18779 .61546 .19019 .60872 .18692 Mtetra
.431 .821 .986 r
.60872 .18692 .61546 .19019 .6294 .19149 .62259 .18462 Mtetra
.744 .834 .919 r
.62259 .18462 .6294 .19149 .6433 .18884 .63636 .17682 Mtetra
.798 .732 .79 r
.63636 .17682 .6433 .18884 .65702 .17985 .64994 .16354 Mtetra
.766 .663 .749 r
.64994 .16354 .65702 .17985 .6705 .16538 .6635 .14982 Mtetra
.643 .614 .805 r
.6635 .14982 .6705 .16538 .68414 .15414 .67748 .14469 Mtetra
.664 .741 .907 r
.67748 .14469 .68414 .15414 .69814 .14903 .69153 .13954 Mtetra
.69153 .13954 .69814 .14903 .71222 .1439 .70565 .13436 Mtetra
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.638 .73 .915 r
.71985 .12915 .72636 .13874 .7406 .13383 .73417 .12479 Mtetra
.663 .756 .92 r
.73417 .12479 .7406 .13383 .75495 .12952 .74852 .11959 Mtetra
.668 .737 .901 r
.74852 .11959 .75495 .12952 .76932 .12433 .76292 .11415 Mtetra
.658 .731 .903 r
.12441 .33708 .1327 .34519 .14416 .34114 .13589 .33301 Mtetra
.653 .73 .906 r
.13589 .33301 .14416 .34114 .15569 .33686 .14741 .32907 Mtetra
.676 .746 .903 r
.14741 .32907 .15569 .33686 .16737 .33177 .15906 .32441 Mtetra
.681 .759 .91 r
.15906 .32441 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.664 .741 .907 r
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20241 .31892 .19425 .31093 Mtetra
.19425 .31093 .20241 .31892 .2142 .3146 .20607 .30657 Mtetra
.656 .739 .911 r
.20607 .30657 .2142 .3146 .22524 .31864 .21792 .30243 Mtetra
.335 .415 .796 r
.21792 .30243 .22524 .31864 .23643 .32228 .22897 .30738 Mtetra
.417 .485 .823 r
.22897 .30738 .23643 .32228 .2482 .3206 .24033 .31015 Mtetra
.583 .657 .888 r
.24033 .31015 .2482 .3206 .2605 .31357 .25223 .30807 Mtetra
.737 .831 .923 r
.25223 .30807 .2605 .31357 .27309 .30336 .26458 .3013 Mtetra
.811 .929 .912 r
.26458 .3013 .27309 .30336 .28575 .29227 .2772 .29171 Mtetra
.824 .963 .898 r
.2772 .29171 .28575 .29227 .29823 .28378 .28991 .28122 Mtetra
.822 .917 .901 r
.28991 .28122 .29823 .28378 .31046 .27929 .30259 .2711 Mtetra
.669 .746 .908 r
.30259 .2711 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.664 .741 .907 r
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.66 .739 .909 r
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18097 Mtetra
.432 .639 .943 r
.54694 .18097 .55407 .18995 .56752 .18502 .5605 .18169 Mtetra
.151 .648 .913 r
.5605 .18169 .56752 .18502 .5811 .18417 .57418 .18281 Mtetra
.086 .638 .821 r
.57418 .18281 .5811 .18417 .59486 .18598 .58797 .18302 Mtetra
.441 .835 .982 r
.58797 .18302 .59486 .18598 .60872 .18692 .6018 .18036 Mtetra
.736 .841 .929 r
.6018 .18036 .60872 .18692 .62259 .18462 .61557 .1729 Mtetra
.791 .735 .801 r
.61557 .1729 .62259 .18462 .63636 .17682 .62922 .16044 Mtetra
.776 .667 .743 r
.62922 .16044 .63636 .17682 .64994 .16354 .64278 .14573 Mtetra
.639 .585 .777 r
.64278 .14573 .64994 .16354 .6635 .14982 .65673 .14033 Mtetra
.664 .741 .907 r
.65673 .14033 .6635 .14982 .67748 .14469 .67076 .13515 Mtetra
.67076 .13515 .67748 .14469 .69153 .13954 .68486 .12995 Mtetra
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.648 .734 .912 r
.69903 .12473 .70565 .13436 .71985 .12915 .71331 .12001 Mtetra
.652 .75 .921 r
.71331 .12001 .71985 .12915 .73417 .12479 .72765 .11513 Mtetra
.673 .746 .906 r
.72765 .11513 .73417 .12479 .74852 .11959 .74202 .10949 Mtetra
.668 .735 .9 r
.74202 .10949 .74852 .11959 .76292 .11415 .75647 .10398 Mtetra
.659 .734 .905 r
.11603 .32902 .12441 .33708 .13589 .33301 .12755 .32487 Mtetra
.652 .731 .907 r
.12755 .32487 .13589 .33301 .14741 .32907 .13909 .32093 Mtetra
.656 .733 .906 r
.13909 .32093 .14741 .32907 .15906 .32441 .1507 .31684 Mtetra
.689 .757 .903 r
.1507 .31684 .15906 .32441 .17078 .31959 .16248 .31171 Mtetra
.668 .745 .908 r
.16248 .31171 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.664 .741 .907 r
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20607 .30657 .19788 .29847 Mtetra
.19788 .29847 .20607 .30657 .21792 .30243 .20979 .29405 Mtetra
.637 .727 .913 r
.20979 .29405 .21792 .30243 .22897 .30738 .22167 .29041 Mtetra
.37 .427 .79 r
.22167 .29041 .22897 .30738 .24033 .31015 .23286 .29477 Mtetra
.436 .49 .817 r
.23286 .29477 .24033 .31015 .25223 .30807 .24435 .29714 Mtetra
.572 .644 .883 r
.24435 .29714 .25223 .30807 .26458 .3013 .2563 .29535 Mtetra
.71 .817 .932 r
.2563 .29535 .26458 .3013 .2772 .29171 .26868 .28943 Mtetra
.784 .928 .93 r
.26868 .28943 .2772 .29171 .28991 .28122 .2813 .28082 Mtetra
.797 .971 .91 r
.2813 .28082 .28991 .28122 .30259 .2711 .29404 .27112 Mtetra
.788 .979 .907 r
.29404 .27112 .30259 .2711 .31492 .26641 .30678 .26145 Mtetra
.77 .857 .915 r
.30678 .26145 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.664 .741 .907 r
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.536 .688 .937 r
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .18015 Mtetra
.36 .709 .986 r
.52629 .18015 .53352 .18578 .54694 .18097 .53979 .18032 Mtetra
.028 .599 .757 r
.53979 .18032 .54694 .18097 .5605 .18169 .55342 .18055 Mtetra
.168 .7 .847 r
.55342 .18055 .5605 .18169 .57418 .18281 .56714 .17967 Mtetra
.514 .866 .99 r
.56714 .17967 .57418 .18281 .58797 .18302 .58091 .17606 Mtetra
.744 .832 .918 r
.58091 .17606 .58797 .18302 .6018 .18036 .59467 .16823 Mtetra
.782 .726 .8 r
.59467 .16823 .6018 .18036 .61557 .1729 .60836 .15612 Mtetra
.767 .659 .743 r
.60836 .15612 .61557 .1729 .62922 .16044 .62198 .14194 Mtetra
.645 .581 .768 r
.62198 .14194 .62922 .16044 .64278 .14573 .63589 .13595 Mtetra
.663 .734 .903 r
.63589 .13595 .64278 .14573 .65673 .14033 .6499 .13076 Mtetra
.664 .741 .907 r
.6499 .13076 .65673 .14033 .67076 .13515 .66398 .12553 Mtetra
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.66 .739 .908 r
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11513 Mtetra
.64 .734 .917 r
.69235 .11513 .69903 .12473 .71331 .12001 .7067 .11064 Mtetra
.671 .754 .913 r
.7067 .11064 .71331 .12001 .72765 .11513 .72105 .10508 Mtetra
.674 .739 .9 r
.72105 .10508 .72765 .11513 .74202 .10949 .73546 .09935 Mtetra
.667 .736 .901 r
.73546 .09935 .74202 .10949 .75647 .10398 .74996 .09384 Mtetra
.661 .737 .906 r
.10758 .32099 .11603 .32902 .12755 .32487 .11913 .31675 Mtetra
.655 .734 .907 r
.11913 .31675 .12755 .32487 .13909 .32093 .13071 .31267 Mtetra
.651 .73 .907 r
.13071 .31267 .13909 .32093 .1507 .31684 .14233 .30869 Mtetra
.661 .737 .906 r
.14233 .30869 .1507 .31684 .16248 .31171 .15404 .3044 Mtetra
.692 .767 .909 r
.15404 .3044 .16248 .31171 .17424 .30724 .16591 .29914 Mtetra
.664 .741 .907 r
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20979 .29405 .20156 .28584 Mtetra
.20156 .28584 .20979 .29405 .22167 .29041 .21355 .28137 Mtetra
.655 .718 .895 r
.21355 .28137 .22167 .29041 .23286 .29477 .22557 .27712 Mtetra
.402 .439 .784 r
.22557 .27712 .23286 .29477 .24435 .29714 .23691 .2808 Mtetra
.444 .482 .805 r
.23691 .2808 .24435 .29714 .2563 .29535 .2485 .28311 Mtetra
.544 .606 .866 r
.2485 .28311 .2563 .29535 .26868 .28943 .26047 .2821 Mtetra
.664 .771 .93 r
.26047 .2821 .26868 .28943 .2813 .28082 .27281 .27753 Mtetra
.743 .903 .949 r
.27281 .27753 .2813 .28082 .29404 .27112 .28542 .27033 Mtetra
.761 .965 .93 r
.28542 .27033 .29404 .27112 .30678 .26145 .29816 .26176 Mtetra
.748 .982 .911 r
.29816 .26176 .30678 .26145 .31944 .25336 .31096 .25284 Mtetra
.754 .972 .926 r
.31096 .25284 .31944 .25336 .33191 .24874 .32376 .24421 Mtetra
.768 .874 .925 r
.32376 .24421 .33191 .24874 .34444 .24409 .33655 .23615 Mtetra
.686 .766 .912 r
.33655 .23615 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.664 .741 .907 r
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.642 .733 .915 r
.46561 .1873 .47307 .19636 .48628 .19146 .47884 .18306 Mtetra
.532 .707 .951 r
.47884 .18306 .48628 .19146 .49955 .18654 .49212 .1815 Mtetra
.416 .76 .995 r
.49212 .1815 .49955 .18654 .51289 .18159 .50549 .18053 Mtetra
.144 .684 .834 r
.50549 .18053 .51289 .18159 .52629 .18015 .51896 .17986 Mtetra
.117 .668 .783 r
.51896 .17986 .52629 .18015 .53979 .18032 .53254 .17884 Mtetra
.33 .802 .918 r
.53254 .17884 .53979 .18032 .55342 .18055 .54621 .17645 Mtetra
.627 .884 .988 r
.54621 .17645 .55342 .18055 .56714 .17967 .55994 .17139 Mtetra
.758 .799 .886 r
.55994 .17139 .56714 .17967 .58091 .17606 .57368 .16267 Mtetra
.771 .703 .787 r
.57368 .16267 .58091 .17606 .59467 .16823 .58738 .15055 Mtetra
.753 .644 .74 r
.58738 .15055 .59467 .16823 .60836 .15612 .60105 .137 Mtetra
.633 .569 .765 r
.60105 .137 .60836 .15612 .62198 .14194 .61496 .13156 Mtetra
.662 .72 .892 r
.61496 .13156 .62198 .14194 .63589 .13595 .62895 .12634 Mtetra
.664 .741 .907 r
.62895 .12634 .63589 .13595 .6499 .13076 .643 .12109 Mtetra
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.637 .73 .915 r
.67133 .11052 .67813 .12028 .69235 .11513 .68565 .10608 Mtetra
.667 .762 .921 r
.68565 .10608 .69235 .11513 .7067 .11064 .69999 .10066 Mtetra
.674 .742 .901 r
.69999 .10066 .7067 .11064 .72105 .10508 .71438 .09489 Mtetra
.671 .737 .9 r
.71438 .09489 .72105 .10508 .73546 .09935 .72885 .08921 Mtetra
.666 .737 .903 r
.72885 .08921 .73546 .09935 .74996 .09384 .74341 .0837 Mtetra
.663 .739 .907 r
.09904 .31296 .10758 .32099 .11913 .31675 .11062 .30864 Mtetra
.659 .737 .907 r
.11062 .30864 .11913 .31675 .13071 .31267 .12225 .30441 Mtetra
.654 .733 .907 r
.12225 .30441 .13071 .31267 .14233 .30869 .13391 .30031 Mtetra
.652 .73 .906 r
.13391 .30031 .14233 .30869 .15404 .3044 .14561 .29625 Mtetra
.666 .741 .906 r
.14561 .29625 .15404 .3044 .16591 .29914 .15743 .29177 Mtetra
.69 .768 .911 r
.15743 .29177 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.664 .741 .907 r
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21355 .28137 .20528 .27305 Mtetra
.20528 .27305 .21355 .28137 .22557 .27712 .21736 .26851 Mtetra
.663 .734 .903 r
.21736 .26851 .22557 .27712 .23691 .2808 .2295 .26396 Mtetra
.474 .493 .798 r
.2295 .26396 .23691 .2808 .2485 .28311 .24113 .26544 Mtetra
.451 .47 .788 r
.24113 .26544 .2485 .28311 .26047 .2821 .2528 .26772 Mtetra
.514 .554 .835 r
.2528 .26772 .26047 .2821 .27281 .27753 .26477 .2677 Mtetra
.605 .689 .902 r
.26477 .2677 .27281 .27753 .28542 .27033 .27707 .26479 Mtetra
.685 .833 .954 r
.27707 .26479 .28542 .27033 .29816 .26176 .28962 .25943 Mtetra
.718 .93 .96 r
.28962 .25943 .29816 .26176 .31096 .25284 .30234 .25248 Mtetra
.705 .968 .934 r
.30234 .25248 .31096 .25284 .32376 .24421 .31515 .24481 Mtetra
.674 .972 .909 r
.31515 .24481 .32376 .24421 .33655 .23615 .328 .23701 Mtetra
.642 .965 .897 r
.328 .23701 .33655 .23615 .34921 .23073 .34087 .2295 Mtetra
.692 .954 .952 r
.34087 .2295 .34921 .23073 .3619 .226 .35376 .22244 Mtetra
.709 .902 .965 r
.35376 .22244 .3619 .226 .37465 .22124 .36665 .21593 Mtetra
.7 .85 .955 r
.36665 .21593 .37465 .22124 .38745 .21646 .37957 .20997 Mtetra
.683 .813 .945 r
.37957 .20997 .38745 .21646 .40032 .21166 .39251 .20456 Mtetra
.664 .791 .942 r
.39251 .20456 .40032 .21166 .41325 .20683 .40548 .1997 Mtetra
.643 .785 .949 r
.40548 .1997 .41325 .20683 .42625 .20199 .41851 .19537 Mtetra
.616 .793 .966 r
.41851 .19537 .42625 .20199 .4393 .19711 .43158 .1916 Mtetra
.574 .813 .989 r
.43158 .1916 .4393 .19711 .45242 .19222 .44471 .18839 Mtetra
.491 .832 .998 r
.44471 .18839 .45242 .19222 .46561 .1873 .4579 .18573 Mtetra
.329 .799 .924 r
.4579 .18573 .46561 .1873 .47884 .18306 .47117 .18354 Mtetra
.147 .691 .758 r
.47117 .18354 .47884 .18306 .49212 .1815 .48453 .18164 Mtetra
.181 .716 .791 r
.48453 .18164 .49212 .1815 .50549 .18053 .49798 .17963 Mtetra
.324 .805 .894 r
.49798 .17963 .50549 .18053 .51896 .17986 .51153 .17688 Mtetra
.557 .887 .988 r
.51153 .17688 .51896 .17986 .53254 .17884 .52517 .17253 Mtetra
.717 .843 .942 r
.52517 .17253 .53254 .17884 .54621 .17645 .53887 .16569 Mtetra
.759 .744 .838 r
.53887 .16569 .54621 .17645 .55994 .17139 .5526 .15589 Mtetra
.754 .668 .767 r
.5526 .15589 .55994 .17139 .57368 .16267 .56632 .14373 Mtetra
.719 .616 .741 r
.56632 .14373 .57368 .16267 .58738 .15055 .58006 .13236 Mtetra
.632 .579 .776 r
.58006 .13236 .58738 .15055 .60105 .137 .59395 .12714 Mtetra
.663 .734 .903 r
.59395 .12714 .60105 .137 .61496 .13156 .60791 .1219 Mtetra
.664 .741 .907 r
.60791 .1219 .61496 .13156 .62895 .12634 .62194 .11663 Mtetra
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.64 .731 .914 r
.65022 .10602 .65713 .11582 .67133 .11052 .66451 .10148 Mtetra
.663 .762 .923 r
.66451 .10148 .67133 .11052 .68565 .10608 .67883 .09617 Mtetra
.674 .745 .904 r
.67883 .09617 .68565 .10608 .69999 .10066 .69321 .09039 Mtetra
.671 .736 .899 r
.69321 .09039 .69999 .10066 .71438 .09489 .70766 .08466 Mtetra
.667 .737 .902 r
.70766 .08466 .71438 .09489 .72885 .08921 .72219 .07906 Mtetra
.665 .739 .905 r
.72219 .07906 .72885 .08921 .74341 .0837 .7368 .07355 Mtetra
.663 .74 .907 r
.09042 .30489 .09904 .31296 .11062 .30864 .10204 .30052 Mtetra
.662 .739 .907 r
.10204 .30052 .11062 .30864 .12225 .30441 .1137 .29617 Mtetra
.659 .736 .907 r
.1137 .29617 .12225 .30441 .13391 .30031 .12541 .2919 Mtetra
.653 .732 .907 r
.12541 .2919 .13391 .30031 .14561 .29625 .13715 .28776 Mtetra
.653 .73 .906 r
.13715 .28776 .14561 .29625 .15743 .29177 .14895 .28362 Mtetra
.667 .744 .907 r
.14895 .28362 .15743 .29177 .16938 .28653 .16085 .27902 Mtetra
.689 .767 .911 r
.16085 .27902 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.664 .741 .907 r
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21736 .26851 .20905 .26009 Mtetra
.20905 .26009 .21736 .26851 .2295 .26396 .22122 .25549 Mtetra
.22122 .25549 .2295 .26396 .24113 .26544 .23345 .25087 Mtetra
.579 .584 .822 r
.23345 .25087 .24113 .26544 .2528 .26772 .2455 .24875 Mtetra
.468 .466 .772 r
.2455 .24875 .2528 .26772 .26477 .2677 .25729 .25063 Mtetra
.498 .507 .797 r
.25729 .25063 .26477 .2677 .27707 .26479 .26927 .25134 Mtetra
.552 .593 .848 r
.26927 .25134 .27707 .26479 .28962 .25943 .28152 .25004 Mtetra
.616 .708 .911 r
.28152 .25004 .28962 .25943 .30234 .25248 .294 .24672 Mtetra
.665 .825 .96 r
.294 .24672 .30234 .25248 .31515 .24481 .30667 .2418 Mtetra
.677 .909 .975 r
.30667 .2418 .31515 .24481 .328 .23701 .31946 .23589 Mtetra
.652 .946 .957 r
.31946 .23589 .328 .23701 .34087 .2295 .33234 .22953 Mtetra
.605 .947 .924 r
.33234 .22953 .34087 .2295 .35376 .22244 .34526 .22311 Mtetra
.553 .931 .893 r
.34526 .22311 .35376 .22244 .36665 .21593 .35822 .21691 Mtetra
.501 .909 .869 r
.35822 .21691 .36665 .21593 .37957 .20997 .37121 .21107 Mtetra
.451 .883 .849 r
.37121 .21107 .37957 .20997 .39251 .20456 .38423 .20568 Mtetra
.402 .857 .832 r
.38423 .20568 .39251 .20456 .40548 .1997 .39729 .20078 Mtetra
.356 .83 .817 r
.39729 .20078 .40548 .1997 .41851 .19537 .41039 .19636 Mtetra
.317 .806 .807 r
.41039 .19636 .41851 .19537 .43158 .1916 .42355 .1924 Mtetra
.292 .791 .806 r
.42355 .1924 .43158 .1916 .44471 .18839 .43677 .18881 Mtetra
.297 .794 .826 r
.43677 .18881 .44471 .18839 .4579 .18573 .45006 .18543 Mtetra
.35 .824 .878 r
.45006 .18543 .4579 .18573 .47117 .18354 .46343 .18201 Mtetra
.464 .873 .95 r
.46343 .18201 .47117 .18354 .48453 .18164 .47688 .17813 Mtetra
.608 .891 .989 r
.47688 .17813 .48453 .18164 .49798 .17963 .49043 .17324 Mtetra
.707 .837 .944 r
.49043 .17324 .49798 .17963 .51153 .17688 .50406 .16674 Mtetra
.742 .751 .859 r
.50406 .16674 .51153 .17688 .52517 .17253 .51774 .15817 Mtetra
.743 .678 .788 r
.51774 .15817 .52517 .17253 .53887 .16569 .53146 .14755 Mtetra
.731 .629 .746 r
.53146 .14755 .53887 .16569 .5526 .15589 .54519 .13571 Mtetra
.665 .577 .747 r
.54519 .13571 .5526 .15589 .56632 .14373 .55897 .12795 Mtetra
.642 .614 .807 r
.55897 .12795 .56632 .14373 .58006 .13236 .57284 .12271 Mtetra
.664 .741 .907 r
.57284 .12271 .58006 .13236 .59395 .12714 .58678 .11744 Mtetra
.58678 .11744 .59395 .12714 .60791 .1219 .60079 .11215 Mtetra
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.641 .731 .914 r
.62902 .10149 .63605 .11134 .65022 .10602 .64328 .09691 Mtetra
.661 .76 .923 r
.64328 .09691 .65022 .10602 .66451 .10148 .65758 .09162 Mtetra
.674 .747 .906 r
.65758 .09162 .66451 .10148 .67883 .09617 .67194 .08586 Mtetra
.672 .737 .899 r
.67194 .08586 .67883 .09617 .69321 .09039 .68637 .08009 Mtetra
.668 .736 .901 r
.68637 .08009 .69321 .09039 .70766 .08466 .70088 .07444 Mtetra
.665 .738 .904 r
.70088 .07444 .70766 .08466 .72219 .07906 .71546 .06887 Mtetra
.664 .74 .906 r
.71546 .06887 .72219 .07906 .7368 .07355 .73013 .06332 Mtetra
.664 .741 .907 r
.08174 .29677 .09042 .30489 .10204 .30052 .09338 .29235 Mtetra
.663 .74 .907 r
.09338 .29235 .10204 .30052 .1137 .29617 .10508 .28792 Mtetra
.662 .739 .907 r
.10508 .28792 .1137 .29617 .12541 .2919 .11683 .28352 Mtetra
.658 .736 .907 r
.11683 .28352 .12541 .2919 .13715 .28776 .12862 .27921 Mtetra
.654 .731 .906 r
.12862 .27921 .13715 .28776 .14895 .28362 .14044 .275 Mtetra
.653 .73 .906 r
.14044 .275 .14895 .28362 .16085 .27902 .15233 .27079 Mtetra
.667 .744 .908 r
.15233 .27079 .16085 .27902 .17289 .27374 .16432 .26616 Mtetra
.69 .768 .911 r
.16432 .26616 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.664 .741 .907 r
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22122 .25549 .21288 .24695 Mtetra
.21288 .24695 .22122 .25549 .23345 .25087 .22514 .24229 Mtetra
.22514 .24229 .23345 .25087 .2455 .24875 .23745 .23761 Mtetra
.656 .681 .862 r
.23745 .23761 .2455 .24875 .25729 .25063 .24983 .23291 Mtetra
.546 .527 .785 r
.24983 .23291 .25729 .25063 .26927 .25134 .26195 .23189 Mtetra
.504 .484 .768 r
.26195 .23189 .26927 .25134 .28152 .25004 .27402 .23253 Mtetra
.528 .521 .791 r
.27402 .23253 .28152 .25004 .294 .24672 .28626 .23218 Mtetra
.564 .583 .831 r
.28626 .23218 .294 .24672 .30667 .2418 .2987 .23047 Mtetra
.603 .662 .88 r
.2987 .23047 .30667 .2418 .31946 .23589 .31132 .22748 Mtetra
.636 .745 .927 r
.31132 .22748 .31946 .23589 .33234 .22953 .32407 .22347 Mtetra
.652 .819 .963 r
.32407 .22347 .33234 .22953 .34526 .22311 .33694 .2188 Mtetra
.649 .871 .982 r
.33694 .2188 .34526 .22311 .35822 .21691 .34989 .21378 Mtetra
.629 .9 .986 r
.34989 .21378 .35822 .21691 .37121 .21107 .3629 .20866 Mtetra
.604 .91 .981 r
.3629 .20866 .37121 .21107 .38423 .20568 .37598 .20359 Mtetra
.582 .91 .977 r
.37598 .20359 .38423 .20568 .39729 .20078 .3891 .19864 Mtetra
.572 .907 .977 r
.3891 .19864 .39729 .20078 .41039 .19636 .40229 .19383 Mtetra
.581 .902 .983 r
.40229 .19383 .41039 .19636 .42355 .1924 .41554 .18907 Mtetra
.608 .893 .989 r
.41554 .18907 .42355 .1924 .43677 .18881 .42886 .18421 Mtetra
.65 .871 .982 r
.42886 .18421 .43677 .18881 .45006 .18543 .44226 .17899 Mtetra
.689 .829 .95 r
.44226 .17899 .45006 .18543 .46343 .18201 .45574 .17311 Mtetra
.714 .77 .896 r
.45574 .17311 .46343 .18201 .47688 .17813 .46929 .16619 Mtetra
.723 .708 .836 r
.46929 .16619 .47688 .17813 .49043 .17324 .48292 .15796 Mtetra
.721 .657 .785 r
.48292 .15796 .49043 .17324 .50406 .16674 .49659 .14835 Mtetra
.714 .619 .75 r
.49659 .14835 .50406 .16674 .51774 .15817 .5103 .13772 Mtetra
.68 .583 .74 r
.5103 .13772 .51774 .15817 .53146 .14755 .52403 .12875 Mtetra
.629 .571 .771 r
.52403 .12875 .53146 .14755 .54519 .13571 .5378 .12352 Mtetra
.656 .681 .862 r
.5378 .12352 .54519 .13571 .55897 .12795 .55165 .11826 Mtetra
.664 .741 .907 r
.55165 .11826 .55897 .12795 .57284 .12271 .56557 .11297 Mtetra
.56557 .11297 .57284 .12271 .58678 .11744 .57955 .10766 Mtetra
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.639 .731 .915 r
.60774 .09695 .61487 .10684 .62902 .10149 .62196 .09237 Mtetra
.662 .761 .923 r
.62196 .09237 .62902 .10149 .64328 .09691 .63624 .08703 Mtetra
.673 .747 .906 r
.63624 .08703 .64328 .09691 .65758 .09162 .65058 .08126 Mtetra
.672 .736 .899 r
.65058 .08126 .65758 .09162 .67194 .08586 .66499 .07547 Mtetra
.668 .735 .9 r
.66499 .07547 .67194 .08586 .68637 .08009 .67947 .0698 Mtetra
.665 .738 .904 r
.67947 .0698 .68637 .08009 .70088 .07444 .69403 .06419 Mtetra
.664 .74 .906 r
.69403 .06419 .70088 .07444 .71546 .06887 .70868 .05861 Mtetra
.664 .74 .907 r
.70868 .05861 .71546 .06887 .73013 .06332 .72339 .05302 Mtetra
.664 .741 .907 r
.07297 .28858 .08174 .29677 .09338 .29235 .08465 .28412 Mtetra
.08465 .28412 .09338 .29235 .10508 .28792 .09638 .27964 Mtetra
.663 .74 .907 r
.09638 .27964 .10508 .28792 .11683 .28352 .10816 .27516 Mtetra
.662 .739 .907 r
.10816 .27516 .11683 .28352 .12862 .27921 .11999 .27071 Mtetra
.658 .735 .906 r
.11999 .27071 .12862 .27921 .14044 .275 .13187 .26632 Mtetra
.654 .731 .905 r
.13187 .26632 .14044 .275 .15233 .27079 .14379 .26204 Mtetra
.653 .73 .905 r
.14379 .26204 .15233 .27079 .16432 .26616 .15576 .25776 Mtetra
.663 .742 .909 r
.15576 .25776 .16432 .26616 .17644 .26079 .16782 .25316 Mtetra
.689 .769 .913 r
.16782 .25316 .17644 .26079 .18853 .2562 .18003 .24779 Mtetra
.668 .745 .908 r
.18003 .24779 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.664 .741 .907 r
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22514 .24229 .21675 .23364 Mtetra
.21675 .23364 .22514 .24229 .23745 .23761 .2291 .22892 Mtetra
.2291 .22892 .23745 .23761 .24983 .23291 .24152 .22417 Mtetra
.24152 .22417 .24983 .23291 .26195 .23189 .25399 .21941 Mtetra
.651 .657 .842 r
.25399 .21941 .26195 .23189 .27402 .23253 .26652 .21462 Mtetra
.587 .549 .779 r
.26652 .21462 .27402 .23253 .28626 .23218 .27894 .21184 Mtetra
.536 .495 .758 r
.27894 .21184 .28626 .23218 .2987 .23047 .29128 .21117 Mtetra
.549 .514 .769 r
.29128 .21117 .2987 .23047 .31132 .22748 .30375 .20992 Mtetra
.57 .546 .789 r
.30375 .20992 .31132 .22748 .32407 .22347 .31637 .20786 Mtetra
.592 .584 .813 r
.31637 .20786 .32407 .22347 .33694 .2188 .32913 .205 Mtetra
.613 .623 .837 r
.32913 .205 .33694 .2188 .34989 .21378 .34201 .20143 Mtetra
.632 .658 .858 r
.34201 .20143 .34989 .21378 .3629 .20866 .35499 .19729 Mtetra
.646 .685 .872 r
.35499 .19729 .3629 .20866 .37598 .20359 .36807 .19269 Mtetra
.658 .7 .877 r
.36807 .19269 .37598 .20359 .3891 .19864 .38123 .18771 Mtetra
.668 .704 .874 r
.38123 .18771 .3891 .19864 .40229 .19383 .39447 .18232 Mtetra
.676 .696 .861 r
.39447 .18232 .40229 .19383 .41554 .18907 .40779 .17648 Mtetra
.683 .679 .84 r
.40779 .17648 .41554 .18907 .42886 .18421 .42119 .17006 Mtetra
.688 .657 .813 r
.42119 .17006 .42886 .18421 .44226 .17899 .43467 .16293 Mtetra
.691 .632 .786 r
.43467 .16293 .44226 .17899 .45574 .17311 .44821 .15497 Mtetra
.69 .609 .76 r
.44821 .15497 .45574 .17311 .46929 .16619 .46181 .14619 Mtetra
.688 .591 .741 r
.46181 .14619 .46929 .16619 .48292 .15796 .47546 .13681 Mtetra
.652 .562 .74 r
.47546 .13681 .48292 .15796 .49659 .14835 .48911 .12955 Mtetra
.629 .571 .771 r
.48911 .12955 .49659 .14835 .5103 .13772 .50279 .12432 Mtetra
.651 .657 .842 r
.50279 .12432 .5103 .13772 .52403 .12875 .51654 .11907 Mtetra
.664 .741 .907 r
.51654 .11907 .52403 .12875 .5378 .12352 .53037 .11378 Mtetra
.53037 .11378 .5378 .12352 .55165 .11826 .54426 .10848 Mtetra
.54426 .10848 .55165 .11826 .56557 .11297 .55822 .10314 Mtetra
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.66 .739 .908 r
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09251 Mtetra
.641 .735 .917 r
.58636 .09251 .59361 .10232 .60774 .09695 .60056 .08786 Mtetra
.665 .764 .924 r
.60056 .08786 .60774 .09695 .62196 .09237 .61481 .0824 Mtetra
.673 .746 .905 r
.61481 .0824 .62196 .09237 .63624 .08703 .62912 .07661 Mtetra
.671 .736 .898 r
.62912 .07661 .63624 .08703 .65058 .08126 .64351 .07082 Mtetra
.668 .735 .9 r
.64351 .07082 .65058 .08126 .66499 .07547 .65797 .06512 Mtetra
.665 .737 .904 r
.65797 .06512 .66499 .07547 .67947 .0698 .67251 .05949 Mtetra
.664 .739 .906 r
.67251 .05949 .67947 .0698 .69403 .06419 .68713 .05388 Mtetra
.664 .74 .907 r
.68713 .05388 .69403 .06419 .70868 .05861 .70182 .04826 Mtetra
.664 .741 .907 r
.70182 .04826 .70868 .05861 .72339 .05302 .7166 .04261 Mtetra
.06413 .28033 .07297 .28858 .08465 .28412 .07584 .27583 Mtetra
.07584 .27583 .08465 .28412 .09638 .27964 .0876 .27131 Mtetra
.0876 .27131 .09638 .27964 .10816 .27516 .09942 .26677 Mtetra
.663 .74 .907 r
.09942 .26677 .10816 .27516 .11999 .27071 .11128 .26223 Mtetra
.662 .739 .907 r
.11128 .26223 .11999 .27071 .13187 .26632 .1232 .25771 Mtetra
.659 .735 .906 r
.1232 .25771 .13187 .26632 .14379 .26204 .13517 .25325 Mtetra
.655 .731 .905 r
.13517 .25325 .14379 .26204 .15576 .25776 .14718 .24887 Mtetra
.653 .729 .905 r
.14718 .24887 .15576 .25776 .16782 .25316 .15924 .24452 Mtetra
.66 .738 .908 r
.15924 .24452 .16782 .25316 .18003 .24779 .17138 .23998 Mtetra
.678 .765 .917 r
.17138 .23998 .18003 .24779 .19222 .24301 .18364 .23489 Mtetra
.681 .759 .91 r
.18364 .23489 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.664 .741 .907 r
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24152 .22417 .23313 .21536 Mtetra
.23313 .21536 .24152 .22417 .25399 .21941 .24563 .21055 Mtetra
.24563 .21055 .25399 .21941 .26652 .21462 .2582 .20572 Mtetra
.2582 .20572 .26652 .21462 .27894 .21184 .27082 .20086 Mtetra
.658 .692 .871 r
.27082 .20086 .27894 .21184 .29128 .21117 .28351 .19599 Mtetra
.64 .613 .807 r
.28351 .19599 .29128 .21117 .30375 .20992 .29626 .19108 Mtetra
.611 .555 .767 r
.29626 .19108 .30375 .20992 .31637 .20786 .30902 .18693 Mtetra
.575 .515 .751 r
.30902 .18693 .31637 .20786 .32913 .205 .32173 .18433 Mtetra
.586 .524 .752 r
.32173 .18433 .32913 .205 .34201 .20143 .33457 .18118 Mtetra
.599 .536 .756 r
.33457 .18118 .34201 .20143 .35499 .19729 .34751 .17743 Mtetra
.612 .548 .758 r
.34751 .17743 .35499 .19729 .36807 .19269 .36057 .17304 Mtetra
.624 .557 .759 r
.36057 .17304 .36807 .19269 .38123 .18771 .37373 .168 Mtetra
.635 .563 .756 r
.37373 .168 .38123 .18771 .39447 .18232 .38698 .16231 Mtetra
.644 .565 .751 r
.38698 .16231 .39447 .18232 .40779 .17648 .40031 .15596 Mtetra
.651 .565 .745 r
.40031 .15596 .40779 .17648 .42119 .17006 .41373 .14901 Mtetra
.656 .564 .739 r
.41373 .14901 .42119 .17006 .43467 .16293 .42721 .14151 Mtetra
.631 .547 .741 r
.42721 .14151 .43467 .16293 .44821 .15497 .44069 .13555 Mtetra
.626 .563 .764 r
.44069 .13555 .44821 .15497 .46181 .14619 .45422 .13035 Mtetra
.64 .613 .807 r
.45422 .13035 .46181 .14619 .47546 .13681 .46781 .12513 Mtetra
.658 .692 .871 r
.46781 .12513 .47546 .13681 .48911 .12955 .48147 .11988 Mtetra
.664 .741 .907 r
.48147 .11988 .48911 .12955 .50279 .12432 .49519 .1146 Mtetra
.49519 .1146 .50279 .12432 .51654 .11907 .50899 .10929 Mtetra
.50899 .10929 .51654 .11907 .53037 .11378 .52286 .10396 Mtetra
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.648 .735 .912 r
.5508 .09322 .55822 .10314 .57225 .09778 .56489 .08835 Mtetra
.652 .75 .921 r
.56489 .08835 .57225 .09778 .58636 .09251 .57905 .08331 Mtetra
.669 .764 .921 r
.57905 .08331 .58636 .09251 .60056 .08786 .59328 .07771 Mtetra
.672 .742 .903 r
.59328 .07771 .60056 .08786 .61481 .0824 .60757 .0719 Mtetra
.67 .734 .898 r
.60757 .0719 .61481 .0824 .62912 .07661 .62194 .06612 Mtetra
.667 .735 .9 r
.62194 .06612 .62912 .07661 .64351 .07082 .63638 .06041 Mtetra
.665 .737 .904 r
.63638 .06041 .64351 .07082 .65797 .06512 .65089 .05477 Mtetra
.664 .739 .906 r
.65089 .05477 .65797 .06512 .67251 .05949 .66549 .04913 Mtetra
.664 .74 .907 r
.66549 .04913 .67251 .05949 .68713 .05388 .68016 .04349 Mtetra
.664 .741 .907 r
.68016 .04349 .68713 .05388 .70182 .04826 .69491 .03782 Mtetra
.69491 .03782 .70182 .04826 .7166 .04261 .70973 .03212 Mtetra
.05522 .27201 .06413 .28033 .07584 .27583 .06696 .26746 Mtetra
.06696 .26746 .07584 .27583 .0876 .27131 .07875 .2629 Mtetra
.07875 .2629 .0876 .27131 .09942 .26677 .09059 .25832 Mtetra
.09059 .25832 .09942 .26677 .11128 .26223 .10249 .25372 Mtetra
.663 .74 .907 r
.10249 .25372 .11128 .26223 .1232 .25771 .11445 .24912 Mtetra
.662 .739 .907 r
.11445 .24912 .1232 .25771 .13517 .25325 .12646 .24452 Mtetra
.66 .736 .906 r
.12646 .24452 .13517 .25325 .14718 .24887 .13851 .23998 Mtetra
.657 .732 .905 r
.13851 .23998 .14718 .24887 .15924 .24452 .15062 .2355 Mtetra
.654 .729 .904 r
.15062 .2355 .15924 .24452 .17138 .23998 .16277 .23107 Mtetra
.656 .733 .906 r
.16277 .23107 .17138 .23998 .18364 .23489 .17499 .22656 Mtetra
.667 .752 .914 r
.17499 .22656 .18364 .23489 .19597 .22964 .1873 .22173 Mtetra
.684 .768 .915 r
.1873 .22173 .19597 .22964 .20829 .2249 .19973 .21636 Mtetra
.673 .75 .909 r
.19973 .21636 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.664 .741 .907 r
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2582 .20572 .2498 .19674 Mtetra
.2498 .19674 .2582 .20572 .27082 .20086 .26247 .19184 Mtetra
.26247 .19184 .27082 .20086 .28351 .19599 .27519 .18692 Mtetra
.27519 .18692 .28351 .19599 .29626 .19108 .28798 .18197 Mtetra
.28798 .18197 .29626 .19108 .30902 .18693 .30083 .177 Mtetra
.662 .722 .893 r
.30083 .177 .30902 .18693 .32173 .18433 .31374 .17201 Mtetra
.653 .669 .853 r
.31374 .17201 .32173 .18433 .33457 .18118 .32671 .16699 Mtetra
.646 .635 .825 r
.32671 .16699 .33457 .18118 .34751 .17743 .33975 .16195 Mtetra
.64 .614 .807 r
.33975 .16195 .34751 .17743 .36057 .17304 .35285 .15688 Mtetra
.638 .604 .799 r
.35285 .15688 .36057 .17304 .37373 .168 .36602 .15178 Mtetra
.36602 .15178 .37373 .168 .38698 .16231 .37925 .14667 Mtetra
.64 .614 .807 r
.37925 .14667 .38698 .16231 .40031 .15596 .39255 .14152 Mtetra
.646 .635 .825 r
.39255 .14152 .40031 .15596 .41373 .14901 .40592 .13635 Mtetra
.653 .669 .853 r
.40592 .13635 .41373 .14901 .42721 .14151 .41935 .13116 Mtetra
.662 .722 .893 r
.41935 .13116 .42721 .14151 .44069 .13555 .43285 .12593 Mtetra
.664 .741 .907 r
.43285 .12593 .44069 .13555 .45422 .13035 .44641 .12069 Mtetra
.44641 .12069 .45422 .13035 .46781 .12513 .46005 .11541 Mtetra
.46005 .11541 .46781 .12513 .48147 .11988 .47375 .11011 Mtetra
.47375 .11011 .48147 .11988 .49519 .1146 .48753 .10478 Mtetra
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.656 .738 .91 r
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08891 Mtetra
.646 .741 .918 r
.52926 .08891 .5368 .0986 .5508 .09322 .54333 .08408 Mtetra
.663 .763 .924 r
.54333 .08408 .5508 .09322 .56489 .08835 .55746 .07868 Mtetra
.671 .754 .912 r
.55746 .07868 .56489 .08835 .57905 .08331 .57166 .07296 Mtetra
.671 .738 .9 r
.57166 .07296 .57905 .08331 .59328 .07771 .58593 .06715 Mtetra
.669 .734 .898 r
.58593 .06715 .59328 .07771 .60757 .0719 .60027 .06138 Mtetra
.667 .735 .901 r
.60027 .06138 .60757 .0719 .62194 .06612 .61469 .05568 Mtetra
.665 .737 .904 r
.61469 .05568 .62194 .06612 .63638 .06041 .62918 .05002 Mtetra
.664 .739 .906 r
.62918 .05002 .63638 .06041 .65089 .05477 .64375 .04436 Mtetra
.664 .74 .907 r
.64375 .04436 .65089 .05477 .66549 .04913 .6584 .03869 Mtetra
.664 .741 .907 r
.6584 .03869 .66549 .04913 .68016 .04349 .67312 .03299 Mtetra
.67312 .03299 .68016 .04349 .69491 .03782 .68792 .02727 Mtetra
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02152 Mtetra
.04623 .26361 .05522 .27201 .06696 .26746 .05799 .25903 Mtetra
.05799 .25903 .06696 .26746 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25832 .08169 .24981 Mtetra
.08169 .24981 .09059 .25832 .10249 .25372 .09362 .24516 Mtetra
.09362 .24516 .10249 .25372 .11445 .24912 .10561 .2405 Mtetra
.663 .74 .907 r
.10561 .2405 .11445 .24912 .12646 .24452 .11766 .23583 Mtetra
.663 .739 .907 r
.11766 .23583 .12646 .24452 .13851 .23998 .12976 .23116 Mtetra
.661 .736 .906 r
.12976 .23116 .13851 .23998 .15062 .2355 .1419 .22652 Mtetra
.658 .733 .905 r
.1419 .22652 .15062 .2355 .16277 .23107 .1541 .22194 Mtetra
.655 .729 .904 r
.1541 .22194 .16277 .23107 .17499 .22656 .16635 .21743 Mtetra
.653 .73 .905 r
.16635 .21743 .17499 .22656 .1873 .22173 .17865 .21295 Mtetra
.656 .74 .912 r
.17865 .21295 .1873 .22173 .19973 .21636 .19102 .20836 Mtetra
.665 .764 .924 r
.19102 .20836 .19973 .21636 .21218 .21129 .20348 .20353 Mtetra
.678 .775 .923 r
.20348 .20353 .21218 .21129 .22466 .20646 .21604 .19827 Mtetra
.689 .767 .911 r
.21604 .19827 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.664 .741 .907 r
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28798 .18197 .27962 .17278 Mtetra
.27962 .17278 .28798 .18197 .30083 .177 .29251 .16776 Mtetra
.29251 .16776 .30083 .177 .31374 .17201 .30546 .16272 Mtetra
.30546 .16272 .31374 .17201 .32671 .16699 .31847 .15766 Mtetra
.31847 .15766 .32671 .16699 .33975 .16195 .33155 .15257 Mtetra
.33155 .15257 .33975 .16195 .35285 .15688 .34469 .14745 Mtetra
.34469 .14745 .35285 .15688 .36602 .15178 .3579 .14231 Mtetra
.3579 .14231 .36602 .15178 .37925 .14667 .37117 .13715 Mtetra
.37117 .13715 .37925 .14667 .39255 .14152 .38451 .13196 Mtetra
.38451 .13196 .39255 .14152 .40592 .13635 .39792 .12674 Mtetra
.39792 .12674 .40592 .13635 .41935 .13116 .41139 .1215 Mtetra
.41139 .1215 .41935 .13116 .43285 .12593 .42493 .11623 Mtetra
.42493 .11623 .43285 .12593 .44641 .12069 .43854 .11093 Mtetra
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.64 .732 .915 r
.47978 .09488 .48753 .10478 .50137 .09943 .49366 .09026 Mtetra
.653 .757 .926 r
.49366 .09026 .50137 .09943 .51528 .09405 .50762 .08523 Mtetra
.666 .772 .929 r
.50762 .08523 .51528 .09405 .52926 .08891 .52166 .07976 Mtetra
.673 .767 .921 r
.52166 .07976 .52926 .08891 .54333 .08408 .53577 .07403 Mtetra
.673 .746 .905 r
.53577 .07403 .54333 .08408 .55746 .07868 .54994 .06819 Mtetra
.671 .736 .899 r
.54994 .06819 .55746 .07868 .57166 .07296 .56419 .06237 Mtetra
.668 .734 .899 r
.56419 .06237 .57166 .07296 .58593 .06715 .57851 .05662 Mtetra
.666 .735 .902 r
.57851 .05662 .58593 .06715 .60027 .06138 .59291 .05092 Mtetra
.665 .738 .904 r
.59291 .05092 .60027 .06138 .61469 .05568 .60738 .04524 Mtetra
.664 .739 .906 r
.60738 .04524 .61469 .05568 .62918 .05002 .62192 .03957 Mtetra
.664 .74 .907 r
.62192 .03957 .62918 .05002 .64375 .04436 .63654 .03387 Mtetra
.664 .741 .907 r
.63654 .03387 .64375 .04436 .6584 .03869 .65124 .02815 Mtetra
.65124 .02815 .6584 .03869 .67312 .03299 .66602 .0224 Mtetra
.66602 .0224 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02152 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04896 .25052 Mtetra
.04896 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24516 .08468 .23653 Mtetra
.08468 .23653 .09362 .24516 .10561 .2405 .0967 .23183 Mtetra
.0967 .23183 .10561 .2405 .11766 .23583 .10877 .2271 Mtetra
.663 .74 .907 r
.10877 .2271 .11766 .23583 .12976 .23116 .12091 .22237 Mtetra
.662 .74 .907 r
.12091 .22237 .12976 .23116 .1419 .22652 .13309 .21765 Mtetra
.66 .738 .908 r
.13309 .21765 .1419 .22652 .1541 .22194 .14533 .21297 Mtetra
.657 .735 .908 r
.14533 .21297 .1541 .22194 .16635 .21743 .15762 .20837 Mtetra
.653 .733 .908 r
.15762 .20837 .16635 .21743 .17865 .21295 .16995 .20387 Mtetra
.649 .733 .91 r
.16995 .20387 .17865 .21295 .19102 .20836 .18233 .19944 Mtetra
.651 .738 .914 r
.18233 .19944 .19102 .20836 .20348 .20353 .19478 .19497 Mtetra
.657 .75 .919 r
.19478 .19497 .20348 .20353 .21604 .19827 .20731 .19028 Mtetra
.67 .77 .925 r
.20731 .19028 .21604 .19827 .2287 .19259 .21995 .1852 Mtetra
.687 .791 .929 r
.21995 .1852 .2287 .19259 .24134 .18768 .23269 .17959 Mtetra
.698 .777 .912 r
.23269 .17959 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.664 .741 .907 r
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13794 Mtetra
.33645 .13794 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.631 .728 .918 r
.44432 .09571 .45222 .10561 .46597 .10026 .45808 .09138 Mtetra
.644 .761 .934 r
.45808 .09138 .46597 .10026 .47978 .09488 .47194 .08661 Mtetra
.66 .784 .94 r
.47194 .08661 .47978 .09488 .49366 .09026 .48588 .0813 Mtetra
.673 .771 .924 r
.48588 .0813 .49366 .09026 .50762 .08523 .4999 .07559 Mtetra
.677 .757 .911 r
.4999 .07559 .50762 .08523 .52166 .07976 .51398 .06965 Mtetra
.677 .747 .904 r
.51398 .06965 .52166 .07976 .53577 .07403 .52814 .06366 Mtetra
.673 .741 .901 r
.52814 .06366 .53577 .07403 .54994 .06819 .54236 .05775 Mtetra
.67 .739 .902 r
.54236 .05775 .54994 .06819 .56419 .06237 .55666 .05192 Mtetra
.667 .739 .904 r
.55666 .05192 .56419 .06237 .57851 .05662 .57103 .04617 Mtetra
.665 .74 .905 r
.57103 .04617 .57851 .05662 .59291 .05092 .58547 .04047 Mtetra
.664 .74 .907 r
.58547 .04047 .59291 .05092 .60738 .04524 .59999 .03476 Mtetra
.664 .741 .907 r
.59999 .03476 .60738 .04524 .62192 .03957 .61459 .02904 Mtetra
.61459 .02904 .62192 .03957 .63654 .03387 .62926 .02329 Mtetra
.62926 .02329 .63654 .03387 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .0224 .65884 .01171 Mtetra
.65884 .01171 .66602 .0224 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Vmj0030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000001/0ZKgX00<000000:Vmj02Y_NP00`2Y_NP00`000000oooo0?ooo`1S0?oo
o`00[P3oool00`3oohl0=@00000000020000000303F?o`3oool0oooo01T0oooo00<0ZKgX00000000
00007P2Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000003oool0oooo0680oooo002^0?ooo`030?oo
a01O51@0GlCo01`0oooo0`0000090:Vmj0<0ZKgW502Y_NP00`000000ZKgX0:Vmj0040:Vmj0030000
003oool0oooo0680oooo002_0?ooo`0308le000eSol0oooo01T0oooo0P0000020:Zmi`030000002Z
_NL0ZKgX00@0ZKgX1`2Y_NLC0:Vmj0030000002Y_NP0ZKgX00D0ZKgX00<000000?ooo`3oool0H@3o
ool00:l0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`<000001`2Z_NL20:Vmj0<0Z[cW
2`2Y_NL>0:Vmj0030000002Y_NP0ZKgX00H0ZKgX00<000000?ooo`3oool0H03oool00<H0oooo0P00
000:0:Zmi`H0Z[cW0`2Y_NL30:Zli`D0ZKgW0`2Y_NP30:Vmi`L0ZKgX00<000000:Vmj02Y_NP01P2Y
_NP00`000000oooo0?ooo`1P0?ooo`00``3oool300000080ZkgV1@2Z_NL60:ZliP/0Z[cW302Y_NL6
0:Vmj0030000002Y_NP0ZKgX00L0ZKgX00<000000?ooo`3oool0G`3oool00<40oooo0P0000000`2[
_NH000000:^miP030:^miP80Z[gW0`2[^nH60:ZliP80Z[cW0`2Z_>H60:Zli`80ZKgW0`2Z_>L;0:Vm
i`030:Vmj0000000ZKgX00T0ZKgX00<000000?ooo`3oool0GP3oool00;h0oooo0`0000020:bmiPH0
ZkgV1P2[^nH;0:ZliP/0Z[cW0`2Y_NL30:Zli`D0ZKgW00<000000:Vmj02Y_NP00`2Y_NL50:Vmj003
0000003oool0oooo05h0oooo002k0?ooo`<000001P2/_NH30:^miP<0ZkcV1P2[^nH20:ZliP<0Zk_U
2`2Z_>H<0:Zli`@0ZKgW00<000000:Vmi`2Y_NL0102Y_NL20:Vmj0<0ZKgW00<000000?ooo`3oool0
G@3oool00;T0oooo0P0000040:foi`H0[;gV1P2[_>H50:^kiPH0Zk_U0`2Z_>H30:^ki@D0Z[cV0`2Z
_>L30:^liPT0Z[cW00<000000:Vmi`2Y_NL02@2Y_NL00`3oool000000?ooo`1M0?ooo`00]P3oool4
000000030:g1j@2]_nL0[KoW00<0[KoW0`2/_NH30:bni`/0ZkcV302[^nD40:ZliPL0ZkcV0P2Z_>L3
0:^liP<0Z[cW00<000000:Zli`2Y_NL00P2Y_NL30:Zli`D0ZKgW00<000000?ooo`3oool0G03oool0
0;@0oooo0P0000040:g1j@030000002]`NT0[KoW00<0[KoW1`2/_^L20:^liP<0Zl7Y1P2[_>H20:^k
i@<0[;gW1P2[^nD50:^li@/0ZkcV0`2Z_>L00`000000Z[cW0:Zli`060:Zli`@0ZKgW00<0oooo0000
003oool0G03oool00;40oooo0`0000020:c5k0H0[L7Y1@2/a>/60:bni`H0Zl7Y1@2[_>H60:bmi`<0
Zk_U0`2/_^L50:^li@<0ZkcV0`2/_>H50:^liP80Z[cW00@000000:^liP2[_>H0ZkcV1@2Z_>L50:Zm
i`800000G03oool00:h0oooo0`0000060:c5k0<0[L7Y0`2ZaNd50:c4j`<0[;kW0`2Y`n`60:_1j@D0
Zl?[1@2/_NL60:bni`D0ZkcU1`2/_>H60:^liP030000002[_>H0ZkcV0080ZkcV0P2Z_>L30:ZliPD0
Z[gW00<000000?ooo`3oool0FP3oool00:`0oooo100000020:S8l0H0[<G/1P2ZaNd50:c4j`H0ZL?/
0`2[`NT30:Joj`D0Zl?[0P2/_NL30:[3k0H0[;kW0P2[_>D30:boi`/0[;cV00<0ZkcV0000002[_>H0
0`2[_>H60:ZliP@0Z[gW00<0oooo0000003oool0FP3oool007/0oooo00D0oon?03D00000000001AO
0<Coo`0Z0?ooo`8000000P2T`^l50:S8l0<0[<G/0`2W`Nd50:[5k@H0YKg[1@2Y`n`70:Joj`@0Zl?[
1P2Z`n`50:bni`H0[;oW0`2/_>H30:boi`D0[;cV00<000000:^liP2[_>H00`2[_>H50:ZliPD0Z[cW
00<0oooo0000003oool0F@3oool007X0oooo00H0ooo405lD000DGl@0oooo0<AO5000=HlW0?ooo`<0
00001@2T`^l50:S8l0H0Yl7]0P2ZaNd30:Nlj0H0YKg[0P2Y`n`30:Flj@H0Y[o[1@2T_>X60:[3k0D0
ZL;/302/_nL40:bliP030000002[_>H0ZkcV00@0ZkcV0P2Z_>H30:^liPD0Z[cW00<000000?ooo`3o
ool0F03oool007X0oooo00L0oon?03D0=@2?ool0oooo0?o4G`0D03D0Sooo02@0oooo0P0000030:6j
j`D0Y<;_1P2S^nX50:O1k@H0YkcX1@2U_N/60:Flj@<0Y[o[0`2X_NP50:BljP<0Z/?/0`2S^nX50:W2
k080[;oW0`2Y`^`60:boi`D0[;kW00<000000:^liP2[_>H02@2[_>H40:Zli`030?ooo`000000oooo
05P0oooo001j0?ooo`070?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4o`0Q0?ooo`@000001@2Q^^/2
0:C2k`<0ZKgX1P2S^nX50:Vmj0H0YkcX1@2Y_NP50:Flj@L0Z;gX102T_>X70:>kjPX0ZL;/0`2/_nL3
0:W3k0@0[;kW00@000000:^liP2[_>H0ZkcV0`2/_NH50:^liPD0Z[cV00<000000?ooo`3oool0E`3o
ool007X0oooo00L0ohle000DG`34ool0oooo0?ooS`0e01@0GlCo01l0oooo0P0000050:Vmj0@0XK[[
1P2Y_NP30:>kjPP0ZKgX0`2W_>P80:Vmj080YKcY0`2Y_NP60:Rmj0D0ZKgX1P2S^nX50:Bkj@H0ZL;/
1P2Y`n`30:bni`030000002/_NH0[;gV00D0[;gV0P2[_>H30:bmiPD0Z[cV00<000000?ooo`3oool0
4P3oool01@3OW4P000000000000004P0W=oo03l0oooo001j0?ooo`070?o4G`0D55l0a?oo0?ooo`3o
ohl0=@0D05o4o`0L0?ooo`<00000;@2Y_NP30:Rmj0P0ZKgX0`2S^nX30:Vmj0D0Y;_Y1P2S^nT50:W3
k0<0Z/?[00<000000:[3j`2/_NH02`2/_NH40:ZliP030?ooo`000000oooo0140oooo00L0okmd0018
W03Oool0oooo0?oog`2LB7@0_ooo03h0oooo001j0?ooo`070?ooS`0e03D0Sooo0?ooo`3oa5l0500e
08ooo`0I0?ooo`<00000@P2Y_NP20:Bkj@<0ZKgX1P2S^nT20:W3k0<0Xk[Z0P2Z`n/00`000000Z/?[
0:[3j`030:bmiP<0Zl7Y1@2/_NH50:^liP030000003oool0oooo01D0oooo00<0_g@007Boo`3oool0
?@3oool007X0oooo00H0ooo405lD000eSol0oooo0<AO5000=HlH0?ooo`80000000<0ZKgX0000002Y
_NP0B02Y_NP50:>kj@H0Xk[Z00@0Z/?[0000002Z`n/0Z/?[1`2[`NT20:bmiP<0[;kW1@2[_>H00`00
0000oooo0?ooo`070?ooo`030?oOW0180000000000<0000000<0001d0;ooo`3oool0103oool00`2o
M000M;oo0?ooo`0m0?ooo`00N`3oool01@3oohl0=@000000000055l0a?oo01D0oooo0`00001C0:Vm
j0D0Xk[Z00<0Xk_Z0000002S^nX00P2S^nX60:_1j@D0[;kW1@2[_>H00`3oool000000?ooo`0?0?oo
o`070?oOW01804P0W=oo0?ooo`3ooml0W4Q809cOo`0n0?ooo`00T`3oool2000005L0ZKgX0P2S^^X3
0:Rmj0030000002S^nX0Xk_Z0080Xk_Z0`2[`NT30:Joj`D0[;kW1@2[_>H00`000000oooo0?ooo`0>
0?ooo`030?oo_`1d000000000080000000<0M;oo0?ooo`3oool0?@3oool00900oooo0`00000V0:Vm
j0<0YZSG1`2Y_NP30:N^g2H0ZKgX1@2X_NP00`000000Xk_Z0:>kjP020:>kjPL0Y[o[102/_^L60:^l
iP030000003oool0oooo00d0oooo00<0oooO09a8B02Lgol0@P3oool008h0oooo0P0000000`2Y_NP0
00000:Vmj00I0:Vmj0D0Z;7N1@2Y_NP70:JXe`@0ZKgX1P2W[]`30:Vmj0<0Y9g>1`2Y_NP30:VkiaH0
ZKgX102X_NP00`000000YK_Y0:Fkj@030:Fkj@H0Y[o[1@2Y`N/50:^liP030?ooo`000000oooo00h0
oooo00<0_g@007Boo`3oool0@@3oool008/0oooo0`00000A0:Vmj0<0ZKST202Y_NP30:>LcPD0Z;7N
0P2Y_NP30:6Ba@H0YZSG1@2QT/D50:N^g0L0Y9g>102Y_NP60:VkiaH0ZKgX0P2X_NP00`2Y_NP00000
0:Vmj0050:Fkj@H0Xk[Z1@2Y`N/20:^liP<0ZKgX00<000000?ooo`3oool03@3oool01P3OW4P00000
000000000000001d0;oooch0oooo00290?ooo`8000004P2Y_NP60:Vhi0D0ZKgX1@2SW<h50:RagPH0
XI;5102VZ=L20:jE_@D0XI;50P2W[]`30:ZC_`H0Y9g>1@2QU<H50:Vki`H0ZKST4`2Y_NP00`000000
ZKgX0:Vmj0020:Fkj@<0ZKgX1P2S^^X40:W1j`H0ZKgX00<000000?ooo`3oool0D03oool008H0oooo
0`00000B0:Vmj0<0Yj_J1P2Y^>@50:2@``D0Xic>0P2X/Mh30:J?_@H0XI;50P2VZ=L30:jE_@D0XI;5
1P2ZTkl40:BMcP80^9fm1@2QU<H20:Vki`<0XY731P2Y^>@50:Vki`d0ZKgX00<000000:Vmj02Y_NP0
1P2Y_NP50:>jjPD0Xkc[1@2Y_NP00`3oool000000?ooo`1@0?ooo`00Q03oool300000180ZKgX1P2W
ZmX30:Vhi0<0XHbm102PT<<50:>LcPD0YXnm1P2QT/D50:jE_@@0XI;50P2kXKh50:ZC_`<0Y9g>0`2h
WKd50:6DaPH0XY730`2Y^>@30:FDa0D0ZK_W302Y_NP00`000000ZKgX0:Vmj0060:Vmj0H0YkcX1@2S
_>/50:Jnj`030000003oool0oooo04l0oooo00210?ooo`<000000`2Y_NP00`000000ZKgX0:Vmj00;
0:Vmj0D0YJ;C1@2WZmX60:6<_@D0X9330`2SW<h20;2G_@D0YXnm102QT/D20;JN_`D0[YFm0P2QT/D3
0;^Q_PH0ZY>o00<0Y9g>0;RM_@2hWKd00P2hWKd40:6DaP80`:Bm1P2RTL<60:FDa0@0ZK_W302Y_NP0
0`000000ZKgX0:Vmj0070:Vmj0H0YkcX0P2S_>/30:6ijPD0Y[k[00<000000?ooo`3oool0CP3oool0
07l0oooo0P00000B0:Vmj0<0Xig>1@2UX]<20:N[fP<0Yi2m1@2QS;d50:2@``80Xic>0`2`Ukd50:J?
_@80XI;5102fW[l50:jE_@030:6Ba@2kXKh0^j6n00<0^j6n1@2ZTkl60;RM_@80XIC60`30Y;d50::A
``80a:Rn1@2UU<@50:>EaP/0ZKgX00<000000:Vmj02Y_NP0202Y_NP50:Nlj0H0XKWZ102V_^/00`3o
ool000000?ooo`1>0?ooo`00O03oool300000180ZKgX1@2SWLh50:FRd`D0Yi2m1P2QS;d40:2@``D0
/9Nm1@2VSkd60;JN_`D0[YFm1P2kXKh40:ZC_`80`J_41@2hWKd00`2QU<H0`:Bm0<2T_@020<2T_@@0
XY730`34Z;h50:FDa0030<JZ_P2SULH0XiG600<0XiG60P2Y_NP30:BMcPD0ZKgX00<000000:Vmj02Y
_NP03P2Y_NP50:6ijPD0XKo^00<000000?ooo`3oool0C@3oool004/0oooo00D0a5lD000000000000
000D05o4o`0Y0?ooo`<0000000<0ZKgX0000002Y_NP03P2Y_NP50:>Jc0D0Xig>0`2UX]<20:J@_PD0
Yi2m1@2QS;d20:2@``<0/9_21@2`Ukd30:J?_@80^:S81P2fW[l30:jE_@80_Zg91P2kXKh20:ZC_`<0
`J_41@2hWKd60<2T_@80XY731034Z;h40:FDa080aZZn1@2SULH60:BMcP<0ZKgX00<0Z:kL0000002X
[]`03`2Y_NP30:6ijP<0Y;_Y1@2Q_nh00`000000oooo0?ooo`1<0?ooo`00BP3oool01`3oScD001AO
0<Coo`3oool0ooo405lD=@2?ool09P3oool200000180ZKgX1`2SV/`50:>McP80YJ;C0`2VT;h50:N@
_@D0XHbm1@2`Vl850;2G_@80YXnm0`2hZ<P60;JN_`80[YFm0`2n[LT60;^Q_P030:ZC_`31Zl@0`J_4
0080`J_4102hWKd20<Fcb@D0`:Bm00<0XY730<BX_P34Z;h01034Z;h20:FDa0<0aZZn102SULH20<BY
_`D0Y9g>1@2X[]`00`000000Z:kL0:Vmj00=0:Vmj0L0Y;_Y102Q_nh00`000000oooo0?ooo`1<0?oo
o`00C`3oool00`2?=@00=Hoo0?ooo`0R0?ooo`<000004P2Y_NP:0:>Jc0@0Xig>1P2VT;h50:N@_@<0
XHbm0P2`XLT40;2K`PD0/9Nm1P2hZ<P50;JN_`D0_Zg91P2kXKh60<6[a080^9fm0`35/lT50<2T_@L0
a:Rn00<0YIC40<JZ_P36Z[h00`36Z[h20:>EaP<0a:Vo102TWLh20;bV``@0Z:kL00<000000:R^g02Y
_NP03P2Y_NP60:Bkj@D0W;O[00<000000?ooo`3oool0B`3oool00480oooo00<0olAO01@000000000
0`0000000`0003D0Sooo0?ooo`040?ooo`0308le000eSol0oooo0200oooo0P00000A0:Vmj0D0Xig>
2@2SV/`50:B@`0D0YY2n1@2WT;d20:6<_@<0/:791@2`Vl830;2G_@80^KGF1@2hZ<P40;JN_`80_L3K
1@2n[LT40;^Q_P80`[kF1@31Zl@00`2hWKd0aK?90<Fcb@030<Fcb@<0`:Bm0P38^L`60<BX_PH0aZZn
00<0XiG60<BY_`34ZKl00`34ZKl20:BMcP@0_:K30`2X[]`00`000000[j790:nQb@0E0:Vmj0D0W;O[
00<000000?ooo`3oool0BP3oool004X0oooo00L0olAO01@0501Oa?l0oooo0?ooa01O51@0GlCo01h0
oooo0`0000000`2Y_NP000000:Vmj00>0:Vmj0<0YJ;C102SWLh70:>Jc0<0XY31102TT<060:J@_P@0
Yi2m1@2`XLT50;2K`P80/9Nm102i]MH50;RXb080]Yjo0`2m`=/50;j]b@80^j6n1032_]H50<6[a0H0
aK?90P30Y;d40<Ric0@0a:Rn0P3:_<d50<JZ_PH0a:Vo1`2lY/<20:R^g0040000002_XLT0[j790:nQ
bAD0ZKgX0P2L]n/20:6jjP030000003oool0oooo04X0oooo001:0?ooo`030?ooS`0e000000000080
000000<0=Hoo0?ooo`3oool06P3oool00`2Y_NP000000000000B0:Vmj0D0YJ;C1@2SWLh40:>Jc0D0
XY311@2TT<050:J@_P80Yi2m0`2`Z=050;2Qb@@0/9_21P2i]MH50;RXb0H0_L3K102n[LT70<:neP80
`J_40`32c>850<Fcb@H0b;W<0`34Z;h30<Zlc@@0aZZn0P3<^lX50<BY_`030<fha@2lY/<0_:K300@0
_:K30P2_XLT010000000[j790:nQb@2_XLT50:NWea00ZKgX1@2Q^^X00`000000oooo0?ooo`190?oo
o`00BP3oool00`3ool@0Ga@D05o4o`0M0?ooo`<00000402Y_NP50:N[fPD0YJ;C102SWLh20:>Jc0<0
Whk2102RT<450:B@`0D0YY2n1@2`Z=050;2Qb@80/9_20`2faND60;VeeP80^:S80`2de_450;g0f`80
_Zg90`2geo460<:nePD0`/cR1035/lT20;kDj`H0b;W<00<0a:Rn0<Zlc@3:_<d00`3:_<d20<JZ_P<0
c;_:1034ZKl20<fha@D0_:K30P3>]<40102_XLT000000:nQb@2_XLT20<R``PD0YjOG402Y_NP50:6j
jP030000003oool0oooo04P0oooo001;0?ooo`0308le000eSol0oooo01X0oooo0P00000A0:Vmj0<0
ZKST102WZmX50:FRd`@0Xig>1@2OS/850::@`@D0Y9300P2VT;h30:j]e`D0/:S@102`XLT60;K5i@D0
^KGF1P2de_440;g0f`H0]mOa0`32_]H30:3Ro0D0`/cR0P35/lT30;kDj`H0b;W<1P3:_<d00`36Z[h0
c;_:0<bkbP030<bkbP80a:Vo103=^<D30;bV``<0c[C100<0[j790000002_XLT00`38/<840:NWe`80
]ZS;502Y_NP00`000000oooo0?ooo`180?ooo`00B`3oool01P34Ga@00000000000000000000e08oo
oa@0oooo0`0000000`2ba^T0ZKgX0000000>0:Vmj0D0ZKST1@2WZmX40:FRd`D0W8c2102OS/850::@
`@D0Y9301@2^[ML50;2Xd080/:790`2`e?<60;K5i@D0VnCm1@2de_4508kSo0H0]mOa1P2Ph_`40<;<
hPH0_]C[0`38^L`30;cGk@D0b[c=1P3<^lX00`34ZKl0cKS50<fha@030<fha@80_:K31@3>]<400`00
0000b;320<R``P030<R``P80YjOG102fZ</D0:Vmj0030000003oool0oooo04L0oooo001S0?ooo`80
00001@2ba^T@0:Vmj0D0ZKST102WZmX509V9`@@0W8c21@2OS/840::@`@<0Y9300`2]/]`50:j]e`@0
/:S@1P2`e?<707KOl`@0VnCm1P1Bc^@408kSo0L0E<g[102Ph_`508?Mo@D0_]C[1`2lend20<Zlc@<0
_]G[1@3<^lX60<fha@L0c[C100<000000<R``P38/<800`38/<860;JXb`D0Z;3N402Y_NP00`000000
oooo0?ooo`160?ooo`00G`3oool4000000<0[l[]1@2ba^T@0:Vmj0@0ZKST1@2FQ/0409V9`@@0W8c2
1@2OS/840::@`@H0[K;L1@2^[ML50:KNn`<0/=Cc1@1Id^0202F``PD0R;Cc0`1Z`_h30:Vmj0D0RK3_
0`1L]O`30:Rmj0D0KZ?a0P0VYNT408?Mo@H0L=Gk1@2lend50;kEj`@0c;_:0P34d><40<fha@80blSH
1P3>]<400`000000b;320<R``P030<R``P030=:j``2fZ</0]ZS;00<0]ZS;00<0bkC40:R`gP2X/=h0
0`2X/=h?0:Vmj0030000003oool0oooo04H0oooo001N0?ooo`<000001P2_b^dE0:Vmj0@0Th?0102F
Q/0409V9`@D0W8c2102OS/850:^dg`H0[K;L0P2^[ML309_To@D0Y]kk0`1Id^0205C<k0D0Y;_Z1@28
]?<60:Vmj0D0RK3_1P2X_NP206jSl@<0ZKgX1023[?0303FRl`D0L=Gk1@1^d_`50;kEj`80c;_:0`34
d><30<fha@@0blSH103>]<400`3@`L`000000<R``P030<R``P80d[[3102fZ</20<^da0D0Z;3N402Y
_NP00`000000oooo0?ooo`150?ooo`00F`3oool3000000@0ZlG/0`2_b^dC0:Vmj0D0W8k40`2CPl05
09J6`0@0VHW1102LS<8209n>`P<0Z;?P1@2[]=l50:fbg0H0VnCm102Bd?d307gDo`<0ZKgX1@2T^nX@
0:Vmj0D0Z;gX1P2Y_NP408>/l0D0RJo_100bW?8406kBo0@0_]G[1P34d><00`3=^<D0blSH0<_8f003
0<_8f0<0c[C10P3@`L`010000000d<7<0<R``P38/<840=:j``80]ZS;103;]<@20:R`gP<0/J[A3`2Y
_NP00`3oool000000?ooo`150?ooo`00F03oool3000000<0Z;o[1@2[aN`C0:Vmj0<0Xic>102LS/@4
09>3`0@0UXK0102IRL4409b<`PH0Z;?P1@2[]=l609CVn`04057>cP2MboL0WL_g09g;m`D0T]3m1P2Y
_NP20:BkjR80ZKgX1@29[nl503:LlP<04IcJ101le?l50<C@h`L0blSH00L0c[C10=31c03@`L`0d<7<
0000003@`L`0b;3200D0d[[300<0]ZS;0<^da03;]<@00`3;]<@60;6Zd@l0ZKgX00<000000?ooo`3o
ool0A03oool005H0oooo0P0000020:Jlj@D0Z;o[1P2`a>T?0:Vmj0D0Xic>102LS/@409>3`0D0UXK0
0`2IRL450:F_g`H0Z;?P0P2[]=l409;XnP<0DLk>1P2MboLd0:Vmj0H0Pjc_0P0PU>`407cDo`D0UmOm
1P3;b=P40=31c0030000003@`L`0d[[300D0d[[31P3;]<@00`3D_<80/J[A0;6Zd@020;6Zd@80`kC;
3`2Y_NP00`000000oooo0?ooo`130?ooo`00D`3oool3000000030:Jlj@000000Y[cY0080Y[cY0P2X
_n/30:g6k0H0/<CY2P2Y_NP50:RagP@0Xic>1@2LS/@409>3`0@0UXK0102QZ=/50:F_g`D0Z;?P0P2B
j?X305_Dd@D0Y<Sb0`2MboLg0:Vmj0<0Pjc_0`2Y_NP506nRl08008KG102Geod30<_8f0<0]=Ga0`3@
`L`00`000000b<cM0<S<g@040=:j``80d/?<103;]<@20=Bl`P<0/J[A1033]</?0:Vmj0030000003o
ool0oooo0480oooo001A0?ooo`800000102V^nP40:Jlj@H0[LK/0`2`a>T=0:Vmj0@0Z;7N1@2SW<h4
09b>a0@0Th?01@2LWmH40:6Xf`D0YJoO102Dj?X00`1Vfm@0ZL[a0:W:l@030:W:l@D0Y<Sb@02Y_NP2
06nRl0<0Z;gX00<0B8g/0026e`15]_H00P15]_H70;CEl@80d<7<00<000000<S<g@38c=d00`3B^/<3
0=;3c0<0bkC4103D_<800`2aZ]40`kC;0<>db`030<>db`D0ZKST2P2Y_NP00`000000oooo0?ooo`12
0?ooo`00CP3oool3000000030:Nkj02V^nP0Y[_X00@0Y[_X1@2Z`n`50:g6k0l0ZKgX1@2X/Mh40:>L
cP@0W8k41@2GUM0409bOePD0XJSK0P2U[ml409[Xn`0407?Rf@2^d?40[]3a0:k@l@D0ZL[aA02Y_NP6
0:Rmj080B8g/1015]_H50;CEl@80b<cM00D000000<S<g@38c=d0b<cM0=:j``050=;3c0030<^da03D
_<80e;c200<0e;c21@33]</20=6laPD0ZKST2P2Y_NP00`000000oooo0?ooo`110?ooo`006@3oool0
0`3ogi`0B01d0;ooo`020?ooo`050?ooS`0e00000000000DG`34ool0:@3oool2000000030:Rlj02W
^nP0Yk_X0080Yk_X0`2V^nP30:Nmj@D0Z/?/502Y_NP40:RagP@0Xic>1@2ARlT409NEd0D0W9oF102Q
Z=/209[Xn`<0Ln;I1P2^d?590:Vmj0D0Z;gX1018SN`300n@hPD0O<[o00<0b<cM00000038c=d00P38
c=d60=;3c0D0e;c20P3E`/L30<>db`@0dKc60P2Y^>@30:faf`X0ZKgX00<000000?ooo`3oool0@03o
ool001T0oooo00X0omnL04P0M02oool0oooo0?oog`1O500055o40?ooo`34Ga@003F?9P3oool30000
0080Z;cX00<000000:Rlj02W^nP00`2W^nP60:Nmj@80Z/?/0`2/_nPC0:Vmj0D0RGk2102<Pl@4096;
b@D0UiG@102LWmH40:7Vo0<0P>SN0`2cfO@30:k@lD`0ZKgX0P2X_NP30:Vmj0D0RZo_0P0EQnL507c:
o`030000002_dO80[m7b0080[m7b103B`l`20<_:f@<0e;c2103E`/L00`33]</0dKc60=6laP030=6l
aPH0[K7K2@2Y_NP00`000000oooo0?ooo`0:0?ooo`050?oo_`1d000000000018W03Oool0<@3oool0
01T0oooo00/0omnL04P0M02oool0oooo0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0R0?ooo`03
0:Rlj0000000000000L0Z;cX1@2W^^L50:Nmj@H0[;oX3@2Y_NP30:JXe`<0UXc71029O/8408b3a0D0
TH_9102GUM0209bOeP@0Y]kk0`20j=h60;?Im5@0ZKgX0P2:[nl30:Vmj0<0DI3]100mZOD00`000000
[m7b0:oAlP020:oAlP80d/?<103;b]T00`3D_<80eL;70=G2a`030=G2a`H0dKc600<0f<730:faf`2]
/M/00`2]/M/:0:Vmj0030000003oool0oooo00P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;la
0?ooo`003@3oool00`3ogi`0B00000000003000000030000M02oool0oooo00<0oooo00/0omnL04P0
M02oool0oooo0?oOW00D55l0a?oo0?ooo`3oohl0=@0D05o4o`0P0?ooo`<000001`2X_>P80:Nji`<0
YkgY0P2_a>X60:boj0X0ZKgX1@2VZ=L309J<a`@0RGk21@2<Pl@4096;b@@0UiG@1@2Vg_/208g^i0@0
]NKgGP2Y_NP3056@k@<06HkY00<000000:oAlP2_dO800P2_dO860<_:f@H0eL;700<0dlK>0=6laP3A
_<H00P3A_<H20=S1``<0[K7K0`2j^MP90:Vmj0030000003oool0oooo00P0oooo00L0oono07@0M02o
ool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Co
o`3oool0oon?03D0501Oa?l07P3oool3000000<0ZKgX102X_>P;0:Nji`D0[lCZ0`2/_nP=0:Vmj0@0
YZSG102FS<L408Un`P@0S8?4102ARlT70:KAmP80SNkT1@2ei_MO0:Vmj0@0DI3]0P0IS^T00`000000
Q<Gm08C5o@0308C5o@@0bl[I0P2kc>L40=G2a`80dlK>0`3A_<H30=S1``H0^[WH2P2Y_NP00`000000
oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`006@3oool02`3o
gi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo01/0oooo0`0000070:Vmj0D0
Z;_W1@2W^^L50:[0j@D0[lCZ3`2Y_NP50:JXe`<0UXc71029O/8408b3a0H0X[k]0`2VdOH209[bk0D0
/OCcHP2Y_NP408B/k`0300n2i00000003h;T00D0Q<Gm0P3;b]T30;_<i`<0eL;7103Ca/h00`3A_<H0
f<730=S1``020=S1``030=W5a@2j^MP0^[WH00<0^[WH2`2Y_NP00`000000oooo0?ooo`060?ooo`07
0?noM000B9`0gooo0?ooo`3ookl0M01809cOo`0`0?ooo`005`3oool03@2oM000001809boW01807@0
_ooo0?ooo`3ookl0=@0e08ooo`3oool0olAO01@0=@2?ool06@3oool2000000H0ZKgX1@2Y_>L50:Rk
i`D0Yk_W1@2Z`>TD0:Vmj0@0YZSG102FS<L308Un`PD0VZWQ1P2R_^d209[bk0<0/OCcI`2Y_NP408B/
k`030000000?P^@03h;T00@0F:kj1P2kc>L00`3E`/L0dlK>0=?6cP030=?6cP@0f<730P3IaLD40;Zi
f080a;oF2P2Y_NP00`000000oooo0?ooo`060?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`0`0?ooo`00603oool02`3o_g@000000000M02oool0oooo0?oog`1O5000=Hoo0?ooo`34Ga@003F?
01L0oooo0`0000090:Vmj0D0ZKcW0P2X^nL30:Nji`D0Yk_W0P2Z`>T30:k2j1<0ZKgX102VZ=L409J<
a`@0T9GD1@2JZN430::nk@80Y_;d0`2TmnD30:o4jFH0ZKgX102T^nT010000000<h?Y03>3j@0cPnT4
05R^nPD0^lcW1@3Ca/h20<g8e@<0f<730`3IaLD20;Zif0@0a;oF2P2Y_NP00`000000oooo0?ooo`05
0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`0`0?ooo`006@3oool00`3ogi`0B01d0;oo
o`020?ooo`050?ooS`0e00000000000DG`34ool0503oool3000000030:Vmj0000000ZKgX00X0ZKgX
102Y_>L60:Nji`@0Yk_W1P2^`^P;0:Vmj0D0YjkL0`2;Q/P4085ka0@0QhG:102@UM@509ZYh@80Y_;d
0`2TmnD60:o4jFH0ZKgX0`2T^nT00`000000Y;_Y03>3j@0203>3j@<0>IWc1P2Ub?830=?6cP@0cLSE
00<0f<730=W5a@3IaLD00P3IaLD50<BoeP80blGE2P2Y_NP00`000000oooo0?ooo`040?ooo`060?oo
g`2LB000M;oo0?ooo`3OW4P007Bo<@3oool003@0oooo00<0ZKgX0000000000004@2Y_NP50:Rki`D0
Yk[W1@2]`nX50:k2j0/0ZKgX102W[]`308^6b0@0PG_41027QLX5092Ee080VZWQ0`2]j?T20:chj0<0
a=o/1@2_a>UY0:Vmj0030000002Y_NP0ZKgX00<0FYG^0`0iVO<60:G8lPH0cLSE103IaLD20=[7b0<0
a;oF103;aMD90:Vmj0030000003oool0oooo00D0oooo00D0oono07@00000000004RL0=ooo`0a0?oo
o`00<P3oool3000000l0ZKgX1@2X_>L50:Rki`D0Z;cX1@2]`nX?0:Vmj0D0YjkL0P2;Q/P5085ka0@0
QhG:102@UM@40:gXn@030:chj034gn`0a=o/00@0a=o/K@2Y_NP010000000ZKgX0:Vmj02Y_NP305ZE
kP<0:h_]1P2<_OL40<g8e@80a/WL0P3IaLD40=[7b0030<BoeP3;aMD0blGE00<0blGE2P2Y_NP00`00
0000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX0100ZKgX1@2X_>L20:Rki`<0
Yk[W1@2X_>P50:^nj0l0ZKgX102W[]`308^6b0@0PG_41027QLX60:[Cm@80]?O_0P31n>d30<COk6h0
ZKgX0P0000030:Vmj0@0FYG^0`0[Rnd508bmm`80cLSE1036bM`00`3IaLD0f/O80=[7b0030=[7b0D0
blGE0P3?b]D:0:Vmj0030000003oool0oooo03T0oooo000/0?ooo`040:Vmj00000000000000001H0
ZKgX102X_>L60:Nji`<0Z;cX0P2`a>T50:^nj0h0ZKgX102W[]`308^6b0@0PG_41@2M]NT30:[Cm@<0
]?O_1031n>e]0:Vmj0<000000P2Y_NP010000000ZKgX0:Vmj02Y_NP407NUk`<09h?Z102<_OL60<K9
g0D0f/O80P3Jb/X30<_5e@@0cl[E2@2Y_NP00`000000oooo0?ooo`0i0?ooo`00:`3oool2000001X0
ZKgX1@2W^nL50:Nji`D0/<CY1@2[_^P;0:Vmj0<0U9GB101gMlD207n1c0D0SIOI1@2M]NT30;Cgk`<0
`OS]K@2Y_NP3000000D0ZKgX00<000000:Vmj02Y_NP00P2Y_NP407NUk`<09h?Z101h/OL40<K9g080
_/OQ0`3JalP40=[:bPH0cl[E2P2Y_NP00`000000oooo0?ooo`0h0?ooo`00:@3oool2000001P0ZKgX
1@2X_>L50:Nki`D0ZKgX1@2`a>T?0:Vmj0<0U9GB101gMlD307n1c0D0SIOI0`2M]NT30;O^m@<0_o_Y
0P35fnYY0:Vmj0<000002@2Y_NP00`000000ZKgX0:Vmj0020:Vmj0@0RZo^0`0ZP>P407Ram`80a/WL
102nan400`3JalP0f/[:0=[:bP030=[:bP030=[<b`3?b]D0cl[E0080cl[E0P3@c]L:0:Vmj0030000
003oool0oooo03L0oooo000M0?ooo`050?oo_`1d000000000018W03Oool01`3oool2000001T0ZKgX
1@2X_>L20:Nki`<0Yk[W6@2Y_NP209BEdP@0MgO5101oPL`508fGf@@0]nke0`2onnT40<GKjVH0ZKgX
0P00000=0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0RZo^0`0ZP>P306ZVm0H0_/OQ1@3Jb/X30=[<b`80
cl[E0`3@c]L:0:Vmj0030000003oool0oooo03L0oooo000L0?ooo`060?oog`2LB000B9cO0?ooo`3O
W4P007Bo1`3oool00`000000oooo0000000I0:Vmj0@0Z;cW1P2W^^L30:Vmj080/<CY4`2Y_NP309BE
dP@0MgO5101oPL`208fGf@@0[mGd0`2onnT60<GKjV<0ZKgX0`00000@0:Vmj0030000002Y_NP0ZKgX
00H0UKC]00<0;goW02Z0j00ZP>P00`1ZY_@30;k7h@<0^LCS0`3Jb/X40=[<b`@0d<kG0P3?d]/:0:Vm
j0030000003oool0oooo03H0oooo000L0?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`05
0?ooo`8000000P3oool00`000000ZKgX0:Vmj00G0:Vmj0D0Yk_W1@2W^^L50;34j@d0ZKgX0P2Y^nL3
07Unc0<0U9GB101gMlD407n1c0@0[mGd1032mnh30<Wjj6@0ZKgX0`00000C0:Vmj0040000002Y_NP0
ZKgX0:Vmj0D0UKC]0`0_OnL406ZVm0H0^LCS00<0f/[:0=[<b`3Jc</00P3Jc</20=_>c080d<kG103?
d]/:0:Vmj0030000003oool0oooo03D0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`030000003oool0oooo0080oooo00<000000:Vmj02Y_NP04P2Y_NP50:Rli`D0Yk_W
1@2Z_^P50;34j@X0ZKgX1@2Y^nL307Unc080LgS9101gMlD609Z`iPD0`_O^0`39n^P20:^nj600ZKgX
0`00000G0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0VkO/0P0fO^H00`0_OnL0Hioa06>Ol@0206>Ol@D0
^LCS103Jc</30=_>c0H0cm;K2P2Y_NP00`000000oooo0?ooo`0e0?ooo`00703oool01`3o_g@004RL
0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`030?oooaD0ZKgX1@2X_>L20:Nk
i`<0Yk[W1@2Z_^P?0:Vmj0@0ZK_W0`1iO/`307=hb@D0PhgE0`2J/>H40;kWlP<0bO[X1@2[_^QL0:Vm
j0<000006`2Y_NP010000000ZKgX0:Vmj02Y_NP509^gk0<0=WkV101SWo420;W4h`<0]L;T0P3Jc</4
0=_>c0030=gAc03?d]/0cm;K0080cm;K0P3;e^8:0:Vmj0030000003oool0oooo03@0oooo000L0?oo
o`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vm
j00B0:Vmj0@0Z;cW1P2W^^L20:Znj0<0/<CY3`2Y_NP40:Vki`<0NGk<0`1cN<T508>=e@@0_^Ob103<
n>P20=;ZiPD0ZkkXF02Y_NP3000001l0ZKgX00@000000:Vmj02Y_NP0ZKgX102K]n`403IniP<0Hi[_
1P2e`^@40=_>c0<0gM7<0P3?d]/40<_FhPX0ZKgX00<000000?ooo`3oool0<`3oool001`0oooo00L0
oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
ZKgX0:Vmj00B0:Vmj0D0Yk_W102W^^L60;34j@`0ZKgX0`2W]nD306I`b0<0NGk<101cN<T208>=e@@0
ZLG^1@3<n>P40=;ZiUT0ZKgX0`00000R0:Vmj0040000002Y_NP0ZKgX0:Vmj0D0VkO/00<0?7kU03In
iP0fO^H0101SV^l30;G2i0<0]L7S0`3Kc/`30=gAc0@0bmKR0`31en/90:Vmj0030000003oool0oooo
03<0oooo000L0?ooo`060?oog`2LB000M;oo0?ooo`3OW4P007Bo1P3oool00`000000oooo0?ooo`07
0?ooo`l0ZKgX1@2X_>P50:Nki`D0Z[kX1@2`a>T90:Vmj0D0YkOU101VL<P2075kcP@0LgS91@2YaNh4
0<S]kP80d^[VFP2Y_NP3000002H0ZKgX00@000000:Vmj02Y_NP0ZKgX1@2K]n`203ani@D0Hi[_1P2e
`N<0103Kc/`0gM7<0=gAc03MdL`30>3Dc0D0`MO[2P2Y_NP00`000000oooo0?ooo`0b0?ooo`007@3o
ool01@3ookl0M00000000000B9`0gooo00H0oooo00<000000?ooo`3oool0203oool?0:Vmj0D0Z;cX
0P2W^nL30:Nji`D0Z[kX3`2Y_NP30:Ngi@@0IW380`1aNlh408^Kg@<0ZLG^1038kNh20=;fi@80b=oY
E`2Y_NP2000002X0ZKgX00@000000:Vmj02Y_NP0ZKgX102K]n`303ani@D0IYS/1@2e`N<30=gAc0@0
h=C<00<0hmW<0<7Gj`31en/00P31en/:0:Vmj0030000003oool0oooo0380oooo000W0?ooo`030000
003oool0oooo00X0oooo3`2Y_NP40:Rlj0H0Yk[W0P2Z_^P30;34j@l0ZKgX0`2W]nD406I`b080LG_>
1@2;Vmd50<S]kP80d_KU1038gnUC0:Vmj0<00000;02Y_NP00`000000ZKgX0:Vmj0020:Vmj0@0UKC]
0`13O^@506JHk080]L7S0`2h`^400`3MdL`0h=C<0>3Dc0020>3Dc080hmW<1@2_aNX:0:Vmj0030000
003oool0oooo0340oooo000W0?ooo`030000003oool0oooo00/0oooo3`2Y_NP50:Nkj0@0Yk[W1P2`
a>T<0:Vmj0<0Xk[Y00<0GVg:0:Ngi@1VL<P00`1VL<P3075kcP80Ri_M1@2edNh20=;fi@L0b=oYC`2Y
_NP300000300ZKgX00<000000:Vmj02Y_NP00P2Y_NP409Fdk@<0@gkT101]VNX50;S2h@@0h=C<0`3S
fL`00`3Vg/`0[lGZ0:o5jP030:o5jPX0ZKgX00<000000?ooo`3oool0<03oool002L0oooo00<00000
0?ooo`3oool0303oool:0:Vmj0D0Z;cX1@2W^nP50:Zmi`D0/<CY2@2Y_NP50:>jj@80GVg:101VL<P3
075kcPH0]M7^0P3?kNT40=Obhe00ZKgX0`00000d0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0UKC]1013
O^@406fIjP<0^<;Q0P2na=l20>3Dc0<0hmW<0`3Vg/`20:o5jP`0ZKgX00<000000?ooo`3oool0<03o
ool002L0oooo0P00000>0?ooo`X0ZKgX1@2X_>P50:Jji`D0Z[gW3`2Y_NP30:>jj@<0GVg:101_OM44
09:ThP<0]M7^0P3?kNT40=Obh`80aM_ZC02Y_NP3000003P0ZKgX00@000000:Vmj02Y_NP0ZKgX102:
[nh304]ohP@0KIWZ0P2h`^440;k4g`@0hmW<0`3Vg/`?0:Vmj0030000003oool0oooo02l0oooo000W
0?ooo`030000003oool0oooo00h0oooo2P2Y_NP30:Rlj080Yk_X1@2V^^L20:Zmi`<0/LCX3`2Y_NP3
0:>jj@<0GVg:0`1_OM4509:ThP<0cngY103Gl^<40<GKjT<0ZKgX0P2Y^nH30:Vmj0<00000>`2Y_NP0
10000000ZKgX0:Vmj02Y_NP508Z_kP<0BgoR0`1gW>P50;k4g`80a/WL0P3SfL`30>KNc080h^GD3`2Y
_NP00`000000oooo0?ooo`0^0?ooo`009`3oool00`000000oooo0?ooo`0?0?ooo`X0ZKgX1@2W^nP4
0:Jji`H0/LCX2P2Y_NP50:Nmj@0305EZb`2S^^T0GVg:00<0GVg:0`1_OM4209:ThP@0_=C/0`3Cj^D6
0<GKjT40ZKgX102Y^nH3000000<0ZK[U?02Y_NP010000000ZKgX0:Vmj02Y_NP407NUk`@0BgoR0`1g
W>P30;k4g`@0a/WL0`3Vg/`40>;Ue0h0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo0P00000A
0?ooo`030000002Y_NP0ZKgX0080ZKgX1@2X_>P50:Nkj0D0ZKcW1@2aa>P:0:Vmj0@0YkgY0P1EJ//4
05i]bP<0KggA1@2le>`30=?Zi@@0f^kP@02Y_NP50:Vji@<0000000<0ZK_V0:Vji@2Y^^D0102Y^^Dl
0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0MjG_0`1CPN4407NLj0D0a/WL0P3@cmT00`3Vg/`0h^GD0>;U
e0020>;Ue080e>[T3P2Y_NP00`000000oooo0?ooo`0]0?ooo`009P3oool2000001<0oooo00<00000
0:Vmj02Y_NP00`2Y_NP40:Rlj0D0Y[[X1@2Y_>L50:^nj0X0ZKgX102W_NT205EZb`@0JWcB1@2EZ><4
0=?Zi@@0f^kP0P38gnTk0:Vmj0H0ZK[U0`0000000`2Y^^D0Zk[T0:^ji0020:^ji0D0ZK[U1@2Y^nHh
0:Vmj0030000002Y_NP0ZKgX00@0MjG_101CPN4408BQiP<0a/WL0`3@cmT40>;Ue0<0e>[T2P2Y_NP5
0:6jjP030000003oool0oooo02`0oooo00090?ooo`0:0?oo_`1d000000000018W03Oool0oooo0?oO
W01807@0_ooo0=nLB0D0000000<0M;oo0?ooo`3OW4P00P0000000`0004P0W=oo0?ooo`060?ooo`03
0000003oool0oooo01<0oooo00<000000:Vmj02Y_NP00`2Y_NP40:Nkj0D0Y[[X1P2``NL40:^nj0X0
ZKgX0`2W_NT205EZb`@0JWcB102EZ><30;kBj@D0f^kP1038gnTh0:Vmj0<0ZK_V0`2Y^^D200000080
ZK[U0`2[^N@40:^ji0D0[K_T1@2Y^nHg0:Vmj0040000002Y_NP0ZKgX0:Vmj0<0Gi?[1@1CPN4408BQ
iP040<K9g03@cmT0d<oI0=3?f@<0f]SE0`3Dj^@30;WCk@X0ZKgX102Q^^X00`000000oooo0?ooo`0:
0?ooo`050=nLB000000000000000B02Lgol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nL
B000M;l40?ooo`030?oOW0180000M;oo00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo
00H0oooo00<000000?ooo`3oool0503oool00`000000ZKgX0:Vmj0030:Vli`@0Yk_X0`2V^^P20:Nk
i`H0/<7W3P2Y_NP205Mde0<0EF[;101ZO=8209FXh`<0_];Y103DiN<40<SOjCP0ZKgX1@2Y^nH30000
0080ZK[U1P2[^N@20:^ji080[;_T1@2]^n@50:bliSL0ZKgX00@000000:Vmj02Y_NP0ZKgX0`1OTn/4
05j5h0@0Q:7V0`3@cmT40=[He@030>?Qd@2idnd0^M?]00@0^M?]2P2Y_NP40:6jjP030000003oool0
oooo00P0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo01`0oooo00080?ooo`070?oo_`1d
07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`030?oOW0180000M;oo00P0oooo00<0_g@007Boo`3o
ool01@3oool2000001H0oooo1P2Y_>L40:Nkj0D0Yk_W0`2``NL30:k2j0d0ZKgX0`1GM=@2065fdP@0
JWcB102nd^T40=CUh`<0fnWM>`2Y_NP01@2Y^nH00000000000000000ZK_V00D0ZKWU1@2[^N@50:bk
i080[K_T0`2^_ND50:bliSH0ZKgX00<0Y;_Y0000002T^nT00P2T^nT00`1JO]`0Gi?[05nCj`0405j5
h0@0U:WU00<0d<oI0=[He@3Jf=D00P3Jf=D20>?Qd@030>WYcP2idnd0^M?]00<0^M?]2P2Y_NP509fb
i`030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@00018W=l01`3oool00`2oM000M;oo0?ooo`05
0?ooo`030000003oool0oooo01L0oooo102Y_>L50:Jkj0D0Yk_W1P2^`^P=0:Vmj080EgCD0`1QM]86
09:ThP@0e>GS0`3KjMd30=?YiCL0ZKgX0`0000050:Rhi@D0ZKWU1@2[^nD40:bki0H0[[gU0P2/_>H3
0:fniSH0ZKgX00@000000:Bkj@2T^nT0Y;_Y0`1JO]`405j5h0@0U:WU103Jf=D20>?Qd@<0jNW>3`2Y
_NP409fbi`030000003oool0oooo00`0oooo00<0_g@007Boo`3oool06`3oool000P0oooo00L0okmd
0018W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00/0oooO09a80018W=l0oooo0?oOW01804P0W=oo
0?ooo`3ooml0W4Q809cOo`060?ooo`030000003oool0oooo01P0oooo1@2X^nL40:Jkj0D0[KkW1@2^
`^P;0:Vmj080J9;W0`1GM=@3065fdP<0TZCR102kbnH40=_Yg@D0dnWU<`2Y_NP3000000@0YkWV1@2X
^>D50:VjiPD0Zk_U102/_NH50:jmi@H0[KkV=P2Y_NP010000000Y;_Y0:Bkj@2T^nT305Yng0<0KH_O
1@2V]><20=[He@<0hn7A0P3YjLh20>;cf0h0ZKgX1@2R]nP00`000000oooo0?ooo`060?ooo`070?oO
W01804P0W=oo0?ooo`3ooml0W4Q809cOo`0L0?ooo`00203oool01`3ogi`0B4RL0=ooo`3oool0oono
07@0B02Lgol01`3oool01@3ookl0M01809cOo`3ookl0M00000<0000000<0M;oo0?ooo`3oool0103o
ool2000001/0oooo1@2X^nL40:Nji`D0[KkW3`2Y_NP306RBi`80DFg@101QM]850;_;iP@0d]kQ103C
jND30:^nj2l0ZKgX0`0000030:Vmj0D0YkWV0P2X^>D30:RjiPD0ZK[V0P2[^nD30:^liP@0[;gV1@2^
_nH50:fniSH0ZKgX00@0Y;_Y0000002T^nT0Y;_Y101JO]`306f;g`D0Y[CS0`3ShM420>WYcP@0h_?H
2@2Y_NP50:Bkj@D0X[OX00<000000?ooo`3oool01@3oool00`3ookl0M000000000020000000307Bo
o`3oool0oooo01/0oooo00080?ooo`070?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`03
0?noM000M;l0oooo0080oooo00D0_g@007Boo`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo
01/0oooo1@2X^nL40:Nji`<0[KkW0`2``nL>0:Vmj080J9;W0`1AKM0408NKg`<0^l_V103Bg^430=_S
f`H0ZkkX:`2Y_NP3000000L0ZKgX102W^NH60:RjiP@0ZK[V1P2[_>H20:bmiP80[KkW1@2^_nH50:g0
icH0ZKgX00@0Q:c_00000024[>l0Q:c_0`1QOmX406f;g`80Y[CS102j`n420>WYcPD0h_?H2P2Y_NP5
0:Bkj@@0X[OX00<000000?ooo`3oool01@3oool00`3ooml0W4Q809cOo`0P0?ooo`00203oool01P3o
oml0W4P007Boo`3oool0gia8001d_`@0oooo00X0oono07@0B02Lgol0oooo0?oOW01804P0W=oo0?oo
o`2oM000M;oo2@3oool00`000000oooo0?ooo`0K0?ooo`H0Z;_W102W^^L60;33i`d0ZKgX0`1XT^L3
055]d0@0Qi_O1@3Bg^430=_Sf`80g>;I1@2[_^PX0:Vmj0<000002`2Y_NP40:Jii`D0Z;[V1@2Y_>L5
0:^liPD0[KkW0P2^_nH30:k0i`D0[L3W=P2Y_NP010000000Q:c_08B/k`24[>l3065ofP<0OYKP1@2j
`n420<kCg@@0h_?H0`35iNh:0:Vmj0@0Y;_Y1@2V_>T00`000000oooo0?ooo`050?ooo`030;md001d
_ol0oooo01l0oooo00090?ooo`050?oo_`1d000000000018W03Oool01@3oool01@3ogi`0B0000000
00000000M;oo0080oooo00H0gia800000000000000000000M02oool50?ooo`030000003oool0oooo
01d0oooo102X^nL50:ZliP<0/<?W0`2/_nP90:Vmj0@0T;G`0P0mHll4055]d080Qi_O102a`>D40=_S
f`@0g>;I:P2Y_NP2000000X0ZKgX1@2U^^P40:Jii`D0Z;_W1@2Y_>L50:^ni`@0[KkW1P2^`>L20:g0
i`<0[<3X=P2Y_NP00`000000JXOM06Z7g@03065ofP@0OYKP0`2j`n430<kCg@80g^CH1@35iNh:0:Vm
j0D0XKOY102V_>T00`000000oooo0?ooo`050?ooo`060=nLB000000000000000000007@0_ooo703o
ool002D0oooo0P00000O0?ooo`D0Z;[V102Z_>H60:boj0T0ZKgX0`2@]O0303eSc`<0LX_L1@2a`>D3
0<cDh0D0g>;I0`35fnXU0:Vmj0<000003@2Y_NP50:Fjj0@0Y[_X1@2X^nL50:Vmj0D0ZkkW102]`>P5
0:k0i`H0[<3X=@2Y_NP01@1ZQmd0000006Z7g@1ZQmd0K8CI0080HGoJ101nU^040<kCg@80g^CH0P3X
lM4?0:Vmj0@0XKOY1@2Y_nT00`000000oooo0?ooo`0V0?ooo`009@3oool00`000000oooo0?ooo`0O
0?ooo`D0Z;[V1@2`_nD40:boj0X0ZKgX0`2@]O0303eSc`<0LX_L0`2a`>D40<cDh0<0f=_J1P35fnXQ
0:Vmj0<000004@2Y_NP50:Bjj0@0Y[_X0P2X^nL30:Rmj0D0ZKgX1@2[_nP40:g0j0D0[/;X1@2/`>Pe
0:Vmj00406Z7g@000000JXOM06Z7g@<0K8CI1@2DYN420<kCg@80g^CH0`3XlM400`3Pn]H0ZKgX0:Vm
j00<0:Vmj0D0XkKV1@2Y_nT00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0P
0?ooo`80Z;[V0`2Z^^H50;2oi@h0ZKgX0P0nLm`403eSc`<0LX_L1@3<e>030=SKfP<0g=cF8P2Y_NP3
00000180ZKgX0`2W_>T50:Bjj0<0Y[_X1P2X_NP20:Vmj0<0ZKoY1@2[_nP40:g1j@D0[/;X>@2Y_NP2
06Z7g@030000001ZQmd0K8CI00<0K8CI1@2DYN420=kTf0<0j?7A0`3Pn]H90:Vmj0D0YkcX1@2S]^H4
0:_0j@030000003oool0oooo02D0oooo000T0?ooo`8000008P3oool60:ZjiP80/;oU0`2b`^D>0:Vm
j080?W?L0`1DM]P509j_i080c=CP0`3HfmX30=cLeP80fM_H7P2Y_NP3000001<0ZKgX1P2W_>T40:Bj
j0D0Y[cY102X_NP60:Voj@80ZkoX0`2[`NT40:g1j@D0[L;Y=@2Y_NP408^_kP80JWoF00<0000006b4
f@1/Q=T00`1/Q=T209BUh@<0[[_S0`3XlM440>3jePX0ZKgX1@2W_>P20:>fiP<0ZKcW102[`>T00`00
0000oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`0S0?ooo`@0Z[[V1P2b`^D=0:Vmj080
?W?L101DM]P509j_i0<0f=_J0`3Lg=H40=WKf1X0ZKgX0`00000G0:Vmj0D0YkcY1@2T^nX50:Jlj@@0
Z;kY1@2Y_nT60:_1j@80[L7Y0P2]`nX50:g2jCD0ZKgX0`2;[nh306YoeP030000001lSm/0O8oK0080
O8oK102^^n<30<[EhP<0h?[F0`2lfNh:0:Vmj0@0YkcX1P2Y_>L40:_0j@030000003oool0oooo02<0
oooo000T0?ooo`030000003oool0oooo02@0oooo1@2]_>D30;;2i@80/<CY2P2Y_NP3082_lP0302mP
d@0nLm`0E7KH00<0E7KH0P2N[n@40;k6h@<0g=cF1@3IfmPG0:Vmj0<000006`2Y_NP50:Flj@D0Y;_Z
1@2V_NX40:Rnj@D0ZL3Z1@2[`NT50:g3jSD0ZKgX1@2X_NP00`1_P=@0Rjo^08^_kP0206YoeP030000
001lSm/0O8oK00<0O8oK0P2^^n<30<[EhP80gngK1P2lfNh90:Vmj0D0XkOV1@2Y_>L40:_0j@030000
003oool0oooo02<0oooo000T0?ooo`8000009P3oool50:fli@D0/<CY2P2Y_NP2082_lP80;f3A101D
M]P50;k6h@<0cm7J1@3IfmP30<SJia80ZKgX0`00000O0:Vmj0D0YKcY1@2T_N/50:JmjP@0Z;o[1@2Y
`>X50:_2j`<0[L?Z0P2/`>Pe0:Vmj0@0Z;gX0`1_P=@306YoeP030000001lSm/0O8oK0080O8oK103:
eN820=o]f`<0iO[>3P2Y_NP50:>giPD0[<3X102[`>T00`000000oooo0?ooo`0R0?ooo`008`3oool2
000002P0oooo1@2a`>D50;34j@X0ZKgX00@0:g?Q082_lP0_H=40;f3A101lUn830;k6h@@0cm7J0`3G
e=D60<SJi`l0ZKgX0P00000S0:Vmj0D0YKcY1@2T_N/50:Joj`@0Z;o[1@2Y`^/50:_2j`D0[<3X=@2Y
_NP40:Rmj0<0Kh3D0`1dQMH00`000000U:?O09BSg`0209BSg`80b]GR0P3OkM/30>GjcP80d?[U3P2Y
_NP50:NiiP@0[<3X1@2[_nP00`000000oooo0?ooo`0Q0?ooo`003@3oool02`3ookl0M00000000000
B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia80080000000<0001809cOo`3oool01`3oool00`00
0000oooo0?ooo`0W0?ooo`D0/L3U3`2Y_NP0100[Ln40;f3A02mPd@0_H=4407bGhPD0cm7J0`3Ge=D2
0=[DdP<0b=[W0`2_a>T;0:Vmj0<000009`2Y_NP40:Flj@D0Y;g[1@2V_n/40:S1k0D0ZL;[1@2[`^X4
0:c0j3D0ZKgX102X_NP406n0e0<0M8GF00<0000009BSg`2DXml00P2DXml20=o]f`<0iO[>0`3@n^D:
0:Vmj0D0YK_X102W^NH50:c1j0@0ZkoX00<000000?ooo`3oool08@3oool000`0oooo00H0oooO09a8
0018W=l0oooo0=nLB000M;l40?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`060?ooo`03
0000003oool0oooo02T0oooo0`2a`>D30;K4i@d0ZKgX0P0[Ln4304Uff`D0Xk?T0P3?dMX30=ODe@@0
f]CB1P2_a>T70:Vmj0<00000:`2Y_NP40:Nlj@D0Y;g[1@2V`>`40:S1k0D0ZL7[1@2[`^Xi0:Vmj0@0
P97J0`1dPM8307B5eP030000002DXml0U:?O00<0/l7U0P3Un/h30=3ji@d0ZKgX102U^nP20:NiiP<0
ZkoX1@2/`NP40:Znj08000008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo
00P0oooo00<0_g@007Boo`3oool01@3oool2000002/0oooo1P2fa>D90:Vmj0@0U[O_00<04eK?02]c
h@19M]/00P19M]/50:>ci0<0emCE103Je=830=[Bd0<0[lCY1@2Y_NP3000002l0ZKgX102W_>T20:Bm
j`<0YKcY1@2V`>`40:RojPD0ZL7[?P2Y_NP3082AfP@0M87B0`26U=X010000000/l7U0;?1i@2c`ND2
0=;Ui080h?cD3`2Y_NP40:Fkj0/0ZkoX102Z_^P00`000000oooo0?ooo`0O0?ooo`00303oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol0203oool00`2oM000M;oo0?ooo`050?ooo`030000003o
ool0oooo02/0oooo0`2fa>D30;;6j@T0ZKgX102F]nl201=Fc`<0BGKK0P2S/n@40;c3g`@0f]CB1@3J
d]040:Vmj0<00000<`2Y_NP30:Nlj@H0YKcY0P2V`>`30:Nlj@@0Z;oZ@P2Y_NP4082AfP<0M87B1026
U=X010000000/l7U0=;Ui03BiN@20>3le080dOo<3P2Y_NP50:Bei@<0ZkoX0`2/`NT40:^oj0@0Z[gX
00<000000?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0
oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;03oool6
0;;6j@T0ZKgX102F]nl201=Fc`80L9;T1@2l`ml20<_:f@80f]CB1@3Jd]020=C@eP<00000>P2Y_NP5
0:Flj@H0YkcY0P2X_nY00:Vmj0@0SI[L0`1hPM0407B1dP<0QYCJ00<000000=;Ui03BiN@00P3Po=@4
0=7oc0T0ZKgX1@2X_NP50:Bei@D0[<7Y0P2[_nP30:^nj0@0Z[gX00<000000?ooo`3oool07P3oool0
00`0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo00<0oono07@0000000000P00
00000`1d_ol0oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo0`2ba^T<0:Vmj080Di[b0P0C
E/l3072Bi0<0_<?O103;b]T50=[Bd0<0000000<0e=3F0:Vmj02Y_NP0@02Y_NP50:NljD80ZKgX102=
V]`407R1d0<0PHcF102R/N<010000000h?cD0>3le03Aol`50:_0j@T0ZKgX1@2X_NP50:Zmj0@0[<7Y
1P2[_^P20:Zmj080ZKgX00<000000?ooo`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo
0?oOW01807@0_ooo00<0oooo00<0oooO09a8B02Lgol02@3oool200000340oooo3`2Y_NP205>JlP03
02=Se`0CE/l0L9;T0080L9;T1@3;b]T30=;<e0<000000`3Dd=H20<_>g8T0ZKgX102=V]`307R1d0@0
PHcF0`2R/N<01@36g>X000000=Wmf@3IoMT0d?k200D0Zl3Y2@2Y_NP50:>ei@@0Z[gX1@2/`>T50:^n
j0@0ZKgX00<000000?ooo`3oool07@3oool000`0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l5
0?ooo`030;md001d_ol0oooo00P0oooo00<000000?ooo`3oool0<@3oool?0:Vmj00300EUfP1CV_80
8f?G00D0Tj[V0P3;b]T20=;<e08000000P3Ec=030=C@eP@0blkLR02Y_NP408fJg0@0N87@0`21S=H2
0::ah`80a]cZ00<0fOgI0000003@o/800P3@o/8>0:Vmj0@0XkGU1@2/`NT50:c0j@D0Z[kX102Y_NP0
0`000000oooo0?ooo`0L0?ooo`003@3oool01@3ookl0M00000000000B9`0gooo00D0oooo00H0gia8
00000000000000000000M02oool50?ooo`030000003oool0oooo0380oooo3`2Y_NP00`05IMX08f?G
02=Se`0509>ZiP<0000000<0d/cD0=G<d03Ec=000P3Ec=040<_>g0<0`/WPQ02Y_NP409:Jf0@0O8;>
0`21R]<3086<eP<0a]cZ0P3IoMT00`000000d?k20:o6jP020:o6jPh0ZKgX102Y_>L50:c1j@D0ZkoX
102Z_^P50:Vmj0030000003oool0oooo01/0oooo000R0?ooo`800000=03oool>0:Vmj0801FGJ0P0o
N^401@2/^N<00000000000000000[;WS0080d/cD103Ec=030=K:cPH0`/WPP`2Y_NP409:Jf0@0O8;>
1021R]<409VWh080fOgI00<0d?k20:o6jP0000000`2_a^X:0:Vmj0D0Y;GU102Y_>L50:c0j@@0ZkoX
2@2Y_NP00`000000oooo0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`X0ZKgX102S
^n/01000BLT000000000000000050:bih`@0eLc@103Fb/h20=K8c0<0`/WP0P2jaN:20:Vmj0@0TY[H
101lP/h4086:d`80VJOP0`2nf>d01@3Ao]X0`o^k0<?k^`2_a^X000000080[lKZ2`2Y_NP40:Bei@80
ZKcW0`2/`NT40:c0j@D0Z[kX2@2Y_NP00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo
0?ooo`0e0?ooo`030000002Y_NP0ZKgX00L0ZKgX00D0Xk_[00000000000000000019b@0303mjh@<0
[;WS0P2k`=h20=G<d0@0e/[>103Fb<`50;[5hWX0ZKgX1@2Y_>L308nBd@<0PH?<101lP/h4086:d`@0
_]S]00<0dOkJ0<?k^`33nk/00P33nk/00`2Y_NP000000:Vmj00;0:Vmj0@0Y;GU1@2/`NT20:c0j@<0
ZkoX1@2Z_^P80:Vmj0030000003oool0oooo00`0oooo00<0omnL04P0M02oool00P3oool01@3ookl0
M00000000000B9`0gooo00@0oooo000R0?ooo`030000003oool0oooo03L0oooo1P2Y_NP3000000<0
Xk_[0P00BLT305f@j@D0^l3N103Fb/h40=K8c080eLG:102jaN9k0:Vmj0@0ZKcW0`2?T]440863c0@0
Q8[A102FY=h20;kHk@030=7nfP33nk/0Zl3Y00@0Zl3Y00<000000:Vmj02Y_NP02P2Y_NP50:Vli`@0
[<7Y1P2[_nP50:Zmj0P0ZKgX0P00000<0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3o
ool0gia8001d_`@0oooo000Q0?ooo`800000>P3oool20:Vmj0<00000102Y_NP308Rcl@03001;bP00
BLT0GI3Y0080GI3Y0`2k`=h40<C3f@@0e/S<103EaLX50;K0hWX0ZKgX0`2Y_>L408nBd@<0PH?<1@24
R]4409JTgP040=7nfP35om<0c?o:0<cobP@0Zl3Y00<0ZKgX0000002Y_NP01P2Y_NP50:Bei@D0ZKcW
102/`NT30:^oj0<0Z[kX102Z_NP90:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0
oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`030?ooo`008@3oool00`000000oooo0?ooo`0h
0?ooo`<00000202Y_NP308Rcl@8004_:0`1MT>T50<C3f@80bLCE0P3Fb<`40=G5bP80e<?91@2f`>9i
0:Vmj0<0ZKcW102?T]440863c0@0Q8[A102kf_001035om<0c?o:0<cobP3<olX60:Vmj0030000002Y
_NP0ZKgX00D0ZKgX1@2T]ND90:c1j@D0Z[kX0P2Z_NP;0:Vmj0030000003oool0oooo00X0oooo00/0
omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`00
0000oooo0?ooo`0f0?ooo`8000000`3oool:0:Vmj080K:Kd0P00BlX307NQk@<0a<?I1039a=D40=G5
bP@0e<?91@2f_=md0:Vmj0D0YjOF0`28QLT308F5b`@0PH?<1@2IYn020;_Jl0030<God`3<olX0ZKgX
00P0ZKgX00<000000:Vmj02Y_NP01P2Y_NP50:Vlj0@0[<7Y1@2[_nP40:Znj0h0ZKgX00<000000?oo
o`3oool02@3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0
oooo000Q0?ooo`800000=03oool3000000H0oooo2P2Y_NP206bVm003001Ac@00BlX0Mj7]0080Mj7]
1@39a=D20<c4d`80eLG:1@3D`lT00`3C`<P0][cO0;Jlg`030;Jlgg@0ZKgX102WYmH308R5b@@0QHG;
1029SM4509VWh0040<God`2`ml00d?[U0=3ji@T0ZKgX00@000000:Vmj02Y_NP0ZKgX1@2T]>@40:Vl
j0D0[<7Y102[_nPC0:Vmj0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<00000
2@3oool;0:Vmj080Di[b00<0057=08V]k@29[Nd00P29[Nd30<W4e@@0c<CC1@3D`lT30=?0b080][cO
0`2h^M]d0:Vmj0<0YjOF1028QLT308F5b`D0RHgA0P2IYn020;cVl`040;3g`03@n^D0d?[U0=3ji@T0
ZKgX00<0ZKcW0000002Y_>L00P2Y_>L40:Bdi0X0[<7Y102Z_^PB0:Vmj0030000003oool0oooo00H0
oooo00d0_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0
oooo00040?ooo`0=0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3ookl0M018
09cOo`040?ooo`050=nLB000000000000000B02Lgol01`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003P3oool:0:Vmj080Di[b00<005G?08V]k@29[Nd00P29[Nd60<c4d`030<c3d@3D`lT0e<?90080
e<?90`3C`<P60;Rifg<0ZKgX0`2WYmH408R5b@@0QHG;1029SM430;cVl`D0d?[U2P2Y_NP00`2Y_>L0
00000:Vli`020:Vli`80Y;CT0P2Y_^P50:c1j@D0ZkoX102Z_^PB0:Vmj0030000003oool0oooo00H0
oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d_`040?ooo`000`3o
ool01P3ooml0W4P004RLg`3oool0gia8001d_`D0oooo00<0oooO09a8B02Lgol00`3oool01`3o_g@0
04RL0=ooo`3oool0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0Z0?ooo`<000004P3oool9
0:Vmj0<0Di[b00<005G?09Bdk@2D]>d00P2D]>d40<c4d`<0c<?A0P3D`lT40=?0b0040=:na`2h^M/0
^;WK0;Rif`<0_;OEJP2Y_NP50:NUd`@0U8c90`2<Q/L308Z8b`@0QHG;1P2N/^D209CVY0l0ZKgX00@0
00000:Vli`2Y_>L0ZKcW1@2Y_^P50:_0j@@0ZkoX4P2Y_NP3000000030?ooo`000000oooo00P0oooo
00<0omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00@0oooo00030?ooo`070?oo
_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`050?ooo`030;md0018W=l0oooo00L0oooo00<0_g@007Bo
o`3oool0103oool2000002T0oooo0`00000F0?ooo`T0ZKgX0`15To000`00E/d0U;C]09Bdk@0209Bd
k@80c<CC1@3<`m440=?0b0<0d[k71P2l]mEV0:Vmj0@0ZKST102WYM<409B<b@<0S8K7102:R</408nD
e0<0W[;U00<0^OO`09CVY02DiZ@00P2lfNh<0:Vmj0<0ZKWU00@000000:Bei@2T]ND0Y;GU0P2Y_^P3
0:c1j@@0Zl3Y1@2Z_^P=0:Vmj0<000001@3oool00`000000oooo0?ooo`0E0?ooo`000`3oool01`3o
gi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`3o_g@004RL0=ooo`070?ooo`030;md001d
_ol0oooo00@0oooo00<000000?ooo`3oool09@3oool3000001X0oooo2@2Y_NP304FCl003001Fc@2D
]>d0U;C]0080U;C]1@3<`m420<c2d@80dl38103B_/L00`3@_<H0_;OE0;bge@020;bge@80`[K?IP2Y
_NP30:Vhi0D0YjGC0`2DS<T408b6a`@0RXS;102?U=@00`2imo00U>JT09CVY0050;cIkPT0ZKgX1@2Y
^ND0102T]ND000000:Bei@2T]ND50:c1j@X0Z[kX2@2Y_NP3000000P0oooo00<000000?ooo`3oool0
5@3oool000<0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0oono07@0B02L
gol00P3oool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01@3oool00`000000oooo0?ooo`0R
0?ooo`<000007P3oool90:Vmj080AI?`0`00E/d309VikP<0c<?A103<`]440=:na`<0d;c60P2l]mD4
0<:fc`D0ZKSTH02Y_NP40:Vhi0@0YjGC0`2DS<T408b6a`@0RXS;102Xb?020:3ec`80/?S43P2Y_NP4
0:Vii@80Z[oY00<000000:Zoj@2Z_nT00`2/`NT20:_0j@D0Z[kX2@2Y_NP4000000`0oooo00<00000
0?ooo`3oool0503oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00H0oooo00H0
gia8001d_`3oool0oooo0?oo_`1d00030000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3o
ool07`3oool300000280oooo2@2Y_NP404FCl004001@aP2I^Nh0VKW^09VikPD0c<;A0P3;`]820=:n
a`D0d;c61@32]/l00`37]LP0ZKST0:Vhi0030:Vhi5l0ZKgX102Y^>@40:NUd`<0U8c9102<Q/L509NS
g@80Z<S`0P2PmLlB0:Vmj0@0YkWV00<0Z[oY0000002Z_nT00P2Z_nT50:_0j@80Z[kX0`2Z_NP40:Vm
j0040?ooo`000000000000000100oooo00<000000?ooo`3oool0503oool000<0oooo00L0oono07@0
M02oool0oooo0?oOW01807@0_ooo00H0oooo00L0oono07@0B02Lgol0oooo0?oog`2LB4P0W=oo00T0
oooo0P00000N0?ooo`8000009P3oool00`000000ZKgX0:Vmj0070:Vmj0<0Di[b00@004Bg09Rkl02H
^o00V;_`0`3<`]440<_2dPD0d;c60P3?^lL30<:fc`<0akG80P2Y^>@30:bZeE/0ZKgX102RULP409B9
a0@0TXS60`2@R/T4092Ad0D0Uj?M00@0X?G?0<GUkP35iNh0aNG^3@2Y_NP50:Jfi0@0YkWV00<0[<7Y
0000002/`NT00P2/`NT40:_0j@D0Z[gX0P3oool3000001<0oooo00<000000?ooo`3oool0503oool0
00<0oooo00H0oooO09a8001d_ol0oooo0=nLB000M;l80?ooo`060?noM000B9`0gooo0?ooo`2oM000
M;oo203oool2000001`0oooo0`00000Z0?ooo`T0ZKgX0`1CV_801000A;L0V;_`09Rkl02H^o050<_2
dP80b<;D0`3@_<H40<nka`030<:fc`37]LP0akG80080akG81P2/Z]EF0:Vmj0D0YYo?0`2RULP409B9
a0@0TXS60`2@R/T5092Ad080Uj?M0P2]joT40<GUkPT0ZKgX1@2Y^nH40:Jfi0D0Zl3Y00@0[<7Y0000
002/`NT0[<7Y1@2Z_^P20:Zmj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3o
okl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003
000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo2@2Y_NP3
06bVm004000aX@2A_?@0TKcd096lm0<0bl;B1038`]@00`3@_<H0ck_70<nka`030<nka`@0akG80P3<
]<<40:bZe@80^Zc<D@2Y_NP50:RWeP@0YYo?102RULP409B9a0@0TXS60`2@R/T4092Ad080[N_i0`2O
l/<=0:Vmj0D0ZK_V102Y_>P40:_0j@030:^oj0000000ZkoX0080ZkoX102Z_^P2000001X0oooo00<0
00000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool05@3oool300000380oooo2@2Y_NP3
06bVm004000aX@2A_?@0TKcd096lm0H0b<;D1@3?^lL20<fkb080akG8103<]<<20:bZe@@0^Zc<102W
Z=I90:Vmj0@0ZJgK1@2XYmH30:JOc`@0XYG8102DRL@409:8aP<0T8[9102S`Nl00`24j<H0ZKgX0:Vm
j00@0:Vmj0D0YKGT102Y_>P40:boj0030:^oj0000000ZkoX0080ZkoX0P00000M0?ooo`030000003o
ool0oooo01@0oooo000O0?ooo`8000004`3oool3000003H0oooo2@2Y_NP408Rcl@<0O[[i0`38`]@3
0<C4f@<0ck_7103=^lP50<bd``D0^Zc<0P35[l@40:NXePD0ZKcW?`2Y_NP50:VagP@0ZJgK102XYmH3
0:JOc`@0XYG81@2FSlX409JFd@@0VJCM00@0Q>S60;WCk@2idnd0^M?]3@2Y_NP50:NdhP@0YKGT2@2/
_nP300000200oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool03`3oool3
000003X0oooo2@2Y_NP40:>kj`<0O[[i1P34a=T50<fkb080c;g<0`3<]<<20<^ea0<0^Zc<1035[l@2
0:NXeP80]ZO91@2Y_>Lk0:Vmj0T0ZK7N0`2Y[M/509b<`P<0VXc4102HSLH409J?bP@0UYKA0P2IY=d2
09k^m`D0^M?]202Y_NP50:Vhh`@0YkCR1@2[_NL40:boj0<000000`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0oooo00`0oooo0`00000n0?oo
o`T0ZKgX102S^n/01000;JH0FK3k05V`n`1I/?/30<C4f@80_LOR0`3=^lP40<bmc0030<bd``3;]L@0
bkG40080bkG400<0^Zc<0<F_a035[l@00`35[l@50;JWb@D0YYk==P2Y_NP50:V]f`P0ZK7N102NSL84
09b<`P<0VXc4102HSLH509J?bP<0UYKA0P2Nk_L20;kik@<0^M?]2`2Y_NP50:Vhh`80YkCR0P2Y^^D5
0:^mi`<000001P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo000O0?oo
o`030000003oool0oooo00T0oooo0`0000120?ooo`h0ZKgX00<002fV01F?i`0ESnL01@2man800`3=
^lP0c;g<0<bmc0030<bmc0D0bkG41@35[l@20<Ra``@0]ZO900<0aJc10:JNc@2VW/d00`2VW/d40:NU
e2h0ZKgX102XYmH40:V]f`@0ZK7N1@2QS/4309j=`PD0W8c20`2JS<@409R=aP@0UXo:0`2Sd_P50;ki
k@h0ZKgX102Y^><50:Vji@80ZkgW0P00000:0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool04`3oool001h0oooo0P0000090?ooo`800000AP3oool>0:Vmj003001QeP0ESnL05HoW00@0
_LOR1@3<_L`20<S2e0<0bkG40P3;^<P30<F_a0<0b;730`2fYlT20<F/`@@0YYk=0P2lY/<40:NUe0D0
Z:OF9P2Y_NP30:JOc`@0Z:OF0`2Y[M/50:>@`@@0XHk1102NSL8409b<`P<0VXc4102HSLH50:2gj@03
06KI`P1ZeJT0J]FY0180ZKgX1@2W]>840:Vji@l0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`<00000B@3oool>0:Vmj080Di[b
00<005B_0:c<l@2/c?400P2/c?430<bmc0@0b<;D00<0bkG40<^hb03;^<P00P3;^<P00`35[l@0b;73
0<Ra``030<Ra``030;JWb@35[<40aJc10080aJc10P2VW/d30;bV``<0YjGD0P2eXL@50:RWeP@0YjGC
102Y_NP50:Vli`d0ZKgX1@2Y^>@40:Vmj0D0YYo?102XYmH40:FA`0@0Xi31102QS/4409j=`P@0W8c2
102NW]@409jWg0<0X;OY00<0I]W20:Vmj02Y_NP03P2Y_NP20:VfhP@0Y:oP102W]>800`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<0
00000?ooo`3oool00P3oool3000004d0oooo00<000000:Vmj02Y_NP02`2Y_NP305>JlP@0[<ca1P38
`]@50<^hb0H0b;731@35[<460;bV``030:NUe02eXL@0]J740080]J740P2XYmH30;:N``@0YjGC102V
WLd50:Vli`@0Z:OF1@2Y_NP40:NUd`@0ZKST1@2UUlL40:JOc`D0Yi;00`2UTL050:>@`@<0XHk1102N
SL8509nJc`@0WYkD102NYm`0101VfL80[lGZ0:o5jP2_aNX=0:Vmj0D0ZKKR102T[n000`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool001h0oooo00<0
00000?ooo`0000000P00001A0?ooo`030000002Y_NP0ZKgX00/0ZKgX0`2F]nl407g9o`<0b<;D0`2n
c>@30<^hb080b;oA1038/L<20<Rfb0@0aJc100<0a[340;bV``2lY/<00`2lY/<50;FQa0H0/Yk30P2W
YM<20;BN`P@0YYg=1@2TU<@40:RWePD0Y9G6102WYM<40:JB`@D0YIO70P2VWll20:VD`0@0Yi;0102U
TL040:>@`@<0XHk11@2QV<`409nJc`@0WYkD0P25jNd20;_Ml@@0[lGZ3P2Y_NP40:VfhP030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0C0?ooo`007P3oool2
000005D0oooo00<000000:Vmj02Y_NP03`2Y_NP307g9o`H0_/cT00<0bkS80<Rod@38_m400P38_m42
0<Ra``<0b;K80`35[<420<J`a0@0_:K30P33Zl840;FQa0030<2X`@2bW/<0/Yk300<0/Yk3102dW/83
0:JMc@80^9no1@2TU<@20:RWeP80/9W01@2TULH20:NUd`80[iRo0`2VT/450:FGa`@0ZIC01@2WT/03
0:FA`0@0Xi31102SV<X40:6Hc0@0Wi[?102Hi?d50;_MlA40ZKgX0P00000O0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool04`3oool001<0oooo00<0omnL04P0M02oool02@3oool00`00
0000oooo0?ooo`1D0?ooo`030000002Y]^80ZKKR0080ZKKR3@2Y_NP0100;Kml01Y3H00J@f006T=P4
0;k<i0D0b;oA1P38]/P00`35[<40a[340<J`a0020<J`a080_:K30`33Zl830;FQa080`:S1102bW/<2
0;jV`P@0]9k200@0YYg=0;RO_`2hWkl0^9no1@2TU<@40;2I`0D0Y9G6102_V;l40:JB`@80YIO70`2/
V<440:VD`0@0Yi;00`2UTL050:FIb@<0XiS:1@2QV<`209nJc`<0X=Wk0`2^k?PB0:Vmj0030000003o
ool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`004`3oool0
0`3ogi`0B01d0;ooo`0:0?ooo`800000EP3oool40:VfhPd0ZKgX1020[o8409WFo@<0b;oA0P2ocnH5
0<Rfb0D0a[341P33Zl800`2eXL@0`:S10<2X`@020<2X`@80/Yk30`2nY/840;BN`PD0^9no0`2TU<@2
0;NO`0@0/9W00P2TULH30;>L`@@0[iRo0`2VT/450:bH`@@0ZIC0102WT/040:RKb@@0YIW9102SV<X4
0:6Hc0<0X=Wk0P2Fk_<A0:Vmj08000009`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00`0oooo00<000000?ooo`3oool0E03oool20:Vf
hP80/K[Q4P2Y_NP309WFo@D0_loV0P38]/P30<K3e`<0a[340P36^ll50<>[`PD0`:S11@2nY/830;BN
`P80_:K3102hWkl20:BDa0<0]io0102`VL050;>L`@@0[iRo0P2VT/420:nLa0D0[9S10`2YU<050:^O
b`<0Z9_91@2UVLT30:>HbPD0Y=3g4P2Y_NP2000002/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0=0?ooo`030000003oool0oooo05<0
oooo1@2a^^450:Vhh`d0ZKgX0`0=L=l40;o?iPH0a/?G00<0a[340<Jkc`36^ll00P36^ll20<>[`P<0
aKK<0`30Z<420<>dc0@0_ZK20P2dW/830;bV``@0^9no1P2gWl020;2I`080]j?5102cW<440:nH_`@0
[ic41@2/V<420:VD`080[ZG?102[Wl/40:RKb@@0YIW91@2Vbo<A0:Vmj0800000<03oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo00h0oooo
00<000000?ooo`3oool0D`3oool30;6jh@80]KoQ1@2Y^><=0:Vmj0<0T;G`1021fOh50<K3e`D0a[_?
1P35]/`01030Z<40`kC<0<>dc033]<`40;jV`PH0_:K30P2hWkl20;^YaPD0]io000@0/9W00;NSa@2g
XlD0]j?5102cW<420:nH_`<0/jC8102_W<@40:bH`@@0[ZG?1@2[Wl/30:RKb@D0Ylcc4@2Y_NP30000
03<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`3ogi`0
B01d0;ooo`0?0?ooo`030000003oool0oooo05<0oooo1@2e_n450:nlha40ZKgX0`1GVo850:oMm`<0
a[_?0P2kenh50<Ffc0D0`kC<0P2nY/820<6fc`D0_:K3102kZLH50;NO`0D0]j?50`2cW<450;>Tb0@0
[ic41@2a[mH40:jUc`@0Zio;1@2XdODA0:Vmj0<00000=`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0180oooo000A0?ooo`050;md000004P0W;nL04P0M02oool0403oool2000005@0
oooo0`2e_n420;;1i@D0[kcS102Y^nHA0:Vmj00401mkiP2_gOL0[mgg0:oMm`D0^mO^0P35]/`30;kD
j`@0`kC<1@31]/l20;bV``<0`;cF102kZLH20;NO`0<0^k7?102gXlD20;>L`@80^;3B1@2cY<P20:nL
a080];kQ102a[mH40:jUc`D0YM[j4@2Y_NP3000003`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0B0?ooo`004P3oool0103o_g@000000000M02ooolB0?ooo`030000003oool0oooo
0580oooo1@2b`ND50;:oi0@0ZK_V4@2Y_NP50:Nmj@<0^mO^1P2ne>/20<>dc080^mS^1031]/l50<2l
eP@0^jW61@2k/Ll40;NSa@D0^;3B102cY<P50;Bnh@<0/JoF1P2Hi?dA0:Vmj0<00000@03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0180oooo000C0?ooo`030?oOW01807@0_ooo01<0
oooo00<000000?ooo`3oool0DP3oool30;;1i@80[L7X1@2b_n@40:^ii140ZKgX1@2W_NT40:>kj`@0
_]C[1@2kf>h20<6fc`80/N;h1@30_=H20;^YaP80_<gV102k/Ll50;[7i@@0^;3B1@2aeO<40;Bnh@D0
KmkZ0P2A^o<?0:Vmj0@00000@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo000Z0?ooo`030000003oool0oooo0580oooo1@2]`NP50;31iP@0ZkWT102Y^NDG0:Vmj0@0YkgY
0`2kf>h50;7Rn0@0`;cF1@2lcNH20;^ac`80XNOk1@2janD508[Vn0@0/MGc102Y_NP40:>kjPh0ZKgX
0`0000180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool002/0oooo0P00
001D0?ooo`@0Z/7Z1@2``NH40;2ni0@0ZKWU1@2Y_>LJ0:Vmj0<0/N;h1P25iOH30;c=iPD0XNOk00<0
Pjoa0:Vmj02Y_NP00P2Y_NP409NgkQH0ZKgX00@0oooo0000000000000000C03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0140oooo000]0?ooo`030000003oool0oooo0580oooo102Z
`NX50:[0j@@0/;kT102]^n@50:VlidH0ZKgX1000001?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool002h0oooo00<000000?ooo`3oool0DP3oool40:RojPD0Z/3Y102]_nP4
0:fki0D0Z[SS@P2Y_NP3000005@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A
0?ooo`00;`3oool00`000000oooo0?ooo`1B0?ooo`@0Z;oZ1@2W_^/40:foj0@0/;oV1@2Z^><50:Vg
h`@0ZKSS=02Y_NP0103oool0000000000000001H0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00300oooo00<000000?ooo`3oool0DP3oool40:RnjPD0Ykk[102W_nX40;2o
iPD0/;oU0P2Y]n<30:nni@@0ZKSS102Y]n<50:Vmj0@0ZKcW8`2Y_NP4000005`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00<@3oool2000005<0oooo102X_^X50:JnjP@0
YkoZ102Y_nX40;2oi@H0[kkU0P2Y^><20:nni0T0ZKOS102Y_>L40:Vii@@0ZKgX1@2Y^nH40:Vmj0@0
ZKSS102Y_NP50:VfhP040?ooo`000000000000000600oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`00<`3oool00`000000oooo0?ooo`1A0?ooo`@0Z;kY1@2V_^X40:Jnj`@0
ZKoZ102Z`>T50:nni@D0[kkT102__^D40:Vgh`D0Z[SS102Y^ND40:Vgh`@0ZK_V1@2Y]N440:Vhh`@0
ZK7N0`2Y]^82000006@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`00
=03oool00`000000oooo0?ooo`1A0?ooo`@0Z;kY1@2W_NT80:Jnj`h0Z/3Y102__^D40:noiPD0Z[SS
102]^n@40:Vgh`@0ZkOR1@2Y]N440:ngg`@0ZK7NJ@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo000e0?ooo`030000003oool0oooo0540oooo102Y_NP:0:Nmj@<0Y[k[1@2V
_n/50:Noj`@0Z/3Y102Y`>X40:noiPD0[L3X102]^n@40:jni@@0ZkOR1@2/^n@40:nggf`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=P3oool200000580oooo102Y_NP6
0:Rmj0@0Z;gY202W_^X90:Noj`@0ZL3Z102X`>/40:g0j0D0Z/3Y102^_^D40:Vmi`@0[;_T00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000h0?oo
o`030000003oool0oooo0500oooo2P2Y_NP80:Rmj@T0YkkZ202W_n/40:S0j`@0Yko[1@2Z`>T40:Nn
j@@0ZKgWM@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000i0?ooo`03
0000003oool0oooo0540oooo3@2Y_NP80:Rmj@T0YkkZ102W_n/40:NnjP@0Yko[1@2W_^X40:NnjGT0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`00>P3oool00`000000oooo
0?ooo`1A0?oooa40ZKgX202X_NT50:NnjP@0Z;kY102W_^X40:Nmj@@0YkkZ00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000k0?ooo`030000003o
ool0oooo0540oooo5@2Y_NP40:Rmj@D0Z;gX102X_^T50:Rmj@<0YkgYP@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00l0oooo000l0?ooo`800000DP3ooolI0:Vmj0@0Z;gX1@2Y_NP0
103oool000000000000000250?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3o
ool003h0oooo00<000000?ooo`3oool0D03ooolN0:Vmj0@00000R@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo000o0?ooo`030000003oool0oooo0500oooo6P2Y_NP30000
08d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`00@03oool00`000000
oooo0?ooo`1@0?oooaH0ZKgX0`00002A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00440oooo0P00001A0?oooa80ZKgX0`00002E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03`3oool004<0oooo00<000000?ooo`3oool0C`3oool=0:Vmj0<00000V@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00140?ooo`030000003oool0
oooo0500oooo202Y_NP3000009d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?
0?ooo`00A@3oool00`000000oooo0?ooo`1@0?ooo`@0ZKgX0`00002Q0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03P3oool004H0oooo0P00001A0?ooo`800000YP3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00180?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00190?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00h0oooo001:0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001;0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00h0oooo001<0?ooo`800000B`3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool004l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool00500oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool0
0540oooo0P0000160?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`00D`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0:`0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00E03oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005D0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2^0?ooo`040000003oool0oooo000000l0oooo001F0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0000000?0?ooo`00
E`3oool2000003l0oooo00<000000?ooo`3oool0/03oool00`000000oooo0000000>0?ooo`00F@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00FP3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00F`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0;40oooo0P00000>0?ooo`00G03oool2000003X0
oooo00<000000?ooo`3oool0[@3oool400000100oooo001N0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0Z@3oool4000001@0oooo001O0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0Y@3oool4000001P0oooo001P0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0X@3oool4000001`0oooo001Q0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0WP3oool300000200oooo001R0?ooo`800000=03oool00`000000oooo0?ooo`2J0?ooo`@0
00008`3oool006@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2F0?ooo`@00000
9`3oool006D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000:`3o
ool006H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2>0?ooo`@00000;`3oool0
06L0oooo0P00000_0?ooo`030000003oool0oooo08X0oooo1000000c0?ooo`00J@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo08L0oooo0`00000g0?ooo`00JP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo08<0oooo1000000j0?ooo`00J`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo07l0oooo1000000n0?ooo`00K03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo07/0oooo100000120?ooo`00K@3oool2000002T0oooo00<000000?oo
o`3oool0M`3oool4000004H0oooo001_0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0M@3oool3000004X0oooo001`0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
L@3oool4000004d0oooo001a0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3o
ool400000540oooo001b0?ooo`8000008`3oool00`000000oooo0?ooo`1Y0?ooo`@00000E@3oool0
07@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1U0?ooo`@00000F@3oool007D0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R0?ooo`<00000G@3oool007H0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`@00000H03oool007L0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@00000I03oool007P0oooo0P00000M
0?ooo`030000003oool0oooo05H0oooo1000001X0?ooo`00NP3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0580oooo1000001/0?ooo`00N`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo04h0oooo1000001`0?ooo`00O03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo04/0oooo0`00001d0?ooo`00O@3oool2000001P0oooo00<000000?ooo`3oool0A`3o
ool4000007L0oooo001o0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool4
000007/0oooo00200?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?`3oool40000
07l0oooo00210?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool4000008<0
oooo00220?ooo`8000004`3oool00`000000oooo0?ooo`0h0?ooo`<00000Q`3oool008@0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@00000RP3oool008D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000SP3oool008H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000TP3oool008L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0X0?ooo`@00000UP3oool008P0oooo0P00000=0?ooo`030000
003oool0oooo02D0oooo0`00002J0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0280oooo1000002M0?ooo`00R`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01h0oooo1000002Q0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo1000002U0?ooo`00S@3oool2000000L0oooo00<000000?ooo`3oool05P3oool400000:T0
oooo002?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool400000:d0oooo
002@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool300000;40oooo002A
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000;@0oooo002B0?oo
o`050000003oool0oooo0?ooo`0000002@3oool400000;P0oooo002C0?ooo`80000000<0oooo0000
003oool0103oool400000;`0oooo002E0?ooo`80000000<0oooo0000000000000P0000300?ooo`00
UP3oool200000<@0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0
oooo003o0?oooed0oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -18.375 -10.5763 ]
[.02757 .24618 0 .36123 ]
[.17646 .18758 -13.7039 -10.9375 ]
[.17646 .18758 .23359 0 ]
[.3345 .12542 -7.8563 -10.9375 ]
[.3345 .12542 .5812 0 ]
[.50253 .05935 -7.41651 -10.9375 ]
[.50253 .05935 1.02099 0 ]
[.68156 -0.01098 -10.646 -10.9375 ]
[.68156 -0.01098 2.22904 0 ]
[.70096 -0.00478 0 -7.61014 ]
[.70096 -0.00478 18.375 3.32736 ]
[.78313 .12104 0 -7.46008 ]
[.78313 .12104 13.9375 3.47742 ]
[.8565 .23339 0 -7.32967 ]
[.8565 .23339 8.4375 3.60783 ]
[.9224 .33431 0 -7.21529 ]
[.9224 .33431 8.4375 3.72221 ]
[.98191 .42546 0 -7.11416 ]
[.98191 .42546 12.875 3.82334 ]
[.02494 .25992 -8.4375 -3.32736 ]
[.02494 .25992 0 7.61014 ]
[.01611 .31527 -19.5625 -3.38421 ]
[.01611 .31527 0 7.55329 ]
[.00696 .37264 -15.125 -3.44336 ]
[.00696 .37264 0 7.49414 ]
[-0.00254 .43215 -19.5625 -3.50495 ]
[-0.00254 .43215 0 7.43255 ]
[-0.0124 .49393 -8.4375 -3.56913 ]
[-0.0124 .49393 0 7.36837 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -11.6101 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -11.4601 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -11.3297 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -11.2153 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.1142 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -69.4375 -7.32736 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -80.5625 -7.38421 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -76.125 -7.44336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -80.5625 -7.50495 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -69.4375 -7.56913 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .907 r
.39907 .59314 .40529 .59895 .41573 .59581 .40953 .58998 Mtetra
.40953 .58998 .41573 .59581 .42621 .59265 .42004 .58681 Mtetra
.42004 .58681 .42621 .59265 .43673 .58949 .43059 .58362 Mtetra
.43059 .58362 .43673 .58949 .44729 .58632 .44117 .58042 Mtetra
.663 .741 .908 r
.44117 .58042 .44729 .58632 .45789 .58314 .4518 .57724 Mtetra
.661 .741 .909 r
.4518 .57724 .45789 .58314 .46854 .57998 .46247 .57408 Mtetra
.659 .741 .911 r
.46247 .57408 .46854 .57998 .47922 .57686 .47318 .57099 Mtetra
.656 .742 .913 r
.47318 .57099 .47922 .57686 .48995 .57383 .48394 .56797 Mtetra
.654 .742 .915 r
.48394 .56797 .48995 .57383 .50072 .57091 .49474 .56499 Mtetra
.657 .742 .913 r
.49474 .56499 .50072 .57091 .51153 .56806 .50558 .5619 Mtetra
.668 .738 .903 r
.50558 .5619 .51153 .56806 .52239 .56513 .51647 .5585 Mtetra
.682 .729 .885 r
.51647 .5585 .52239 .56513 .5333 .56185 .5274 .55458 Mtetra
.67 .707 .876 r
.5274 .55458 .5333 .56185 .54424 .55797 .53837 .55103 Mtetra
.664 .715 .887 r
.53837 .55103 .54424 .55797 .55522 .55384 .54938 .5477 Mtetra
.664 .741 .907 r
.54938 .5477 .55522 .55384 .56625 .55052 .56044 .54436 Mtetra
.56044 .54436 .56625 .55052 .57732 .54719 .57154 .541 Mtetra
.57154 .541 .57732 .54719 .58844 .54384 .58269 .53763 Mtetra
.58269 .53763 .58844 .54384 .59961 .54048 .59388 .53425 Mtetra
.59388 .53425 .59961 .54048 .61081 .53711 .60512 .53085 Mtetra
.60512 .53085 .61081 .53711 .62207 .53373 .6164 .52744 Mtetra
.6164 .52744 .62207 .53373 .63336 .53033 .62773 .52401 Mtetra
.62773 .52401 .63336 .53033 .64471 .52691 .63911 .52058 Mtetra
.63911 .52058 .64471 .52691 .6561 .52349 .65053 .51712 Mtetra
.65053 .51712 .6561 .52349 .66753 .52005 .662 .51366 Mtetra
.662 .51366 .66753 .52005 .67902 .51659 .67351 .51018 Mtetra
.67351 .51018 .67902 .51659 .69055 .51312 .68508 .50668 Mtetra
.68508 .50668 .69055 .51312 .70212 .50964 .69669 .50317 Mtetra
.69669 .50317 .70212 .50964 .71375 .50614 .70834 .49965 Mtetra
.70834 .49965 .71375 .50614 .72542 .50263 .72005 .49611 Mtetra
.72005 .49611 .72542 .50263 .73714 .4991 .7318 .49256 Mtetra
.7318 .49256 .73714 .4991 .74891 .49556 .7436 .48899 Mtetra
.7436 .48899 .74891 .49556 .76073 .49201 .75545 .4854 Mtetra
.75545 .4854 .76073 .49201 .77259 .48844 .76735 .48181 Mtetra
.76735 .48181 .77259 .48844 .78451 .48485 .7793 .47819 Mtetra
.7793 .47819 .78451 .48485 .79647 .48125 .7913 .47457 Mtetra
.7913 .47457 .79647 .48125 .80856 .47849 .80335 .47092 Mtetra
.657 .712 .889 r
.80335 .47092 .80856 .47849 .82068 .47546 .81547 .46751 Mtetra
.646 .698 .884 r
.81547 .46751 .82068 .47546 .8328 .47181 .82768 .46447 Mtetra
.661 .722 .894 r
.82768 .46447 .8328 .47181 .84494 .46781 .8399 .4609 Mtetra
.67 .739 .902 r
.8399 .4609 .84494 .46781 .85712 .46372 .85214 .457 Mtetra
.673 .748 .907 r
.85214 .457 .85712 .46372 .86935 .4597 .86442 .45299 Mtetra
.671 .748 .908 r
.86442 .45299 .86935 .4597 .88165 .45579 .87675 .44901 Mtetra
.668 .746 .908 r
.87675 .44901 .88165 .45579 .89401 .45197 .88915 .44511 Mtetra
.666 .743 .908 r
.88915 .44511 .89401 .45197 .90643 .44819 .9016 .44127 Mtetra
.665 .742 .908 r
.9016 .44127 .90643 .44819 .91891 .44442 .91411 .43746 Mtetra
.664 .741 .907 r
.91411 .43746 .91891 .44442 .93144 .44065 .92668 .43365 Mtetra
.92668 .43365 .93144 .44065 .94402 .43686 .9393 .42983 Mtetra
.9393 .42983 .94402 .43686 .95666 .43306 .95198 .42599 Mtetra
.95198 .42599 .95666 .43306 .96935 .42924 .96471 .42215 Mtetra
.39281 .58729 .39907 .59314 .40953 .58998 .4033 .58411 Mtetra
.4033 .58411 .40953 .58998 .42004 .58681 .41383 .58091 Mtetra
.663 .741 .907 r
.41383 .58091 .42004 .58681 .43059 .58362 .4244 .57771 Mtetra
.663 .741 .908 r
.4244 .57771 .43059 .58362 .44117 .58042 .43501 .57451 Mtetra
.661 .741 .909 r
.43501 .57451 .44117 .58042 .4518 .57724 .44567 .57136 Mtetra
.658 .742 .912 r
.44567 .57136 .4518 .57724 .46247 .57408 .45636 .56828 Mtetra
.655 .745 .916 r
.45636 .56828 .46247 .57408 .47318 .57099 .4671 .56525 Mtetra
.656 .748 .918 r
.4671 .56525 .47318 .57099 .48394 .56797 .47788 .56219 Mtetra
.666 .75 .913 r
.47788 .56219 .48394 .56797 .49474 .56499 .48871 .55882 Mtetra
.684 .743 .896 r
.48871 .55882 .49474 .56499 .50558 .5619 .49959 .5549 Mtetra
.665 .713 .884 r
.49959 .5549 .50558 .5619 .51647 .5585 .5105 .55154 Mtetra
.664 .715 .886 r
.5105 .55154 .51647 .5585 .5274 .55458 .52145 .54821 Mtetra
.664 .733 .901 r
.52145 .54821 .5274 .55458 .53837 .55103 .53245 .54487 Mtetra
.664 .741 .907 r
.53245 .54487 .53837 .55103 .54938 .5477 .5435 .54152 Mtetra
.5435 .54152 .54938 .5477 .56044 .54436 .55459 .53815 Mtetra
.55459 .53815 .56044 .54436 .57154 .541 .56572 .53477 Mtetra
.56572 .53477 .57154 .541 .58269 .53763 .5769 .53137 Mtetra
.5769 .53137 .58269 .53763 .59388 .53425 .58812 .52797 Mtetra
.645 .735 .915 r
.58812 .52797 .59388 .53425 .60512 .53085 .5994 .52511 Mtetra
.576 .73 .947 r
.5994 .52511 .60512 .53085 .6164 .52744 .61077 .52376 Mtetra
.544 .803 .993 r
.61077 .52376 .6164 .52744 .62773 .52401 .62219 .52202 Mtetra
.485 .848 .991 r
.62219 .52202 .62773 .52401 .63911 .52058 .63365 .51983 Mtetra
.415 .851 .936 r
.63365 .51983 .63911 .52058 .65053 .51712 .64515 .51718 Mtetra
.366 .835 .873 r
.64515 .51718 .65053 .51712 .662 .51366 .65669 .51409 Mtetra
.361 .833 .841 r
.65669 .51409 .662 .51366 .67351 .51018 .66826 .51059 Mtetra
.404 .858 .854 r
.66826 .51059 .67351 .51018 .68508 .50668 .67986 .50667 Mtetra
.492 .902 .903 r
.67986 .50667 .68508 .50668 .69669 .50317 .69149 .50232 Mtetra
.6 .933 .956 r
.69149 .50232 .69669 .50317 .70834 .49965 .70313 .4975 Mtetra
.688 .918 .971 r
.70313 .4975 .70834 .49965 .72005 .49611 .71479 .49221 Mtetra
.729 .857 .941 r
.71479 .49221 .72005 .49611 .7318 .49256 .72646 .48653 Mtetra
.682 .766 .915 r
.72646 .48653 .7318 .49256 .7436 .48899 .73826 .48236 Mtetra
.664 .741 .907 r
.73826 .48236 .7436 .48899 .75545 .4854 .75014 .47875 Mtetra
.75014 .47875 .75545 .4854 .76735 .48181 .76208 .47513 Mtetra
.76208 .47513 .76735 .48181 .7793 .47819 .77406 .47149 Mtetra
.77406 .47149 .7793 .47819 .7913 .47457 .7861 .46783 Mtetra
.7861 .46783 .7913 .47457 .80335 .47092 .79818 .46416 Mtetra
.79818 .46416 .80335 .47092 .81547 .46751 .81032 .46047 Mtetra
.664 .733 .901 r
.81032 .46047 .81547 .46751 .82768 .46447 .82251 .45677 Mtetra
.663 .714 .887 r
.82251 .45677 .82768 .46447 .8399 .4609 .83475 .45309 Mtetra
.645 .705 .89 r
.83475 .45309 .8399 .4609 .85214 .457 .8471 .45 Mtetra
.662 .736 .905 r
.8471 .45 .85214 .457 .86442 .45299 .85946 .44633 Mtetra
.67 .752 .912 r
.85946 .44633 .86442 .45299 .87675 .44901 .87183 .44236 Mtetra
.671 .753 .912 r
.87183 .44236 .87675 .44901 .88915 .44511 .88426 .43833 Mtetra
.669 .749 .91 r
.88426 .43833 .88915 .44511 .9016 .44127 .89674 .43436 Mtetra
.666 .745 .909 r
.89674 .43436 .9016 .44127 .91411 .43746 .90928 .43046 Mtetra
.665 .742 .908 r
.90928 .43046 .91411 .43746 .92668 .43365 .92189 .4266 Mtetra
.664 .741 .907 r
.92189 .4266 .92668 .43365 .9393 .42983 .93455 .42274 Mtetra
.93455 .42274 .9393 .42983 .95198 .42599 .94727 .41888 Mtetra
.94727 .41888 .95198 .42599 .96471 .42215 .96004 .415 Mtetra
.3865 .5814 .39281 .58729 .4033 .58411 .39701 .57819 Mtetra
.663 .741 .907 r
.39701 .57819 .4033 .58411 .41383 .58091 .40757 .57498 Mtetra
.663 .741 .908 r
.40757 .57498 .41383 .58091 .4244 .57771 .41817 .57178 Mtetra
.661 .741 .91 r
.41817 .57178 .4244 .57771 .43501 .57451 .42881 .56862 Mtetra
.657 .742 .913 r
.42881 .56862 .43501 .57451 .44567 .57136 .43948 .56555 Mtetra
.654 .745 .916 r
.43948 .56555 .44567 .57136 .45636 .56828 .4502 .56254 Mtetra
.658 .749 .917 r
.4502 .56254 .45636 .56828 .4671 .56525 .46097 .55941 Mtetra
.673 .75 .909 r
.46097 .55941 .4671 .56525 .47788 .56219 .47179 .55582 Mtetra
.678 .736 .894 r
.47179 .55582 .47788 .56219 .48871 .55882 .48265 .55205 Mtetra
.664 .72 .891 r
.48265 .55205 .48871 .55882 .49959 .5549 .49354 .54873 Mtetra
.664 .74 .906 r
.49354 .54873 .49959 .5549 .5105 .55154 .50449 .54539 Mtetra
.664 .741 .907 r
.50449 .54539 .5105 .55154 .52145 .54821 .51547 .54204 Mtetra
.51547 .54204 .52145 .54821 .53245 .54487 .5265 .53867 Mtetra
.5265 .53867 .53245 .54487 .5435 .54152 .53757 .53529 Mtetra
.53757 .53529 .5435 .54152 .55459 .53815 .54869 .5319 Mtetra
.627 .729 .921 r
.54869 .5319 .55459 .53815 .56572 .53477 .55986 .52952 Mtetra
.446 .695 .972 r
.55986 .52952 .56572 .53477 .5769 .53137 .57113 .5301 Mtetra
.147 .675 .87 r
.57113 .5301 .5769 .53137 .58812 .52797 .58246 .53028 Mtetra
.203 0 0 r
.58246 .53028 .58812 .52797 .5994 .52511 .59385 .52977 Mtetra
.301 0 0 r
.59385 .52977 .5994 .52511 .61077 .52376 .60528 .52847 Mtetra
.253 0 0 r
.60528 .52847 .61077 .52376 .62219 .52202 .61676 .52645 Mtetra
.19 0 0 r
.61676 .52645 .62219 .52202 .63365 .51983 .62828 .52386 Mtetra
.125 0 0 r
.62828 .52386 .63365 .51983 .64515 .51718 .63984 .52086 Mtetra
.067 0 0 r
.63984 .52086 .64515 .51718 .65669 .51409 .65144 .51757 Mtetra
.027 0 0 r
.65144 .51757 .65669 .51409 .66826 .51059 .66308 .51405 Mtetra
.006 0 0 r
.66308 .51405 .66826 .51059 .67986 .50667 .67476 .51031 Mtetra
0 0 0 r
.67476 .51031 .67986 .50667 .69149 .50232 .68647 .50627 Mtetra
.68647 .50627 .69149 .50232 .70313 .4975 .6982 .50182 Mtetra
.6982 .50182 .70313 .4975 .71479 .49221 .70995 .49678 Mtetra
.70995 .49678 .71479 .49221 .72646 .48653 .72169 .49102 Mtetra
.72169 .49102 .72646 .48653 .73826 .48236 .73342 .48444 Mtetra
.489 .884 .719 r
.73342 .48444 .73826 .48236 .75014 .47875 .74513 .47715 Mtetra
.77 .956 .932 r
.74513 .47715 .75014 .47875 .76208 .47513 .75683 .46944 Mtetra
.696 .787 .921 r
.75683 .46944 .76208 .47513 .77406 .47149 .76878 .46473 Mtetra
.664 .741 .907 r
.76878 .46473 .77406 .47149 .7861 .46783 .78085 .46104 Mtetra
.78085 .46104 .7861 .46783 .79818 .46416 .79297 .45734 Mtetra
.79297 .45734 .79818 .46416 .81032 .46047 .80514 .45363 Mtetra
.80514 .45363 .81032 .46047 .82251 .45677 .81737 .4499 Mtetra
.81737 .4499 .82251 .45677 .83475 .45309 .82964 .44615 Mtetra
.664 .74 .906 r
.82964 .44615 .83475 .45309 .8471 .45 .84197 .44239 Mtetra
.65 .715 .895 r
.84197 .44239 .8471 .45 .85946 .44633 .8544 .43908 Mtetra
.655 .728 .903 r
.8544 .43908 .85946 .44633 .87183 .44236 .86687 .43558 Mtetra
.669 .75 .911 r
.86687 .43558 .87183 .44236 .88426 .43833 .87934 .43161 Mtetra
.672 .754 .912 r
.87934 .43161 .88426 .43833 .89674 .43436 .89185 .42751 Mtetra
.67 .75 .911 r
.89185 .42751 .89674 .43436 .90928 .43046 .90442 .42348 Mtetra
.667 .745 .909 r
.90442 .42348 .90928 .43046 .92189 .4266 .91706 .41952 Mtetra
.665 .742 .908 r
.91706 .41952 .92189 .4266 .93455 .42274 .92976 .41561 Mtetra
.664 .741 .908 r
.92976 .41561 .93455 .42274 .94727 .41888 .94251 .4117 Mtetra
.664 .741 .907 r
.94251 .4117 .94727 .41888 .96004 .415 .95533 .40779 Mtetra
.664 .741 .908 r
.38014 .57547 .3865 .5814 .39701 .57819 .39068 .57224 Mtetra
.663 .741 .908 r
.39068 .57224 .39701 .57819 .40757 .57498 .40127 .56903 Mtetra
.661 .741 .91 r
.40127 .56903 .40757 .57498 .41817 .57178 .41189 .56587 Mtetra
.657 .742 .913 r
.41189 .56587 .41817 .57178 .42881 .56862 .42255 .56279 Mtetra
.654 .745 .917 r
.42255 .56279 .42881 .56862 .43948 .56555 .43325 .55979 Mtetra
.659 .749 .917 r
.43325 .55979 .43948 .56555 .4502 .56254 .444 .55661 Mtetra
.679 .75 .904 r
.444 .55661 .4502 .56254 .46097 .55941 .45481 .55284 Mtetra
.672 .728 .892 r
.45481 .55284 .46097 .55941 .47179 .55582 .46565 .54924 Mtetra
.664 .727 .896 r
.46565 .54924 .47179 .55582 .48265 .55205 .47653 .5459 Mtetra
.664 .741 .907 r
.47653 .5459 .48265 .55205 .49354 .54873 .48746 .54255 Mtetra
.48746 .54255 .49354 .54873 .50449 .54539 .49843 .53919 Mtetra
.49843 .53919 .50449 .54539 .51547 .54204 .50944 .53581 Mtetra
.50944 .53581 .51547 .54204 .5265 .53867 .5205 .53242 Mtetra
.605 .722 .927 r
.5205 .53242 .5265 .53867 .53757 .53529 .5316 .53058 Mtetra
.33 .661 .973 r
.5316 .53058 .53757 .53529 .54869 .5319 .54278 .53215 Mtetra
.156 0 0 r
.54278 .53215 .54869 .5319 .55986 .52952 .55403 .53314 Mtetra
.324 0 0 r
.55403 .53314 .55986 .52952 .57113 .5301 .56535 .53298 Mtetra
.161 0 0 r
.56535 .53298 .57113 .5301 .58246 .53028 .57671 .53156 Mtetra
0 0 0 r
.57671 .53156 .58246 .53028 .59385 .52977 .58812 .52907 Mtetra
.477 .882 .948 r
.58812 .52907 .59385 .52977 .60528 .52847 .59956 .5258 Mtetra
.628 .876 .988 r
.59956 .5258 .60528 .52847 .61676 .52645 .61103 .52208 Mtetra
.668 .818 .955 r
.61103 .52208 .61676 .52645 .62828 .52386 .62255 .51818 Mtetra
.674 .772 .924 r
.62255 .51818 .62828 .52386 .63984 .52086 .63411 .51429 Mtetra
.67 .742 .904 r
.63411 .51429 .63984 .52086 .65144 .51757 .64573 .51055 Mtetra
.663 .727 .897 r
.64573 .51055 .65144 .51757 .66308 .51405 .6574 .50701 Mtetra
.656 .724 .899 r
.6574 .50701 .66308 .51405 .67476 .51031 .66913 .50366 Mtetra
.651 .735 .911 r
.66913 .50366 .67476 .51031 .68647 .50627 .68091 .50046 Mtetra
.646 .763 .934 r
.68091 .50046 .68647 .50627 .6982 .50182 .69275 .49727 Mtetra
.641 .81 .964 r
.69275 .49727 .6982 .50182 .70995 .49678 .70464 .4939 Mtetra
.626 .875 .988 r
.70464 .4939 .70995 .49678 .72169 .49102 .71655 .49008 Mtetra
.575 .924 .956 r
.71655 .49008 .72169 .49102 .73342 .48444 .72846 .48547 Mtetra
.474 .892 .811 r
.72846 .48547 .73342 .48444 .74513 .47715 .74034 .47977 Mtetra
.387 .813 .637 r
.74034 .47977 .74513 .47715 .75683 .46944 .75217 .47277 Mtetra
0 0 0 r
.75217 .47277 .75683 .46944 .76878 .46473 .76394 .46459 Mtetra
.759 .991 .886 r
.76394 .46459 .76878 .46473 .78085 .46104 .77568 .45579 Mtetra
.713 .811 .926 r
.77568 .45579 .78085 .46104 .79297 .45734 .78772 .45047 Mtetra
.664 .741 .907 r
.78772 .45047 .79297 .45734 .80514 .45363 .79993 .44673 Mtetra
.79993 .44673 .80514 .45363 .81737 .4499 .81219 .44297 Mtetra
.81219 .44297 .81737 .4499 .82964 .44615 .8245 .43919 Mtetra
.8245 .43919 .82964 .44615 .84197 .44239 .83687 .4354 Mtetra
.83687 .4354 .84197 .44239 .8544 .43908 .84929 .43159 Mtetra
.656 .723 .899 r
.84929 .43159 .8544 .43908 .86687 .43558 .86179 .42805 Mtetra
.65 .72 .9 r
.86179 .42805 .86687 .43558 .87934 .43161 .87437 .42469 Mtetra
.668 .747 .91 r
.87437 .42469 .87934 .43161 .89185 .42751 .88693 .4207 Mtetra
.672 .754 .912 r
.88693 .4207 .89185 .42751 .90442 .42348 .89954 .41655 Mtetra
.67 .75 .91 r
.89954 .41655 .90442 .42348 .91706 .41952 .9122 .41245 Mtetra
.667 .745 .909 r
.9122 .41245 .91706 .41952 .92976 .41561 .92493 .40844 Mtetra
.665 .742 .908 r
.92493 .40844 .92976 .41561 .94251 .4117 .93773 .40448 Mtetra
.664 .741 .907 r
.93773 .40448 .94251 .4117 .95533 .40779 .95058 .40053 Mtetra
.663 .741 .908 r
.37374 .5695 .38014 .57547 .39068 .57224 .38431 .56627 Mtetra
.661 .741 .909 r
.38431 .56627 .39068 .57224 .40127 .56903 .39491 .56309 Mtetra
.657 .742 .912 r
.39491 .56309 .40127 .56903 .41189 .56587 .40556 .56 Mtetra
.653 .744 .916 r
.40556 .56 .41189 .56587 .42255 .56279 .41624 .557 Mtetra
.659 .749 .916 r
.41624 .557 .42255 .56279 .43325 .55979 .42698 .55381 Mtetra
.683 .749 .902 r
.42698 .55381 .43325 .55979 .444 .55661 .43777 .54991 Mtetra
.669 .724 .891 r
.43777 .54991 .444 .55661 .45481 .55284 .4486 .54642 Mtetra
.664 .732 .901 r
.4486 .54642 .45481 .55284 .46565 .54924 .45947 .54307 Mtetra
.664 .741 .907 r
.45947 .54307 .46565 .54924 .47653 .5459 .47037 .53971 Mtetra
.47037 .53971 .47653 .5459 .48746 .54255 .48133 .53633 Mtetra
.48133 .53633 .48746 .54255 .49843 .53919 .49232 .53294 Mtetra
.66 .74 .909 r
.49232 .53294 .49843 .53919 .50944 .53581 .50337 .52966 Mtetra
.339 .608 .948 r
.50337 .52966 .50944 .53581 .5205 .53242 .51443 .53208 Mtetra
.201 0 0 r
.51443 .53208 .5205 .53242 .5316 .53058 .52559 .53399 Mtetra
.346 0 0 r
.52559 .53399 .5316 .53058 .54278 .53215 .53681 .53429 Mtetra
.058 0 0 r
.53681 .53429 .54278 .53215 .55403 .53314 .5481 .53267 Mtetra
.467 .881 .937 r
.5481 .53267 .55403 .53314 .56535 .53298 .55943 .52936 Mtetra
.688 .849 .96 r
.55943 .52936 .56535 .53298 .57671 .53156 .57078 .52487 Mtetra
.709 .747 .881 r
.57078 .52487 .57671 .53156 .58812 .52907 .58217 .51975 Mtetra
.698 .68 .829 r
.58217 .51975 .58812 .52907 .59956 .5258 .59359 .51444 Mtetra
.685 .64 .799 r
.59359 .51444 .59956 .5258 .61103 .52208 .60505 .50924 Mtetra
.672 .614 .782 r
.60505 .50924 .61103 .52208 .62255 .51818 .61655 .50435 Mtetra
.661 .597 .772 r
.61655 .50435 .62255 .51818 .63411 .51429 .6281 .49985 Mtetra
.651 .585 .768 r
.6281 .49985 .63411 .51429 .64573 .51055 .63971 .4958 Mtetra
.642 .578 .767 r
.63971 .4958 .64573 .51055 .6574 .50701 .65139 .49222 Mtetra
.634 .573 .769 r
.65139 .49222 .6574 .50701 .66913 .50366 .66313 .48911 Mtetra
.626 .572 .774 r
.66313 .48911 .66913 .50366 .68091 .50046 .67495 .48645 Mtetra
.62 .576 .783 r
.67495 .48645 .68091 .50046 .69275 .49727 .68684 .4842 Mtetra
.614 .585 .797 r
.68684 .4842 .69275 .49727 .70464 .4939 .69881 .48226 Mtetra
.612 .606 .82 r
.69881 .48226 .70464 .4939 .71655 .49008 .71085 .48043 Mtetra
.616 .646 .857 r
.71085 .48043 .71655 .49008 .72846 .48547 .72294 .47842 Mtetra
.629 .72 .913 r
.72294 .47842 .72846 .48547 .74034 .47977 .73506 .47577 Mtetra
.648 .841 .975 r
.73506 .47577 .74034 .47977 .75217 .47277 .74716 .47194 Mtetra
.622 .946 .945 r
.74716 .47194 .75217 .47277 .76394 .46459 .75918 .46638 Mtetra
.523 .905 .746 r
.75918 .46638 .76394 .46459 .77568 .45579 .7711 .45883 Mtetra
.495 .859 .62 r
.7711 .45883 .77568 .45579 .78772 .45047 .78291 .44964 Mtetra
.812 .984 .888 r
.78291 .44964 .78772 .45047 .79993 .44673 .79468 .4399 Mtetra
.668 .746 .909 r
.79468 .4399 .79993 .44673 .81219 .44297 .80697 .43598 Mtetra
.664 .741 .907 r
.80697 .43598 .81219 .44297 .8245 .43919 .81932 .43218 Mtetra
.81932 .43218 .8245 .43919 .83687 .4354 .83172 .42835 Mtetra
.83172 .42835 .83687 .4354 .84929 .43159 .84418 .42452 Mtetra
.84418 .42452 .84929 .43159 .86179 .42805 .85669 .42066 Mtetra
.659 .73 .902 r
.85669 .42066 .86179 .42805 .87437 .42469 .86927 .41695 Mtetra
.646 .715 .898 r
.86927 .41695 .87437 .42469 .88693 .4207 .88196 .41366 Mtetra
.667 .746 .909 r
.88196 .41366 .88693 .4207 .89954 .41655 .89462 .40964 Mtetra
.673 .753 .911 r
.89462 .40964 .89954 .41655 .9122 .41245 .90731 .40541 Mtetra
.67 .749 .91 r
.90731 .40541 .9122 .41245 .92493 .40844 .92007 .40127 Mtetra
.667 .745 .909 r
.92007 .40127 .92493 .40844 .93773 .40448 .9329 .39722 Mtetra
.665 .742 .908 r
.9329 .39722 .93773 .40448 .95058 .40053 .94579 .39322 Mtetra
.662 .742 .909 r
.36729 .56352 .37374 .5695 .38431 .56627 .37788 .56029 Mtetra
.657 .741 .912 r
.37788 .56029 .38431 .56627 .39491 .56309 .38851 .55719 Mtetra
.653 .744 .916 r
.38851 .55719 .39491 .56309 .40556 .56 .39918 .55417 Mtetra
.658 .748 .916 r
.39918 .55417 .40556 .56 .41624 .557 .40989 .551 Mtetra
.683 .749 .902 r
.40989 .551 .41624 .557 .42698 .55381 .42068 .54709 Mtetra
.669 .725 .891 r
.42068 .54709 .42698 .55381 .43777 .54991 .43149 .54358 Mtetra
.664 .736 .903 r
.43149 .54358 .43777 .54991 .4486 .54642 .44234 .54023 Mtetra
.664 .741 .907 r
.44234 .54023 .4486 .54642 .45947 .54307 .45323 .53685 Mtetra
.45323 .53685 .45947 .54307 .47037 .53971 .46417 .53347 Mtetra
.46417 .53347 .47037 .53971 .48133 .53633 .47515 .53006 Mtetra
.537 .697 .943 r
.47515 .53006 .48133 .53633 .49232 .53294 .48614 .52959 Mtetra
.013 .52 .865 r
.48614 .52959 .49232 .53294 .50337 .52966 .49717 .53266 Mtetra
.415 0 0 r
.49717 .53266 .50337 .52966 .51443 .53208 .50829 .53421 Mtetra
.122 0 0 r
.50829 .53421 .51443 .53208 .52559 .53399 .5195 .5332 Mtetra
.52 .897 .961 r
.5195 .5332 .52559 .53399 .53681 .53429 .53076 .52967 Mtetra
.724 .816 .922 r
.53076 .52967 .53681 .53429 .5481 .53267 .54206 .52432 Mtetra
.726 .708 .834 r
.54206 .52432 .5481 .53267 .55943 .52936 .55338 .51796 Mtetra
.709 .649 .787 r
.55338 .51796 .55943 .52936 .57078 .52487 .56473 .5113 Mtetra
.693 .615 .764 r
.56473 .5113 .57078 .52487 .58217 .51975 .57611 .50479 Mtetra
.68 .594 .753 r
.57611 .50479 .58217 .51975 .59359 .51444 .58752 .49869 Mtetra
.67 .582 .748 r
.58752 .49869 .59359 .51444 .60505 .50924 .59897 .49308 Mtetra
.658 .572 .747 r
.59897 .49308 .60505 .50924 .61655 .50435 .61047 .48816 Mtetra
.638 .561 .752 r
.61047 .48816 .61655 .50435 .6281 .49985 .62205 .48458 Mtetra
.641 .572 .761 r
.62205 .48458 .6281 .49985 .63971 .4958 .63368 .48097 Mtetra
.642 .577 .767 r
.63368 .48097 .63971 .4958 .65139 .49222 .64536 .47736 Mtetra
.64536 .47736 .65139 .49222 .66313 .48911 .65708 .47373 Mtetra
.641 .572 .761 r
.65708 .47373 .66313 .48911 .67495 .48645 .66886 .47008 Mtetra
.616 .549 .756 r
.66886 .47008 .67495 .48645 .68684 .4842 .68075 .46778 Mtetra
.604 .542 .759 r
.68075 .46778 .68684 .4842 .69881 .48226 .69273 .46617 Mtetra
.595 .541 .764 r
.69273 .46617 .69881 .48226 .71085 .48043 .70481 .46508 Mtetra
.587 .544 .774 r
.70481 .46508 .71085 .48043 .72294 .47842 .71698 .4644 Mtetra
.582 .558 .792 r
.71698 .4644 .72294 .47842 .73506 .47577 .72924 .46389 Mtetra
.586 .591 .824 r
.72924 .46389 .73506 .47577 .74716 .47194 .74156 .46308 Mtetra
.607 .663 .879 r
.74156 .46308 .74716 .47194 .75918 .46638 .75388 .46127 Mtetra
.652 .801 .954 r
.75388 .46127 .75918 .46638 .7711 .45883 .76613 .45758 Mtetra
.679 .955 .95 r
.76613 .45758 .7711 .45883 .78291 .44964 .77823 .45133 Mtetra
.616 .946 .762 r
.77823 .45133 .78291 .44964 .79468 .4399 .79016 .44244 Mtetra
.623 .928 .682 r
.79016 .44244 .79468 .4399 .80697 .43598 .80197 .43196 Mtetra
.755 .875 .934 r
.80197 .43196 .80697 .43598 .81932 .43218 .8141 .42511 Mtetra
.664 .741 .907 r
.8141 .42511 .81932 .43218 .83172 .42835 .82654 .42126 Mtetra
.82654 .42126 .83172 .42835 .84418 .42452 .83903 .41739 Mtetra
.83903 .41739 .84418 .42452 .85669 .42066 .85158 .4135 Mtetra
.85158 .4135 .85669 .42066 .86927 .41695 .86419 .4096 Mtetra
.659 .734 .905 r
.86419 .4096 .86927 .41695 .88196 .41366 .87686 .40584 Mtetra
.646 .716 .898 r
.87686 .40584 .88196 .41366 .89462 .40964 .88964 .40251 Mtetra
.669 .747 .909 r
.88964 .40251 .89462 .40964 .90731 .40541 .9024 .3984 Mtetra
.673 .753 .911 r
.9024 .3984 .90731 .40541 .92007 .40127 .91519 .39413 Mtetra
.67 .749 .91 r
.91519 .39413 .92007 .40127 .9329 .39722 .92804 .38994 Mtetra
.665 .744 .909 r
.92804 .38994 .9329 .39722 .94579 .39322 .94097 .38589 Mtetra
.66 .743 .911 r
.36079 .55755 .36729 .56352 .37788 .56029 .37141 .55435 Mtetra
.654 .743 .915 r
.37141 .55435 .37788 .56029 .38851 .55719 .38206 .55131 Mtetra
.656 .747 .917 r
.38206 .55131 .38851 .55719 .39918 .55417 .39275 .54819 Mtetra
.68 .75 .904 r
.39275 .54819 .39918 .55417 .40989 .551 .40352 .54437 Mtetra
.672 .729 .892 r
.40352 .54437 .40989 .551 .42068 .54709 .41432 .54074 Mtetra
.664 .736 .903 r
.41432 .54074 .42068 .54709 .43149 .54358 .42515 .53737 Mtetra
.664 .741 .907 r
.42515 .53737 .43149 .54358 .44234 .54023 .43603 .53399 Mtetra
.43603 .53399 .44234 .54023 .45323 .53685 .44695 .53059 Mtetra
.44695 .53059 .45323 .53685 .46417 .53347 .45792 .52718 Mtetra
.408 .641 .951 r
.45792 .52718 .46417 .53347 .47515 .53006 .46884 .5287 Mtetra
.271 0 0 r
.46884 .5287 .47515 .53006 .48614 .52959 .47982 .53207 Mtetra
.335 0 0 r
.47982 .53207 .48614 .52959 .49717 .53266 .49092 .53294 Mtetra
.295 .792 .843 r
.49092 .53294 .49717 .53266 .50829 .53421 .50211 .53047 Mtetra
.723 .848 .941 r
.50211 .53047 .50829 .53421 .5195 .5332 .51336 .52513 Mtetra
.741 .719 .831 r
.51336 .52513 .5195 .5332 .53076 .52967 .52465 .51806 Mtetra
.723 .651 .778 r
.52465 .51806 .53076 .52967 .54206 .52432 .53596 .51035 Mtetra
.706 .616 .754 r
.53596 .51035 .54206 .52432 .55338 .51796 .54729 .50273 Mtetra
.689 .596 .747 r
.54729 .50273 .55338 .51796 .56473 .5113 .55864 .49584 Mtetra
.64 .568 .758 r
.55864 .49584 .56473 .5113 .57611 .50479 .57006 .49228 Mtetra
.649 .607 .794 r
.57006 .49228 .57611 .50479 .58752 .49869 .58153 .48871 Mtetra
.657 .653 .835 r
.58153 .48871 .58752 .49869 .59897 .49308 .59305 .48513 Mtetra
.663 .702 .876 r
.59305 .48513 .59897 .49308 .61047 .48816 .60461 .48153 Mtetra
.664 .741 .907 r
.60461 .48153 .61047 .48816 .62205 .48458 .61622 .47792 Mtetra
.61622 .47792 .62205 .48458 .63368 .48097 .62789 .47429 Mtetra
.62789 .47429 .63368 .48097 .64536 .47736 .6396 .47064 Mtetra
.6396 .47064 .64536 .47736 .65708 .47373 .65136 .46698 Mtetra
.65136 .46698 .65708 .47373 .66886 .47008 .66316 .46331 Mtetra
.66316 .46331 .66886 .47008 .68075 .46778 .67502 .45962 Mtetra
.663 .702 .876 r
.67502 .45962 .68075 .46778 .69273 .46617 .68693 .45591 Mtetra
.657 .653 .835 r
.68693 .45591 .69273 .46617 .70481 .46508 .69889 .45219 Mtetra
.649 .607 .794 r
.69889 .45219 .70481 .46508 .71698 .4644 .7109 .44846 Mtetra
.58 .535 .769 r
.7109 .44846 .71698 .4644 .72924 .46389 .72316 .44811 Mtetra
.565 .529 .774 r
.72316 .44811 .72924 .46389 .74156 .46308 .73556 .44851 Mtetra
.559 .54 .79 r
.73556 .44851 .74156 .46308 .75388 .46127 .74804 .44902 Mtetra
.568 .578 .823 r
.74804 .44902 .75388 .46127 .76613 .45758 .76057 .4489 Mtetra
.606 .671 .885 r
.76057 .4489 .76613 .45758 .77823 .45133 .77304 .44701 Mtetra
.686 .847 .96 r
.77304 .44701 .77823 .45133 .79016 .44244 .78535 .44219 Mtetra
.723 .985 .893 r
.78535 .44219 .79016 .44244 .80197 .43196 .79742 .43393 Mtetra
.691 .964 .733 r
.79742 .43393 .80197 .43196 .8141 .42511 .80928 .42307 Mtetra
.803 .957 .914 r
.80928 .42307 .8141 .42511 .82654 .42126 .82131 .4141 Mtetra
.664 .741 .907 r
.82131 .4141 .82654 .42126 .83903 .41739 .83385 .4102 Mtetra
.83385 .4102 .83903 .41739 .85158 .4135 .84643 .40628 Mtetra
.84643 .40628 .85158 .4135 .86419 .4096 .85908 .40235 Mtetra
.85908 .40235 .86419 .4096 .87686 .40584 .87177 .3984 Mtetra
.655 .732 .906 r
.87177 .3984 .87686 .40584 .88964 .40251 .88456 .39471 Mtetra
.649 .72 .9 r
.88456 .39471 .88964 .40251 .9024 .3984 .89743 .39122 Mtetra
.67 .749 .909 r
.89743 .39122 .9024 .3984 .91519 .39413 .91027 .387 Mtetra
.672 .752 .911 r
.91027 .387 .91519 .39413 .92804 .38994 .92316 .38269 Mtetra
.667 .747 .91 r
.92316 .38269 .92804 .38994 .94097 .38589 .93612 .37854 Mtetra
.659 .746 .914 r
.35424 .55165 .36079 .55755 .37141 .55435 .36488 .54845 Mtetra
.655 .746 .917 r
.36488 .54845 .37141 .55435 .38206 .55131 .37556 .54536 Mtetra
.673 .75 .908 r
.37556 .54536 .38206 .55131 .39275 .54819 .3863 .54172 Mtetra
.678 .736 .894 r
.3863 .54172 .39275 .54819 .40352 .54437 .39709 .53789 Mtetra
.664 .732 .901 r
.39709 .53789 .40352 .54437 .41432 .54074 .40791 .53451 Mtetra
.664 .741 .907 r
.40791 .53451 .41432 .54074 .42515 .53737 .41877 .53111 Mtetra
.41877 .53111 .42515 .53737 .43603 .53399 .42968 .5277 Mtetra
.42968 .5277 .43603 .53399 .44695 .53059 .44063 .52428 Mtetra
.323 .598 .945 r
.44063 .52428 .44695 .53059 .45792 .52718 .45149 .52681 Mtetra
.39 0 0 r
.45149 .52681 .45792 .52718 .46884 .5287 .46241 .53042 Mtetra
.224 0 0 r
.46241 .53042 .46884 .5287 .47982 .53207 .47348 .53072 Mtetra
.58 .903 .982 r
.47348 .53072 .47982 .53207 .49092 .53294 .48467 .527 Mtetra
.753 .775 .871 r
.48467 .527 .49092 .53294 .50211 .53047 .49593 .5202 Mtetra
.742 .678 .789 r
.49593 .5202 .50211 .53047 .51336 .52513 .50722 .51187 Mtetra
.723 .631 .756 r
.50722 .51187 .51336 .52513 .52465 .51806 .51852 .50327 Mtetra
.692 .601 .75 r
.51852 .50327 .52465 .51806 .53596 .51035 .52984 .49638 Mtetra
.644 .586 .775 r
.52984 .49638 .53596 .51035 .54729 .50273 .5412 .49283 Mtetra
.657 .654 .836 r
.5412 .49283 .54729 .50273 .55864 .49584 .55261 .48926 Mtetra
.664 .741 .907 r
.55261 .48926 .55864 .49584 .57006 .49228 .56406 .48568 Mtetra
.56406 .48568 .57006 .49228 .58153 .48871 .57556 .48208 Mtetra
.57556 .48208 .58153 .48871 .59305 .48513 .58711 .47847 Mtetra
.58711 .47847 .59305 .48513 .60461 .48153 .59871 .47485 Mtetra
.59871 .47485 .60461 .48153 .61622 .47792 .61035 .47121 Mtetra
.61035 .47121 .61622 .47792 .62789 .47429 .62205 .46755 Mtetra
.62205 .46755 .62789 .47429 .6396 .47064 .63379 .46388 Mtetra
.63379 .46388 .6396 .47064 .65136 .46698 .64558 .46019 Mtetra
.64558 .46019 .65136 .46698 .66316 .46331 .65742 .45649 Mtetra
.65742 .45649 .66316 .46331 .67502 .45962 .66932 .45277 Mtetra
.66932 .45277 .67502 .45962 .68693 .45591 .68126 .44903 Mtetra
.68126 .44903 .68693 .45591 .69889 .45219 .69325 .44528 Mtetra
.69325 .44528 .69889 .45219 .7109 .44846 .7053 .44152 Mtetra
.7053 .44152 .7109 .44846 .72316 .44811 .71739 .43773 Mtetra
.657 .654 .836 r
.71739 .43773 .72316 .44811 .73556 .44851 .72954 .43394 Mtetra
.578 .551 .788 r
.72954 .43394 .73556 .44851 .74804 .44902 .74197 .43354 Mtetra
.542 .521 .781 r
.74197 .43354 .74804 .44902 .76057 .4489 .7546 .43489 Mtetra
.542 .54 .801 r
.7546 .43489 .76057 .4489 .77304 .44701 .7673 .436 Mtetra
.571 .604 .847 r
.7673 .436 .77304 .44701 .78535 .44219 .77998 .43555 Mtetra
.653 .753 .923 r
.77998 .43555 .78535 .44219 .79742 .43393 .79248 .43195 Mtetra
.76 .954 .937 r
.79248 .43195 .79742 .43393 .80928 .42307 .80468 .4242 Mtetra
.76 .992 .788 r
.80468 .4242 .80928 .42307 .82131 .4141 .8166 .41304 Mtetra
.815 .985 .885 r
.8166 .41304 .82131 .4141 .83385 .4102 .82862 .40295 Mtetra
.664 .741 .907 r
.82862 .40295 .83385 .4102 .84643 .40628 .84124 .39901 Mtetra
.84124 .39901 .84643 .40628 .85908 .40235 .85393 .39504 Mtetra
.85393 .39504 .85908 .40235 .87177 .3984 .86666 .39106 Mtetra
.86666 .39106 .87177 .3984 .88456 .39471 .87946 .38706 Mtetra
.65 .726 .905 r
.87946 .38706 .88456 .39471 .89743 .39122 .89236 .38352 Mtetra
.655 .728 .903 r
.89236 .38352 .89743 .39122 .91027 .387 .9053 .37978 Mtetra
.672 .751 .91 r
.9053 .37978 .91027 .387 .92316 .38269 .91824 .37546 Mtetra
.668 .75 .912 r
.91824 .37546 .92316 .38269 .93612 .37854 .93124 .37125 Mtetra
.66 .75 .917 r
.34763 .54581 .35424 .55165 .36488 .54845 .3583 .54256 Mtetra
.668 .751 .913 r
.3583 .54256 .36488 .54845 .37556 .54536 .36902 .53908 Mtetra
.685 .744 .895 r
.36902 .53908 .37556 .54536 .3863 .54172 .37981 .53503 Mtetra
.664 .727 .896 r
.37981 .53503 .3863 .54172 .39709 .53789 .39061 .53164 Mtetra
.664 .741 .907 r
.39061 .53164 .39709 .53789 .40791 .53451 .40145 .52823 Mtetra
.40145 .52823 .40791 .53451 .41877 .53111 .41234 .52481 Mtetra
.41234 .52481 .41877 .53111 .42968 .5277 .42327 .52137 Mtetra
.32 .598 .945 r
.42327 .52137 .42968 .5277 .44063 .52428 .43409 .5239 Mtetra
.426 0 0 r
.43409 .5239 .44063 .52428 .45149 .52681 .44495 .52789 Mtetra
.139 0 0 r
.44495 .52789 .45149 .52681 .46241 .53042 .45599 .528 Mtetra
.673 .891 .977 r
.45599 .528 .46241 .53042 .47348 .53072 .46718 .52347 Mtetra
.761 .742 .835 r
.46718 .52347 .47348 .53072 .48467 .527 .47845 .51562 Mtetra
.744 .663 .77 r
.47845 .51562 .48467 .527 .49593 .5202 .48975 .50638 Mtetra
.726 .627 .748 r
.48975 .50638 .49593 .5202 .50722 .51187 .50106 .49721 Mtetra
.646 .58 .766 r
.50106 .49721 .50722 .51187 .51852 .50327 .51236 .49338 Mtetra
.657 .655 .836 r
.51236 .49338 .51852 .50327 .52984 .49638 .5237 .48981 Mtetra
.664 .741 .907 r
.5237 .48981 .52984 .49638 .5412 .49283 .53509 .48623 Mtetra
.53509 .48623 .5412 .49283 .55261 .48926 .54653 .48264 Mtetra
.54653 .48264 .55261 .48926 .56406 .48568 .55801 .47903 Mtetra
.55801 .47903 .56406 .48568 .57556 .48208 .56955 .47541 Mtetra
.56955 .47541 .57556 .48208 .58711 .47847 .58113 .47177 Mtetra
.58113 .47177 .58711 .47847 .59871 .47485 .59276 .46811 Mtetra
.59276 .46811 .59871 .47485 .61035 .47121 .60443 .46444 Mtetra
.60443 .46444 .61035 .47121 .62205 .46755 .61616 .46076 Mtetra
.61616 .46076 .62205 .46755 .63379 .46388 .62794 .45706 Mtetra
.62794 .45706 .63379 .46388 .64558 .46019 .63976 .45334 Mtetra
.63976 .45334 .64558 .46019 .65742 .45649 .65164 .44961 Mtetra
.65164 .44961 .65742 .45649 .66932 .45277 .66357 .44586 Mtetra
.66357 .44586 .66932 .45277 .68126 .44903 .67554 .4421 Mtetra
.67554 .4421 .68126 .44903 .69325 .44528 .68757 .43832 Mtetra
.68757 .43832 .69325 .44528 .7053 .44152 .69965 .43452 Mtetra
.69965 .43452 .7053 .44152 .71739 .43773 .71178 .43071 Mtetra
.71178 .43071 .71739 .43773 .72954 .43394 .72397 .42688 Mtetra
.72397 .42688 .72954 .43394 .74197 .43354 .7362 .42304 Mtetra
.65 .651 .838 r
.7362 .42304 .74197 .43354 .7546 .43489 .74851 .41947 Mtetra
.529 .515 .784 r
.74851 .41947 .7546 .43489 .7673 .436 .76127 .42135 Mtetra
.523 .521 .796 r
.76127 .42135 .7673 .436 .77998 .43555 .77414 .42333 Mtetra
.546 .571 .831 r
.77414 .42333 .77998 .43555 .79248 .43195 .787 .42391 Mtetra
.63 .704 .899 r
.787 .42391 .79248 .43195 .80468 .4242 .79966 .42108 Mtetra
.769 .918 .937 r
.79966 .42108 .80468 .4242 .8166 .41304 .81196 .41346 Mtetra
.81 1 .817 r
.81196 .41346 .8166 .41304 .82862 .40295 .82392 .40182 Mtetra
.815 .985 .885 r
.82392 .40182 .82862 .40295 .84124 .39901 .83601 .39167 Mtetra
.664 .741 .907 r
.83601 .39167 .84124 .39901 .85393 .39504 .84873 .38767 Mtetra
.84873 .38767 .85393 .39504 .86666 .39106 .86151 .38366 Mtetra
.86151 .38366 .86666 .39106 .87946 .38706 .87435 .37962 Mtetra
.87435 .37962 .87946 .38706 .89236 .38352 .88724 .37557 Mtetra
.643 .718 .902 r
.88724 .37557 .89236 .38352 .9053 .37978 .90026 .3722 Mtetra
.66 .737 .907 r
.90026 .3722 .9053 .37978 .91824 .37546 .91329 .36824 Mtetra
.667 .751 .914 r
.91329 .36824 .91824 .37546 .93124 .37125 .92634 .36403 Mtetra
.668 .755 .916 r
.34096 .54002 .34763 .54581 .3583 .54256 .35167 .53652 Mtetra
.694 .753 .898 r
.35167 .53652 .3583 .54256 .36902 .53908 .36246 .5322 Mtetra
.665 .722 .892 r
.36246 .5322 .36902 .53908 .37981 .53503 .37325 .52875 Mtetra
.664 .741 .907 r
.37325 .52875 .37981 .53503 .39061 .53164 .38407 .52533 Mtetra
.38407 .52533 .39061 .53164 .40145 .52823 .39495 .5219 Mtetra
.39495 .5219 .40145 .52823 .41234 .52481 .40586 .51845 Mtetra
.402 .64 .952 r
.40586 .51845 .41234 .52481 .42327 .52137 .41666 .51995 Mtetra
.41 0 0 r
.41666 .51995 .42327 .52137 .43409 .5239 .42745 .52456 Mtetra
.143 0 0 r
.42745 .52456 .43409 .5239 .44495 .52789 .43844 .52506 Mtetra
.693 .878 .967 r
.43844 .52506 .44495 .52789 .45599 .528 .44962 .52028 Mtetra
.767 .732 .821 r
.44962 .52028 .45599 .528 .46718 .52347 .46091 .51177 Mtetra
.75 .661 .763 r
.46091 .51177 .46718 .52347 .47845 .51562 .47223 .50185 Mtetra
.711 .621 .755 r
.47223 .50185 .47845 .51562 .48975 .50638 .48354 .49392 Mtetra
.648 .608 .795 r
.48354 .49392 .48975 .50638 .50106 .49721 .49482 .49036 Mtetra
.664 .732 .9 r
.49482 .49036 .50106 .49721 .51236 .49338 .50614 .48678 Mtetra
.664 .741 .907 r
.50614 .48678 .51236 .49338 .5237 .48981 .51752 .48319 Mtetra
.51752 .48319 .5237 .48981 .53509 .48623 .52894 .47959 Mtetra
.52894 .47959 .53509 .48623 .54653 .48264 .54041 .47596 Mtetra
.54041 .47596 .54653 .48264 .55801 .47903 .55192 .47233 Mtetra
.55192 .47233 .55801 .47903 .56955 .47541 .56349 .46868 Mtetra
.56349 .46868 .56955 .47541 .58113 .47177 .5751 .46501 Mtetra
.5751 .46501 .58113 .47177 .59276 .46811 .58676 .46133 Mtetra
.58676 .46133 .59276 .46811 .60443 .46444 .59847 .45763 Mtetra
.59847 .45763 .60443 .46444 .61616 .46076 .61023 .45391 Mtetra
.61023 .45391 .61616 .46076 .62794 .45706 .62204 .45018 Mtetra
.62204 .45018 .62794 .45706 .63976 .45334 .6339 .44644 Mtetra
.6339 .44644 .63976 .45334 .65164 .44961 .64581 .44268 Mtetra
.64581 .44268 .65164 .44961 .66357 .44586 .65777 .4389 Mtetra
.65777 .4389 .66357 .44586 .67554 .4421 .66979 .43511 Mtetra
.66979 .43511 .67554 .4421 .68757 .43832 .68185 .4313 Mtetra
.68185 .4313 .68757 .43832 .69965 .43452 .69396 .42747 Mtetra
.69396 .42747 .69965 .43452 .71178 .43071 .70613 .42363 Mtetra
.70613 .42363 .71178 .43071 .72397 .42688 .71835 .41977 Mtetra
.71835 .41977 .72397 .42688 .7362 .42304 .73062 .41589 Mtetra
.73062 .41589 .7362 .42304 .74851 .41947 .74295 .412 Mtetra
.664 .732 .9 r
.74295 .412 .74851 .41947 .76127 .42135 .75533 .40809 Mtetra
.55 .556 .814 r
.75533 .40809 .76127 .42135 .77414 .42333 .7681 .40866 Mtetra
.505 .512 .798 r
.7681 .40866 .77414 .42333 .787 .42391 .78112 .41128 Mtetra
.53 .557 .827 r
.78112 .41128 .787 .42391 .79966 .42108 .79413 .41248 Mtetra
.624 .689 .89 r
.79413 .41248 .79966 .42108 .81196 .41346 .80691 .40985 Mtetra
.783 .904 .926 r
.80691 .40985 .81196 .41346 .82392 .40182 .81926 .40177 Mtetra
.845 .998 .822 r
.81926 .40177 .82392 .40182 .83601 .39167 .83123 .38941 Mtetra
.803 .957 .914 r
.83123 .38941 .83601 .39167 .84873 .38767 .8435 .38025 Mtetra
.664 .741 .907 r
.8435 .38025 .84873 .38767 .86151 .38366 .85632 .3762 Mtetra
.85632 .3762 .86151 .38366 .87435 .37962 .86919 .37213 Mtetra
.86919 .37213 .87435 .37962 .88724 .37557 .88212 .36805 Mtetra
.663 .74 .908 r
.88212 .36805 .88724 .37557 .90026 .3722 .89512 .36399 Mtetra
.635 .709 .9 r
.89512 .36399 .90026 .3722 .91329 .36824 .90828 .36084 Mtetra
.66 .745 .913 r
.90828 .36084 .91329 .36824 .92634 .36403 .92141 .35683 Mtetra
.683 .756 .907 r
.33425 .53411 .34096 .54002 .35167 .53652 .34501 .53013 Mtetra
.691 .744 .892 r
.34501 .53013 .35167 .53652 .36246 .5322 .35583 .52586 Mtetra
.664 .74 .906 r
.35583 .52586 .36246 .5322 .37325 .52875 .36664 .52243 Mtetra
.664 .741 .907 r
.36664 .52243 .37325 .52875 .38407 .52533 .37749 .51898 Mtetra
.37749 .51898 .38407 .52533 .39495 .5219 .38839 .51553 Mtetra
.534 .698 .945 r
.38839 .51553 .39495 .5219 .40586 .51845 .39922 .515 Mtetra
0 .266 .646 r
.39922 .515 .40586 .51845 .41666 .51995 .40992 .52036 Mtetra
.242 0 0 r
.40992 .52036 .41666 .51995 .42745 .52456 .42083 .5219 Mtetra
.669 .88 .977 r
.42083 .5219 .42745 .52456 .43844 .52506 .43199 .51756 Mtetra
.773 .738 .821 r
.43199 .51756 .43844 .52506 .44962 .52028 .4433 .5088 Mtetra
.757 .666 .761 r
.4433 .5088 .44962 .52028 .46091 .51177 .45465 .49834 Mtetra
.707 .623 .761 r
.45465 .49834 .46091 .51177 .47223 .50185 .46595 .49091 Mtetra
.653 .635 .819 r
.46595 .49091 .47223 .50185 .48354 .49392 .47721 .48734 Mtetra
.664 .741 .907 r
.47721 .48734 .48354 .49392 .49482 .49036 .48852 .48375 Mtetra
.48852 .48375 .49482 .49036 .50614 .48678 .49988 .48014 Mtetra
.49988 .48014 .50614 .48678 .51752 .48319 .51128 .47652 Mtetra
.51128 .47652 .51752 .48319 .52894 .47959 .52273 .47289 Mtetra
.52273 .47289 .52894 .47959 .54041 .47596 .53423 .46924 Mtetra
.53423 .46924 .54041 .47596 .55192 .47233 .54578 .46557 Mtetra
.54578 .46557 .55192 .47233 .56349 .46868 .55738 .46189 Mtetra
.55738 .46189 .56349 .46868 .5751 .46501 .56902 .4582 Mtetra
.56902 .4582 .5751 .46501 .58676 .46133 .58072 .45449 Mtetra
.58072 .45449 .58676 .46133 .59847 .45763 .59246 .45076 Mtetra
.59246 .45076 .59847 .45763 .61023 .45391 .60425 .44702 Mtetra
.60425 .44702 .61023 .45391 .62204 .45018 .6161 .44326 Mtetra
.6161 .44326 .62204 .45018 .6339 .44644 .62799 .43948 Mtetra
.62799 .43948 .6339 .44644 .64581 .44268 .63994 .43569 Mtetra
.63994 .43569 .64581 .44268 .65777 .4389 .65193 .43188 Mtetra
.65193 .43188 .65777 .4389 .66979 .43511 .66398 .42806 Mtetra
.66398 .42806 .66979 .43511 .68185 .4313 .67608 .42422 Mtetra
.67608 .42422 .68185 .4313 .69396 .42747 .68823 .42036 Mtetra
.68823 .42036 .69396 .42747 .70613 .42363 .70043 .41649 Mtetra
.70043 .41649 .70613 .42363 .71835 .41977 .71269 .4126 Mtetra
.71269 .4126 .71835 .41977 .73062 .41589 .725 .40869 Mtetra
.725 .40869 .73062 .41589 .74295 .412 .73736 .40477 Mtetra
.73736 .40477 .74295 .412 .75533 .40809 .74978 .40083 Mtetra
.74978 .40083 .75533 .40809 .7681 .40866 .76225 .39687 Mtetra
.557 .586 .839 r
.76225 .39687 .7681 .40866 .78112 .41128 .77508 .39688 Mtetra
.489 .508 .804 r
.77508 .39688 .78112 .41128 .79413 .41248 .78826 .39999 Mtetra
.521 .556 .832 r
.78826 .39999 .79413 .41248 .80691 .40985 .8014 .4014 Mtetra
.637 .701 .892 r
.8014 .4014 .80691 .40985 .81926 .40177 .81424 .39826 Mtetra
.811 .914 .909 r
.81424 .39826 .81926 .40177 .83123 .38941 .82657 .38903 Mtetra
.869 .992 .816 r
.82657 .38903 .83123 .38941 .8435 .38025 .83852 .37582 Mtetra
.755 .875 .934 r
.83852 .37582 .8435 .38025 .85632 .3762 .85108 .36868 Mtetra
.664 .741 .907 r
.85108 .36868 .85632 .3762 .86919 .37213 .864 .36458 Mtetra
.864 .36458 .86919 .37213 .88212 .36805 .87697 .36046 Mtetra
.87697 .36046 .88212 .36805 .89512 .36399 .89 .35633 Mtetra
.636 .728 .914 r
.89 .35633 .89512 .36399 .90828 .36084 .9032 .35307 Mtetra
.646 .73 .91 r
.9032 .35307 .90828 .36084 .92141 .35683 .91642 .34949 Mtetra
.701 .749 .889 r
.32751 .52782 .33425 .53411 .34501 .53013 .33833 .52319 Mtetra
.671 .724 .889 r
.33833 .52319 .34501 .53013 .35583 .52586 .34914 .51952 Mtetra
.664 .741 .907 r
.34914 .51952 .35583 .52586 .36664 .52243 .35998 .51606 Mtetra
.35998 .51606 .36664 .52243 .37749 .51898 .37086 .51259 Mtetra
.66 .74 .909 r
.37086 .51259 .37749 .51898 .38839 .51553 .38178 .50922 Mtetra
0 .37 .826 r
.38178 .50922 .38839 .51553 .39922 .515 .39238 .51509 Mtetra
.385 0 0 r
.39238 .51509 .39922 .515 .40992 .52036 .40319 .51824 Mtetra
.57 .875 .994 r
.40319 .51824 .40992 .52036 .42083 .5219 .41429 .51517 Mtetra
.776 .757 .836 r
.41429 .51517 .42083 .5219 .43199 .51756 .4256 .50669 Mtetra
.767 .678 .765 r
.4256 .50669 .43199 .51756 .4433 .5088 .43698 .49585 Mtetra
.717 .633 .764 r
.43698 .49585 .4433 .5088 .45465 .49834 .4483 .48789 Mtetra
.655 .644 .827 r
.4483 .48789 .45465 .49834 .46595 .49091 .45955 .4843 Mtetra
.664 .741 .907 r
.45955 .4843 .46595 .49091 .47721 .48734 .47084 .4807 Mtetra
.47084 .4807 .47721 .48734 .48852 .48375 .48218 .47708 Mtetra
.48218 .47708 .48852 .48375 .49988 .48014 .49357 .47345 Mtetra
.49357 .47345 .49988 .48014 .51128 .47652 .505 .4698 Mtetra
.505 .4698 .51128 .47652 .52273 .47289 .51648 .46614 Mtetra
.51648 .46614 .52273 .47289 .53423 .46924 .52801 .46246 Mtetra
.52801 .46246 .53423 .46924 .54578 .46557 .53959 .45877 Mtetra
.53959 .45877 .54578 .46557 .55738 .46189 .55122 .45506 Mtetra
.55122 .45506 .55738 .46189 .56902 .4582 .5629 .45133 Mtetra
.5629 .45133 .56902 .4582 .58072 .45449 .57463 .44759 Mtetra
.57463 .44759 .58072 .45449 .59246 .45076 .5864 .44384 Mtetra
.5864 .44384 .59246 .45076 .60425 .44702 .59823 .44006 Mtetra
.59823 .44006 .60425 .44702 .6161 .44326 .61011 .43627 Mtetra
.61011 .43627 .6161 .44326 .62799 .43948 .62204 .43247 Mtetra
.62204 .43247 .62799 .43948 .63994 .43569 .63402 .42865 Mtetra
.63402 .42865 .63994 .43569 .65193 .43188 .64605 .42481 Mtetra
.64605 .42481 .65193 .43188 .66398 .42806 .65813 .42096 Mtetra
.65813 .42096 .66398 .42806 .67608 .42422 .67026 .41709 Mtetra
.67026 .41709 .67608 .42422 .68823 .42036 .68245 .4132 Mtetra
.68245 .4132 .68823 .42036 .70043 .41649 .69469 .4093 Mtetra
.69469 .4093 .70043 .41649 .71269 .4126 .70698 .40538 Mtetra
.70698 .40538 .71269 .4126 .725 .40869 .71933 .40144 Mtetra
.71933 .40144 .725 .40869 .73736 .40477 .73173 .39748 Mtetra
.73173 .39748 .73736 .40477 .74978 .40083 .74418 .39351 Mtetra
.74418 .39351 .74978 .40083 .76225 .39687 .75669 .38952 Mtetra
.75669 .38952 .76225 .39687 .77508 .39688 .76925 .38551 Mtetra
.539 .586 .85 r
.76925 .38551 .77508 .39688 .78826 .39999 .78223 .386 Mtetra
.473 .506 .811 r
.78223 .386 .78826 .39999 .8014 .4014 .79556 .38948 Mtetra
.526 .57 .843 r
.79556 .38948 .8014 .4014 .81424 .39826 .80879 .39054 Mtetra
.676 .74 .899 r
.80879 .39054 .81424 .39826 .82657 .38903 .82161 .38602 Mtetra
.849 .934 .882 r
.82161 .38602 .82657 .38903 .83852 .37582 .83385 .37505 Mtetra
.886 .985 .813 r
.83385 .37505 .83852 .37582 .85108 .36868 .84581 .36122 Mtetra
.668 .746 .909 r
.84581 .36122 .85108 .36868 .864 .36458 .85876 .35696 Mtetra
.664 .741 .907 r
.85876 .35696 .864 .36458 .87697 .36046 .87177 .35281 Mtetra
.87177 .35281 .87697 .36046 .89 .35633 .88485 .34864 Mtetra
.657 .738 .91 r
.88485 .34864 .89 .35633 .9032 .35307 .89801 .3447 Mtetra
.627 .706 .902 r
.89801 .3447 .9032 .35307 .91642 .34949 .91135 .34174 Mtetra
.689 .729 .882 r
.32075 .52089 .32751 .52782 .33833 .52319 .33158 .51659 Mtetra
.664 .734 .902 r
.33158 .51659 .33833 .52319 .34914 .51952 .3424 .51312 Mtetra
.664 .741 .907 r
.3424 .51312 .34914 .51952 .35998 .51606 .35327 .50964 Mtetra
.35327 .50964 .35998 .51606 .37086 .51259 .36418 .50614 Mtetra
.31 .595 .946 r
.36418 .50614 .37086 .51259 .38178 .50922 .37486 .50863 Mtetra
.502 0 0 r
.37486 .50863 .38178 .50922 .39238 .51509 .38553 .51362 Mtetra
.295 .767 .936 r
.38553 .51362 .39238 .51509 .40319 .51824 .39652 .51273 Mtetra
.768 .79 .871 r
.39652 .51273 .40319 .51824 .41429 .51517 .4078 .50532 Mtetra
.777 .696 .774 r
.4078 .50532 .41429 .51517 .4256 .50669 .41922 .49438 Mtetra
.741 .651 .761 r
.41922 .49438 .4256 .50669 .43698 .49585 .43059 .48485 Mtetra
.653 .635 .819 r
.43059 .48485 .43698 .49585 .4483 .48789 .44182 .48125 Mtetra
.664 .741 .907 r
.44182 .48125 .4483 .48789 .45955 .4843 .45309 .47764 Mtetra
.45309 .47764 .45955 .4843 .47084 .4807 .46442 .47401 Mtetra
.46442 .47401 .47084 .4807 .48218 .47708 .47579 .47036 Mtetra
.47579 .47036 .48218 .47708 .49357 .47345 .4872 .4667 Mtetra
.4872 .4667 .49357 .47345 .505 .4698 .49867 .46303 Mtetra
.49867 .46303 .505 .4698 .51648 .46614 .51018 .45934 Mtetra
.51018 .45934 .51648 .46614 .52801 .46246 .52175 .45563 Mtetra
.52175 .45563 .52801 .46246 .53959 .45877 .53336 .45191 Mtetra
.53336 .45191 .53959 .45877 .55122 .45506 .54502 .44817 Mtetra
.54502 .44817 .55122 .45506 .5629 .45133 .55673 .44441 Mtetra
.55673 .44441 .5629 .45133 .57463 .44759 .56849 .44064 Mtetra
.56849 .44064 .57463 .44759 .5864 .44384 .5803 .43686 Mtetra
.5803 .43686 .5864 .44384 .59823 .44006 .59216 .43306 Mtetra
.59216 .43306 .59823 .44006 .61011 .43627 .60407 .42924 Mtetra
.60407 .42924 .61011 .43627 .62204 .43247 .61603 .4254 Mtetra
.61603 .4254 .62204 .43247 .63402 .42865 .62805 .42155 Mtetra
.62805 .42155 .63402 .42865 .64605 .42481 .64011 .41768 Mtetra
.64011 .41768 .64605 .42481 .65813 .42096 .65223 .4138 Mtetra
.65223 .4138 .65813 .42096 .67026 .41709 .6644 .4099 Mtetra
.6644 .4099 .67026 .41709 .68245 .4132 .67662 .40598 Mtetra
.67662 .40598 .68245 .4132 .69469 .4093 .6889 .40204 Mtetra
.6889 .40204 .69469 .4093 .70698 .40538 .70123 .39809 Mtetra
.70123 .39809 .70698 .40538 .71933 .40144 .71361 .39412 Mtetra
.71361 .39412 .71933 .40144 .73173 .39748 .72605 .39014 Mtetra
.72605 .39014 .73173 .39748 .74418 .39351 .73854 .38613 Mtetra
.73854 .38613 .74418 .39351 .75669 .38952 .75109 .38211 Mtetra
.75109 .38211 .75669 .38952 .76925 .38551 .76369 .37807 Mtetra
.76369 .37807 .76925 .38551 .78223 .386 .77635 .37401 Mtetra
.494 .552 .844 r
.77635 .37401 .78223 .386 .79556 .38948 .78957 .37606 Mtetra
.464 .511 .822 r
.78957 .37606 .79556 .38948 .80879 .39054 .80302 .37959 Mtetra
.552 .605 .86 r
.80302 .37959 .80879 .39054 .82161 .38602 .81627 .3795 Mtetra
.741 .801 .9 r
.81627 .3795 .82161 .38602 .83385 .37505 .82897 .37264 Mtetra
.883 .95 .847 r
.82897 .37264 .83385 .37505 .84581 .36122 .8411 .35968 Mtetra
.818 .981 .887 r
.8411 .35968 .84581 .36122 .85876 .35696 .85348 .34928 Mtetra
.664 .741 .907 r
.85348 .34928 .85876 .35696 .87177 .35281 .86653 .3451 Mtetra
.86653 .3451 .87177 .35281 .88485 .34864 .87965 .34089 Mtetra
.87965 .34089 .88485 .34864 .89801 .3447 .89283 .33667 Mtetra
.638 .722 .909 r
.89283 .33667 .89801 .3447 .91135 .34174 .90617 .33331 Mtetra
.663 .716 .888 r
.31396 .51366 .32075 .52089 .33158 .51659 .32477 .51018 Mtetra
.664 .741 .907 r
.32477 .51018 .33158 .51659 .3424 .51312 .33562 .50668 Mtetra
.33562 .50668 .3424 .51312 .35327 .50964 .34651 .50317 Mtetra
.603 .723 .929 r
.34651 .50317 .35327 .50964 .36418 .50614 .35737 .50122 Mtetra
0 .255 .693 r
.35737 .50122 .36418 .50614 .37486 .50863 .36789 .50749 Mtetra
.152 0 0 r
.36789 .50749 .37486 .50863 .38553 .51362 .37871 .50954 Mtetra
.718 .835 .937 r
.37871 .50954 .38553 .51362 .39652 .51273 .38991 .5043 Mtetra
.785 .722 .794 r
.38991 .5043 .39652 .51273 .4078 .50532 .40133 .49387 Mtetra
.771 .673 .755 r
.40133 .49387 .4078 .50532 .41922 .49438 .4128 .4821 Mtetra
.654 .616 .798 r
.4128 .4821 .41922 .49438 .43059 .48485 .42403 .47819 Mtetra
.664 .741 .907 r
.42403 .47819 .43059 .48485 .44182 .48125 .43528 .47457 Mtetra
.43528 .47457 .44182 .48125 .45309 .47764 .44659 .47092 Mtetra
.44659 .47092 .45309 .47764 .46442 .47401 .45794 .46727 Mtetra
.45794 .46727 .46442 .47401 .47579 .47036 .46934 .46359 Mtetra
.46934 .46359 .47579 .47036 .4872 .4667 .48079 .4599 Mtetra
.48079 .4599 .4872 .4667 .49867 .46303 .49229 .4562 Mtetra
.49229 .4562 .49867 .46303 .51018 .45934 .50384 .45248 Mtetra
.50384 .45248 .51018 .45934 .52175 .45563 .51543 .44874 Mtetra
.51543 .44874 .52175 .45563 .53336 .45191 .52707 .44499 Mtetra
.52707 .44499 .53336 .45191 .54502 .44817 .53877 .44123 Mtetra
.53877 .44123 .54502 .44817 .55673 .44441 .55051 .43744 Mtetra
.55051 .43744 .55673 .44441 .56849 .44064 .5623 .43364 Mtetra
.5623 .43364 .56849 .44064 .5803 .43686 .57415 .42983 Mtetra
.57415 .42983 .5803 .43686 .59216 .43306 .58604 .42599 Mtetra
.58604 .42599 .59216 .43306 .60407 .42924 .59799 .42215 Mtetra
.59799 .42215 .60407 .42924 .61603 .4254 .60998 .41828 Mtetra
.60998 .41828 .61603 .4254 .62805 .42155 .62203 .4144 Mtetra
.62203 .4144 .62805 .42155 .64011 .41768 .63413 .4105 Mtetra
.63413 .4105 .64011 .41768 .65223 .4138 .64628 .40658 Mtetra
.64628 .40658 .65223 .4138 .6644 .4099 .65849 .40265 Mtetra
.65849 .40265 .6644 .4099 .67662 .40598 .67075 .3987 Mtetra
.67075 .3987 .67662 .40598 .6889 .40204 .68306 .39473 Mtetra
.68306 .39473 .6889 .40204 .70123 .39809 .69543 .39075 Mtetra
.69543 .39075 .70123 .39809 .71361 .39412 .70785 .38675 Mtetra
.70785 .38675 .71361 .39412 .72605 .39014 .72032 .38273 Mtetra
.72032 .38273 .72605 .39014 .73854 .38613 .73285 .37869 Mtetra
.73285 .37869 .73854 .38613 .75109 .38211 .74544 .37464 Mtetra
.74544 .37464 .75109 .38211 .76369 .37807 .75808 .37056 Mtetra
.75808 .37056 .76369 .37807 .77635 .37401 .77078 .36647 Mtetra
.655 .737 .91 r
.77078 .36647 .77635 .37401 .78957 .37606 .78355 .36266 Mtetra
.437 .497 .823 r
.78355 .36266 .78957 .37606 .80302 .37959 .79708 .36698 Mtetra
.47 .53 .837 r
.79708 .36698 .80302 .37959 .81627 .3795 .81062 .36994 Mtetra
.613 .669 .88 r
.81062 .36994 .81627 .3795 .82897 .37264 .82378 .36754 Mtetra
.819 .866 .882 r
.82378 .36754 .82897 .37264 .8411 .35968 .83627 .35756 Mtetra
.903 .955 .821 r
.83627 .35756 .8411 .35968 .85348 .34928 .84832 .34318 Mtetra
.713 .811 .926 r
.84832 .34318 .85348 .34928 .86653 .3451 .86125 .33732 Mtetra
.664 .741 .907 r
.86125 .33732 .86653 .3451 .87965 .34089 .87441 .33308 Mtetra
.87441 .33308 .87965 .34089 .89283 .33667 .88763 .32882 Mtetra
.88763 .32882 .89283 .33667 .90617 .33331 .90091 .32455 Mtetra
.30707 .50722 .31396 .51366 .32477 .51018 .3179 .50371 Mtetra
.3179 .50371 .32477 .51018 .33562 .50668 .32878 .50019 Mtetra
.32878 .50019 .33562 .50668 .34651 .50317 .3397 .49665 Mtetra
.249 .562 .935 r
.3397 .49665 .34651 .50317 .35737 .50122 .35031 .49972 Mtetra
.452 0 0 r
.35031 .49972 .35737 .50122 .36789 .50749 .36092 .50471 Mtetra
.494 .826 .999 r
.36092 .50471 .36789 .50749 .37871 .50954 .37195 .5029 Mtetra
.781 .761 .835 r
.37195 .5029 .37871 .50954 .38991 .5043 .38333 .49409 Mtetra
.784 .694 .764 r
.38333 .49409 .38991 .5043 .40133 .49387 .39485 .48212 Mtetra
.711 .648 .785 r
.39485 .48212 .40133 .49387 .4128 .4821 .40617 .47513 Mtetra
.664 .732 .901 r
.40617 .47513 .4128 .4821 .42403 .47819 .41741 .47149 Mtetra
.664 .741 .907 r
.41741 .47149 .42403 .47819 .43528 .47457 .4287 .46783 Mtetra
.4287 .46783 .43528 .47457 .44659 .47092 .44004 .46416 Mtetra
.44004 .46416 .44659 .47092 .45794 .46727 .45142 .46047 Mtetra
.45142 .46047 .45794 .46727 .46934 .46359 .46285 .45677 Mtetra
.46285 .45677 .46934 .46359 .48079 .4599 .47433 .45305 Mtetra
.47433 .45305 .48079 .4599 .49229 .4562 .48586 .44932 Mtetra
.48586 .44932 .49229 .4562 .50384 .45248 .49744 .44557 Mtetra
.49744 .44557 .50384 .45248 .51543 .44874 .50906 .44181 Mtetra
.50906 .44181 .51543 .44874 .52707 .44499 .52074 .43803 Mtetra
.52074 .43803 .52707 .44499 .53877 .44123 .53247 .43423 Mtetra
.53247 .43423 .53877 .44123 .55051 .43744 .54424 .43041 Mtetra
.54424 .43041 .55051 .43744 .5623 .43364 .55607 .42658 Mtetra
.55607 .42658 .5623 .43364 .57415 .42983 .56794 .42274 Mtetra
.56794 .42274 .57415 .42983 .58604 .42599 .57987 .41888 Mtetra
.57987 .41888 .58604 .42599 .59799 .42215 .59185 .415 Mtetra
.59185 .415 .59799 .42215 .60998 .41828 .60388 .4111 Mtetra
.60388 .4111 .60998 .41828 .62203 .4144 .61597 .40719 Mtetra
.61597 .40719 .62203 .4144 .63413 .4105 .6281 .40326 Mtetra
.6281 .40326 .63413 .4105 .64628 .40658 .64029 .39931 Mtetra
.64029 .39931 .64628 .40658 .65849 .40265 .65253 .39535 Mtetra
.65253 .39535 .65849 .40265 .67075 .3987 .66483 .39136 Mtetra
.66483 .39136 .67075 .3987 .68306 .39473 .67718 .38737 Mtetra
.67718 .38737 .68306 .39473 .69543 .39075 .68958 .38335 Mtetra
.68958 .38335 .69543 .39075 .70785 .38675 .70204 .37931 Mtetra
.70204 .37931 .70785 .38675 .72032 .38273 .71455 .37526 Mtetra
.71455 .37526 .72032 .38273 .73285 .37869 .72712 .37119 Mtetra
.72712 .37119 .73285 .37869 .74544 .37464 .73974 .3671 Mtetra
.73974 .3671 .74544 .37464 .75808 .37056 .75242 .363 Mtetra
.75242 .363 .75808 .37056 .77078 .36647 .76516 .35887 Mtetra
.76516 .35887 .77078 .36647 .78355 .36266 .77795 .35473 Mtetra
.543 .678 .927 r
.77795 .35473 .78355 .36266 .79708 .36698 .7911 .35405 Mtetra
.423 .498 .832 r
.7911 .35405 .79708 .36698 .81062 .36994 .80478 .35852 Mtetra
.511 .577 .858 r
.80478 .35852 .81062 .36994 .82378 .36754 .8183 .35976 Mtetra
.712 .759 .889 r
.8183 .35976 .82378 .36754 .83627 .35756 .83122 .35373 Mtetra
.88 .911 .845 r
.83122 .35373 .83627 .35756 .84832 .34318 .84348 .34062 Mtetra
.846 .957 .883 r
.84348 .34062 .84832 .34318 .86125 .33732 .85593 .32948 Mtetra
.664 .741 .907 r
.85593 .32948 .86125 .33732 .87441 .33308 .86913 .32521 Mtetra
.86913 .32521 .87441 .33308 .88763 .32882 .88239 .32091 Mtetra
.88239 .32091 .88763 .32882 .90091 .32455 .89571 .3166 Mtetra
.30013 .50073 .30707 .50722 .3179 .50371 .31098 .4972 Mtetra
.31098 .4972 .3179 .50371 .32878 .50019 .32189 .49365 Mtetra
.625 .73 .922 r
.32189 .49365 .32878 .50019 .3397 .49665 .33277 .49113 Mtetra
0 .26 .714 r
.33277 .49113 .3397 .49665 .35031 .49972 .34322 .49759 Mtetra
0 .485 .762 r
.34322 .49759 .35031 .49972 .36092 .50471 .35399 .49995 Mtetra
.728 .813 .918 r
.35399 .49995 .36092 .50471 .37195 .5029 .36522 .49438 Mtetra
.792 .723 .787 r
.36522 .49438 .37195 .5029 .38333 .49409 .37674 .48319 Mtetra
.77 .681 .765 r
.37674 .48319 .38333 .49409 .39485 .48212 .38826 .47205 Mtetra
.656 .655 .837 r
.38826 .47205 .39485 .48212 .40617 .47513 .39948 .46839 Mtetra
.664 .741 .907 r
.39948 .46839 .40617 .47513 .41741 .47149 .41075 .46473 Mtetra
.41075 .46473 .41741 .47149 .4287 .46783 .42207 .46104 Mtetra
.42207 .46104 .4287 .46783 .44004 .46416 .43343 .45734 Mtetra
.43343 .45734 .44004 .46416 .45142 .46047 .44485 .45363 Mtetra
.44485 .45363 .45142 .46047 .46285 .45677 .45631 .4499 Mtetra
.45631 .4499 .46285 .45677 .47433 .45305 .46782 .44615 Mtetra
.46782 .44615 .47433 .45305 .48586 .44932 .47938 .44239 Mtetra
.47938 .44239 .48586 .44932 .49744 .44557 .49099 .43861 Mtetra
.49099 .43861 .49744 .44557 .50906 .44181 .50265 .43481 Mtetra
.50265 .43481 .50906 .44181 .52074 .43803 .51436 .431 Mtetra
.51436 .431 .52074 .43803 .53247 .43423 .52611 .42718 Mtetra
.52611 .42718 .53247 .43423 .54424 .43041 .53792 .42333 Mtetra
.53792 .42333 .54424 .43041 .55607 .42658 .54978 .41947 Mtetra
.54978 .41947 .55607 .42658 .56794 .42274 .56169 .41559 Mtetra
.56169 .41559 .56794 .42274 .57987 .41888 .57366 .4117 Mtetra
.57366 .4117 .57987 .41888 .59185 .415 .58567 .40779 Mtetra
.58567 .40779 .59185 .415 .60388 .4111 .59774 .40386 Mtetra
.59774 .40386 .60388 .4111 .61597 .40719 .60985 .39992 Mtetra
.60985 .39992 .61597 .40719 .6281 .40326 .62203 .39596 Mtetra
.62203 .39596 .6281 .40326 .64029 .39931 .63425 .39198 Mtetra
.63425 .39198 .64029 .39931 .65253 .39535 .64653 .38798 Mtetra
.64653 .38798 .65253 .39535 .66483 .39136 .65886 .38397 Mtetra
.65886 .38397 .66483 .39136 .67718 .38737 .67125 .37994 Mtetra
.67125 .37994 .67718 .38737 .68958 .38335 .68369 .37589 Mtetra
.68369 .37589 .68958 .38335 .70204 .37931 .69618 .37182 Mtetra
.69618 .37182 .70204 .37931 .71455 .37526 .70873 .36773 Mtetra
.70873 .36773 .71455 .37526 .72712 .37119 .72134 .36363 Mtetra
.72134 .36363 .72712 .37119 .73974 .3671 .734 .35951 Mtetra
.734 .35951 .73974 .3671 .75242 .363 .74672 .35537 Mtetra
.74672 .35537 .75242 .363 .76516 .35887 .7595 .35121 Mtetra
.7595 .35121 .76516 .35887 .77795 .35473 .77233 .34703 Mtetra
.77233 .34703 .77795 .35473 .7911 .35405 .78522 .34284 Mtetra
.425 .533 .864 r
.78522 .34284 .7911 .35405 .80478 .35852 .79884 .34638 Mtetra
.438 .523 .848 r
.79884 .34638 .80478 .35852 .8183 .35976 .8126 .35001 Mtetra
.604 .664 .881 r
.8126 .35001 .8183 .35976 .83122 .35373 .82592 .34783 Mtetra
.82 .846 .868 r
.82592 .34783 .83122 .35373 .84348 .34062 .83851 .33739 Mtetra
.905 .927 .82 r
.83851 .33739 .84348 .34062 .85593 .32948 .85067 .32266 Mtetra
.696 .787 .921 r
.85067 .32266 .85593 .32948 .86913 .32521 .8638 .31726 Mtetra
.664 .741 .907 r
.8638 .31726 .86913 .32521 .88239 .32091 .8771 .31293 Mtetra
.8771 .31293 .88239 .32091 .89571 .3166 .89047 .30858 Mtetra
.29313 .4942 .30013 .50073 .31098 .4972 .30401 .49064 Mtetra
.30401 .49064 .31098 .4972 .32189 .49365 .31494 .48706 Mtetra
.386 .635 .953 r
.31494 .48706 .32189 .49365 .33277 .49113 .32561 .48855 Mtetra
.449 0 0 r
.32561 .48855 .33277 .49113 .34322 .49759 .33612 .49428 Mtetra
.43 .781 .997 r
.33612 .49428 .34322 .49759 .35399 .49995 .34708 .49345 Mtetra
.78 .766 .841 r
.34708 .49345 .35399 .49995 .36522 .49438 .3585 .48481 Mtetra
.795 .707 .767 r
.3585 .48481 .36522 .49438 .37674 .48319 .37012 .47234 Mtetra
.718 .666 .797 r
.37012 .47234 .37674 .48319 .38826 .47205 .38148 .46529 Mtetra
.664 .741 .907 r
.38148 .46529 .38826 .47205 .39948 .46839 .39273 .46161 Mtetra
.39273 .46161 .39948 .46839 .41075 .46473 .40403 .45791 Mtetra
.40403 .45791 .41075 .46473 .42207 .46104 .41538 .4542 Mtetra
.41538 .4542 .42207 .46104 .43343 .45734 .42678 .45047 Mtetra
.42678 .45047 .43343 .45734 .44485 .45363 .43822 .44673 Mtetra
.43822 .44673 .44485 .45363 .45631 .4499 .44972 .44297 Mtetra
.44972 .44297 .45631 .4499 .46782 .44615 .46126 .43919 Mtetra
.46126 .43919 .46782 .44615 .47938 .44239 .47285 .4354 Mtetra
.47285 .4354 .47938 .44239 .49099 .43861 .48449 .43159 Mtetra
.48449 .43159 .49099 .43861 .50265 .43481 .49618 .42777 Mtetra
.49618 .42777 .50265 .43481 .51436 .431 .50792 .42392 Mtetra
.50792 .42392 .51436 .431 .52611 .42718 .51971 .42007 Mtetra
.51971 .42007 .52611 .42718 .53792 .42333 .53155 .41619 Mtetra
.648 .736 .913 r
.53155 .41619 .53792 .42333 .54978 .41947 .54345 .41279 Mtetra
.649 .751 .924 r
.54345 .41279 .54978 .41947 .56169 .41559 .5554 .40929 Mtetra
.656 .766 .931 r
.5554 .40929 .56169 .41559 .57366 .4117 .5674 .40557 Mtetra
.662 .775 .933 r
.5674 .40557 .57366 .4117 .58567 .40779 .57946 .40163 Mtetra
.67 .777 .93 r
.57946 .40163 .58567 .40779 .59774 .40386 .59156 .39747 Mtetra
.677 .773 .923 r
.59156 .39747 .59774 .40386 .60985 .39992 .6037 .39308 Mtetra
.679 .761 .913 r
.6037 .39308 .60985 .39992 .62203 .39596 .6159 .3886 Mtetra
.664 .741 .907 r
.6159 .3886 .62203 .39596 .63425 .39198 .62816 .38459 Mtetra
.62816 .38459 .63425 .39198 .64653 .38798 .64047 .38056 Mtetra
.64047 .38056 .64653 .38798 .65886 .38397 .65284 .37651 Mtetra
.65284 .37651 .65886 .38397 .67125 .37994 .66527 .37245 Mtetra
.66527 .37245 .67125 .37994 .68369 .37589 .67775 .36836 Mtetra
.67775 .36836 .68369 .37589 .69618 .37182 .69028 .36426 Mtetra
.69028 .36426 .69618 .37182 .70873 .36773 .70287 .36014 Mtetra
.70287 .36014 .70873 .36773 .72134 .36363 .71551 .35601 Mtetra
.71551 .35601 .72134 .36363 .734 .35951 .72822 .35185 Mtetra
.72822 .35185 .734 .35951 .74672 .35537 .74097 .34768 Mtetra
.74097 .34768 .74672 .35537 .7595 .35121 .75379 .34348 Mtetra
.75379 .34348 .7595 .35121 .77233 .34703 .76666 .33927 Mtetra
.76666 .33927 .77233 .34703 .78522 .34284 .7796 .33504 Mtetra
.539 .685 .933 r
.7796 .33504 .78522 .34284 .79884 .34638 .79288 .33429 Mtetra
.389 .497 .847 r
.79288 .33429 .79884 .34638 .8126 .35001 .80676 .33916 Mtetra
.511 .593 .873 r
.80676 .33916 .8126 .35001 .82592 .34783 .82041 .3401 Mtetra
.739 .775 .882 r
.82041 .3401 .82592 .34783 .83851 .33739 .83338 .33292 Mtetra
.887 .894 .83 r
.83338 .33292 .83851 .33739 .85067 .32266 .84568 .3189 Mtetra
.813 .922 .909 r
.84568 .3189 .85067 .32266 .8638 .31726 .85843 .30925 Mtetra
.664 .741 .907 r
.85843 .30925 .8638 .31726 .8771 .31293 .87177 .30488 Mtetra
.87177 .30488 .8771 .31293 .89047 .30858 .88518 .3005 Mtetra
.28608 .48761 .29313 .4942 .30401 .49064 .29699 .48402 Mtetra
.29699 .48402 .30401 .49064 .31494 .48706 .30794 .48042 Mtetra
.01 .416 .858 r
.30794 .48042 .31494 .48706 .32561 .48855 .3184 .48556 Mtetra
0 .345 .683 r
.3184 .48556 .32561 .48855 .33612 .49428 .32902 .48967 Mtetra
.669 .812 .952 r
.32902 .48967 .33612 .49428 .34708 .49345 .34019 .48573 Mtetra
.796 .74 .8 r
.34019 .48573 .34708 .49345 .3585 .48481 .35176 .47489 Mtetra
.794 .702 .763 r
.35176 .47489 .3585 .48481 .37012 .47234 .36342 .46218 Mtetra
.656 .656 .838 r
.36342 .46218 .37012 .47234 .38148 .46529 .37465 .45848 Mtetra
.664 .741 .907 r
.37465 .45848 .38148 .46529 .39273 .46161 .38594 .45477 Mtetra
.38594 .45477 .39273 .46161 .40403 .45791 .39727 .45105 Mtetra
.39727 .45105 .40403 .45791 .41538 .4542 .40865 .4473 Mtetra
.40865 .4473 .41538 .4542 .42678 .45047 .42007 .44355 Mtetra
.42007 .44355 .42678 .45047 .43822 .44673 .43155 .43977 Mtetra
.43155 .43977 .43822 .44673 .44972 .44297 .44307 .43598 Mtetra
.44307 .43598 .44972 .44297 .46126 .43919 .45464 .43218 Mtetra
.45464 .43218 .46126 .43919 .47285 .4354 .46627 .42835 Mtetra
.46627 .42835 .47285 .4354 .48449 .43159 .47794 .42452 Mtetra
.47794 .42452 .48449 .43159 .49618 .42777 .48966 .42066 Mtetra
.48966 .42066 .49618 .42777 .50792 .42392 .50144 .41679 Mtetra
.648 .736 .913 r
.50144 .41679 .50792 .42392 .51971 .42007 .51326 .41338 Mtetra
.634 .746 .929 r
.51326 .41338 .51971 .42007 .53155 .41619 .52513 .4103 Mtetra
.639 .775 .945 r
.52513 .4103 .53155 .41619 .54345 .41279 .53707 .40697 Mtetra
.646 .781 .945 r
.53707 .40697 .54345 .41279 .5554 .40929 .54906 .40342 Mtetra
.654 .782 .942 r
.54906 .40342 .5554 .40929 .5674 .40557 .5611 .39966 Mtetra
.661 .784 .939 r
.5611 .39966 .5674 .40557 .57946 .40163 .57319 .39569 Mtetra
.668 .786 .937 r
.57319 .39569 .57946 .40163 .59156 .39747 .58533 .39151 Mtetra
.675 .788 .934 r
.58533 .39151 .59156 .39747 .6037 .39308 .59752 .38711 Mtetra
.682 .791 .932 r
.59752 .38711 .6037 .39308 .6159 .3886 .60976 .38249 Mtetra
.69 .79 .927 r
.60976 .38249 .6159 .3886 .62816 .38459 .62203 .37762 Mtetra
.679 .76 .913 r
.62203 .37762 .62816 .38459 .64047 .38056 .63437 .37307 Mtetra
.664 .741 .907 r
.63437 .37307 .64047 .38056 .65284 .37651 .64678 .36899 Mtetra
.64678 .36899 .65284 .37651 .66527 .37245 .65924 .3649 Mtetra
.65924 .3649 .66527 .37245 .67775 .36836 .67175 .36078 Mtetra
.67175 .36078 .67775 .36836 .69028 .36426 .68433 .35664 Mtetra
.68433 .35664 .69028 .36426 .70287 .36014 .69695 .35249 Mtetra
.69695 .35249 .70287 .36014 .71551 .35601 .70964 .34832 Mtetra
.70964 .34832 .71551 .35601 .72822 .35185 .72238 .34413 Mtetra
.72238 .34413 .72822 .35185 .74097 .34768 .73518 .33992 Mtetra
.73518 .33992 .74097 .34768 .75379 .34348 .74803 .33569 Mtetra
.74803 .33569 .75379 .34348 .76666 .33927 .76095 .33145 Mtetra
.76095 .33145 .76666 .33927 .7796 .33504 .77392 .32718 Mtetra
.77392 .32718 .7796 .33504 .79288 .33429 .78695 .3229 Mtetra
.364 .497 .859 r
.78695 .3229 .79288 .33429 .80676 .33916 .80086 .32795 Mtetra
.435 .544 .868 r
.80086 .32795 .80676 .33916 .82041 .3401 .81474 .33109 Mtetra
.653 .709 .889 r
.81474 .33109 .82041 .3401 .83338 .33292 .82806 .32708 Mtetra
.852 .856 .844 r
.82806 .32708 .83338 .33292 .84568 .3189 .84059 .31468 Mtetra
.882 .907 .841 r
.84059 .31468 .84568 .3189 .85843 .30925 .85301 .30117 Mtetra
.664 .741 .907 r
.85301 .30117 .85843 .30925 .87177 .30488 .8664 .29677 Mtetra
.8664 .29677 .87177 .30488 .88518 .3005 .87985 .29234 Mtetra
.27897 .48097 .28608 .48761 .29699 .48402 .28991 .47736 Mtetra
.644 .736 .916 r
.28991 .47736 .29699 .48402 .30794 .48042 .30085 .4743 Mtetra
0 .177 .651 r
.30085 .4743 .30794 .48042 .3184 .48556 .31116 .48183 Mtetra
.113 .591 .912 r
.31116 .48183 .3184 .48556 .32902 .48967 .32193 .48392 Mtetra
.748 .787 .884 r
.32193 .48392 .32902 .48967 .34019 .48573 .33328 .47733 Mtetra
.804 .729 .781 r
.33328 .47733 .34019 .48573 .35176 .47489 .34496 .46508 Mtetra
.764 .698 .789 r
.34496 .46508 .35176 .47489 .36342 .46218 .35651 .45534 Mtetra
.664 .741 .907 r
.35651 .45534 .36342 .46218 .37465 .45848 .36777 .45162 Mtetra
.36777 .45162 .37465 .45848 .38594 .45477 .37909 .44788 Mtetra
.37909 .44788 .38594 .45477 .39727 .45105 .39045 .44413 Mtetra
.39045 .44413 .39727 .45105 .40865 .4473 .40185 .44035 Mtetra
.40185 .44035 .40865 .4473 .42007 .44355 .41331 .43657 Mtetra
.41331 .43657 .42007 .44355 .43155 .43977 .42482 .43276 Mtetra
.42482 .43276 .43155 .43977 .44307 .43598 .43637 .42894 Mtetra
.43637 .42894 .44307 .43598 .45464 .43218 .44798 .42511 Mtetra
.44798 .42511 .45464 .43218 .46627 .42835 .45963 .42126 Mtetra
.45963 .42126 .46627 .42835 .47794 .42452 .47134 .41739 Mtetra
.47134 .41739 .47794 .42452 .48966 .42066 .48309 .4135 Mtetra
.64 .733 .916 r
.48309 .4135 .48966 .42066 .50144 .41679 .49489 .41029 Mtetra
.626 .75 .936 r
.49489 .41029 .50144 .41679 .51326 .41338 .50675 .40738 Mtetra
.632 .77 .946 r
.50675 .40738 .51326 .41338 .52513 .4103 .51866 .40422 Mtetra
.641 .771 .942 r
.51866 .40422 .52513 .4103 .53707 .40697 .53063 .40083 Mtetra
.649 .772 .938 r
.53063 .40083 .53707 .40697 .54906 .40342 .54266 .39722 Mtetra
.656 .773 .935 r
.54266 .39722 .54906 .40342 .5611 .39966 .55474 .39341 Mtetra
.662 .775 .933 r
.55474 .39341 .5611 .39966 .57319 .39569 .56687 .38941 Mtetra
.669 .777 .93 r
.56687 .38941 .57319 .39569 .58533 .39151 .57905 .38521 Mtetra
.675 .779 .928 r
.57905 .38521 .58533 .39151 .59752 .38711 .59128 .38081 Mtetra
.681 .782 .926 r
.59128 .38081 .59752 .38711 .60976 .38249 .60356 .3762 Mtetra
.688 .785 .924 r
.60356 .3762 .60976 .38249 .62203 .37762 .61588 .37134 Mtetra
.696 .789 .922 r
.61588 .37134 .62203 .37762 .63437 .37307 .62824 .36623 Mtetra
.686 .769 .915 r
.62824 .36623 .63437 .37307 .64678 .36899 .64066 .36141 Mtetra
.664 .741 .907 r
.64066 .36141 .64678 .36899 .65924 .3649 .65316 .35728 Mtetra
.65316 .35728 .65924 .3649 .67175 .36078 .66571 .35313 Mtetra
.66571 .35313 .67175 .36078 .68433 .35664 .67832 .34896 Mtetra
.67832 .34896 .68433 .35664 .69695 .35249 .69099 .34478 Mtetra
.69099 .34478 .69695 .35249 .70964 .34832 .70371 .34057 Mtetra
.70371 .34057 .70964 .34832 .72238 .34413 .7165 .33635 Mtetra
.7165 .33635 .72238 .34413 .73518 .33992 .72933 .3321 Mtetra
.72933 .3321 .73518 .33992 .74803 .33569 .74223 .32784 Mtetra
.74223 .32784 .74803 .33569 .76095 .33145 .75519 .32356 Mtetra
.75519 .32356 .76095 .33145 .77392 .32718 .7682 .31925 Mtetra
.7682 .31925 .77392 .32718 .78695 .3229 .78127 .31493 Mtetra
.415 .619 .936 r
.78127 .31493 .78695 .3229 .80086 .32795 .79494 .31683 Mtetra
.376 .513 .868 r
.79494 .31683 .80086 .32795 .81474 .33109 .80897 .32137 Mtetra
.573 .655 .893 r
.80897 .32137 .81474 .33109 .82806 .32708 .82258 .32005 Mtetra
.807 .817 .859 r
.82258 .32005 .82806 .32708 .84059 .31468 .83538 .30968 Mtetra
.905 .88 .799 r
.83538 .30968 .84059 .31468 .85301 .30117 .8476 .29362 Mtetra
.682 .766 .915 r
.8476 .29362 .85301 .30117 .8664 .29677 .86098 .28858 Mtetra
.664 .741 .907 r
.86098 .28858 .8664 .29677 .87985 .29234 .87448 .28412 Mtetra
.27181 .47429 .27897 .48097 .28991 .47736 .28278 .47064 Mtetra
.548 .705 .943 r
.28278 .47064 .28991 .47736 .30085 .4743 .2936 .46967 Mtetra
.475 0 0 r
.2936 .46967 .30085 .4743 .31116 .48183 .30391 .47725 Mtetra
.402 .724 .989 r
.30391 .47725 .31116 .48183 .32193 .48392 .31482 .47736 Mtetra
.779 .767 .842 r
.31482 .47736 .32193 .48392 .33328 .47733 .32633 .4687 Mtetra
.81 .726 .773 r
.32633 .4687 .33328 .47733 .34496 .46508 .3381 .45563 Mtetra
.73 .697 .818 r
.3381 .45563 .34496 .46508 .35651 .45534 .34955 .44846 Mtetra
.664 .741 .907 r
.34955 .44846 .35651 .45534 .36777 .45162 .36084 .4447 Mtetra
.36084 .4447 .36777 .45162 .37909 .44788 .37218 .44094 Mtetra
.37218 .44094 .37909 .44788 .39045 .44413 .38357 .43715 Mtetra
.38357 .43715 .39045 .44413 .40185 .44035 .39501 .43335 Mtetra
.39501 .43335 .40185 .44035 .41331 .43657 .4065 .42953 Mtetra
.4065 .42953 .41331 .43657 .42482 .43276 .41803 .4257 Mtetra
.41803 .4257 .42482 .43276 .43637 .42894 .42962 .42185 Mtetra
.42962 .42185 .43637 .42894 .44798 .42511 .44126 .41798 Mtetra
.44126 .41798 .44798 .42511 .45963 .42126 .45294 .4141 Mtetra
.45294 .4141 .45963 .42126 .47134 .41739 .46468 .4102 Mtetra
.648 .736 .913 r
.46468 .4102 .47134 .41739 .48309 .4135 .47646 .40677 Mtetra
.619 .741 .934 r
.47646 .40677 .48309 .4135 .49489 .41029 .48829 .40405 Mtetra
.626 .76 .943 r
.48829 .40405 .49489 .41029 .50675 .40738 .50018 .40106 Mtetra
.636 .762 .939 r
.50018 .40106 .50675 .40738 .51866 .40422 .51213 .39783 Mtetra
.644 .763 .935 r
.51213 .39783 .51866 .40422 .53063 .40083 .52413 .39437 Mtetra
.651 .764 .932 r
.52413 .39437 .53063 .40083 .54266 .39722 .5362 .39071 Mtetra
.657 .765 .929 r
.5362 .39071 .54266 .39722 .55474 .39341 .54832 .38686 Mtetra
.663 .767 .927 r
.54832 .38686 .55474 .39341 .56687 .38941 .56049 .38282 Mtetra
.669 .769 .925 r
.56049 .38282 .56687 .38941 .57905 .38521 .57271 .3786 Mtetra
.674 .771 .923 r
.57271 .3786 .57905 .38521 .59128 .38081 .58498 .3742 Mtetra
.68 .773 .921 r
.58498 .3742 .59128 .38081 .60356 .3762 .5973 .36958 Mtetra
.687 .776 .919 r
.5973 .36958 .60356 .3762 .61588 .37134 .60966 .36474 Mtetra
.694 .78 .917 r
.60966 .36474 .61588 .37134 .62824 .36623 .62207 .35964 Mtetra
.702 .784 .915 r
.62207 .35964 .62824 .36623 .64066 .36141 .63451 .35426 Mtetra
.679 .76 .913 r
.63451 .35426 .64066 .36141 .65316 .35728 .64703 .34961 Mtetra
.664 .741 .907 r
.64703 .34961 .65316 .35728 .66571 .35313 .65962 .34542 Mtetra
.65962 .34542 .66571 .35313 .67832 .34896 .67227 .34122 Mtetra
.67227 .34122 .67832 .34896 .69099 .34478 .68498 .337 Mtetra
.68498 .337 .69099 .34478 .70371 .34057 .69774 .33276 Mtetra
.69774 .33276 .70371 .34057 .7165 .33635 .71056 .3285 Mtetra
.71056 .3285 .7165 .33635 .72933 .3321 .72344 .32422 Mtetra
.72344 .32422 .72933 .3321 .74223 .32784 .73638 .31992 Mtetra
.73638 .31992 .74223 .32784 .75519 .32356 .74937 .3156 Mtetra
.74937 .3156 .75519 .32356 .7682 .31925 .76243 .31126 Mtetra
.76243 .31126 .7682 .31925 .78127 .31493 .77555 .3069 Mtetra
.538 .684 .933 r
.77555 .3069 .78127 .31493 .79494 .31683 .78902 .30608 Mtetra
.331 .496 .871 r
.78902 .30608 .79494 .31683 .80897 .32137 .80313 .31139 Mtetra
.501 .614 .896 r
.80313 .31139 .80897 .32137 .82258 .32005 .81697 .31215 Mtetra
.761 .784 .871 r
.81697 .31215 .82258 .32005 .83538 .30968 .83003 .30379 Mtetra
.897 .857 .795 r
.83003 .30379 .83538 .30968 .8476 .29362 .84232 .28762 Mtetra
.747 .839 .921 r
.84232 .28762 .8476 .29362 .86098 .28858 .85551 .28033 Mtetra
.664 .741 .907 r
.85551 .28033 .86098 .28858 .87448 .28412 .86906 .27583 Mtetra
.26459 .46755 .27181 .47429 .28278 .47064 .27559 .46388 Mtetra
.437 .659 .954 r
.27559 .46388 .28278 .47064 .2936 .46967 .28631 .46462 Mtetra
.416 0 0 r
.28631 .46462 .2936 .46967 .30391 .47725 .29664 .47192 Mtetra
.557 .76 .972 r
.29664 .47192 .30391 .47725 .31482 .47736 .30769 .4703 Mtetra
.795 .757 .818 r
.30769 .4703 .31482 .47736 .32633 .4687 .31933 .46014 Mtetra
.814 .729 .771 r
.31933 .46014 .32633 .4687 .3381 .45563 .33117 .44665 Mtetra
.694 .696 .848 r
.33117 .44665 .3381 .45563 .34955 .44846 .34253 .44152 Mtetra
.664 .741 .907 r
.34253 .44152 .34955 .44846 .36084 .4447 .35385 .43773 Mtetra
.35385 .43773 .36084 .4447 .37218 .44094 .36522 .43394 Mtetra
.36522 .43394 .37218 .44094 .38357 .43715 .37664 .43012 Mtetra
.37664 .43012 .38357 .43715 .39501 .43335 .38811 .42629 Mtetra
.38811 .42629 .39501 .43335 .4065 .42953 .39963 .42244 Mtetra
.39963 .42244 .4065 .42953 .41803 .4257 .4112 .41858 Mtetra
.4112 .41858 .41803 .4257 .42962 .42185 .42282 .4147 Mtetra
.42282 .4147 .42962 .42185 .44126 .41798 .43448 .4108 Mtetra
.43448 .4108 .44126 .41798 .45294 .4141 .4462 .40689 Mtetra
.4462 .40689 .45294 .4141 .46468 .4102 .45797 .40295 Mtetra
.618 .726 .923 r
.45797 .40295 .46468 .4102 .47646 .40677 .46977 .40031 Mtetra
.618 .752 .941 r
.46977 .40031 .47646 .40677 .48829 .40405 .48163 .39753 Mtetra
.629 .754 .937 r
.48163 .39753 .48829 .40405 .50018 .40106 .49356 .39446 Mtetra
.638 .755 .933 r
.49356 .39446 .50018 .40106 .51213 .39783 .50554 .39116 Mtetra
.646 .757 .93 r
.50554 .39116 .51213 .39783 .52413 .39437 .51758 .38764 Mtetra
.652 .758 .927 r
.51758 .38764 .52413 .39437 .5362 .39071 .52968 .38393 Mtetra
.658 .759 .924 r
.52968 .38393 .5362 .39071 .54832 .38686 .54184 .38003 Mtetra
.663 .76 .922 r
.54184 .38003 .54832 .38686 .56049 .38282 .55405 .37597 Mtetra
.668 .762 .92 r
.55405 .37597 .56049 .38282 .57271 .3786 .56631 .37173 Mtetra
.674 .764 .918 r
.56631 .37173 .57271 .3786 .58498 .3742 .57862 .3673 Mtetra
.679 .766 .917 r
.57862 .3673 .58498 .3742 .5973 .36958 .59098 .36269 Mtetra
.686 .769 .915 r
.59098 .36269 .5973 .36958 .60966 .36474 .60338 .35784 Mtetra
.692 .772 .913 r
.60338 .35784 .60966 .36474 .62207 .35964 .61583 .35276 Mtetra
.7 .776 .91 r
.61583 .35276 .62207 .35964 .63451 .35426 .62832 .34739 Mtetra
.704 .778 .91 r
.62832 .34739 .63451 .35426 .64703 .34961 .64085 .34187 Mtetra
.664 .741 .907 r
.64085 .34187 .64703 .34961 .65962 .34542 .65348 .33765 Mtetra
.65348 .33765 .65962 .34542 .67227 .34122 .66617 .33341 Mtetra
.66617 .33341 .67227 .34122 .68498 .337 .67892 .32915 Mtetra
.67892 .32915 .68498 .337 .69774 .33276 .69172 .32488 Mtetra
.69172 .32488 .69774 .33276 .71056 .3285 .70458 .32058 Mtetra
.70458 .32058 .71056 .3285 .72344 .32422 .7175 .31626 Mtetra
.7175 .31626 .72344 .32422 .73638 .31992 .73048 .31193 Mtetra
.73048 .31193 .73638 .31992 .74937 .3156 .74351 .30757 Mtetra
.74351 .30757 .74937 .3156 .76243 .31126 .75661 .3032 Mtetra
.75661 .3032 .76243 .31126 .77555 .3069 .76977 .2988 Mtetra
.619 .722 .92 r
.76977 .2988 .77555 .3069 .78902 .30608 .7831 .2958 Mtetra
.296 .487 .876 r
.7831 .2958 .78902 .30608 .80313 .31139 .79727 .30147 Mtetra
.439 .583 .899 r
.79727 .30147 .80313 .31139 .81697 .31215 .81128 .30372 Mtetra
.719 .758 .883 r
.81128 .30372 .81697 .31215 .83003 .30379 .82455 .2971 Mtetra
.885 .838 .794 r
.82455 .2971 .83003 .30379 .84232 .28762 .83694 .28115 Mtetra
.788 .836 .889 r
.83694 .28115 .84232 .28762 .85551 .28033 .85 .272 Mtetra
.664 .741 .907 r
.85 .272 .85551 .28033 .86906 .27583 .86359 .26746 Mtetra
.25732 .46076 .26459 .46755 .27559 .46388 .26834 .45706 Mtetra
.332 .609 .95 r
.26834 .45706 .27559 .46388 .28631 .46462 .27898 .45907 Mtetra
0 .197 .648 r
.27898 .45907 .28631 .46462 .29664 .47192 .28935 .46597 Mtetra
.631 .762 .942 r
.28935 .46597 .29664 .47192 .30769 .4703 .30051 .46302 Mtetra
.805 .754 .805 r
.30051 .46302 .30769 .4703 .31933 .46014 .31226 .45184 Mtetra
.817 .735 .773 r
.31226 .45184 .31933 .46014 .33117 .44665 .32415 .43832 Mtetra
.662 .703 .878 r
.32415 .43832 .33117 .44665 .34253 .44152 .33546 .43452 Mtetra
.664 .741 .907 r
.33546 .43452 .34253 .44152 .35385 .43773 .34681 .43071 Mtetra
.34681 .43071 .35385 .43773 .36522 .43394 .35821 .42688 Mtetra
.35821 .42688 .36522 .43394 .37664 .43012 .36966 .42304 Mtetra
.36966 .42304 .37664 .43012 .38811 .42629 .38116 .41917 Mtetra
.38116 .41917 .38811 .42629 .39963 .42244 .39271 .4153 Mtetra
.39271 .4153 .39963 .42244 .4112 .41858 .40431 .4114 Mtetra
.40431 .4114 .4112 .41858 .42282 .4147 .41596 .40749 Mtetra
.41596 .40749 .42282 .4147 .43448 .4108 .42766 .40356 Mtetra
.42766 .40356 .43448 .4108 .4462 .40689 .43941 .39961 Mtetra
.648 .736 .913 r
.43941 .39961 .4462 .40689 .45797 .40295 .4512 .39614 Mtetra
.611 .738 .936 r
.4512 .39614 .45797 .40295 .46977 .40031 .46303 .39358 Mtetra
.622 .745 .935 r
.46303 .39358 .46977 .40031 .48163 .39753 .47492 .39072 Mtetra
.632 .748 .931 r
.47492 .39072 .48163 .39753 .49356 .39446 .48688 .38759 Mtetra
.64 .749 .928 r
.48688 .38759 .49356 .39446 .50554 .39116 .4989 .38423 Mtetra
.647 .751 .925 r
.4989 .38423 .50554 .39116 .51758 .38764 .51098 .38066 Mtetra
.653 .752 .922 r
.51098 .38066 .51758 .38764 .52968 .38393 .52311 .3769 Mtetra
.659 .753 .92 r
.52311 .3769 .52968 .38393 .54184 .38003 .5353 .37296 Mtetra
.663 .755 .918 r
.5353 .37296 .54184 .38003 .55405 .37597 .54755 .36886 Mtetra
.668 .756 .916 r
.54755 .36886 .55405 .37597 .56631 .37173 .55985 .3646 Mtetra
.673 .758 .914 r
.55985 .3646 .56631 .37173 .57862 .3673 .5722 .36016 Mtetra
.679 .76 .913 r
.5722 .36016 .57862 .3673 .59098 .36269 .5846 .35552 Mtetra
.684 .762 .911 r
.5846 .35552 .59098 .36269 .60338 .35784 .59704 .35068 Mtetra
.691 .766 .909 r
.59704 .35068 .60338 .35784 .61583 .35276 .60954 .34559 Mtetra
.698 .769 .906 r
.60954 .34559 .61583 .35276 .62832 .34739 .62207 .34023 Mtetra
.706 .772 .903 r
.62207 .34023 .62832 .34739 .64085 .34187 .63464 .33456 Mtetra
.679 .761 .913 r
.63464 .33456 .64085 .34187 .65348 .33765 .64729 .32981 Mtetra
.664 .741 .907 r
.64729 .32981 .65348 .33765 .66617 .33341 .66002 .32553 Mtetra
.66002 .32553 .66617 .33341 .67892 .32915 .6728 .32124 Mtetra
.6728 .32124 .67892 .32915 .69172 .32488 .68564 .31693 Mtetra
.68564 .31693 .69172 .32488 .70458 .32058 .69855 .3126 Mtetra
.69855 .3126 .70458 .32058 .7175 .31626 .71151 .30825 Mtetra
.71151 .30825 .7175 .31626 .73048 .31193 .72452 .30387 Mtetra
.72452 .30387 .73048 .31193 .74351 .30757 .7376 .29948 Mtetra
.7376 .29948 .74351 .30757 .75661 .3032 .75074 .29507 Mtetra
.75074 .29507 .75661 .3032 .76977 .2988 .76394 .29064 Mtetra
.76394 .29064 .76977 .2988 .7831 .2958 .7772 .28618 Mtetra
.27 .49 .886 r
.7772 .28618 .7831 .2958 .79727 .30147 .79139 .29181 Mtetra
.387 .562 .903 r
.79139 .29181 .79727 .30147 .81128 .30372 .80552 .29505 Mtetra
.685 .74 .893 r
.80552 .29505 .81128 .30372 .82455 .2971 .81897 .28974 Mtetra
.874 .823 .794 r
.81897 .28974 .82455 .2971 .83694 .28115 .83146 .27414 Mtetra
.81 .827 .863 r
.83146 .27414 .83694 .28115 .85 .272 .84444 .26361 Mtetra
.664 .741 .907 r
.84444 .26361 .85 .272 .86359 .26746 .85807 .25903 Mtetra
.24999 .45391 .25732 .46076 .26834 .45706 .26104 .45018 Mtetra
.253 .566 .937 r
.26104 .45018 .26834 .45706 .27898 .45907 .27163 .45302 Mtetra
0 .254 .714 r
.27163 .45302 .27898 .45907 .28935 .46597 .28203 .45957 Mtetra
.666 .758 .919 r
.28203 .45957 .28935 .46597 .30051 .46302 .29328 .45572 Mtetra
.811 .754 .799 r
.29328 .45572 .30051 .46302 .31226 .45184 .30512 .4439 Mtetra
.813 .742 .786 r
.30512 .4439 .31226 .45184 .32415 .43832 .31699 .4313 Mtetra
.664 .741 .907 r
.31699 .4313 .32415 .43832 .33546 .43452 .32833 .42747 Mtetra
.32833 .42747 .33546 .43452 .34681 .43071 .33971 .42363 Mtetra
.33971 .42363 .34681 .43071 .35821 .42688 .35114 .41977 Mtetra
.35114 .41977 .35821 .42688 .36966 .42304 .36262 .41589 Mtetra
.36262 .41589 .36966 .42304 .38116 .41917 .37415 .412 Mtetra
.37415 .412 .38116 .41917 .39271 .4153 .38573 .40809 Mtetra
.38573 .40809 .39271 .4153 .40431 .4114 .39736 .40417 Mtetra
.39736 .40417 .40431 .4114 .41596 .40749 .40904 .40022 Mtetra
.40904 .40022 .41596 .40749 .42766 .40356 .42077 .39626 Mtetra
.42077 .39626 .42766 .40356 .43941 .39961 .43256 .39228 Mtetra
.633 .731 .919 r
.43256 .39228 .43941 .39961 .4512 .39614 .44437 .38919 Mtetra
.612 .737 .934 r
.44437 .38919 .4512 .39614 .46303 .39358 .45623 .38657 Mtetra
.624 .74 .93 r
.45623 .38657 .46303 .39358 .47492 .39072 .46816 .38366 Mtetra
.634 .742 .926 r
.46816 .38366 .47492 .39072 .48688 .38759 .48015 .38048 Mtetra
.641 .744 .923 r
.48015 .38048 .48688 .38759 .4989 .38423 .4922 .37707 Mtetra
.648 .746 .921 r
.4922 .37707 .4989 .38423 .51098 .38066 .50432 .37344 Mtetra
.654 .747 .918 r
.50432 .37344 .51098 .38066 .52311 .3769 .51649 .36964 Mtetra
.659 .748 .916 r
.51649 .36964 .52311 .3769 .5353 .37296 .52871 .36567 Mtetra
.664 .75 .914 r
.52871 .36567 .5353 .37296 .54755 .36886 .541 .36154 Mtetra
.668 .751 .913 r
.541 .36154 .54755 .36886 .55985 .3646 .55333 .35724 Mtetra
.673 .753 .911 r
.55333 .35724 .55985 .3646 .5722 .36016 .56572 .35277 Mtetra
.678 .755 .909 r
.56572 .35277 .5722 .36016 .5846 .35552 .57816 .34813 Mtetra
.684 .757 .907 r
.57816 .34813 .5846 .35552 .59704 .35068 .59065 .34326 Mtetra
.69 .76 .905 r
.59065 .34326 .59704 .35068 .60954 .34559 .60318 .33817 Mtetra
.697 .763 .902 r
.60318 .33817 .60954 .34559 .62207 .34023 .61575 .33279 Mtetra
.705 .766 .899 r
.61575 .33279 .62207 .34023 .63464 .33456 .62837 .32711 Mtetra
.691 .762 .906 r
.62837 .32711 .63464 .33456 .64729 .32981 .64105 .3219 Mtetra
.664 .741 .907 r
.64105 .3219 .64729 .32981 .66002 .32553 .65381 .31759 Mtetra
.65381 .31759 .66002 .32553 .6728 .32124 .66664 .31327 Mtetra
.66664 .31327 .6728 .32124 .68564 .31693 .67952 .30892 Mtetra
.67952 .30892 .68564 .31693 .69855 .3126 .69246 .30455 Mtetra
.69246 .30455 .69855 .3126 .71151 .30825 .70546 .30016 Mtetra
.70546 .30016 .71151 .30825 .72452 .30387 .71852 .29575 Mtetra
.71852 .29575 .72452 .30387 .7376 .29948 .73164 .29132 Mtetra
.73164 .29132 .7376 .29948 .75074 .29507 .74482 .28687 Mtetra
.74482 .28687 .75074 .29507 .76394 .29064 .75807 .2824 Mtetra
.75807 .2824 .76394 .29064 .7772 .28618 .77137 .27791 Mtetra
.266 .529 .914 r
.77137 .27791 .7772 .28618 .79139 .29181 .7855 .28252 Mtetra
.346 .549 .908 r
.7855 .28252 .79139 .29181 .80552 .29505 .79971 .28634 Mtetra
.66 .731 .902 r
.79971 .28634 .80552 .29505 .81897 .28974 .81329 .28189 Mtetra
.866 .813 .795 r
.81329 .28189 .81897 .28974 .83146 .27414 .82588 .26659 Mtetra
.82 .816 .845 r
.82588 .26659 .83146 .27414 .84444 .26361 .83883 .25514 Mtetra
.664 .741 .907 r
.83883 .25514 .84444 .26361 .85807 .25903 .85251 .25052 Mtetra
.24261 .44702 .24999 .45391 .26104 .45018 .25368 .44326 Mtetra
.211 .542 .928 r
.25368 .44326 .26104 .45018 .27163 .45302 .26425 .44648 Mtetra
0 .292 .758 r
.26425 .44648 .27163 .45302 .28203 .45957 .27467 .45283 Mtetra
.68 .753 .906 r
.27467 .45283 .28203 .45957 .29328 .45572 .28598 .44851 Mtetra
.816 .757 .798 r
.28598 .44851 .29328 .45572 .30512 .4439 .29788 .43638 Mtetra
.813 .752 .795 r
.29788 .43638 .30512 .4439 .31699 .4313 .30978 .42422 Mtetra
.664 .741 .907 r
.30978 .42422 .31699 .4313 .32833 .42747 .32114 .42036 Mtetra
.32114 .42036 .32833 .42747 .33971 .42363 .33255 .41649 Mtetra
.33255 .41649 .33971 .42363 .35114 .41977 .34401 .4126 Mtetra
.34401 .4126 .35114 .41977 .36262 .41589 .35552 .40869 Mtetra
.35552 .40869 .36262 .41589 .37415 .412 .36709 .40477 Mtetra
.36709 .40477 .37415 .412 .38573 .40809 .3787 .40083 Mtetra
.3787 .40083 .38573 .40809 .39736 .40417 .39036 .39687 Mtetra
.39036 .39687 .39736 .40417 .40904 .40022 .40207 .3929 Mtetra
.40207 .3929 .40904 .40022 .42077 .39626 .41384 .38891 Mtetra
.41384 .38891 .42077 .39626 .43256 .39228 .42565 .3849 Mtetra
.625 .728 .921 r
.42565 .3849 .43256 .39228 .44437 .38919 .43749 .38198 Mtetra
.614 .731 .929 r
.43749 .38198 .44437 .38919 .45623 .38657 .44938 .37931 Mtetra
.625 .734 .925 r
.44938 .37931 .45623 .38657 .46816 .38366 .46134 .37636 Mtetra
.635 .737 .922 r
.46134 .37636 .46816 .38366 .48015 .38048 .47336 .37313 Mtetra
.642 .739 .919 r
.47336 .37313 .48015 .38048 .4922 .37707 .48545 .36968 Mtetra
.649 .741 .917 r
.48545 .36968 .4922 .37707 .50432 .37344 .4976 .36601 Mtetra
.654 .743 .915 r
.4976 .36601 .50432 .37344 .51649 .36964 .50981 .36217 Mtetra
.659 .744 .913 r
.50981 .36217 .51649 .36964 .52871 .36567 .52207 .35816 Mtetra
.664 .745 .911 r
.52207 .35816 .52871 .36567 .541 .36154 .53439 .354 Mtetra
.668 .747 .909 r
.53439 .354 .541 .36154 .55333 .35724 .54676 .34967 Mtetra
.673 .748 .908 r
.54676 .34967 .55333 .35724 .56572 .35277 .55919 .34517 Mtetra
.677 .75 .906 r
.55919 .34517 .56572 .35277 .57816 .34813 .57166 .3405 Mtetra
.683 .752 .904 r
.57166 .3405 .57816 .34813 .59065 .34326 .58419 .33561 Mtetra
.689 .754 .901 r
.58419 .33561 .59065 .34326 .60318 .33817 .59676 .33049 Mtetra
.696 .757 .899 r
.59676 .33049 .60318 .33817 .61575 .33279 .60938 .32509 Mtetra
.704 .76 .896 r
.60938 .32509 .61575 .33279 .62837 .32711 .62204 .31939 Mtetra
.697 .758 .899 r
.62204 .31939 .62837 .32711 .64105 .3219 .63475 .31393 Mtetra
.664 .741 .907 r
.63475 .31393 .64105 .3219 .65381 .31759 .64756 .30959 Mtetra
.64756 .30959 .65381 .31759 .66664 .31327 .66042 .30522 Mtetra
.66042 .30522 .66664 .31327 .67952 .30892 .67334 .30084 Mtetra
.67334 .30084 .67952 .30892 .69246 .30455 .68632 .29643 Mtetra
.68632 .29643 .69246 .30455 .70546 .30016 .69937 .292 Mtetra
.69937 .292 .70546 .30016 .71852 .29575 .71247 .28756 Mtetra
.71247 .28756 .71852 .29575 .73164 .29132 .72563 .28309 Mtetra
.72563 .28309 .73164 .29132 .74482 .28687 .73886 .2786 Mtetra
.73886 .2786 .74482 .28687 .75807 .2824 .75214 .27409 Mtetra
.75214 .27409 .75807 .2824 .77137 .27791 .76549 .26956 Mtetra
.295 .547 .92 r
.76549 .26956 .77137 .27791 .7855 .28252 .77961 .27363 Mtetra
.316 .545 .914 r
.77961 .27363 .7855 .28252 .79971 .28634 .79387 .27771 Mtetra
.647 .729 .909 r
.79387 .27771 .79971 .28634 .81329 .28189 .80754 .27368 Mtetra
.86 .805 .795 r
.80754 .27368 .81329 .28189 .82588 .26659 .82021 .25853 Mtetra
.822 .804 .834 r
.82021 .25853 .82588 .26659 .83883 .25514 .83317 .24659 Mtetra
.664 .741 .907 r
.83317 .24659 .83883 .25514 .85251 .25052 .8469 .24193 Mtetra
.23517 .44006 .24261 .44702 .25368 .44326 .24627 .43627 Mtetra
.211 .542 .928 r
.24627 .43627 .25368 .44326 .26425 .44648 .25684 .43948 Mtetra
0 .308 .779 r
.25684 .43948 .26425 .44648 .27467 .45283 .26727 .44582 Mtetra
.68 .747 .902 r
.26727 .44582 .27467 .45283 .28598 .44851 .27861 .44147 Mtetra
.818 .762 .8 r
.27861 .44147 .28598 .44851 .29788 .43638 .29056 .42929 Mtetra
.29056 .42929 .29788 .43638 .30978 .42422 .3025 .41709 Mtetra
.664 .741 .907 r
.3025 .41709 .30978 .42422 .32114 .42036 .3139 .4132 Mtetra
.3139 .4132 .32114 .42036 .33255 .41649 .32534 .4093 Mtetra
.32534 .4093 .33255 .41649 .34401 .4126 .33683 .40538 Mtetra
.33683 .40538 .34401 .4126 .35552 .40869 .34837 .40144 Mtetra
.34837 .40144 .35552 .40869 .36709 .40477 .35996 .39748 Mtetra
.35996 .39748 .36709 .40477 .3787 .40083 .37161 .39351 Mtetra
.37161 .39351 .3787 .40083 .39036 .39687 .3833 .38952 Mtetra
.3833 .38952 .39036 .39687 .40207 .3929 .39504 .38551 Mtetra
.39504 .38551 .40207 .3929 .41384 .38891 .40684 .38149 Mtetra
.40684 .38149 .41384 .38891 .42565 .3849 .41869 .37745 Mtetra
.625 .728 .921 r
.41869 .37745 .42565 .3849 .43749 .38198 .43056 .3745 Mtetra
.615 .725 .924 r
.43056 .3745 .43749 .38198 .44938 .37931 .44248 .3718 Mtetra
.626 .729 .921 r
.44248 .3718 .44938 .37931 .46134 .37636 .45447 .36882 Mtetra
.635 .732 .918 r
.45447 .36882 .46134 .37636 .47336 .37313 .46653 .36556 Mtetra
.642 .734 .916 r
.46653 .36556 .47336 .37313 .48545 .36968 .47865 .36207 Mtetra
.649 .737 .913 r
.47865 .36207 .48545 .36968 .4976 .36601 .49083 .35837 Mtetra
.654 .738 .911 r
.49083 .35837 .4976 .36601 .50981 .36217 .50307 .3545 Mtetra
.659 .74 .91 r
.50307 .3545 .50981 .36217 .52207 .35816 .51537 .35046 Mtetra
.663 .741 .908 r
.51537 .35046 .52207 .35816 .53439 .354 .52772 .34625 Mtetra
.668 .743 .906 r
.52772 .34625 .53439 .354 .54676 .34967 .54013 .34189 Mtetra
.672 .744 .905 r
.54013 .34189 .54676 .34967 .55919 .34517 .5526 .33736 Mtetra
.677 .746 .903 r
.5526 .33736 .55919 .34517 .57166 .3405 .56511 .33265 Mtetra
.683 .748 .9 r
.56511 .33265 .57166 .3405 .58419 .33561 .57768 .32772 Mtetra
.689 .75 .898 r
.57768 .32772 .58419 .33561 .59676 .33049 .59029 .32256 Mtetra
.696 .752 .895 r
.59029 .32256 .59676 .33049 .60938 .32509 .60295 .31713 Mtetra
.703 .754 .892 r
.60295 .31713 .60938 .32509 .62204 .31939 .61565 .31138 Mtetra
.696 .752 .895 r
.61565 .31138 .62204 .31939 .63475 .31393 .6284 .30589 Mtetra
.664 .741 .907 r
.6284 .30589 .63475 .31393 .64756 .30959 .64125 .30151 Mtetra
.64125 .30151 .64756 .30959 .66042 .30522 .65415 .29711 Mtetra
.65415 .29711 .66042 .30522 .67334 .30084 .66711 .29269 Mtetra
.66711 .29269 .67334 .30084 .68632 .29643 .68014 .28824 Mtetra
.68014 .28824 .68632 .29643 .69937 .292 .69322 .28378 Mtetra
.69322 .28378 .69937 .292 .71247 .28756 .70636 .27929 Mtetra
.70636 .27929 .71247 .28756 .72563 .28309 .71957 .27479 Mtetra
.71957 .27479 .72563 .28309 .73886 .2786 .73284 .27026 Mtetra
.73284 .27026 .73886 .2786 .75214 .27409 .74616 .26571 Mtetra
.74616 .26571 .75214 .27409 .76549 .26956 .75956 .26114 Mtetra
.295 .547 .92 r
.75956 .26114 .76549 .26956 .77961 .27363 .77371 .26519 Mtetra
.297 .549 .921 r
.77371 .26519 .77961 .27363 .79387 .27771 .788 .26924 Mtetra
.646 .736 .914 r
.788 .26924 .79387 .27771 .80754 .27368 .80171 .26517 Mtetra
.858 .8 .793 r
.80171 .26517 .80754 .27368 .82021 .25853 .81444 .24996 Mtetra
.817 .793 .829 r
.81444 .24996 .82021 .25853 .83317 .24659 .82746 .23797 Mtetra
.664 .741 .907 r
.82746 .23797 .83317 .24659 .8469 .24193 .84124 .23327 Mtetra
.22766 .43306 .23517 .44006 .24627 .43627 .23879 .42924 Mtetra
.253 .566 .937 r
.23879 .42924 .24627 .43627 .25684 .43948 .24941 .43202 Mtetra
0 .305 .784 r
.24941 .43202 .25684 .43948 .26727 .44582 .25982 .43854 Mtetra
.666 .737 .903 r
.25982 .43854 .26727 .44582 .27861 .44147 .27116 .43459 Mtetra
.817 .767 .805 r
.27116 .43459 .27861 .44147 .29056 .42929 .28314 .42264 Mtetra
.828 .772 .8 r
.28314 .42264 .29056 .42929 .3025 .41709 .29517 .4099 Mtetra
.664 .741 .907 r
.29517 .4099 .3025 .41709 .3139 .4132 .3066 .40598 Mtetra
.3066 .40598 .3139 .4132 .32534 .4093 .31807 .40204 Mtetra
.31807 .40204 .32534 .4093 .33683 .40538 .32959 .39809 Mtetra
.32959 .39809 .33683 .40538 .34837 .40144 .34116 .39412 Mtetra
.34116 .39412 .34837 .40144 .35996 .39748 .35279 .39014 Mtetra
.35279 .39014 .35996 .39748 .37161 .39351 .36446 .38613 Mtetra
.36446 .38613 .37161 .39351 .3833 .38952 .37618 .38211 Mtetra
.37618 .38211 .3833 .38952 .39504 .38551 .38796 .37807 Mtetra
.38796 .37807 .39504 .38551 .40684 .38149 .39979 .37401 Mtetra
.39979 .37401 .40684 .38149 .41869 .37745 .41167 .36994 Mtetra
.633 .731 .919 r
.41167 .36994 .41869 .37745 .43056 .3745 .42358 .36675 Mtetra
.616 .719 .919 r
.42358 .36675 .43056 .3745 .44248 .3718 .43553 .36404 Mtetra
.626 .723 .917 r
.43553 .36404 .44248 .3718 .45447 .36882 .44755 .36103 Mtetra
.635 .727 .914 r
.44755 .36103 .45447 .36882 .46653 .36556 .45964 .35775 Mtetra
.642 .73 .912 r
.45964 .35775 .46653 .36556 .47865 .36207 .47179 .35424 Mtetra
.649 .732 .91 r
.47179 .35424 .47865 .36207 .49083 .35837 .484 .35052 Mtetra
.654 .734 .908 r
.484 .35052 .49083 .35837 .50307 .3545 .49628 .34662 Mtetra
.659 .736 .907 r
.49628 .34662 .50307 .3545 .51537 .35046 .50861 .34254 Mtetra
.663 .737 .905 r
.50861 .34254 .51537 .35046 .52772 .34625 .521 .33831 Mtetra
.668 .739 .903 r
.521 .33831 .52772 .34625 .54013 .34189 .53345 .33391 Mtetra
.672 .74 .902 r
.53345 .33391 .54013 .34189 .5526 .33736 .54595 .32933 Mtetra
.677 .742 .9 r
.54595 .32933 .5526 .33736 .56511 .33265 .5585 .32458 Mtetra
.683 .743 .897 r
.5585 .32458 .56511 .33265 .57768 .32772 .57111 .3196 Mtetra
.688 .745 .894 r
.57111 .3196 .57768 .32772 .59029 .32256 .58376 .31439 Mtetra
.695 .747 .891 r
.58376 .31439 .59029 .32256 .60295 .31713 .59646 .3089 Mtetra
.703 .749 .888 r
.59646 .3089 .60295 .31713 .61565 .31138 .6092 .30311 Mtetra
.69 .744 .893 r
.6092 .30311 .61565 .31138 .6284 .30589 .622 .29779 Mtetra
.664 .741 .907 r
.622 .29779 .6284 .30589 .64125 .30151 .63488 .29337 Mtetra
.63488 .29337 .64125 .30151 .65415 .29711 .64783 .28893 Mtetra
.64783 .28893 .65415 .29711 .66711 .29269 .66083 .28447 Mtetra
.66083 .28447 .66711 .29269 .68014 .28824 .67389 .27998 Mtetra
.67389 .27998 .68014 .28824 .69322 .28378 .68702 .27548 Mtetra
.68702 .27548 .69322 .28378 .70636 .27929 .70021 .27096 Mtetra
.70021 .27096 .70636 .27929 .71957 .27479 .71345 .26641 Mtetra
.71345 .26641 .71957 .27479 .73284 .27026 .72676 .26185 Mtetra
.72676 .26185 .73284 .27026 .74616 .26571 .74014 .25726 Mtetra
.74014 .25726 .74616 .26571 .75956 .26114 .75357 .25265 Mtetra
.266 .529 .914 r
.75357 .25265 .75956 .26114 .77371 .26519 .76779 .25718 Mtetra
.292 .562 .93 r
.76779 .25718 .77371 .26519 .788 .26924 .7821 .26093 Mtetra
.66 .748 .915 r
.7821 .26093 .788 .26924 .80171 .26517 .79581 .25636 Mtetra
.857 .795 .789 r
.79581 .25636 .80171 .26517 .81444 .24996 .80859 .24089 Mtetra
.807 .78 .828 r
.80859 .24089 .81444 .24996 .82746 .23797 .82171 .22928 Mtetra
.664 .741 .907 r
.82171 .22928 .82746 .23797 .84124 .23327 .83553 .22454 Mtetra
.2201 .42599 .22766 .43306 .23879 .42924 .23126 .42215 Mtetra
.332 .609 .95 r
.23126 .42215 .23879 .42924 .24941 .43202 .24196 .42406 Mtetra
0 .29 .778 r
.24196 .42406 .24941 .43202 .25982 .43854 .25234 .43091 Mtetra
.636 .721 .909 r
.25234 .43091 .25982 .43854 .27116 .43459 .26364 .42782 Mtetra
.813 .771 .814 r
.26364 .42782 .27116 .43459 .28314 .42264 .27562 .41641 Mtetra
.841 .781 .794 r
.27562 .41641 .28314 .42264 .29517 .4099 .28778 .40265 Mtetra
.664 .741 .907 r
.28778 .40265 .29517 .4099 .3066 .40598 .29924 .3987 Mtetra
.29924 .3987 .3066 .40598 .31807 .40204 .31074 .39473 Mtetra
.31074 .39473 .31807 .40204 .32959 .39809 .32229 .39075 Mtetra
.32229 .39075 .32959 .39809 .34116 .39412 .33389 .38675 Mtetra
.33389 .38675 .34116 .39412 .35279 .39014 .34555 .38273 Mtetra
.34555 .38273 .35279 .39014 .36446 .38613 .35725 .37869 Mtetra
.35725 .37869 .36446 .38613 .37618 .38211 .36901 .37464 Mtetra
.36901 .37464 .37618 .38211 .38796 .37807 .38082 .37056 Mtetra
.38082 .37056 .38796 .37807 .39979 .37401 .39268 .36647 Mtetra
.39268 .36647 .39979 .37401 .41167 .36994 .40459 .36236 Mtetra
.648 .736 .913 r
.40459 .36236 .41167 .36994 .42358 .36675 .41654 .35873 Mtetra
.615 .713 .915 r
.41654 .35873 .42358 .36675 .43553 .36404 .42852 .35601 Mtetra
.625 .717 .912 r
.42852 .35601 .43553 .36404 .44755 .36103 .44057 .353 Mtetra
.634 .721 .91 r
.44057 .353 .44755 .36103 .45964 .35775 .45269 .34971 Mtetra
.642 .725 .908 r
.45269 .34971 .45964 .35775 .47179 .35424 .46488 .34619 Mtetra
.648 .727 .906 r
.46488 .34619 .47179 .35424 .484 .35052 .47713 .34245 Mtetra
.654 .73 .905 r
.47713 .34245 .484 .35052 .49628 .34662 .48943 .33852 Mtetra
.659 .732 .903 r
.48943 .33852 .49628 .34662 .50861 .34254 .5018 .33441 Mtetra
.663 .733 .902 r
.5018 .33441 .50861 .34254 .521 .33831 .51423 .33014 Mtetra
.668 .735 .9 r
.51423 .33014 .521 .33831 .53345 .33391 .52671 .3257 Mtetra
.672 .736 .898 r
.52671 .3257 .53345 .33391 .54595 .32933 .53925 .32108 Mtetra
.677 .738 .896 r
.53925 .32108 .54595 .32933 .5585 .32458 .55184 .31627 Mtetra
.683 .739 .893 r
.55184 .31627 .5585 .32458 .57111 .3196 .56448 .31124 Mtetra
.689 .74 .891 r
.56448 .31124 .57111 .3196 .58376 .31439 .57717 .30596 Mtetra
.695 .742 .887 r
.57717 .30596 .58376 .31439 .59646 .3089 .58991 .30041 Mtetra
.702 .744 .884 r
.58991 .30041 .59646 .3089 .6092 .30311 .60269 .29455 Mtetra
.678 .734 .893 r
.60269 .29455 .6092 .30311 .622 .29779 .61554 .28961 Mtetra
.664 .741 .907 r
.61554 .28961 .622 .29779 .63488 .29337 .62846 .28515 Mtetra
.62846 .28515 .63488 .29337 .64783 .28893 .64145 .28068 Mtetra
.64145 .28068 .64783 .28893 .66083 .28447 .65449 .27618 Mtetra
.65449 .27618 .66083 .28447 .67389 .27998 .6676 .27166 Mtetra
.6676 .27166 .67389 .27998 .68702 .27548 .68077 .26711 Mtetra
.68077 .26711 .68702 .27548 .70021 .27096 .69399 .26255 Mtetra
.69399 .26255 .70021 .27096 .71345 .26641 .70729 .25797 Mtetra
.70729 .25797 .71345 .26641 .72676 .26185 .72064 .25336 Mtetra
.72064 .25336 .72676 .26185 .74014 .25726 .73405 .24874 Mtetra
.73405 .24874 .74014 .25726 .75357 .25265 .74753 .24409 Mtetra
.208 .492 .9 r
.74753 .24409 .75357 .25265 .76779 .25718 .76186 .2496 Mtetra
.308 .588 .942 r
.76186 .2496 .76779 .25718 .7821 .26093 .77615 .2527 Mtetra
.687 .763 .91 r
.77615 .2527 .7821 .26093 .79581 .25636 .78984 .24718 Mtetra
.857 .789 .783 r
.78984 .24718 .79581 .25636 .80859 .24089 .80264 .23129 Mtetra
.789 .765 .832 r
.80264 .23129 .80859 .24089 .82171 .22928 .8159 .22051 Mtetra
.664 .741 .907 r
.8159 .22051 .82171 .22928 .83553 .22454 .82977 .21573 Mtetra
.21248 .41888 .2201 .42599 .23126 .42215 .22367 .415 Mtetra
.437 .659 .954 r
.22367 .415 .23126 .42215 .24196 .42406 .2345 .41559 Mtetra
0 .272 .769 r
.2345 .41559 .24196 .42406 .25234 .43091 .24484 .42282 Mtetra
.585 .693 .916 r
.24484 .42282 .25234 .43091 .26364 .42782 .25605 .42102 Mtetra
.801 .772 .826 r
.25605 .42102 .26364 .42782 .27562 .41641 .26801 .41055 Mtetra
.846 .79 .797 r
.26801 .41055 .27562 .41641 .28778 .40265 .28023 .39673 Mtetra
.709 .791 .915 r
.28023 .39673 .28778 .40265 .29924 .3987 .29182 .39136 Mtetra
.664 .741 .907 r
.29182 .39136 .29924 .3987 .31074 .39473 .30335 .38737 Mtetra
.30335 .38737 .31074 .39473 .32229 .39075 .31493 .38335 Mtetra
.31493 .38335 .32229 .39075 .33389 .38675 .32657 .37931 Mtetra
.32657 .37931 .33389 .38675 .34555 .38273 .33825 .37526 Mtetra
.33825 .37526 .34555 .38273 .35725 .37869 .34999 .37119 Mtetra
.34999 .37119 .35725 .37869 .36901 .37464 .36178 .3671 Mtetra
.36178 .3671 .36901 .37464 .38082 .37056 .37362 .363 Mtetra
.37362 .363 .38082 .37056 .39268 .36647 .38551 .35887 Mtetra
.38551 .35887 .39268 .36647 .40459 .36236 .39746 .35473 Mtetra
.39746 .35473 .40459 .36236 .41654 .35873 .40946 .35057 Mtetra
.619 .712 .912 r
.40946 .35057 .41654 .35873 .42852 .35601 .42147 .34771 Mtetra
.624 .711 .908 r
.42147 .34771 .42852 .35601 .44057 .353 .43355 .34471 Mtetra
.634 .716 .906 r
.43355 .34471 .44057 .353 .45269 .34971 .4457 .34142 Mtetra
.641 .719 .905 r
.4457 .34142 .45269 .34971 .46488 .34619 .45791 .33789 Mtetra
.648 .722 .903 r
.45791 .33789 .46488 .34619 .47713 .34245 .47019 .33414 Mtetra
.653 .725 .901 r
.47019 .33414 .47713 .34245 .48943 .33852 .48254 .33019 Mtetra
.658 .727 .9 r
.48254 .33019 .48943 .33852 .5018 .33441 .49494 .32606 Mtetra
.663 .729 .898 r
.49494 .32606 .5018 .33441 .51423 .33014 .5074 .32175 Mtetra
.668 .73 .897 r
.5074 .32175 .51423 .33014 .52671 .3257 .51992 .31726 Mtetra
.672 .732 .895 r
.51992 .31726 .52671 .3257 .53925 .32108 .53249 .31259 Mtetra
.677 .733 .892 r
.53249 .31259 .53925 .32108 .55184 .31627 .54512 .30772 Mtetra
.683 .735 .89 r
.54512 .30772 .55184 .31627 .56448 .31124 .5578 .30262 Mtetra
.689 .736 .887 r
.5578 .30262 .56448 .31124 .57717 .30596 .57053 .29727 Mtetra
.696 .737 .883 r
.57053 .29727 .57717 .30596 .58991 .30041 .5833 .29163 Mtetra
.699 .737 .881 r
.5833 .29163 .58991 .30041 .60269 .29455 .59612 .28584 Mtetra
.663 .727 .897 r
.59612 .28584 .60269 .29455 .61554 .28961 .60903 .28137 Mtetra
.664 .741 .907 r
.60903 .28137 .61554 .28961 .62846 .28515 .62199 .27687 Mtetra
.62199 .27687 .62846 .28515 .64145 .28068 .63502 .27235 Mtetra
.63502 .27235 .64145 .28068 .65449 .27618 .6481 .26781 Mtetra
.6481 .26781 .65449 .27618 .6676 .27166 .66125 .26326 Mtetra
.66125 .26326 .6676 .27166 .68077 .26711 .67446 .25868 Mtetra
.67446 .25868 .68077 .26711 .69399 .26255 .68773 .25407 Mtetra
.68773 .25407 .69399 .26255 .70729 .25797 .70106 .24945 Mtetra
.70106 .24945 .70729 .25797 .72064 .25336 .71446 .2448 Mtetra
.71446 .2448 .72064 .25336 .73405 .24874 .72792 .24014 Mtetra
.619 .722 .92 r
.72792 .24014 .73405 .24874 .74753 .24409 .74155 .23688 Mtetra
.131 .487 .902 r
.74155 .23688 .74753 .24409 .76186 .2496 .75591 .24238 Mtetra
.35 .628 .957 r
.75591 .24238 .76186 .2496 .77615 .2527 .77016 .24443 Mtetra
.723 .777 .895 r
.77016 .24443 .77615 .2527 .78984 .24718 .78378 .2375 Mtetra
.857 .78 .775 r
.78378 .2375 .78984 .24718 .80264 .23129 .7966 .22114 Mtetra
.762 .746 .839 r
.7966 .22114 .80264 .23129 .8159 .22051 .81004 .21166 Mtetra
.664 .741 .907 r
.81004 .21166 .8159 .22051 .82977 .21573 .82395 .20683 Mtetra
.2048 .4117 .21248 .41888 .22367 .415 .21601 .40779 Mtetra
.548 .705 .943 r
.21601 .40779 .22367 .415 .2345 .41559 .22702 .4066 Mtetra
0 .263 .766 r
.22702 .4066 .2345 .41559 .24484 .42282 .23733 .41409 Mtetra
.508 .646 .918 r
.23733 .41409 .24484 .42282 .25605 .42102 .24841 .41399 Mtetra
.779 .768 .843 r
.24841 .41399 .25605 .42102 .26801 .41055 .2603 .40497 Mtetra
.846 .798 .804 r
.2603 .40497 .26801 .41055 .28023 .39673 .27255 .39148 Mtetra
.766 .818 .893 r
.27255 .39148 .28023 .39673 .29182 .39136 .28434 .38397 Mtetra
.664 .741 .907 r
.28434 .38397 .29182 .39136 .30335 .38737 .2959 .37994 Mtetra
.2959 .37994 .30335 .38737 .31493 .38335 .30751 .37589 Mtetra
.30751 .37589 .31493 .38335 .32657 .37931 .31918 .37182 Mtetra
.31918 .37182 .32657 .37931 .33825 .37526 .3309 .36773 Mtetra
.3309 .36773 .33825 .37526 .34999 .37119 .34266 .36363 Mtetra
.34266 .36363 .34999 .37119 .36178 .3671 .35449 .35951 Mtetra
.35449 .35951 .36178 .3671 .37362 .363 .36636 .35537 Mtetra
.36636 .35537 .37362 .363 .38551 .35887 .37829 .35121 Mtetra
.37829 .35121 .38551 .35887 .39746 .35473 .39027 .34703 Mtetra
.39027 .34703 .39746 .35473 .40946 .35057 .4023 .34284 Mtetra
.648 .736 .913 r
.4023 .34284 .40946 .35057 .42147 .34771 .41437 .33911 Mtetra
.623 .705 .904 r
.41437 .33911 .42147 .34771 .43355 .34471 .42648 .33612 Mtetra
.632 .709 .902 r
.42648 .33612 .43355 .34471 .4457 .34142 .43865 .33285 Mtetra
.64 .713 .9 r
.43865 .33285 .4457 .34142 .45791 .33789 .4509 .32932 Mtetra
.646 .716 .899 r
.4509 .32932 .45791 .33789 .47019 .33414 .46321 .32556 Mtetra
.652 .719 .898 r
.46321 .32556 .47019 .33414 .48254 .33019 .47558 .3216 Mtetra
.658 .722 .896 r
.47558 .3216 .48254 .33019 .49494 .32606 .48802 .31744 Mtetra
.663 .724 .894 r
.48802 .31744 .49494 .32606 .5074 .32175 .50051 .31309 Mtetra
.668 .725 .893 r
.50051 .31309 .5074 .32175 .51992 .31726 .51307 .30856 Mtetra
.672 .727 .89 r
.51307 .30856 .51992 .31726 .53249 .31259 .52568 .30383 Mtetra
.678 .728 .888 r
.52568 .30383 .53249 .31259 .54512 .30772 .53834 .29888 Mtetra
.683 .729 .885 r
.53834 .29888 .54512 .30772 .5578 .30262 .55106 .29371 Mtetra
.689 .73 .882 r
.55106 .29371 .5578 .30262 .57053 .29727 .56382 .28828 Mtetra
.696 .731 .878 r
.56382 .28828 .57053 .29727 .5833 .29163 .57663 .28255 Mtetra
.676 .723 .885 r
.57663 .28255 .5833 .29163 .59612 .28584 .58951 .27756 Mtetra
.664 .741 .907 r
.58951 .27756 .59612 .28584 .60903 .28137 .60246 .27305 Mtetra
.60246 .27305 .60903 .28137 .62199 .27687 .61546 .26851 Mtetra
.61546 .26851 .62199 .27687 .63502 .27235 .62853 .26396 Mtetra
.62853 .26396 .63502 .27235 .6481 .26781 .64166 .25938 Mtetra
.64166 .25938 .6481 .26781 .66125 .26326 .65485 .25478 Mtetra
.65485 .25478 .66125 .26326 .67446 .25868 .6681 .25016 Mtetra
.6681 .25016 .67446 .25868 .68773 .25407 .68141 .24552 Mtetra
.68141 .24552 .68773 .25407 .70106 .24945 .69479 .24086 Mtetra
.69479 .24086 .70106 .24945 .71446 .2448 .70823 .23617 Mtetra
.70823 .23617 .71446 .2448 .72792 .24014 .72173 .23146 Mtetra
.538 .684 .933 r
.72173 .23146 .72792 .24014 .74155 .23688 .73555 .23034 Mtetra
.112 .5 .905 r
.73555 .23034 .74155 .23688 .75591 .24238 .74992 .23543 Mtetra
.426 .683 .971 r
.74992 .23543 .75591 .24238 .77016 .24443 .7641 .23591 Mtetra
.762 .784 .872 r
.7641 .23591 .77016 .24443 .78378 .2375 .77762 .22713 Mtetra
.853 .768 .768 r
.77762 .22713 .78378 .2375 .7966 .22114 .79048 .21042 Mtetra
.724 .722 .848 r
.79048 .21042 .7966 .22114 .81004 .21166 .80412 .20273 Mtetra
.664 .741 .907 r
.80412 .20273 .81004 .21166 .82395 .20683 .81809 .19786 Mtetra
.19705 .40447 .2048 .4117 .21601 .40779 .2083 .40053 Mtetra
.644 .736 .916 r
.2083 .40053 .21601 .40779 .22702 .4066 .21953 .39715 Mtetra
0 .277 .779 r
.21953 .39715 .22702 .4066 .23733 .41409 .22984 .40457 Mtetra
.404 .577 .909 r
.22984 .40457 .23733 .41409 .24841 .41399 .24075 .40645 Mtetra
.739 .753 .863 r
.24075 .40645 .24841 .41399 .2603 .40497 .25251 .39946 Mtetra
.84 .803 .815 r
.25251 .39946 .2603 .40497 .27255 .39148 .26476 .3867 Mtetra
.818 .829 .858 r
.26476 .3867 .27255 .39148 .28434 .38397 .2768 .37651 Mtetra
.664 .741 .907 r
.2768 .37651 .28434 .38397 .2959 .37994 .28839 .37245 Mtetra
.28839 .37245 .2959 .37994 .30751 .37589 .30004 .36836 Mtetra
.30004 .36836 .30751 .37589 .31918 .37182 .31173 .36426 Mtetra
.31173 .36426 .31918 .37182 .3309 .36773 .32348 .36014 Mtetra
.32348 .36014 .3309 .36773 .34266 .36363 .33528 .35601 Mtetra
.33528 .35601 .34266 .36363 .35449 .35951 .34713 .35185 Mtetra
.34713 .35185 .35449 .35951 .36636 .35537 .35904 .34768 Mtetra
.35904 .34768 .36636 .35537 .37829 .35121 .371 .34348 Mtetra
.371 .34348 .37829 .35121 .39027 .34703 .38301 .33927 Mtetra
.38301 .33927 .39027 .34703 .4023 .34284 .39508 .33504 Mtetra
.39508 .33504 .4023 .34284 .41437 .33911 .4072 .33079 Mtetra
.641 .72 .905 r
.4072 .33079 .41437 .33911 .42648 .33612 .41936 .32723 Mtetra
.631 .702 .897 r
.41936 .32723 .42648 .33612 .43865 .33285 .43156 .32397 Mtetra
.638 .706 .896 r
.43156 .32397 .43865 .33285 .4509 .32932 .44383 .32046 Mtetra
.645 .71 .895 r
.44383 .32046 .4509 .32932 .46321 .32556 .45618 .31669 Mtetra
.651 .713 .893 r
.45618 .31669 .46321 .32556 .47558 .3216 .46858 .31272 Mtetra
.657 .716 .892 r
.46858 .31272 .47558 .3216 .48802 .31744 .48105 .30854 Mtetra
.662 .718 .89 r
.48105 .30854 .48802 .31744 .50051 .31309 .49358 .30415 Mtetra
.667 .72 .888 r
.49358 .30415 .50051 .31309 .51307 .30856 .50616 .29957 Mtetra
.673 .722 .886 r
.50616 .29957 .51307 .30856 .52568 .30383 .51881 .29477 Mtetra
.678 .723 .883 r
.51881 .29477 .52568 .30383 .53834 .29888 .53151 .28976 Mtetra
.684 .724 .88 r
.53151 .28976 .53834 .29888 .55106 .29371 .54426 .28449 Mtetra
.689 .725 .877 r
.54426 .28449 .55106 .29371 .56382 .28828 .55706 .27897 Mtetra
.681 .721 .879 r
.55706 .27897 .56382 .28828 .57663 .28255 .56992 .27374 Mtetra
.663 .727 .897 r
.56992 .27374 .57663 .28255 .58951 .27756 .58284 .26921 Mtetra
.664 .741 .907 r
.58284 .26921 .58951 .27756 .60246 .27305 .59583 .26466 Mtetra
.59583 .26466 .60246 .27305 .61546 .26851 .60888 .26009 Mtetra
.60888 .26009 .61546 .26851 .62853 .26396 .62198 .25549 Mtetra
.62198 .25549 .62853 .26396 .64166 .25938 .63515 .25087 Mtetra
.63515 .25087 .64166 .25938 .65485 .25478 .64838 .24624 Mtetra
.64838 .24624 .65485 .25478 .6681 .25016 .66168 .24157 Mtetra
.66168 .24157 .6681 .25016 .68141 .24552 .67504 .23689 Mtetra
.67504 .23689 .68141 .24552 .69479 .24086 .68846 .23219 Mtetra
.68846 .23219 .69479 .24086 .70823 .23617 .70194 .22746 Mtetra
.70194 .22746 .70823 .23617 .72173 .23146 .71549 .22271 Mtetra
.415 .619 .936 r
.71549 .22271 .72173 .23146 .73555 .23034 .72953 .22429 Mtetra
.135 .535 .92 r
.72953 .22429 .73555 .23034 .74992 .23543 .74389 .22855 Mtetra
.533 .743 .972 r
.74389 .22855 .74992 .23543 .7641 .23591 .75794 .22684 Mtetra
.795 .782 .841 r
.75794 .22684 .7641 .23591 .77762 .22713 .77135 .21593 Mtetra
.844 .753 .763 r
.77135 .21593 .77762 .22713 .79048 .21042 .78427 .19922 Mtetra
.673 .692 .86 r
.78427 .19922 .79048 .21042 .80412 .20273 .79816 .19373 Mtetra
.664 .741 .907 r
.79816 .19373 .80412 .20273 .81809 .19786 .81217 .18881 Mtetra
.18925 .39718 .19705 .40447 .2083 .40053 .20052 .3932 Mtetra
.20052 .3932 .2083 .40053 .21953 .39715 .21184 .38921 Mtetra
.054 .425 .868 r
.21184 .38921 .21953 .39715 .22984 .40457 .22237 .39417 Mtetra
.286 .491 .883 r
.22237 .39417 .22984 .40457 .24075 .40645 .2331 .39807 Mtetra
.67 .718 .885 r
.2331 .39807 .24075 .40645 .25251 .39946 .24466 .39373 Mtetra
.824 .802 .831 r
.24466 .39373 .25251 .39946 .26476 .3867 .25685 .38232 Mtetra
.857 .829 .82 r
.25685 .38232 .26476 .3867 .2768 .37651 .2692 .36899 Mtetra
.664 .741 .907 r
.2692 .36899 .2768 .37651 .28839 .37245 .28082 .3649 Mtetra
.28082 .3649 .28839 .37245 .30004 .36836 .2925 .36078 Mtetra
.2925 .36078 .30004 .36836 .31173 .36426 .30422 .35664 Mtetra
.30422 .35664 .31173 .36426 .32348 .36014 .316 .35249 Mtetra
.316 .35249 .32348 .36014 .33528 .35601 .32784 .34832 Mtetra
.32784 .34832 .33528 .35601 .34713 .35185 .33972 .34413 Mtetra
.33972 .34413 .34713 .35185 .35904 .34768 .35166 .33992 Mtetra
.35166 .33992 .35904 .34768 .371 .34348 .36365 .33569 Mtetra
.36365 .33569 .371 .34348 .38301 .33927 .3757 .33145 Mtetra
.3757 .33145 .38301 .33927 .39508 .33504 .3878 .32718 Mtetra
.3878 .32718 .39508 .33504 .4072 .33079 .39996 .3229 Mtetra
.39996 .3229 .4072 .33079 .41936 .32723 .41217 .31859 Mtetra
.648 .717 .898 r
.41217 .31859 .41936 .32723 .43156 .32397 .42442 .31476 Mtetra
.637 .699 .891 r
.42442 .31476 .43156 .32397 .44383 .32046 .43672 .31126 Mtetra
.644 .703 .89 r
.43672 .31126 .44383 .32046 .45618 .31669 .44909 .3075 Mtetra
.65 .706 .888 r
.44909 .3075 .45618 .31669 .46858 .31272 .46153 .30351 Mtetra
.656 .709 .887 r
.46153 .30351 .46858 .31272 .48105 .30854 .47403 .2993 Mtetra
.662 .712 .885 r
.47403 .2993 .48105 .30854 .49358 .30415 .48659 .29488 Mtetra
.667 .714 .883 r
.48659 .29488 .49358 .30415 .50616 .29957 .49921 .29024 Mtetra
.672 .715 .881 r
.49921 .29024 .50616 .29957 .51881 .29477 .51189 .28538 Mtetra
.678 .716 .878 r
.51189 .28538 .51881 .29477 .53151 .28976 .52462 .28029 Mtetra
.684 .718 .875 r
.52462 .28029 .53151 .28976 .54426 .28449 .53741 .27494 Mtetra
.675 .713 .877 r
.53741 .27494 .54426 .28449 .55706 .27897 .55025 .26991 Mtetra
.663 .722 .893 r
.55025 .26991 .55706 .27897 .56992 .27374 .56316 .26536 Mtetra
.664 .741 .907 r
.56316 .26536 .56992 .27374 .58284 .26921 .57612 .26079 Mtetra
.57612 .26079 .58284 .26921 .59583 .26466 .58915 .2562 Mtetra
.58915 .2562 .59583 .26466 .60888 .26009 .60223 .25159 Mtetra
.60223 .25159 .60888 .26009 .62198 .25549 .61538 .24695 Mtetra
.61538 .24695 .62198 .25549 .63515 .25087 .62859 .24229 Mtetra
.62859 .24229 .63515 .25087 .64838 .24624 .64187 .23761 Mtetra
.64187 .23761 .64838 .24624 .66168 .24157 .6552 .23291 Mtetra
.6552 .23291 .66168 .24157 .67504 .23689 .66861 .22819 Mtetra
.66861 .22819 .67504 .23689 .68846 .23219 .68207 .22344 Mtetra
.68207 .22344 .68846 .23219 .70194 .22746 .6956 .21867 Mtetra
.6956 .21867 .70194 .22746 .71549 .22271 .70919 .21388 Mtetra
.243 .516 .91 r
.70919 .21388 .71549 .22271 .72953 .22429 .72347 .21862 Mtetra
.213 .603 .949 r
.72347 .21862 .72953 .22429 .74389 .22855 .73778 .22141 Mtetra
.65 .788 .948 r
.73778 .22141 .74389 .22855 .75794 .22684 .75167 .21688 Mtetra
.817 .77 .808 r
.75167 .21688 .75794 .22684 .77135 .21593 .76496 .20379 Mtetra
.809 .729 .777 r
.76496 .20379 .77135 .21593 .78427 .19922 .77815 .18957 Mtetra
.663 .725 .895 r
.77815 .18957 .78427 .19922 .79816 .19373 .79214 .18464 Mtetra
.664 .741 .907 r
.79214 .18464 .79816 .19373 .81217 .18881 .8062 .17968 Mtetra
.18138 .38983 .18925 .39718 .20052 .3932 .19268 .38582 Mtetra
.19268 .38582 .20052 .3932 .21184 .38921 .20403 .3818 Mtetra
.386 .635 .953 r
.20403 .3818 .21184 .38921 .22237 .39417 .21492 .38298 Mtetra
.185 .413 .849 r
.21492 .38298 .22237 .39417 .2331 .39807 .2255 .38851 Mtetra
.561 .652 .897 r
.2255 .38851 .2331 .39807 .24466 .39373 .23679 .3873 Mtetra
.788 .788 .853 r
.23679 .3873 .24466 .39373 .25685 .38232 .24885 .37806 Mtetra
.856 .834 .824 r
.24885 .37806 .25685 .38232 .2692 .36899 .26124 .36489 Mtetra
.772 .859 .914 r
.26124 .36489 .2692 .36899 .28082 .3649 .27319 .35728 Mtetra
.664 .741 .907 r
.27319 .35728 .28082 .3649 .2925 .36078 .28489 .35313 Mtetra
.28489 .35313 .2925 .36078 .30422 .35664 .29665 .34896 Mtetra
.29665 .34896 .30422 .35664 .316 .35249 .30846 .34478 Mtetra
.30846 .34478 .316 .35249 .32784 .34832 .32033 .34057 Mtetra
.32033 .34057 .32784 .34832 .33972 .34413 .33225 .33635 Mtetra
.33225 .33635 .33972 .34413 .35166 .33992 .34422 .3321 Mtetra
.34422 .3321 .35166 .33992 .36365 .33569 .35624 .32784 Mtetra
.35624 .32784 .36365 .33569 .3757 .33145 .36833 .32356 Mtetra
.36833 .32356 .3757 .33145 .3878 .32718 .38046 .31925 Mtetra
.38046 .31925 .3878 .32718 .39996 .3229 .39265 .31493 Mtetra
.39265 .31493 .39996 .3229 .41217 .31859 .4049 .31059 Mtetra
.4049 .31059 .41217 .31859 .42442 .31476 .4172 .30623 Mtetra
.663 .727 .897 r
.4172 .30623 .42442 .31476 .43672 .31126 .42956 .30185 Mtetra
.647 .701 .886 r
.42956 .30185 .43672 .31126 .44909 .3075 .44196 .29795 Mtetra
.649 .699 .883 r
.44196 .29795 .44909 .3075 .46153 .30351 .45443 .29395 Mtetra
.655 .702 .881 r
.45443 .29395 .46153 .30351 .47403 .2993 .46696 .28972 Mtetra
.661 .705 .879 r
.46696 .28972 .47403 .2993 .48659 .29488 .47955 .28526 Mtetra
.667 .707 .877 r
.47955 .28526 .48659 .29488 .49921 .29024 .4922 .28056 Mtetra
.672 .708 .875 r
.4922 .28056 .49921 .29024 .51189 .28538 .50491 .27564 Mtetra
.674 .708 .874 r
.50491 .27564 .51189 .28538 .52462 .28029 .51768 .27061 Mtetra
.661 .706 .881 r
.51768 .27061 .52462 .28029 .53741 .27494 .5305 .26606 Mtetra
.663 .727 .897 r
.5305 .26606 .53741 .27494 .55025 .26991 .54339 .2615 Mtetra
.664 .741 .907 r
.54339 .2615 .55025 .26991 .56316 .26536 .55633 .25691 Mtetra
.55633 .25691 .56316 .26536 .57612 .26079 .56934 .2523 Mtetra
.56934 .2523 .57612 .26079 .58915 .2562 .58241 .24767 Mtetra
.58241 .24767 .58915 .2562 .60223 .25159 .59553 .24301 Mtetra
.59553 .24301 .60223 .25159 .61538 .24695 .60872 .23834 Mtetra
.60872 .23834 .61538 .24695 .62859 .24229 .62198 .23364 Mtetra
.62198 .23364 .62859 .24229 .64187 .23761 .63529 .22892 Mtetra
.63529 .22892 .64187 .23761 .6552 .23291 .64867 .22417 Mtetra
.64867 .22417 .6552 .23291 .66861 .22819 .66212 .21941 Mtetra
.66212 .21941 .66861 .22819 .68207 .22344 .67563 .21462 Mtetra
.67563 .21462 .68207 .22344 .6956 .21867 .6892 .20981 Mtetra
.539 .685 .933 r
.6892 .20981 .6956 .21867 .70919 .21388 .70305 .20856 Mtetra
.055 .507 .892 r
.70305 .20856 .70919 .21388 .72347 .21862 .71736 .21306 Mtetra
.363 .703 .985 r
.71736 .21306 .72347 .21862 .73778 .22141 .73156 .21353 Mtetra
.744 .801 .898 r
.73156 .21353 .73778 .22141 .75167 .21688 .74527 .20568 Mtetra
.825 .75 .781 r
.74527 .20568 .75167 .21688 .76496 .20379 .75848 .19082 Mtetra
.751 .696 .799 r
.75848 .19082 .76496 .20379 .77815 .18957 .77203 .18045 Mtetra
.664 .741 .907 r
.77203 .18045 .77815 .18957 .79214 .18464 .78607 .17547 Mtetra
.78607 .17547 .79214 .18464 .8062 .17968 .80018 .17047 Mtetra
.17344 .38242 .18138 .38983 .19268 .38582 .18477 .37838 Mtetra
.18477 .37838 .19268 .38582 .20403 .3818 .19615 .37432 Mtetra
.625 .73 .922 r
.19615 .37432 .20403 .3818 .21492 .38298 .20747 .37133 Mtetra
.14 .375 .83 r
.20747 .37133 .21492 .38298 .2255 .38851 .21796 .37758 Mtetra
.415 .552 .884 r
.21796 .37758 .2255 .38851 .23679 .3873 .22897 .37961 Mtetra
.719 .751 .878 r
.22897 .37961 .23679 .3873 .24885 .37806 .24079 .37346 Mtetra
.841 .832 .838 r
.24079 .37346 .24885 .37806 .26124 .36489 .25315 .3615 Mtetra
.851 .865 .851 r
.25315 .3615 .26124 .36489 .27319 .35728 .26549 .34961 Mtetra
.664 .741 .907 r
.26549 .34961 .27319 .35728 .28489 .35313 .27723 .34542 Mtetra
.27723 .34542 .28489 .35313 .29665 .34896 .28902 .34122 Mtetra
.28902 .34122 .29665 .34896 .30846 .34478 .30086 .337 Mtetra
.30086 .337 .30846 .34478 .32033 .34057 .31276 .33276 Mtetra
.31276 .33276 .32033 .34057 .33225 .33635 .32471 .3285 Mtetra
.32471 .3285 .33225 .33635 .34422 .3321 .33671 .32422 Mtetra
.33671 .32422 .34422 .3321 .35624 .32784 .34877 .31992 Mtetra
.34877 .31992 .35624 .32784 .36833 .32356 .36089 .3156 Mtetra
.36089 .3156 .36833 .32356 .38046 .31925 .37306 .31126 Mtetra
.37306 .31126 .38046 .31925 .39265 .31493 .38528 .3069 Mtetra
.38528 .3069 .39265 .31493 .4049 .31059 .39756 .30252 Mtetra
.39756 .30252 .4049 .31059 .4172 .30623 .4099 .29813 Mtetra
.4099 .29813 .4172 .30623 .42956 .30185 .4223 .29371 Mtetra
.4223 .29371 .42956 .30185 .44196 .29795 .43475 .28927 Mtetra
.663 .727 .897 r
.43475 .28927 .44196 .29795 .45443 .29395 .44726 .28481 Mtetra
.662 .717 .889 r
.44726 .28481 .45443 .29395 .46696 .28972 .45982 .28033 Mtetra
.662 .711 .885 r
.45982 .28033 .46696 .28972 .47955 .28526 .47245 .27583 Mtetra
.47245 .27583 .47955 .28526 .4922 .28056 .48513 .27131 Mtetra
.662 .717 .889 r
.48513 .27131 .4922 .28056 .50491 .27564 .49788 .26676 Mtetra
.663 .727 .897 r
.49788 .26676 .50491 .27564 .51768 .27061 .51068 .2622 Mtetra
.664 .741 .907 r
.51068 .2622 .51768 .27061 .5305 .26606 .52354 .25762 Mtetra
.52354 .25762 .5305 .26606 .54339 .2615 .53647 .25301 Mtetra
.53647 .25301 .54339 .2615 .55633 .25691 .54945 .24838 Mtetra
.54945 .24838 .55633 .25691 .56934 .2523 .5625 .24373 Mtetra
.5625 .24373 .56934 .2523 .58241 .24767 .57561 .23906 Mtetra
.57561 .23906 .58241 .24767 .59553 .24301 .58877 .23436 Mtetra
.58877 .23436 .59553 .24301 .60872 .23834 .60201 .22964 Mtetra
.60201 .22964 .60872 .23834 .62198 .23364 .6153 .2249 Mtetra
.6153 .2249 .62198 .23364 .63529 .22892 .62866 .22014 Mtetra
.62866 .22014 .63529 .22892 .64867 .22417 .64209 .21536 Mtetra
.64209 .21536 .64867 .22417 .66212 .21941 .65557 .21055 Mtetra
.65557 .21055 .66212 .21941 .67563 .21462 .66913 .20572 Mtetra
.66913 .20572 .67563 .21462 .6892 .20981 .68274 .20086 Mtetra
.329 .57 .927 r
.68274 .20086 .6892 .20981 .70305 .20856 .69688 .20396 Mtetra
.102 .567 .911 r
.69688 .20396 .70305 .20856 .71736 .21306 .71116 .20713 Mtetra
.561 .794 .986 r
.71116 .20713 .71736 .21306 .73156 .21353 .7252 .20434 Mtetra
.799 .784 .839 r
.7252 .20434 .73156 .21353 .74527 .20568 .73872 .19305 Mtetra
.82 .727 .762 r
.73872 .19305 .74527 .20568 .75848 .19082 .75191 .17735 Mtetra
.674 .655 .824 r
.75191 .17735 .75848 .19082 .77203 .18045 .76585 .17124 Mtetra
.664 .741 .907 r
.76585 .17124 .77203 .18045 .78607 .17547 .77994 .16621 Mtetra
.77994 .16621 .78607 .17547 .80018 .17047 .7941 .16117 Mtetra
.16545 .37495 .17344 .38242 .18477 .37838 .1768 .37088 Mtetra
.1768 .37088 .18477 .37838 .19615 .37432 .18821 .36679 Mtetra
.18821 .36679 .19615 .37432 .20747 .37133 .19967 .36268 Mtetra
.298 .554 .924 r
.19967 .36268 .20747 .37133 .21796 .37758 .2105 .3654 Mtetra
.274 .446 .85 r
.2105 .3654 .21796 .37758 .22897 .37961 .22125 .37011 Mtetra
.6 .673 .892 r
.22125 .37011 .22897 .37961 .24079 .37346 .23274 .36778 Mtetra
.799 .812 .862 r
.23274 .36778 .24079 .37346 .25315 .3615 .24495 .3582 Mtetra
.862 .864 .839 r
.24495 .3582 .25315 .3615 .26549 .34961 .25744 .34535 Mtetra
.772 .858 .914 r
.25744 .34535 .26549 .34961 .27723 .34542 .2695 .33765 Mtetra
.664 .741 .907 r
.2695 .33765 .27723 .34542 .28902 .34122 .28132 .33341 Mtetra
.28132 .33341 .28902 .34122 .30086 .337 .2932 .32915 Mtetra
.2932 .32915 .30086 .337 .31276 .33276 .30513 .32488 Mtetra
.30513 .32488 .31276 .33276 .32471 .3285 .31711 .32058 Mtetra
.31711 .32058 .32471 .3285 .33671 .32422 .32915 .31626 Mtetra
.32915 .31626 .33671 .32422 .34877 .31992 .34124 .31193 Mtetra
.34124 .31193 .34877 .31992 .36089 .3156 .35339 .30757 Mtetra
.35339 .30757 .36089 .3156 .37306 .31126 .36559 .3032 Mtetra
.36559 .3032 .37306 .31126 .38528 .3069 .37785 .2988 Mtetra
.37785 .2988 .38528 .3069 .39756 .30252 .39017 .29439 Mtetra
.39017 .29439 .39756 .30252 .4099 .29813 .40254 .28995 Mtetra
.40254 .28995 .4099 .29813 .4223 .29371 .41497 .2855 Mtetra
.41497 .2855 .4223 .29371 .43475 .28927 .42746 .28102 Mtetra
.42746 .28102 .43475 .28927 .44726 .28481 .44001 .27652 Mtetra
.44001 .27652 .44726 .28481 .45982 .28033 .45261 .272 Mtetra
.45261 .272 .45982 .28033 .47245 .27583 .46527 .26746 Mtetra
.46527 .26746 .47245 .27583 .48513 .27131 .478 .2629 Mtetra
.478 .2629 .48513 .27131 .49788 .26676 .49078 .25832 Mtetra
.49078 .25832 .49788 .26676 .51068 .2622 .50362 .25372 Mtetra
.50362 .25372 .51068 .2622 .52354 .25762 .51652 .24909 Mtetra
.51652 .24909 .52354 .25762 .53647 .25301 .52949 .24445 Mtetra
.52949 .24445 .53647 .25301 .54945 .24838 .54251 .23978 Mtetra
.54251 .23978 .54945 .24838 .5625 .24373 .5556 .23509 Mtetra
.5556 .23509 .5625 .24373 .57561 .23906 .56875 .23037 Mtetra
.56875 .23037 .57561 .23906 .58877 .23436 .58196 .22564 Mtetra
.58196 .22564 .58877 .23436 .60201 .22964 .59523 .22088 Mtetra
.59523 .22088 .60201 .22964 .6153 .2249 .60857 .21609 Mtetra
.60857 .21609 .6153 .2249 .62866 .22014 .62197 .21129 Mtetra
.62197 .21129 .62866 .22014 .64209 .21536 .63544 .20646 Mtetra
.63544 .20646 .64209 .21536 .65557 .21055 .64897 .20161 Mtetra
.64897 .20161 .65557 .21055 .66913 .20572 .66257 .19674 Mtetra
.539 .686 .934 r
.66257 .19674 .66913 .20572 .68274 .20086 .67641 .19543 Mtetra
.089 .532 .907 r
.67641 .19543 .68274 .20086 .69688 .20396 .69064 .19943 Mtetra
.29 .698 .973 r
.69064 .19943 .69688 .20396 .71116 .20713 .70483 .20008 Mtetra
.72 .82 .927 r
.70483 .20008 .71116 .20713 .7252 .20434 .71866 .19324 Mtetra
.819 .752 .79 r
.71866 .19324 .7252 .20434 .73872 .19305 .73204 .1791 Mtetra
.767 .69 .778 r
.73204 .1791 .73872 .19305 .75191 .17735 .74555 .16699 Mtetra
.662 .712 .886 r
.74555 .16699 .75191 .17735 .76585 .17124 .75962 .16195 Mtetra
.664 .741 .907 r
.75962 .16195 .76585 .17124 .77994 .16621 .77376 .15688 Mtetra
.77376 .15688 .77994 .16621 .7941 .16117 .78796 .15178 Mtetra
.15738 .36742 .16545 .37495 .1768 .37088 .16877 .36331 Mtetra
.16877 .36331 .1768 .37088 .18821 .36679 .18021 .35919 Mtetra
.18021 .35919 .18821 .36679 .19967 .36268 .19169 .35505 Mtetra
.603 .723 .929 r
.19169 .35505 .19967 .36268 .2105 .3654 .20307 .35252 Mtetra
.201 .388 .825 r
.20307 .35252 .2105 .3654 .22125 .37011 .21367 .35852 Mtetra
.441 .554 .875 r
.21367 .35852 .22125 .37011 .23274 .36778 .2248 .36015 Mtetra
.713 .756 .886 r
.2248 .36015 .23274 .36778 .24495 .3582 .23672 .3542 Mtetra
.838 .854 .857 r
.23672 .3542 .24495 .3582 .25744 .34535 .24914 .34285 Mtetra
.867 .887 .848 r
.24914 .34285 .25744 .34535 .2695 .33765 .26168 .33011 Mtetra
.674 .752 .909 r
.26168 .33011 .2695 .33765 .28132 .33341 .27356 .32553 Mtetra
.664 .741 .907 r
.27356 .32553 .28132 .33341 .2932 .32915 .28547 .32124 Mtetra
.28547 .32124 .2932 .32915 .30513 .32488 .29743 .31693 Mtetra
.29743 .31693 .30513 .32488 .31711 .32058 .30945 .3126 Mtetra
.30945 .3126 .31711 .32058 .32915 .31626 .32152 .30825 Mtetra
.32152 .30825 .32915 .31626 .34124 .31193 .33364 .30387 Mtetra
.33364 .30387 .34124 .31193 .35339 .30757 .34583 .29948 Mtetra
.34583 .29948 .35339 .30757 .36559 .3032 .35806 .29507 Mtetra
.35806 .29507 .36559 .3032 .37785 .2988 .37036 .29064 Mtetra
.37036 .29064 .37785 .2988 .39017 .29439 .38271 .28618 Mtetra
.38271 .28618 .39017 .29439 .40254 .28995 .39512 .28171 Mtetra
.39512 .28171 .40254 .28995 .41497 .2855 .40759 .27722 Mtetra
.40759 .27722 .41497 .2855 .42746 .28102 .42011 .2727 Mtetra
.42011 .2727 .42746 .28102 .44001 .27652 .43269 .26816 Mtetra
.43269 .26816 .44001 .27652 .45261 .272 .44533 .26361 Mtetra
.44533 .26361 .45261 .272 .46527 .26746 .45803 .25903 Mtetra
.45803 .25903 .46527 .26746 .478 .2629 .4708 .25443 Mtetra
.4708 .25443 .478 .2629 .49078 .25832 .48362 .24981 Mtetra
.48362 .24981 .49078 .25832 .50362 .25372 .4965 .24516 Mtetra
.4965 .24516 .50362 .25372 .51652 .24909 .50944 .2405 Mtetra
.50944 .2405 .51652 .24909 .52949 .24445 .52244 .23581 Mtetra
.52244 .23581 .52949 .24445 .54251 .23978 .53551 .2311 Mtetra
.53551 .2311 .54251 .23978 .5556 .23509 .54863 .22637 Mtetra
.54863 .22637 .5556 .23509 .56875 .23037 .56182 .22161 Mtetra
.56182 .22161 .56875 .23037 .58196 .22564 .57508 .21683 Mtetra
.57508 .21683 .58196 .22564 .59523 .22088 .58839 .21203 Mtetra
.58839 .21203 .59523 .22088 .60857 .21609 .60178 .20721 Mtetra
.60178 .20721 .60857 .21609 .62197 .21129 .61522 .20236 Mtetra
.61522 .20236 .62197 .21129 .63544 .20646 .62873 .19749 Mtetra
.62873 .19749 .63544 .20646 .64897 .20161 .64231 .19259 Mtetra
.655 .737 .91 r
.64231 .19259 .64897 .20161 .66257 .19674 .65596 .18798 Mtetra
.272 .546 .924 r
.65596 .18798 .66257 .19674 .67641 .19543 .67009 .19178 Mtetra
.087 .589 .894 r
.67009 .19178 .67641 .19543 .69064 .19943 .6843 .19416 Mtetra
.561 .819 .994 r
.6843 .19416 .69064 .19943 .70483 .20008 .69832 .19099 Mtetra
.796 .788 .845 r
.69832 .19099 .70483 .20008 .71866 .19324 .71195 .17998 Mtetra
.812 .717 .76 r
.71195 .17998 .71866 .19324 .73204 .1791 .72528 .16442 Mtetra
.679 .642 .806 r
.72528 .16442 .73204 .1791 .74555 .16699 .73921 .15766 Mtetra
.664 .741 .907 r
.73921 .15766 .74555 .16699 .75962 .16195 .75333 .15257 Mtetra
.75333 .15257 .75962 .16195 .77376 .15688 .76752 .14745 Mtetra
.76752 .14745 .77376 .15688 .78796 .15178 .78177 .14231 Mtetra
.693 .771 .911 r
.14915 .3607 .15738 .36742 .16877 .36331 .16067 .35569 Mtetra
.664 .741 .907 r
.16067 .35569 .16877 .36331 .18021 .35919 .17213 .35153 Mtetra
.17213 .35153 .18021 .35919 .19169 .35505 .18365 .34736 Mtetra
.18365 .34736 .19169 .35505 .20307 .35252 .19522 .34316 Mtetra
.367 .574 .919 r
.19522 .34316 .20307 .35252 .21367 .35852 .20621 .3452 Mtetra
.302 .442 .836 r
.20621 .3452 .21367 .35852 .2248 .36015 .21704 .34984 Mtetra
.567 .645 .887 r
.21704 .34984 .2248 .36015 .23672 .3542 .22857 .34835 Mtetra
.775 .813 .883 r
.22857 .34835 .23672 .3542 .24914 .34285 .24077 .34006 Mtetra
.855 .886 .86 r
.24077 .34006 .24914 .34285 .26168 .33011 .25331 .32809 Mtetra
.835 .917 .89 r
.25331 .32809 .26168 .33011 .27356 .32553 .26573 .31759 Mtetra
.664 .741 .907 r
.26573 .31759 .27356 .32553 .28547 .32124 .27767 .31327 Mtetra
.27767 .31327 .28547 .32124 .29743 .31693 .28967 .30892 Mtetra
.28967 .30892 .29743 .31693 .30945 .3126 .30172 .30455 Mtetra
.30172 .30455 .30945 .3126 .32152 .30825 .31382 .30016 Mtetra
.31382 .30016 .32152 .30825 .33364 .30387 .32598 .29575 Mtetra
.32598 .29575 .33364 .30387 .34583 .29948 .3382 .29132 Mtetra
.3382 .29132 .34583 .29948 .35806 .29507 .35047 .28687 Mtetra
.35047 .28687 .35806 .29507 .37036 .29064 .3628 .2824 Mtetra
.3628 .2824 .37036 .29064 .38271 .28618 .37519 .27791 Mtetra
.37519 .27791 .38271 .28618 .39512 .28171 .38763 .2734 Mtetra
.38763 .2734 .39512 .28171 .40759 .27722 .40013 .26886 Mtetra
.40013 .26886 .40759 .27722 .42011 .2727 .4127 .26431 Mtetra
.4127 .26431 .42011 .2727 .43269 .26816 .42532 .25973 Mtetra
.42532 .25973 .43269 .26816 .44533 .26361 .43799 .25514 Mtetra
.43799 .25514 .44533 .26361 .45803 .25903 .45073 .25052 Mtetra
.45073 .25052 .45803 .25903 .4708 .25443 .46353 .24588 Mtetra
.46353 .24588 .4708 .25443 .48362 .24981 .47639 .24122 Mtetra
.47639 .24122 .48362 .24981 .4965 .24516 .48931 .23653 Mtetra
.48931 .23653 .4965 .24516 .50944 .2405 .50229 .23182 Mtetra
.50229 .23182 .50944 .2405 .52244 .23581 .51534 .22709 Mtetra
.51534 .22709 .52244 .23581 .53551 .2311 .52844 .22234 Mtetra
.52844 .22234 .53551 .2311 .54863 .22637 .54161 .21757 Mtetra
.54161 .21757 .54863 .22637 .56182 .22161 .55484 .21277 Mtetra
.55484 .21277 .56182 .22161 .57508 .21683 .56814 .20795 Mtetra
.56814 .20795 .57508 .21683 .58839 .21203 .5815 .20311 Mtetra
.5815 .20311 .58839 .21203 .60178 .20721 .59492 .19824 Mtetra
.59492 .19824 .60178 .20721 .61522 .20236 .60841 .19335 Mtetra
.60841 .19335 .61522 .20236 .62873 .19749 .62196 .18843 Mtetra
.62196 .18843 .62873 .19749 .64231 .19259 .63558 .1835 Mtetra
.411 .62 .937 r
.63558 .1835 .64231 .19259 .65596 .18798 .64954 .18489 Mtetra
0 .533 .836 r
.64954 .18489 .65596 .18798 .67009 .19178 .66368 .18781 Mtetra
.362 .762 .985 r
.66368 .18781 .67009 .19178 .6843 .19416 .67778 .18697 Mtetra
.745 .826 .914 r
.67778 .18697 .6843 .19416 .69832 .19099 .6916 .17911 Mtetra
.811 .738 .784 r
.6916 .17911 .69832 .19099 .71195 .17998 .70508 .1649 Mtetra
.75 .67 .772 r
.70508 .1649 .71195 .17998 .72528 .16442 .71872 .15335 Mtetra
.66 .699 .875 r
.71872 .15335 .72528 .16442 .73921 .15766 .73282 .14824 Mtetra
.664 .741 .907 r
.73282 .14824 .73921 .15766 .75333 .15257 .74698 .14311 Mtetra
.74698 .14311 .75333 .15257 .76752 .14745 .76122 .13794 Mtetra
.637 .729 .915 r
.76122 .13794 .76752 .14745 .78177 .14231 .7756 .13367 Mtetra
.703 .766 .901 r
.14088 .35367 .14915 .3607 .16067 .35569 .15247 .34825 Mtetra
.672 .749 .909 r
.15247 .34825 .16067 .35569 .17213 .35153 .164 .34381 Mtetra
.664 .741 .907 r
.164 .34381 .17213 .35153 .18365 .34736 .17554 .3396 Mtetra
.17554 .3396 .18365 .34736 .19522 .34316 .18714 .33537 Mtetra
.66 .74 .909 r
.18714 .33537 .19522 .34316 .20621 .3452 .19878 .33125 Mtetra
.258 .404 .819 r
.19878 .33125 .20621 .3452 .21704 .34984 .2095 .33677 Mtetra
.402 .506 .85 r
.2095 .33677 .21704 .34984 .22857 .34835 .22062 .33946 Mtetra
.647 .711 .895 r
.22062 .33946 .22857 .34835 .24077 .34006 .23245 .33563 Mtetra
.806 .854 .885 r
.23245 .33563 .24077 .34006 .25331 .32809 .24484 .32613 Mtetra
.858 .911 .867 r
.24484 .32613 .25331 .32809 .26573 .31759 .25745 .31417 Mtetra
.8 .887 .908 r
.25745 .31417 .26573 .31759 .27767 .31327 .26981 .30522 Mtetra
.664 .741 .907 r
.26981 .30522 .27767 .31327 .28967 .30892 .28184 .30084 Mtetra
.28184 .30084 .28967 .30892 .30172 .30455 .29392 .29643 Mtetra
.29392 .29643 .30172 .30455 .31382 .30016 .30606 .292 Mtetra
.30606 .292 .31382 .30016 .32598 .29575 .31826 .28756 Mtetra
.31826 .28756 .32598 .29575 .3382 .29132 .33051 .28309 Mtetra
.33051 .28309 .3382 .29132 .35047 .28687 .34281 .2786 Mtetra
.34281 .2786 .35047 .28687 .3628 .2824 .35518 .27409 Mtetra
.35518 .27409 .3628 .2824 .37519 .27791 .3676 .26956 Mtetra
.3676 .26956 .37519 .27791 .38763 .2734 .38008 .26501 Mtetra
.38008 .26501 .38763 .2734 .40013 .26886 .39262 .26044 Mtetra
.39262 .26044 .40013 .26886 .4127 .26431 .40522 .25585 Mtetra
.40522 .25585 .4127 .26431 .42532 .25973 .41787 .25123 Mtetra
.41787 .25123 .42532 .25973 .43799 .25514 .43059 .24659 Mtetra
.43059 .24659 .43799 .25514 .45073 .25052 .44337 .24193 Mtetra
.44337 .24193 .45073 .25052 .46353 .24588 .45621 .23725 Mtetra
.45621 .23725 .46353 .24588 .47639 .24122 .4691 .23255 Mtetra
.4691 .23255 .47639 .24122 .48931 .23653 .48206 .22782 Mtetra
.48206 .22782 .48931 .23653 .50229 .23182 .49509 .22308 Mtetra
.49509 .22308 .50229 .23182 .51534 .22709 .50817 .2183 Mtetra
.50817 .2183 .51534 .22709 .52844 .22234 .52132 .21351 Mtetra
.52132 .21351 .52844 .22234 .54161 .21757 .53453 .20869 Mtetra
.53453 .20869 .54161 .21757 .55484 .21277 .5478 .20385 Mtetra
.5478 .20385 .55484 .21277 .56814 .20795 .56114 .19899 Mtetra
.56114 .19899 .56814 .20795 .5815 .20311 .57454 .1941 Mtetra
.57454 .1941 .5815 .20311 .59492 .19824 .58801 .18919 Mtetra
.58801 .18919 .59492 .19824 .60841 .19335 .60154 .18426 Mtetra
.60154 .18426 .60841 .19335 .62196 .18843 .61514 .1793 Mtetra
.489 .662 .938 r
.61514 .1793 .62196 .18843 .63558 .1835 .62897 .17902 Mtetra
.099 .576 .908 r
.62897 .17902 .63558 .1835 .64954 .18489 .64303 .18183 Mtetra
.21 .694 .93 r
.64303 .18183 .64954 .18489 .66368 .18781 .65712 .18214 Mtetra
.669 .85 .969 r
.65712 .18214 .66368 .18781 .67778 .18697 .67105 .17662 Mtetra
.802 .764 .819 r
.67105 .17662 .67778 .18697 .6916 .17911 .68468 .16437 Mtetra
.795 .693 .752 r
.68468 .16437 .6916 .17911 .70508 .1649 .69815 .14916 Mtetra
.645 .612 .802 r
.69815 .14916 .70508 .1649 .71872 .15335 .71222 .1439 Mtetra
.664 .741 .907 r
.71222 .1439 .71872 .15335 .73282 .14824 .72636 .13874 Mtetra
.72636 .13874 .73282 .14824 .74698 .14311 .74058 .13356 Mtetra
.657 .738 .91 r
.74058 .13356 .74698 .14311 .76122 .13794 .75488 .1286 Mtetra
.624 .73 .923 r
.75488 .1286 .76122 .13794 .7756 .13367 .76935 .12467 Mtetra
.682 .745 .899 r
.13261 .34595 .14088 .35367 .15247 .34825 .14416 .34114 Mtetra
.693 .765 .907 r
.14416 .34114 .15247 .34825 .164 .34381 .15579 .33602 Mtetra
.664 .741 .907 r
.15579 .33602 .164 .34381 .17554 .3396 .16737 .33177 Mtetra
.16737 .33177 .17554 .3396 .18714 .33537 .17899 .32751 Mtetra
.17899 .32751 .18714 .33537 .19878 .33125 .19067 .32323 Mtetra
.535 .695 .942 r
.19067 .32323 .19878 .33125 .2095 .33677 .20209 .32202 Mtetra
.308 .421 .814 r
.20209 .32202 .2095 .33677 .22062 .33946 .21297 .32698 Mtetra
.475 .559 .862 r
.21297 .32698 .22062 .33946 .23245 .33563 .22435 .32792 Mtetra
.69 .756 .902 r
.22435 .32792 .23245 .33563 .24484 .32613 .23639 .32269 Mtetra
.817 .883 .892 r
.23639 .32269 .24484 .32613 .25745 .31417 .24889 .31282 Mtetra
.854 .931 .876 r
.24889 .31282 .25745 .31417 .26981 .30522 .26154 .30117 Mtetra
.786 .873 .911 r
.26154 .30117 .26981 .30522 .28184 .30084 .27395 .29269 Mtetra
.664 .741 .907 r
.27395 .29269 .28184 .30084 .29392 .29643 .28606 .28824 Mtetra
.28606 .28824 .29392 .29643 .30606 .292 .29823 .28378 Mtetra
.29823 .28378 .30606 .292 .31826 .28756 .31046 .27929 Mtetra
.31046 .27929 .31826 .28756 .33051 .28309 .32275 .27479 Mtetra
.32275 .27479 .33051 .28309 .34281 .2786 .33509 .27026 Mtetra
.33509 .27026 .34281 .2786 .35518 .27409 .34749 .26571 Mtetra
.34749 .26571 .35518 .27409 .3676 .26956 .35995 .26114 Mtetra
.35995 .26114 .3676 .26956 .38008 .26501 .37246 .25655 Mtetra
.37246 .25655 .38008 .26501 .39262 .26044 .38504 .25194 Mtetra
.38504 .25194 .39262 .26044 .40522 .25585 .39767 .24731 Mtetra
.39767 .24731 .40522 .25585 .41787 .25123 .41037 .24265 Mtetra
.41037 .24265 .41787 .25123 .43059 .24659 .42312 .23797 Mtetra
.42312 .23797 .43059 .24659 .44337 .24193 .43594 .23327 Mtetra
.43594 .23327 .44337 .24193 .45621 .23725 .44881 .22855 Mtetra
.44881 .22855 .45621 .23725 .4691 .23255 .46175 .22381 Mtetra
.46175 .22381 .4691 .23255 .48206 .22782 .47475 .21904 Mtetra
.47475 .21904 .48206 .22782 .49509 .22308 .48781 .21425 Mtetra
.48781 .21425 .49509 .22308 .50817 .2183 .50094 .20944 Mtetra
.50094 .20944 .50817 .2183 .52132 .21351 .51413 .2046 Mtetra
.51413 .2046 .52132 .21351 .53453 .20869 .52738 .19974 Mtetra
.52738 .19974 .53453 .20869 .5478 .20385 .54069 .19486 Mtetra
.54069 .19486 .5478 .20385 .56114 .19899 .55407 .18995 Mtetra
.55407 .18995 .56114 .19899 .57454 .1941 .56752 .18502 Mtetra
.56752 .18502 .57454 .1941 .58801 .18919 .58103 .18006 Mtetra
.58103 .18006 .58801 .18919 .60154 .18426 .5946 .17508 Mtetra
.513 .674 .937 r
.5946 .17508 .60154 .18426 .61514 .1793 .60836 .17423 Mtetra
.166 .606 .937 r
.60836 .17423 .61514 .1793 .62897 .17902 .62233 .17664 Mtetra
.131 .655 .88 r
.62233 .17664 .62897 .17902 .64303 .18183 .63638 .17724 Mtetra
.591 .857 .994 r
.63638 .17724 .64303 .18183 .65712 .18214 .65034 .17309 Mtetra
.787 .789 .854 r
.65034 .17309 .65712 .18214 .67105 .17662 .66409 .16257 Mtetra
.796 .703 .762 r
.66409 .16257 .67105 .17662 .68468 .16437 .67764 .14788 Mtetra
.694 .628 .778 r
.67764 .14788 .68468 .16437 .69815 .14916 .69153 .13954 Mtetra
.664 .737 .905 r
.69153 .13954 .69815 .14916 .71222 .1439 .70565 .13436 Mtetra
.664 .741 .907 r
.70565 .13436 .71222 .1439 .72636 .13874 .71985 .12915 Mtetra
.71985 .12915 .72636 .13874 .74058 .13356 .73411 .12392 Mtetra
.636 .729 .915 r
.73411 .12392 .74058 .13356 .75488 .1286 .74852 .1196 Mtetra
.645 .751 .926 r
.74852 .1196 .75488 .1286 .76935 .12467 .76298 .11493 Mtetra
.667 .733 .899 r
.12432 .33782 .13261 .34595 .14416 .34114 .13584 .33345 Mtetra
.694 .751 .895 r
.13584 .33345 .14416 .34114 .15579 .33602 .14751 .32821 Mtetra
.665 .742 .908 r
.14751 .32821 .15579 .33602 .16737 .33177 .15912 .32389 Mtetra
.664 .741 .907 r
.15912 .32389 .16737 .33177 .17899 .32751 .17078 .31959 Mtetra
.17078 .31959 .17899 .32751 .19067 .32323 .18249 .31527 Mtetra
.18249 .31527 .19067 .32323 .20209 .32202 .19425 .31093 Mtetra
.461 .583 .889 r
.19425 .31093 .20209 .32202 .21297 .32698 .20554 .31178 Mtetra
.356 .444 .814 r
.20554 .31178 .21297 .32698 .22435 .32792 .2166 .31592 Mtetra
.517 .592 .869 r
.2166 .31592 .22435 .32792 .23639 .32269 .22818 .31572 Mtetra
.706 .782 .911 r
.22818 .31572 .23639 .32269 .24889 .31282 .24035 .30996 Mtetra
.815 .903 .903 r
.24035 .30996 .24889 .31282 .26154 .30117 .25291 .30026 Mtetra
.844 .947 .886 r
.25291 .30026 .26154 .30117 .27395 .29269 .2656 .28908 Mtetra
.8 .887 .908 r
.2656 .28908 .27395 .29269 .28606 .28824 .27813 .27998 Mtetra
.664 .741 .907 r
.27813 .27998 .28606 .28824 .29823 .28378 .29034 .27548 Mtetra
.29034 .27548 .29823 .28378 .31046 .27929 .3026 .27096 Mtetra
.3026 .27096 .31046 .27929 .32275 .27479 .31492 .26641 Mtetra
.31492 .26641 .32275 .27479 .33509 .27026 .3273 .26185 Mtetra
.3273 .26185 .33509 .27026 .34749 .26571 .33974 .25726 Mtetra
.33974 .25726 .34749 .26571 .35995 .26114 .35223 .25265 Mtetra
.35223 .25265 .35995 .26114 .37246 .25655 .36478 .24802 Mtetra
.36478 .24802 .37246 .25655 .38504 .25194 .37739 .24337 Mtetra
.37739 .24337 .38504 .25194 .39767 .24731 .39007 .2387 Mtetra
.39007 .2387 .39767 .24731 .41037 .24265 .4028 .234 Mtetra
.4028 .234 .41037 .24265 .42312 .23797 .41559 .22928 Mtetra
.41559 .22928 .42312 .23797 .43594 .23327 .42844 .22454 Mtetra
.42844 .22454 .43594 .23327 .44881 .22855 .44136 .21978 Mtetra
.44136 .21978 .44881 .22855 .46175 .22381 .45434 .21499 Mtetra
.45434 .21499 .46175 .22381 .47475 .21904 .46737 .21018 Mtetra
.46737 .21018 .47475 .21904 .48781 .21425 .48048 .20535 Mtetra
.48048 .20535 .48781 .21425 .50094 .20944 .49364 .20049 Mtetra
.49364 .20049 .50094 .20944 .51413 .2046 .50687 .19561 Mtetra
.50687 .19561 .51413 .2046 .52738 .19974 .52016 .19071 Mtetra
.52016 .19071 .52738 .19974 .54069 .19486 .53352 .18578 Mtetra
.53352 .18578 .54069 .19486 .55407 .18995 .54694 .18083 Mtetra
.54694 .18083 .55407 .18995 .56752 .18502 .56043 .17585 Mtetra
.56043 .17585 .56752 .18502 .58103 .18006 .57399 .17085 Mtetra
.487 .662 .939 r
.57399 .17085 .58103 .18006 .5946 .17508 .58771 .17053 Mtetra
.174 .629 .937 r
.58771 .17053 .5946 .17508 .60836 .17423 .60159 .17237 Mtetra
.114 .652 .854 r
.60159 .17237 .60836 .17423 .62233 .17664 .61557 .1727 Mtetra
.545 .859 .997 r
.61557 .1727 .62233 .17664 .63638 .17724 .62952 .16901 Mtetra
.773 .807 .88 r
.62952 .16901 .63638 .17724 .65034 .17309 .64333 .1596 Mtetra
.792 .71 .773 r
.64333 .1596 .65034 .17309 .66409 .16257 .65697 .1457 Mtetra
.723 .639 .764 r
.65697 .1457 .66409 .16257 .67764 .14788 .67076 .13515 Mtetra
.654 .667 .85 r
.67076 .13515 .67764 .14788 .69153 .13954 .68486 .12995 Mtetra
.664 .741 .907 r
.68486 .12995 .69153 .13954 .70565 .13436 .69903 .12473 Mtetra
.69903 .12473 .70565 .13436 .71985 .12915 .71327 .11947 Mtetra
.663 .74 .908 r
.71327 .11947 .71985 .12915 .73411 .12392 .72759 .11423 Mtetra
.634 .729 .917 r
.72759 .11423 .73411 .12392 .74852 .1196 .74205 .10995 Mtetra
.66 .743 .911 r
.74205 .10995 .74852 .1196 .76298 .11493 .75653 .10474 Mtetra
.66 .729 .9 r
.11597 .32954 .12432 .33782 .13584 .33345 .12748 .32537 Mtetra
.667 .737 .902 r
.12748 .32537 .13584 .33345 .14751 .32821 .13908 .32095 Mtetra
.687 .764 .91 r
.13908 .32095 .14751 .32821 .15912 .32389 .15081 .31593 Mtetra
.664 .741 .907 r
.15081 .31593 .15912 .32389 .17078 .31959 .16249 .31159 Mtetra
.16249 .31159 .17078 .31959 .18249 .31527 .17424 .30724 Mtetra
.17424 .30724 .18249 .31527 .19425 .31093 .18603 .30286 Mtetra
.18603 .30286 .19425 .31093 .20554 .31178 .19788 .29847 Mtetra
.434 .524 .85 r
.19788 .29847 .20554 .31178 .2166 .31592 .20915 .30036 Mtetra
.391 .461 .812 r
.20915 .30036 .2166 .31592 .22818 .31572 .22036 .3038 Mtetra
.533 .604 .87 r
.22036 .3038 .22818 .31572 .24035 .30996 .23208 .30313 Mtetra
.7 .788 .919 r
.23208 .30313 .24035 .30996 .25291 .30026 .24431 .29756 Mtetra
.8 .912 .917 r
.24431 .29756 .25291 .30026 .2656 .28908 .2569 .28847 Mtetra
.826 .96 .898 r
.2569 .28847 .2656 .28908 .27813 .27998 .26962 .27791 Mtetra
.83 .927 .897 r
.26962 .27791 .27813 .27998 .29034 .27548 .28235 .26742 Mtetra
.674 .752 .909 r
.28235 .26742 .29034 .27548 .3026 .27096 .29467 .26255 Mtetra
.664 .741 .907 r
.29467 .26255 .3026 .27096 .31492 .26641 .30703 .25797 Mtetra
.30703 .25797 .31492 .26641 .3273 .26185 .31944 .25336 Mtetra
.31944 .25336 .3273 .26185 .33974 .25726 .33191 .24874 Mtetra
.33191 .24874 .33974 .25726 .35223 .25265 .34444 .24409 Mtetra
.34444 .24409 .35223 .25265 .36478 .24802 .35703 .23942 Mtetra
.35703 .23942 .36478 .24802 .37739 .24337 .36968 .23472 Mtetra
.36968 .23472 .37739 .24337 .39007 .2387 .38239 .23001 Mtetra
.38239 .23001 .39007 .2387 .4028 .234 .39516 .22527 Mtetra
.39516 .22527 .4028 .234 .41559 .22928 .40799 .22051 Mtetra
.40799 .22051 .41559 .22928 .42844 .22454 .42088 .21573 Mtetra
.42088 .21573 .42844 .22454 .44136 .21978 .43384 .21092 Mtetra
.43384 .21092 .44136 .21978 .45434 .21499 .44685 .20609 Mtetra
.44685 .20609 .45434 .21499 .46737 .21018 .45993 .20124 Mtetra
.45993 .20124 .46737 .21018 .48048 .20535 .47307 .19636 Mtetra
.47307 .19636 .48048 .20535 .49364 .20049 .48628 .19146 Mtetra
.48628 .19146 .49364 .20049 .50687 .19561 .49955 .18654 Mtetra
.49955 .18654 .50687 .19561 .52016 .19071 .51289 .18159 Mtetra
.51289 .18159 .52016 .19071 .53352 .18578 .52629 .17662 Mtetra
.52629 .17662 .53352 .18578 .54694 .18083 .53975 .17162 Mtetra
.655 .737 .91 r
.53975 .17162 .54694 .18083 .56043 .17585 .55329 .16691 Mtetra
.412 .632 .945 r
.55329 .16691 .56043 .17585 .57399 .17085 .56697 .16793 Mtetra
.12 .636 .89 r
.56697 .16793 .57399 .17085 .58771 .17053 .58078 .16903 Mtetra
.148 .682 .854 r
.58078 .16903 .58771 .17053 .60159 .17237 .59468 .16866 Mtetra
.553 .869 .995 r
.59468 .16866 .60159 .17237 .61557 .1727 .6086 .16469 Mtetra
.766 .811 .889 r
.6086 .16469 .61557 .1727 .62952 .16901 .62243 .15568 Mtetra
.786 .711 .78 r
.62243 .15568 .62952 .16901 .64333 .1596 .63613 .14244 Mtetra
.736 .642 .755 r
.63613 .14244 .64333 .1596 .65697 .1457 .6499 .13076 Mtetra
.646 .627 .817 r
.6499 .13076 .65697 .1457 .67076 .13515 .66398 .12553 Mtetra
.664 .741 .907 r
.66398 .12553 .67076 .13515 .68486 .12995 .67813 .12028 Mtetra
.67813 .12028 .68486 .12995 .69903 .12473 .69235 .11501 Mtetra
.69235 .11501 .69903 .12473 .71327 .11947 .70664 .1097 Mtetra
.642 .732 .914 r
.70664 .1097 .71327 .11947 .72759 .11423 .72105 .1051 Mtetra
.661 .757 .922 r
.72105 .1051 .72759 .11423 .74205 .10995 .7355 .09987 Mtetra
.667 .737 .903 r
.7355 .09987 .74205 .10995 .75653 .10474 .75001 .09438 Mtetra
.659 .731 .903 r
.10754 .32129 .11597 .32954 .12748 .32537 .11908 .31712 Mtetra
.655 .731 .905 r
.11908 .31712 .12748 .32537 .13908 .32095 .13066 .31305 Mtetra
.674 .745 .905 r
.13066 .31305 .13908 .32095 .15081 .31593 .14236 .3084 Mtetra
.68 .758 .91 r
.14236 .3084 .15081 .31593 .16249 .31159 .15414 .30354 Mtetra
.664 .741 .907 r
.15414 .30354 .16249 .31159 .17424 .30724 .16591 .29914 Mtetra
.16591 .29914 .17424 .30724 .18603 .30286 .17774 .29473 Mtetra
.17774 .29473 .18603 .30286 .19788 .29847 .18962 .2903 Mtetra
.18962 .2903 .19788 .29847 .20915 .30036 .20156 .28584 Mtetra
.446 .51 .831 r
.20156 .28584 .20915 .30036 .22036 .3038 .21291 .28769 Mtetra
.414 .467 .807 r
.21291 .28769 .22036 .3038 .23208 .30313 .22426 .29068 Mtetra
.527 .593 .863 r
.22426 .29068 .23208 .30313 .24431 .29756 .23605 .29015 Mtetra
.672 .769 .923 r
.23605 .29015 .24431 .29756 .2569 .28847 .2483 .28536 Mtetra
.771 .906 .934 r
.2483 .28536 .2569 .28847 .26962 .27791 .26088 .2773 Mtetra
.8 .965 .912 r
.26088 .2773 .26962 .27791 .28235 .26742 .27362 .2676 Mtetra
.796 .98 .902 r
.27362 .2676 .28235 .26742 .29467 .26255 .2864 .25762 Mtetra
.772 .858 .914 r
.2864 .25762 .29467 .26255 .30703 .25797 .29907 .24945 Mtetra
.664 .741 .907 r
.29907 .24945 .30703 .25797 .31944 .25336 .31152 .2448 Mtetra
.31152 .2448 .31944 .25336 .33191 .24874 .32402 .24014 Mtetra
.32402 .24014 .33191 .24874 .34444 .24409 .33659 .23545 Mtetra
.33659 .23545 .34444 .24409 .35703 .23942 .34921 .23073 Mtetra
.34921 .23073 .35703 .23942 .36968 .23472 .3619 .226 Mtetra
.3619 .226 .36968 .23472 .38239 .23001 .37465 .22124 Mtetra
.37465 .22124 .38239 .23001 .39516 .22527 .38745 .21646 Mtetra
.38745 .21646 .39516 .22527 .40799 .22051 .40032 .21166 Mtetra
.40032 .21166 .40799 .22051 .42088 .21573 .41325 .20683 Mtetra
.41325 .20683 .42088 .21573 .43384 .21092 .42625 .20199 Mtetra
.42625 .20199 .43384 .21092 .44685 .20609 .4393 .19711 Mtetra
.4393 .19711 .44685 .20609 .45993 .20124 .45242 .19222 Mtetra
.45242 .19222 .45993 .20124 .47307 .19636 .46561 .1873 Mtetra
.46561 .1873 .47307 .19636 .48628 .19146 .47885 .18235 Mtetra
.47885 .18235 .48628 .19146 .49955 .18654 .49217 .17739 Mtetra
.49217 .17739 .49955 .18654 .51289 .18159 .50554 .17239 Mtetra
.50554 .17239 .51289 .18159 .52629 .17662 .51898 .16738 Mtetra
.534 .686 .937 r
.51898 .16738 .52629 .17662 .53975 .17162 .5325 .16594 Mtetra
.34 .699 .983 r
.5325 .16594 .53975 .17162 .55329 .16691 .54613 .16634 Mtetra
.029 .6 .753 r
.54613 .16634 .55329 .16691 .56697 .16793 .55988 .16649 Mtetra
.246 .75 .888 r
.55988 .16649 .56697 .16793 .58078 .16903 .57371 .16497 Mtetra
.612 .882 .991 r
.57371 .16497 .58078 .16903 .59468 .16866 .58758 .16012 Mtetra
.767 .798 .878 r
.58758 .16012 .59468 .16866 .6086 .16469 .60141 .15089 Mtetra
.777 .701 .779 r
.60141 .15089 .6086 .16469 .62243 .15568 .61516 .13805 Mtetra
.733 .636 .752 r
.61516 .13805 .62243 .15568 .63613 .14244 .62895 .12634 Mtetra
.641 .609 .802 r
.62895 .12634 .63613 .14244 .6499 .13076 .643 .12109 Mtetra
.664 .741 .907 r
.643 .12109 .6499 .13076 .66398 .12553 .65713 .11582 Mtetra
.65713 .11582 .66398 .12553 .67813 .12028 .67133 .11052 Mtetra
.67133 .11052 .67813 .12028 .69235 .11501 .6856 .1052 Mtetra
.649 .735 .912 r
.6856 .1052 .69235 .11501 .70664 .1097 .69997 .10035 Mtetra
.655 .75 .92 r
.69997 .10035 .70664 .1097 .72105 .1051 .71441 .09528 Mtetra
.672 .746 .907 r
.71441 .09528 .72105 .1051 .7355 .09987 .72888 .0896 Mtetra
.667 .735 .9 r
.72888 .0896 .7355 .09987 .75001 .09438 .74343 .08402 Mtetra
.66 .734 .905 r
.09902 .3131 .10754 .32129 .11908 .31712 .11059 .30886 Mtetra
.654 .732 .907 r
.11059 .30886 .11908 .31712 .13066 .31305 .1222 .30478 Mtetra
.656 .733 .906 r
.1222 .30478 .13066 .31305 .14236 .3084 .13387 .30061 Mtetra
.68 .753 .906 r
.13387 .30061 .14236 .3084 .15414 .30354 .14568 .2957 Mtetra
.674 .751 .909 r
.14568 .2957 .15414 .30354 .16591 .29914 .15752 .29098 Mtetra
.664 .741 .907 r
.15752 .29098 .16591 .29914 .17774 .29473 .16938 .28653 Mtetra
.16938 .28653 .17774 .29473 .18962 .2903 .18129 .28206 Mtetra
.18129 .28206 .18962 .2903 .20156 .28584 .19326 .27756 Mtetra
.19326 .27756 .20156 .28584 .21291 .28769 .20528 .27305 Mtetra
.489 .533 .829 r
.20528 .27305 .21291 .28769 .22426 .29068 .21684 .27377 Mtetra
.43 .467 .797 r
.21684 .27377 .22426 .29068 .23605 .29015 .2283 .27646 Mtetra
.51 .563 .845 r
.2283 .27646 .23605 .29015 .2483 .28536 .24012 .27649 Mtetra
.628 .72 .913 r
.24012 .27649 .2483 .28536 .26088 .2773 .25234 .27295 Mtetra
.727 .871 .949 r
.25234 .27295 .26088 .2773 .27362 .2676 .26488 .26635 Mtetra
.764 .955 .935 r
.26488 .26635 .27362 .2676 .2864 .25762 .27762 .2579 Mtetra
.759 .982 .911 r
.27762 .2579 .2864 .25762 .29907 .24945 .29043 .24877 Mtetra
.773 .969 .923 r
.29043 .24877 .29907 .24945 .31152 .2448 .30326 .23974 Mtetra
.772 .859 .914 r
.30326 .23974 .31152 .2448 .32402 .24014 .31606 .23146 Mtetra
.664 .741 .907 r
.31606 .23146 .32402 .24014 .33659 .23545 .32866 .22673 Mtetra
.32866 .22673 .33659 .23545 .34921 .23073 .34133 .22198 Mtetra
.34133 .22198 .34921 .23073 .3619 .226 .35405 .2172 Mtetra
.35405 .2172 .3619 .226 .37465 .22124 .36683 .2124 Mtetra
.36683 .2124 .37465 .22124 .38745 .21646 .37968 .20758 Mtetra
.37968 .20758 .38745 .21646 .40032 .21166 .39259 .20273 Mtetra
.39259 .20273 .40032 .21166 .41325 .20683 .40556 .19786 Mtetra
.40556 .19786 .41325 .20683 .42625 .20199 .41859 .19297 Mtetra
.41859 .19297 .42625 .20199 .4393 .19711 .43169 .18806 Mtetra
.43169 .18806 .4393 .19711 .45242 .19222 .44485 .18312 Mtetra
.44485 .18312 .45242 .19222 .46561 .1873 .45807 .17815 Mtetra
.45807 .17815 .46561 .1873 .47885 .18235 .47136 .17316 Mtetra
.47136 .17316 .47885 .18235 .49217 .17739 .48471 .16815 Mtetra
.532 .686 .937 r
.48471 .16815 .49217 .17739 .50554 .17239 .4981 .16672 Mtetra
.413 .74 .992 r
.4981 .16672 .50554 .17239 .51898 .16738 .51158 .16607 Mtetra
.148 .684 .845 r
.51158 .16607 .51898 .16738 .5325 .16594 .52517 .16554 Mtetra
.143 .687 .8 r
.52517 .16554 .5325 .16594 .54613 .16634 .53887 .16431 Mtetra
.418 .844 .955 r
.53887 .16431 .54613 .16634 .55988 .16649 .55265 .16122 Mtetra
.689 .87 .967 r
.55265 .16122 .55988 .16649 .57371 .16497 .56648 .15501 Mtetra
.767 .765 .851 r
.56648 .15501 .57371 .16497 .58758 .16012 .58029 .14514 Mtetra
.764 .68 .77 r
.58029 .14514 .58758 .16012 .60141 .15089 .59407 .13252 Mtetra
.714 .62 .751 r
.59407 .13252 .60141 .15089 .61516 .13805 .60791 .1219 Mtetra
.641 .609 .802 r
.60791 .1219 .61516 .13805 .62895 .12634 .62194 .11663 Mtetra
.664 .741 .907 r
.62194 .11663 .62895 .12634 .643 .12109 .63605 .11134 Mtetra
.63605 .11134 .643 .12109 .65713 .11582 .65022 .10602 Mtetra
.65022 .10602 .65713 .11582 .67133 .11052 .66447 .10067 Mtetra
.655 .737 .91 r
.66447 .10067 .67133 .11052 .6856 .1052 .6788 .09559 Mtetra
.649 .742 .918 r
.6788 .09559 .6856 .1052 .69997 .10035 .69323 .09071 Mtetra
.671 .752 .911 r
.69323 .09071 .69997 .10035 .71441 .09528 .70768 .08505 Mtetra
.672 .739 .9 r
.70768 .08505 .71441 .09528 .72888 .0896 .7222 .07929 Mtetra
.666 .736 .902 r
.7222 .07929 .72888 .0896 .74343 .08402 .73681 .07369 Mtetra
.662 .738 .906 r
.09042 .30495 .09902 .3131 .11059 .30886 .10203 .30061 Mtetra
.657 .735 .907 r
.10203 .30061 .11059 .30886 .1222 .30478 .11367 .2964 Mtetra
.653 .732 .907 r
.11367 .2964 .1222 .30478 .13387 .30061 .12536 .29229 Mtetra
.658 .735 .906 r
.12536 .29229 .13387 .30061 .14568 .2957 .13712 .288 Mtetra
.684 .759 .908 r
.13712 .288 .14568 .2957 .15752 .29098 .14903 .28291 Mtetra
.67 .747 .908 r
.14903 .28291 .15752 .29098 .16938 .28653 .16094 .27826 Mtetra
.664 .741 .907 r
.16094 .27826 .16938 .28653 .18129 .28206 .17289 .27374 Mtetra
.17289 .27374 .18129 .28206 .19326 .27756 .18489 .26921 Mtetra
.18489 .26921 .19326 .27756 .20528 .27305 .19694 .26466 Mtetra
.19694 .26466 .20528 .27305 .21684 .27377 .20905 .26009 Mtetra
.56 .588 .839 r
.20905 .26009 .21684 .27377 .2283 .27646 .22091 .25863 Mtetra
.447 .466 .786 r
.22091 .25863 .2283 .27646 .24012 .27649 .23249 .26094 Mtetra
.492 .525 .819 r
.23249 .26094 .24012 .27649 .25234 .27295 .24433 .26163 Mtetra
.575 .644 .881 r
.24433 .26163 .25234 .27295 .26488 .26635 .25651 .25958 Mtetra
.665 .792 .942 r
.25651 .25958 .26488 .26635 .27762 .2579 .26898 .25483 Mtetra
.718 .91 .962 r
.26898 .25483 .27762 .2579 .29043 .24877 .28167 .24812 Mtetra
.719 .965 .939 r
.28167 .24812 .29043 .24877 .30326 .23974 .29448 .24035 Mtetra
.693 .976 .909 r
.29448 .24035 .30326 .23974 .31606 .23146 .30735 .23224 Mtetra
.675 .973 .903 r
.30735 .23224 .31606 .23146 .32866 .22673 .32024 .22429 Mtetra
.737 .934 .953 r
.32024 .22429 .32866 .22673 .34133 .22198 .33314 .21676 Mtetra
.734 .858 .939 r
.33314 .21676 .34133 .22198 .35405 .2172 .34605 .20976 Mtetra
.709 .791 .915 r
.34605 .20976 .35405 .2172 .36683 .2124 .35895 .20348 Mtetra
.664 .741 .907 r
.35895 .20348 .36683 .2124 .37968 .20758 .37184 .19862 Mtetra
.37184 .19862 .37968 .20758 .39259 .20273 .38478 .19373 Mtetra
.38478 .19373 .39259 .20273 .40556 .19786 .39779 .18881 Mtetra
.39779 .18881 .40556 .19786 .41859 .19297 .41086 .18388 Mtetra
.41086 .18388 .41859 .19297 .43169 .18806 .424 .17892 Mtetra
.617 .724 .922 r
.424 .17892 .43169 .18806 .44485 .18312 .43716 .17538 Mtetra
.579 .749 .958 r
.43716 .17538 .44485 .18312 .45807 .17815 .45038 .17257 Mtetra
.516 .791 .995 r
.45038 .17257 .45807 .17815 .47136 .17316 .46367 .1703 Mtetra
.374 .8 .97 r
.46367 .1703 .47136 .17316 .48471 .16815 .47704 .16846 Mtetra
.135 .682 .761 r
.47704 .16846 .48471 .16815 .4981 .16672 .4905 .16679 Mtetra
.182 .716 .795 r
.4905 .16679 .4981 .16672 .51158 .16607 .50407 .16479 Mtetra
.373 .83 .921 r
.50407 .16479 .51158 .16607 .52517 .16554 .51774 .16172 Mtetra
.618 .89 .989 r
.51774 .16172 .52517 .16554 .53887 .16431 .53148 .15665 Mtetra
.74 .814 .91 r
.53148 .15665 .53887 .16431 .55265 .16122 .54528 .14883 Mtetra
.759 .717 .813 r
.54528 .14883 .55265 .16122 .56648 .15501 .55909 .13822 Mtetra
.746 .652 .756 r
.55909 .13822 .56648 .15501 .58029 .14514 .5729 .12591 Mtetra
.679 .595 .754 r
.5729 .12591 .58029 .14514 .59407 .13252 .58678 .11744 Mtetra
.645 .627 .818 r
.58678 .11744 .59407 .13252 .60791 .1219 .60079 .11215 Mtetra
.664 .741 .907 r
.60079 .11215 .60791 .1219 .62194 .11663 .61487 .10684 Mtetra
.61487 .10684 .62194 .11663 .63605 .11134 .62902 .10149 Mtetra
.62902 .10149 .63605 .11134 .65022 .10602 .64325 .09612 Mtetra
.659 .739 .909 r
.64325 .09612 .65022 .10602 .66447 .10067 .65755 .0909 Mtetra
.645 .737 .916 r
.65755 .0909 .66447 .10067 .6788 .09559 .67195 .08611 Mtetra
.67 .756 .915 r
.67195 .08611 .6788 .09559 .69323 .09071 .68639 .08049 Mtetra
.672 .74 .901 r
.68639 .08049 .69323 .09071 .70768 .08505 .70089 .07469 Mtetra
.669 .737 .901 r
.70089 .07469 .70768 .08505 .7222 .07929 .71547 .06897 Mtetra
.665 .737 .904 r
.71547 .06897 .7222 .07929 .73681 .07369 .73013 .06338 Mtetra
.663 .739 .907 r
.08173 .29679 .09042 .30495 .10203 .30061 .09338 .29239 Mtetra
.661 .738 .907 r
.09338 .29239 .10203 .30061 .11367 .2964 .10507 .28804 Mtetra
.657 .734 .907 r
.10507 .28804 .11367 .2964 .12536 .29229 .11679 .28378 Mtetra
.653 .731 .906 r
.11679 .28378 .12536 .29229 .13712 .288 .12857 .27961 Mtetra
.66 .736 .907 r
.12857 .27961 .13712 .288 .14903 .28291 .14042 .27522 Mtetra
.684 .762 .91 r
.14042 .27522 .14903 .28291 .16094 .27826 .15241 .27008 Mtetra
.67 .747 .908 r
.15241 .27008 .16094 .27826 .17289 .27374 .16441 .26536 Mtetra
.664 .741 .907 r
.16441 .26536 .17289 .27374 .18489 .26921 .17644 .26079 Mtetra
.17644 .26079 .18489 .26921 .19694 .26466 .18853 .2562 Mtetra
.18853 .2562 .19694 .26466 .20905 .26009 .20067 .25159 Mtetra
.20067 .25159 .20905 .26009 .22091 .25863 .21288 .24695 Mtetra
.65 .666 .852 r
.21288 .24695 .22091 .25863 .23249 .26094 .22512 .24242 Mtetra
.473 .475 .778 r
.22512 .24242 .23249 .26094 .24433 .26163 .23686 .24399 Mtetra
.488 .495 .791 r
.23686 .24399 .24433 .26163 .25651 .25958 .24874 .245 Mtetra
.534 .565 .833 r
.24874 .245 .25651 .25958 .26898 .25483 .26088 .24429 Mtetra
.597 .674 .894 r
.26088 .24429 .26898 .25483 .28167 .24812 .27328 .2415 Mtetra
.657 .798 .951 r
.27328 .2415 .28167 .24812 .29448 .24035 .28589 .2369 Mtetra
.682 .898 .974 r
.28589 .2369 .29448 .24035 .30735 .23224 .29866 .23103 Mtetra
.666 .947 .957 r
.29866 .23103 .30735 .23224 .32024 .22429 .31153 .22448 Mtetra
.622 .954 .921 r
.31153 .22448 .32024 .22429 .33314 .21676 .32445 .21772 Mtetra
.572 .94 .886 r
.32445 .21772 .33314 .21676 .34605 .20976 .33742 .21108 Mtetra
.523 .919 .86 r
.33742 .21108 .34605 .20976 .35895 .20348 .35041 .20474 Mtetra
.488 .902 .853 r
.35041 .20474 .35895 .20348 .37184 .19862 .36343 .19883 Mtetra
.511 .911 .903 r
.36343 .19883 .37184 .19862 .38478 .19373 .37648 .19338 Mtetra
.501 .903 .921 r
.37648 .19338 .38478 .19373 .39779 .18881 .38956 .18843 Mtetra
.459 .883 .914 r
.38956 .18843 .39779 .18881 .41086 .18388 .40269 .18398 Mtetra
.383 .845 .873 r
.40269 .18398 .41086 .18388 .424 .17892 .41587 .18 Mtetra
.268 .774 .782 r
.41587 .18 .424 .17892 .43716 .17538 .42911 .17644 Mtetra
.235 .752 .768 r
.42911 .17644 .43716 .17538 .45038 .17257 .44242 .1732 Mtetra
.253 .765 .797 r
.44242 .1732 .45038 .17257 .46367 .1703 .45581 .17008 Mtetra
.33 .813 .866 r
.45581 .17008 .46367 .1703 .47704 .16846 .46928 .16676 Mtetra
.477 .878 .956 r
.46928 .16676 .47704 .16846 .4905 .16679 .48285 .16274 Mtetra
.636 .888 .986 r
.48285 .16274 .4905 .16679 .50407 .16479 .49651 .15745 Mtetra
.724 .817 .923 r
.49651 .15745 .50407 .16479 .51774 .16172 .51024 .1503 Mtetra
.745 .729 .837 r
.51024 .1503 .51774 .16172 .53148 .15665 .52402 .14104 Mtetra
.739 .662 .775 r
.52402 .14104 .53148 .15665 .54528 .14883 .53783 .13001 Mtetra
.723 .621 .743 r
.53783 .13001 .54528 .14883 .55909 .13822 .55165 .11839 Mtetra
.628 .562 .761 r
.55165 .11839 .55909 .13822 .5729 .12591 .56557 .11297 Mtetra
.654 .668 .851 r
.56557 .11297 .5729 .12591 .58678 .11744 .57955 .10766 Mtetra
.664 .741 .907 r
.57955 .10766 .58678 .11744 .60079 .11215 .59361 .10232 Mtetra
.59361 .10232 .60079 .11215 .61487 .10684 .60774 .09695 Mtetra
.60774 .09695 .61487 .10684 .62902 .10149 .62194 .09156 Mtetra
.659 .739 .909 r
.62194 .09156 .62902 .10149 .64325 .09612 .63621 .08631 Mtetra
.645 .738 .916 r
.63621 .08631 .64325 .09612 .65755 .0909 .65059 .08149 Mtetra
.669 .759 .918 r
.65059 .08149 .65755 .0909 .67195 .08611 .665 .07589 Mtetra
.672 .741 .902 r
.665 .07589 .67195 .08611 .68639 .08049 .67948 .07006 Mtetra
.669 .736 .9 r
.67948 .07006 .68639 .08049 .70089 .07469 .69404 .06431 Mtetra
.666 .737 .903 r
.69404 .06431 .70089 .07469 .71547 .06897 .70868 .05865 Mtetra
.664 .739 .906 r
.70868 .05865 .71547 .06897 .73013 .06338 .7234 .05303 Mtetra
.664 .74 .907 r
.07297 .28859 .08173 .29679 .09338 .29239 .08465 .28414 Mtetra
.663 .74 .907 r
.08465 .28414 .09338 .29239 .10507 .28804 .09637 .27969 Mtetra
.66 .738 .907 r
.09637 .27969 .10507 .28804 .11679 .28378 .10815 .27529 Mtetra
.657 .734 .906 r
.10815 .27529 .11679 .28378 .12857 .27961 .11996 .27097 Mtetra
.654 .731 .906 r
.11996 .27097 .12857 .27961 .14042 .27522 .13182 .26672 Mtetra
.659 .736 .907 r
.13182 .26672 .14042 .27522 .15241 .27008 .14376 .26229 Mtetra
.681 .761 .912 r
.14376 .26229 .15241 .27008 .16441 .26536 .15583 .2572 Mtetra
.674 .751 .909 r
.15583 .2572 .16441 .26536 .17644 .26079 .16792 .2523 Mtetra
.664 .741 .907 r
.16792 .2523 .17644 .26079 .18853 .2562 .18005 .24767 Mtetra
.18005 .24767 .18853 .2562 .20067 .25159 .19222 .24301 Mtetra
.19222 .24301 .20067 .25159 .21288 .24695 .20446 .23834 Mtetra
.20446 .23834 .21288 .24695 .22512 .24242 .21675 .23364 Mtetra
.664 .737 .905 r
.21675 .23364 .22512 .24242 .23686 .24399 .2291 .22892 Mtetra
.601 .591 .814 r
.2291 .22892 .23686 .24399 .24874 .245 .24136 .22585 Mtetra
.502 .486 .772 r
.24136 .22585 .24874 .245 .26088 .24429 .25336 .22644 Mtetra
.517 .511 .788 r
.25336 .22644 .26088 .24429 .27328 .2415 .26551 .2264 Mtetra
.55 .568 .825 r
.26551 .2264 .27328 .2415 .28589 .2369 .27787 .22511 Mtetra
.591 .648 .875 r
.27787 .22511 .28589 .2369 .29866 .23103 .29041 .22247 Mtetra
.628 .74 .928 r
.29041 .22247 .29866 .23103 .31153 .22448 .30312 .21866 Mtetra
.649 .825 .968 r
.30312 .21866 .31153 .22448 .32445 .21772 .31595 .21401 Mtetra
.644 .887 .984 r
.31595 .21401 .32445 .21772 .33742 .21108 .32888 .20887 Mtetra
.617 .918 .978 r
.32888 .20887 .33742 .21108 .35041 .20474 .34188 .20353 Mtetra
.577 .923 .958 r
.34188 .20353 .35041 .20474 .36343 .19883 .35494 .19819 Mtetra
.536 .915 .937 r
.35494 .19819 .36343 .19883 .37648 .19338 .36805 .193 Mtetra
.503 .904 .923 r
.36805 .193 .37648 .19338 .38956 .18843 .38121 .18801 Mtetra
.485 .895 .92 r
.38121 .18801 .38956 .18843 .40269 .18398 .39443 .18323 Mtetra
.488 .894 .931 r
.39443 .18323 .40269 .18398 .41587 .18 .40771 .17859 Mtetra
.519 .9 .955 r
.40771 .17859 .41587 .18 .42911 .17644 .42106 .17396 Mtetra
.575 .903 .981 r
.42106 .17396 .42911 .17644 .44242 .1732 .43448 .16912 Mtetra
.642 .887 .985 r
.43448 .16912 .44242 .1732 .45581 .17008 .44798 .16379 Mtetra
.696 .838 .951 r
.44798 .16379 .45581 .17008 .46928 .16676 .46157 .15761 Mtetra
.722 .769 .89 r
.46157 .15761 .46928 .16676 .48285 .16274 .47523 .15024 Mtetra
.728 .703 .827 r
.47523 .15024 .48285 .16274 .49651 .15745 .48896 .14149 Mtetra
.722 .651 .777 r
.48896 .14149 .49651 .15745 .51024 .1503 .50274 .13146 Mtetra
.712 .615 .747 r
.50274 .13146 .51024 .1503 .52402 .14104 .51654 .12077 Mtetra
.652 .571 .751 r
.51654 .12077 .52402 .14104 .53783 .13001 .53037 .11378 Mtetra
.64 .61 .803 r
.53037 .11378 .53783 .13001 .55165 .11839 .54426 .10848 Mtetra
.664 .737 .905 r
.54426 .10848 .55165 .11839 .56557 .11297 .55822 .10314 Mtetra
.664 .741 .907 r
.55822 .10314 .56557 .11297 .57955 .10766 .57225 .09778 Mtetra
.57225 .09778 .57955 .10766 .59361 .10232 .58636 .09239 Mtetra
.58636 .09239 .59361 .10232 .60774 .09695 .60053 .08697 Mtetra
.655 .737 .91 r
.60053 .08697 .60774 .09695 .62194 .09156 .61479 .08182 Mtetra
.649 .742 .918 r
.61479 .08182 .62194 .09156 .63621 .08631 .62913 .07687 Mtetra
.669 .759 .918 r
.62913 .07687 .63621 .08631 .65059 .08149 .64352 .07123 Mtetra
.672 .741 .902 r
.64352 .07123 .65059 .08149 .665 .07589 .65798 .0654 Mtetra
.669 .736 .9 r
.65798 .0654 .665 .07589 .67948 .07006 .67252 .05962 Mtetra
.666 .737 .903 r
.67252 .05962 .67948 .07006 .69404 .06431 .68713 .05392 Mtetra
.665 .739 .905 r
.68713 .05392 .69404 .06431 .70868 .05865 .70182 .04827 Mtetra
.664 .74 .907 r
.70182 .04827 .70868 .05865 .7234 .05303 .7166 .04262 Mtetra
.664 .741 .907 r
.06413 .28033 .07297 .28859 .08465 .28414 .07584 .27583 Mtetra
.663 .74 .907 r
.07584 .27583 .08465 .28414 .09637 .27969 .0876 .27132 Mtetra
.0876 .27132 .09637 .27969 .10815 .27529 .09941 .26682 Mtetra
.66 .737 .907 r
.09941 .26682 .10815 .27529 .11996 .27097 .11127 .26235 Mtetra
.657 .734 .906 r
.11127 .26235 .11996 .27097 .13182 .26672 .12317 .25797 Mtetra
.654 .73 .905 r
.12317 .25797 .13182 .26672 .14376 .26229 .13512 .25364 Mtetra
.658 .735 .907 r
.13512 .25364 .14376 .26229 .15583 .2572 .14714 .24918 Mtetra
.675 .757 .913 r
.14714 .24918 .15583 .2572 .16792 .2523 .15927 .24422 Mtetra
.68 .758 .91 r
.15927 .24422 .16792 .2523 .18005 .24767 .17149 .23906 Mtetra
.664 .741 .907 r
.17149 .23906 .18005 .24767 .19222 .24301 .1837 .23436 Mtetra
.1837 .23436 .19222 .24301 .20446 .23834 .19597 .22964 Mtetra
.19597 .22964 .20446 .23834 .21675 .23364 .20829 .2249 Mtetra
.20829 .2249 .21675 .23364 .2291 .22892 .22068 .22014 Mtetra
.22068 .22014 .2291 .22892 .24136 .22585 .23313 .21536 Mtetra
.659 .7 .877 r
.23313 .21536 .24136 .22585 .25336 .22644 .24563 .21055 Mtetra
.613 .588 .802 r
.24563 .21055 .25336 .22644 .26551 .2264 .2581 .20683 Mtetra
.531 .501 .768 r
.2581 .20683 .26551 .2264 .27787 .22511 .27037 .20627 Mtetra
.541 .515 .776 r
.27037 .20627 .27787 .22511 .29041 .22247 .28277 .20529 Mtetra
.561 .547 .796 r
.28277 .20529 .29041 .22247 .30312 .21866 .29531 .20356 Mtetra
.585 .589 .823 r
.29531 .20356 .30312 .21866 .31595 .21401 .30801 .20095 Mtetra
.609 .635 .852 r
.30801 .20095 .31595 .21401 .32888 .20887 .32084 .19757 Mtetra
.63 .68 .878 r
.32084 .19757 .32888 .20887 .34188 .20353 .33378 .19357 Mtetra
.645 .716 .9 r
.33378 .19357 .34188 .20353 .35494 .19819 .34682 .18911 Mtetra
.656 .743 .914 r
.34682 .18911 .35494 .19819 .36805 .193 .35995 .18433 Mtetra
.663 .757 .92 r
.35995 .18433 .36805 .193 .38121 .18801 .37316 .17929 Mtetra
.671 .759 .917 r
.37316 .17929 .38121 .18801 .39443 .18323 .38644 .17401 Mtetra
.678 .75 .905 r
.38644 .17401 .39443 .18323 .40771 .17859 .39979 .1684 Mtetra
.686 .731 .884 r
.39979 .1684 .40771 .17859 .42106 .17396 .41323 .16233 Mtetra
.694 .704 .855 r
.41323 .16233 .42106 .17396 .43448 .16912 .42674 .15562 Mtetra
.698 .673 .822 r
.42674 .15562 .43448 .16912 .44798 .16379 .44033 .14813 Mtetra
.699 .643 .79 r
.44033 .14813 .44798 .16379 .46157 .15761 .45399 .13976 Mtetra
.697 .617 .763 r
.45399 .13976 .46157 .15761 .47523 .15024 .4677 .1306 Mtetra
.693 .598 .745 r
.4677 .1306 .47523 .15024 .48896 .14149 .48145 .121 Mtetra
.641 .563 .751 r
.48145 .121 .48896 .14149 .50274 .13146 .49519 .1146 Mtetra
.637 .6 .795 r
.49519 .1146 .50274 .13146 .51654 .12077 .50899 .10929 Mtetra
.659 .7 .877 r
.50899 .10929 .51654 .12077 .53037 .11378 .52286 .10396 Mtetra
.664 .741 .907 r
.52286 .10396 .53037 .11378 .54426 .10848 .5368 .0986 Mtetra
.5368 .0986 .54426 .10848 .55822 .10314 .5508 .09322 Mtetra
.5508 .09322 .55822 .10314 .57225 .09778 .56488 .08781 Mtetra
.56488 .08781 .57225 .09778 .58636 .09239 .57904 .08236 Mtetra
.649 .735 .912 r
.57904 .08236 .58636 .09239 .60053 .08697 .59327 .0774 Mtetra
.655 .75 .92 r
.59327 .0774 .60053 .08697 .61479 .08182 .60758 .07222 Mtetra
.67 .756 .915 r
.60758 .07222 .61479 .08182 .62913 .07687 .62195 .06652 Mtetra
.671 .74 .902 r
.62195 .06652 .62913 .07687 .64352 .07123 .63639 .06068 Mtetra
.669 .735 .9 r
.63639 .06068 .64352 .07123 .65798 .0654 .6509 .05489 Mtetra
.666 .736 .902 r
.6509 .05489 .65798 .0654 .67252 .05962 .66549 .04918 Mtetra
.665 .739 .905 r
.66549 .04918 .67252 .05962 .68713 .05392 .68016 .0435 Mtetra
.664 .74 .907 r
.68016 .0435 .68713 .05392 .70182 .04827 .69491 .03782 Mtetra
.664 .741 .907 r
.69491 .03782 .70182 .04827 .7166 .04262 .70973 .03212 Mtetra
.05522 .272 .06413 .28033 .07584 .27583 .06696 .26747 Mtetra
.06696 .26747 .07584 .27583 .0876 .27132 .07875 .2629 Mtetra
.663 .74 .907 r
.07875 .2629 .0876 .27132 .09941 .26682 .09059 .25834 Mtetra
.09059 .25834 .09941 .26682 .11127 .26235 .10249 .25377 Mtetra
.661 .737 .907 r
.10249 .25377 .11127 .26235 .12317 .25797 .11443 .24923 Mtetra
.658 .734 .906 r
.11443 .24923 .12317 .25797 .13512 .25364 .12643 .24476 Mtetra
.655 .731 .905 r
.12643 .24476 .13512 .25364 .14714 .24918 .13847 .24035 Mtetra
.656 .733 .906 r
.13847 .24035 .14714 .24918 .15927 .24422 .15057 .23588 Mtetra
.667 .75 .912 r
.15057 .23588 .15927 .24422 .17149 .23906 .16277 .23109 Mtetra
.686 .765 .911 r
.16277 .23109 .17149 .23906 .1837 .23436 .17509 .22568 Mtetra
.665 .742 .908 r
.17509 .22568 .1837 .23436 .19597 .22964 .1874 .22088 Mtetra
.664 .741 .907 r
.1874 .22088 .19597 .22964 .20829 .2249 .19976 .21609 Mtetra
.19976 .21609 .20829 .2249 .22068 .22014 .21218 .21129 Mtetra
.21218 .21129 .22068 .22014 .23313 .21536 .22466 .20646 Mtetra
.22466 .20646 .23313 .21536 .24563 .21055 .2372 .20161 Mtetra
.2372 .20161 .24563 .21055 .2581 .20683 .2498 .19674 Mtetra
.661 .713 .887 r
.2498 .19674 .2581 .20683 .27037 .20627 .26247 .19184 Mtetra
.644 .626 .818 r
.26247 .19184 .27037 .20627 .28277 .20529 .27519 .18692 Mtetra
.616 .563 .772 r
.27519 .18692 .28277 .20529 .29531 .20356 .28793 .18258 Mtetra
.576 .516 .75 r
.28793 .18258 .29531 .20356 .30801 .20095 .30061 .17986 Mtetra
.584 .52 .749 r
.30061 .17986 .30801 .20095 .32084 .19757 .31341 .17672 Mtetra
.594 .528 .751 r
.31341 .17672 .32084 .19757 .33378 .19357 .32631 .17307 Mtetra
.604 .538 .753 r
.32631 .17307 .33378 .19357 .34682 .18911 .33932 .16892 Mtetra
.614 .547 .755 r
.33932 .16892 .34682 .18911 .35995 .18433 .35243 .16429 Mtetra
.622 .553 .756 r
.35243 .16429 .35995 .18433 .37316 .17929 .36562 .1592 Mtetra
.63 .558 .754 r
.36562 .1592 .37316 .17929 .38644 .17401 .37891 .15366 Mtetra
.637 .559 .751 r
.37891 .15366 .38644 .17401 .39979 .1684 .39228 .14762 Mtetra
.643 .56 .746 r
.39228 .14762 .39979 .1684 .41323 .16233 .40573 .14108 Mtetra
.648 .559 .74 r
.40573 .14108 .41323 .16233 .42674 .15562 .41925 .13403 Mtetra
.653 .559 .736 r
.41925 .13403 .42674 .15562 .44033 .14813 .43283 .12655 Mtetra
.628 .546 .742 r
.43283 .12655 .44033 .14813 .45399 .13976 .44641 .12069 Mtetra
.628 .569 .769 r
.44641 .12069 .45399 .13976 .4677 .1306 .46005 .11541 Mtetra
.644 .626 .818 r
.46005 .11541 .4677 .1306 .48145 .121 .47375 .11011 Mtetra
.661 .713 .887 r
.47375 .11011 .48145 .121 .49519 .1146 .48753 .10478 Mtetra
.664 .741 .907 r
.48753 .10478 .49519 .1146 .50899 .10929 .50137 .09943 Mtetra
.50137 .09943 .50899 .10929 .52286 .10396 .51528 .09405 Mtetra
.51528 .09405 .52286 .10396 .5368 .0986 .52926 .08864 Mtetra
.52926 .08864 .5368 .0986 .5508 .09322 .54332 .0832 Mtetra
.663 .74 .908 r
.54332 .0832 .5508 .09322 .56488 .08781 .55745 .07778 Mtetra
.643 .734 .915 r
.55745 .07778 .56488 .08781 .57904 .08236 .57166 .07298 Mtetra
.662 .759 .922 r
.57166 .07298 .57904 .08236 .59327 .0774 .58594 .06754 Mtetra
.671 .751 .911 r
.58594 .06754 .59327 .0774 .60758 .07222 .60028 .06177 Mtetra
.671 .738 .901 r
.60028 .06177 .60758 .07222 .62195 .06652 .6147 .05593 Mtetra
.668 .735 .9 r
.6147 .05593 .62195 .06652 .63639 .06068 .62919 .05013 Mtetra
.666 .736 .903 r
.62919 .05013 .63639 .06068 .6509 .05489 .64375 .0444 Mtetra
.665 .739 .905 r
.64375 .0444 .6509 .05489 .66549 .04918 .6584 .0387 Mtetra
.664 .74 .906 r
.6584 .0387 .66549 .04918 .68016 .0435 .67312 .03299 Mtetra
.664 .74 .907 r
.67312 .03299 .68016 .0435 .69491 .03782 .68792 .02727 Mtetra
.664 .741 .907 r
.68792 .02727 .69491 .03782 .70973 .03212 .7028 .02151 Mtetra
.04623 .26361 .05522 .272 .06696 .26747 .05799 .25903 Mtetra
.05799 .25903 .06696 .26747 .07875 .2629 .06982 .25443 Mtetra
.06982 .25443 .07875 .2629 .09059 .25834 .08169 .24981 Mtetra
.664 .74 .907 r
.08169 .24981 .09059 .25834 .10249 .25377 .09362 .24518 Mtetra
.663 .74 .907 r
.09362 .24518 .10249 .25377 .11443 .24923 .10561 .24054 Mtetra
.661 .738 .907 r
.10561 .24054 .11443 .24923 .12643 .24476 .11764 .23593 Mtetra
.658 .734 .906 r
.11764 .23593 .12643 .24476 .13847 .24035 .12973 .23138 Mtetra
.655 .731 .905 r
.12973 .23138 .13847 .24035 .15057 .23588 .14186 .2269 Mtetra
.653 .731 .906 r
.14186 .2269 .15057 .23588 .16277 .23109 .15404 .22245 Mtetra
.658 .742 .912 r
.15404 .22245 .16277 .23109 .17509 .22568 .1663 .21788 Mtetra
.669 .768 .924 r
.1663 .21788 .17509 .22568 .1874 .22088 .17865 .21295 Mtetra
.686 .77 .915 r
.17865 .21295 .1874 .22088 .19976 .21609 .19112 .20746 Mtetra
.672 .749 .909 r
.19112 .20746 .19976 .21609 .21218 .21129 .20361 .20236 Mtetra
.664 .741 .907 r
.20361 .20236 .21218 .21129 .22466 .20646 .21612 .19749 Mtetra
.21612 .19749 .22466 .20646 .2372 .20161 .2287 .19259 Mtetra
.2287 .19259 .2372 .20161 .2498 .19674 .24134 .18768 Mtetra
.24134 .18768 .2498 .19674 .26247 .19184 .25404 .18273 Mtetra
.25404 .18273 .26247 .19184 .27519 .18692 .2668 .17777 Mtetra
.2668 .17777 .27519 .18692 .28793 .18258 .27962 .17278 Mtetra
.662 .726 .896 r
.27962 .17278 .28793 .18258 .30061 .17986 .29251 .16776 Mtetra
.654 .675 .857 r
.29251 .16776 .30061 .17986 .31341 .17672 .30546 .16272 Mtetra
.647 .639 .828 r
.30546 .16272 .31341 .17672 .32631 .17307 .31847 .15766 Mtetra
.641 .616 .809 r
.31847 .15766 .32631 .17307 .33932 .16892 .33155 .15257 Mtetra
.637 .602 .798 r
.33155 .15257 .33932 .16892 .35243 .16429 .34469 .14745 Mtetra
.635 .595 .792 r
.34469 .14745 .35243 .16429 .36562 .1592 .3579 .14231 Mtetra
.3579 .14231 .36562 .1592 .37891 .15366 .37117 .13715 Mtetra
.637 .602 .798 r
.37117 .13715 .37891 .15366 .39228 .14762 .38451 .13196 Mtetra
.641 .616 .809 r
.38451 .13196 .39228 .14762 .40573 .14108 .39792 .12674 Mtetra
.647 .639 .828 r
.39792 .12674 .40573 .14108 .41925 .13403 .41139 .1215 Mtetra
.654 .675 .857 r
.41139 .1215 .41925 .13403 .43283 .12655 .42493 .11623 Mtetra
.662 .726 .896 r
.42493 .11623 .43283 .12655 .44641 .12069 .43854 .11093 Mtetra
.664 .741 .907 r
.43854 .11093 .44641 .12069 .46005 .11541 .45222 .10561 Mtetra
.45222 .10561 .46005 .11541 .47375 .11011 .46597 .10026 Mtetra
.46597 .10026 .47375 .11011 .48753 .10478 .47978 .09488 Mtetra
.47978 .09488 .48753 .10478 .50137 .09943 .49367 .08947 Mtetra
.49367 .08947 .50137 .09943 .51528 .09405 .50763 .08404 Mtetra
.656 .738 .91 r
.50763 .08404 .51528 .09405 .52926 .08864 .52166 .07884 Mtetra
.644 .739 .919 r
.52166 .07884 .52926 .08864 .54332 .0832 .53577 .07403 Mtetra
.661 .764 .926 r
.53577 .07403 .54332 .0832 .55745 .07778 .54995 .06864 Mtetra
.672 .77 .924 r
.54995 .06864 .55745 .07778 .57166 .07298 .5642 .06289 Mtetra
.673 .748 .907 r
.5642 .06289 .57166 .07298 .58594 .06754 .57852 .057 Mtetra
.67 .737 .9 r
.57852 .057 .58594 .06754 .60028 .06177 .59291 .05114 Mtetra
.668 .735 .9 r
.59291 .05114 .60028 .06177 .6147 .05593 .60738 .04534 Mtetra
.666 .737 .903 r
.60738 .04534 .6147 .05593 .62919 .05013 .62192 .03961 Mtetra
.664 .739 .905 r
.62192 .03961 .62919 .05013 .64375 .0444 .63654 .03389 Mtetra
.664 .74 .907 r
.63654 .03389 .64375 .0444 .6584 .0387 .65124 .02815 Mtetra
.65124 .02815 .6584 .0387 .67312 .03299 .66602 .02241 Mtetra
.664 .741 .907 r
.66602 .02241 .67312 .03299 .68792 .02727 .68087 .01662 Mtetra
.68087 .01662 .68792 .02727 .7028 .02151 .6958 .01081 Mtetra
.03716 .25514 .04623 .26361 .05799 .25903 .04895 .25052 Mtetra
.04895 .25052 .05799 .25903 .06982 .25443 .06081 .24588 Mtetra
.06081 .24588 .06982 .25443 .08169 .24981 .07271 .24122 Mtetra
.07271 .24122 .08169 .24981 .09362 .24518 .08468 .23653 Mtetra
.663 .74 .907 r
.08468 .23653 .09362 .24518 .10561 .24054 .09669 .23184 Mtetra
.662 .74 .908 r
.09669 .23184 .10561 .24054 .11764 .23593 .10877 .22716 Mtetra
.66 .739 .908 r
.10877 .22716 .11764 .23593 .12973 .23138 .12089 .22251 Mtetra
.657 .736 .908 r
.12089 .22251 .12973 .23138 .14186 .2269 .13305 .21796 Mtetra
.653 .734 .909 r
.13305 .21796 .14186 .2269 .15404 .22245 .14526 .21351 Mtetra
.649 .734 .911 r
.14526 .21351 .15404 .22245 .1663 .21788 .15752 .20913 Mtetra
.652 .741 .915 r
.15752 .20913 .1663 .21788 .17865 .21295 .16986 .20464 Mtetra
.665 .757 .919 r
.16986 .20464 .17865 .21295 .19112 .20746 .18229 .19978 Mtetra
.686 .78 .922 r
.18229 .19978 .19112 .20746 .20361 .20236 .19486 .19425 Mtetra
.693 .771 .911 r
.19486 .19425 .20361 .20236 .21612 .19749 .20751 .18843 Mtetra
.664 .741 .907 r
.20751 .18843 .21612 .19749 .2287 .19259 .22012 .1835 Mtetra
.22012 .1835 .2287 .19259 .24134 .18768 .23279 .17853 Mtetra
.23279 .17853 .24134 .18768 .25404 .18273 .24553 .17355 Mtetra
.24553 .17355 .25404 .18273 .2668 .17777 .25833 .16854 Mtetra
.25833 .16854 .2668 .17777 .27962 .17278 .27119 .1635 Mtetra
.27119 .1635 .27962 .17278 .29251 .16776 .28411 .15844 Mtetra
.28411 .15844 .29251 .16776 .30546 .16272 .2971 .15335 Mtetra
.2971 .15335 .30546 .16272 .31847 .15766 .31015 .14824 Mtetra
.31015 .14824 .31847 .15766 .33155 .15257 .32327 .14311 Mtetra
.32327 .14311 .33155 .15257 .34469 .14745 .33645 .13794 Mtetra
.33645 .13794 .34469 .14745 .3579 .14231 .3497 .13276 Mtetra
.3497 .13276 .3579 .14231 .37117 .13715 .36301 .12754 Mtetra
.36301 .12754 .37117 .13715 .38451 .13196 .37639 .1223 Mtetra
.37639 .1223 .38451 .13196 .39792 .12674 .38984 .11704 Mtetra
.38984 .11704 .39792 .12674 .41139 .1215 .40336 .11175 Mtetra
.40336 .11175 .41139 .1215 .42493 .11623 .41694 .10643 Mtetra
.41694 .10643 .42493 .11623 .43854 .11093 .43059 .10108 Mtetra
.43059 .10108 .43854 .11093 .45222 .10561 .44432 .09571 Mtetra
.44432 .09571 .45222 .10561 .46597 .10026 .45811 .09031 Mtetra
.45811 .09031 .46597 .10026 .47978 .09488 .47197 .08488 Mtetra
.47197 .08488 .47978 .09488 .49367 .08947 .4859 .07942 Mtetra
.636 .73 .916 r
.4859 .07942 .49367 .08947 .50763 .08404 .4999 .07486 Mtetra
.645 .757 .931 r
.4999 .07486 .50763 .08404 .52166 .07884 .51398 .06999 Mtetra
.666 .775 .931 r
.51398 .06999 .52166 .07884 .53577 .07403 .52814 .06445 Mtetra
.676 .761 .915 r
.52814 .06445 .53577 .07403 .54995 .06864 .54237 .05852 Mtetra
.677 .749 .905 r
.54237 .05852 .54995 .06864 .5642 .06289 .55666 .05247 Mtetra
.673 .742 .902 r
.55666 .05247 .5642 .06289 .57852 .057 .57103 .04649 Mtetra
.67 .74 .903 r
.57103 .04649 .57852 .057 .59291 .05114 .58548 .04061 Mtetra
.667 .739 .904 r
.58548 .04061 .59291 .05114 .60738 .04534 .59999 .03482 Mtetra
.665 .74 .906 r
.59999 .03482 .60738 .04534 .62192 .03961 .61459 .02905 Mtetra
.664 .74 .907 r
.61459 .02905 .62192 .03961 .63654 .03389 .62926 .02329 Mtetra
.664 .741 .907 r
.62926 .02329 .63654 .03389 .65124 .02815 .64401 .01751 Mtetra
.64401 .01751 .65124 .02815 .66602 .02241 .65884 .01171 Mtetra
.65884 .01171 .66602 .02241 .68087 .01662 .67375 .00587 Mtetra
.67375 .00587 .68087 .01662 .6958 .01081 .68874 0 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -79.375 -14.5763 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -74.7039 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -68.8563 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -68.4165 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -71.646 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{232.5, 188.625},
  ImageMargins->{{0.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L00016R000`400?l00000o`00003oo`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM
0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00h`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo
_`1d000000000018W03Oool0K`3oool00><0oooo00X0omnL04P0M02oool0oooo0?oog`2LB000B9cO
0?ooo`3OW4P007BoK`3oool00><0oooo00/0omnL04P0M02oool0oooo0?oo_`1d07@0_ooo0?ooo`3o
gi`0B01d0;ooo`1^0?ooo`00h`3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03Oool0oooo0?oo
_`1d04P0W=oo06h0oooo003S0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono
07@0B02Lgol0KP3oool00><0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0
M01809cOo`1^0?ooo`00h@3oool03@2oM000001809boW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool04`3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03O
ool0D@3oool00>80oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8001d
_`0D0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RLg`3oool0gia8001d_e40oooo003S0?oo
o`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`0D0?ooo`0;0?oOW01807@0
_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?H0oooo00<0omnL04P00000
00000`0000000`0007@0_ooo0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3o
ool0oono07@0B02Lgol0D03oool00?l0oooo0P3oool02`3ogi`0B01d0;ooo`3oool0okmd0018W03O
ool0oooo0?oo_`1d04P0W=oo0500oooo003o0?ooo`80oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`1@0?ooo`00o`3oool03@2oM000001809boW01807@0_ooo0?oo
o`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0D03oool00?l0oooo0@3oool02`3o_g@000000000
M02oool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo0540oooo003^0?ooo`8000004@3oool00`3o
gi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018W03Oool0D@3oool00>`0oooo0P0000000`2Y
_NP000000000001[0?ooo`00j@3oool3000000<0ZKgX0P00001[0?ooo`00i`3oool2000000H0ZKgX
00<000000:Vmj0000000JP3oool00>@0oooo0`0000080:Vmj0040000002Y_NP0ZKgX000006T0oooo
003R0?ooo`<000002P2Y_NP010000000ZKgX0:Vmj000001Y0?ooo`00g`3oool300000080ZKgX00<0
00000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000006P0oooo002_0?ooo`050<AO5000
000000000000501Oa?l0:03oool300000100ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001W0?oo
o`00[P3oool01`3oScD001AO0<Coo`3oool0ooo405lD=@2?ool09@3oool2000001<0ZKgX00<00000
0:Vmj02Y_NP00P2Y_NP00`000000oooo0?ooo`1U0?ooo`00/`3oool00`2?=@00=Hoo0?ooo`0Q0?oo
o`<000005@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000003oool0oooo06@0oooo002c0?ooo`03
08le000eSol0oooo01l0oooo0P0000020:Zmi`030000002Y_NP0ZKgX01@0ZKgX00<000000:Vmj02Y
_NP00P2Y_NP00`000000oooo0?ooo`1T0?ooo`00[P3oool01`3oa5l0500D05o4o`3oool0ooo405lD
501Oa?l07@3oool3000000D0Z[gW0`2Y_NP30:Vmi`P0ZKgX0`2Y_NL50:Vmj0030000002Y_NP0ZKgX
00<0ZKgX00<000000?ooo`3oool0H`3oool00:h0oooo00<0oon?03D0000000000P0000000`0eSol0
oooo0?ooo`0J0?ooo`8000002@2Z_NL50:Vmi`H0ZKgX1P2Y_NL40:Vmj0030000002Y_NP0ZKgX00@0
ZKgX00<000000?ooo`3oool0HP3oool00:h0oooo00<0ooo405lD501Oa?l0703oool3000000T0Z[gW
0`2Z_>L50:Vmi`<0ZKgX0`2Z_NL50:Vmi`@0ZKgX00<000000:Vmj02Y_NP0102Y_NP00`000000oooo
0?ooo`1R0?ooo`00[`3oool00`2?=@00=Hoo0?ooo`0I0?ooo`8000000P2[_NL00`000000Z[gW0:Zm
i`040:Zmi`L0Z[cW102Y_NL70:Zmi`80ZKgW0`2Z_NL30:Vmj0030000002Y_NP0ZKgX00D0ZKgX00<0
00000?ooo`3oool0H@3oool00:l0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`<00000
00<0[;gV0:^mi`2[_NL00`2[_NL30:Zmi`<0ZkcV2`2Z_>L;0:Zmi`<0ZKgX00<000000:Vmj02Y_NP0
1P2Y_NP00`000000oooo0?ooo`1P0?ooo`00aP3oool2000000D0[;gV1@2[_NL60:^liP<0Z[cW0`2[
_>H50:Zli`<0Z[gW0`2Z_>H50:Zmi`80ZKgX00@000000:Zmi`2Z_NL0Z[gW1@2Y_NP00`000000oooo
0?ooo`1P0?ooo`00``3oool300000080[KoW1@2/_NHA0:^liPD0Z[cW1`2Z_>H60:Zmi`030000002Z
_NL0Z[gW0080Z[gW0P2Y_NP30:Vmi`030000003oool0oooo05l0oooo00310?ooo`80000000<0[KoW
0000002]_nL00`2]_nL20:bmiP<0[;oX4@2[_>H20:Zli`<0ZkcV1P2Z_>H50:Zli`030:Zmi`000000
Z[gW00<0Z[gW1P2Y_NL00`000000oooo0?ooo`1N0?ooo`00_P3oool300000080[L;Z1P2]_nL60:bo
j1H0ZkcV0`2Z_>H30:^liPD0Z[cW00<000000:Zmi`2Z_NL00`2Z_>L50:Vmi`030000003oool0oooo
05h0oooo002k0?ooo`<000001P2]`^X30:foi`<0[<G/1P2/_nP20:^liP<0Zl3Y1P2[_>H50:^miP`0
ZkcV102Z_>L00`000000Z[cW0:Zli`040:Zli`80ZKgW0`2Z_>L00`000000oooo0?ooo`1M0?ooo`00
^@3oool2000000@0Z/K^1P2]`^X60:c5k0D0[;oX1P2[`>T30:^liP<0Zl7Z1@2[_NH30:^liP<0[;gV
2@2[_>H00`000000Z[cW0:Zli`090:Zli`030?ooo`000000oooo05d0oooo002f0?ooo`@0000000<0
YL7^0:[6kP2Za^h00`2Za^h30:g2jP<0ZL?]1@2/aN`60:W2k0D0Zl3Y1P2[`NX50:^miPL0[;gV0P2[
_>H30:bmiP<0ZkcV00<000000:^liP2Z_>L00P2Z_>L30:^liPD0Z[cW00<000000?ooo`3oool0G03o
ool00;@0oooo0P0000040:G1kP030000002U`Nh0Z/K^00<0Z/K^1`2Y`nd20:c5k0<0Y;_Z1P2Y`^`2
0:_0j@<0Yko[1P2[`NX20:^miP<0Zl;[2`2/_NH30:^liP030000002[_>H0ZkcV00H0ZkcV102Z_>L0
0`3oool000000?ooo`1L0?ooo`00/@3oool300000080X[[Z1P2U`Nh60:Bmj`D0ZL?]1P2T^nX50:W2
k0H0Yko[1@2[`NX60:_2j`<0[;gV0`2[`^/50:bmiP80ZkcV00@000000:bmiP2/_NH0[;gV1@2[_>H5
0:ZliP800000G03oool00:h0oooo0`0000000`2Y_NP0X[[Z0::jjP030::jjP<0YL7^0`2W_>P60:Bm
j`D0ZKgX1P2T^nX50:Jlj@D0Yko[1P2V_N/<0:_2j`H0[;gV00<000000:bmiP2/_NH00P2/_NH20:^l
iP<0[;gV1@2Z_>H00`000000oooo0?ooo`1J0?ooo`00[03oool4000000<0ZKgX1@2R^^X60:Nlj0<0
Y;g[202Y_NP30:BkjP<0ZKgX1@2V_>T20:Noj`<0YkcX1P2V_N/50:FljPH0Zl;[1@2[`NX00`2/_NH0
00000:bmiP090:bmiP@0Z[cV00<0oooo0000003oool0FP3oool007/0oooo00D0oon?03D000000000
01AO0<Coo`0Z0?ooo`8000003@2Y_NP50:Nlj180ZKgX102V_>T60:Nlj0<0Y[g[0`2X_NP50:FljP<0
Zl;[0`2U_>X50:_1jP030000002/_NH0[;gV00<0Zl3Y1@2/_NH50:ZliP030?ooo`000000oooo05T0
oooo001j0?ooo`060?ooa01O500055o40?ooo`34Ga@003F?9`3oool300000100ZKgX0P2W_>PI0:Vm
j0H0YkcX1P2X_NP;0:FljP@0Zl7Z00<000000:_0j@2[`>T0102[`>T20:bmiP<0[;kX1@2Z_>H00`00
0000oooo0?ooo`1H0?ooo`00NP3oool01`3oohl0=@0e08ooo`3oool0olAO01@0=@2?ool0903oool2
000002l0ZKgX0`2W_>P30:Vmj0X0Z;gX1P2U_>X50:Jmj`030000002[`>T0Zl3Y00<0Zl3Y1@2/_^P5
0:ZliP030?ooo`000000oooo05P0oooo001j0?ooo`070?o4G`0D55l0a?oo0?ooo`3oohl0=@0D05o4
o`0Q0?ooo`@00000=`2Y_NP20:Rmj0<0ZKgX1@2X_NP30:FljP<0YkcX102V_N/010000000Zl3Y0:_0
j@2[`>T30:Noj`D0[;kX0P2Z_>H30:Zli`030000003oool0oooo05L0oooo001j0?ooo`070?n?=@00
55l0a?oo0?ooo`3oohl0=@0D05o4o`0O0?ooo`800000@@2Y_NP40:Rmj0L0YkcX0`2V_N/00`000000
Yko[0:Noj`050:Noj`@0[;kX1P2Z_>L00`000000oooo0?ooo`0B0?ooo`050=nLB000000000000000
B02Lgol0?`3oool007X0oooo00L0olAO01@DG`34ool0oooo0?ooS`0e01@0GlCo01`0oooo0`000018
0:Vmj0H0YkcX0`2V_>T00`000000Y[cY0:Noj`050:Noj`D0ZL7/1@2Z_>L00`3oool000000?ooo`0A
0?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0n0?ooo`00NP3oool01`3oohl0=@0e08oo
o`3oool0olAO01@0=@2?ool06@3oool3000001<0ZKgX0`2Y]^<50:Vmj0D0Z;?P1P2Y_NP50:Vlib40
ZKgX0`2W_>P30:Vmj080Y[cY00<000000:Jlj@2V_>T00`2W_n/30:Bkj@D0ZL7/0P2Z_>L30:Rnj@03
0000003oool0oooo01D0oooo00<0_g@007Boo`3oool0?@3oool007X0oooo00H0ooo405lD000eSol0
oooo0<AO5000=HlH0?ooo`80000000<0ZKgX0000002Y_NP04@2Y_NP60:Vfh`80ZKgX0`2SVL/50:Rc
h0<0ZKgX0`2SW<d50:Vli`<0ZKgX0`2WZmTQ0:Vmj0040:Jlj@000000Y[cY0:Jlj@L0Y;_Y102Y`N`6
0:Rnj@030000003oool0oooo00L0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`04
0?ooo`030;md001d_ol0oooo03d0oooo001k0?ooo`050?ooS`0e00000000000DG`34ool05@3oool3
000000L0ZKgX1@2Y^ND50:Vmj0H0Y:3A1@2Y]^<60:>Ib`D0Z;?P1P2SW<d40:Vli`L0Yj_I0P2Y_NP3
0:FPdA`0ZKgX00@000000:Vmj02Y_NP0ZKgX1P2T^nT50::jjPD0Z;kY00<0oooo0000003oool03`3o
ool01`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol0?P3oool009<0oooo0P0000080:Vmj0<0YjcK
1@2Y^ND20:Vmj0<0X9741P2TX=420:Vfh`<0Y9301P2SVL/20:Rch0<0YY;01@2SW<d50:2?`PH0Yj_I
1P2UX=4K0:Vmj0030000002Y_NP0ZKgX00P0ZKgX1@2R^^X20:Rnj@<0YL3]00<000000?ooo`3oool0
3P3oool00`3ookl0M000000000020000000307Boo`3oool0oooo03d0oooo002@0?ooo`<00000202Y
_NP50:N/f`D0ZKWU1P2PTL@50:BPd@D0Y9301P2SVL/50:JB`0@0Xic=0P2iW[h50:2?`P<0Yj_I0`2]
V<450:FPd@H0Y9_=5@2Y_NP00`000000ZKgX0:Vmj0090:Vmj0@0X[[Z1P2U`>d00`000000oooo0?oo
o`0=0?ooo`030?oog`2LB4P0W=oo0480oooo002>0?ooo`80000000<0ZKgX0000002Y_NP01P2Y_NP3
0:FSd`D0YjcK0P2Y^ND30:2;_@D0X974102TX=420;6I_PD0Y930102SVL/20;JM_`D0YY;00P2SW<d3
0;VN_PH0X8o21@2]V<440:FPd@80]Yk01P2TVld20:Vmj0<0Y9_=3`2Y_NP00`000000ZKgX0:Vmj009
0:Vmj0D0X[[Z1@2U`>d00`3oool000000?ooo`0>0?ooo`030;md001d_ol0oooo0440oooo002;0?oo
o`<000002@2Y_NP50:FSd`D0YjcK1@2PRkd60:2Aa080Y:3A0`2aVKh50:B@`080XiW;102fWKl50:JB
`0030:>Lc@2iW[h0^Ijn0080^Ijn1@2PSl820;jV`@D0[IS10P2UX=440;JN`0/0Y9_=0P2Y_NP30:FP
d@T0ZKgX00<000000:Vmj02Y_NP02P2Y_NP50::jjPD0Wk[/00<000000?ooo`3oool03@3oool01P3O
W4P00000000000000000001d0;oooch0oooo00290?ooo`8000001`2Y_NP60:BMc`D0YJ?C0P2W[=/3
0:N?_0D0X8^m1@2PTL@50;6I_PD0Y9301P2fWKl50:JB`0H0^Ijn0`2PSl830;jV`@D0[IS11P2fW/04
0:BKc@80^j;01@2TVld60:FPd@P0ZKgX00<000000:Vmj02Y_NP02`2Y_NP20::jjP<0Z;cX1@2O^^`0
0`000000oooo0?ooo`1@0?ooo`00QP3oool3000000L0ZKgX0`2SV/`50:BMc`D0YJ?C1@2WSk`50:2;
_@@0X9740P2bWL<50;6I_P<0Y9300P2hY/H60;JM_`<0YY;00P2mZLH50;VN_P80X8o2102nY/440:fH
`@80`jk51P2fW/020:BKc@<0^j;0102TVld20;bT`@D0YJ3A1P2WZ]T20:Vmj0030000002Y_NP0ZKgX
00/0ZKgX1P2X_>P409njk0030?ooo`000000oooo0500oooo00240?ooo`<000001`2Y_NP60:>Jc0D0
Y9g?0P2UXm<30:F?_@@0Yhnl1P2PRkd20:2Aa0<0/Yg31@2aVKh20:B@`0<0^:K61P2fWKl20:JB`0<0
_JW61@2iW[h70;jV`@80[IS10`33[/D60;JN`0H0^j;00P2TVld30;bT`@@0YJ3A0P2iXl<60:NZf@03
0:Vmj0000000ZKcW0080ZKcW2`2Y_NP50:Rlj0D0Xk[Z00<000000?ooo`3oool0C`3oool00840oooo
0`0000030:Vmj0030000002Y_NP0ZKgX00D0XYS:1@2SV/`50:BMc`D0YHnm1@2WSk`50:2;_@D0/Yg3
1@2aVKh60;RVaPD0]Yfo1P2mZLH30;VN_P80`[O@1P2nY/400`2]V<40`jk50<>^a@020<>^a@D0]Yk0
0P36/lL50;^R`0H0_:C10P2UX=430;VS``H0Yj[I00<0ZKcW0000002Y_>L00`2Y_>L;0:Vmj080Z;cX
0`2Y_NP50:>jjP030000003oool0oooo04h0oooo001o0?ooo`8000001`2Y_NP80::HbPD0Xi[<0P2T
WLl30:B?_P@0YHnm1@2WSk`30:2;_@<0/ZC:1@2bWL<30;6I_P80^[?C1@2hY/H40;JM_`80_[[F1@2m
ZLH20;VN_P@0`[O@1@2nY/460<>^a@<0]Yk00`36/lL40;^R`080bKK71@2lY<460;VS``<0Yj[I0`2a
X<L00`000000ZKcW0:Vli`020:Vlia40ZKgX0P2S^^X30:Vmj0030000003oool0oooo04d0oooo001l
0?ooo`<000001`2Y_NP:0::HbPD0Xi[<1@2TSkh50:F?_@@0Yhnl1P2bY<X50;:M``80/IVn0`2j/m<6
0;RVaP80]Yfo0`2n^]H50;fYaPH0`[O@102nY/420<C3f@D0`jk50P2fW/050<Jca`80^j;00`39]/L5
0;bT`@030<Zea@2iXl<0^J?300<0^J?31P2aX<L00`000000YIc=0:FLc@030:FLcAD0ZKgX00<00000
0?ooo`3oool0C@3oool004/0oooo00D0a5lD000000000000000D05o4o`0Y0?ooo`<0000000<0ZKgX
0000002Y_NP01@2Y_NP30:>Jc0X0XYS:0P2SV/`30:>?`0@0Y8nn1@2USkd20:N?_0<0/ZcB1P2bY<X4
0;:M``H0^[?C1@2hY/H60;jjeP<0_JW60P2md>P60<:gd080_ZK10`34`mT50<>^a@L0a[?700<0^j;0
0<Vfa`39]/L00P39]/L40;bT`@80b[G51@2iXl<00`3;/l<0/J370;6Pa`030;6Pa`030000003;/L00
YIc=00@0YIc=0P2Y_NP30:Rbga00ZKgX00<000000?ooo`3oool0C03oool004X0oooo00L0ohle000D
G`34ool0oooo0?ooa01O53D0Sooo02H0oooo0P0000090:Vmj0H0Xi[<2@2RV<X50:>?`0D0Y8nn102U
Skd60;:/dPD0/ZC:0P2bWL<30;S4h`D0^[?C0`2hY/H30;WAk0D0_[[F0P2mZLH40;g@j0D0`[O@1P34
`mT30<>^a@80a<cP1P36/lL60<Vfa`80_:C10`3:]LD40;VS``<0bk?3102aX<L00`3;/L0000000:FL
c@040:FLc@H0Z;;O3`2Y_NP00`000000oooo0?ooo`1<0?ooo`00C`3oool00`2?=@00=Hoo0?ooo`0R
0?ooo`<000001`2Y_NP50:BMc`D0Xi[<1`2RV<X30:6>`@@0Xho01@2TSkh30:F?_@80/KCJ1@2b[=85
0;:TbPD0^<CS1@2j/m<70;WAk0@0_[[F1`2md>P20<:gd0<0/=kg1@34`mT20<>^a@@0a<cP1036/lL2
0<C?h`D0bKK700<0_:C10<Zea@3:]LD00`3:]LD20;VS``@0bk?30`2aX<L20<^a`0030000003;/L00
YIc=0080YIc=0P2oZlD50:Rbga00ZKgX00<000000?ooo`3oool0B`3oool00480oooo00<0olAO01@0
000000000`0000000`0003D0Sooo0?ooo`040?ooo`0308le000eSol0oooo0200oooo0P0000080:Vm
j0<0YJ?C1@2TWLl50:>Jc0@0XYS:1@2QS/450:>?`0@0Y8nn0P2USkd40;6dfPD0/ZcB0P2bY<X30;;F
l`D0^<CS0P2j/m<40:;So0D0^M7/1@2Nhod60;g@j0H0/=kg1034`mT70<C<h080a[?70`34cn<50<Vf
a`H0b[G500<0^J?30<^c``3;/l<0103;/l<01P2aX<L0bk700<^a`03;/L0000000<^a`080YIc=102o
ZlD20:Rbg`<0[JC>402Y_NP00`000000oooo0?ooo`1:0?ooo`00BP3oool01`3oa5l0500D05o4o`3o
ool0ooo405lD501Oa?l07P3oool3000000030:Vmj0000000ZKgX00D0ZKgX1P2UXm<40:BMc`D0Xi[<
1@2OSL440:6>`@D0Xho0102TSkh60;6dfPD0/ZcB1P2be_<40;S4h`L0X^?l1P1Oe>/409kSo@H0JmSd
1@2`g_L509cQo@H0a<cP1P34cn<30<Vfa`80aLkQ1@3:]LD70<^c``@0bk7000<000000<^a`02oZlD0
1@2oZlD60:fTcP80ZKgX0`2Y]^8:0:Vmj0030000003oool0oooo04X0oooo001:0?ooo`030?ooS`0e
000000000080000000<0=Hoo0?ooo`3oool06P3oool00`2Y_NP00000000000070:Vmj0D0YjcK1@2U
Xm<50:BMc`80Xi[<0`2MS<4409n=`@D0XHk1102SSl050:nkhPH0/KCJ0P2b[=830:CSo0D0/]Kc1`1j
h?@602jgb`H09JoH1@0T[l`406_Hm0D0?[oS1@2LhOd608gNoPD0a<oS0P39]/L30<G>h@@0b[G50P39
bMX50<^c``80cL?A0`3;/L000`000000bk700<nlb0050;n[a@030<ng`P2]Y<h0[JC>00<0[JC>1P2Y
]^8:0:Vmj0030000003oool0oooo04T0oooo001:0?ooo`030?ooa01O51@0GlCo01d0oooo0`000008
0:Vmj080ZKWU1@2W[=/50:FSd`@0Y9g?1@2MS<4409n=`@D0XHk10P2SSl030:foi`D0[k_R1@2a]=X6
0:CSo080E=3M1@1Oc?P30:Vmj0@0R:o_0`1Y_Od30:Vmj0H0R:o_1@2W_>P506VQl@807Z;S1@0U[]X6
08gNoP@0a<oS1P35c^420<Zea@<0bLWJ103;/l<30<g3d@<0bk7000<000000<nlb03?_<P0102oZlD2
0<ng`P@0[JC>0P34/<L50:VfhP/0ZKgX00<000000?ooo`3oool0B03oool004/0oooo00<0ScD003F?
o`3oool06P3oool2000000T0ZKgX1@2Y^ND50:N/f`@0YJ?C1@2JRL0409f<`@D0Whg1102QS/460:fo
i`D0[k_R1P2Cio/20433c0L0Q<[n1P2Y_NP408R_k`H0ZKgX0`28[nl30:Vmj0D0YkcX0P1YXO430:Vm
j0D0O:W`0P0/XNl508gNoPD0Rm_o1@35c^460<W9fP80bk?31@3=`m420<^a`0040000003?_<P0ckc8
0<nlb080_j_5103?]l820:fTcP@0a;370P2Y]^830:bWdPX0ZKgX00<000000?ooo`3oool0B03oool0
04/0oooo00H0a5lD00000000000000000000=@2?oolC0?ooo`040:Vmj0000000000000000080ZKgX
00<000000:Vmj02Y_NP01`2Y_NP50:Vii@@0YjcK1@2HQl0409Z9`0D0WHc1102OSL420:6>`@<0Zl;Z
1@2]_nL708CVm0<0WKW/1P2D_oDK0:Vmj0@0YkcX1P2Y_NP207bYl0<0ZKgX1@23[>l302ZKk`@0Rm_o
1@2Gfoh50<W9fPL0cL?A00<0bk700<nlb00000000`3?_<P00`2oZlD0ckO20<ng`P030<ng`P030:fT
cP34/<L0a;3700<0a;371P2/Ym8:0:Vmj0030000003oool0oooo04L0oooo001R0?ooo`030:Vmj000
000000000100ZKgX102Y^ND509F5_`@0V8O0102JRL0509f<`@@0Whg11P2[`^X20:foi`D0O>C^0P14
a/P609fik0<0U;oe;@2Y_NP508>/k`@0:Y__100QYn4409OKoP80bLWJ0`2[fOP60<g3d@80ckc800@0
00000<nlb03?_<P0ckc81P3?]l860<B`a`030=6j``2/Ym80[:OB00<0[:OB2`2Y_NP00`000000oooo
0?ooo`160?ooo`00G`3oool400000180ZKgX1@2CQ;l409F5_`@0V8O01@2JRL0409f<`@D0ZL7[1@2[
`^X307cTkP80H]SO1P2Y_NP509fik3D0ZKgX1@1mZO0401VCj080=K7^1P2[fOP30<g3d@<0_]?Y00@0
ckc80000003?_<P0ckc80P3;bMP40<ng`P80dL3:1034/<L20=6j``@0[:OB0P30//`:0:Vmj0030000
003oool0oooo04H0oooo001M0?ooo`040:Vmj0000000000000000100ZKgX1@2MT<D409>4_`@0UHFo
1@2HQl0409Z9`080WHc10`2W_^T50:W1j`<0O>G[101eh^U80:Vmj0D0JIk_0P00R=H50:_In0H0_]?Y
00<000000<nlb03;bMP00P3;bMP30<ng`P<0dL3:0`34/<L40=6j``80[:OB1030//`20:Vmj0<0ZKWU
1@2Y_NP00`000000oooo0?ooo`150?ooo`00F`3oool3000000l0ZKgX1@2TX=4409f@a@@0ThBo1@2E
QKl409R7`0@0VXW01P2W_^T20:W1j`<0P>O/1020in];0:Vmj080JIk_0`2W_>P304F;k0@0G<?l1@2n
dnT00`000000blWH0<_9f0030<_9f0030<ng`P3A`<X0dL3:00<0dL3:00<0a;370=6j``3A^/<00`3A
^/<60<2bc0H0ZKWU102Y_NP00`3oool000000?ooo`150?ooo`00F03oool3000000@0/LGY3@2Y_NP2
0:Vfh`@0Y:3A102MT<D509>4_`@0UHFo102HQl050:FgiPD0YkkY0`20in`3083Wjdh0ZKgX1P2W_>P3
04F;k0@05YKT102?dOh00`000000blWH0<_9f0030<_9f0H0dL3:1P3A^/<00`3C_lL0`;;<0<2bc002
0<2bc080ck[61@2Y^ND50:Vmj0030000003oool0oooo04@0oooo001F0?ooo`8000000P2_an`50;75
j@/0ZKgX1@2Y]^<40:BPd@@0WI35102CQ;l409F5_`D0XJkP1@2U]nH508WZk`<0P^WWD@2Y_NP50:Nl
j0@0AH_/100FU^@308oAoP040000002?dOh0blWH0<_9f0<0^=7]103A`<X20<c8eP@0dK[30P3C_lL3
0<2bc0@0ck[60P2Y^ND30:bag0D0ZKgX00<000000?ooo`3oool0@`3oool005<0oooo0`0000000`2_
an`000000:o7k0020:o7k080/LGY3P2Y_NP40:Vfh`@0Y:3A102MT<D409>4_`D0Vj;J1@2Q[^020:Fg
iPD0Tnce0`22jNMI0:Vmj0D0RJo_0P0FR>P308oAoP030000002?dOh0^=7]00D0^=7]0P3A`<X30<c8
eP<0dK[3103C_lL00`30//`0ck[60<njaP030<njaPH0[;7L1@2Y_NP00`000000oooo0?ooo`120?oo
o`00D@3oool2000000@0Z/7[102_an`A0:Vmj0@0ZKKS102TX=4309f@a@D0UIKB1@2KX]X40:6^h0<0
Tnce0`1li]YN0:Vmj080RJo_0`2Y_NP305BAk@0404Zbn@000000B[;i04Zbn@D0^=7]1P3<b=H00`3A
^/<0dko70=>oa`030=>oa`H0ck[600<0f<330:bag02//M`00`2//M`50:Vmj0030000003oool0oooo
0480oooo001>0?ooo`<0000000<0Y[gZ0:[1j`2Z`N/0102Z`N/50:boj0l0ZKgX102Y]^<40:BPd@@0
Shc;1@2EU]8509^RfP80XJkP0P2MjoX308G[g0<0]L[ZH`2Y_NP305BAk@040000000JTNT06Y7Y01ZA
j@D0Sl_l1@3<b=H50=>oa`80dLG>103?^/H30=S0``80[;7L0`2i^=T50:Vmj0030000003oool0oooo
0440oooo000I0?ooo`030?oOW01807@0_ooo0080oooo00D0oon?03D00000000001AO0<Coo`0Y0?oo
o`8000001@2V_NX30:[1j`<0[lGZ1@2/_nP:0:Vmj0D0W9K=1027P<@408Z3aP@0Shc;1@2EU]8409^R
fP80WN_j0`25jm`60;G:jV80ZKgX0`1DTNd00`0000006Y7Y01ZAj@0201ZAj@D0Sl_l0P3<b=H30;k=
i@<0dko70`3AaLh30<njaP@0f<331P2i^=T50:Vmj0030000003oool0oooo0400oooo000I0?ooo`0:
0?oOW01807@0_ooo0?ooo`3ooml0Ga@001AOa03oool0a5lD000eSbH0oooo0`0000020:Jkj@030000
002V_NX0Y[gZ00<0Y[gZ1P2_aNX20:boj0X0ZKgX0`2X/n0409bFc@@0Qh34102:PlH408n<b`D0UIKB
102Tho/309;`hP<0^m_`1@2eb^YS0:Vmj080RJo^00<0000008V_kP29[nh00`0>PN@408o;o0H0_/gU
00<0dko70=75cP3AaLh00`3AaLh00`3?^/H0f<330=S0``030=S0``030=[4a02i^=T0^KSI0080^KSI
0P33_]H40:Vmj0030000003oool0oooo00X0oooo00D0oono07@00000000004RL0=ooo`0a0?ooo`00
6@3oool02`3ogi`0B01d0;ooo`3oool0oono03D0=@2?ool0oooo0?o4G`0D03D0Sooo0280oooo00<0
Yk_X0000000000000P2W^nP50:Jkj@H0ZlC/102_aNX:0:Vmj0H0Z;?P0`2LU/d408N0a0D0RX?6102?
S</209FFdP@0Y]?g0`2Bl>860;_Kl6P0ZKgX0P29[nh010000000ZKgX0:Vmj00nQ>P200j1i0@0G;?l
1@2ncND60=75cPD0f<330`3Ja<@20;Vhf@@0`kkF102Y_NP00`000000oooo0?ooo`080?ooo`060?oo
g`2LB000B9cO0?ooo`3OW4P007Bo<@3oool000d0oooo00<0omnL04P0000000000`0000000`0007@0
_ooo0?ooo`030?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`051AO0<Coo`3oool0oon?03D0501Oa?l0
803oool3000000D0Yk_X0P2V^nT30:Rmj@H0ZlC/3P2Y_NP50:Rch0@0W9K=1027P<@408Z3aP@0Shc;
102VdoL309odj`<0_>oc0`2kfo1/0:Vmj0040000002Y_NP0ZKgX0:Vmj080?XCX1@1L/o`50:K9lP@0
dLG>0P3;b=L30=S0``@0f/C41P33_]H40:Vmj0030000003oool0oooo00P0oooo00L0oono07@0M02o
ool0oooo0?oOW01807@0_ooo0300oooo000I0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@001AO0<Co
o`3oool0oon?03D0501Oa?l07P3oool3000000<0Z;cX102W^nP60:Rmj@<0ZlC/0`2Z_NP>0:Vmj0D0
Z;?P0`2LU/d408N0a0@0RX?61P2P_Nd309odj`H0_>ocKP2Y_NP010000000ZKgX0:Vmj02Y_NP403j4
j0@0=Y[b1@2VbO820=75cP@0blSG00<0f<330=[4a03Ja<@00`3Ja<@00`3KalH0`kkF0<>neP020<>n
eP80bL?D102Y_NP00`000000oooo0?ooo`070?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cO
o`0`0?ooo`006@3oool02`3ogi`0B01d0;ooo`3oool0omnL01@DG`34ool0oooo0?ooS`0e01@0GlCo
01/0oooo0`0000020:Rmj0D0Z;cX1@2W^nL50:Rmj@H0Z[gX3P2Y_NP40:Rch0<0W9K=1027P<@509NU
g`<0X;g]102Zl_@30:ciig80ZKgX00<000000:Vmj02Y_NP00P2Y_NP406ZNk`808XS[0P0fV_840:K9
lPH0blSG1@3Ja<@20=_7aP80`kkF1039`m@50:Vmj0030000003oool0oooo00H0oooo00L0okmd0018
W03Oool0oooo0?oo_`1d04P0W=oo0300oooo000G0?ooo`0=0;md000004P0W;nL04P0M02oool0oooo
0?oo_`0e03D0Sooo0?ooo`3oa5l0500e08ooo`0I0?ooo`80000000<0ZKgX0:Rmj02X_NP00`2X_NP:
0:Nki`D0[l?Y1@2Z_NP:0:Vmj0D0VIO@1020O<D308B2b@@0S97C1@2GYMl50:[bm0<0[?WWL`2Y_NP0
0`000000ZKgX0:Vmj0030:Vmj0@0JYk_0`0RR>/508Rnn0@0blSG0P33b=l30=[4a0<0flO61P39`m@5
0:Vmj0030000003oool0oooo00H0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo0300oooo
000H0?ooo`0;0?noM0000000001d0;ooo`3oool0oooO05lD000eSol0oooo0<AO5000=Hl05`3oool3
000000@0ZKgX0P2X_NP30:Rki`L0Yk_W0`2Z_nT50:o3j@X0ZKgX1@2Y_>L409VGd0@0P7c51024P/T4
08bAd`80UjGO1@2^iOT30:ciigD0ZKgX00<000000:Vmj02Y_NP00`2Y_NP508V_kP0301aoi`0RR>/0
8XS[00D0R;kh0P3;b=L40<?8g`030=[4a03KalH0flO60080flO600<0flW80<W3e039`m@00P39`m@2
0<k7d`D0ZKgX00<000000?ooo`3oool01@3oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
<03oool001T0oooo00<0omnL04P0M02oool00P3oool01@3oohl0=@000000000055l0a?oo01@0oooo
0`0000000`2Y_NP000000:Vmj0040:Vmj0H0Z;_W102W^nL60:Zoj@<0[l?Y302Y_NP50:Vli`<0VIO@
1@20O<D308B2b@@0S97C1@2^iOT30;7ij0<0aM_YM02Y_NP00`000000ZKgX0:Vmj0040:Vmj0D0RJo^
0P0LOnL508Rnn0H0`lSO103KalH30=_9b080bL?D103>am<50:Vmj0030000003oool0oooo00@0oooo
00H0oooO09a8001d_ol0oooo0=nLB000M;la0?ooo`00=03oool00`2Y_NP00000000000070:Vmj0@0
ZKcX1P2X^nL50:Nki`D0Z[oY3`2Y_NP50:Vli`<0VIO@1020O<D408B2b@80S97C102Xc?<30;7ij0H0
aM_YL`2Y_NP00`000000ZKgX0:Vmj0050:Vmj0D0W[S[00<08GcV01aoi`1][_P0101][_P30<?8g`<0
^LKU0`3KalH30=_9b0D0c/OC0P3Abm@40:Vmj0030000003oool0oooo00D0oooo00D0oono07@00000
000004RL0=ooo`0a0?ooo`00<P3oool3000000X0ZKgX102Y_>P30:Rki`P0Yk_W1@2^`^P?0:Vmj0@0
ZKcW0`2IUm04081la@@0Q8;91@2Xc?<30;Sgl080aOS/0`35fnUe0:Vmj0030000002Y_NP0ZKgX00H0
ZKgX1@2N^>/2025liPD0KJkh1P2ia^D00`3KalH0flW80=_9b0020=_9b0040=_;b@3>am<0c/OC0<k7
d`@0dL_D102Y_NP00`000000oooo0?ooo`0j0?ooo`00<03oool2000000030:Vmj0000000ZKgX00/0
ZKgX102Y_>P80:Nki`<0[<7Y1@2^`^P:0:Vmj0D0YZ[J101iNLL207anbPD0R93E102H[>@30:S<l`<0
^?O`1035n>af0:Vmj08000002@2Y_NP209jhj`<0ZKgX00<0=GgV025liP1IX?@0101IX?@50;W6i@@0
flW80`3KblT00`3>am<0dL_D0=7;e0030=7;e0D0ZKgX00<000000?ooo`3oool0>@3oool002`0oooo
00@0ZKgX0000000000000000402Y_NP60:Rki`@0Yk_W1P2/`NT30:k2j0`0ZKgX102VZ]X407Uia`<0
O7k:1028T=D509R/i0<0^?O`0P35n>ag0:Vmj0<000000P2Y_NP00`000000ZKgX0:Vmj00<0:Vmj080
=GgV101IX?@30;W6i@<0[l?X0P3KbLP40=_;b@D0dL_D0P3BcMD40:Vmj0030000003oool0oooo03T0
oooo000[0?ooo`800000402Y_NP40:Vlj0H0Z;_W1@2X_>P50:c1j@l0ZKgX102VZ]X307Uia`@0O7k:
1028T=D209R/i0@0]nSf0P32nnT20<GKjG<0ZKgX0`0000050:Vmj0030000002Y_NP0ZKgX00`0ZKgX
0`0eONH304jFl@H0[l?X00<0flW80=_;b@3KblT00`3KblT0103Kc</0dL_D0=7;e03Abm@30=;=e@D0
ZKgX00<000000?ooo`3oool0>03oool002T0oooo0P00000C0:Vmj0@0ZKcX0`2X^nL30:Nji`D0Z;cX
1@2/`>P?0:Vmj0<0YZ[J101iNLL407anbP<0R93E1@2gj?H00`32nnT0aM_Y0<GKj@030<GKjFl0ZKgX
0`0000090:Vmj0030000002Y_NP0ZKgX00`0ZKgX0`14QnT304jFl@D0[l?X1@3KblT30=_<b`030=7;
e03BcMD0d/gE0080d/gE1P2Y_NP00`000000oooo0?ooo`0g0?ooo`007@3oool01@3ookl0M0000000
0000B9`0gooo00L0oooo0P00000D0:Vmj0@0ZKcX1P2W^^L20:Rlj0<0[/;Y1@2/`>P>0:Vmj0<0YZ[J
101iNLL407anbPH0Z/[a0P33m>l20<_jiPD0aM_YK02Y_NP2000000d0ZKgX00<000000:Vmj02Y_NP0
2`2Y_NP404B7j@<0BXo^1@2X_nX30=_;b@@0flc;103BcMD20=7@f0D0ZKgX00<000000?ooo`3oool0
=`3oool001`0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l70?ooo`030000003oool0000001<0
ZKgX1P2X^nL40:Nji`H0[/;Y0`2/`>P<0:Vmj0@0SiKF0`1bMlT307f6d@D0TjCQ0`2Zb_430<?dk`@0
bo[VK@2Y_NP300000100ZKgX00<000000:Vmj02Y_NP02P2Y_NP504B7j@<0BXo^1@2X_nX00`3KblT0
flc;0=_<b`020=_<b`80g<k;0P3BcMD40=7@f0D0ZKgX00<000000?ooo`3oool0=P3oool001`0oooo
00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0oooo0P0000020?ooo`030000002Y_NP0ZKgX
00d0ZKgX102X_>P60:Rki`D0Z;cX1@2^`^T>0:Vmj0@0SiKF101bMlT307f6d@D0TjCQ0`33m>l20<_j
iPD0[<3X?@2Y_NP50:Vji@D0ZKgX1@2Y^^DM0:Vmj0<000004`2Y_NP00`000000ZKgX0:Vmj00;0:Vm
j0@0Bhc[101:Snh40:RojP@0flc;103Lc//40=7@f080cm?L1@2Y_NP00`000000oooo0?ooo`0e0?oo
o`00703oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01@3oool00`000000oooo0?ooo`02
0?ooo`030000002Y_NP0ZKgX00d0ZKgX102X_>P30:Rki`<0Yk_W1@2X_>P50:^oj0h0ZKgX102?U]H3
079gb@@0OHKA0P2CY>440;[NlP<0c?OY00<0e>gU0:c0j02/`>P00`2/`>Pj0:Vmj0<0ZKOS1@2Y^^D5
0:Vdh@D0ZK[U1@2Y^>@D0:Vmj0<000005`2Y_NP00`000000ZKgX0:Vmj00;0:Vmj0@0Bhc[0`1<S>/5
0:Flj@80flc;1@3Lc//00`3Md</0dM3H0=7@f0040<oCg0@0ZKgX00<000000?ooo`3oool0=@3oool0
01`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<000000?ooo`3oool00`3o
ool@0:Vmj0@0Z;cX1P2W^nL20:Rlj0<0[l?X1@2[_nP=0:Vmj0@0SiKF101bMlT307f6d@D0^]kb0`3<
mnT30=C]i@D0[<3X=`2Y_NP60:Vgh`80ZK[U0`2/]Ml50:Vdh@80ZK[U0`2/]^050:Vhi0D0ZK[U2`2Y
_NP3000001/0ZKgX00<000000:Vmj02Y_NP02`2Y_NP304^<j`@0C8c[1@2U_>T50=c>b`80gM3;1P3?
dm`50:Vmj0030000003oool0oooo03@0oooo000L0?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`050?ooo`8000001@3oool00`000000ZKgX0:Vmj00<0:Vmj0H0Z;_W102W^nL60:o3j0<0ZkoX
302Y_NP307f8e0<0KWO<101bMlT60:2hj@@0c?OY1@3DkNDg0:Vmj0D0ZKKR1@2Y]n<60:beg`@0ZKCQ
1P2/]^020:Vhi0<0[[SQ1@2Y^^D70:Vmj0<000007`2Y_NP00`000000ZKgX0:Vmj00;0:Vmj0<0Bhc[
0P1@RnT204b<j`80YKcY0`2U^^P30=c>b`<0gM3;00<0gm;;0<oCg03?dm`00P3?dm`20<WFh`D0ZKgX
00<000000?ooo`3oool0<`3oool001`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000ZKgX0:Vmj0080:Vmj0D0Z;cX1@2X^nL50:Rlj0D0
[l?X3P2Y_NP407f8e0<0KWO<1022T=P40:2hj@@0aNO_0P3DkNDg0:Vmj0X0ZKKR2P2/]Ml50:ngg`D0
[;KP1P2^^>440:Vji@@0ZKgX0`00000R0:Vmj0030000002Y_NP0ZKgX00/0ZKgX101;S>/3052;j@H0
YK[X00@0g<k;0=g@b`3Md</0gM3;0`3Od//20<oCg0@0bMKS102Y_NP00`000000oooo0?ooo`0c0?oo
o`00703oool01P3ooml0W4P007Boo`3oool0gia8001d_`H0oooo00<000000?ooo`3oool01`3oool:
0:Vmj0D0Z;cX1@2W^nL50:Rlj0D0ZkoX3P2Y_NP307f8e0<0KWO<1@22T=P20:2hj@@0aNO_0P3CmND2
0<cSj3D0ZKgX0P2Y]n<70:VfhP<0Z[CP1`2/]Ml30:fgh0D0[kOO0P2/]^030;2ih0D0[[SQ1@2]^N83
000002H0ZKgX00<000000:Vmj02Y_NP02`2Y_NP304B7j@@0D8_Y1@2U^^P30=g@b`@0gm;;1@39e^<2
0;oFj`@0ZKgX00<000000?ooo`3oool0<P3oool001d0oooo00D0oono07@00000000004RL0=ooo`06
0?ooo`030000003oool0oooo00P0oooo2P2Y_NP30:Rlj080Z;_X1@2W^nL20:Rlj0<0[l;X1@2[_nP=
0:Vmj0@0OHSD0`1^Ml`408:@f0D0aNO_0P3CmND40<cSj380ZKgX1@2Y]n<40:VfhPH0Z[CP102/]Ml6
0:fgh0@0[kOO1P2`^N020:jhh@<0/[_P0P2]^N82000000030:fihP2Y^^D0ZK[U00<0ZK[U902Y_NP0
0`000000ZKgX0:Vmj00;0:Vmj0<0A8OY101HS>P50:RkiP030=g@b`3Od//0gm;;0080gm;;0P3Re//3
0<WFh`<0_mK[102Y_NP00`000000oooo0?ooo`0b0?ooo`009`3oool00`000000oooo0?ooo`0:0?oo
o`X0ZKgX1@2X^nP40:Nki`H0[l;X0P2[_nP=0:Vmj080LX;D101mR=@306igc0L0[<C/0P3CmND70<cS
j2d0ZKgX1@2Y^^D40:Vgh`D0ZKCQ1@2Z]>050:bgh@D0[KOP1@2_^N450;2ih0@0/[_P0`000000102]
^N80/[cQ0;:lh@2b_>450:VjiB<0ZKgX00<000000:Vmj02Y_NP0302Y_NP00`15ON80A8OY04B7j@04
05R<j0@0Z;_V103Od//40>;Fb`D0_mK[1@2Y_NP00`000000oooo0?ooo`0a0?ooo`009`3oool00`00
0000oooo0?ooo`0;0?ooo`D0ZKgX1@2Y_>P50:Rkj0D0Z;cW102_`^P?0:Vmj0<0LX;D101YMlh308JG
g0D0[<C/0P3<jNX40=SbhS80ZKgX1@2Y^^D40:Nch@D0ZKCQ0P2Z]>030:ZfhPD0[;OQ0P2]]n030:fi
hPD0[kWQ1@2`^^4300000080/[_P1P2b_>420:Vji@<0[K_T8`2Y_NP00`000000ZKgX0:Vmj00<0:Vm
j080AGgR101HS>P20:RkiP<0[kgT0P3Od//40>;Fb`80iM_;1@2^a>X50:Vmj0030000003oool0oooo
0300oooo000W0?ooo`030000003oool0oooo00`0oooo1@2Y_NP50:Vlj0D0Yk_X1@2X_>L50:c0j0h0
ZKgX0`1bP]@306UgcP@0QYOL0`2/a>`20<cYjP@0f?;R0P39gnTb0:Vmj080ZK[U0`2V/^840:Nch@@0
ZKCQ1P2Z]^840:bgh@H0[KWR0P2_^N430:jjhP050;2jh@00000000000000002`^^401@2b_>850;:l
h@H0[K_T8`2Y_NP00`000000ZKgX0:Vmj00;0:Vmj0<0AGgR0`1SSnL60:nmi0@0h]K;0`3Ufl/00`3W
hL`0[/CZ0:k4jP030:k4jP@0ZKgX00<000000?ooo`3oool0<03oool002L0oooo0P00000>0?ooo`D0
ZKgX0`2Y_>P20:Rlj0D0Yk_X0P2X_>L30:k0i`D0[<3X3@2Y_NP407:2e0<0JGO>1026Um`20<cYjPD0
f?;R1039gnTa0:Vmj0H0Y[;R102W/n440:VfhPD0Z[KR1@2/^>850:fihP<0[[[R0`0000020;2jh@<0
/;cS1@2b_>850;>nhPD0[K_T902Y_NP00`000000ZKgX0:Vmj0050:Vmj0H0W[S[00<0BgcP04EmhP15
ON800`1SSnL30:nmi0<0^<;R0P3Re//30>GKb`<0in7<0P2^a>X70:Vmj0030000003oool0oooo02l0
oooo000W0?ooo`030000003oool0oooo00h0oooo1@2Y_NP50:Rlj0@0Yk_X1P2^`>L?0:Vmj0<0KhKI
0`1TM/l306UgcPD0/lW[103@inL60<WOjBd0ZKgX1@2U/n850:JbhPD0YkGS102Y]^830:ZfhP80Z[SS
1@2/^>840:fjh`<000000`2^^^860;2lh`80/[cR0`2a_N<50;>nhPD0/;kT8`2Y_NP00`000000ZKgX
0:Vmj0060:Vmj0D0W[S[0`1;O>0406>?i`H0^<;R0`3Ufl/40>OQc0X0ZKgX00<000000?ooo`3oool0
;P3oool002L0oooo00<000000?ooo`3oool03`3oool50:Vli`D0Z;cX1@2W^nL30:k0i`80[/;X3P2Y
_NP306n6f@@0I7K?1028V]h20;?9j`@0d>OW103Jk^0/0:Vmj0D0ZK[U1@2U/n820:JbhP<0Y[CS1@2W
]N<40:VfhPD0Z[SS0P2/^>830:bjh`<000000P2]^^<20:jjhP<0[[cS1@2`_><60;6mh`80/kkR0`2c
_n<50;2ni2<0ZKgX00<000000:Vmj02Y_NP01P2Y_NP409jhj`@0BgcP101`UNH40;S2hP80`/SN00<0
iM_;0>OQc03WhL`00P3WhL`20>7Xe`T0ZKgX00<000000?ooo`3oool0;P3oool002L0oooo0P00000A
0?ooo`030000002Y_>L0ZKcW0080ZKcW1@2W^nP50:Nki`D0[/;X3P2Y_NP306n6f@<0I7K?1@28V]h4
0=3Wi`@0f^kP0P3<hnP/0:Vmj0D0ZK[U102U/n860:Jdh`@0YkGS1@2Y]n<40:Zhh`80[;[S0`000000
0`2/^^<0[K[S0:fjh`020:fjh`H0[[cS0P2`_><30;2mi0D0/KgS1P2c_n<20;2ni0<0//3U8`2Y_NP0
0`000000ZKgX0:Vmj0060:Vmj0@0RJo^0P1DO]h204]lh0@0L9GV0P2h`^830<;8gP@0in7<0`3Qj=L:
0:Vmj0030000003oool0oooo02d0oooo000V0?ooo`8000004`3oool00`000000Z;_W0:Rki`020:Rk
i`D0Yk_X1@2/_^L50:k2j0d0ZKgX0`1_Q]T406Afc`80R9[N102db>T50=[^h0@0c>?X;02Y_NP40:Vj
i@D0Y;?S1@2V]><50:Rgi0D0ZKOS0P2[^N@3000000@0[;[S1@2]^n@50:jlh`H0/;gT0P2a_N<30;6o
i0D0/koS1@2b`>DT0:Vmj0030000002Y_NP0ZKgX00H0ZKgX1029[nh305AngP@0L9GV1032b=h20<kA
f`80in7<0`3Qj=L20=3/j0X0ZKgX00<000000?ooo`3oool0;03oool000T0oooo00X0oono07@00000
000004RL0=ooo`3oool0omnL04P0M02oool0gia81@0000000`1d_ol0oooo0=nLB002000000030000
B02Lgol0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000Z;_W0:Rki`020:Rki`<0Yk_X
0P2W^nL50:bni`l0ZKgX0`1fUN<205]ad0@0I7K?1@2db>T40=7Ri0@0c>?X;`2Y_NP40:>bi0D0Y;?S
1@2V]^@50:Rgi080ZKOS0P2Y^N@2000000<0ZkWT0`2/^^<20:bki@D0[K_T1@2^_N@50;2mi0H0/KoT
0P2c_n<30;?1i0@0//3U902Y_NP00`000000ZKgX0:Vmj0060:Vmj0@0RJo^101DO]h4082Mi@80`/SN
103>dM/30>7Xe`@0d>cX2@2Y_NP00`000000oooo0?ooo`0:0?ooo`050=nLB000000000000000B02L
gol07@3oool000P0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l40?ooo`030?oOW0180000M;oo
00@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0503o
ool00`000000Z;_W0:Rki`020:Rki`D0Yk_W0`2/_^L20:o3j0l0ZKgX0P1fUN<305]ad0@0Q9ON0`2d
b>T40=7Ri0<0fnWM;@2Y_NP50:Fgi@@0Xk;T0P2T/n<30:Fei@D0Y[KT102X]n@0102Y^N@000000000
000000020:Vii0@0ZkWT1@2/^nD20:fki0<0[KcU1@2^_N@50;2ni0D0/KoT1P2c`N@40;;2iR@0ZKgX
00<000000:Vmj02Y_NP01P2Y_NP406ZNk`030623gP1DO]h0E7kN00D0P9gU103>dM/30=[Kf0D0d>cX
2P2Y_NP00`000000oooo0?ooo`080?ooo`070?noM000B9`0gooo0?ooo`3ooml0W4Qd0;ooo`0L0?oo
o`00203oool01`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0103oool00`3ogi`0B00007Boo`08
0?ooo`030;md001d_ol0oooo00D0oooo0P00000F0?ooo`D0Z;_W1@2W^nL50:o3j0h0ZKgX0`1fUN<3
05]ad0@0Q9ON1@3Ah^@30=_Yg@<0eN[S;02Y_NP50:Fgi@<0Xk;T1P2U]ND40:Jfi080Z;SU0`000005
0:Vii0D0Zk[U102/^nD60:fli@80[[gT0`2^_^D50;2ni0D0//3U0`2c`N@30;C2i@@0//;V902Y_NP0
0`000000ZKgX0:Vmj0060:Vmj0<0JYk_0`1PPmh609:Wi080c]7K0`3JfmP20>?Te0D0//W[2P2Y_NP0
0`000000oooo0?ooo`0<0?ooo`030;md001d_ol0oooo01/0oooo00080?ooo`070?oOW018B9`0gooo
0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d0000B9cO00L0oooo00<0_g@007Boo`3oool01@3o
ool00`000000oooo0?ooo`0G0?ooo`@0Z;_W1@2Z_>H50:o3j0/0ZKgX0`28/O400`1>Jm00MYGS05]a
d00305]ad080Q9ON102``NH40=_Yg@D0eN[S;02Y_NP40:Fgi@D0XkCU102U]ND30:Jhi@<00000102X
^>D50:Vji@D0Zk[U102/_>D50:fli@H0[[kU0P2`_^@30;2oi@D0//3U1P2d`^D20;;2iP80/<?W8`2Y
_NP00`000000ZKgX0:Vmj0070:Vmj00305eof`1ZW^l0JYk_00<0H8?N1@2BYn@0103>dM/0f]_H0=[K
f03JfmP30>?Te0030>O]d@2bbN/0//W[00<0//W[2@2Y_NP00`000000oooo0?ooo`0<0?ooo`030;md
001d_ol0oooo01/0oooo00080?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`0;
0?oog`2LB000B9cO0?ooo`3ogi`0B01809cOo`3oool0oooO09a8B02Lgol01P3oool00`000000oooo
0?ooo`0H0?ooo`D0Z;[V102Z_>H50:Zmj0/0ZKgX0P28/O4204i[d0@0Fg7@1@2``NH40<kJhP80eN[S
1@2/`>P[0:Vmj0D0XK?U1@2S]>D30:FgiP<000000`2V^>D50:RjiPD0ZK[U1@2[_>H40:bli@D0[KgV
1@2^_^D60;2oi@80//3U0`2b`NH50;C2i@D0/<?W8`2Y_NP00`000000ZKgX0:Vmj0060:Vmj0<0GGoK
101PPmh409:Wi0<0f]_H0`3Si=@30>O]d@h0ZKgX00<000000?ooo`3oool01P3oool01`3ogi`0B018
09cOo`3oool0oooO09a8B02Lgol0703oool000P0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0
W=oo00L0oooo00D0oono07@0B02Lgol0oono07@000030000000307Boo`3oool0oooo00@0oooo0P00
000K0?ooo`D0Z;[V1@2a`>D40:Zmj0X0ZKgX0`28/O4204i[d0@0NHoL0`2``NH40<kJhP80f^;L0P3M
hmT50:c0j2H0ZKgX1@2T^>L50:6ci@@0XkKV0`0000020:FgiP80Y[SU0`2W^NH50:RjiP80ZK[U0`2Y
^nH50:^liP80[;cU0P2/_NH50:fmiPD0[[oV1@2`_nD60;;1iPD0]<CV0P2``nL30:g2jB<0ZKgX00<0
00000:Vmj02Y_NP01P2Y_NP305eof`<0Kh_N1P2W]N<30>?Te0<0ingA0P3Hm>8>0:Vmj0030000003o
ool0oooo00D0oooo00<0oono07@0000000000P0000000`1d_ol0oooo0?ooo`0K0?ooo`00203oool0
1`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`050;md
001d_ol0oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0K0?ooo`80Z;[V0`2Z^nH50;70i@T0
ZKgX1@2X_NP2049Wd@<0CV_@101iSm`50<kJhP80f^;L103MhmT20:c0j2X0ZKgX102T^>L50:6eiP<0
00000P2S]^H30:FgiPH0YkWV102X^^H60:VkiP@0ZkcV1@2/_NH30:fmiP80[KkW1@2^_nH50;31iP<0
//7V0`2b`nH40;C4iPH0[L;Y8`2Y_NP00`000000ZKgX0:Vmj0050:Vmj0@0GGoK0`1_Rmh40:Neh`80
_LKQ00@0hnCD0>O]d@3WkM40ingA0`3Hm>8:0:Vmj0@0XkSX00<000000?ooo`3oool01@3oool00`3o
oml0W4Q809cOo`0P0?ooo`00203oool01P3ooml0W4P007Boo`3oool0gia8001d_`@0oooo00X0oono
07@0B02Lgol0oooo0?oOW01804P0W=oo0?ooo`2oM000M;oo2@3oool00`000000oooo0?ooo`0K0?oo
o`H0Z[_V0P2a`>D30;73j0X0ZKgX0`2X_NP3049Wd@<0IX7I1P2U]^D30=[Rg0D0gN?I;@2Y_NP409nd
i`050:6eiP00000000000000002Q]NH0102S]^H50:Fhi`@0YkWV1@2X^nL50:VkiPD0ZkgW1@2/_NH5
0:fni`80[[oV0`2^`>L50;31iPH0//?V0P2da>H20;C5i`D0[L;Y8`2Y_NP010000000ZKgX0:Vmj02Y
_NP508V_kP<0HgoH101_Rmh20:Neh`<0_LKQ0`3WkM440=SdhP/0ZKgX102S^>P00`000000oooo0?oo
o`050?ooo`030;md001d_ol0oooo01l0oooo00090?ooo`050?oo_`1d000000000018W03Oool01@3o
ool01@3ogi`0B000000000000000M;oo0080oooo00H0gia800000000000000000000M02oool50?oo
o`030000003oool0oooo01d0oooo102Z^nH60;73j0X0ZKgX0`2X_NP3049Wd@<0IX7I102U]^D30<K@
hPD0gN?I0`35fnTW0:Vmj0D0YKcY0P2O]>L2000000@0XKGV1@2T^>L50:Fhi`@0Yk[W1@2X^nL50:Vl
i`D0ZkgW1@2/_^L40:fni`H0[/3W1@2``^L50;;3iPD0]<GW:02Y_NP010000000ZKgX0:Vmj02Y_NP4
08V_kP@0HgoH0`22Uml40;g6h@<0dMSN00<0f?CR0;K?k@2fcnd00`2fcnd:0:Vmj0@0XkSX00<00000
0?ooo`3oool01@3oool01P3OW4P00000000000000000001d0;oooa`0oooo000U0?ooo`8000007`3o
ool50:jniP@0/L?X2`2Y_NP205fBj`@0@VOA0`1VPMT20:Ffi@@0a]3R0`3Ff]/60<GKjBL0ZKgX0`2U
_>T300000080WkCW1@2R]nL50:Bhi`D0YK[W102W^^L50:Rlj0D0ZKcW1@2[_^L50:bni`@0[KoW0`2^
`>L30:o1j0D0/<;W1@2ba>L30;C5i`80]<OX:02Y_NP010000000ZKgX0:Vmj02Y_NP306b8g@@0HgoH
1022Uml20;g6h@<0dMSN0P3QjMP00`3Wm=80]/o]0;K?k@030;K?k@T0ZKgX1@2P]>H00`000000oooo
0?ooo`0V0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`D0[[kV1@2/_nP:0:Vmj080GI;[0`1=
LMH306J1f@D0a]3R0`3Ff]/30=cMeR/0ZKgX0`0000020:Flj@@0WkKX1@2R]nL50:Bij0D0YK[W0P2W
^^L20:Nkj0D0Z;cX0P2Y_>L30:Vmj0D0ZkkW1@2/_nP40:foi`H0[l7X0P2``^L30;34j0D0//CW1@2d
anPW0:Vmj0040000002Y_NP0ZKgX0:Vmj0@0K8SM00<0L8GI06=of01SOmP01@22Uml30=7HgP80hNWH
0`3Wm=890:Vmj0D0Z;cX1@2P]>H00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?oo
o`0P0?ooo`80[[kV0`2ca>H50:boj0T0ZKgX0`1MT^/304eaeP@0TJGS0P36d>830=KJf`@0g=gF00<0
fMgI0:Vmj02Y_NP09@2Y_NP3000000030:Vmj02N]^T0W[KY00<0W[KY102O]^P50::hj0D0Y;WX102U
^^L50:Nkj0@0Z;cX1P2Y_NP20:^ni`<0ZkoX102/_nP50:g1j0D0[l7X1P2`a>P50;?6j080]<OX0`2]
`^TW0:Vmj0040000002Y_NP0ZKgX0:Vmj0<0K8SM0`1`QMT609ZYh@040=7HgP3QjMP0hNWH0>7Yf080
ioCB0P3Ann<90:Vmj0D0Z;cX102U^^P00`000000oooo0?ooo`0U0?ooo`00903oool200000280oooo
1P2ca>H:0:Vmj0@0V[W]00<0<f?C05fBj`1MT^/00P1=LMH5096Uh`<0e][K103LgMH30=WMfB<0ZKgX
0`0000050:Vmj0D0W[KY102O]nT50::hj0@0Y;WX1@2V^nP40:Nkj0D0Z;gX1@2Y_NP60:^oj080[;oX
0P2/`>T50:g1j0D0[l?Y0`2`a>P30;75j@@0/lKX1P2]`^TW0:Vmj0030000002Y_NP0ZKgX00@0K8SM
0`1`QMT509ZYh@<0hNWH0P3Wm=840=7kh`T0ZKgX1@2R^^T40:Fjj0030000003oool0oooo02@0oooo
000T0?ooo`030000003oool0oooo02<0oooo0`2ca>H20;75j@X0ZKgX102J^Nd203=Sd`<0CG7F0P2A
YN<40;K1hP@0g=gF1@3IgMTO0:Vmj0<000002@2Y_NP509ffjP@0WkOY102R^>P50:Bjj@D0Y[_X1@2W
_>T40:Rmj0D0ZKkY1@2[_nP50:c0j@80[L7X0`2]`^T50:o3j@H0/LGY102cb>X50:g2jBL0ZKgX00@0
Rjg]0000002;[Nd0Rjg]0`1/Om@40725f@H0]/;S00<0ioCB0=7kh`3Ann<0103Ann<:0:Vmj0D0X[[Y
102U^^P00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0T0?ooo`D0/LGY2P2Y
_NP409Zik@80<f?C0P1`SMl50;K1hP@0c<oL103IgMT30<GKjA/0ZKgX0`0000090:Vmj0@0YKcY1@2M
]^X409ngj@@0X[[Y1@2T^^T50:Jlj@D0YkcY102X_^T50:Vnj@D0Zl3Y102/`>T60:g2j@D0[lCZ0`2a
aNT30;77jP@0/lSZ;02Y_NP00`000000Rjg]08^]k@0406aoe0@0PY?K102f`^<0103AgN40h_?H0>;c
f03RlmP50:^nj0X0ZKgX102R^^T40:Rnj@030000003oool0oooo02<0oooo000T0?ooo`8000009P3o
ool50;75j@X0ZKgX0`1<SN`203=Sd`<0L8gO0`2f`N840<c?g0<0emCF1P35fnTG0:Vmj0<000003@2Y
_NP40:Flj@@0WKKZ1@2P^NX40::jj@D0Y;_Z1@2V_>T50:NnjP@0Z;kY1@2Y_nT50:_0j@@0[<;Y0`2]
`^T30:g4jPD0[lCZ1@2aanX50:o4jRT0ZKgX0`2W_>P00`000000Rjg]08^]k@0306aoe0D0PY?K0P2f
`^<0103AgN40h_?H0>;cf03RlmP20>;ld0@0ZkkX2P2Y_NP50::eiP@0Z;kY00<000000?ooo`3oool0
8P3oool002<0oooo0P00000X0?ooo`l0ZKgX0`1<SN`00`16L]T0<f?C072=g`02072=g`D0c<oL0`3G
e=H30=_EdQT0ZKgX0P00000A0:Vmj0<0YKcY1@2M^>/50:2ijP@0X[_[1@2T^nX50:JmjPD0YkkZ102X
_nX50:Voj@D0Zl7Z102/`^T60:g4jPD0[lK[0`2aanX20;;9k0D0[lCZ9P2Y_NP50:Nlj00306modP00
0000KgoB00@0K7oD1022Tm/20=7Mh@<0h_?H0`3Ro=0?0:Vmj0@0X[GV1@2Z`>T00`000000oooo0?oo
o`0Q0?ooo`003@3oool02`3ookl0M00000000000B9`0gooo0?ooo`3ogi`0B01d0;ooo`3oool0gia8
0080000000<0001809cOo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`h0ZKgX0P1<SN`204Ib
f@D0VJcT0P3<cm`30=ODeP@0fmGB00<0fmCA0:Vmj02Y_NP04`2Y_NP3000001<0ZKgX102R^n/509fh
j`D0X;[[102R^n/20:BkjP<0Y;g[1@2V_NX20:NnjP<0Yko[102X_nX50:W1j`D0Zl7Z102/`n/30:g4
jP<0[/G[1@2_a^/50;;9k080[lCZ:@2Y_NP50:Nlj00306modP000000KgoB00<0N8OF1@2LZn430>;c
f080h_c@0`31gnl>0:Vmj0D0Z;cX102Z`>T00`000000oooo0?ooo`0Q0?ooo`00303oool01P3ooml0
W4P004RLg`3oool0gia8001d_`@0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0oooo
00<000000?ooo`3oool0:P3oool90:Vmj0D0Wk[/00@08eoD04b=k016L]T0AW;I1@2I[>@30=ODeP@0
fmGB0`3Ke=4A0:Vmj0<000005`2Y_NP40::kj`D0WKW/1@2P^^/30::kj`H0Y;g[102V_NX60:Noj`80
Z;oZ0P2X`>/50:W1j`D0Zl?[102/`n/60:k5j`D0/<S/102bbN`[0:Vmj0D0YkcX00<0KgoB0000001_
Om80101hQmH309b[h@<0_LgV00<0h_c@0<7Ok`31gnl01031gnl90:Vmj0D0Y;OV1@2X_>P40:^oj@80
00008@3oool000`0oooo00L0oono07@0M02oool0oooo0?oOW01807@0_ooo00P0oooo00<0_g@007Bo
o`3oool01@3oool2000002`0oooo2P2Y_NP309njk0808eoD0`16L]T209V/i0@0^<3P103KeM850=_D
d@d0ZKgX0`00000K0:Vmj0D0Wk[[102M^N`40:2jj`@0X[c/1@2T_N/50:Fnj`D0Yko[1@2X`>/20:W1
j`<0ZL;/1@2[`n/40:c5k0<0[/G[0`2^b>d50;38k0@0[L;Y:`2Y_NP507j=f00307J2dP000000KgoB
00@0N8OF102mcNH20=W_h@040=kmd031gnl0`Mo_0<7Ok``0ZKgX1@2T]nH20:Rlj0<0[<3X102[_nT0
0`000000oooo0?ooo`0O0?ooo`00303oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol0203o
ool00`2oM000M;oo0?ooo`050?ooo`030000003oool0oooo02`0oooo2P2Y_NP309njk0808eoD0P1Z
SN850;S0h0@0bLWJ1@3Ke=420=7Df`T0ZKgX0`00000O0:Vmj0D0Wk[[102M^nd409nkk0@0X[c/1@2T
_^`50:Fnj`D0Yl3/102X`>/60:W2k0D0ZlC/102/aN`60:k8k@D0/<[]102]`^T[0:Vmj0@0OXgH0P1f
P]800`000000SI[L08fJg00308fJg080_LgV0P3Ikn430=kmd0l0ZKgX102T]nH50:c0j0@0Z[oX00<0
00000?ooo`3oool07`3oool000`0oooo00L0okmd0018W03Oool0oooo0?oo_`1d04P0W=oo00<0oooo
00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00H0oooo00<000000?ooo`3oool0;@3oool:0:Vm
j080HZ;c0`0SGm@306Z=hP80^<3P1039bMX20=;=e0<0fmCA103Ae=/50:Vmj0<000008`2Y_NP509nj
j`@0WK_]102O^n`50::mk@@0Y;k/1@2U`>`50:O0k0@0Z<;/0`2Y`^`30:W4k@D0ZlC/102/and30:k8
k@<0[/[^102`b^d_0:Vmj0@0OXgH0P1fP]800`000000MX;B08fJg00308fJg0<0fNoQ0P3NoM030<gd
j@h0ZKgX1@2W^^L20:c0j0<0[<3Y102Z_nP00`000000oooo0?ooo`0N0?ooo`00303oool01`3ogi`0
B4RL0=ooo`3oool0oono07@0B02Lgol00`3oool00`3ookl0M000000000020000000307Boo`3oool0
oooo00D0oooo00<000000?ooo`3oool0;P3oool:0:Vmj080HZ;c0P0_JMT406Z=hP@0bLWJ103BcM@4
0=7Df`<0a=7T00@0ZKgX00000000000000009`2Y_NP509njj`<0WK_]1@2O_Nh50::mk@@0Xko]1@2U
`>`50:K2k@@0Z<;/1P2Ya>d50:_6kP@0[<O]1P2^b^h_0:Vmj0@0RIKI00<0NH7?07j=f01nSMP00`1f
P]800`000000SI[L08fJg0040:fmiP030=kmd03=m>T0cOCY00<0cOCY2P2Y_NP50:Jii`@0Yk[W1P2/
`>T20:Zoj080Z[kX00<000000?ooo`3oool07@3oool000`0oooo00L0oono07@0M02oool0oooo0?oO
W01807@0_ooo00<0oooo00<0oooO09a8B02Lgol02@3oool200000340oooo2P2Y_NP0100=K=h0HZ;c
02mYf@0_JMT408nVi@80bLWJ103BcM@30=O=d0<0a=7T0`00000[0:Vmj0D0X[_[0`2L_>l509nmkPD0
XKo^102S_nd50:G1kPD0Y/;]102X`nd30:W4k@<0ZLK^102[a^h50:c9k`<0[/[^0`2]`^T^0:Vmj0@0
RIKI0`1iPLl407J2dP030000002]_NH0[KgV0080[KgV0P3?jNP20=SodPh0ZKgX102V^NL50:^oj0D0
[<3Y102Z_^P00`000000oooo0?ooo`0M0?ooo`00303oool01P3ooml0W4P007Boo`3oool0gia8001d
_`D0oooo00<0_g@007Boo`3oool0203oool00`000000oooo0?ooo`0a0?ooo`X0ZKgX00@03FcN02mY
f@0_JMT0;fWI102?Y^D40=;=e0@0elg@00<0f<c=0000000000000P34dN@30;G:jRX0ZKgX1@2R^n/3
09blk`D0Wkk_1@2Q_nh40:?1kPD0YL7^1@2V`nh40:S3k@H0ZLK^102[bNl50:c9k`H0[L;Y;P2Y_NP4
08VFf@<0NH7?1026TML00`000000[KgV0:fmiP020<oYj080f?oB0P3@o>8=0:Vmj0D0Y[SV2P2[_nP4
0:Znj0030000003oool0oooo01`0oooo000=0?ooo`050?oo_`1d000000000018W03Oool01@3oool0
1P3OW4P00000000000000000001d0;ooo`D0oooo00<000000?ooo`3oool0<P3oool90:Vmj0803FcN
0P19ON850:^ghP80d/gD0`3GcM0300000080f<c=1P2eb^XZ0:Vmj0@0X[_[102L_>l509nnk`D0XL7_
102S`Nh50:C3k`@0Y/?^1@2WaNl30:W6kP<0ZLS`102[bNl50:g5k0<0[L;Y<02Y_NP408VFf@@0NH7?
0`26TML010000000cnWX0<oYj03?jNP20=SodP<0d?cR2@2Y_NP50:Nki`D0Y[SV1@2/`>T40:^oj0D0
Z[gX00<000000?ooo`3oool06`3oool00280oooo0P00000d0?ooo`D0ZKgX102T_>X01000A/L03FcN
04UmhP19ON850:^ghP040=O=d00000000000000000@0f<c=0P3Hb/`30;G:jR`0ZKgX1@2U_>T409bl
k`D0W/3`1@2Q`Nl40:;3l0D0Y<?_102VaO050:O5k`H0ZLS`102[a^h50:g5k2l0ZKgX102>U]H307f2
c@@0NH7?102S/n@00`000000Xk?T0=SodP030=3lhP`0ZKgX1@2W^nL50:^oj0@0[<3Y1@2Z_^P40:Zm
j0030000003oool0oooo01/0oooo000R0?ooo`030000003oool0oooo03@0oooo1@2Y_NP40:BljP04
0016a`19ON80BGgR04UmhP80ZkOR0`0000020;g0g0@0f<c=103Hb/`_0:Vmj0D0YKcY102N^N`509k0
l0D0X<;a102R`o050:C5l@@0Y/G`1P2Wb?450:W6kP@0ZlK^=02Y_NP308jFeP@0OH;=1025S]@40:>c
i0030000003?om40cooA00l0ZKgX1@2U]nD90:^oj0D0Z[kX102Y_NP00`000000oooo0?ooo`0J0?oo
o`008P3oool00`000000oooo0?ooo`0e0?ooo`030000002Y_NP0ZKgX0080ZKgX102T_>X00`00A/L0
Ii?X00000002000000@0_L3L0P37a=L20=S<c@@0f<[<0P3Gal/d0:Vmj0@0W[W/1@2N_Nl50:32l@@0
XLGb1@2TaO440:G7l@<0YlSa0`2Wa>h50:W6kSL0ZKgX102>U]H407f2c@@0QHkD0P2S/n@00`38ind0
cooA000000020=3lhP`0ZKgX0`2X^nL40:Fgi@80ZkoX0`2/`>T50:^oj0D0Z[gX0`2Y_NP00`000000
oooo0?ooo`0<0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`040?oo
o`008P3oool00`000000oooo0?ooo`0g0?ooo`D0ZKgX00@0S;Ca00000000000000000`1WTnP30;g0
g0@0alCG103Hb/`40=O7bc@0ZKgX102U_>T509jmk`D0X;o_102QaO850:?6l@@0YLOa1P2Wa>hc0:Vm
j0D0ZK_V102<S]030863c0@0OH;=1025S]@20<SWk@80cooA00@000000=3lhP3@o>80d?cR2@2Y_NP6
0:Rki`<0YKOU1P2/`>T50:Znj0@0Z[gX102Y_NP2000000`0oooo00X0omnL04P0M02oool0oooo0?oo
g`2LB000B9cO0?ooo`3OW4P007Bo103oool00240oooo0P00000j0?ooo`80ZKgX0`00000308bdl@04
0013a01WTnP0Ii?X06NCj0D0alCG0P3=aM<20=S:c0D0elO;0P3CaL`c0:Vmj0@0YKcY1@2S^nX50:2o
k`@0X[k]1@2Sa_450:K0k3P0ZKgX102Y^nH408b>d0@0PH?<1027S]<409n`h`80cooA00<0d?cR0:Vm
j0000000302Y_NP50:Rki`@0Z[kX0`2/`>T30:^oj0@0Z[kX2@2Y_NP00`000000oooo0?ooo`0:0?oo
o`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool00`3oool00240oooo
00<000000?ooo`3oool0>03oool3000000@0ZKgX0`1_Z?@01000@l@0PZG[08:Uj`22YN/30<O4e`@0
cLGC1@3Gal/40=?5c3L0ZKgX1@2S^nX50:Flj@@0X[k]1@2U_>T30:K0k3X0ZKgX102Y^nH408b>d0<0
PH?<1@27S]<209n`h`80a>__00D0`_g90<gdj@3=m>T0ZKgX0000000<0:Vmj0D0YKOU102Z_^P50:^o
j080Z[kX0`2Z_NP80:Vmj0030000003oool0oooo00X0oooo00/0omnL04P0M02oool0oooo0?oOW018
B9`0gooo0?ooo`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0f0?ooo`800000
0`3oool50:Vmj0<0KjSd00@004?408:Uj`22YN/0PZG[1@3=aM<30=35d080elO;103CaL`20=73c3`0
ZKgX1@2U_>T40:Vmj0D0YKcY?02Y_NP40:VkiP@0S8k@1021Pl`408N>d`<0a>__00<0`_g90<gdj@3=
m>T00P3=m>T00`000000ZKgX0:Vmj0060:Vmj0D0Z;[V102U]nD50:c1j@@0ZkoX1P2Z_NP80:Vmj003
0000003oool0oooo00T0oooo00/0omnL04P0M02oool0oooo0?noM000B9`0gooo0?ooo`3ookl0M018
09cOo`030?ooo`008@3oool2000003@0oooo0`0000060?ooo`D0ZKgX0P1DVo<00`00AL@0UK7Z09Fa
jP0309FajP80cLGC1@3@aM040=?5c0@0dL?<P@2Y_NP50:JVeP@0Qh?80`25QL/40863c0D0XKCV00<0
`_g90<gdj@3=m>T01@2Y_NP00`000000ZKgX0:Vmj0060:Vmj0@0Z;[V1@2[_nP40:c1j@D0Z[kX1@2Z
_NP90:Vmj0030000003oool0oooo00P0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?oo
o`3ookl0M01809cOo`030?ooo`008@3oool00`000000oooo0?ooo`0`0?ooo`<000002@3oool60:Vm
j080E9_c00<004[709FajP2E/NX00`2E/NX50=35d080dLC>0P3CaL`40=73c080d<3;P@2Y_NP40:JV
eP@0Qh?81025QL/408^Be080XKCV0P32m>l0102`m[/0`Mo_0<7Ok`31gnl50:Vmj0030000002Y_NP0
ZKgX00D0ZKgX1@2V^>H50:^oj0@0ZkoY1@2Z_^P=0:Vmj0030000003oool0oooo00H0oooo00d0_g@0
0000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00<0oooo00040?oo
o`0=0?oo_`1d000000000018W03Oool0oooo0?oOW01807@0_ooo0?ooo`3ookl0M01809cOo`040?oo
o`050=nLB000000000000000B02Lgol01`3oool00`000000oooo0?ooo`0]0?ooo`<000003P3oool4
0:Vmj0<0E9_c00<004[70::hj02R^>P00`2R^>P30=35d0@0dLC>103A`l`40=30bh40ZKgX102VY]H4
08N3b0<0QHG;102;T]@30<;dk`H0`Mo_1@2Y_NP010000000ZKgX0:Vmj02Y_NP40:NiiPD0Y[SV1@2/
`NT40:^oj@D0Z[gX3@2Y_NP00`000000oooo0?ooo`060?ooo`0;0?noM0000000001d0;ooo`3oool0
oooO09a8001d_ol0oooo0=nLB000M;l0103oool000<0oooo00H0oooO09a80018W=l0oooo0=nLB000
M;l50?ooo`030?oog`2LB4P0W=oo00<0oooo00L0okmd0018W03Oool0oooo0?oog`2LB7@0_ooo00H0
oooo00<000000?ooo`3oool0:P3oool300000180oooo102Y_NP3042@k`03001>b000B/L0X[SX00<0
X[SX1@3Aa<h40=73c0@0d<3;0P3@_LV00:Vmj0@0YZKF1027PlP408F5b`80Ri;D0`2W`>`00`2io>@0
Wnf^0<7Ok`020<7Ok`L0ZKgX00<000000:Vmj02Y_NP00P2Y_NP40:NiiP80Y[SV0`2[_nT40:c1j@D0
Z[kX102Z_NP90:Vmj0<0000000<0oooo0000003oool0203oool00`3ogi`0B01d0;ooo`020?ooo`05
0?oo_`1d000000000018W03Oool0103oool000<0oooo00L0oono07@0M02oool0oooo0?oOW01807@0
_ooo00D0oooo00<0_g@004RLg`3oool01`3oool00`2oM000M;oo0?ooo`040?ooo`800000:@3oool3
000001H0oooo102Y_NP3042@k`8004k8102Z_>L30=74cP@0dL?<103@`</40=2mb@D0ZK?PL`2Y_NP4
0:RWeP@0Thg9102:QLL308Z:c@@0QHG;102W`>`0102io>@0Wnf^09o][P2OkJh:0:Vmj0040000002Y
_NP0ZKgX0:Vmj0@0YkWV1@2[_nT50:^oj0@0Z[kX2@2Y_NP3000000D0oooo00<000000?ooo`3oool0
5@3oool000<0oooo00L0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo00D0oooo00<0okmd0018W03O
ool01`3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0oooo02D0oooo0`00000J0?ooo`D0
ZKgX0P0fR^d2001>b0@0Z[cW1@3A`l`20=31c080d<3;103@_LT20=6la@D0ZK?PL`2Y_NP30:RWeP@0
Thg9102:QLL408Z:c@@0TY[H0P2W`>`00`2io>@0ZkkX0:^nj0030:^nj0X0ZKgX00<000000:Vmj02Y
_NP01@2W^^L20:^oj@<0Zl3Y1@2[_nP40:Zmj0D0ZKgX0`0000080?ooo`030000003oool0oooo01D0
oooo00030?ooo`070?noM000B9`0gooo0?ooo`3ookl0M01809cOo`050?ooo`030?oo_`1d04P0W=oo
0080oooo00L0omnL04P0B02Lgol0oooo0?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool08P3o
ool3000001h0oooo1@2Y_NP203J:k@04001>a`00C/P0Z[cW0:Zli`<0[[oV0P3A`l`40=31c0@0d;g9
103A_<D20:Vch0<0/K;ILP2Y_NP40:RWeP@0Thg9102:QLL308Z:c@@0TY[H0P2io>@20<okh`@0ZkkX
2@2Y_NP20:Jgi@030000002V]nD0Y[OU00@0Yk[W1P2[`>T50:Znj0@0Z[gX1000000<0?ooo`030000
003oool0oooo01@0oooo00030?ooo`070?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`060?ooo`06
0=nLB000M;l0oooo0?ooo`3ookl0M0000`0000000`1d_ol0oooo0?ooo`040?ooo`030000003oool0
oooo01l0oooo0`00000R0?ooo`D0ZKgX0P0fR^d00`00C/L0[[oV0:joiP040:joiPD0d<7<00<0cl7<
0=2mb@3@_LT01@3A_<D60;6bfG40ZKgX102XYmH409>=b@@0RXG70`2:R/d40:oHm@0309gb``3?nn<0
co_S0080co_S2@2Y_NP40:Vmi`030:Jgi@000000Y[OU0080Y[OU1`2[`>T30:^nj0@0Z[kX00@0oooo
0000000000000000403oool00`000000oooo0?ooo`0D0?ooo`000`3oool01`3ookl0M01d0;ooo`3o
ool0omnL04P0M02oool01P3oool01`3ookl0M01809cOo`3oool0oooO09a8B02Lgol02@3oool20000
01h0oooo0P00000V0?ooo`030000002Y_NP0ZKgX0080ZKgX0P0fR^d01000B/80[[oV0:joiP2^_nH3
0:k0i`<0d<7<0`3?`L`60=6la@030=2ja@2a/]T0/K;I0080/K;I0P2j/]5[0:Vmj0<0YY_;0`2DR<@4
0927aP<0Sh[:102:QLL509^[hP0309gb``3?nn<0co_S00h0ZKgX102Y_NL00`2Y_>L000000:Vli`02
0:Vli`@0Zl3Y1@2[_^P20?ooo`<000004`3oool00`000000oooo0?ooo`0D0?ooo`000`3oool01P3o
oml0W4P007Boo`3oool0gia8001d_`P0oooo00H0okmd0018W03Oool0oooo0;md001d_ol80?ooo`80
0000703oool3000002X0oooo102Y_NP2042@k`03001:`P2^`>L0[/3W00@0[/3W00<0d<7<0<o1c03?
`L`00P3?`L`00`3>`Lh0dKc50=6la@020=6la@<0d;[50P2a/]T40;ZbdFP0ZKgX1@2VVl/309B8a0@0
T8O6102?R/X4096CdP80Vj_R0P2]m?<0101nfih0]/o]0;K?k@2fcnd=0:Vmj0D0YKCS00@0ZKcW0000
002Y_>L0ZKcW1@2[_nP20:^nj0@000005P3oool00`000000oooo0?ooo`0D0?ooo`00103oool01@3o
okl0M00000000000B9`0gooo00@0oooo00<0gia80000000000000`0000000`1d_ol0oooo0=nLB003
000000030000M02oool0oooo00@0oooo00<000000?ooo`3oool05`3oool3000002h0oooo102Y_NP2
042@k`030011]P2^`>L0[/3W00<0[/3W103?`L`30<k1cP80dKc5103@^/D60;ZbdF@0ZKgX1@2XYmD4
0:JKb`@0U8S4102@QlH408n:bP<0TI?B0`2]m?<60;K?k@T0ZKgX102Y]^<50:Fdh`040000002/_nP0
[;oX0:boj0@0ZkoX0P00000J0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0
oooo01D0oooo0`00000b0?ooo`@0ZKgX0P1DVo<00`00@KH0Z/;[0:[2j`030:[2j`80cl7<1@3>`Lh5
0=2ja@040<nia@2j/]40^[;A0;Zbd@<0`k;90`2Y_NP20:NWeU/0ZKgX102Y/n050:RWe@<0YY_;102D
R<@40927aP@0Sh[:1@2VcO@30<;mhPT0ZKgX1@2Y^nH40:Vfh`D0ZkgV00@000000:boj02/_nP0[;oX
0P00000M0?ooo`030000003oool0oooo01@0oooo000O0?ooo`8000004`3oool3000003H0oooo102Y
_NP305BKl`030011]P2Z`^/0Z/;[0080Z/;[1@3>`Lh20<_1d@<0d;[50`3?^LD60<>bb@D0YjOFF`2Y
_NP40:Vch0@0Z:OE0`2VVl/409B8a0@0T8O61@2KZN420:K=m0030<;mhP2Y_NP0ZKgX00`0ZKgX102Y
^nH50:Vhi0@0ZkgV0`00000P0?ooo`030000003oool0oooo01@0oooo000O0?ooo`030000003oool0
oooo00l0oooo0`00000j0?ooo`D0ZKgX0`1_Z?@40:73l@<0c/7>103;`M400`3@^/D0ckW50<nia@02
0<nia@030<fja`33//T0`k;90080`k;90P3;/l<50:NWeUX0ZKgX102Y/n0509R:``<0UX_6102DS/X4
09JGdP@0VjWQ00@0Wo;a0000002bbN/0//W[3@2Y_NP50:FbhP@0ZKST0`0000030?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0503oool001l0oooo00<000000?ooo`3oool0303oool3
000003h0oooo1@2Y_NP306nXm0@0XL?a1P3;`M440<nia@<0cK[70P33//T40<^c``80YjOF0`2gZ/`3
0:Vmj080YjOFD@2Y_NP409f<`@@0VX[2102HR/<309J;aP@0U8k:1@2FUm8209^Yh@0309obl@2bbN/0
//W[00<0//W[2@2Y_NP40:Rfh`D0YK;R0P2Y^>@00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04`3oool001l0oooo00<000000?ooo`3oool02@3oool30000
0480oooo1@2Y_NP308bdl@@0S/;h0`3;`M430<O4e`80ckW5103=^/L60<^c``H0]j[<1@2WYmH20:Vm
j080ZK_VB02Y_NP50:BB`P<0WHc1102JR/8509R:``<0UX_6102DS/X409JGdP0409obl@35m>h0aOC^
0<GdkP80//W[302Y_NP40:Rfh`@0YK;R2P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01<0oooo000N0?ooo`8000002@3oool2000004H0oooo1@2Y_NP40:BljP<0S/;h1P37a=L50<fj
a`030<^mc03;/l<0bk?30080bk?30P3;]<@40;NZc080aJk3102WYmH50:VkiT@0ZKgX102TTl@40:BB
`P@0WHc1102JR/8409R:``<0UX_6102DS/X40:GGn@@0aOC^3P2Y_NP40:Rfh`l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`<0
0000B@3oool50:Vmj0@0Y;cZ0`1V^Od30<O4e`<0_lWR0`3=^/L30<^mc080bk?3103;]<@20;NZc0@0
aJk30P2WYmH20;JUb0<0ZK_V0P2WWL`o0:Vmj0P0Y9?41@2TT/8309f<`@@0VX[2102HR/<309J;aPH0
XKSY0`1mh[PA0:Vmj0030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000ZKgX
0:Vmj0060:Vmj0<0I[Wm1P2obN800`3=^/L0bkg<0<^mc0030<^mc0D0bkC41P35[/<50;JUb0D0Yig<
1@2WX]4_0:Vmj080ZK?P1@2Y_NP40:BB`PP0Y9?4102TT/8309f<`@@0VX[21@2LVm4309fUf`<0XKSY
00<0ON:h0:Vmj02Y_NP0302Y_NP00`3oool0000000000002000001H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0C0?ooo`007P3oool00`000000oooo0000000200000540oooo00<0
00000:Vmj02Y_NP01P2Y_NP01002J]/079OY01bGj@0LUnT40;o9hPD0bkg<0P37a=L30<^da080b[W9
1035[/<20<Ra``<0]ZG80P35[<430:NMc080_JK21@2WX]440:NTdbP0ZKgX1@2Y/n050:>?`0<0Y9;2
202TTl@40:BB`P@0WY?8102MUL`409bKd@@0WJGK102^a>X;0:Vmj0<000006`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01<0oooo000N0?ooo`800000E@3oool00`000000ZKgX0:Vm
j0060:Vmj0<0HZ;c00<005R^0:_?l`2[co<00P2[co<30<^mc0@0alCG00<0bkC40<Zib@3:^LT00P3:
^LT20<F^``@0b;7300<0]ZG80<F/`@35[<400P35[<40102WWL`0_JK20;fV`P2mY/840:NRd@80]j;3
102WY=<50:NRd@@0ZKgX102Y^nHF0:Vmj0D0Z:OE0`2Y/n020:RB_`@0Xho0102TT/870:BCa0D0X9;6
0`2NTlP509fEc0<0W9_A0P2Ck?@20;[Kl0D0[/CZ202Y_NP2000001l0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0C0?ooo`004`3oool00`3ogi`0B01d0;ooo`090?ooo`030000003o
ool0oooo05@0oooo00<000000:Vmj02Y_NP01P2Y_NP509njk0<0Zloc1P37a=L50<Zib@H0b;731@35
[<450;fV`P80Yj;A0`2gX/<30:NTd`80]9o21@2WX]440:FKb`@0ZK_V1@2XYmH40:Vmj0D0Z:OF102Y
_NP40:JKb`D0Z:OE102XT[l40:>?`0@0Y9;2102TTl@40::Ba0@0X9;6102NTlP409fEc0<0X=ol1@2j
fo090:Vmj0030000003oool0oooo0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`3ogi`0B01d0;ooo`0:0?ooo`800000EP3oool90:Vmj0@0Wk[/00<004:f
06k7o`1^aol00`37a=L30;[@j`<0b[W90P37`]D40<Ra``80b;S;1035[<400`36//H0_JK20;fV`P02
0;fV`PH0]j;300@0YjCC0;BO`P2dWl80]9o2102WX]420;JN`@@0YI_;102UU<@50:RWeP@0Y9K6102X
YmH50:>A`P@0YY_;0P2XYmD30:^D_`@0Z9:o0`2SSl040:BB`PD0Y9?40`2RT/@40:2BaP@0WY?81@2T
coH30;3[n0T0ZKgX0P00000W0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3o
ool001<0oooo00<0omnL04P0M02oool0303oool00`000000oooo0?ooo`1D0?ooo`d0ZKgX0P0oSnl0
0`00O<<0^]3[0;[@j`040;[@j`030<Zib@37`]D0al;E0080al;E0P38/L<30<Rhb`<0aJc10P36//H3
0;fV`P80a:g31@2gX/<50;BO`P80Yj;A0`2fW/430:FKb`80^J2o102UU<@20:RWeP<0/IVo102TU/H2
0:RWeP80/9Ro102STL840:JKb`D0ZiBo102XT[l30:>?`0D0YYG4102TTl@40::Ba0<0X9;61@2U`nl3
0:C?mP0309W^m02Y_NP0ZKgX00L0ZKgX0P00000[0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool04P3oool001<0oooo00<0omnL04P0M02oool03@3oool00`000000oooo0?ooo`1D0?oo
o`d0ZKgX0`2J^Nd50;[@j`D0al;E1P38^</00`35[<40a[;60<JbaP020<JbaP040;fV`P34[L<0a:g3
0<B]``@0]j;30P31Z/840;BO`PD0]Yk10P2UVl/30;VP_`@0YIC41@2aVKl40:BFaP@0/9Ro1@2STL82
0:JKb`80[YS0102[U;l40:RB_`@0ZIS5102VUL@40:BCa0@0XY;4102V_>T50:G3k`P0ZKgX0P00000`
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0omnL04P0
M02oool03P3oool00`000000oooo0?ooo`1D0?ooo`d0ZKgX0`2J^Nd507kCo`<0al;E0P2geNl50<Rh
b`D0a[;61@34[L<20;NR``<0`J[20`2dWl820;nY``@0]Yk11P2iX;l20:FDa080^J71102aVKl20:BF
aP<0]9g1102`V;l40:>A`P@0[YS0102[U;l20:RB_`<0[9g80`2YV<D50:JEa0<0Y9?41@2W^NH40:Jl
j@P0ZKgX0`00000c0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool001<0
oooo00<0omnL04P0M02oool03`3oool00`000000oooo0?ooo`1D0?oooa40ZKgX0`1?V?800`0V0000
]mG_0;OEk`030;OEk`80b;S;0`34b]h30<JbaP80a/7F1034[L<60<6Z`P040;BO`P2oZL<0_jW30;nY
``<0]Yk10P2nZLD50;VP_`040:FDa02iXL40^J710;VQ`@@0/IVo1@2dWL440;2H_`80Xi720`2aWL<4
0:jH`0<0ZiBo1@2/WLP40:VHa@@0YYG4102Y^^D50:NiiPP0ZKgX0`00000g0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04P3oool00140oooo00D0_g@00000B02L_i`0B01d0;ooo`0@
0?ooo`800000E@3oool40:Vgh`d0ZKgX1@2X_NP30;OEk`D0a<[N0P36//H40<K1eP80a:g30P35_=85
0<6Z`PD0_jW300@0]Yk10;jYa@2nZLD0_ZW51@2iX;l50;VQ`@80/IVo0P2iY/L50;BM`@<0/9Ro1@2a
WL<40:jH`0@0[j?<1@2/WLP30:VHa@D0ZkgW102Y^^D80:Vmj0<00000?03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0180oooo000B0?ooo`040?noM0000000001d0;oooa80oooo00<0
00000?ooo`3oool0D`3oool40:Vgh`D0ZK_V202Y_NP50:Rmj003001Nd`1;a>l0BlC_00@0a<[N1P36
`MH50<FldP80`J[20`34^m840;nY``D0_ZW50P2iX;l30;f]b@@0^J7100@0/IVo0;VVa`2iY/L0^JK7
1@2dWL420;2H_`80]JK9102aWL<20:jH`0<0/ZkD0`2_Xl`50:bMb080ZIS50P2/aN`50:^mi`P0ZKgX
0`0000100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04P3oool001<0oooo00<0
omnL04P0M02oool04`3oool00`000000oooo0?ooo`1C0?ooo`@0/;[Q1@2Y^nH=0:Vmj0<0R;;a102A
goh30<K1eP<0Zn7j1035_=860<BkdP80_jW30P32_MD40;jYa@D0_Jg9102iXL450;VVa`@0]9g1102e
Y/T40;6M``D0/ZkD102_Xl`40:bMb0D0[<G/202Y_NP4000004<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0A0?ooo`00:P3oool00`000000oooo0?ooo`1C0?ooo`@0/;[Q1@2[^N<A
0:Vmj0<0IZ?c1P2[hOX20<FldP80/N3g1@34^m850<:me@80_ZW50P30a]h50;f]b@80^J710P2m^=@4
0;VVa`D0^KGE102eY/T20;6M``80]KoQ1@2b[]@30:nSc0D0Zm7d2@2Y_NP3000004P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00:`3oool2000005@0oooo0P2`^^420;>o
h`D0ZkWS102Y_NLA0:Vmj0@0Zn7j1@2ah?L20<BkdP<0[>Cj1032_MD50<36gP@0_Jg91@2m^=@20;VV
a`80^M3/1@2i]MD30;FVb@D0]KoQ102b[]@50:3Po0P0ZKgX00@0oooo0000000000000000C03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo000]0?ooo`030000003oool0oooo
0540oooo1@2c_n<50;2ni0@0ZKgW5P2Y_NP30;7Pm`D0[>Cj1@2Dio/40<36gPD0^MW`102m^=@50;W@
k0@0^KGE102`fOD40;Foh@H0N^7b202Y_NP4000004l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0A0?ooo`00;P3oool00`000000oooo0?ooo`1B0?ooo`@0[/7X1@2`_^@40:Zhi1l0
ZKgX102Dio/504_:e`<0^MW`1@25iOH40;W@k0D0Mn7_102`fOD>0:Vmj0<00000E03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000_0?ooo`030000003oool0oooo0580oooo
102^`NP50;70i@@0Z[ST102Y^^DO0:Vmj0@0Z;gX1@2Y_NP409Zhk@@0ZKgX102P^^/>0:Vmj0040?oo
o`0000000000000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`00
<03oool00`000000oooo0?ooo`1B0?ooo`@0Zl7Z1@2a`>D40:nni@@0ZK[U1@2Y^nH50:Vlic@0ZKgX
1000001L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00340oooo0P00
001C0?ooo`@0Zl7Z1@2[`>T40:nni@@0[KcT0`2Y^nH20:bji0T0ZKcW:`2Y_NP0103oool000000000
0000001P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool003<0oooo00<0
00000?ooo`3oool0D@3oool40:RojPD0Zl3Y102/_nP40:fli0D0[;[T1@2[^N@40:Vli`@0ZK_V8`2Y
_NP4000006@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`00=03oool0
0`000000oooo0?ooo`1A0?ooo`@0Z;oZ1@2W_^X40:boj0@0[[oW0`2/^^@20:joiPT0ZkWT102Y^nH4
0:Vji@D0ZKgX102Y_NL40:Vmj0@0ZK_V2P2Y_NP3000006T0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo0?ooo`1A0?ooo`@0Z;kY1@2W_^X40:No
jP@0[[oW2P2^_nH40:^ii0@0[;[T102Y^^D50:Vhi0@0ZKgW102Y]n840:VkiPD0ZKOS00@0oooo0000
000000000000K03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000f0?oo
o`800000DP3oool40:Rnj@H0YkkZ0`2W_nX90:RojPD0[[oV102]_nL40:bji0@0[KcT102Y^>@50:Zf
hP@0ZKOR102[]>030:Vgh`800000L03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo000h0?ooo`030000003oool0oooo0500oooo1@2X_^T50:Rmj@P0YkkZ2@2X_nX40:foi`@0
[;oX102]_>@40:nni@D0Z[KR102^^^840:^dh7D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0@0?ooo`00>@3oool00`000000oooo0?ooo`1A0?ooo`@0ZKgX2@2X_NT80:NnjPT0Z;oZ
102/_nP40:Zoj@@0[kkU1@2[_>L40:jjhWT0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0@0?ooo`00>P3oool00`000000oooo0?ooo`1A0?ooo`T0ZKgX202X_NT80:NnjPD0Z;oZ102W
_n/40:Zoj@@0Z;gY102[_>L00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0403oool003/0oooo00<000000?ooo`3oool0D@3oool=0:Vmj0P0Z;gY2@2W_^X4
0:Noj`@0YkgZ102X_NV10?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool0
03`0oooo0P00001B0?oooa40ZKgX202X_NT40:NnjPD0YkgY102W_NZ50?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03`3oool003h0oooo00<000000?ooo`3oool0D03ooolE0:Vmj0T0
Z;gY0`2W_NT00`000000oooo0?ooo`270?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03`3oool003l0oooo00<000000?ooo`3oool0D03ooolJ0:Vmj0<00000S@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00100?ooo`030000003oool0oooo0500oooo5P2Y
_NP300000940oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00@@3oool2
00000540oooo4P2Y_NP3000009D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?
0?ooo`00@`3oool00`000000oooo0?ooo`1?0?ooo`d0ZKgX0`00002I0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03`3oool004@0oooo00<000000?ooo`3oool0D03oool80:Vmj0<0
0000W@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00150?ooo`030000
003oool0oooo0500oooo102Y_NP300000:40oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0>0?ooo`00AP3oool200000540oooo0P00002V0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool004P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03P3oool004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool004`0oooo0P00001;0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0>0?ooo`00CP3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`00C`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`00D03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool2000004H0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
001C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0[03oool01@000000oooo0?oo
o`3oool0000000l0oooo001D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0[P3o
ool010000000oooo0?ooo`00000?0?ooo`00E@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0:h0oooo00@000000?ooo`3oool000003`3oool005H0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0000000l0oooo001G0?ooo`800000?`3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0000000h0oooo001I0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001J0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0/@3oool2000000h0oooo001K0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0/@3oool2000000h0oooo001L0?ooo`800000>P3oool00`000000oooo0?oo
o`2]0?ooo`@00000403oool005h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Y
0?ooo`@00000503oool005l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`2U0?oo
o`@00000603oool00600oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2Q0?ooo`@0
0000703oool00640oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2N0?ooo`<00000
803oool00680oooo0P00000d0?ooo`030000003oool0oooo09X0oooo1000000S0?ooo`00I03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09H0oooo1000000W0?ooo`00I@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0980oooo1000000[0?ooo`00IP3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo08h0oooo1000000_0?ooo`00I`3oool2000002l0oooo
00<000000?ooo`3oool0RP3oool4000003<0oooo001Y0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0Q`3oool3000003L0oooo001Z0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0P`3oool4000003X0oooo001[0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0O`3oool4000003h0oooo001/0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0N`3oool400000480oooo001]0?ooo`800000:@3oool00`000000oooo0?ooo`1g0?ooo`@00000
AP3oool006l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1e0?ooo`<00000BP3o
ool00700oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1a0?ooo`@00000C@3oool0
0740oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000D@3oool00780
oooo0P00000S0?ooo`030000003oool0oooo06T0oooo1000001E0?ooo`00M03oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo06D0oooo1000001I0?ooo`00M@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0680oooo0`00001M0?ooo`00MP3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo05h0oooo1000001P0?ooo`00M`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo05X0oooo1000001T0?ooo`00N03oool2000001d0oooo00<000000?ooo`3o
ool0EP3oool4000006P0oooo001j0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
DP3oool4000006`0oooo001k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3o
ool400000700oooo001l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool3
000007@0oooo001m0?ooo`800000603oool00`000000oooo0?ooo`170?ooo`@00000M`3oool007l0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`130?ooo`@00000N`3oool00800oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`@00000O`3oool00840oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`@00000P`3oool00880oooo0P00000C
0?ooo`030000003oool0oooo03P0oooo0`0000270?ooo`00Q03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo03@0oooo1000002:0?ooo`00Q@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0300oooo1000002>0?ooo`00QP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo02`0oooo1000002B0?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02P0oooo1000002F0?ooo`00R03oool2000000d0oooo00<000000?ooo`3oool09@3oool3
000009X0oooo002:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool40000
09d0oooo002;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000:40
oooo002<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000:D0oooo
002=0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?ooo`@00000Z@3oool008l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000[@3oool00900oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`<00000/@3oool00940oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000]03oool00980oooo00D000000?ooo`3oool0
oooo000000090?ooo`@00000^03oool009<0oooo0P0000000`3oool000000?ooo`040?ooo`@00000
_03oool009D0oooo0P0000000`3oool000000000000200000<00oooo002F0?ooo`800000a03oool0
0?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool0
0?l0ooooG@3oool00?l0ooooG@3oool00001\
\>"],
  ImageRangeCache->{{{0, 347.75}, {281.938, 0}} -> {-0.0944294, -0.0218685, \
0.00470314, 0.00470314}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Big Number Arithmetic", "Section"],

Cell["Top of class performance for all precision ranges", "BulletText"],

Cell["\<\
Competitive Situation: On par or better then special purpose libraries. \
Unchallenged by general systems\
\>", "BulletText"],

Cell[CellGroupData[{

Cell["Reals", "Subsection"],

Cell["\<\
Speed improvement in 10 \[Dash] 1,000 digit range comes from low level \
assembler libraries, up to 3x improvement. \
\>", "BulletText"],

Cell["\<\
Speed improvement in 1,000 \[Dash] 10,000,000 digit range comes from \
asymptotically efficient algorithms; unbounded improvement.\
\>", "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "All the examples below are done by remotely evaluating in two versions of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version // R\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \({"5.0 for Microsoft Windows (November 18, 2003)", 
      "4.2 for Microsoft Windows (August 23, 2002)"}\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell["\<\
These are examples of speedups for arbitrary precision real arithmetic.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Real, {0, 1}, 10\^2]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^5}]]] // R\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({{0.20999999999999996`\ Second, Null}, {0.39099999999999824`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Real, {0, 1}, 10\^3]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^4}]]] // R\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \({{0.31099999999999994`\ Second, Null}, {0.9310000000000009`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Real, {0, 1}, 10\^4]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^3}]]] // R\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \({{1.0010000000000003`\ Second, Null}, {1.843`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["\<\
These are some algebraic functions with high precision input.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Real, {0, 1}, 10\^3]}, \[IndentingNewLine]Timing[
          Do[1\/a\^2, {10\^3}]]] // R\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({{0.09999999999999964`\ Second, Null}, {0.2699999999999996`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Real, {0, 1}, 10\^3]}, \[IndentingNewLine]Timing[
          Do[\@a, {10\^3}]]] // R\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({{0.04999999999999982`\ Second, Null}, {0.3910000000000018`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integers", "Subsection"],

Cell["\<\
Applications include: cryptography, symbolic computing\
\>", "BulletText"],

Cell["\<\
Speed improvement in 10 \[Dash] 1,000 digit range comes from low level \
assembler libraries, up to 3x improvement.\
\>", "BulletText"],

Cell["\<\
Speed improvement in 1,000 \[Dash] 10,000,000 digit range comes from \
asymptotically efficient algorithms; unbounded improvement.\
\>", "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell["These are some speedups for bignum integer multiplication. ", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \($Version // R\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({"5.0 for Microsoft Windows (April 3, 2003)", 
      "4.2 for Microsoft Windows (August 23, 2002)"}\)], "Output",
  CellLabel->"Out[46]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = 
            Random[Integer, {10\^\(10\^2 - 1\), 
                10\^\(10\^2\)}]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^5}]]] // R\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({{0.1609999999999996`\ Second, Null}, {0.33100000000000307`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = 
            Random[Integer, {10\^\(10\^3 - 1\), 
                10\^\(10\^3\)}]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^4}]]] // R\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \({{0.29999999999999893`\ Second, Null}, {1.421999999999997`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = 
            Random[Integer, {10\^\(10\^4 - 1\), 
                10\^\(10\^4\)}]}, \[IndentingNewLine]Timing[
          Do[a\ a, {10\^3}]]] // R\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \({{0.9720000000000013`\ Second, Null}, {2.763999999999996`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell["\<\
This shows dramatic speedup for large integer GCD computations (this is an \
asymptotically efficient algorithm).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Integer, {10\^\(10\^4 - 1\), 10\^\(10\^4\)}], 
          b = Random[Integer, {10\^\(10\^2 - 1\), 10\^\(10\^2\)}]}, 
        Timing[Do[GCD[a, b], {10\^2}]]] // R\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \({{0.019999999999999574`\ Second, Null}, {1.1219999999999999`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[79]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{a = Random[Integer, {10\^\(10\^5 - 1\), 10\^\(10\^5\)}], 
          b = Random[Integer, {10\^\(10\^2 - 1\), 10\^\(10\^2\)}]}, 
        Timing[GCD[a, b]; ]] // R\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({{0.`\ Second, Null}, {0.9509999999999934`\ Second, Null}}\)], "Output",\

  CellLabel->"Out[80]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Reduce", "Section"],

Cell[TextData[{
  StyleBox["Reduce", "MR"],
  " solves equations and inequalities over different ",
  StyleBox["domains",
    FontSlant->"Italic"],
  ". "
}], "BulletText"],

Cell[TextData[{
  StyleBox["Reduce", "MR"],
  " generates ",
  StyleBox["complete solution",
    FontSlant->"Italic"],
  " sets even when they are infinite, such as may happen for transcendental \
equations over the ",
  "complexes",
  " or reals and polynomial equations over the integers."
}], "BulletText"],

Cell[TextData[{
  StyleBox["Reduce", "MR"],
  " allows you to use ",
  StyleBox["existential and universal quantifiers",
    FontSlant->"Italic"],
  " in the equation specification."
}], "BulletText"],

Cell[TextData[{
  StyleBox["Reduce", "MR"],
  " extended input allows you to use equations, inequations, inequalities, \
existential quantifiers, universal quantifiers, domain specifications. "
}], "BulletText"],

Cell[TextData[{
  "Competitive Situation: Unchallenged. Unique ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " feature."
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  "In the example below we solve the same equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 - 2  y\^2 \[Equal] 1\)]],
  " over different domains. In all cases there are infinitely many solutions. \
In the case of complexes and reals, we can use earlier variables in the \
variable list to paramatrize later ones. However in the case of Diophantine \
equations that is no longer enough, but we need to generate additional \
parameters to fully describe the solutions. "
}], "Text"],

Cell["Solving a simple equation over the complexes. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ x\^2 - 2\ y\^2 \[Equal] 1, \ {x, y}, \ Complexes\ ]\)], "Input",\

  CellLabel->"In[55]:="],

Cell[BoxData[
    \(y == \(-\(\@\(\(-1\) + x\^2\)\/\@2\)\) || 
      y == \@\(\(-1\) + x\^2\)\/\@2\)], "Output",
  CellLabel->"Out[55]="]
}, Closed]],

Cell["\<\
Solving the same equation over the reals, requires inequalities to describe \
the solution.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ x\^2 - 2  y\^2 \[Equal] 1, \ {x, y}, \ Reals\ ]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(x \[LessEqual] \(-1\) && \((y == \(-\(\@\(\(-1\) + x\^2\)\/\@2\)\) || 
            y == \@\(\(-1\) + x\^2\)\/\@2)\) || 
      x \[GreaterEqual] 
          1 && \((y == \(-\(\@\(\(-1\) + x\^2\)\/\@2\)\) || 
            y == \@\(\(-1\) + x\^2\)\/\@2)\)\)], "Output",
  CellLabel->"Out[56]="]
}, Closed]],

Cell["\<\
Solving the same equation over the integers in addition requires parameters \
to describe the solution.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ 
      Integers\ ]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(C[1] \[Element] Integers && C[1] \[GreaterEqual] 0 && 
        x == 1\/2\ \((\(-\((3 - 2\ \@2)\)\^C[1]\) - \((3 + 2\ \@2)\)\^C[1])\) \
&& y == \(-\(\(\((3 - 2\ \@2)\)\^C[1] - \((3 + 2\ \@2)\)\^C[1]\)\/\(2\ \
\@2\)\)\) || 
      C[1] \[Element] Integers && C[1] \[GreaterEqual] 0 && 
        x == 1\/2\ \((\(-\((3 - 2\ \@2)\)\^C[1]\) - \((3 + 2\ \@2)\)\^C[1])\) \
&& y == \(\((3 - 2\ \@2)\)\^C[1] - \((3 + 2\ \@2)\)\^C[1]\)\/\(2\ \@2\) || 
      C[1] \[Element] Integers && C[1] \[GreaterEqual] 0 && 
        x == 1\/2\ \((\((3 - 2\ \@2)\)\^C[1] + \((3 + 2\ \@2)\)\^C[1])\) && 
        y == \(-\(\(\((3 - 2\ \@2)\)\^C[1] - \((3 + 2\ \@2)\)\^C[1]\)\/\(2\ \
\@2\)\)\) || 
      C[1] \[Element] Integers && C[1] \[GreaterEqual] 0 && 
        x == 1\/2\ \((\((3 - 2\ \@2)\)\^C[1] + \((3 + 2\ \@2)\)\^C[1])\) && 
        y == \(\((3 - 2\ \@2)\)\^C[1] - \((3 + 2\ \@2)\)\^C[1]\)\/\(2\ \
\@2\)\)], "Output",
  CellLabel->"Out[57]="]
}, Closed]],

Cell["This solves the equation over the integers modulo 12.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ 
      Modulus\  \[Rule] \ 12\ ]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(x == 1 && y == 0 || x == 1 && y == 6 || x == 3 && y == 2 || 
      x == 3 && y == 4 || x == 3 && y == 8 || x == 3 && y == 10 || 
      x == 5 && y == 0 || x == 5 && y == 6 || x == 7 && y == 0 || 
      x == 7 && y == 6 || x == 9 && y == 2 || x == 9 && y == 4 || 
      x == 9 && y == 8 || x == 9 && y == 10 || x == 11 && y == 0 || 
      x == 11 && y == 6\)], "Output",
  CellLabel->"Out[58]="]
}, Closed]],

Cell["\<\
You can also solve over mixed domains. You will then need to add the domain \
equations along with your ordinary equations. \
\>", "Text"],

Cell["\<\
Solving the same equation over the mixed reals and complexes. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ 
      x\^2 - 2  y\^2 \[Equal] 1\  && \ x \[Element] Reals\  && \ 
        y \[Element] Complexes, \ {x, y}\ ]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(x < \(-1\) && \((y == \(-\(\@\(\(-1\) + x\^2\)\/\@2\)\) || 
            y == \@\(\(-1\) + x\^2\)\/\@2)\) || 
      x == \(-1\) && 
        y == 0 || \(-1\) < x < 
          1 && \((y == \(-\(\(\[ImaginaryI]\ \@\(1 - x\^2\)\)\/\@2\)\) || 
            y == \(\[ImaginaryI]\ \@\(1 - x\^2\)\)\/\@2)\) || 
      x == 1 && y == 0 || 
      x > 1 && \((y == \(-\(\@\(\(-1\) + x\^2\)\/\@2\)\) || 
            y == \@\(\(-1\) + x\^2\)\/\@2)\)\)], "Output",
  CellLabel->"Out[59]="]
}, Closed]],

Cell["\<\
Interestingly even when solving equations over the complexes one sometimes \
needs inequalities to fully describe the solution set. \
\>", "Text"],

Cell["\<\
An example of where inequalities are needed to describe the solution set over \
the the complexes.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ z\ Conjugate[z] \[Equal] 1, \ z\ ]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(\(-1\) \[LessEqual] Re[z] \[LessEqual] 
        1 && \((Im[z] == \(-\@\(1 - Re[z]\^2\)\) || 
          Im[z] == \@\(1 - Re[z]\^2\))\)\)], "Output",
  CellLabel->"Out[60]="]
}, Closed]],

Cell[TextData[{
  StyleBox["Reduce", "MR"],
  " will generate complete solutions. In this case there are infinitely \
(countably) many  complex roots, a single real root and no integer roots. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ 
      5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\)\  && \ x \[Element] Complexes, \ 
      x\ ]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(C[1] \[Element] Integers && 
      x == \(-\(\(2\ \[ImaginaryI]\ \[Pi]\ C[1] + 
                Log[1715]\)\/\(\(-2\)\ Log[5] - Log[7]\)\)\)\)], "Output",
  CellLabel->"Out[61]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ 5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\) && x \[Element] Reals, \ 
      x\ ]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(x == Log[1715]\/\(2\ Log[5] + Log[7]\)\)], "Output",
  CellLabel->"Out[62]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ 
      5\^\(2  x - 1\) \[Equal] 7\^\(3 - x\) && x \[Element] Integers, \ 
      x\ ]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[63]="]
}, Closed]],

Cell["\<\
Here is an example where there are also infinitely many real roots. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\ 
      Tan[2  x]\^2 + Cot[2  x]\^2 + \ 2  Tan[2  x] + 2  Cot[2  x] \[Equal] 
          6\  && \ x \[Element] Reals, \ x\ ]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(C[1] \[Element] 
        Integers && \((x == 1\/8\ \((\[Pi] + 4\ \[Pi]\ C[1])\) || 
          x == 1\/24\ \((\(-5\)\ \[Pi] + 12\ \[Pi]\ C[1])\) || 
          x == 1\/24\ \((\(-\[Pi]\) + 12\ \[Pi]\ C[1])\))\)\)], "Output",
  CellLabel->"Out[64]="]
}, Closed]],

Cell[TextData[{
  "Another type of equation is one that includes quantifiers, such as \
existential (",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \)]],
  ") or universal (",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \)]],
  ") quanfiers. "
}], "Text"],

Cell[TextData[{
  "This reduces the values for ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " that make the quadratic polynomial positive for all real ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "MathCaption"],

Cell[BoxData[
    \(Clear[a, b, x]\)], "Input",
  CellLabel->"In[22]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[\[ForAll] \_\(x, x \[Element] Reals\)x\^2 + a\ x + 
            b \[GreaterEqual] 0, {a, b}, Reals]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(b \[GreaterEqual] a\^2\/4\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["FindInstance ", "Section"],

Cell[TextData[{
  StyleBox["FindInstance", "MR"],
  " is a new function that takes the same input as ",
  StyleBox["Reduce", "MR"],
  " and will produce instances of variables satisfying the equations and \
inequalities."
}], "BulletText"],

Cell[TextData[{
  "Competitive Situation: Unchallenged. Unique ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " feature."
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  "In the example below we solve the same equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 - 2  y\^2 \[Equal] 1\)]],
  " over different domains. In all cases there are infinitely many solutions, \
but ",
  StyleBox["FindInstance", "MR"],
  " makes it easy to generate a finite number of them. "
}], "Text"],

Cell["Solving a simple equation over the complexes. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[x\^2 - 2\ y\^2 \[Equal] 1, {x, y}, Complexes, 
      2]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{x \[Rule] \(-\(8\/5\)\) - \(19\ \[ImaginaryI]\)\/10, 
        y \[Rule] \(-\(1\/10\)\)\ \@\(\(-\(205\/2\)\) + 304\ \
\[ImaginaryI]\)}, {x \[Rule] 8\/5 + \(21\ \[ImaginaryI]\)\/5, 
        y \[Rule] 1\/5\ \@\(\(-201\) + 168\ \[ImaginaryI]\)}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["Solving the same equation over the reals:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ x\^2 - 2  y\^2 \[Equal] 1, \ {x, y}, \ Reals, \ 
      2\ ]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{x \[Rule] 1, y \[Rule] 0}, {x \[Rule] 106, 
        y \[Rule] \(-\@\(11235\/2\)\)}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["Solving the same equation over the integers:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ Integers, \ 
      2\ ]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({{x \[Rule] 1, 
        y \[Rule] 0}, {x \[Rule] 
          12074354578020693796362087827636314615757933529584148670654481490782\
6387361122499, 
        y \[Rule] 
          85378580005692670970000276413671736634579869085031841817841431131972\
661051642450}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["This solves the equation over the integers modulo 12.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ x\^2 - \ 2\ y\^2 \[Equal] 1, \ {x, y}, \ 2, \ 
      Modulus\  \[Rule] \ 12\ ]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({{x \[Rule] 3, y \[Rule] 8}, {x \[Rule] 7, y \[Rule] 6}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["You can also solve over mixed domains.", "Text"],

Cell["\<\
Solving the same equation over the mixed reals and complexes. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ 
      x\^2 - 2  y\^2 \[Equal] 1\  && \ x \[Element] Reals\  && \ 
        y \[Element] Complexes, \ {x, y}\ , \ 2]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({{x \[Rule] \(-30\), y \[Rule] \(-\@\(899\/2\)\)}, {x \[Rule] 1, 
        y \[Rule] 0}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
Here is an example where there are also infinitely many real roots. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ 
      Tan[2  x]\^2 + Cot[2  x]\^2 + \ 2  Tan[2  x] + 2  Cot[2  x] \[Equal] 
          6\  && \ x \[Element] Reals, \ x\ ]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \({{x \[Rule] \(5\ \[Pi]\)\/8}}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[TextData[{
  "Another type of equation is one that includes quantifiers, such as \
existential (",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \)]],
  ") or universal (",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \)]],
  ") quanfiers. "
}], "Text"],

Cell[TextData[{
  "This reduces the values for ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " that make the quadratic polynomial positive for all real ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\ 
      ForAll[\ x, x \[Element] Reals, \ 
        x\^2 + \ a\ x\  + \ b \[GreaterEqual] 0\ ], \ {a, b}, \ 
      Reals\ ]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \({{a \[Rule] 4\/5, b \[Rule] 18}}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["RSolve", "Section"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " is a comprehensive solver for recurrence or difference equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " solves single linear or nonlinear difference equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " solves systems of linear and nonlinear difference equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " solves difference algebraic equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " solves partial difference equations. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " in addition solves ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-difference equations or divide-and-conquer equations. "
}], "BulletText"],

Cell[TextData[{
  "Competitive Situation: Best in class. Far outperforms Maple\
\[CloseCurlyQuote]s ",
  StyleBox["rsolve", "MR"],
  ". "
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  "Just as ",
  StyleBox["DSolve", "MR"],
  " solves for functions of a continuous argument, so ",
  StyleBox["RSolve", "MR"],
  " solves for functions of a discrete argument or a sequence."
}], "Text"],

Cell[TextData[{
  "This gives the general solution to ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(k + 1\) \[Equal] \ \((k + 1)\)\ y\_k\)]],
  " involving one arbitrary constant ",
  Cell[BoxData[
      \(TraditionalForm\`C[1]\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ y[k + 1] \[Equal] \ \((k + 1)\)\ y[k], \ y, \ k\ ]\)], "Input",\

  CellLabel->"In[34]:="],

Cell[BoxData[
    \({{y \[Rule] Function[{k}, C[1]\ Gamma[1 + k]]}}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  "This solves the difference equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(k + 1\) \[Equal] \ \((k + 1)\)\ y\_k\)]],
  " and the initial value equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0 \[Equal] 1\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ 
      y[k + 1] \[Equal] \ \((k + 1)\)\ y[k]\  && \ y[0] \[Equal] 1, \ y, \ 
      k\ ]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({{y \[Rule] Function[{k}, Gamma[1 + k]]}}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
This shows that the solution satisfies the difference and initial value \
equations.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y[k + 1] \[Equal] \ \((k + 1)\)\ y[k]\  && \ y[0] \[Equal] 1 /. % // 
      FullSimplify\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({True}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["W", "MR"],
  "hen given difference equation or system of difference equations,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`F(k, y(k), y(k + 1), \[Ellipsis], y(k + n)) = 
      0\)]]], "DisplayFormula",
  FormatType->DefaultTraditionalFormatType],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " will attempt to find a ",
  StyleBox["general solution",
    FontSlant->"Italic"],
  ": "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`G(k, y(k), C(1), \[Ellipsis], C(n)) = 
      0\)]]], "DisplayFormula",
  FormatType->DefaultTraditionalFormatType],

Cell[TextData[{
  "By adding additional initial value equation or boudary value constraints \
",
  StyleBox["RSolve", "MR"],
  " will attempt to eliminate the general constants ",
  Cell[BoxData[
      \(TraditionalForm\`C[i]\)]],
  ". "
}], "Text"],

Cell["\<\
This solves a second order difference equation with two boundary equations. \
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      RSolve[\ y[k + 2]\  + \ 2\ y[k + 1]\  + \ y[k]\  \[Equal] \ 0\  && \ 
          y[0]\  \[Equal] \ 1\  && \ y[1]\  \[Equal] \ 2, \ y, \ 
        k\ ]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{k}, \(-\((\(-1\))\)\^k\)\ \((\(-1\) + 
                  3\ k)\)]}}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
This is how you can visualize the resulting sequence using a typical stem \
plot. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MultipleListPlot[\ 
        Table[\ Evaluate[\ {k, \ y[k]\  /. \ First[\ s\ ]}], \ {k, \ 0, \ 
            10}\ ], \ SymbolShape\  \[Rule] \ Stem\ ];\)\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.32507 0.0107019 [
[.21429 .31257 -4.21875 -10.9375 ]
[.21429 .31257 4.21875 0 ]
[.40476 .31257 -4.21875 -10.9375 ]
[.40476 .31257 4.21875 0 ]
[.59524 .31257 -4.21875 -10.9375 ]
[.59524 .31257 4.21875 0 ]
[.78571 .31257 -4.21875 -10.9375 ]
[.78571 .31257 4.21875 0 ]
[.97619 .31257 -6.4375 -10.9375 ]
[.97619 .31257 6.4375 0 ]
[.01131 .00401 -18.375 -5.46875 ]
[.01131 .00401 0 5.46875 ]
[.01131 .11103 -18.375 -5.46875 ]
[.01131 .11103 0 5.46875 ]
[.01131 .21805 -18.375 -5.46875 ]
[.01131 .21805 0 5.46875 ]
[.01131 .43209 -12.875 -5.46875 ]
[.01131 .43209 0 5.46875 ]
[.01131 .53911 -12.875 -5.46875 ]
[.01131 .53911 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .32507 m
.21429 .33132 L
s
gsave
.21429 .31257 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .32507 m
.40476 .33132 L
s
gsave
.40476 .31257 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .32507 m
.59524 .33132 L
s
gsave
.59524 .31257 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .32507 m
.78571 .33132 L
s
gsave
.78571 .31257 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .32507 m
.97619 .33132 L
s
gsave
.97619 .31257 -67.4375 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .32507 m
.07143 .32882 L
s
.11905 .32507 m
.11905 .32882 L
s
.16667 .32507 m
.16667 .32882 L
s
.2619 .32507 m
.2619 .32882 L
s
.30952 .32507 m
.30952 .32882 L
s
.35714 .32507 m
.35714 .32882 L
s
.45238 .32507 m
.45238 .32882 L
s
.5 .32507 m
.5 .32882 L
s
.54762 .32507 m
.54762 .32882 L
s
.64286 .32507 m
.64286 .32882 L
s
.69048 .32507 m
.69048 .32882 L
s
.7381 .32507 m
.7381 .32882 L
s
.83333 .32507 m
.83333 .32882 L
s
.88095 .32507 m
.88095 .32882 L
s
.92857 .32507 m
.92857 .32882 L
s
.25 Mabswid
0 .32507 m
1 .32507 L
s
.02381 .00401 m
.03006 .00401 L
s
gsave
.01131 .00401 -79.375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.02381 .11103 m
.03006 .11103 L
s
gsave
.01131 .11103 -79.375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.02381 .21805 m
.03006 .21805 L
s
gsave
.01131 .21805 -79.375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .43209 m
.03006 .43209 L
s
gsave
.01131 .43209 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .53911 m
.03006 .53911 L
s
gsave
.01131 .53911 -73.875 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .02542 m
.02756 .02542 L
s
.02381 .04682 m
.02756 .04682 L
s
.02381 .06822 m
.02756 .06822 L
s
.02381 .08963 m
.02756 .08963 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15384 m
.02756 .15384 L
s
.02381 .17524 m
.02756 .17524 L
s
.02381 .19665 m
.02756 .19665 L
s
.02381 .23945 m
.02756 .23945 L
s
.02381 .26086 m
.02756 .26086 L
s
.02381 .28226 m
.02756 .28226 L
s
.02381 .30367 m
.02756 .30367 L
s
.02381 .34647 m
.02756 .34647 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .38928 m
.02756 .38928 L
s
.02381 .41068 m
.02756 .41068 L
s
.02381 .45349 m
.02756 .45349 L
s
.02381 .4749 m
.02756 .4749 L
s
.02381 .4963 m
.02756 .4963 L
s
.02381 .5177 m
.02756 .5177 L
s
.02381 .56051 m
.02756 .56051 L
s
.02381 .58192 m
.02756 .58192 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .33577 Mdot
.0001 w
.02381 .33577 m
.02381 .32507 L
s
.02 w
.11905 .34647 Mdot
.0001 w
.11905 .34647 m
.11905 .32507 L
s
.02 w
.21429 .27156 Mdot
.0001 w
.21429 .27156 m
.21429 .32507 L
s
.02 w
.30952 .41068 Mdot
.0001 w
.30952 .41068 m
.30952 .32507 L
s
.02 w
.40476 .20735 Mdot
.0001 w
.40476 .20735 m
.40476 .32507 L
s
.02 w
.5 .4749 Mdot
.0001 w
.5 .4749 m
.5 .32507 L
s
.02 w
.59524 .14314 Mdot
.0001 w
.59524 .14314 m
.59524 .32507 L
s
.02 w
.69048 .53911 Mdot
.0001 w
.69048 .53911 m
.69048 .32507 L
s
.02 w
.78571 .07893 Mdot
.0001 w
.78571 .07893 m
.78571 .32507 L
s
.02 w
.88095 .60332 Mdot
.0001 w
.88095 .60332 m
.88095 .32507 L
s
.02 w
.97619 .01472 Mdot
.0001 w
.97619 .01472 m
.97619 .32507 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00303oool01@3OW4P000000000000004P0W=oo0080
oooo00D0oono07@00000000004RL0=ooo`3o0?oooiT0oooo000;0?ooo`0=0?noM000B9`0gooo0?oo
o`3ookl0M01809cOo`3ooml0W4P004RLg`3oool0gia8001d_`3o0?oooiT0oooo000@0?ooo`090;md
001d_ol0oono07@0M02oool0oooo0?oOW01807@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooon>
0?ooo`000`3oool00`3ogi`0B00000000003000000030000M02oool0oooo00<0oooo00X0oono07@0
B02Lgol0omnL04Q8W03Oool0oooo0?oo_`1d04P0W=oo1`3oool400000?l0ooooS@3oool000d0oooo
00`0omnL04P0000004P0W=oo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol70?ooo`030000
003oool0oooo0?l0ooooPP3oool2000000X0oooo000?0?ooo`0:0=nLB000M;l0oooo0?oOW018B9`0
gooo0?ooo`3ookl0M01809cOo`L0oooo00<000000?ooo`3oool0o`3ooon00?ooo`H00000203oool0
00l0oooo00X0omnL04P0M02oool0oono07@0M02oool0oooo0?oOW01807@0_ooo1`3oool00`000000
oooo0?ooo`3o0?oooh00oooo1P0000080?ooo`002`3oool03@3ogi`0B01d0;ooo`3oool0gia8001d
_`3oool0oooO09a8001d_ol0oooo0=nLB000M;l0203oool00`000000oooo0?ooo`3o0?ooogl0oooo
200000070?ooo`00303oool01@3o_g@000000000000007@0_ooo0080oooo00D0oono07@000000000
04RL0=ooo`080?ooo`030000003oool0oooo0?l0ooooO`3oool8000000L0oooo000P0?ooo`030000
003oool0oooo0?l0ooooP03oool6000000P0oooo000P0?ooo`030000003oool0oooo0?l0ooooP03o
ool6000000P0oooo000P0?ooo`030000003oool0oooo0?l0ooooPP3oool2000000X0oooo000P0?oo
o`<00000o`3ooon30?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo0?l0
ooooP`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3o0?oooh<0oooo
00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003o
ool0oooo00P0oooo000P0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`08
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool0203oool00200
oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000
003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?oo
o`3o0?oooh<0oooo00<000000?ooo`3oool0203oool00200oooo0`00003o0?oooh<0oooo00<00000
0?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo
00P0oooo000P0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo0?ooo`080?ooo`00
803oool00`000000oooo0?ooo`3o0?oooh<0oooo00<000000?ooo`3oool0203oool00200oooo00<0
00000?ooo`3oool0o`3ooon30?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0
oooo0?l0ooooP`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3o0?oo
oh<0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0o`3ooon30?ooo`03
0000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo0?l0ooooP`3oool00`000000oooo
0?ooo`080?ooo`00803oool300000?l0ooooP`3oool00`000000oooo0?ooo`080?ooo`00803oool0
0`000000oooo0?ooo`3o0?oooc@0oooo0P00001=0?ooo`030000003oool0oooo00P0oooo000P0?oo
o`030000003oool0oooo0?l0oooo<P3oool6000004/0oooo00<000000?ooo`3oool0203oool00200
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`H00000B`3oool00`000000oooo0?ooo`080?ooo`00
803oool00`000000oooo0?ooo`3o0?oooc40oooo2000001:0?ooo`030000003oool0oooo00P0oooo
000P0?ooo`030000003oool0oooo0?l0oooo<@3oool8000004X0oooo00<000000?ooo`3oool0203o
ool00200oooo00<000000?ooo`3oool0o`3ooolb0?ooo`H00000B`3oool00`000000oooo0?ooo`08
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooc80oooo1P00001;0?ooo`030000003oool0oooo
00P0oooo000P0?ooo`<00000o`3ooold0?ooo`800000C@3oool00`000000oooo0?ooo`080?ooo`00
803oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3o0?ooocD0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3o0?oo
ocD0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000
oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`3OW4P00000000000030000000707Boo`3oool0oono07@00000000004RL0=ooo`080?oo
o`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
00P0oooo000;0?ooo`030?oOW0180000M;oo00@0oooo00H0oooO09a80018W=l0oooo0=nLB000M;l8
0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo00P0oooo000<0?ooo`030?oOW0180000M;oo00<0oooo00L0oono07@0M02oool0oooo0?oOW018
07@0_ooo00L0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0203oool000<0oooo00<0omnL04P0000000000`0000001`0007@0_ooo0?ooo`3o
ool0oono07@00018W=l00P3oool01`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool40000
0?l0oooo=03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000>0?ooo`0;
0?oog`2LB000B9cO0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol01`3oool00`000000oooo
0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`003`3o
ool02P3ookl0M01809cOo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol70?ooo`030000003oool0
oooo0?l0oooo=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000;0?oo
o`030?noM000M;l0oooo0080oooo00T0_g@007Boo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool0
1`3oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`080?ooo`002`3oool03@3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooO09a8001d_ol0
oooo0=nLB000M;l0203oool00`000000oooo0?ooo`3o0?ooocD0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`080?ooo`00303oool01@3ogi`0B000000000000000M;oo0080oooo00D0
oono07@00000000004RL0=ooo`080?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo0?l0oooo=@3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0
oooo0?l0oooo=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?oo
o`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
00P0oooo000P0?ooo`<00000o`3ooole0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0203oool00200oooo00<000000?ooo`3oool0iP3oool2000004`0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3T0?ooo`H00000BP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0
oooo0>@0oooo1P00001:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool0
0200oooo00<000000?ooo`3oool0h`3oool8000004T0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3S0?ooo`P00000B@3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo0>@0oooo
1P00001:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<0
00000?ooo`3oool0i03oool6000004X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`080?ooo`00803oool00`000000oooo0?ooo`3V0?ooo`800000C03oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo00P0oooo000P0?ooo`<00000iP3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3o
ool0iP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0203oool00200oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0iP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203o
ool00200oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0iP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200
oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0iP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo0`00
003V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`080?ooo`00803oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3V0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?oo
o`00803oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3V0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803o
ool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3V0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`00
0000oooo0?ooo`3V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool300000>H0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo
000P0?ooo`030000003oool0oooo09P0oooo0P00001<0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`2F
0?ooo`H00000BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0UP3oool6000004X0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`03
0000003oool0oooo09D0oooo200000190?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`2E0?ooo`P00000
B@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
203oool000h0oooo00<0omnL04P0M02oool00P3oool01@3ookl0M00000000000B9`0gooo00P0oooo
00<000000?ooo`3oool0UP3oool6000004X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000>0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0
W4P004RLg`3oool0gia8001d_`P0oooo00<000000?ooo`3oool0UP3oool6000004X0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000>0?oo
o`0;0?oOW01807@0_ooo0?ooo`3ookl0M01d0;ooo`3oool0omnL04P0M02oool01`3oool00`000000
oooo0?ooo`2H0?ooo`800000C03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0203oool000<0oooo00<0omnL04P0000000000`0000000`0007@0_ooo
0?ooo`020?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3o
ool4000009P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0203oool000h0oooo00/0omnL04P0M02oool0oooo0?no
M000B9`0gooo0?ooo`3ookl0M01809cOo`070?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0203oool000h0oooo00/0omnL04P0M02oool0oooo0?oOW018B9`0gooo0?ooo`3ookl0M018
09cOo`070?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool000`0oooo00d0
_g@00000B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00L0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`003@3oool02`3o_g@000000000M02o
ool0oooo0?oog`2LB000M;oo0?ooo`3OW4P007Bo00P0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`080?ooo`003P3oool00`3ogi`0B01d0;ooo`020?ooo`050?oo_`1d000000000018
W03Oool0203oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`080?ooo`00803oool3000009T0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203o
ool00200oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`080?ooo`00803oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool00200oooo00<000000?oo
o`3oool0V@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo00P0oooo000P0?ooo`<00000V@3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803o
ool00`000000oooo0?ooo`1:0?ooo`800000C@3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool0
0`000000oooo0?ooo`180?ooo`H00000B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`00
0000oooo0?ooo`180?ooo`H00000B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000
oooo0?ooo`170?ooo`P00000BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo
0?ooo`170?ooo`P00000BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?oo
o`180?ooo`H00000B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`18
0?ooo`H00000B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`1:0?oo
o`800000C@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool3000004/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`180?ooo`030=nL
B0000000000000<0000000<0M;oo0?ooo`3oool0A`3oool00`3ooml0000007Boo`190?ooo`050?oo
_`1d000000000000M02oool0B@3oool01@3o_g@000000000000004P0W=oo04L0oooo00X0omnL04P0
M02oool0oooo0000003ookl0M00000000000B9`0gooo1@3oool00200oooo00<000000?ooo`3oool0
B03oool0103ogi`0B00007Boo`00001<0?ooo`030?oog`000000M;oo04T0oooo00H0_g@007Boo`00
0000omnL04Q8W03Ooom70?ooo`070?oOW01804P0W=oo0000003o_g@0001d0;ooo`160?ooo`0:0?oO
W01807@0_ooo0?ooo`000000W4P004RLg`3oool0gia8001d_`D0oooo000P0?ooo`030000003oool0
oooo04T0oooo00<0omnL04P000000000B@3oool00`3OW4P00000000000030000000304RLg`3oool0
oooo04D0oooo00L0oono07A8W03Oool000000?oo_`1d04P0W=oo04L0oooo00L0okmd0018W03Oool0
00000?oo_`1d04P0W=oo04H0oooo00/0omnL04P0M02oool0oooo0000001d07@0_ooo0?ooo`3ogi`0
B01d0;ooo`040?ooo`00803oool00`000000oooo0?ooo`1:0?ooo`030?oo_`000000B9cO04P0oooo
00H0omnL04Q8W03Oool0oooO0000001d_om80?ooo`070?oOW018B9`0gooo0000003ookl0M01809cO
o`170?ooo`070?oOW01804P0W=oo0000003o_g@0001d0;ooo`160?ooo`0;0?oOW01807@0_ooo0?oo
o`000000B4RL0=ooo`3oool0oono07@0B02Lgol0103oool00200oooo00<000000?ooo`3oool0B`3o
ool00`000000W4P004RLg`180?ooo`050=nLB018W=l0oooO0000001d_ol0B03oool01`3ogi`0B000
07Boo`000000omnL04Q8W03Oool0B03oool01@3ookl0M00000000000B9`0gooo04L0oooo00/0omnL
04P0M02oool0oooo00000000B9`0gooo0?ooo`3ookl0M01809cOo`040?ooo`00803oool00`000000
oooo0?ooo`1;0?ooo`040000003ookl0M01809cOodL0oooo00D0oooO09a8B02Lgml0000007Boo`18
0?ooo`060?oOW018B9`0W7@00000000004P0W=ooB03oool01`3ookl0M01809cOo`000000gia80018
W03Oool0AP3oool02`3ogi`0B01d0;ooo`3oool0000004Q8W03Oool0oooo0?oo_`1d04P0W=oo00@0
oooo000P0?ooo`030000003oool0oooo04P0oooo00L0okmd001d_`3oool000000?ooo`2oM000M;oo
04P0oooo00@0omnL04Q8M0000000M;ooB03oool0103ookl0M01d0;ooo`00001:0?ooo`070?oOW018
B9`0gooo0000003ookl0M01d0;ooo`140?ooo`0=0;md000004P0W;nL04P0M02oool0oooo0000001d
07@0_ooo0?ooo`3ogi`0B01d0;ooo`040?ooo`00803oool00`000000oooo0?ooo`180?ooo`070?oo
_`1d04P0W=oo0000003ogi`0B01809cOo`190?ooo`030=nLB0000000M;oo04T0oooo00H0_g@007Bo
o`000000okmd0018W03Ooom70?ooo`070?oo_`1d04P0W=oo0000003OW4P004RL0=ooo`150?ooo`0;
0?noM0000000001d0;ooo`3oool0000009a8001d_ol0oooo0=nLB000M;l01@3oool00200oooo0`00
00190?ooo`050?oOW018000000000000001d_ol0BP3oool00`3ooml0000007Boo`190?ooo`050?oo
g`2LB00000000000B02Lgol0B@3oool01@3ogi`0B0000000000007@0_ooo04L0oooo00X0omnL04P0
M02oool0oooo0000003ookl0M00000000000B9`0gooo1@3oool00200oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00P0oooo000P0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`00803oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0203oool0
0200oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
00P0oooo000P0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`080?ooo`00803oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0203oool00200oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo00P0oooo000F0?ooool00000VP0000010?ooo`00803oool20000
0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`007P3oool600000100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`007P3oool6000002<0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001d0oooo2000000R0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0;`3oool001d0oooo2000000R0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0;`3oool001h0oooo1P00000R0?ooo`800000C@3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?oo
o`007P3oool600000200oooo1P00001;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`800000
8P3oool6000004/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo0`00000P0?ooo`P00000BP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`0P0?ooo`P00000BP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`0Q0?ooo`H00000B`3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`0Q0?ooo`H00000B`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`0S0?ooo`800000C@3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo02l0oooo000P0?ooo`<00000LP3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0
oooo0780oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0LP3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0
oooo000P0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0;`3oool00200oooo0`00001b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000
003oool0oooo0780oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo02l0oooo000P0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200
oooo00<000000?ooo`3oool0L@3oool2000004`0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo06l0oooo
1P00001:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1_0?ooo`H00000BP3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo0`00001^
0?ooo`P00000B@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0KP3oool8000004T0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`03
0000003oool0oooo06l0oooo1P00001:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1_0?ooo`H00000
BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
;`3oool00200oooo00<000000?ooo`3oool0L@3oool2000004`0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo02l0oooo000>0?ooo`030?oOW01807@0_ooo0080oooo00D0oono07@00000000004RL0=ooo`08
0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo02l0oooo000>0?ooo`0:0?oOW01807@0_ooo0?ooo`3ooml0W4P004RL
g`3oool0gia8001d_`P0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool000h0oooo00/0omnL04P0M02oool0
oooo0?oo_`1d07@0_ooo0?ooo`3ogi`0B01d0;ooo`070?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000>
0?ooo`0;0?oOW01807@0_ooo0?ooo`3ogi`0B4RL0=ooo`3oool0oono07@0B02Lgol01`3oool40000
0;h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
02l0oooo000>0?ooo`0;0?oOW01807@0_ooo0?ooo`3o_g@004RL0=ooo`3oool0oono07@0B02Lgol0
1`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0_0?ooo`003P3oool02`3ogi`0B01d0;ooo`3oool0omnL04Q8W03O
ool0oooo0?oo_`1d04P0W=oo00L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool000`0oooo00d0_g@00000
B02L_i`0B01d0;ooo`3oool0oono07@0M02oool0oooo0?oOW01807@0_ooo00L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0;`3oool000d0oooo00/0okmd0000000007@0_ooo0?ooo`3ooml0W4P007Boo`3oool0gia8
001d_`080?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000>0?ooo`030?oOW01807@0_ooo0080oooo00D0
oono07@00000000004RL0=ooo`080?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo02l0oooo000P0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
02l0oooo000P0?ooo`<00000_`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<0
00000?ooo`3oool0_`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0;`3oool00200oooo00<000000?ooo`3oool0_`3oool2000004`0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`2m0?ooo`H00000
BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003o
ool0oooo0;d0oooo1P00001:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3o
ool00200oooo00<000000?ooo`3oool0_03oool8000004T0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0_0?ooo`00803oool300000;`0oooo200000190?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0_@3oool6000004X0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo
0?ooo`2m0?ooo`H00000BP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo
000P0?ooo`030000003oool0oooo0;l0oooo0P00001<0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0o`3oool>0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3o
ool0o`3oool>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;`3oool00200oooo
00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
;`3oool00200oooo0`00003o0?ooo`h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803o
ool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0_0?ooo`00803oool300000?l0oooo
3P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003o
ool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P
0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0oooo
3P3oool2000004`0oooo00<000000?ooo`3oool0;`3oool000/0oooo00<0gia80000000000000`00
00001`1d_ol0oooo0?oo_`1d000000000018W03Oool0203oool00`000000oooo0?ooo`3o0?ooo``0
oooo1P00001:0?ooo`030000003oool0oooo02l0oooo000;0?ooo`030?oOW0180000M;oo00@0oooo
00H0oooO09a80018W=l0oooo0=nLB000M;l80?ooo`030000003oool0oooo0?l0oooo303oool60000
04X0oooo00<000000?ooo`3oool0;`3oool000`0oooo00<0omnL04P0001d_ol00`3oool01`3ookl0
M01d0;ooo`3oool0omnL04P0M02oool01`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo20000019
0?ooo`030000003oool0oooo02l0oooo000=0?ooo`030?oo_`1d0000B9cO0080oooo00L0omnL04Q8
W03Oool0oooo0?oo_`1d04P0W=oo00L0oooo1000003o0?ooo`X0oooo200000190?ooo`030000003o
ool0oooo02l0oooo000>0?ooo`0;0?oog`2LB000B9cO0?ooo`3o_g@004RL0=ooo`3oool0oono07@0
B02Lgol01`3oool00`000000oooo0?ooo`3o0?ooo``0oooo1P00001:0?ooo`030000003oool0oooo
02l0oooo000?0?ooo`0:0?oo_`1d04P0W=oo0?oOW018B9`0gooo0?ooo`3ookl0M01809cOo`L0oooo
00<000000?ooo`3oool0o`3oool<0?ooo`H00000BP3oool00`000000oooo0?ooo`0_0?ooo`002`3o
ool00`3o_g@007Bo0?ooo`020?ooo`090;md001d_ol0oono07@0M02oool0oooo0?oOW01807@0_ooo
00L0oooo00<000000?ooo`3oool0o`3oool>0?ooo`800000C03oool00`000000oooo0?ooo`0_0?oo
o`002`3oool03@3ookl0M01809cOo`3oool0omnL04P0B02Lgol0oooO09a8001d_ol0oooo0=nLB000
M;l0203oool00`000000oooo0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0;`3oool000`0oooo
00D0omnL04P000000000000007Boo`020?ooo`050?oo_`1d000000000018W03Oool0203oool00`00
0000oooo0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3o
ool0o`3ooomL0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0oooo
G03oool00`000000oooo0?ooo`0_0?ooo`00803oool300000?l0ooooG03oool00`000000oooo0?oo
o`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0;`3oool0
0200oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000003oool0oooo02l0oooo000P0?ooo`03
0000003oool0oooo0?l0ooooG03oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo
0?ooo`3o0?oooe`0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0o`3o
oomL0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0ooooG03oool0
0`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe`0oooo00<000000?oo
o`3oool0;`3oool00200oooo00<000000?ooo`3oool0o`3ooomL0?ooo`030000003oool0oooo02l0
oooo000P0?ooo`<00000o`3ooomL0?ooo`030000003oool0oooo02l0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooG03oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o
0?oooe`0oooo00<000000?ooo`3oool0;`3oool00200oooo00<000000?ooo`3oool0o`3ooomL0?oo
o`030000003oool0oooo02l0oooo000P0?ooo`030000003oool0oooo0?l0ooooG03oool00`000000
oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe/0oooo0P00000a0?ooo`00803o
ool00`000000oooo0?ooo`3o0?oooeT0oooo1P00000_0?ooo`00803oool00`000000oooo0?ooo`3o
0?oooeT0oooo1P00000_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooeP0oooo2000000^0?oo
o`00803oool300000?l0ooooF03oool8000002h0oooo000P0?ooo`030000003oool0oooo0?l0oooo
F@3oool6000002l0oooo000P0?ooo`030000003oool0oooo0?l0ooooF@3oool6000002l0oooo000P
0?ooo`030000003oool0oooo0?l0ooooF`3oool200000340oooo000P0?ooo`030000003oool0oooo
0?l0ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooohh0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.840541, -32.6942, \
0.0385984, 0.343494}}]
}, Open  ]],

Cell[TextData[{
  "Just as for ",
  StyleBox["DSolve", "MR"],
  ", fairly innocent equations for ",
  StyleBox["RSolve", "MR"],
  " can generate very complicated solutions. And ultimately there are not \
general enough functions to express all solutions in closed form. But these \
are some examples of what one might expect. "
}], "Text"],

Cell["A linear second order, varying coefficient equation. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ 
      y[n + 2]\  + \ \((n^2\  + \ 1)\)\ y[n + 1]\  + \ n^2\ y[n] \[Equal] 
        0, \ y, \ n\ ]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{n}, \(-\((\(-1\))\)\^n\)\ C[1] - \((\(-1\))\)\^n\ C[
                  2]\ \((HypergeometricPFQ[{1, 1, 1}, {}, 1] - 
                    Gamma[n]\^2\ HypergeometricPFQ[{1, n, n}, {}, 
                        1])\)]}}\)], "Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell["A nonlinear first order, equation. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ y[n + 1]\  \[Equal] \ 4\ y[n]\ \((1 - y[n])\), \ y, \ 
      n\ ]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \({{y \[Rule] Function[{n}, 1\/2 - 1\/2\ Cos[2\^n\ C[1]]]}}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell["A nonlinear second order, equation. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ y[n]\ y[n + 2] \[Equal] \ y[n + 1]\^2, \ y, \ n\ ]\)], "Input",\

  CellLabel->"In[86]:="],

Cell[BoxData[
    \({{y \[Rule] 
          Function[{n}, \[ExponentialE]\^\(C[1] + n\ C[2]\)]}}\)], "Output",
  CellLabel->"Out[86]="]
}, Closed]],

Cell["Some systems of equations can also be solved. ", "Text"],

Cell["\<\
A linear system of constant coefficient difference equations. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ 
      x\_1[k + 1]\  \[Equal] \ \ x\_2[k]\  && \ 
        x\_2[k + 1] \[Equal] \ \(-\ x\_1[k]\)\  - 2\ x\_2[k], \ {x\_1, \ 
        x\_2}, \ k\ ]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({{x\_1 \[Rule] 
          Function[{k}, \(-\((\(-1\))\)\^k\)\ \((\(-1\) + k)\)\ C[
                  1] - \((\(-1\))\)\^k\ k\ C[2]], 
        x\_2 \[Rule] 
          Function[{k}, \((\(-1\))\)\^k\ k\ C[1] + 
              C[2]\ ChebyshevU[k, \(-1\)]]}}\)], "Output",
  CellLabel->"Out[87]="]
}, Closed]],

Cell["\<\
A linear system of varying coefficient difference equations. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ {\(-\(\(\((1 + 3\ k + k\^2)\)\ u[k]\)\/k\^2\)\) + u[1 + k] + 
            v[k]\/k + \(\((1 + 2\ k)\)\ w[k]\)\/k\^2 == 
          0, \(-v[k]\) + \(\(1\/k\^2\)\((k\^2\ v[
                    1 + k] + \((1 + 2\ k)\)\ \((\(-u[k]\) + w[k])\))\)\) == 
          0, \(\(-u[k]\) + v[k] - k\ w[k] + k\ w[1 + k]\)\/k == 0}, \ {u, \ 
        v, \ w}, \ k\ ]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \({{u \[Rule] Function[{k}, k\^2\ C[1] + C[2] + k\ C[3]], 
        v \[Rule] Function[{k}, k\^2\ C[1] + C[2]], 
        w \[Rule] Function[{k}, C[2] + k\ C[3]]}}\)], "Output",
  CellLabel->"Out[88]="]
}, Closed]],

Cell["A linear system of difference algebraic equations. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ \[IndentingNewLine]{\[IndentingNewLine]x1[1 + k] + x2[k] + 
            2\ x3[k] - 2\ x3[1 + k] == 
          0, \(-27\)\ x1[k] - x1[1 + k] - 22\ x2[k] - 17\ x3[k] + 
            2\ x3[1 + k] == 0, 
        18\ x1[k] + 2\ x1[1 + k] + 14\ x2[k] + 3\ x2[1 + k] + 10\ x3[k] + 
            2\ x3[1 + k] == 0\[IndentingNewLine]}, \ {x1, \ x2, \ x3}, \ 
      k\ ]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({{x1 \[Rule] 
          Function[{k}, \(-2\^k\)\ 3\^\(1 - k\)\ C[2] + \((2\/3)\)\^k\ C[
                  1]\ \((\(-1\) + 
                    UnitStep[\(-1\) + k])\) + \((3\/2)\)\^\(1 - k\)\ C[
                  2]\ UnitStep[\(-1\) + k]], 
        x2 \[Rule] 
          Function[{k}, \(-2\^k\)\ 3\^\(2 - k\)\ C[2] + 
              2\ \((\(-\((2\/3)\)\^k\)\ C[
                        1]\ \((\(-1\) + 
                          UnitStep[\(-1\) + k])\) - \((3\/2)\)\^\(1 - k\)\ C[
                        2]\ UnitStep[\(-1\) + k])\)], 
        x3 \[Rule] 
          Function[{k}, 
            2\^\(1 + k\)\ 3\^\(2 - k\)\ C[2] + \((2\/3)\)\^k\ C[
                  1]\ \((\(-1\) + 
                    UnitStep[\(-1\) + k])\) + \((3\/2)\)\^\(1 - k\)\ C[
                  2]\ UnitStep[\(-1\) + k]]}}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
In the case where there are several independent variables we have a partial \
difference equation. In these cases the general solution is parametrized by \
general functions. \
\>", "Text"],

Cell[TextData[{
  "A linear partial difference equation, with a general arbitrary function ",
  Cell[BoxData[
      \(TraditionalForm\`\(C[1]\)[l\  - k]\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[\ u[k + 1, \ l + 1] \[Equal] \ a\ u[k, l], \ 
      u, \ {k, l}]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \({{u \[Rule] 
          Function[{k, l}, 
            a\^\(\(-1\) + k\)\ \(C[1]\)[\(-k\) + l]]}}\)], "Output",
  CellLabel->"Out[90]="]
}, Closed]],

Cell[TextData[{
  StyleBox["RSolve", "MR"],
  " can also solve so called ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-difference equations or divide-and-conquer equations. These are equations \
of the form: "
}], "Text"],

Cell[BoxData[
    \(F[k, \ y[k], \ y[q\ k], \ \[Ellipsis], \ y[q\^n\ k]\ ]\  \[Equal] \ 
      0\)], "DisplayMath"],

Cell["If you compare these to the normal difference equations: ", "Text"],

Cell[BoxData[
    \(F[k, \ y[k], \ y[k + 1], \ \[Ellipsis], \ y[k + n]]\  \[Equal] 
      0\)], "DisplayMath"],

Cell[TextData[{
  "You can see that the arguments to the dependent function ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " form an arithmetic sequence for difference equations and a geometric \
sequence for ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-difference equations and hence these are also often called arithmetic and \
geometric difference equations, respectively. "
}], "Text"],

Cell["\<\
Geometric difference equations often come up in analysis of algorithms, \
combinatorics and number theory.  \
\>", "Text"],

Cell["\<\
This a first order linear q-difference equation, that gives the number of \
comparisons when doing binary search. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[b[n] \[Equal] b[n/2] + 1\  && \ b[1] \[Equal] 1, b, 
      n]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \({{b \[Rule] Function[{n}, \(Log[2] + Log[n]\)\/Log[2]]}}\)], "Output",
  CellLabel->"Out[91]="]
}, Closed]],

Cell["\<\
This gives the arithmetic complexity for a fast Fourier transform operation. \
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[f[n] \[Equal] 2\ f[n/2] + \((3/2)\) n, f, n]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({{f \[Rule] 
          Function[{n}, 
            2\ n\ C[1] + \(3\ n\ Log[n]\)\/\(2\ Log[2]\)]}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Minimize / Maximize", "Section"],

Cell[TextData[{
  StyleBox["Minimize", "MR"],
  " and ",
  StyleBox["Maximize", "MR"],
  " optimize a function over a region specified by equations, inequalities, \
and domain specifications. "
}], "BulletText"],

Cell["Competitive Situation: Several unique solvers.", "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell["\<\
The rectangle with a given circumference and maximal area is a square. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Maximize[\ {x\ y, \ 2  x + 2  y \[Equal] 1}, \ {x, y}]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \({1\/16, {x \[Rule] 1\/4, y \[Rule] 1\/4}}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "This is the maximum volume box that be inscribed in a sphere or radius ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Maximize[\ {8\ x\_1\ x\_2\ x\_3, \ 
        x\_1\^2 + x\_2\^2 + x\_3\^2 \[LessEqual] 1\  && \ 
          x\_1 \[GreaterEqual] 0\  && \ x\_2\  \[GreaterEqual] 0\  && \ 
          x\_3 \[GreaterEqual] 0}, \ {x\_1, \ x\_2, \ x\_3}]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({8\/\(3\ \@3\), {x\_1 \[Rule] 1\/\@3, x\_2 \[Rule] 1\/\@3, 
        x\_3 \[Rule] 1\/\@3}}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
  "This maximizes the volume of a cylinder where the surface area is ",
  Cell[BoxData[
      \(TraditionalForm\`24\ \[Pi]\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Maximize[\ {\ \[Pi]\ \(r\^2\) h, 
        2  \[Pi]\ r\^2 + 2  \[Pi]\ r\ h \[Equal] 24\ \[Pi]\  && \ 
          r\  \[GreaterEqual] 0\  && \ h \[GreaterEqual] 0\ }, \ {r, \ 
        h}]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({16\ \[Pi], {r \[Rule] 2, h \[Rule] 4}}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell["This is a quadratic integer programming problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Maximize[2  x\^2 + x\ y - 3  y\^2 + 4  x, 
      x + y \[LessEqual] 5\/4 && 2  x + 4  y \[LessEqual] 3 && 
        x \[GreaterEqual] 0 && 
        y \[GreaterEqual] 0 && {x, y} \[Element] Integers, {x, y}]\)], "Input",\

  CellLabel->"In[22]:="],

Cell[BoxData[
    \({6, {x \[Rule] 1, y \[Rule] 0}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["DSolve", "Section"],

Cell[TextData[{
  StyleBox["DSolve", "MR"],
  " can now find all rational function solutions to systems of linear \
equations with rational coefficients. "
}], "BulletText"],

Cell[TextData[{
  StyleBox["DSolve", "MR"],
  " can solve all linear systems of constant coefficient differential \
algebraic equations."
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell["\<\
A linear system with rational function coefficients that has a rational \
solution.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", " ", "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "==", \(\(\((6 + 2\ t - 3\ t\^3 - t\^5)\)\ u[t]\)\/\(t\ \((\(-3\
\) - 2\ t + t\^2)\)\ \((\(-1\) + t\^3)\)\) + \(\((5 + t)\)\ v[t]\)\/\(\((\(-3\
\) - 2\ t + t\^2)\)\ \((\(-1\) + t\^3)\)\)\)}], ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "==", \(\(-\(\(4\ t\ \((\(-3\) - 2\ t + t\^2)\)\ u[
                          t]\)\/\(\((5 + t)\)\ \((\(-1\) + 
                            t\^3)\)\)\)\) + \(\((1 + 20\ t\^2 + 3\ t\^3)\)\ \
v[t]\)\/\(\((5 + t)\)\ \((\(-1\) + t\^3)\)\)\)}]}], "\[IndentingNewLine]", 
          "}"}], ",", "\[IndentingNewLine]", \({u, \ v}\), ",", " ", 
        "\[IndentingNewLine]", "t"}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({{u \[Rule] 
          Function[{t}, \(t\ C[1]\)\/\(\(-3\) - 2\ t + t\^2\) + \(t\^2\ \
C[2]\)\/\(\(-3\) - 2\ t + t\^2\)], 
        v \[Rule] 
          Function[{t}, 
            C[1]\/\(5 + t\) + \(t\^4\ C[2]\)\/\(5 + t\)]}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "In addition ",
  StyleBox["DSolve", "MR"],
  " can solve some singular or differential algebraic equations. In \
particular systems of linear equations of the form: "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`A . \(\(x\^\[Prime]\)(t)\) + B . \(x(t)\) = 
      g(t)\)]]], "DisplayFormula",
  FormatType->DefaultTraditionalFormatType],

Cell[TextData[{
  "When the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " is singular then this is a singular or differential algebraic system of \
equations. "
}], "Text"],

Cell["\<\
Notice how the general solution to this DAE have only two general parameters \
even though it is a system of order three. Basically one degree of freedom \
has been by having an implicit algebraic equation between state variables in \
these equations. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{\(x2[t]\), "+", \(2\ x3[t]\), "+", 
                RowBox[{
                  SuperscriptBox["x1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}], ",", 
            RowBox[{
              
              RowBox[{\(\(-27\)\ x1[t]\), "-", \(22\ x2[t]\), 
                "-", \(17\ x3[t]\), "-", 
                RowBox[{
                  SuperscriptBox["x1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}], ",", 
            RowBox[{
              
              RowBox[{\(18\ x1[t]\), "+", \(14\ x2[t]\), "+", \(10\ x3[t]\), 
                "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x1", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{
                    SuperscriptBox["x2", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}]}], "\[IndentingNewLine]", "}"}], ",", " ", 
        "\[IndentingNewLine]", \({x1, \ x2, \ x3}\), ",", " ", 
        "\[IndentingNewLine]", "t"}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({{x1 \[Rule] 
          Function[{t}, \(-C[1]\) - 
              3\ \[ExponentialE]\^\(\(2\ t\)/3\)\ C[2] + 
              3\/2\ \((\(-1\) + \[ExponentialE]\^\(\(2\ t\)/3\))\)\ C[2]], 
        x2 \[Rule] 
          Function[{t}, \(-9\)\ \[ExponentialE]\^\(\(2\ t\)/3\)\ C[2] + 
              2\ \((C[1] - 
                    3\/2\ \((\(-1\) + \[ExponentialE]\^\(\(2\ t\)/3\))\)\ C[
                        2])\)], 
        x3 \[Rule] 
          Function[{t}, \(-C[1]\) + 
              18\ \[ExponentialE]\^\(\(2\ t\)/3\)\ C[2] + 
              3\/2\ \((\(-1\) + \[ExponentialE]\^\(\(2\ t\)/3\))\)\ C[
                  2]]}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
In this case you only have the freedom to choose two initial values.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{\(x2[t]\), "+", \(2\ x3[t]\), "+", 
                RowBox[{
                  SuperscriptBox["x1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}], ",", 
            RowBox[{
              
              RowBox[{\(\(-27\)\ x1[t]\), "-", \(22\ x2[t]\), 
                "-", \(17\ x3[t]\), "-", 
                RowBox[{
                  SuperscriptBox["x1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}], ",", 
            RowBox[{
              
              RowBox[{\(18\ x1[t]\), "+", \(14\ x2[t]\), "+", \(10\ x3[t]\), 
                "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x1", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{"3", " ", 
                  RowBox[{
                    SuperscriptBox["x2", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["x3", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}]}], "==", 
              "0"}], ",", "\[IndentingNewLine]", \(x1[0] \[Equal] 1\), ",", 
            " ", \(x2[0] \[Equal] 1\)}], "\[IndentingNewLine]", "}"}], ",", 
        " ", "\[IndentingNewLine]", \({x1, \ x2, \ x3}\), ",", " ", 
        "\[IndentingNewLine]", "t"}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{x1 \[Rule] 
          Function[{t}, 1\/10\ \((7 + 3\ \[ExponentialE]\^\(\(2\ t\)/3\))\)], 
        x2 \[Rule] 
          Function[{t}, 
            1\/5\ \((\(-7\) + 12\ \[ExponentialE]\^\(\(2\ t\)/3\))\)], 
        x3 \[Rule] 
          Function[{t}, 
            1\/10\ \((7 - 
                  39\ \[ExponentialE]\^\(\(2\ t\)/3\))\)]}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["The implied initial value of the last variable.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x3[0]\  /. \ First[\ %\ ]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\(-\(16\/5\)\)\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Assuming / Refine", "Section"],

Cell["\<\
Refine is essentially symbolic evaluation with assumptions. \
\>", "BulletText"],

Cell[TextData[{
  "By using ",
  StyleBox["Assuming", "MR"],
  " you make assumptions available to all functions that take the ",
  StyleBox["Assumptions", "MR"],
  " option. "
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell["\<\
The first expression is numeric, the second expression is symbolic, but with \
appropriate assumptions it generates the same form.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Log[2\^\[Pi]]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\[Pi]\ Log[2]\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Refine[Log[a\^b], a > 0 && b > 0]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(b\ Log[a]\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
Another example of where symbolic refining is possible with the right \
assumptions. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[12345\ \[Pi]]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Refine[Sin[k\ \[Pi]], k \[Element] Integers]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["Some examples go further then one might at first expect. ", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Refine[\@\((x\^2 + y\^2 - x\ y)\)\^2, x > y]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(x\^2 - x\ y + y\^2\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
The result you get may very well depend heavily on your assumptions. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(e = \@\(x\ y\^2\ z\^4\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(\@\(x\ y\^2\ z\^4\)\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ x\  > \ 0, Refine[\ e]]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(\@x\ \@\(y\^2\ z\^4\)\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ x > 0\  && \ y < 0, Refine[\ e]]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\(-\@x\)\ y\ \@z\^4\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ x > 0\  && \ y < 0\  && \ z > 0, \ Refine[\ e]]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(\(-\@x\)\ y\ z\^2\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
This is the cumulative density function of the normal distribution, which has \
a simple form if we make some assumptions about the parameters. \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ \[Sigma] > 
        0, \[IndentingNewLine]F\  = \ \[Integral]\_\(-\[Infinity]\)\%y\( 
                1\/\(\@\(2\ \[Pi]\)\ \[Sigma]\)\) 
            Exp[\(-\(\((x - \[Mu])\)\^2\/\(2\ \[Sigma]\^2\)\)\)] \
\[DifferentialD]x\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(1\/2\ \((1 + Erf[\(y - \[Mu]\)\/\(\@2\ \[Sigma]\)])\)\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["\<\
As expected in this case the limit of this cumulative density function is \
one.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ \[Sigma] > 0, \ 
      Limit[\ F, \ y \[Rule] \[Infinity]]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "Putting these things together, both ",
  StyleBox["Integrate", "MR"],
  " and ",
  StyleBox["Limit", "MR"],
  " pick up the assumption. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Assuming[\ \[Sigma] > 
        0, \[IndentingNewLine]F\  = \ \[Integral]\_\(-\[Infinity]\)\%y\( 
                1\/\(\@\(2\ \[Pi]\)\ \[Sigma]\)\) 
            Exp[\(-\(\((x - \[Mu])\)\^2\/\(2\ \[Sigma]\^2\)\)\)] \
\[DifferentialD]x; \[IndentingNewLine]Limit[\ F, \ 
        y \[Rule] \[Infinity]]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Resolve", "Section"],

Cell[TextData[{
  StyleBox["Resolve", "MR"],
  " eliminates quantifiers from formulae and produce an equivalent formulae \
free of quantifiers. "
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell["\<\
Quantifier elimination is a general and convenient way to formulate many \
types of problems. \
\>", "Text"],

Cell[TextData[{
  "This tests whether the unit disk ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2 < 1\)]],
  " is a subset of the sublevel set ",
  Cell[BoxData[
      \(TraditionalForm\`y > x\^4 - 2\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Resolve[\ \[ForAll] \_{x, y}Implies[x\^2 + y\^2 < 1, 
          y > x\^4 - 2]\ ]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["In this case we can visually check this as well. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]InequalityPlot[\ 
          y > x\^4 - 2, \ {x, \ \(-2\), \ 2}, \ {y, \ \(-2\), \ 
            2}, \ \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), \ 
                2}, \ {\(-2\), \ 2}}], 
        InequalityPlot[\ 
          x\^2 + y\^2 < 
            1, \ {x}, \ {y}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), \ 
                2}, \ {\(-2\), \ 
                2}}, \ \[IndentingNewLine]Fills \[Rule] \ {{{1, 2}, \ 
                RGBColor[1, 0, 0]}}]];\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6.96875 -10.9375 ]
[0 .4875 6.96875 0 ]
[.125 .4875 -10.3125 -10.9375 ]
[.125 .4875 10.3125 0 ]
[.25 .4875 -6.96875 -10.9375 ]
[.25 .4875 6.96875 0 ]
[.375 .4875 -10.3125 -10.9375 ]
[.375 .4875 10.3125 0 ]
[.625 .4875 -7.5625 -10.9375 ]
[.625 .4875 7.5625 0 ]
[.75 .4875 -4.21875 -10.9375 ]
[.75 .4875 4.21875 0 ]
[.875 .4875 -7.5625 -10.9375 ]
[.875 .4875 7.5625 0 ]
[1 .4875 -4.21875 -10.9375 ]
[1 .4875 4.21875 0 ]
[.4875 0 -13.9375 -5.46875 ]
[.4875 0 0 5.46875 ]
[.4875 .125 -20.625 -5.46875 ]
[.4875 .125 0 5.46875 ]
[.4875 .25 -13.9375 -5.46875 ]
[.4875 .25 0 5.46875 ]
[.4875 .375 -20.625 -5.46875 ]
[.4875 .375 0 5.46875 ]
[.4875 .625 -15.125 -5.46875 ]
[.4875 .625 0 5.46875 ]
[.4875 .75 -8.4375 -5.46875 ]
[.4875 .75 0 5.46875 ]
[.4875 .875 -15.125 -5.46875 ]
[.4875 .875 0 5.46875 ]
[.4875 1 -8.4375 -5.46875 ]
[.4875 1 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
gsave
.4875 0 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.14645 1 m
.17513 .71287 L
.20642 .47546 L
.2358 .31184 L
.26405 .19836 L
.27858 .15382 L
.29413 .11497 L
.30888 .08538 L
.3249 .06016 L
.34031 .04161 L
.35455 .02865 L
.36845 .01917 L
.37645 .01491 L
.38376 .01168 L
.39817 .00688 L
.40612 .00497 L
.41367 .00355 L
.42079 .00252 L
.42838 .00168 L
.43554 .00111 L
.44203 .00072 L
.44565 .00056 L
.44947 .00042 L
.45278 .00032 L
.45632 .00023 L
.46013 .00016 L
.46369 .00011 L
.46586 9e-005 L
.46792 7e-005 L
.46991 5e-005 L
.47178 4e-005 L
.47519 2e-005 L
.477 2e-005 L
.47895 1e-005 L
.48088 1e-005 L
.48292 1e-005 L
.48466 0 L
.48564 0 L
.48656 0 L
.48742 0 L
.48834 0 L
.48916 0 L
.49003 0 L
.49081 0 L
.49166 0 L
.49244 0 L
.49317 0 L
.49409 0 L
.49495 0 L
.49573 0 L
Mistroke
.49658 0 L
.4975 0 L
.49848 0 L
.4994 0 L
.50024 0 L
.50113 0 L
.50197 0 L
.50289 0 L
.50387 0 L
.50436 0 L
.5049 0 L
.50587 0 L
.50682 0 L
.5077 0 L
.50852 0 L
.50928 0 L
.51012 0 L
.51103 0 L
.51192 0 L
.51287 0 L
.51456 0 L
.51553 0 L
.51641 0 L
.51839 1e-005 L
.52022 1e-005 L
.52195 1e-005 L
.52397 2e-005 L
.52583 3e-005 L
.52802 4e-005 L
.53002 5e-005 L
.53351 8e-005 L
.53724 .00012 L
.5407 .00018 L
.54398 .00024 L
.5478 .00033 L
.55132 .00044 L
.55517 .00059 L
.55932 .00079 L
.56645 .00125 L
.57316 .00183 L
.58113 .00277 L
.58845 .00392 L
.59571 .00537 L
.60248 .00706 L
.61038 .0095 L
.61784 .01234 L
.63301 .02003 L
.64681 .02973 L
.66165 .0437 L
.67534 .0605 L
Mistroke
.68926 .08211 L
.70458 .1121 L
.72021 .15049 L
.7345 .19354 L
.7633 .30762 L
.7928 .4704 L
.82117 .68098 L
.85137 .97547 L
.85355 1 L
Mfstroke
.14645 1 m
.17513 1 L
.20642 1 L
.2358 1 L
.26405 1 L
.29413 1 L
.32308 1 L
.35385 1 L
.3835 1 L
.41202 1 L
.44236 1 L
.47158 1 L
.49967 1 L
.52958 1 L
.55837 1 L
.58897 1 L
.61846 1 L
.64681 1 L
.67699 1 L
.70604 1 L
.73692 1 L
.76666 1 L
.79529 1 L
.82573 1 L
.85355 1 L
s
0 1 1 r
.14645 1 m
.17513 .71287 L
.20642 .47546 L
.2358 .31184 L
.26405 .19836 L
.27858 .15382 L
.29413 .11497 L
.30888 .08538 L
.3249 .06016 L
.34031 .04161 L
.35455 .02865 L
.36845 .01917 L
.37645 .01491 L
.38376 .01168 L
.39817 .00688 L
.40612 .00497 L
.41367 .00355 L
.42079 .00252 L
.42838 .00168 L
.43554 .00111 L
.44203 .00072 L
.44565 .00056 L
.44947 .00042 L
.45278 .00032 L
.45632 .00023 L
.46013 .00016 L
.46369 .00011 L
.46586 9e-005 L
.46792 7e-005 L
.46991 5e-005 L
.47178 4e-005 L
.47519 2e-005 L
.477 2e-005 L
.47895 1e-005 L
.48088 1e-005 L
.48292 1e-005 L
.48466 0 L
.48564 0 L
.48656 0 L
.48742 0 L
.48834 0 L
.48916 0 L
.49003 0 L
.49081 0 L
.49166 0 L
.49244 0 L
.49317 0 L
.49409 0 L
.49495 0 L
.49573 0 L
.49658 0 L
.4975 0 L
.49848 0 L
.4994 0 L
.50024 0 L
.50113 0 L
.50197 0 L
.50289 0 L
.50387 0 L
.50436 0 L
.5049 0 L
.50587 0 L
.50682 0 L
.5077 0 L
.50852 0 L
.50928 0 L
.51012 0 L
.51103 0 L
.51192 0 L
.51287 0 L
.51456 0 L
.51553 0 L
.51641 0 L
.51839 1e-005 L
.52022 1e-005 L
.52195 1e-005 L
.52397 2e-005 L
.52583 3e-005 L
.52802 4e-005 L
.53002 5e-005 L
.53351 8e-005 L
.53724 .00012 L
.5407 .00018 L
.54398 .00024 L
.5478 .00033 L
.55132 .00044 L
.55517 .00059 L
.55932 .00079 L
.56645 .00125 L
.57316 .00183 L
.58113 .00277 L
.58845 .00392 L
.59571 .00537 L
.60248 .00706 L
.61038 .0095 L
.61784 .01234 L
.63301 .02003 L
.64681 .02973 L
.66165 .0437 L
.67534 .0605 L
.68926 .08211 L
.70458 .1121 L
.72021 .15049 L
.7345 .19354 L
.7633 .30762 L
.7928 .4704 L
.82117 .68098 L
.85137 .97547 L
.85355 1 L
.85355 1 L
.82573 1 L
.79529 1 L
.76666 1 L
.73692 1 L
.70604 1 L
.67699 1 L
.64681 1 L
.61846 1 L
.58897 1 L
.55837 1 L
.52958 1 L
.49967 1 L
.47158 1 L
.44236 1 L
.41202 1 L
.3835 1 L
.35385 1 L
.32308 1 L
.29413 1 L
.26405 1 L
.2358 1 L
.20642 1 L
.17513 1 L
.14645 1 L
F
0 g
.14645 1 m
.17513 .71287 L
.20642 .47546 L
.2358 .31184 L
.26405 .19836 L
.27858 .15382 L
.29413 .11497 L
.30888 .08538 L
.3249 .06016 L
.34031 .04161 L
.35455 .02865 L
.36845 .01917 L
.37645 .01491 L
.38376 .01168 L
.39817 .00688 L
.40612 .00497 L
.41367 .00355 L
.42079 .00252 L
.42838 .00168 L
.43554 .00111 L
.44203 .00072 L
.44565 .00056 L
.44947 .00042 L
.45278 .00032 L
.45632 .00023 L
.46013 .00016 L
.46369 .00011 L
.46586 9e-005 L
.46792 7e-005 L
.46991 5e-005 L
.47178 4e-005 L
.47519 2e-005 L
.477 2e-005 L
.47895 1e-005 L
.48088 1e-005 L
.48292 1e-005 L
.48466 0 L
.48564 0 L
.48656 0 L
.48742 0 L
.48834 0 L
.48916 0 L
.49003 0 L
.49081 0 L
.49166 0 L
.49244 0 L
.49317 0 L
.49409 0 L
.49495 0 L
.49573 0 L
Mistroke
.49658 0 L
.4975 0 L
.49848 0 L
.4994 0 L
.50024 0 L
.50113 0 L
.50197 0 L
.50289 0 L
.50387 0 L
.50436 0 L
.5049 0 L
.50587 0 L
.50682 0 L
.5077 0 L
.50852 0 L
.50928 0 L
.51012 0 L
.51103 0 L
.51192 0 L
.51287 0 L
.51456 0 L
.51553 0 L
.51641 0 L
.51839 1e-005 L
.52022 1e-005 L
.52195 1e-005 L
.52397 2e-005 L
.52583 3e-005 L
.52802 4e-005 L
.53002 5e-005 L
.53351 8e-005 L
.53724 .00012 L
.5407 .00018 L
.54398 .00024 L
.5478 .00033 L
.55132 .00044 L
.55517 .00059 L
.55932 .00079 L
.56645 .00125 L
.57316 .00183 L
.58113 .00277 L
.58845 .00392 L
.59571 .00537 L
.60248 .00706 L
.61038 .0095 L
.61784 .01234 L
.63301 .02003 L
.64681 .02973 L
.66165 .0437 L
.67534 .0605 L
Mistroke
.68926 .08211 L
.70458 .1121 L
.72021 .15049 L
.7345 .19354 L
.7633 .30762 L
.7928 .4704 L
.82117 .68098 L
.85137 .97547 L
.85355 1 L
Mfstroke
.14645 1 m
.17513 1 L
.20642 1 L
.2358 1 L
.26405 1 L
.29413 1 L
.32308 1 L
.35385 1 L
.3835 1 L
.41202 1 L
.44236 1 L
.47158 1 L
.49967 1 L
.52958 1 L
.55837 1 L
.58897 1 L
.61846 1 L
.64681 1 L
.67699 1 L
.70604 1 L
.73692 1 L
.76666 1 L
.79529 1 L
.82573 1 L
.85355 1 L
s
.25 .4999 m
.25062 .48244 L
.25118 .47575 L
.25244 .46516 L
.25471 .45169 L
.25737 .43976 L
.25987 .43043 L
.27028 .40136 L
.28089 .37962 L
.2924 .3607 L
.31386 .33311 L
.33452 .31261 L
.35438 .29679 L
.37553 .28319 L
.39589 .27271 L
.41753 .26399 L
.42834 .26049 L
.43838 .25771 L
.4487 .25532 L
.45843 .25348 L
.4692 .2519 L
.47897 .25089 L
.4841 .25051 L
.4869 .25034 L
.48951 .25022 L
.49174 .25014 L
.49414 .25007 L
.4955 .25004 L
.49617 .25003 L
.49679 .25002 L
.49734 .25001 L
.49795 .25001 L
.49856 .25 L
.49921 .25 L
.49985 .25 L
.50044 .25 L
.5011 .25 L
.50146 .25 L
.50179 .25001 L
.50246 .25001 L
.50319 .25002 L
.50451 .25004 L
.50574 .25007 L
.50704 .2501 L
.50937 .25018 L
.51206 .25029 L
.51458 .25043 L
.52032 .25083 L
.52578 .25133 L
.53097 .25193 L
Mistroke
.5407 .25334 L
.55112 .25528 L
.56078 .2575 L
.58135 .26361 L
.60321 .2723 L
.62427 .28307 L
.64454 .29602 L
.66609 .31315 L
.68685 .33391 L
.70681 .35954 L
.71793 .37751 L
.72806 .39759 L
.7331 .40964 L
.73857 .42528 L
.74108 .43382 L
.74374 .44441 L
.74601 .45553 L
.74722 .46281 L
.74852 .4728 L
.74889 .47651 L
.74929 .48118 L
.74963 .4864 L
.75 .4999 L
Mfstroke
.25 .5001 m
.25062 .51756 L
.25118 .52425 L
.25244 .53484 L
.25471 .54831 L
.25737 .56024 L
.25987 .56957 L
.27028 .59864 L
.28089 .62038 L
.2924 .6393 L
.31386 .66689 L
.33452 .68739 L
.35438 .70321 L
.37553 .71681 L
.39589 .72729 L
.41753 .73601 L
.42834 .73951 L
.43838 .74229 L
.4487 .74468 L
.45843 .74652 L
.4692 .7481 L
.47897 .74911 L
.4841 .74949 L
.4869 .74966 L
.48951 .74978 L
.49174 .74986 L
.49414 .74993 L
.4955 .74996 L
.49617 .74997 L
.49679 .74998 L
.49734 .74999 L
.49795 .74999 L
.49856 .75 L
.49921 .75 L
.49985 .75 L
.50044 .75 L
.5011 .75 L
.50146 .75 L
.50179 .74999 L
.50246 .74999 L
.50319 .74998 L
.50451 .74996 L
.50574 .74993 L
.50704 .7499 L
.50937 .74982 L
.51206 .74971 L
.51458 .74957 L
.52032 .74917 L
.52578 .74867 L
.53097 .74807 L
Mistroke
.5407 .74666 L
.55112 .74472 L
.56078 .7425 L
.58135 .73639 L
.60321 .7277 L
.62427 .71693 L
.64454 .70398 L
.66609 .68685 L
.68685 .66609 L
.70681 .64046 L
.71793 .62249 L
.72806 .60241 L
.7331 .59036 L
.73857 .57472 L
.74108 .56618 L
.74374 .55559 L
.74601 .54447 L
.74722 .53719 L
.74852 .5272 L
.74889 .52349 L
.74929 .51882 L
.74963 .5136 L
.75 .5001 L
Mfstroke
1 0 0 r
.25 .4999 m
.25062 .48244 L
.25118 .47575 L
.25244 .46516 L
.25471 .45169 L
.25737 .43976 L
.25987 .43043 L
.27028 .40136 L
.28089 .37962 L
.2924 .3607 L
.31386 .33311 L
.33452 .31261 L
.35438 .29679 L
.37553 .28319 L
.39589 .27271 L
.41753 .26399 L
.42834 .26049 L
.43838 .25771 L
.4487 .25532 L
.45843 .25348 L
.4692 .2519 L
.47897 .25089 L
.4841 .25051 L
.4869 .25034 L
.48951 .25022 L
.49174 .25014 L
.49414 .25007 L
.4955 .25004 L
.49617 .25003 L
.49679 .25002 L
.49734 .25001 L
.49795 .25001 L
.49856 .25 L
.49921 .25 L
.49985 .25 L
.50044 .25 L
.5011 .25 L
.50146 .25 L
.50179 .25001 L
.50246 .25001 L
.50319 .25002 L
.50451 .25004 L
.50574 .25007 L
.50704 .2501 L
.50937 .25018 L
.51206 .25029 L
.51458 .25043 L
.52032 .25083 L
.52578 .25133 L
.53097 .25193 L
.5407 .25334 L
.55112 .25528 L
.56078 .2575 L
.58135 .26361 L
.60321 .2723 L
.62427 .28307 L
.64454 .29602 L
.66609 .31315 L
.68685 .33391 L
.70681 .35954 L
.71793 .37751 L
.72806 .39759 L
.7331 .40964 L
.73857 .42528 L
.74108 .43382 L
.74374 .44441 L
.74601 .45553 L
.74722 .46281 L
.74852 .4728 L
.74889 .47651 L
.74929 .48118 L
.74963 .4864 L
.75 .4999 L
.75 .5001 L
.74963 .5136 L
.74929 .51882 L
.74889 .52349 L
.74852 .5272 L
.74722 .53719 L
.74601 .54447 L
.74374 .55559 L
.74108 .56618 L
.73857 .57472 L
.7331 .59036 L
.72806 .60241 L
.71793 .62249 L
.70681 .64046 L
.68685 .66609 L
.66609 .68685 L
.64454 .70398 L
.62427 .71693 L
.60321 .7277 L
.58135 .73639 L
.56078 .7425 L
.55112 .74472 L
.5407 .74666 L
.53097 .74807 L
.52578 .74867 L
.52032 .74917 L
.51458 .74957 L
.51206 .74971 L
.50937 .74982 L
.50704 .7499 L
.50574 .74993 L
.50451 .74996 L
.50319 .74998 L
.50246 .74999 L
.50179 .74999 L
.50146 .75 L
.5011 .75 L
.50044 .75 L
.49985 .75 L
.49921 .75 L
.49856 .75 L
.49795 .74999 L
.49734 .74999 L
.49679 .74998 L
.49617 .74997 L
.4955 .74996 L
.49414 .74993 L
.49174 .74986 L
.48951 .74978 L
.4869 .74966 L
.4841 .74949 L
.47897 .74911 L
.4692 .7481 L
.45843 .74652 L
.4487 .74468 L
.43838 .74229 L
.42834 .73951 L
.41753 .73601 L
.39589 .72729 L
.37553 .71681 L
.35438 .70321 L
.33452 .68739 L
.31386 .66689 L
.2924 .6393 L
.28089 .62038 L
.27028 .59864 L
.25987 .56957 L
.25737 .56024 L
.25471 .54831 L
.25244 .53484 L
.25118 .52425 L
.25062 .51756 L
.25 .5001 L
F
0 g
.25 .4999 m
.25062 .48244 L
.25118 .47575 L
.25244 .46516 L
.25471 .45169 L
.25737 .43976 L
.25987 .43043 L
.27028 .40136 L
.28089 .37962 L
.2924 .3607 L
.31386 .33311 L
.33452 .31261 L
.35438 .29679 L
.37553 .28319 L
.39589 .27271 L
.41753 .26399 L
.42834 .26049 L
.43838 .25771 L
.4487 .25532 L
.45843 .25348 L
.4692 .2519 L
.47897 .25089 L
.4841 .25051 L
.4869 .25034 L
.48951 .25022 L
.49174 .25014 L
.49414 .25007 L
.4955 .25004 L
.49617 .25003 L
.49679 .25002 L
.49734 .25001 L
.49795 .25001 L
.49856 .25 L
.49921 .25 L
.49985 .25 L
.50044 .25 L
.5011 .25 L
.50146 .25 L
.50179 .25001 L
.50246 .25001 L
.50319 .25002 L
.50451 .25004 L
.50574 .25007 L
.50704 .2501 L
.50937 .25018 L
.51206 .25029 L
.51458 .25043 L
.52032 .25083 L
.52578 .25133 L
.53097 .25193 L
Mistroke
.5407 .25334 L
.55112 .25528 L
.56078 .2575 L
.58135 .26361 L
.60321 .2723 L
.62427 .28307 L
.64454 .29602 L
.66609 .31315 L
.68685 .33391 L
.70681 .35954 L
.71793 .37751 L
.72806 .39759 L
.7331 .40964 L
.73857 .42528 L
.74108 .43382 L
.74374 .44441 L
.74601 .45553 L
.74722 .46281 L
.74852 .4728 L
.74889 .47651 L
.74929 .48118 L
.74963 .4864 L
.75 .4999 L
Mfstroke
.25 .5001 m
.25062 .51756 L
.25118 .52425 L
.25244 .53484 L
.25471 .54831 L
.25737 .56024 L
.25987 .56957 L
.27028 .59864 L
.28089 .62038 L
.2924 .6393 L
.31386 .66689 L
.33452 .68739 L
.35438 .70321 L
.37553 .71681 L
.39589 .72729 L
.41753 .73601 L
.42834 .73951 L
.43838 .74229 L
.4487 .74468 L
.45843 .74652 L
.4692 .7481 L
.47897 .74911 L
.4841 .74949 L
.4869 .74966 L
.48951 .74978 L
.49174 .74986 L
.49414 .74993 L
.4955 .74996 L
.49617 .74997 L
.49679 .74998 L
.49734 .74999 L
.49795 .74999 L
.49856 .75 L
.49921 .75 L
.49985 .75 L
.50044 .75 L
.5011 .75 L
.50146 .75 L
.50179 .74999 L
.50246 .74999 L
.50319 .74998 L
.50451 .74996 L
.50574 .74993 L
.50704 .7499 L
.50937 .74982 L
.51206 .74971 L
.51458 .74957 L
.52032 .74917 L
.52578 .74867 L
.53097 .74807 L
Mistroke
.5407 .74666 L
.55112 .74472 L
.56078 .7425 L
.58135 .73639 L
.60321 .7277 L
.62427 .71693 L
.64454 .70398 L
.66609 .68685 L
.68685 .66609 L
.70681 .64046 L
.71793 .62249 L
.72806 .60241 L
.7331 .59036 L
.73857 .57472 L
.74108 .56618 L
.74374 .55559 L
.74601 .54447 L
.74722 .53719 L
.74852 .5272 L
.74889 .52349 L
.74929 .51882 L
.74963 .5136 L
.75 .5001 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.25 0.5 0.25 [
[0 .4875 -6.96875 -10.9375 ]
[0 .4875 6.96875 0 ]
[.125 .4875 -10.3125 -10.9375 ]
[.125 .4875 10.3125 0 ]
[.25 .4875 -6.96875 -10.9375 ]
[.25 .4875 6.96875 0 ]
[.375 .4875 -10.3125 -10.9375 ]
[.375 .4875 10.3125 0 ]
[.625 .4875 -7.5625 -10.9375 ]
[.625 .4875 7.5625 0 ]
[.75 .4875 -4.21875 -10.9375 ]
[.75 .4875 4.21875 0 ]
[.875 .4875 -7.5625 -10.9375 ]
[.875 .4875 7.5625 0 ]
[1 .4875 -4.21875 -10.9375 ]
[1 .4875 4.21875 0 ]
[.4875 0 -13.9375 -5.46875 ]
[.4875 0 0 5.46875 ]
[.4875 .125 -20.625 -5.46875 ]
[.4875 .125 0 5.46875 ]
[.4875 .25 -13.9375 -5.46875 ]
[.4875 .25 0 5.46875 ]
[.4875 .375 -20.625 -5.46875 ]
[.4875 .375 0 5.46875 ]
[.4875 .625 -15.125 -5.46875 ]
[.4875 .625 0 5.46875 ]
[.4875 .75 -8.4375 -5.46875 ]
[.4875 .75 0 5.46875 ]
[.4875 .875 -15.125 -5.46875 ]
[.4875 .875 0 5.46875 ]
[.4875 1 -8.4375 -5.46875 ]
[.4875 1 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
gsave
0 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 .5 m
.125 .50625 L
s
gsave
.125 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.25 .5 m
.25 .50625 L
s
gsave
.25 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.375 .5 m
.375 .50625 L
s
gsave
.375 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.625 .5 m
.625 .50625 L
s
gsave
.625 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.75 .5 m
.75 .50625 L
s
gsave
.75 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.875 .5 m
.875 .50625 L
s
gsave
.875 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .5 m
1 .50625 L
s
gsave
1 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
gsave
.4875 0 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .125 m
.50625 .125 L
s
gsave
.4875 .125 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 .25 m
.50625 .25 L
s
gsave
.4875 .25 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .375 m
.50625 .375 L
s
gsave
.4875 .375 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .625 m
.50625 .625 L
s
gsave
.4875 .625 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .75 m
.50625 .75 L
s
gsave
.4875 .75 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .875 m
.50625 .875 L
s
gsave
.4875 .875 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.5 1 m
.50625 1 L
s
gsave
.4875 1 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00bP3oool00`34Ga@00000000000030000000303F?o`3oool0oooo0=d0oooo003:0?ooo`03
0?o4G`0D0000=Hoo0><0oooo003;0?ooo`030?o4G`0D0000=Hoo0>80oooo002m0?ooocT00000^P3o
ool00;@0oooo2@00000@003oo`03003og`00B00009cO00T00?oo00<00000003oo`00ool06P00ool7
00000;<0oooo002a0?ooo`<000006P00ool00`00okl00018003Oo`08003oo`0300000000ool00?oo
02400?oo1@00002^0?ooo`00[P3oool3000001T00?oo00<00;md001d_`00ool00P00ool00`00M000
0;oo003oo`07003oo`0300000000ool00?oo02H00?oo0`00002[0?ooo`00Z`3oool3000001`00?oo
00L00?no0000B000gol00?oo003OW00004P00=oo00P00?oo00<00000003oo`00ool0:@00ool40000
0:L0oooo002X0?ooo`<000008000ool01@00gi`000000000000000000;oo00T00?oo00<00000003o
o`00ool0;@00ool200000:D0oooo002V0?ooo`800000<@00ool00`0000000?oo003oo`0_003oo`80
0000X`3oool00:@0oooo0P00000c003oo`0300000000ool00?oo03400?oo0P00002Q0?ooo`00X`3o
ool00`0000000?oo003oo`0c003oo`0300000000ool00?oo03<00?oo0P00002O0?ooo`00X@3oool2
000003H00?oo00<00000003oo`00ool0=@00ool2000009d0oooo002P0?ooo`0300000000ool00?oo
03H00?oo0`00000g003oo`030000003oool0oooo09X0oooo002N0?ooo`800000>@00ool00`000000
0?oo003oo`0h003oo`800000VP3oool009d0oooo00<00000003oo`00ool0>@00ool00`0000000?oo
003oo`0j003oo`030000003oool0oooo09L0oooo002L0?ooo`0300000000ool00?oo03X00?oo00<0
0000003oo`00ool0>`00ool00`000000oooo0?ooo`2F0?ooo`00V`3oool00`0000000?oo003oo`0k
003oo`0300000000ool00?oo03`00?oo00<000000?ooo`3oool0U@3oool009T0oooo0P00000n003o
o`0300000000ool00?oo03d00?oo00<000000?ooo`3oool0U03oool009P0oooo00<00000003oo`00
ool0?P00ool00`0000000?oo003oo`0n003oo`030000003oool0oooo09<0oooo002G0?ooo`030000
0000ool00?oo03l00?oo00<00000003oo`00ool0?`00ool00`000000oooo0?ooo`2B0?ooo`00UP3o
ool00`0000000?oo003oo`10003oo`0300000000ool00?oo04000?oo00<000000?ooo`3oool0T@3o
ool009D0oooo00<00000003oo`00ool0@@00ool00`0000000?oo003oo`11003oo`030000003oool0
oooo0900oooo002E0?ooo`0300000000ool00?oo04400?oo00<00000003oo`00ool0@P00ool00`00
0000oooo0?ooo`2?0?ooo`00U03oool00`0000000?oo003oo`12003oo`<00000@`00ool00`000000
oooo0?ooo`2>0?ooo`00T`3oool00`0000000?oo003oo`13003oo`0300000000ool00?oo04<00?oo
00<000000?ooo`3oool0SP3oool00980oooo00<00000003oo`00ool0A000ool00`0000000?oo003o
o`14003oo`030000003oool0oooo08d0oooo002B0?ooo`0300000000ool00?oo04@00?oo00<00000
003oo`00ool0A@00ool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`0000000?oo003oo`15003o
o`0300000000ool00?oo04H00?oo00<000000?ooo`3oool0R`3oool00900oooo00<00000003oo`00
ool0AP00ool00`0000000?oo003oo`17003oo`030000003oool0oooo08X0oooo002@0?ooo`030000
0000ool00?oo04H00?oo00<00000003oo`00ool0A`00ool00`000000oooo0?ooo`2:0?ooo`00S`3o
ool00`0000000?oo003oo`17003oo`0300000000ool00?oo04P00?oo00<000000?ooo`3oool0R@3o
ool008h0oooo00<00000003oo`00ool0B000ool00`0000000?oo003oo`18003oo`030000003oool0
oooo08T0oooo002=0?ooo`0300000000ool00?oo04T00?oo00<00000003oo`00ool0B@00ool00`00
0000oooo0?ooo`280?ooo`00S@3oool00`0000000?oo003oo`19003oo`<00000B@00ool00`000000
oooo0?ooo`280?ooo`00S03oool00`0000000?oo003oo`1:003oo`0300000000ool00?oo04X00?oo
00<000000?ooo`3oool0Q`3oool008/0oooo00<00000003oo`00ool0B`00ool00`0000000?oo003o
o`1:003oo`030000003oool0oooo08L0oooo002;0?ooo`0300000000ool00?oo04/00?oo00<00000
003oo`00ool0B`00ool00`000000oooo0?ooo`260?ooo`00RP3oool00`0000000?oo003oo`1<003o
o`0300000000ool00?oo04`00?oo00<000000?ooo`3oool0Q@3oool008X0oooo00<00000003oo`00
ool0C000ool00`0000000?oo003oo`1<003oo`030000003oool0oooo08D0oooo00290?ooo`030000
0000ool00?oo04d00?oo00<00000003oo`00ool0C@00ool00`000000oooo0?ooo`240?ooo`00R@3o
ool00`0000000?oo003oo`1=003oo`0300000000ool00?oo04d00?oo00<000000?ooo`3oool0Q03o
ool008P0oooo00<00000003oo`00ool0CP00ool00`0000000?oo003oo`1>003oo`030000003oool0
oooo08<0oooo00280?ooo`0300000000ool00?oo04h00?oo00<00000003oo`00ool0CP00ool00`00
0000oooo0?ooo`230?ooo`00Q`3oool00`0000000?oo003oo`1?003oo`<00000C`00ool00`000000
oooo0?ooo`220?ooo`00Q`3oool00`0000000?oo003oo`1?003oo`0300000000ool00?oo05000?oo
00<000000?ooo`3oool0P@3oool008H0oooo00<00000003oo`00ool0D000ool00`0000000?oo003o
o`1@003oo`030000003oool0oooo0840oooo00260?ooo`0300000000ool00?oo05000?oo00<00000
003oo`00ool0D@00ool00`000000oooo0?ooo`200?ooo`00Q@3oool00`0000000?oo003oo`1A003o
o`0300000000ool00?oo05400?oo00<000000?ooo`3oool0P03oool008D0oooo00<00000003oo`00
ool0D@00ool00`0000000?oo003oo`1B003oo`030000003oool0oooo07l0oooo00240?ooo`030000
0000ool00?oo05800?oo00<00000003oo`00ool0DP00ool00`000000oooo0?ooo`1o0?ooo`00Q03o
ool00`0000000?oo003oo`1B003oo`0300000000ool00?oo05<00?oo00<000000?ooo`3oool0OP3o
ool008@0oooo00<00000003oo`00ool0?000ool01P00gi`0001d003oo`00ool00=nL0000M0800?oo
00D009a80000000000000018003Oo`09003oo`0300000000ool00?oo05<00?oo00<000000?ooo`3o
ool0OP3oool008<0oooo00<00000003oo`00ool0?@00ool00`00gi`0001d003oo`04003oo`06002o
M000B9`00?oo003oo`00oml004Qd2@00ool00`0000000?oo003oo`1C003oo`030000003oool0oooo
07h0oooo00230?ooo`0300000000ool00?oo03d00?oo00<00=nL0000M000ool02@00ool00`00M000
0;oo003oo`07003oo`0300000000ool00?oo05@00?oo00<000000?ooo`3oool0O@3oool00880oooo
00<00000003oo`00ool0<`00ool00`00gi`0000000000003000000030000M000ool00?oo00800?oo
00<00=nL0000M000ool02@00ool00`00M0000;oo003oo`07003oo`@00000D`00ool00`000000oooo
0?ooo`1m0?ooo`00PP3oool00`0000000?oo003oo`0n003oo`03003OW00007@00?oo00@00?oo00L0
0=nL0000B000gol00?oo003og`00B4P00=oo00P00?oo00<00000003oo`00ool0E@00ool00`000000
oooo0?ooo`1l0?ooo`00P@3oool00`0000000?oo003oo`0o003oo`03003OW00007@00?oo00@00?oo
00<00?no0000000000000P0000000`00_ol00?oo003oo`07003oo`0300000000ool00?oo05D00?oo
00<000000?ooo`3oool0O03oool00840oooo00<00000003oo`00ool0?@00ool01000M0000018002o
W00007@5003oo`03003og`00B4P00=oo00`00?oo00<00000003oo`00ool0E@00ool00`000000oooo
0?ooo`1l0?ooo`00P03oool00`0000000?oo003oo`0o003oo`03002oM0000000001d00H00?oo00<0
07@0002oo`00ool02`00ool00`0000000?oo003oo`1F003oo`030000003oool0oooo07/0oooo0020
0?ooo`0300000000ool00?oo04000?oo00<00=nL0000M000ool01@00ool01@00W4P0000000000000
0000001d00T00?oo00<00000003oo`00ool0EP00ool00`000000oooo0?ooo`1k0?ooo`00P03oool0
0`0000000?oo003oo`1F003oo`0300000000ool00?oo05H00?oo00<000000?ooo`3oool0N`3oool0
07l0oooo00<00000003oo`00ool0E`00ool00`0000000?oo003oo`1G003oo`030000003oool0oooo
07X0oooo001o0?ooo`0300000000ool00?oo05L00?oo00<00000003oo`00ool0E`00ool00`000000
oooo0?ooo`1j0?ooo`00OP3oool00`0000000?oo003oo`1H003oo`0300000000ool00?oo05P00?oo
00<000000?ooo`3oool0N@3oool007h0oooo00<00000003oo`00ool0F000ool3000005P00?oo00<0
00000?ooo`3oool0N@3oool007d0oooo00<00000003oo`00ool0F@00ool00`0000000?oo003oo`1H
003oo`030000003oool0oooo07T0oooo001m0?ooo`0300000000ool00?oo05T00?oo00<00000003o
o`00ool0F@00ool00`000000oooo0?ooo`1h0?ooo`00O@3oool00`0000000?oo003oo`1I003oo`03
00000000ool00?oo05T00?oo00<000000?ooo`3oool0N03oool007`0oooo00<00000003oo`00ool0
FP00ool00`0000000?oo003oo`1I003oo`030000003oool0oooo07P0oooo001l0?ooo`0300000000
ool00?oo05X00?oo00<00000003oo`00ool0FP00ool00`000000oooo0?ooo`1g0?ooo`00O03oool0
0`0000000?oo003oo`1J003oo`0300000000ool00?oo05X00?oo00<000000?ooo`3oool0M`3oool0
07/0oooo00<00000003oo`00ool0F`00ool00`0000000?oo003oo`1J003oo`030000003oool0oooo
07L0oooo001k0?ooo`0300000000ool00?oo05/00?oo00<00000003oo`00ool0F`00ool00`000000
oooo0?ooo`1f0?ooo`00N`3oool00`0000000?oo003oo`1K003oo`0300000000ool00?oo05/00?oo
00<000000?ooo`3oool0MP3oool007X0oooo00<00000003oo`00ool0G000ool3000005/00?oo00<0
00000?ooo`3oool0MP3oool007X0oooo00<00000003oo`00ool0G000ool00`0000000?oo003oo`1L
003oo`030000003oool0oooo07D0oooo001j0?ooo`0300000000ool00?oo05`00?oo00<00000003o
o`00ool0G000ool00`000000oooo0?ooo`1e0?ooo`00N@3oool00`0000000?oo003oo`1M003oo`03
00000000ool00?oo05`00?oo00<000000?ooo`3oool0M@3oool007T0oooo00<00000003oo`00ool0
G@00ool00`0000000?oo003oo`1M003oo`030000003oool0oooo07@0oooo001i0?ooo`0300000000
ool00?oo05d00?oo00<00000003oo`00ool0G@00ool00`000000oooo0?ooo`1d0?ooo`00N03oool0
0`0000000?oo003oo`1N003oo`0300000000ool00?oo05d00?oo00<000000?ooo`3oool0M03oool0
07P0oooo00<00000003oo`00ool0GP00ool00`0000000?oo003oo`1N003oo`030000003oool0oooo
07<0oooo001h0?ooo`0300000000ool00?oo05h00?oo00<00000003oo`00ool0GP00ool00`000000
oooo0?ooo`1c0?ooo`00M`3oool00`0000000?oo003oo`1O003oo`0300000000ool00?oo05h00?oo
00<000000?ooo`3oool0L`3oool007L0oooo00<00000003oo`00ool0G`00ool00`0000000?oo003o
o`1O003oo`030000003oool0oooo0780oooo001g0?ooo`0300000000ool00?oo05l00?oo0`00001O
003oo`030000003oool0oooo0780oooo001g0?ooo`0300000000ool00?oo05l00?oo00<00000003o
o`00ool0G`00ool00`000000oooo0?ooo`1b0?ooo`00MP3oool00`0000000?oo003oo`1P003oo`03
00000000ool00?oo05l00?oo00<000000?ooo`3oool0LP3oool007H0oooo00<00000003oo`00ool0
H000ool00`0000000?oo003oo`1P003oo`030000003oool0oooo0740oooo001f0?ooo`0300000000
ool00?oo06000?oo00<00000003oo`00ool0H000ool00`000000oooo0?ooo`1a0?ooo`00MP3oool0
0`0000000?oo003oo`1P003oo`0300000000ool00?oo06000?oo00<000000?ooo`3oool0L@3oool0
07D0oooo00<00000003oo`00ool0H@00ool00`0000000?oo003oo`1P003oo`030000003oool0oooo
0740oooo001e0?ooo`0300000000ool00?oo06400?oo00<00000003oo`00ool0H@00ool00`000000
oooo0?ooo`1`0?ooo`00M@3oool00`0000000?oo003oo`1Q003oo`0300000000ool00?oo06400?oo
00<000000?ooo`3oool0L03oool007D0oooo00<00000003oo`00ool0H@00ool00`0000000?oo003o
o`1Q003oo`030000003oool0oooo0700oooo001d0?ooo`0300000000ool00?oo06800?oo0`00001Q
003oo`030000003oool0oooo0700oooo001d0?ooo`0300000000ool00?oo06800?oo00<00000003o
o`00ool0HP00ool00`000000oooo0?ooo`1_0?ooo`00M03oool00`0000000?oo003oo`1R003oo`03
00000000ool00?oo06800?oo00<000000?ooo`3oool0K`3oool007@0oooo00<00000003oo`00ool0
HP00ool00`0000000?oo003oo`1R003oo`030000003oool0oooo06l0oooo001c0?ooo`0300000000
ool00?oo06<00?oo00<00000003oo`00ool0HP00ool00`000000oooo0?ooo`1_0?ooo`00L`3oool0
0`0000000?oo003oo`1S003oo`0300000000ool00?oo06<00?oo00<000000?ooo`3oool0KP3oool0
07<0oooo00<00000003oo`00ool0H`00ool00`0000000?oo003oo`1S003oo`030000003oool0oooo
06h0oooo001c0?ooo`0300000000ool00?oo05L00?oo00<00=nL0000M000ool02@00ool00`000000
0?oo003oo`1S003oo`030000003oool0oooo06h0oooo001c0?ooo`0300000000ool00?oo05L00?oo
00<00=nL0000M000ool02@00ool00`0000000?oo003oo`1S003oo`030000003oool0oooo06h0oooo
001b0?ooo`0300000000ool00?oo05P00?oo00<00=nL0000M000ool02@00ool00`0000000?oo003o
o`1T003oo`030000003oool0oooo06d0oooo001b0?ooo`0300000000ool00?oo04d00?oo00<00=nL
0000000000000`0000000`0007@00?oo003oo`02003oo`03003OW00007@00?oo00P00?oo1@00001S
003oo`030000003oool0oooo06d0oooo001b0?ooo`0300000000ool00?oo05H00?oo3@0000000`3o
000000000?l0000=000005P00?oo00<000000?ooo`3oool0K@3oool00780oooo00<00000003oo`00
ool0DP00ool4000000<0o`0000<0B0000;l0003o0000203o00000`000000o`000?l0000<0?l000@0
0000E000ool00`000000oooo0?ooo`1]0?ooo`00L@3oool00`0000000?oo003oo`1?003oo`@00000
103o00001@2o0000000009`000180000_`0000T0o`0000<000000?l0003o0000403o000400000540
0?oo00<000000?ooo`3oool0K03oool00740oooo00<00000003oo`00ool0BP00ool5000000X0o`00
0P0000000`2o0000o`000?l000070?l000030000003o0000o`0001@0o`001@00001<003oo`030000
003oool0oooo06`0oooo001a0?ooo`0300000000ool00?oo04H00?oo1000000@0?l0000304P0002o
0000o`0000P0o`0000<000000?l0003o00006@3o0004000004P00?oo00<000000?ooo`3oool0K03o
ool00740oooo00<00000003oo`00ool0@P00ool4000001l0o`0000<000000?l0003o00007@3o0004
000004@00?oo00<000000?ooo`3oool0K03oool00700oooo00<00000003oo`00ool0@@00ool20000
02<0o`0000<000000?l0003o00008@3o0002000004<00?oo00<000000?ooo`3oool0J`3oool00700
oooo00<00000003oo`00ool0?`00ool2000002D0o`0000<000000?l0003o00008`3o000200000440
0?oo00<000000?ooo`3oool0J`3oool00700oooo00<00000003oo`00ool0?@00ool2000002L0o`00
00<000000?l0003o00009@3o0002000003l00?oo00<000000?ooo`3oool0J`3oool00700oooo00<0
0000003oo`00ool0>P00ool3000002T0o`0000<000000?l0003o00009`3o0002000003d00?oo00<0
00000?ooo`3oool0J`3oool00700oooo00<00000003oo`00ool0>000ool2000002`0o`000`00000Y
0?l000800000?000ool00`000000oooo0?ooo`1Z0?ooo`00K`3oool00`0000000?oo003oo`0g003o
o`800000;P3o00000`000000o`000?l0000[0?l000800000>P00ool00`000000oooo0?ooo`1Z0?oo
o`00K`3oool00`0000000?oo003oo`0e003oo`800000<03o00000`000000o`000?l0000]0?l00080
0000>000ool00`000000oooo0?ooo`1Z0?ooo`00K`3oool00`0000000?oo003oo`0c003oo`800000
<P3o00000`000000o`000?l0000_0?l000800000=P00ool00`000000oooo0?ooo`1Z0?ooo`00K`3o
ool00`0000000?oo003oo`0b003oo`030000003o0000o`000380o`0000<000000?l0003o0000<@3o
0002000003D00?oo00<000000?ooo`3oool0J@3oool006h0oooo00<00000003oo`00ool0<@00ool2
000003D0o`0000<000000?l0003o0000<`3o00000`0000000?oo003oo`0b003oo`030000003oool0
oooo06T0oooo001^0?ooo`0300000000ool00?oo03000?oo00<000000?l0003o0000=@3o00000`00
0000o`000?l0000d0?l000800000<P00ool00`000000oooo0?ooo`1Y0?ooo`00KP3oool00`000000
0?oo003oo`0_003oo`030000003o0000o`0003H0o`0000<000000?l0003o0000=P3o00000`000000
0?oo003oo`0_003oo`030000003oool0oooo06T0oooo001^0?ooo`0300000000ool00?oo02d00?oo
0P00000i0?l000030000003o0000o`0003L0o`000P00000`003oo`030000003oool0oooo06P0oooo
001]0?ooo`0300000000ool00?oo02d00?oo00<000000?l0003o0000>@3o00000`000000o`000?l0
000i0?l0000300000000ool00?oo02d00?oo00<000000?ooo`3oool0J03oool006d0oooo00<00000
003oo`00ool0:`00ool2000003`0o`000`00000j0?l0000300000000ool00?oo02`00?oo00<00000
0?ooo`3oool0J03oool006d0oooo00<00000003oo`00ool0:P00ool00`000000o`000?l0000l0?l0
00030000003o0000o`0003/0o`000P00000/003oo`030000003oool0oooo06P0oooo001]0?ooo`03
00000000ool00?oo02P00?oo0P00000o0?l000030000003o0000o`0003d0o`0000<00000003oo`00
ool0:P00ool00`000000oooo0?ooo`1W0?ooo`00K03oool00`0000000?oo003oo`0X003oo`030000
003o0000o`0003l0o`0000<000000?l0003o0000?P3o00000`0000000?oo003oo`0Y003oo`030000
003oool0oooo06L0oooo001/0?ooo`0300000000ool00?oo02H00?oo0P0000120?l000030000003o
0000o`0003l0o`000P00000Y003oo`030000003oool0oooo06L0oooo001/0?ooo`0300000000ool0
0?oo02D00?oo00<000000?l0003o0000@P3o00000`000000o`000?l000110?l0000300000000ool0
0?oo02H00?oo00<000000?ooo`3oool0I`3oool006`0oooo00<00000003oo`00ool09000ool00`00
0000o`000?l000130?l000030000003o0000o`000480o`0000<00000003oo`00ool09P00ool00`00
0000oooo0?ooo`1V0?ooo`00K03oool00`0000000?oo003oo`0S003oo`030000003o0000o`0004@0
o`0000<000000?l0003o0000@`3o00000`0000000?oo003oo`0U003oo`030000003oool0oooo06H0
oooo001[0?ooo`0300000000ool00?oo02<00?oo00<000000?l0003o0000A@3o00000`000000o`00
0?l000140?l0000300000000ool00?oo02@00?oo00<000000?ooo`3oool0IP3oool006/0oooo00<0
0000003oo`00ool08P00ool00`000000o`000?l000160?l000030000003o0000o`0004D0o`0000<0
0000003oo`00ool08`00ool00`000000oooo0?ooo`1V0?ooo`00J`3oool00`0000000?oo003oo`0R
003oo`030000003o0000o`0004H0o`0000<000000?l0003o0000AP3o00000`0000000?oo003oo`0R
003oo`030000003oool0oooo06H0oooo001[0?ooo`0300000000ool00?oo02400?oo00<000000?l0
003o0000A`3o0003000004L0o`0000<00000003oo`00ool08@00ool00`000000oooo0?ooo`1V0?oo
o`00J`3oool00`0000000?oo003oo`0P003oo`030000003o0000o`0004P0o`0000<000000?l0003o
0000B03o00000`0000000?oo003oo`0Q003oo`030000003oool0oooo06D0oooo001Z0?ooo`030000
0000ool00?oo02000?oo00<000000?l0003o0000B@3o00000`000000o`000?l000190?l000030000
0000ool00?oo02000?oo00<000000?ooo`3oool0I@3oool006X0oooo00<00000003oo`00ool07`00
ool00`000000o`000?l0001:0?l000030000003o0000o`0004X0o`0000<00000003oo`00ool07`00
ool00`000000oooo0?ooo`1U0?ooo`00JP3oool00`0000000?oo003oo`0N003oo`030000003o0000
o`0004/0o`0000<000000?l0003o0000B`3o00000`0000000?oo003oo`0N003oo`030000003oool0
oooo06D0oooo001Z0?ooo`0300000000ool00?oo01d00?oo00<000000?l0003o0000C03o00000`00
0000o`000?l0001<0?l0000300000000ool00?oo01d00?oo00<000000?ooo`3oool0I@3oool006X0
oooo00<00000003oo`00ool07@00ool00`000000o`000?l0001<0?l000030000003o0000o`0004`0
o`0000<00000003oo`00ool07@00ool00`000000oooo0?ooo`1U0?ooo`00JP3oool00`0000000?oo
003oo`0L003oo`030000003o0000o`0004d0o`0000<000000?l0003o0000C@3o00000`0000000?oo
003oo`0M003oo`030000003oool0oooo06@0oooo001Y0?ooo`0300000000ool00?oo01`00?oo00<0
00000?l0003o0000CP3o00000`000000o`000?l0001>0?l0000300000000ool00?oo01`00?oo00<0
00000?ooo`3oool0I03oool006T0oooo00<00000003oo`00ool06`00ool00`000000o`000?l0001?
0?l000030000003o0000o`0004l0o`0000<00000003oo`00ool06`00ool00`000000oooo0?ooo`1T
0?ooo`00J@3oool00`0000000?oo003oo`0J003oo`030000003o0000o`000500o`000`00001@0?l0
000300000000ool00?oo01X00?oo00<000000?ooo`3oool0I03oool006T0oooo00<00000003oo`00
ool06@00ool00`000000o`000?l0001A0?l000030000003o0000o`000540o`0000<00000003oo`00
ool06@00ool00`000000oooo0?ooo`1T0?ooo`00J@3oool00`0000000?oo003oo`0I003oo`030000
003o0000o`000540o`0000<000000?l0003o0000D@3o00000`0000000?oo003oo`0J003oo`030000
003oool0oooo06<0oooo001X0?ooo`0300000000ool00?oo01T00?oo00<000000?l0003o0000DP3o
00000`000000o`000?l0001B0?l0000300000000ool00?oo01T00?oo00<000000?ooo`3oool0H`3o
ool006P0oooo00<00000003oo`00ool06000ool00`000000o`000?l0001C0?l000030000003o0000
o`0005<0o`0000<00000003oo`00ool06000ool00`000000oooo0?ooo`1S0?ooo`00J03oool00`00
00000?oo003oo`0G003oo`030000003o0000o`0005@0o`0000<000000?l0003o0000E03o00000`00
00000?oo003oo`0G003oo`030000003oool0oooo06<0oooo001X0?ooo`0300000000ool00?oo01L0
0?oo00<000000?l0003o0000E03o00000`000000o`000?l0001D0?l0000300000000ool00?oo01L0
0?oo00<000000?ooo`3oool0H`3oool006P0oooo00<00000003oo`00ool05P00ool00`000000o`00
0?l0000n0?l0000407@00000000000000=l00080o`0000@0B0000;l0003o0000g`000`0000000`2L
0000o`000?l000070?l000030000003o0000o`0005D0o`0000<00000003oo`00ool05P00ool00`00
0000oooo0?ooo`1S0?ooo`00I`3oool00`0000000?oo003oo`0F003oo`030000003o0000o`0003h0
o`0000D0W00004P0003o0000g`00000000050?l000060000003O0000o`000?l0002L0000_`00203o
00000`000000o`000?l0001E0?l0000300000000ool00?oo01L00?oo00<000000?ooo`3oool0HP3o
ool006L0oooo00<00000003oo`00ool05P00ool00`000000o`000?l0000n0?l0000607@0002o0000
o`000?l000180000_`00203o00000`2o0000M0000?l000070?l000030000003o0000o`0005H0o`00
00<00000003oo`00ool05P00ool00`000000oooo0?ooo`1R0?ooo`00I`3oool00`0000000?oo003o
o`0E003oo`030000003o0000o`0003L0o`0000<0B0000000000000000`000000102o0000o`0004P0
003O00020?l0000307@0002L0000o`0000L0o`0000<0_`0007@0003o00001`3o0004000005D0o`00
00<00000003oo`00ool05P00ool00`000000oooo0?ooo`1R0?ooo`00I`3oool00`0000000?oo003o
o`0E003oo`030000003o0000o`0003l0o`0000H000000=l0003o0000o`0007@0002L00040?l00004
04P0002L0000o`000?l00080W000203o00000`000000o`000?l0001G0?l0000300000000ool00?oo
01D00?oo00<000000?ooo`3oool0HP3oool006L0oooo00<00000003oo`00ool05000ool00`000000
o`000?l000100?l0000604P0003O0000o`000?l0001d0000W000103o00001@1d0000000000000000
0000M00000T0o`0000<000000?l0003o0000E`3o00000`0000000?oo003oo`0E003oo`030000003o
ool0oooo0680oooo001V0?ooo`0300000000ool00?oo01D00?oo00<000000?l0003o0000@03o0000
1P1d0000_`000?l0003o0000B0000;l000@0o`000P2L000<0?l000030000003o0000o`0005P0o`00
00<00000003oo`00ool05000ool00`000000oooo0?ooo`1R0?ooo`00IP3oool00`0000000?oo003o
o`0D003oo`030000003o0000o`000440o`0000D0W00007@0003o0000g`00000000050?l000030;l0
001d0000o`0000/0o`0000<000000?l0003o0000F03o00000`0000000?oo003oo`0E003oo`030000
003oool0oooo0640oooo001V0?ooo`0300000000ool00?oo01@00?oo00<000000?l0003o0000@P3o
0000101d000000000000003O00050?l000030=l00000000000000080000000<0_`000?l0003o0000
1P3o00000`000000o`000?l0001I0?l0000300000000ool00?oo01@00?oo00<000000?ooo`3oool0
H@3oool006H0oooo00<00000003oo`00ool04`00ool00`000000o`000?l0001J0?l000030000003o
0000o`0005T0o`0000<00000003oo`00ool05000ool00`000000oooo0?ooo`1Q0?ooo`00IP3oool0
0`0000000?oo003oo`0C003oo`030000003o0000o`0005X0o`0000<000000?l0003o0000FP3o0000
0`0000000?oo003oo`0C003oo`030000003oool0oooo0640oooo001U0?ooo`0300000000ool00?oo
01<00?oo00<000000?l0003o0000F`3o00000`000000o`000?l0001J0?l0000300000000ool00?oo
01<00?oo00<000000?ooo`3oool0H@3oool006D0oooo00<00000003oo`00ool04`00ool00`000000
o`000?l0001K0?l000030000003o0000o`0005/0o`0000<00000003oo`00ool04`00ool00`000000
oooo0?ooo`1P0?ooo`00I@3oool00`0000000?oo003oo`0B003oo`030000003o0000o`0005`0o`00
00<000000?l0003o0000F`3o00000`0000000?oo003oo`0C003oo`030000003oool0oooo0600oooo
001U0?ooo`0300000000ool00?oo01800?oo00<000000?l0003o0000G03o0003000005`0o`0000<0
0000003oo`00ool04P00ool00`000000oooo0?ooo`1P0?ooo`00I@3oool00`0000000?oo003oo`0B
003oo`030000003o0000o`0005`0o`0000<000000?l0003o0000G03o00000`0000000?oo003oo`0B
003oo`030000003oool0oooo0600oooo001U0?ooo`0300000000ool00?oo01400?oo00<000000?l0
003o0000G@3o00000`000000o`000?l0001M0?l0000300000000ool00?oo01400?oo00<000000?oo
o`3oool0H03oool006@0oooo00<00000003oo`00ool04P00ool00`000000o`000?l0001M0?l00003
0000003o0000o`0005d0o`0000<00000003oo`00ool04@00ool00`000000oooo0?ooo`1P0?ooo`00
I03oool00`0000000?oo003oo`0B003oo`030000003o0000o`0005d0o`0000<000000?l0003o0000
GP3o00000`0000000?oo003oo`0A003oo`030000003oool0oooo05l0oooo001T0?ooo`0300000000
ool00?oo01400?oo00<000000?l0003o0000GP3o00000`000000o`000?l0001N0?l0000300000000
ool00?oo01400?oo00<000000?ooo`3oool0G`3oool006@0oooo00<00000003oo`00ool04@00ool0
0`000000o`000?l0001N0?l000030000003o0000o`0005l0o`0000<00000003oo`00ool04000ool0
0`000000oooo0?ooo`1O0?ooo`00I03oool00`0000000?oo003oo`0A003oo`030000003o0000o`00
05h0o`0000<000000?l0003o0000G`3o00000`0000000?oo003oo`0@003oo`030000003oool0oooo
05l0oooo001S0?ooo`0300000000ool00?oo01400?oo00<000000?l0003o0000G`3o00000`000000
o`000?l0001O0?l0000300000000ool00?oo01000?oo00<000000?ooo`3oool0G`3oool006<0oooo
00<00000003oo`00ool04@00ool00`000000o`000?l0001O0?l000030000003o0000o`000600o`00
00<00000003oo`00ool03`00ool00`000000oooo0?ooo`1O0?ooo`00H`3oool00`0000000?oo003o
o`0A003oo`030000003o0000o`0005l0o`000`00001P0?l0000300000000ool00?oo01000?oo00<0
00000?ooo`3oool0GP3oool006<0oooo00<00000003oo`00ool04000ool00`000000o`000?l0001P
0?l000030000003o0000o`000600o`0000<00000003oo`00ool04000ool00`000000oooo0?ooo`1N
0?ooo`00H`3oool00`0000000?oo003oo`0@003oo`030000003o0000o`000600o`0000<000000?l0
003o0000H03o00000`0000000?oo003oo`0@003oo`030000003oool0oooo05h0oooo001R0?ooo`03
00000000ool00?oo01400?oo00<000000?l0003o0000H03o00000`000000o`000?l0001Q0?l00003
00000000ool00?oo00l00?oo00<000000?ooo`3oool0GP3oool00680oooo00<00000003oo`00ool0
4000ool00`000000o`000?l0001Q0?l000030000003o0000o`000640o`0000<00000003oo`00ool0
3`00ool00`000000oooo0?ooo`1N0?ooo`00HP3oool00`0000000?oo003oo`0@003oo`030000003o
0000o`000640o`0000<000000?l0003o0000H@3o00000`0000000?oo003oo`0@003oo`030000003o
ool0oooo05d0oooo001R0?ooo`0300000000ool00?oo01000?oo00<000000?l0003o0000H@3o0000
0`000000o`000?l0001Q0?l0000300000000ool00?oo01000?oo00<000000?ooo`3oool0G@3oool0
0680oooo00<00000003oo`00ool04000ool00`000000o`000?l0001Q0?l000030000003o0000o`00
0680o`0000<00000003oo`00ool03`00ool00`000000oooo0?ooo`1M0?ooo`00H@3oool00`000000
0?oo003oo`0@003oo`030000003o0000o`000680o`0000<000000?l0003o0000HP3o00000`000000
0?oo003oo`0?003oo`030000003oool0oooo05d0oooo001Q0?ooo`0300000000ool00?oo01000?oo
00<000000?l0003o0000HP3o00000`000000o`000?l0001R0?l0000300000000ool00?oo00l00?oo
00<000000?ooo`3oool0G@3oool00640oooo00<00000003oo`00ool03`00ool00`000000o`000?l0
001S0?l000<00000HP3o00000`0000000?oo003oo`0?003oo`030000003oool0oooo05d0oooo001Q
0?ooo`0300000000ool00?oo00l00?oo00<000000?l0003o0000H`3o00000`000000o`000?l0001S
0?l0000300000000ool00?oo00l00?oo00<000000?ooo`3oool0G03oool00640oooo00<00000003o
o`00ool03`00ool00`000000o`000?l0001S0?l000030000003o0000o`0006<0o`0000<00000003o
o`00ool03`00ool00`000000oooo0?ooo`1L0?ooo`00H@3oool00`0000000?oo003oo`0?003oo`03
0000003o0000o`0006<0o`0000<000000?l0003o0000H`3o00000`0000000?oo003oo`0?003oo`03
0000003oool0oooo05`0oooo001P0?ooo`0300000000ool00?oo01000?oo00<000000?l0003o0000
H`3o00000`000000o`000?l0001S0?l0000300000000ool00?oo00l00?oo00<000000?ooo`3oool0
G03oool000/0oooo00<0a5lD0000000000000`0000000`0eSol0oooo0?ooo`0Y0?ooo`090?o4G`0D
03D0Sooo0?ooo`3oa5l0500e08ooo`3oool0a5lD0080000000<0000D05o4o`3oool05@3oool00`00
00000?oo003oo`0@003oo`050000003o0000o`0004P0002o0000:`3o0000101d000000000000003O
00020?l0000404P0002o0000o`000=l000<0000000<0W0000?l0003o00009P3o00000`000000o`00
0?l0000Z0?l0000407@00000000000000=l00080o`0000@0B0000;l0003o0000g`000`0000000`2L
0000o`000?l0000Y0?l0000300000000gi`0001d00l00?oo00<000000?ooo`3oool06`3oool02@3o
a5l0500e08ooo`3oool0olAO01@0=@2?ool0oooo0<AO5002000000030000501Oa?l0oooo02P0oooo
00<0a5lD0000000000000`0000000`0eSol0oooo0?ooo`020?ooo`002`3oool00`3oa5l0500003F?
o`0_0?ooo`030?o4G`0D03D0Sooo00@0oooo00L0ohle000DG`34ool0oooo0?ooa01O53D0Sooo01D0
oooo00<00000003oo`00ool04000ool01@000000o`000?l000180000_`0002X0o`0000D0W00004P0
003o0000g`00000000050?l000060000003O0000o`000?l0002L0000_`009`3o00000`000000o`00
0?l0000Y0?l0000509`000180000o`000=l0000000001@3o00001P000000g`000?l0003o0000W000
0;l002X0o`0000<00000003OW00007@03`00ool00`000000oooo0?ooo`0K0?ooo`030?o4G`0D03D0
Sooo00@0oooo00L0ohle000DG`34ool0oooo0?ooa01O53D0Sooo02P0oooo00<0olAO01@0000eSol0
203oool000`0oooo00<0olAO01@0000eSol0;P3oool00`3oa5l0500e08ooo`090?ooo`0308le000e
Sol0oooo01@0oooo00<00000003oo`00ool04000ool01@000000o`000?l000180000_`0002X0o`00
00H0M0000;l0003o0000o`0004P0002o00080?l000030;l0001d0000o`0002H0o`0000<000000?l0
003o0000:@3o00001P1d0000_`000?l0003o0000B0000;l000P0o`0000<0_`0007@0003o0000:@3o
00000`0000000=nL0000M00@003oo`030000003oool0oooo01X0oooo00<0olAO01@0=@2?ool02@3o
ool00`2?=@00=Hoo0?ooo`0X0?ooo`030?o4G`0D0000=Hoo00L0oooo00030?ooo`030?o4G`0D0000
000000<0000000L0000e08ooo`3oool0oooo0?ooS`0e000055o40240oooo00<0olAO01@000000000
0`0000000`0003D0Sooo0?ooo`030?ooo`030?o4G`0D03D0Sooo00T0oooo00<0ScD003F?o`3oool0
503oool00`0000000?oo003oo`07003oo`03003OW0000000000000<0000000@0001d003oo`00ool0
00000P3o00000`180000_`000?l0000Q0?l0000304P000000000000000<0000000@0_`000?l00018
0000g`000P3o00000`1d0000W0000?l000070?l000030;l0001d0000o`0002H0o`0000<000000?l0
003o0000:@3o00001P180000g`000?l0003o0000M00009`000P0o`0000<0_`0007@0003o0000:@3o
00000`0000000=nL0000M00@003oo`030000003oool0oooo01X0oooo00<0olAO01@0=@2?ool02@3o
ool00`2?=@00=Hoo0?ooo`0Y0?ooo`030?ooS`0e000055o400H0oooo000>0?ooo`030?ooa01O5000
55o402`0oooo00<0olAO01@0=@2?ool0103oool01`3oa5l0500D05o4o`3oool0ooo405lD501Oa?l0
503oool00`0000000?oo003oo`0@003oo`060000003o0000o`000?l000180000_`00:P3o00001P00
0000g`000?l0003o0000M00009`000@0o`0000@0B00009`0003o0000o`000P2L000W0?l000030000
003o0000o`0002T0o`0000H000000=l0003o0000o`0007@0002L00040?l0000404P0002L0000o`00
0?l00080W000:`3o00000`000000001d003oo`0?003oo`030000003oool0oooo01X0oooo00<0olAO
01@0=@2?ool0103oool01`3oa5l0500D05o4o`3oool0ooo405lD501Oa?l0:`3oool00`3ool@0Ga@0
01AOa0050?ooo`003`3oool00`3oohl0=@0D05o4o`0[0?ooo`030?o4G`0D03D0Sooo00@0oooo00<0
oon?03D0000000000P0000000`0eSol0oooo0?ooo`0C0?ooo`0300000000ool00?oo01000?oo00H0
00000?l0003o0000o`0004P0002o000Z0?l0000604P0003O0000o`000?l0001d0000W000103o0000
1@1d00000000000000000000M00002P0o`0000<000000?l0003o0000:@3o00001P180000g`000?l0
003o0000M00009`000@0o`0000D0M000000000000000000007@0000/0?l000030000000007@00?oo
00l00?oo00<000000?ooo`3oool06P3oool00`3oa5l0500e08ooo`040?ooo`030?ooS`0e00000000
0080000000<0=Hoo0?ooo`3oool0:`3oool00`3oohl0=@0D05o4o`040?ooo`002`3oool00`3oScD0
03F?0?ooo`020?ooo`0308le000eSol0oooo02P0oooo00D0ScD00000501OSel0500e08ooo`040?oo
o`030?ooa01O51@0GlCo01P0oooo00<00000003oo`00ool04000ool01P000000_`000000002L0000
B0000;l002X0o`0000H0M0000;l0003o0000o`0004P0002o00040?l00080W000:`3o0003000002T0
o`0000H0M0000;l0003o0000o`0004P0002o00040?l00080W000;@3o0000102o0000000000000000
07@@003oo`030000003oool0oooo01P0oooo00D0ScD00000501OSel0500e08ooo`040?ooo`030?oo
a01O51@0GlCo02`0oooo00<0ohle000eS`3oool00P3oool00`2?=@00=Hoo0?ooo`030?ooo`002`3o
ool01`3oohl0=@0D05o4o`3oool0olAO01@0501Oa?l0:P3oool0103oScD000000000=@2?ool50?oo
o`0308le000eSol0oooo01L0oooo00<00000003oo`00ool04000ool00`000000o`000?l000020000
00030;l0003o0000o`0002P0o`0000D0W00007@0003o0000g`00000000050?l000030;l0001d0000
o`0002X0o`0000<000000?l0003o0000:@3o00001@2L0000M0000?l0003O0000000000D0o`0000<0
_`0007@0003o0000;P3o00000`000000001d003oo`0?003oo`030000003oool0oooo01T0oooo00@0
ohle0000000003D0Sooo1@3oool00`2?=@00=Hoo0?ooo`0[0?ooo`070?ooS`0e01@0GlCo0?ooo`3o
a5l0500D05o4o`040?ooo`00303oool01@3oa5l05000000000000000=Hoo02`0oooo00<0olAO01@0
=@2?ool01@3oool01P34Ga@00000000000000000000e08oooa@0oooo00<00000003oo`00ool04000
ool01P000000o`000?l0003o0000B0000;l002/0o`0000@0M000000000000000g`001@3o00000`3O
0000000000000002000000030;l0003o0000o`0002D0o`0000<000000?l0003o0000:P3o0000101d
000000000000003O00050?l000030=l00000000000000080000000<0_`000?l0003o0000:@3o0000
0`000000001d003oo`0@003oo`030000003oool0oooo01T0oooo00<0olAO01@0=@2?ool01@3oool0
1P34Ga@00000000000000000000e08ooobT0oooo00D0olAO01@000000000000003F?o`050?ooo`00
G`3oool00`0000000?oo003oo`0@003oo`030000003o0000o`0006@0o`0000<000000?l0003o0000
I03o00000`0000000?oo003oo`0@003oo`030000003oool0oooo05X0oooo001N0?ooo`0300000000
ool00?oo01400?oo00<000000?l0003o0000I03o00000`000000o`000?l0001T0?l0000300000000
ool00?oo01000?oo00<000000?ooo`3oool0FP3oool005h0oooo00<00000003oo`00ool04@00ool0
0`000000o`000?l0001T0?l000030000003o0000o`0006@0o`0000<00000003oo`00ool04000ool0
0`000000oooo0?ooo`1J0?ooo`00GP3oool00`0000000?oo003oo`0A003oo`030000003o0000o`00
06@0o`0000<000000?l0003o0000I03o00000`0000000?oo003oo`0@003oo`030000003oool0oooo
05X0oooo001N0?ooo`0300000000ool00?oo01000?oo00<000000?l0003o0000I@3o00000`000000
o`000?l0001T0?l0000300000000ool00?oo01000?oo00<000000?ooo`3oool0FP3oool005h0oooo
00<00000003oo`00ool04000ool00`000000o`000?l0001U0?l000030000003o0000o`0006D0o`00
00<00000003oo`00ool03`00ool00`000000oooo0?ooo`1J0?ooo`00GP3oool00`0000000?oo003o
o`0@003oo`030000003o0000o`0006D0o`0000<000000?l0003o0000I@3o00000`0000000?oo003o
o`0@003oo`030000003oool0oooo05T0oooo000:0?ooool00000X00000070?ooo`002P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P000008003oo`0300000000ool00?oo
00L00?oo00<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0000300000000ool00?oo
00L00?oo00<00000003oo`00ool01P00ool2000000X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<00000003oo`00ool01`00ool00`0000000?oo003oo`07003oo`030000003o0000o`0000P0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o0000203o00000`0000000?oo003oo`07003oo`0300000000ool00?oo00H0
0?oo0P00000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool000X0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0L0?ooo`0300000000ool00?oo01400?oo
00<000000?l0003o0000<@3o00000`000000o`000?l0000a0?l000030000003o0000o`000340o`00
00<000000?l0003o0000<03o0002000001800?oo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00D0oooo001M0?ooo`0300000000ool00?oo01800?oo00<0
00000?l0003o0000I03o00000`000000o`000?l0001T0?l0000300000000ool00?oo01400?oo00<0
00000?ooo`3oool0F@3oool005d0oooo00<00000003oo`00ool04P00ool00`000000o`000?l0001T
0?l000030000003o0000o`0006@0o`0000<00000003oo`00ool04@00ool00`000000oooo0?ooo`1I
0?ooo`00G@3oool00`0000000?oo003oo`0B003oo`030000003o0000o`0006@0o`0000<000000?l0
003o0000I03o00000`0000000?oo003oo`0A003oo`030000003oool0oooo05T0oooo001M0?ooo`03
00000000ool00?oo01800?oo00<000000?l0003o0000I03o00000`000000o`000?l0001T0?l00003
00000000ool00?oo01800?oo00<000000?ooo`3oool0F03oool005d0oooo00<00000003oo`00ool0
4P00ool00`000000o`000?l0001T0?l000030000003o0000o`0006@0o`0000<00000003oo`00ool0
4P00ool00`000000oooo0?ooo`1H0?ooo`00G03oool00`0000000?oo003oo`0C003oo`030000003o
0000o`0006@0o`0000<000000?l0003o0000I03o00000`0000000?oo003oo`0B003oo`030000003o
ool0oooo05P0oooo001L0?ooo`0300000000ool00?oo01<00?oo00<000000?l0003o0000I03o0003
000006@0o`0000<00000003oo`00ool04P00ool00`000000oooo0?ooo`1H0?ooo`00G03oool00`00
00000?oo003oo`0C003oo`030000003o0000o`0006@0o`0000<000000?l0003o0000I03o00000`00
00000?oo003oo`0B003oo`030000003oool0oooo05P0oooo001L0?ooo`0300000000ool00?oo01<0
0?oo00<000000?l0003o0000I03o00000`000000o`000?l0001T0?l0000300000000ool00?oo0180
0?oo00<000000?ooo`3oool0F03oool005`0oooo00<00000003oo`00ool05000ool00`000000o`00
0?l0001S0?l000030000003o0000o`0006<0o`0000<00000003oo`00ool04`00ool00`000000oooo
0?ooo`1H0?ooo`00G03oool00`0000000?oo003oo`0D003oo`030000003o0000o`0006<0o`0000<0
00000?l0003o0000H`3o00000`0000000?oo003oo`0D003oo`030000003oool0oooo05L0oooo001L
0?ooo`0300000000ool00?oo01@00?oo00<000000?l0003o0000H`3o00000`000000o`000?l0001S
0?l0000300000000ool00?oo01@00?oo00<000000?ooo`3oool0E`3oool005`0oooo00<00000003o
o`00ool05000ool00`000000o`000?l0001S0?l000030000003o0000o`0006<0o`0000<00000003o
o`00ool05000ool00`000000oooo0?ooo`1G0?ooo`00F`3oool00`0000000?oo003oo`0E003oo`03
0000003o0000o`0006<0o`0000<000000?l0003o0000H`3o00000`0000000?oo003oo`0D003oo`03
0000003oool0oooo05L0oooo001K0?ooo`0300000000ool00?oo01D00?oo00<000000?l0003o0000
H`3o00000`000000o`000?l0001S0?l0000300000000ool00?oo01@00?oo00<000000?ooo`3oool0
E`3oool005/0oooo00<00000003oo`00ool05@00ool00`000000o`000?l0001S0?l000030000003o
0000o`0006<0o`0000<00000003oo`00ool05000ool00`000000oooo0?ooo`1G0?ooo`00F`3oool0
0`0000000?oo003oo`0E003oo`030000003o0000o`0006<0o`0000<000000?l0003o0000H`3o0000
0`0000000?oo003oo`0D003oo`030000003oool0oooo05L0oooo001K0?ooo`0300000000ool00?oo
01D00?oo00<000000?l0003o0000H`3o000300000680o`0000<00000003oo`00ool05P00ool00`00
0000oooo0?ooo`1F0?ooo`00F`3oool00`0000000?oo003oo`0F003oo`030000003o0000o`000680
o`0000<000000?l0003o0000HP3o00000`0000000?oo003oo`0F003oo`030000003oool0oooo05H0
oooo001K0?ooo`0300000000ool00?oo01H00?oo00<000000?l0003o0000HP3o00000`000000o`00
0?l0001R0?l0000300000000ool00?oo01H00?oo00<000000?ooo`3oool0EP3oool005X0oooo00<0
0000003oo`00ool06000ool00`000000o`000?l0001Q0?l000030000003o0000o`000680o`0000<0
0000003oo`00ool05P00ool00`000000oooo0?ooo`1F0?ooo`00FP3oool00`0000000?oo003oo`0H
003oo`030000003o0000o`000640o`0000<000000?l0003o0000H@3o00000`0000000?oo003oo`0G
003oo`030000003oool0oooo05H0oooo001J0?ooo`0300000000ool00?oo01P00?oo00<000000?l0
003o0000H@3o00000`000000o`000?l0001Q0?l0000300000000ool00?oo01L00?oo00<000000?oo
o`3oool0EP3oool005X0oooo00<00000003oo`00ool06000ool00`000000o`000?l0001Q0?l00003
0000003o0000o`000640o`0000<00000003oo`00ool05`00ool00`000000oooo0?ooo`1F0?ooo`00
FP3oool00`0000000?oo003oo`0I003oo`030000003o0000o`000600o`0000<000000?l0003o0000
H@3o00000`0000000?oo003oo`0H003oo`030000003oool0oooo05D0oooo001J0?ooo`0300000000
ool00?oo01T00?oo00<000000?l0003o0000H03o00000`000000o`000?l0001P0?l0000300000000
ool00?oo01T00?oo00<000000?ooo`3oool0E@3oool005X0oooo00<00000003oo`00ool06@00ool0
0`000000o`000?l0001P0?l000030000003o0000o`000600o`0000<00000003oo`00ool06@00ool0
0`000000oooo0?ooo`1E0?ooo`00FP3oool00`0000000?oo003oo`0J003oo`030000003o0000o`00
05l0o`000`00001P0?l0000300000000ool00?oo01T00?oo00<000000?ooo`3oool0E@3oool005T0
oooo00<00000003oo`00ool06`00ool00`000000o`000?l0001O0?l000030000003o0000o`000600
o`0000<00000003oo`00ool06@00ool00`000000oooo0?ooo`1E0?ooo`00F@3oool00`0000000?oo
003oo`0K003oo`030000003o0000o`0005l0o`0000<000000?l0003o0000G`3o00000`0000000?oo
003oo`0J003oo`030000003oool0oooo05D0oooo001I0?ooo`0300000000ool00?oo01`00?oo00<0
00000?l0003o0000GP3o00000`000000o`000?l0001O0?l0000300000000ool00?oo01X00?oo00<0
00000?ooo`3oool0E@3oool005T0oooo00<00000003oo`00ool07000ool00`000000o`000?l0001N
0?l000030000003o0000o`0005l0o`0000<00000003oo`00ool06P00ool00`000000oooo0?ooo`1E
0?ooo`00F@3oool00`0000000?oo003oo`0L003oo`030000003o0000o`0005h0o`0000<000000?l0
003o0000GP3o00000`0000000?oo003oo`0L003oo`030000003oool0oooo05@0oooo001I0?ooo`03
00000000ool00?oo01d00?oo00<000000?l0003o0000G@3o00000`000000o`000?l0001N0?l00003
00000000ool00?oo01`00?oo00<000000?ooo`3oool0E03oool005T0oooo00<00000003oo`00ool0
7@00ool00`000000o`000?l0001M0?l000030000003o0000o`0005d0o`0000<00000003oo`00ool0
7@00ool00`000000oooo0?ooo`1D0?ooo`00F03oool00`0000000?oo003oo`0N003oo`030000003o
0000o`0005d0o`0000<000000?l0003o0000G@3o00000`0000000?oo003oo`0M003oo`030000003o
ool0oooo05@0oooo001H0?ooo`0300000000ool00?oo01l00?oo00<000000?l0003o0000G03o0000
0`000000o`000?l0001L0?l0000300000000ool00?oo01h00?oo00<000000?ooo`3oool0E03oool0
05P0oooo00<00000003oo`00ool07`00ool00`000000o`000?l0001L0?l000<00000G03o00000`00
00000?oo003oo`0N003oo`030000003oool0oooo05@0oooo001H0?ooo`0300000000ool00?oo01l0
0?oo00<000000?l0003o0000G03o00000`000000o`000?l0001K0?l0000300000000ool00?oo01l0
0?oo00<000000?ooo`3oool0E03oool005P0oooo00<00000003oo`00ool08000ool00`000000o`00
0?l0001K0?l000030000003o0000o`0005/0o`0000<00000003oo`00ool08000ool00`000000oooo
0?ooo`1C0?ooo`00F03oool00`0000000?oo003oo`0P003oo`030000003o0000o`0005/0o`0000<0
00000?l0003o0000FP3o00000`0000000?oo003oo`0Q003oo`030000003oool0oooo05<0oooo001H
0?ooo`0300000000ool00?oo02400?oo00<000000?l0003o0000FP3o00000`000000o`000?l0001J
0?l0000300000000ool00?oo02400?oo00<000000?ooo`3oool0D`3oool005P0oooo00<00000003o
o`00ool08@00ool00`000000o`000?l0001J0?l000030000003o0000o`0005T0o`0000<00000003o
o`00ool08P00ool00`000000oooo0?ooo`1C0?ooo`00E`3oool00`0000000?oo003oo`0S003oo`03
0000003o0000o`0005T0o`0000<000000?l0003o0000F@3o00000`0000000?oo003oo`0R003oo`03
0000003oool0oooo05<0oooo001G0?ooo`0300000000ool00?oo02<00?oo00<000000?l0003o0000
F@3o00000`000000o`000?l0001H0?l0000300000000ool00?oo02<00?oo00<000000?ooo`3oool0
D`3oool005L0oooo00<00000003oo`00ool09000ool00`000000o`000?l000110?l0000407@00000
000000000=l00080o`0000@0B0000;l0003o0000g`000`0000000`2L0000o`000?l000070?l00003
0000003o0000o`0005P0o`0000<00000003oo`00ool08`00ool00`000000oooo0?ooo`1C0?ooo`00
E`3oool00`0000000?oo003oo`0T003oo`030000003o0000o`000400o`0000D0W00004P0003o0000
g`00000000050?l000060000003O0000o`000?l0002L0000_`00203o00000`000000o`000?l0001G
0?l0000300000000ool00?oo02D00?oo00<000000?ooo`3oool0DP3oool005L0oooo00<00000003o
o`00ool09@00ool00`000000o`000?l0000o0?l0000607@0002o0000o`000?l000180000_`00203o
00000`2o0000M0000?l000070?l000030000003o0000o`0005L0o`0000<00000003oo`00ool09@00
ool00`000000oooo0?ooo`1B0?ooo`00E`3oool00`0000000?oo003oo`0U003oo`030000003o0000
o`0003l0o`0000H0B0000=l0003o0000o`0007@0002L00080?l000030;l0001d0000o`0000L0o`00
1000001E0?l0000300000000ool00?oo02H00?oo00<000000?ooo`3oool0DP3oool005L0oooo00<0
0000003oo`00ool09P00ool00`000000o`000?l0000n0?l000060000003O0000o`000?l0001d0000
W000103o000010180000W0000?l0003o000209`000P0o`0000<000000?l0003o0000EP3o00000`00
00000?oo003oo`0V003oo`030000003oool0oooo0580oooo001G0?ooo`0300000000ool00?oo02H0
0?oo00<000000?l0003o0000?P3o00001P180000g`000?l0003o0000M00009`000@0o`0000D0M000
000000000000000007@000090?l000030000003o0000o`0005D0o`0000<00000003oo`00ool09`00
ool00`000000oooo0?ooo`1B0?ooo`00EP3oool00`0000000?oo003oo`0X003oo`030000003o0000
o`0003d0o`0000H0M0000;l0003o0000o`0004P0002o00040?l00080W000303o00000`000000o`00
0?l0001E0?l0000300000000ool00?oo02L00?oo00<000000?ooo`3oool0DP3oool005H0oooo00<0
0000003oo`00ool0:@00ool00`000000o`000?l0000l0?l0000509`0001d0000o`000=l000000000
1@3o00000`2o0000M0000?l0000;0?l000030000003o0000o`0005@0o`0000<00000003oo`00ool0
:000ool00`000000oooo0?ooo`1B0?ooo`00EP3oool00`0000000?oo003oo`0Y003oo`030000003o
0000o`0003d0o`0000@0M000000000000000g`001@3o00000`3O0000000000000002000000030;l0
003o0000o`0000H0o`0000<000000?l0003o0000E03o00000`0000000?oo003oo`0Y003oo`030000
003oool0oooo0540oooo001F0?ooo`0300000000ool00?oo02X00?oo00<000000?l0003o0000D`3o
00000`000000o`000?l0001C0?l0000300000000ool00?oo02X00?oo00<000000?ooo`3oool0D@3o
ool005H0oooo00<00000003oo`00ool0:`00ool00`000000o`000?l0001B0?l000030000003o0000
o`000580o`0000<00000003oo`00ool0:`00ool00`000000oooo0?ooo`1A0?ooo`00EP3oool00`00
00000?oo003oo`0/003oo`030000003o0000o`000540o`0000<000000?l0003o0000D@3o00000`00
00000?oo003oo`0/003oo`030000003oool0oooo0540oooo001F0?ooo`0300000000ool00?oo02`0
0?oo00<000000?l0003o0000D@3o00000`000000o`000?l0001A0?l0000300000000ool00?oo02`0
0?oo00<000000?ooo`3oool0D@3oool005D0oooo00<00000003oo`00ool0;P00ool00`000000o`00
0?l0001@0?l000<00000D03o00000`0000000?oo003oo`0]003oo`030000003oool0oooo0540oooo
001E0?ooo`0300000000ool00?oo02l00?oo00<000000?l0003o0000C`3o00000`000000o`000?l0
001?0?l0000300000000ool00?oo02h00?oo00<000000?ooo`3oool0D@3oool005D0oooo00<00000
003oo`00ool0<000ool00`000000o`000?l0001>0?l000030000003o0000o`0004h0o`0000<00000
003oo`00ool0;`00ool00`000000oooo0?ooo`1A0?ooo`00E@3oool00`0000000?oo003oo`0a003o
o`030000003o0000o`0004d0o`0000<000000?l0003o0000C@3o00000`0000000?oo003oo`0a003o
o`030000003oool0oooo0500oooo001E0?ooo`0300000000ool00?oo03800?oo00<000000?l0003o
0000C03o00000`000000o`000?l0001<0?l0000300000000ool00?oo03800?oo00<000000?ooo`3o
ool0D03oool005D0oooo00<00000003oo`00ool0<P00ool00`000000o`000?l0001<0?l000030000
003o0000o`0004`0o`0000<00000003oo`00ool0<P00ool00`000000oooo0?ooo`1@0?ooo`00E@3o
ool00`0000000?oo003oo`0c003oo`030000003o0000o`0004/0o`0000<000000?l0003o0000B`3o
00000`0000000?oo003oo`0c003oo`030000003oool0oooo0500oooo001E0?ooo`0300000000ool0
0?oo03@00?oo00<000000?l0003o0000BP3o00000`000000o`000?l0001:0?l0000300000000ool0
0?oo03@00?oo00<000000?ooo`3oool0D03oool005@0oooo00<00000003oo`00ool0=P00ool00`00
0000o`000?l000190?l000030000003o0000o`0004T0o`0000<00000003oo`00ool0=@00ool00`00
0000oooo0?ooo`1@0?ooo`00E03oool00`0000000?oo003oo`0g003oo`030000003o0000o`0004P0
o`0000<000000?l0003o0000B03o00000`0000000?oo003oo`0f003oo`030000003oool0oooo0500
oooo001D0?ooo`0300000000ool00?oo03P00?oo00<000000?l0003o0000A`3o00000`000000o`00
0?l000170?l0000300000000ool00?oo03P00?oo00<000000?ooo`3oool0C`3oool005@0oooo00<0
0000003oo`00ool0>@00ool00`000000o`000?l000160?l000<00000AP3o00000`0000000?oo003o
o`0i003oo`030000003oool0oooo04l0oooo001D0?ooo`0300000000ool00?oo03T00?oo00<00000
0?l0003o0000AP3o00000`000000o`000?l000150?l0000300000000ool00?oo03X00?oo00<00000
0?ooo`3oool0C`3oool005@0oooo00<00000003oo`00ool0>P00ool00`000000o`000?l000150?l0
00030000003o0000o`0004@0o`0000<00000003oo`00ool0>`00ool00`000000oooo0?ooo`1?0?oo
o`00E03oool00`0000000?oo003oo`0k003oo`030000003o0000o`0004@0o`0000<000000?l0003o
0000@`3o00000`0000000?oo003oo`0l003oo`030000003oool0oooo04l0oooo001C0?ooo`030000
0000ool00?oo03d00?oo00<000000?l0003o0000@`3o00000`000000o`000?l000120?l000030000
0000ool00?oo03d00?oo00<000000?ooo`3oool0C`3oool005<0oooo00<00000003oo`00ool0?P00
ool00`000000o`000?l000120?l000030000003o0000o`000440o`0000<00000003oo`00ool0?P00
ool00`000000oooo0?ooo`1?0?ooo`00D`3oool00`0000000?oo003oo`0o003oo`800000@P3o0000
0`000000o`000?l000100?l0000300000000ool00?oo03l00?oo00<000000?ooo`3oool0C`3oool0
05<0oooo00<00000003oo`00ool0@@00ool00`000000o`000?l0000o0?l000030000003o0000o`00
03l0o`0000<00000003oo`00ool0@@00ool00`000000oooo0?ooo`1>0?ooo`00D`3oool00`000000
0?oo003oo`12003oo`800000?`3o00000`000000o`000?l0000m0?l000800000A000ool00`000000
oooo0?ooo`1>0?ooo`00D`3oool00`0000000?oo003oo`14003oo`030000003o0000o`0003`0o`00
00<000000?l0003o0000?03o00000`0000000?oo003oo`14003oo`030000003oool0oooo04h0oooo
001C0?ooo`0300000000ool00?oo04D00?oo0P00000l0?l000<00000>`3o00000`0000000?oo003o
o`15003oo`030000003oool0oooo04h0oooo001C0?ooo`0300000000ool00?oo04L00?oo00<00000
0?l0003o0000>@3o00000`000000o`000?l0000j0?l0000300000000ool00?oo04H00?oo00<00000
0?ooo`3oool0CP3oool00580oooo00<00000003oo`00ool0B@00ool00`000000o`000?l0000h0?l0
00030000003o0000o`0003T0o`0000<00000003oo`00ool0A`00ool00`000000oooo0?ooo`1>0?oo
o`00DP3oool00`0000000?oo003oo`1:003oo`800000>03o00000`000000o`000?l0000g0?l00080
0000BP00ool00`000000oooo0?ooo`1>0?ooo`00DP3oool00`0000000?oo003oo`1<003oo`030000
003o0000o`0003D0o`0000<000000?l0003o0000=@3o0002000004`00?oo00<000000?ooo`3oool0
CP3oool00580oooo00<00000003oo`00ool0C@00ool00`000000o`000?l0000d0?l000030000003o
0000o`0003<0o`000P00001>003oo`030000003oool0oooo04h0oooo001B0?ooo`0300000000ool0
0?oo04h00?oo0P00000d0?l000030000003o0000o`000340o`000P00001@003oo`030000003oool0
oooo04h0oooo001B0?ooo`0300000000ool00?oo05000?oo0P00000b0?l000030000003o0000o`00
0300o`0000<00000003oo`00ool0D@00ool00`000000oooo0?ooo`1=0?ooo`00DP3oool00`000000
0?oo003oo`1B003oo`800000<03o00000`000000o`000?l0000^0?l000800000E000ool00`000000
oooo0?ooo`1=0?ooo`00DP3oool00`0000000?oo003oo`1D003oo`800000;P3o00000`000000o`00
0?l0000/0?l000800000EP00ool00`000000oooo0?ooo`1=0?ooo`00DP3oool00`0000000?oo003o
o`1F003oo`800000;03o0003000002X0o`000P00001H003oo`030000003oool0oooo04d0oooo001A
0?ooo`0300000000ool00?oo05T00?oo0`00000Y0?l000030000003o0000o`0002L0o`000`00001J
003oo`030000003oool0oooo04d0oooo001A0?ooo`0300000000ool00?oo05`00?oo0P00000W0?l0
00030000003o0000o`0002D0o`000P00001M003oo`030000003oool0oooo04d0oooo001A0?ooo`03
00000000ool00?oo05h00?oo0P00000U0?l000030000003o0000o`0002<0o`000P00001O003oo`03
0000003oool0oooo04d0oooo001A0?ooo`0300000000ool00?oo06000?oo0P00000S0?l000030000
003o0000o`000240o`000P00001Q003oo`030000003oool0oooo04d0oooo001A0?ooo`0300000000
ool00?oo06800?oo0`00000P0?l000030000003o0000o`0001d0o`001000001S003oo`030000003o
ool0oooo04d0oooo001A0?ooo`0300000000ool00?oo06D00?oo1@00000K0?l000030000003o0000
o`0001T0o`001000001X003oo`030000003oool0oooo04`0oooo001A0?ooo`0300000000ool00?oo
06X00?oo1000000<0?l0000304P0002o0000o`0000P0o`0000<000000?l0003o00005@3o00040000
06`00?oo00<000000?ooo`3oool0C03oool00540oooo00<00000003oo`00ool0KP00ool4000000P0
o`0000<0B0000;l0003o0000203o00000`000000o`000?l0000A0?l000@00000L000ool00`000000
oooo0?ooo`1<0?ooo`00D@3oool00`0000000?oo003oo`1b003oo`@00000103o00000`180000_`00
0?l000080?l000030000003o0000o`0000d0o`001000001d003oo`030000003oool0oooo04`0oooo
001A0?ooo`0300000000ool00?oo07H00?oo300000030?l000040000003o0000o`000?l000`00000
N000ool00`000000oooo0?ooo`1<0?ooo`00D@3oool00`0000000?oo003oo`1i003oo`03003OW000
07@00?oo00H00?oo1`000024003oo`030000003oool0oooo04`0oooo001@0?ooo`0300000000ool0
0?oo07X00?oo00<00=nL0000M000ool02@00ool00`0000000?oo003oo`25003oo`030000003oool0
oooo04`0oooo001@0?ooo`0300000000ool00?oo07P00?oo00@007@00000B000_i`0001d2P00ool0
0`0000000?oo003oo`25003oo`030000003oool0oooo04`0oooo001@0?ooo`0300000000ool00?oo
07T00?oo00<00;md0000000007@02P00ool00`0000000?oo003oo`25003oo`030000003oool0oooo
04`0oooo001@0?ooo`0300000000ool00?oo07X00?oo00<00=nL0000M000ool02@00ool00`000000
0?oo003oo`26003oo`030000003oool0oooo04/0oooo001@0?ooo`0300000000ool00?oo08H00?oo
00<00000003oo`00ool0QP00ool00`000000oooo0?ooo`1;0?ooo`00D03oool00`0000000?oo003o
o`26003oo`0300000000ool00?oo08H00?oo00<000000?ooo`3oool0B`3oool00500oooo00<00000
003oo`00ool0QP00ool00`0000000?oo003oo`26003oo`030000003oool0oooo04/0oooo001@0?oo
o`0300000000ool00?oo08H00?oo00<00000003oo`00ool0QP00ool00`000000oooo0?ooo`1;0?oo
o`00D03oool00`0000000?oo003oo`26003oo`0300000000ool00?oo08H00?oo00<000000?ooo`3o
ool0B`3oool00500oooo00<00000003oo`00ool0QP00ool3000008H00?oo00<000000?ooo`3oool0
B`3oool00500oooo00<00000003oo`00ool0QP00ool00`0000000?oo003oo`26003oo`030000003o
ool0oooo04/0oooo001?0?ooo`0300000000ool00?oo08L00?oo00<00000003oo`00ool0QP00ool0
0`000000oooo0?ooo`1;0?ooo`00C`3oool00`0000000?oo003oo`27003oo`0300000000ool00?oo
08H00?oo00<000000?ooo`3oool0B`3oool004l0oooo00<00000003oo`00ool0Q`00ool00`000000
0?oo003oo`27003oo`030000003oool0oooo04X0oooo001?0?ooo`0300000000ool00?oo08L00?oo
00<00000003oo`00ool0Q`00ool00`000000oooo0?ooo`1:0?ooo`00C`3oool00`0000000?oo003o
o`27003oo`0300000000ool00?oo08L00?oo00<000000?ooo`3oool0BP3oool004l0oooo00<00000
003oo`00ool0Q`00ool00`0000000?oo003oo`27003oo`030000003oool0oooo04X0oooo001?0?oo
o`0300000000ool00?oo08L00?oo00<00000003oo`00ool0Q`00ool00`000000oooo0?ooo`1:0?oo
o`00C`3oool00`0000000?oo003oo`27003oo`0300000000ool00?oo08L00?oo00<000000?ooo`3o
ool0BP3oool004l0oooo00<00000003oo`00ool0Q`00ool3000008L00?oo00<000000?ooo`3oool0
BP3oool004l0oooo00<00000003oo`00ool0Q`00ool00`0000000?oo003oo`27003oo`030000003o
ool0oooo04X0oooo001>0?ooo`0300000000ool00?oo08P00?oo00<00000003oo`00ool0Q`00ool0
0`000000oooo0?ooo`1:0?ooo`00CP3oool00`0000000?oo003oo`28003oo`0300000000ool00?oo
08P00?oo00<000000?ooo`3oool0B@3oool004h0oooo00<00000003oo`00ool0R000ool00`000000
0?oo003oo`28003oo`030000003oool0oooo04T0oooo001>0?ooo`0300000000ool00?oo08P00?oo
00<00000003oo`00ool0R000ool00`000000oooo0?ooo`190?ooo`00CP3oool00`0000000?oo003o
o`28003oo`0300000000ool00?oo08P00?oo00<000000?ooo`3oool0B@3oool004h0oooo00<00000
003oo`00ool0R000ool00`0000000?oo003oo`28003oo`030000003oool0oooo04T0oooo001>0?oo
o`0300000000ool00?oo08P00?oo00<00000003oo`00ool0R000ool00`000000oooo0?ooo`190?oo
o`00CP3oool00`0000000?oo003oo`28003oo`0300000000ool00?oo08P00?oo00<000000?ooo`3o
ool0B@3oool004h0oooo00<00000003oo`00ool0R000ool00`0000000?oo003oo`28003oo`030000
003oool0oooo04T0oooo001>0?ooo`0300000000ool00?oo08P00?oo0`000028003oo`030000003o
ool0oooo04T0oooo001>0?ooo`0300000000ool00?oo08P00?oo00<00000003oo`00ool0R000ool0
0`000000oooo0?ooo`190?ooo`00C@3oool00`0000000?oo003oo`29003oo`0300000000ool00?oo
08T00?oo00<000000?ooo`3oool0B03oool004d0oooo00<00000003oo`00ool0R@00ool00`000000
0?oo003oo`29003oo`030000003oool0oooo04P0oooo001=0?ooo`0300000000ool00?oo08T00?oo
00<00000003oo`00ool0R@00ool00`000000oooo0?ooo`180?ooo`00C@3oool00`0000000?oo003o
o`29003oo`0300000000ool00?oo08T00?oo00<000000?ooo`3oool0B03oool004d0oooo00<00000
003oo`00ool0R@00ool00`0000000?oo003oo`29003oo`030000003oool0oooo04P0oooo001=0?oo
o`0300000000ool00?oo08T00?oo00<00000003oo`00ool0R@00ool00`000000oooo0?ooo`180?oo
o`00C@3oool00`0000000?oo003oo`29003oo`0300000000ool00?oo08T00?oo00<000000?ooo`3o
ool0B03oool004d0oooo00<00000003oo`00ool0R@00ool00`0000000?oo003oo`29003oo`030000
003oool0oooo04P0oooo001=0?ooo`0300000000ool00?oo08T00?oo0`000029003oo`030000003o
ool0oooo04P0oooo001=0?ooo`0300000000ool00?oo08T00?oo00<00000003oo`00ool0RP00ool0
0`000000oooo0?ooo`170?ooo`00C@3oool00`0000000?oo003oo`29003oo`0300000000ool00?oo
08X00?oo00<000000?ooo`3oool0A`3oool004`0oooo00<00000003oo`00ool0RP00ool00`000000
0?oo003oo`2:003oo`030000003oool0oooo04L0oooo001<0?ooo`0300000000ool00?oo08X00?oo
00<00000003oo`00ool0RP00ool00`000000oooo0?ooo`170?ooo`00C03oool00`0000000?oo003o
o`2:003oo`0300000000ool00?oo08X00?oo00<000000?ooo`3oool0A`3oool004`0oooo00<00000
003oo`00ool0RP00ool00`0000000?oo003oo`2:003oo`030000003oool0oooo04L0oooo001<0?oo
o`0300000000ool00?oo07@00?oo00H00=nL0000M000ool00?oo003OW00007@2003oo`05002LB000
000000000000B000gol02@00ool00`0000000?oo003oo`2:003oo`030000003oool0oooo04L0oooo
001<0?ooo`0300000000ool00?oo07@00?oo00<00=nL0000M000ool01000ool01P00_g@004RL003o
o`00ool00?oO0018M0T00?oo00<00000003oo`00ool0RP00ool00`000000oooo0?ooo`170?ooo`00
C03oool00`0000000?oo003oo`1d003oo`03003OW00007@00?oo00T00?oo00<007@0002oo`00ool0
1`00ool00`0000000?oo003oo`2:003oo`030000003oool0oooo04L0oooo001<0?ooo`0300000000
ool00?oo07@00?oo00<00=nL0000M000ool02@00ool00`00M0000;oo003oo`07003oo`@00000RP00
ool00`000000oooo0?ooo`160?ooo`00C03oool00`0000000?oo003oo`1d003oo`03003OW00007@0
0?oo00@00?oo00L00=nL0000B000gol00?oo003og`00B4P00=oo00P00?oo00<00000003oo`00ool0
R`00ool00`000000oooo0?ooo`160?ooo`00C03oool00`0000000?oo003oo`1d003oo`03003OW000
07@00?oo00@00?oo00<00?no0000000000000P0000000`00_ol00?oo003oo`07003oo`0300000000
ool00?oo08/00?oo00<000000?ooo`3oool0AP3oool004`0oooo00<00000003oo`00ool0LP00ool0
1000M0000018002oW00007@5003oo`03003og`00B4P00=oo00`00?oo00<00000003oo`00ool0R`00
ool00`000000oooo0?ooo`160?ooo`00B`3oool00`0000000?oo003oo`1d003oo`03002oM0000000
001d00H00?oo00<007@0002oo`00ool02`00ool00`0000000?oo003oo`2;003oo`030000003oool0
oooo04H0oooo001;0?ooo`0300000000ool00?oo07D00?oo00<00=nL0000M000ool01@00ool01@00
W4P00000000000000000001d00T00?oo00<00000003oo`00ool0R`00ool00`000000oooo0?ooo`16
0?ooo`00B`3oool00`0000000?oo003oo`2;003oo`0300000000ool00?oo08/00?oo00<000000?oo
o`3oool0AP3oool004/0oooo00<00000003oo`00ool0R`00ool00`0000000?oo003oo`2;003oo`03
0000003oool0oooo04H0oooo001;0?ooo`0300000000ool00?oo08/00?oo00<00000003oo`00ool0
R`00ool00`000000oooo0?ooo`160?ooo`00B`3oool00`0000000?oo003oo`2;003oo`0300000000
ool00?oo08/00?oo00<000000?ooo`3oool0AP3oool004/0oooo00<00000003oo`00ool0R`00ool0
0`0000000?oo003oo`2<003oo`030000003oool0oooo04D0oooo001;0?ooo`0300000000ool00?oo
08/00?oo0`00002<003oo`030000003oool0oooo04D0oooo001;0?ooo`0300000000ool00?oo08/0
0?oo00<00000003oo`00ool0S000ool00`000000oooo0?ooo`150?ooo`00B`3oool00`0000000?oo
003oo`2;003oo`0300000000ool00?oo08`00?oo00<000000?ooo`3oool0A@3oool004/0oooo00<0
0000003oo`00ool0R`00ool00`0000000?oo003oo`2<003oo`030000003oool0oooo04D0oooo001:
0?ooo`0300000000ool00?oo08`00?oo00<00000003oo`00ool0S000ool00`000000oooo0?ooo`15
0?ooo`00BP3oool00`0000000?oo003oo`2<003oo`0300000000ool00?oo08`00?oo00<000000?oo
o`3oool0A@3oool004X0oooo00<00000003oo`00ool0S000ool00`0000000?oo003oo`2<003oo`03
0000003oool0oooo04D0oooo001:0?ooo`0300000000ool00?oo08`00?oo00<00000003oo`00ool0
S000ool00`000000oooo0?ooo`150?ooo`00BP3oool00`0000000?oo003oo`2<003oo`0300000000
ool00?oo08d00?oo00<000000?ooo`3oool0A03oool004X0oooo00<00000003oo`00ool0S000ool0
0`0000000?oo003oo`2=003oo`030000003oool0oooo04@0oooo001:0?ooo`0300000000ool00?oo
08`00?oo0`00002=003oo`030000003oool0oooo04@0oooo001:0?ooo`0300000000ool00?oo08`0
0?oo00<00000003oo`00ool0S@00ool00`000000oooo0?ooo`140?ooo`00BP3oool00`0000000?oo
003oo`2<003oo`0300000000ool00?oo08d00?oo00<000000?ooo`3oool0A03oool004X0oooo00<0
0000003oo`00ool0S000ool00`0000000?oo003oo`2=003oo`030000003oool0oooo04@0oooo0019
0?ooo`0300000000ool00?oo08d00?oo00<00000003oo`00ool0S@00ool00`000000oooo0?ooo`14
0?ooo`00B@3oool00`0000000?oo003oo`2=003oo`0300000000ool00?oo08d00?oo00<000000?oo
o`3oool0A03oool004T0oooo00<00000003oo`00ool0S@00ool00`0000000?oo003oo`2=003oo`03
0000003oool0oooo04@0oooo00190?ooo`0300000000ool00?oo08d00?oo00<00000003oo`00ool0
SP00ool00`000000oooo0?ooo`130?ooo`00B@3oool00`0000000?oo003oo`2=003oo`0300000000
ool00?oo08h00?oo00<000000?ooo`3oool0@`3oool004T0oooo00<00000003oo`00ool0S@00ool0
0`0000000?oo003oo`2>003oo`030000003oool0oooo04<0oooo00190?ooo`0300000000ool00?oo
08d00?oo0`00002>003oo`030000003oool0oooo04<0oooo00190?ooo`0300000000ool00?oo08d0
0?oo00<00000003oo`00ool0SP00ool00`000000oooo0?ooo`130?ooo`00B@3oool00`0000000?oo
003oo`2=003oo`0300000000ool00?oo08h00?oo00<000000?ooo`3oool0@`3oool004T0oooo00<0
0000003oo`00ool0S@00ool00`0000000?oo003oo`2>003oo`030000003oool0oooo04<0oooo0019
0?ooo`0300000000ool00?oo08d00?oo00<00000003oo`00ool0SP00ool00`000000oooo0?ooo`13
0?ooo`00B03oool00`0000000?oo003oo`2>003oo`0300000000ool00?oo08h00?oo00<000000?oo
o`3oool0@`3oool004P0oooo00<00000003oo`00ool0SP00ool00`0000000?oo003oo`2>003oo`03
0000003oool0oooo04<0oooo00180?ooo`0300000000ool00?oo08h00?oo00<00000003oo`00ool0
S`00ool00`000000oooo0?ooo`120?ooo`00B03oool00`0000000?oo003oo`2>003oo`0300000000
ool00?oo08l00?oo00<000000?ooo`3oool0@P3oool004P0oooo00<00000003oo`00ool0SP00ool0
0`0000000?oo003oo`2?003oo`030000003oool0oooo0480oooo00180?ooo`0300000000ool00?oo
08h00?oo00<00000003oo`00ool0S`00ool00`000000oooo0?ooo`120?ooo`00B03oool00`000000
0?oo003oo`2>003oo`<00000S`00ool00`000000oooo0?ooo`120?ooo`00B03oool00`0000000?oo
003oo`2>003oo`0300000000ool00?oo08l00?oo00<000000?ooo`3oool0@P3oool004P0oooo00<0
0000003oo`00ool0SP00ool00`0000000?oo003oo`2?003oo`030000003oool0oooo0480oooo0018
0?ooo`0300000000ool00?oo08h00?oo00<00000003oo`00ool0S`00ool00`000000oooo0?ooo`12
0?ooo`00B03oool00`0000000?oo003oo`2>003oo`0300000000ool00?oo08l00?oo00<000000?oo
o`3oool0@P3oool004L0oooo00<00000003oo`00ool0S`00ool00`0000000?oo003oo`2?003oo`03
0000003oool0oooo0480oooo00170?ooo`0300000000ool00?oo08l00?oo00<00000003oo`00ool0
S`00ool00`000000oooo0?ooo`120?ooo`00A`3oool00`0000000?oo003oo`20003oo`03002LB000
0000000000<0000000<00;oo003oo`00ool01P00ool00`0000000?oo003oo`2?003oo`030000003o
ool0oooo0480oooo00170?ooo`0300000000ool00?oo08000?oo00<00=nL00000000_ol03000ool0
0`0000000?oo003oo`2?003oo`030000003oool0oooo0480oooo00170?ooo`0300000000ool00?oo
08400?oo00<00=nL00000000_ol02`00ool00`0000000?oo003oo`2?003oo`030000003oool0oooo
0480oooo00170?ooool000009P0000140?ooo`00c@3oool00`3ool@0Ga@001AOa03P0?ooo`00cP3o
ool00`3oohl0=@0D05o4o`3O0?ooo`00bP3oool00`3oScD003F?0?ooo`020?ooo`0308le000eSol0
oooo0=h0oooo003:0?ooo`070?ooS`0e01@0GlCo0?ooo`3oa5l0500D05o4o`3O0?ooo`00b`3oool0
1@3oa5l05000000000000000=Hoo0>00oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348031, 0.00348031}, {{0, 430.938}, {430.938, 0}} -> {-2.10098, -2.08166, \
0.0144874, 0.0144874}, {{0, 430.938}, {430.938, 0}} -> {-2.10098, -2.08166, \
0.0144874, 0.0144874}}]
}, Open  ]],

Cell["\<\
This gives the conditions for a quadratic polynomial to be positive.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(Clear[a, b, c];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Resolve[\ 
      ForAll[x, \ {x, a, \ b, \ c} \[Element] Reals, \ 
        c\ x\^2 + \ b\ x\  + \ a\  > 0]\ ]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(b < 0 && c > 0 && a > b\^2\/\(4\ c\) || 
      b \[Equal] 0 && c \[GreaterEqual] 0 && a > 0 || 
      b > 0 && c > 0 && a > b\^2\/\(4\ c\)\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Limit", "Section"],

Cell[TextData[{
  StyleBox["Limit", "MR"],
  " now has an ",
  StyleBox["Assumptions", "MR"],
  " option, which means more limits involving parameters can be computed. "
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples", "Subsection"],

Cell[TextData[{
  "Normally this limit depends on the value of the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\ x\^\[Alpha], \ x \[Rule] \[Infinity]]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(Limit[x\^\[Alpha], x \[Rule] \[Infinity]]\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[TextData[{
  "The limit depends on the assumptions you make on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[x\^\[Alpha], x \[Rule] \[Infinity], 
      Assumptions \[Rule] \[Alpha] > 0]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[x\^\[Alpha], x \[Rule] \[Infinity], 
      Assumptions \[Rule] \[Alpha] < 0]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[124]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\ x\^\[Alpha], \ x \[Rule] \[Infinity], \ 
      Assumptions \[Rule] \ \[Alpha] \[Equal] 0\ ]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[125]="]
}, Closed]],

Cell[TextData[{
  "Here is a similar example where the limit depends on the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\ x\^\[Alpha], \ \[Alpha] \[Rule] \[Infinity], \ 
      Assumptions\  \[Rule] \ 0 < x < 1]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[126]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\ x\^\[Alpha], \ \[Alpha] \[Rule] \[Infinity], \ 
      Assumptions\  \[Rule] \ x > 1]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[127]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[\ x\^\[Alpha], \ \[Alpha] \[Rule] \[Infinity], \ 
      Assumptions\  \[Rule] \ x \[Equal] 1]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[128]="]
}, Closed]],

Cell[TextData[{
  "In the case below ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " is cumulative density function (cdf) of the normal probability density \
function (pdf). "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = 
      Integrate[\[ExponentialE]\^\(-\(\((x - \[Mu])\)\^2\/\(2\ \
\[Sigma]\^2\)\)\)\/\(\@\(2\ \[Pi]\)\ \[Sigma]\), {x, \(-\[Infinity]\), y}, 
        Assumptions \[Rule] \[Sigma] > 0]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(1\/2\ \((1 + Erf[\(y - \[Mu]\)\/\(\@2\ \[Sigma]\)])\)\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Limit[F, y \[Rule] \[Infinity], 
      Assumptions \[Rule] \[Sigma] > 0]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Import / Export", "Section"],

Cell["\<\
New format: DICOM for biomedical images.\
\>", "BulletText"],

Cell["\<\
New format: PNG for raster graphics.\
\>", "BulletText"],

Cell["\<\
New format: SVG for vector graphics. \
\>", "BulletText"],

Cell["\<\
New format: MatrixMarket for sparse matrices.\
\>", "BulletText"],

Cell["\<\
New format: Harwell-Boeing for sparse matrices. \
\>", "BulletText"],

Cell["\<\
New format: MPS for operations research models.\
\>", "BulletText"],

Cell[TextData[{
  "Performance improvement for ",
  StyleBox["Export", "MR"],
  " of raster images. (2x to 3x)"
}], "BulletText"],

Cell["\<\
Performance improvement for Import / Export of tabular data (2x to 100x)\
\>", "BulletText"],

Cell["\<\
Improved export of XTHML, now also generates cascading style sheets.\
\>", "BulletText"],

Cell[TextData[{
  "We are now at roughly 50 formats supported by ",
  StyleBox["Import", "MR"],
  " and ",
  StyleBox["Export", "MR"],
  "."
}], "BulletText"],

Cell[CellGroupData[{

Cell[BoxData[
    \($ImportFormats\  // \ Length\)], "Input",
  CellLabel->"In[262]:="],

Cell[BoxData[
    \(50\)], "Output",
  CellLabel->"Out[262]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \($ExportFormats\  // \ Length\)], "Input",
  CellLabel->"In[263]:="],

Cell[BoxData[
    \(52\)], "Output",
  CellLabel->"Out[263]="]
}, Closed]],

Cell["\<\
Competitive Situation: Best in class. \
\>", "BulletText"],

Cell[CellGroupData[{

Cell["Example: XHTML Export with Cascading Style Sheets", "Subsection"],

Cell["\<\
This is a notebook expression corresponding to a simple notebook in the \
Classroom style sheet.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(nb\  = \ 
        Notebook[{Cell["\<Heading\>", "\<Title\>"], 
            Cell["\<Section 1\>", "\<Section\>"], 
            Cell["\<Some text in the middle.\>", "\<Text\>"], 
            Cell["\<Section 2\>", "\<Section\>"]}, 
          StyleDefinitions \[Rule] "\<Classroom.nb\>"];\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[TextData[{
  "This is what it looks like in ",
  StyleBox["Mathematica. ",
    FontSlant->"Italic"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NotebookPut[nb]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    InterpretationBox[\(NotebookObject[\[LeftSkeleton]"Untitled-1"\
\[RightSkeleton]]\),
      NotebookObject[ 
        FrontEndObject[ 
          LinkObject[ "wyd_shm", 1, 1]], 16],
      Editable->False]], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["This is the same notebook save as an XHTML file. ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<document.htm\>", \ nb, "\<XHTML+MathML\>"]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \("document.htm"\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  "If you view this file in a web browser you should see that the look \
simulates the look inside ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: DICOM Import Medical Image Format", "Subsection"],

Cell["This imports and image scanned using a MRI scanner.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ Import[\ "\<MR-MONO2-16-knee\>", \ "\<DICOM\>"]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\ g\ ];\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 256 256 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
6.93889e-018 0.00392157 -0.00392157 0.00392157 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00392 translate
1.00392 1.00392 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000102010004060300010405060706040506050606030100000101
00000001000002010001050605070908080A0B0D0B060809080808090C0C090708070609
090A090B0C0D0E0C0A090B0E0E0D0C0D0D0D0C0805090B0C0C0805040505050403030505
040606060705050503010101030301000203030100010100000100000001020608060103
080402060405070403030301020202030303030305050506050505050505050403030404
050606070706070707080807070707080908070705050403030708080807070707080805
03010000
060505060505040403040300020302060807060908050504030002060406040506070909
010609060405020200061219100C31432308102B3A3C413A283139323D361D1306050B0D
0903090D0508120C010B292D2C36443F3B474E5C4B2D373E383A3940525140363C332A3F
3E423C434D545A4F403B46575A534E515255513C283E464F4D35251F2227221D19172326
1D2B2D2D33212325160D0D0F16180D070E17170F060D0B05070D0606020D173041310E20
41221432232B3B2220221E1317171920211E1F243233323C3C383C3D3E3E3B31272E3935
40534E5762555D5C5E6B6F6E6668737F888176716158553B46819597978D8A8998A0A073
472A0105
030202090C0A040302030604050203030201030405060606010102020106020401040600
0105050104040304030111150C0A2F3F2415203D433A3A3B332D2D2F3A3926160504060E
0F04030804000103000A2B2C292E3D393A494B4D402D2E3333383B4558564643453B303C
34312D384548443F383340555551504A444B54513D41494B3F261E1D212A1C0D12172528
1E2F332D2A12211D100E0C110A010E0F030B130D0107090B090F13130D0B1D37382B1824
3313102B1D2D311A1F251F16201E18201D181A212D2B293036332F333430302829404E50
545351596458575658626566615E748680777C73657066404C7A8A91918B939FA7A5AE87
50240004
0703050302010401030305050305060300040402090401050305040605040000060B0102
05030007090301020202161C0A0C273D372123383E3A36322F2D1D2534372D1C0D090408
0803030806000407000723291F23393B35434F553D24232A323E42444B42313736313335
2D3A3E414749443C37343E50554D48474B54514F43373F4748331E15162020151110161A
142F392A2F1E1E130B0C0A11130A151C140D0B120507100E111914161D1121423A27131B
2D130E201A282A18131B1C19191B1A1D1B22262B352F282C2F2D2E31302E2C2A39505244
51514F525C5D595758646165655D6E7C756E756E67735C3B648A7F8C9592A0ADB6B8BD92
40130006
0403020307050205070203030305000203010101060D090409040103090707020A080804
000509030506080202020C14090A253F3E343938363536352B2F1D1E2E38281C160B0D0E
0D0908070101060A07031225202230383E4A454D3D1D1E2A2F3F433C4140313129292D2F
36473934373A4E503D39484E46444643475754564B383339402C1B1D20140D0E0E161E1A
1225332D33291D17140A0709070A12110D0F12110B0C0E0F0D181A171B25213D46321414
231109191D272817111D1C15181D2023262B24262C29252B333C3C2A242A303D45474640
4A4C5250515153595C68605F59556B777370706B6E724F35709A98ACB5B5B9B7BFC3C28F
2F070304
070401020808040204050A07000609050503050407020603080404000604020502000609
080200040503030202040B100C0C24393738362A3639312E2C2822212C3B261617110D0E
0D0805070402090500090C1C1A21272D3B4D46525B3D2F2825343631343A3A2F2823272A
354531353B33464E37344D4F3C3E463D385051453E403927231D171616110A06080F1718
121425322C2520170D0E151A141212100D0F14110C0B0E100918221F122011243D33191B
220C0614202F2A1B191C1C152723212527252128282622282E342F22222932393C424443
464C5955544D4B5452565964645B6C736A69676D7A794F3F7FA4AAB8B9BAC0C1C0C7C87D
19050602
040002030305040305080701010506040603060A020A0307060306020804070400030003
040304010002040703020E120C0D1A252C34322E2F3634313425232328332814090A0E17
1608050905020C0D01040F1D16192A303C4C475571674C2E21293035323836262F32312B
3437323F4A3931362E2C3B4B4C414953484A403233424023131C1A1413201A080B100E0A
0A132F3921282218151411171A12101C1D171A19120E1412101A1C18190C011C393A2723
21100811242E251E1B1D1D1C2C25242B27242323232E2E302C2824242C3839333E443B3E
4B4D4F515253545A5A5058615E55515B645E646E6D6F483B80ABB3BAB8BFCBC8BDC9CA6C
110B0903
03070602010203050502030604000307060A010204040504020501080504030800050B06
020201030303030B0D05060D0C0C1E2C2D2B2F3A2E2E2F2F2B212B29262E2B1904020D18
1203050A070707090B07171E1D1C282C394D445B7E674C402C26333E393A2E21212B392D
2E314140433F302F3A403C4858464D5D444236353B473F362C1A101F1E1E1D1821231910
0D193737242C1F23211916171B17151D1C161A1A0F101A1C1D1E1C1813100D061D302A24
221C100B171E1A1410181C2429272B2B1F1F232025302E2C222028262B3D39333E403B3E
4648444A4F524C5057464D56534B48495661666C6364424F92A3A8C0BEBDC7C7C1D0BE51
0A0D0904
03080605050309060B0C040200030104030A030908080006040503070306070404020005
080502040506020308090A07060C1C31352E2E2D2A2D24262321312A2126241705060912
110103070B0A0301020410191D1A202B3948426A906946412F202837322D2D352021372C
283441383A44403B414C4C4E4E404950425044423B403C352E150B19171820211C171D19
101B2E3A39271F2A292422201A1A1817201F16121114141D302A241509211F081222231F
15131914121B1C15141A1C2122262B2822201F222D31272624252A2428332F39453A3339
40454040454039474B40444243484F44435D5C646051355E96A1AEC0BBB9D0D8CFCBB561
1E140800
03010306050201060603020303050504030C0605000105080B02070A0A07040A04010402
0002030A0B04030202060404050E171E2B292B262223162126202B251D2228180904030F
13070200040707040309081D1C101F2E383B37608359333A35221F2926262E3420242A2A
2B35353036373D3A4146414A4D494B40444B3D3F3E43412E231F17111C231D1A1C1D1A10
152C303C422B302C2A31312D1A16191318211D1A1B18141A2D292C16212D2A1F02161E12
101110080A121715131D2627252023212825201F252F27262527292124292E383D342E3C
4C4C423E4140414D463F464B4D4E555E4A54566363523C6691ABBDC9CCC2CEC5C8B6A271
2C0F0C05
0509050804040605020208040802050904040B0902040006070905000107040303080904
0605020409060103080C0A0C0D04141D23212B2A1F1C1122211D241C1923261505040608
0D0A0100020A05050505021011131A1C2E43415C7B5D33333520141E28302F2A172E2F2D
2A2F3D38312E4138374745463D313D3C45464248423844301A2527161F25231F19201707
1B28243343322E2D293433301F161C1E19161A1D181519232A2D291F2F1F292C0B161F0E
12060A0B090E141314212325262224202926282320282E2F24242C242227302F2E32353E
4544403B3D414345484A4D5759545E7561504F5A625840759AA7C0D2CEC7D7B7B5ADA375
26030D07
010607050A080904020605040B0A010606060700030600040A070304060A050006070607
060504070807050406030C15110A1B1D1B1F25211B1D14201713201D191D1B170D020710
11090000010405060501060F151C151C36444760735D3B292418101E292E3330212D322D
26384C3C3937494749606252392E506055595F533E284031222D342E38363227141D2018
2221272F493E202C2E3A3B30272418181F1D2023181420292C312711111226362C20130B
060009100A0D10111D23242F3129262730302E25282D28242826292D282B2F2E31353537
38373A3E434641404B5148494E495375625552515D58457FA1B0C6CDC4C8D8BCAEB8B56F
24080602
050004060207090005000206040005070302040205010004050302030303020006070303
050A08020303060A0A02070D0C051224261C15171B211614140E191F1B18191A0D00050D
09050504070404040403020E15150E2237355276664A3F2B1C1B1C1D1F25323015213A38
283C4B2D414B404859625E5C5D5B676F67696A64635759463A38331F323B2819171A0F08
12161F2E4C54393E3D414E4030322726282526231D2228292F2E2A1B1D2A2B29211E1B16
0D0208110B0D0A0A19212630302828272A2F30313A392A24342E29302F2E2A2B2E2E2932
3D3A373F4442454A504E45464C4A4B564753524B50464C81A0BCC4C7CDD0C7C0BEB4AF68
1E0B0807
050307030404060100030806020304060303030703040403090806000606010008090406
03060501060505060808060A09040F151F14191E181E1D191F1E1B19171A1F1C0D020507
060705070B04050501030711130F0C1F3334587E6E4B3420151417161A202928192A3B40
21234A3D545F43415B5539446056454C767666686B5F5A463B3C38333E361C0E111E1B0F
0E131C353F4A4851514C574E3C362931362B25202231302631342B384A3F210C0B121D1D
1E130B0C040C0F08173138312720262B2B2E2F3237302828322F292D322A242C2A2C2A2E
3B403D3D3B363E494F4D48475052483D32494F4F4F405186A4BDC4D3D7D1CBC2C5CDBF57
1E0D0305
070A06040309060604050407050503060807030603020106010304040408090304070407
07000204040304050302050606030D0819151617161915151917110C101D1F1206010109
0E0403020303020D050B0713150F0C1F2C2E4E71765B2F150E0A0F111A1D252E2A35282E
25284D3F39475D5C605D41485B5551577D7C7B76644E4C4344463C363C3B3028272C2C1F
17232A33303E4C5754525A594C402E2F332C2A29262F342D3130265567281B2C3C362B24
251904080D0C090B20313335312C2A2834332B2B2F37352B322F202A362E2C3232352F2F
37423F3C41414040464E4D54594F424247444C5756405C98A4ADBFD3D3D2D0C6C6D9A638
16080606
050D0806040005010405020707040A02080807050705010606090D080706050907030303
0707050505050007050202040400101017161214191C110D100E0B09111B1B120804050C
140702060308030807080513150D0D203130466C7B5A270E050B1411181920312C382F36
35343D36404F5B51627C6F6A6A6F77636C788575544A615F5E564038454F45362E32301F
181F1F2B353D4C5D5D616C6D5745372D2D292D322B2C312A2F312B65501E486165524033
261106080D08000F292F2B292B332A2A3F362B2E2F3B39363D362A2E372F30383B352F3A
393D423B3B46473F4247474D4C473D455E47425553416593909DBCCAD0D9CAB7CACD7433
16090B05
060B09040401040305030707040201060506080303060301060805020609040809010003
08090202040B00020707020909020C12130E0F110B121211110E0F11151816150E050808
0C060301070704020306030F0E0A0F21343849737941130D060E1217211717302E2B2B40
403C463D48605945738B6B65575F7861647E7B75717B7D5D5E58474A4B4A4D3F2C303628
1B1B1B2A3036495D676A717C6F5D442E2A2A30363234322E342737733A2E6D8989765838
291E160D120A000E233231252834363A3B312F3137322E403B2F2D2C3B3935373A333541
3C42493D364047424146494A48473A405E4B4451463C6699A4B2BFCFD9D7C3B3DCBF543D
1E0C1000
050306080501030509050B0606000105050A080708050103050505040608050406060104
0C07020707060305020B04050804000D101017180F0F0D1012110D0A0B0A0D130C00050B
08040409080205050006020C0F0F1D2F333A5E7C6430110B0405051C23171A2F3E443E58
5645575B4C55513B595A33464B54758185897B82868263395F7053585F584C3F372F2F30
261F222B27304458666972867B6955362B35404038393537361E49652C588489705A553D
2A2B20111A0A001A2D3638353C3B393B34383B3330242F3D3532342B343933343C343235
353F40403D39404849443F4549423C4A574A4D503D407FAEABB1BACCD0C5B4A8BE9C6242
1806070A
0205010C06070502000603030201010A080501020D0D0605040603040601030407080401
03050807040106050204030502050801000E110E0C0C100F0B0B0605101110140C00050D
030203060707070B020406140A0F2030303C6F7A4C2A1507000507171E1C1C2B41504452
53454E615E5F574B5552475C7178899377768184808777606A6C50414A58595F52281E36
2B18203031303A515D636F8B7F6C5E3F2F373938353B3C3A322C5A513C6C747B6C616151
332320171E1A0E1D2D2F383E443F393D37383D393332403C373937363839313A402D2932
3842404346403F4547423F444540404B49404B4A364082A79BABBAC6CAB9A5ABBBA6803B
0B050809
0605010A070606050005090607070401080906060C100804040205070704060606030302
050106020400070202050207050A1204000C07080C06141707090D070C16120C0A020509
010905010502050C04020414091025333C42616E4C250E0C06070B1D231E233E44433948
54504F493E5265657480787D8C83758B858085806B707072665B4E3E42494A504B312329
27262625222E3A3E4D5F607D7E746048373129323C3F3C3A34486E4C5271757F6C65625B
4B20152225221610232F373740423D3F3E383531334048423E35303A37362E383A303136
3A3E424541403E404444454D4D45393D40404A48304491A8A3BCC1C3B99FA8C2DADEA135
07040208
030305070C03020205020305050401040604020507040303050403060B03090404060106
090205040403050301040504060306040206090809050E1209090C060812120D0906050B
080F0704020401060406030B0B1A272F3A3F505E492305090C0A131E1F282E3B46585352
534F585D415775626E88726985896575A39C8C8965504F71766A6F705F5153473B342525
3534262A1D2C3B32455A5F75867A5A554026263D4D4339342C4B5B3753647075615A5447
4E340E2A2E181217253A423B3B403E3B3C403E353940403F3E3A353E3C38303535373937
3C3A3E443D404847433F424D4640383B3E3C4B5A3953A59F9EC0BBBBBBBAC5C8E4E98418
08000303
09070409070504050A0801010300030B07030203030206060807050D0E07060203030408
010403050603060505050607080204020503070E0D0704080B0D0C0B0909110E020A080A
050707050308070301030206071E2429384253472719040101040E1F2835313946555553
54626073676275635164726F636E84738B9A918E847446405560626B685D585248423F37
302723271C2F3927354757698773545C4F2A2A3B433C402F1A4B624F625E675E5150453E
484E26203119131E253D4B43383440483E3F423C43423A3F3D3C3E403F37363838393B35
3B3D3A3E4144444041424A4E424040434040535D3761A896A2BEB5C8DCD8D0DBFAD65712
17020504
0402060B040407050205070404010C100504030506070804040406050506030201070508
0104020403030406070603030A0603050A040613120904050A0E0B0A0B030E0F01090804
03030103030206090303030B071625303E484B33170F030507020C1F27292C39414B5064
5D593D4D74675B69675C667E746E98766E88827A7F75491E24455A6B6F67564F505A5B40
2C2C2F312832382B363F4B5E7D67585B533F3639403F472E21515D5E7369645A5C4A2F2C
39534A22212C24132543483D40403F423D3D403A3B3A393D3739403631383C36353D3F34
3E443F3840434140444549463F3F3D413F3A50523982AA8BAFC9C0CAD2CFC6D9FFCD531B
0E000206
00050802000506050606060101020305020503030B020303020604040209030304050607
0609040705010508040602030A0801070602040A0B0909090A0904070C02050503040400
0209050702060107080B04090D1E2E3035434739230C030707041821222834343E484C69
65492C335A5D596A7E88787B866C8A8878758374706A5A57536F87816661676965584031
343A4645322F292C302E404E62545A5D524B3939494D472C4170626481765F606A4D2F1E
263546422F2D2B1C2E474435474639393E41413F3F40413F3C40413739403A372E3B423B
424646403F3E474444424247424245423D324F4D3C98A287B3B2B7CAC8C7BED5F0A84119
0C050705
05060804020300030B090201060700000405000204040302070402080305040304020805
0A03050506050908040906010C090506080602040908080D090407060B0A0D0703040904
080A060A0600030404040908122227262C414C341505090A020C1D1C1723363D4D4B4253
5654523B455F746856849A806844899A7F6C8A94866E62808C84887765686463503E4751
463D545032352B292B2E352B3A465D6B5C56443B4347402C537B66646F6E605D635C4A27
2022264245292B353134434747413D393D4141414144443D3C403A353F3F3B3F31384842
423D3E404040433C4447444A403F4D4241405C403FA08F83A89FC1D6CCC7B6CDCB773417
0A070505
080403040607050201040606080400020505040504070404020505070102040502020507
0605030905050303060C0B04050504080903020B0F05020605070A04060A0D0705020A0C
10010304040300060604080610232B2F394C4C291008030B040D1B2124283F404A595B5D
6661595A6F615A5E3C5283786F507876616B7480795D69898670706C7A836B5F58606C63
5B4E52503D38272A2B251B20364A6C7A5D5050423E3F443859755F697466545358574D3C
2F282C2B3F3D32463D324451434140394040424B474745393B423E3F4640404441424942
413C3A3E454844383E47414940444D40424C632750AF7D80A6ABC4CAD0CFBAC2BB895123
0A040406
0305050308050505040604070503010100040605020B0102020103050505040904070506
0704020600090304070A050805020603060B08090804090B0305090707040A0401020508
090503020305030309050509142838373347502B0C070605030E141E2F32414042566C6E
736E646E836A4F6B69585543575A7673657E7E7C7B67637B87807D7B766B67757D7C6356
5E4C4F59452E1C282F261626334057736C494D4B3C40492F537E6B7A865B3F4D5E54433A
352B212930373C504A3D4D54413B3F41463F3F4A4D48413B3E4240454A423F3F4045473F
3E404749494B4A403E3F37434049423F42495B1777B76A8EA4AABFC5CEC3C7C5C0AD5A15
05040404
05080B050608030707050304050504030104060800050408030705080802040005040401
04040604030503090A060205050404040A0C0B04000A0E09030604080E070A0804040304
0103050707000402060506061627313223394E2601070C0306151818272E3B4642404F5D
61737A5D5C736B738D7D5950626D8693868B907967686D80776B72756665808C7B676576
7B6553463B363B3C30332B29243830577C524A48333D48345D85747D836247475553473D
3A3224262929395143364E50403F4A4B3E3B3D444D4843434242444B4B41434440474D48
43414D48474D4D4140434347474A3F424146491C969F5E9B99A3BFC1C7BED0C3C4B54500
04070402
040403090301030505020106060405070306050105050606010B0C040403070304010401
07070506030B090002050604080802070500020305090300080A01070904080C0C090508
0A050503050906070605040017282A312C2E3828110F0A030A0E111C242E48574234455C
5A63695D526D80737B775B7482787B756C829372657280886A72817867768983726B7171
6D6F6A67664A4C3B2529302B213A333D675740453D3B4445607F726D736756474F564841
3F3431332F323C4F423A4941404446453A3C3D424D4A4A4F4C423F43474A4C464649474B
4D43494B4B514D414448494947484448414D342BB18E6394979DB0BFC6C9D8D0DEBF3F05
05030303
05050207050405020606030701040507000609080805000C020206040103090309040601
0501030406090503020203030403050A070608040A090201040804070D0704050B080805
05060505060C070303020103182C2E37463F25221407050B0A060B25291B354234335571
6A64635B4D5B898A6F65586D80665E7E8B897A6C7C7377786F847F7D857B6E666A6C6E7E
79626D80705060442B3232261D2236284B6443454B404246527E7B79877160504E564545
403737393A39414F43393C3A3B3D40403F454A4F4A42484D49404045444E4C4048494348
524A4B4D494D464547434B4B40464C433C522940C07B6CA2ACA7B5CDCED2D2DDE6A53908
05060B07
030400030602010704060306030506050202040A02020208020303010204060503050302
030206070B030507030204040303020405050C090607010707060304090C000105060403
01040605030605030403000411243541534620170D07080D07060C1A262A352D2D304C64
676B6B624F4D75805751666769696483806861737C65685D62726A7C87706B7C84767192
976C637063627568513A232225112E282E5C4C454B4040483C66818D9C7E6C614C4F4B47
3B393437403C43483D383647473E42454A494B4C44464B4643474C46464B42444D484A4F
4C46484945484244403A444343474C48414D2056B26575AEADB6C9D1D1DED5EADA7D3411
0803090B
040207040603010703010606070404060603080403040601060405030806060703000305
0206010508020405060805040203060506010105030001080C050304070E030504050506
04040904010304090A050606112739484D3B24140D1207080B09090C1C262C2A444E5552
5459565F5E5C6A746649546C60797B7D88848673606C6A678887776E6972819194786479
806F747268858267585444361B182B321C3342474C434052424B788D9D90736C59494542
3A3735353E3C414942473340493A3B45554B41424C514B424649433E4E4F404A493F4A52
4B484B4A45494646424448495449474A463D1F739A5D7FABA7C0DCDCD4DBD5E7BC5A3214
0706090F
0301080105050803030506080703040306070B03040D040808050503030305050A070505
0A0A0609080501050A08050404040A070506020403030002050201000106030503060503
020305030204050B0A03090F192C374646362711020D0B070B0305111F262B2B3C404950
595B58606B7A71688073668273767A899F827860676E726F6F695E688193877775685E6E
766A6A65688F7C5D575157410B1212211B1C384047493A45584C65859B9F7B665B46413C
383B433D393D444C3F4234323D3540434C4B4A4A52504749514942444B484C544A464B4E
4B484B49464B4748494A474B514546434436308E8F5A8DB0A5C2DED9D7CDC9D8B9643515
04070706
0002030306010D060500000A0A0403000401000601050205080400040506060306060506
090709060005070608060404040503010407070105020201020504040404030305000803
0606060506060805010606112832353940391D0E070F120D08000209162A363029263F4C
40414D4753747971818D84848E92837778606578865966785A626E7D867A66687A766165
7F836F62779276737E5B513F16140F1017182E3C444C3C3E6C796978939E8A72614F4332
2E394648403E444C403F443940404647484241474945454B504941474F4B4D4F4C4C4445
4E4D464044484649464640404D47484443314190816095B1A0C4DAD4D1CFD3D8C0662F11
03070A04
010204020003040500060208080200010103000406040505010302050A0902030403070A
07020506050505070706060908090702050807000304030104070508040402010B03070B
07090502020506050409030B2B322B354C3E1505060D0E0D0B090F160D1C3332393C5351
41456261596C7065656D747A7C6E6C5B6C6E798A856C7B8778838075676D6E69818E8070
7588867A7B7B6D788A7754402C20170F1A1B253A3B4046415C8D76708A97947C5E4A3E35
373B404A4A464C524E4545464F554D4B473B3F43464D4A49454945454F4A494E4A46474C
4E4E474045413E403F4242434F4E48423F2F548B716798ABA6CDDFDDC9CECDC89A351E0D
0408030D
0402010406030002060B020604030204040402020C070802040201030204040203060402
030006070606040706040605010209000004010307070406050307070503030A05030409
040305050604010709020312292D27425D3D1E0D090910110E15181D152B3D363F475A5A
5C57677C7C84785E6B6E66776F5A6F6C84756F7F7F969582807C6E7676828F7D746A6775
7B77768285776E6D797C65564B2F1A1310081325262D4F433C7C7D6B879792755247413A
35363E47534C50554C4545544F4C494740404A44464F4A524948494A493D4B564E4C524F
494B45414645444845434541414543413C3561826B708E99A4C7D9D1C7C8BBB270201104
03080201
05060306060104040607050602040B050603050304010805050200060A07040506020105
030103040401060906040504000106060102050808030507060508040509060605080402
040304040507070703000817252E3047502718130F0B0B0B080D0E1A21383A3532354B53
686A617374767B6D6D656876727E9482827C6C82838084867F7B75848F8080867F676582
908176757D8380696A7976624C3E1F0F030018292D203A413C69826D6F757A7860544A3F
393844414B46484D484B4B5449404846484B4742464745515352494D41384D4F4F524C47
4B4B484B4A474952504845464A4B46423B3C6176686F8696ACC0D2C7CACFC7AF673E1C0B
02090705
060A02030500060803020B0802000D0605030201050206050307030B0D05040505050406
050402060B0605050504030705040706040706080408050403040804030B0C0209080403
060403020407060303040B1C28323F4C43240E0A080605050A0D081410333F403D374B4F
54595A756D5D706F6B73807F8081877D677F7C828F7064696A7D74748681838B77657C80
636277756D7E8C776D70706958452F090409102534291F3040597A7A5D53798E72584B3F
3533403E4545444A4C4F4F514A474D444E494045474748424A5648494045524B5152494B
4B45474D4B41414D4A40454E514E463C34405C6D5E6A8A91A7C2D8C9C4CBD3BD7A401505
05050406
020F0400050307020201090806020B080204010707020505040C07020004070304050203
050806030709060406060505050405010303040306040903050205030208080707090805
040204060501000206050A1D2C34404B41300C0407050C0809140B0D0F2E4549463D4740
344B6B7F685E7160637F80798B8264655A697D76817E62606976847F7F868C8B76687670
5C6980745763786767656765645639140F12030C2C3E222844658290663E658968484440
313042403D3E404A4F4B4C4F4E4843444B443F4045474F4B48504C4C41515548494C4F4F
4B4B474145423E423F38444C4647473E3E505C6864778882A7CCD4CCC5C2CFCA812D0D00
06090403
04090906050106070402040606030F0D0304020706040405020507010003060405060202
060803000106030307090700020409050502060506020505090905070603000504050207
0604080602020505020511222F363E493A2F0D03070712070913100F162B45463F373832
3249525C5D68735A65766D65697E6E7984808C75718778767D748483848983888881777A
8781787A7E7B645C766B625656524F36231607001F3226223A658F99703855856D4D4C49
3A3A474340403C414845474C50483C4346493E2D3B40484F534A4A483E515749454A4F49
4A57534546504B413B2E35464C4D4441474A526162737D7D9EBABFC9CEC4C4B965241605
01040306
030408050202040B0904030405050803040607060A060004040505050905000303040705
06070001030101020002080403030707070204020A0503040B08040A0805010105080304
04070B070203080700061D303132405036280A010A070C030A07120E0F293C4B44373430
3B5455687A6B67686B6C736F657B7986817B7261798A6F657A68717E8689858D867E726F
7B7A758091836974796B6C5C5D625F3C2D250C080E202C14265782805F35537A705E4E41
393A44474742393A494C474A49483C434748422D3D41414B534D5044425C5244474C514F
4D50594E455450403C3A434A4C464048433D52625C6E7C84A0BCB9B8C9C3B9AA4A171603
0103090C
020506010104040607070405050604010306090707040305060807050B0B02010404070B
060505070905070302020405010607060B0801040B0404070905050705010002020A0704
0704090B0301040300071B2E33343C4B371F0A090907070A1208150920332D50482F3745
464C6488825C60716C6E7B75727C6D6F636F706977806865725F697C7A7E858782847767
6A7481887F6F6E75635E665B6174694A4A2C14130A19281B1D3C5C4C28143B5B5C544844
3F39444D43362D344B4D474D464D43454B423E2F3E3A404B4A4E593B43614D4553524C53
51485751444E4B44435467554945424E4A42555D5B6C7B869FC4CABEC2B9C0B950100D03
06020603
02030B060402040307090306050303050305060504070806060305040206060406050407
020207060C0A090404030205010805050204070609080305010202020404010803030407
0E06070803070603060B1B3034303543381D0F100B090B0D0B0913071B3330494B3D334E
58404B6F72666C747B837865597377706B72888372796C7677777B847880908F7E737277
726A77827B66606B72715E5047715D43645E370C10101F3122344E442821335466564748
4440484F453321274348444949564B3B4A453E3C40394F534853543848594E505A514E53
4B465253484D4E4E4D59664D424740474C465151546977869DB9C4C6C8C0B49352190304
07040203
0200040507050305080802070603020203050A0602070703010505040201060905030209
0404000108090303030406030303020503040B03040D0603010302040408050809030505
0508090302070301060B1A353123334235190D1314110F0C0A0F170F0B253C36454E3137
4E484B56616B6C6A6B80736560707978807D847C8083637B7C7F8C8F8A9EA78E6D70818D
897A7C827E7C7E7364686355415E434058574520080D14331D245052454A3C4F7E6A413D
3E414C4D453622203C4D4A4848545335465751494340504D40544A40534D435659525A57
4D4E4E514F53524D4C59654E4244474C4445524B5570727EA3AEAFC2D6DB9B5440230701
05070308
03020103080A070304060205090704010204080502050604050A07030405050301060507
06060406030503010505080207080605070A0603040607070600000602060A0703000507
080A0A04010204040210212D2C293E412A130F181E1006061613121109182E2A3E4B352A
3D5055505961686859717A8187796D72847D7A686171617F79778B7F7B8283716C93978F
8C756E727583856E5468715A5D615567644B473D1707111E1309233936382F3D725D2C33
3B3C464A48381A122A42494E4F57573D475C52424E46363F3C5042415E4E41514E545852
4D4D4C4D4D494B4D4F606049404151523F424E49556E6A74A3B2BAC7D9DC925334130905
09080509
080602050C0B050505040402070903030706000107080505070406020304050602060403
0403040A0605060004010204050507010409060103050303040501030303040107060205
060303050100050A061C312F2C2F453D1D1113181C0E0B0D1413090F090A24393C3D392E
3D4E4A46566064685C617079676A6D6B6E656871607B8F91817D846D6D77776C67807C75
7A72675B6169676F74816D587F806D666966544538150D0C19110822322D1F24595A3228
323A40434C40160C253B444F54504F4B4A5B5546594B2C2B323D3B374D514F504750514F
45444D50504C494C5254443C3D3F4C4D43444B4D58635C73A4B9C3C7D8C057393A0E040C
09080B0A
050404050804030908070A03020503010609010205030604020305010201080803030404
06070209050203040502030402000304030505030503050702070504040102030A090704
00050705040002060B1A332F3438473E1F1111120F101412071317190802152E4453452C
364B56595E6265787564676B5C7183856A6C738586929D85888D917A6C7C838B7C6D747F
83857E7884806B686769675D6F615F52546355514E3C09010E0D08193F39273540404227
1E3541444B441E0B1F37454A4B464E513A48574D55523F252814414D3B4D504E474B4D52
4A46494D51554842473D304043414F4F4A49474C575D5A709DC2C2BACAB7715749170708
01090C08
050304060906070701060D05060506060609040305060705060205080904020103010304
0B0803090304010905000102040804060204030606020508050706060504070906020204
04080906040707090F142B292F39454129130F09070E0F0C0912272F100B13193C62593A
35475B5D5D6164767972697780757C7B61697D8B8B8F775B7C858B7B6B7F8A918A78808C
8B847C82948D766C62697860584C5A5F555F53485057250D0D160A0E323D3D4B352A5144
1E293E444947290A19364243464F574C2D3857595653443630186F7B4543474D4F524E54
4C4546524F4F48433A3F3F45434959514E4C434E58575C6C99CBC8B5AAABC69F3E0A0705
00050708
070A0804080703040504050405090606080A060405090307090409080805030100040103
0402070403070604050306010108060701040204040500040B0E03010204050506040003
0A060306060B0B112127282D3240453B2921170D1218141519202D2D180C23343A4F5C5A
4A3C4854596460566479676C6E67757077736B7D6F746B6A817C7D8076727B7B7D757479
7672707788836662728370465760646658655E3134553930392913020E325440252E586C
3F273440424332111730404B484D534A3E3D4A625647383C3D49967B503F484E51565254
4B464A55544D433E40666349424F55474C493F4D51465771A1CFCEBDAFA4B08528000408
04020005
06080802050703020606020205060507060206040104020707030B050602050301040608
050305060508060406050701040100080104020505060204070A05030303010002040504
050703060A07060D242C26323A4948311A1C171515131213152C362A1B15313A394A555A
644A3C5561666559677E7C7E776F79757C81676E6D6E666D797D7A84806B7D87776D8292
84716F757B7B706B717E65465052474E584B4B3A363B544C4A3C28060013625F262B4761
492D394541453E1D142943544A484F4A4C442D585B4C46403A58916856454D4B4E4E4C4D
4B4B545B5547403D4C6C5C4E4A4A4A464B42414A49485B73ABDACBB9C5CCA55716030608
09050608
0608020005050606090505050C03050C08070605020402060A0007080B03000607020C05
0807040604050306060102030A040603020302050A04030000080A060201030202080E08
02070807070505061225282F3D4A3F281411141E1108110D06313F2F0C1E37333D4F5649
5A543C535B586365747A7E847962696B6A766D677570607988847885968C879A92848792
94848086847F7D80796752535D5A4E5B69393852603F555637544A140C024B8F35253547
3B28383E364445292032474F4A4C504C575822335B5049433C5987685A49444B544D494A
444B57584B3F40465456464F524C4C4C41404E4E4E515177BED9C0B9CCE294351A0F0700
0A080E0A
040B07040002070A080104060C040D070607090502060205030404040504010709030303
010305060302020203040104080307060A040100050502040408070303030A0B03050806
05070D0D080E0E061D29282E3E45331D160E10190C06110F0B3A402E0B1F31334852625E
4C352D49585E63687065627368566C7C877C7F796A71738B99959382878E7E929E967F7B
7977888F938D6A66807557535E5E636B7059484569545158465964321F0C116C391D202E
2E2831373141503C263450534D4C4F53586446254B48494C3C4F7B69614E474B4F4D4A4E
464A4A474544444F584C4C514F4F4F4D39405049484A4C81C1D0C5C5D0D6732E23120300
07060603
03070A0501040907000102050D0606010502070803050305050602020004050507030006
030205060008030202060005050200070A040404000501080501020305050A0A06060000
06070C0A04131C132527253440463D20120C0E1109070D09103B4A311211263A534E4848
3F3733334458515A6B64575E6366777689807A766887867F959A9277758C919F9C887A89
7B708F9BA09B756884806D676755525C5F53524564475265695B4B4E32120422240D0B18
303928323736494D32345156514D4E564A54733F1B394A533A47625E6258584B4F4E484A
494D494C474B4752594F5753454B4C483947524842475581B8D8D2C5CED87C36170C0401
02050100
03050702050505040204020A0F07020104060507050203040700020202080A0103050205
070605060308060703030005040506030404050604050303030405040406060304080707
060304040109262C201B2F3F47484329130A090A090A1207123556381D1E193C5E4D3F42
40444B413E403F4B656A686C6E6C7D7771696D7578797B849386798384889299907F7591
8D849FA5928B7F6F7B715D676C5A4A57674F5546543B49515965354838270E000B061214
1B2616273A303A52453A4A54544A48534B4F805C092C393E39474F55554F534456564A4A
4F544E4E4A505251534A4F4D434F4D443E4F514B45445789BED9C9C4C9D98D3616090606
010C0607
0003050104040301050707080905060405040504050406020101000005060B0102050401
040303070605020906050104060303060604040304030302020308030106040201040605
0607060809091C32271C2E3F44443C2A170C01050F1217091D3D563D2D301F2E4143585B
5143495F5043516467677C80746474765F6780898061748D908B898F8C888C908C89777F
807E90906D60756F6A6B6168665A4F5365656D4D5F67483C4266543E324013100B091B0E
0006071C343337494C494F5555504B504E4B757831211821435845535248494552534A45
484844434C51594B45454E4542524E46424D454844425092CCD0C0CCCCCE943F1D060405
03060609
010203000405050200030501040605040602080B02040604020304040504060706040300
0605060403050006070804080B0501040906020707020204040305030203010000040200
04090808070B15262E29293743423722150D0A0F1918190F2F606A43252B403F39445945
464F4C625C55535D666C7E7A77767772828B8D9186717F80778B9183848A9694878B9096
8D7D8387787D998E6F6E686D6C57535E604D5A57696A525352535A4034463B312E200D04
0F09050C2A37313344504F54544E4F524E4061814C20172E6E6F42525E4E414950484643
413D434B54545847414B523B3E4A44484647434E40405998C8CCC7D3C8C7A0491C060302
04020509
030307090304060405030304070502050503060606010308020509050405020808000404
050604000102020804020707070404080803040A0A020306050607050301000203030401
01040507080A1C283834363D40332716100F1419211B1C1640777A45152E4B403D4C614C
434D393651654C3B4E636B7278818A7E91816E737B746E777083848193979B9782747F8E
8C8B89797E94978B7C736D705F4351666C4E49525C514F574E32323F4A36402F47411B11
0B0D0A021928242D434C4B5753484D4D4A41547B5A2D365C87755B5D584440484D42414A
4940495357605C44454D4B40484D434A4A4448513F416FA2C5CBC7C7C0CA943610090203
04010205
0308030D0004030308060507070102060801000104070904040406040501000505040706
0101040703040606050305020201020A050607030C0B0402040708090300060A06030808
0000030912121F2E3C323E40361E170E182527292C28251E33483C210E243C55594C524A
373D3D3A5269675340526674787D8B8583807371777767939A8D80798EA0A1988F7B766F
789796858C88717780605C7A5E415A585A5E624C514331425347414A513129142E342940
301603051115182C404B4F504D4C4E4647485273592F406A867F70614F454F4F4B43404A
4B4B5253545E5D464E534B4E4F524C4D4E464A48444A6BA6CAC1BFC8CCCD78260E0C0607
09030103
040803040808040206060604060105020800000A01090B07040203030200010704070605
0501030A05020202050704040101000307050306090A0502060A050204060805080B0807
0505050C142A272C302D40402D130E0B1B3030302F2B2C2A150A080714293D62684B3F37
2C3A4A536571776A525A616F81847E848C8E80817D84849A928B8C7E8BA0997C80959977
738D86848C87807871564F7462436564545D644548463A4F5A58554B2F27322B35283453
4E3724130D0A12293B424B4B4A4B4E4D4B454D6F55324B6A81806D625B4E4D4E453F424D
474D54555955584D5258544B4C504C4B4E404647464D74B1C8BEC0C7CAC0611E0E040904
09060404
040307040A07060803080607040306030502020803020506080205030002020604030503
040101050301020005070705030504080703010805020909070604040306060006070300
0307060912322D2E2831483D2810070E1220272E26232815102A45352D3231464A404442
404640425760563D515E44566F7D88887D77707A7372777B778080859A9D948486938F7B
809181808D8A857B73685D6C61496167516260495B6A5B5C4C4D4A4E403755584220405E
4243451F1709092838394A565041434B4B41506C543F546E7C726B67604A495248454749
3E44555E564A4F504E4C4E4657584A474E3F474E4A507AACC6C0C4C1BEAB501E0E020500
04060702
09080702060606040606010501060802030309030304020406090607040B080603060806
0803060601030905050504020403050D0C06030606060706050405050304060403030301
0106040F1E292F3631364438200C05130B11232419240F083F7C9364402D244B52362F49
635A4F4D464D503C6078535046588B8F7A848280767275898980707F9792929891909188
8C968E8E9D9475757C62606A5957605C576F674D5B5F474F4F654B4F67576D563E1F2745
2A222519140B0C22343A47514C41434645404E5F50424B6A776C67665C4446524C535043
3A46585D4E4A50514D44484853544A4648434D4A474D75A9CFC5C6C7C7983E1F0F000407
06090502
0C06040006030204080504020707060504000E060206030500090204090A0A070304040A
0903070402040507020106050201050A0C04030703030403050507070403030806010106
080507162B2A333F3D34332E1C0C020C0E161F211A0E0C357CA2925A30252B47553E2B42
55526159384E6C5A677C6A60535A868E788C847B7D898E9A8F8F867E867F8B9D9B9A9994
9691877F8693817D816B6A654E5E615C5F6D7F6D575B50585C635855594F57342F372A31
33402F14111310162430464B454343494C434959524A556971685E63624B474A45494D46
4355574D49555554524949494C4C4C473F3E4C44384B80B2D1CAC7BFC28435200A05050E
0B060001
0406040203000503040509030405020908030A0603030805070207060501040202000209
090504020402020801010806030609050709040605050602040204070303030506080706
0B020F21292F3A4039373B2E1A0B01060D13122615042D5A96AF82532C20303C40363641
4040565E4652625B5956627E7D666F857783817B83887F9396978C848E83979E9BA5A092
8E928C838981787A7A7F7259596D646268617D6D5C685F5B4D41686748434B3D333B3549
5E6F52261E2423100B25434F473F444D473D4B5D554E576568645F6062564C4B4E414043
4B5D594B4E58514B4C4E4D4F524F4A433D3E49453A5385B3C7C4CFC4B7814F2803100306
0B060304
040D0705030404010406050300080608070303050503060708030A060202030604030505
06030302010202040505030306080B0303090304060507050102050100030404060A0706
06040E1D213336383739432E1706010D1012111E0F2050799EAC8B673E2427383D33384C
4C3B4863635443556D6C6976806C45708984887D7F7F6A717E82838F988E9F9695A39988
849893889D8E7B747283786D6E6B5F556561654E546265655E585C5449485E614747424F
4D545A534630281C061737524D424D4C40424F5550474C5D6060615C5B564E4B51494143
4F554E4E57534D4E4F4D484D555249403D464A4645588CC0C2C4D6C8B58D561300090105
08060703
080702020409010004010703010906030500030201000306060503020704030E09070603
04030402000406030A080002050305090500000404000304030502040705050304040108
0602051025312C2D3C3C3A24150906090C1211101B3767A0A89C997A44271E394C403143
4B384855565047586872605A727A5B526575957F6D7D6E56585D79988F8996949DA29895
878D9480838D7F686B7A7C7B5C606342535040354A5468665F68473F5349545A4C524E4F
41485153575034281E0C20474D464D4C474947484E494A5A605B5C5F5B5851484F524C4B
5554494854524D54564A3F464F4C48403C4B4C46445893B2AAC1CFC2B68A3C0600060B0E
07060800
0306020707050206040007050705070705040308030402000C0705050905060C05080502
06050404040306090B030004060606060A0A070303060303030504080907040207050007
02020F20342D292E393F311B100A0400041011122F5584B1A394A0854E26223A40351B32
564A4D44404243505151556A68666C4942587E705B6A6E57695D6986787678868B829790
746C77705956615751555959475F644542352E363F3140464357483E503C4C5A484A4B56
52434454617545293007153A48474B4A4442414B504B4F5D60545363675D4E4956535052
55544F4855584D4A4E4C4C4C4A47403B434542453F4F8AA5B1C9CCC1AD75280C07090907
04080D02
070603070507070601020401080406070405020908090905090B0804080B050504050502
020402050704060708080502040704010609070507050406050202040602030208050507
06030C28332B2A3535382F190B0B08050A161124477AA3AE9FA1A6885C2F1E2B2F2D223A
605745404954606358525B715E58676768575A5B464A594766634B59525E597171566E62
605B515D50474E484B52504C57635752474A686E53333D4442504D454A4356543D524C4C
51485161657F5D37503614314949484B474441444145535855504C5A6C624A464F505956
4D49494A504E4B524B3F494C4E4F40404E474545404E8BB5C1C9CAC39B5D22100B050003
05070701
0807010402030304050604080A0500050302000306060607040703050709060505040704
0202030604020301040C080304070401050500060A030305060001010201060604030707
100418282F332A383B382A120B0A080C14140B2D5790AEA6A5ABA892683116282F202D41
4B4D41475254575358685A4E505D6B6774726E704B474A467569576E5B65676D5F4E5043
534551635054514A5964706C6260515F6D717F89764B565C403C444742424036344A4851
5265675C5A887F4E716E1E26464B43494944413B3E454A4E514E4D58625F5446414C5D54
46484E4D494847524D3C3C404D50403D494F4E4740548FB2B5BCCAC088501E0A09020204
02020207
07080606060902060A0C0304060304090405050705050502010309050205030704070903
05080B0A050000040504070707050407080B070704060803040405060603040401030307
0B071F2A32332D2E39381B0B0D0C0B1513051E4775A3B0A6A4A5AC9B6A3717201600243F
3C52615A50473A47636B5D656A5B54416A7669806E6E635989797983667A84866F757257
553C52664E5A6C68726863796F61545167796E77908F7B6B47335355392A273C3C3C4355
536B625262806F4F63642B26444C404243434A44464D4B4F534E4F575A59544D4C515D55
48515D5A4E4E474648433C3C4446403B424E4847405489ACB2BAC9BB7D421305060A0709
02050504
06080502090B03060609060103020707030304090704050602030C080408060D0A070703
060807050404020303020606040406040206080503040303030204070305060001030407
040F162C34262F30362C130D0B0912180C052F5B91A8A5A1A0A9B295623C2420190E3158
4D4256655F5F68797460708172646C556B5F3E635D667556737A6E787080858666828B76
787280806F71766A6E5A40636B646A584F635556748F6C534B385A523A2C284945404741
515B5A5F676464656A653A2F494D44413F424E47444E51555654525455534F535B5C5F57
5052566058504B49463F3B444844464748484547445A88A9AFB8C1AF6D30110400080908
03040503
040505010406030302010504060B080402030605080300080B050A0B0604050808040509
0A0402020103020306060401040802010506040004050304040105030404050304040403
0623262B33252F3D341C0E0C08091D1C14132C639DA7A3A1A1AFB288583C302725283C50
4B5D79786D6F7478696F7964555E6B4E485D5F77645B72546E80545F6A6F79797391807C
81727065736C515E67504C68696270623A465A6656564A414E505135425A514B3F4E5D3D
5761605843507165625D37334D53574A44444C444148494D5656524E4B4F4E50565C5F52
54504B57504A4B4B4849484C4F4840454D4A4849415996ACA9BCC1A762341B0403020502
0101050B
05000207090B080304030305090B03070B0807030505040605030C090308050005040105
080507070402030809090A04010502020A0C050102080506070406030901030802050501
0F2C382A332D323E2B15050C0D0B171018213C7BA4A9AAA9A7ABAB7A524C44352625313D
4C6B6C5B64675859697D765E4C535F443B606267655B68586C825F6E756C6D708388615F
51526951606C4B576D6771736868726437506E675F6A4F4841363C2B4D6865443C4E5241
57694343394D7A7670672C2A49515D4A474B4A4446413B40525C54444553504C47566654
51544E4A484C53524849504D4E4E4544484947433F59A1B8B4C5C7A56439160006070203
06090907
030505070D0A0509070201050608040509050100030507070B060404080807090B080406
050607050705020A0B080B0903010402060903050305030506010308010007060509040F
1D34312A3931353920110A0F080F160810194A879CA6A6A5AAA8986B484E584E28182A36
4B5B62686B7976696D6E776E565F7C6C4D494C6E795D69666471707A674E61696B5D5065
59608E80727C6044505E5E5A585B625843727A5463753B5663383F4B6575683E432D3940
416741626C567C8074602435594E503F4052534C4C44404449535344485C5B4F4557654D
4753504D504F4F4F46414A4B4B4A4A504846443B3F63A5BDB9BFC9A6652F0F0103040103
06090500
03030806060701060806050703070B0504050207090306090A0603030C0902070603060B
0600070703090506090503060A0504050404020603040803040503070009040A0A05001A
28362C2C3331332D160810120312170F14275B8D9EA6A5A6ABA48C6233223B4C28102329
3B5053585E676A6F635A5D5F575667604A3A4E7378434B5D5A627B867A55646C6A54567D
6E626F606359473B3146545445364039375861525D5D38708F766857617A693A4D2C4559
3B697779886983787651244268433A3F404E58504D4D4649464A4F4952635F544E5E5E41
3F4B53534D4E4A4A4F49454C514A4A4E494B463C476CA0C2C3C3D4AE5F1F0D0702050602
05070300
05010406080604050503050A05040A0500070B070503020505040704050603090A05070F
0D030202030A0502040607070808040204010303030A050104050608030603070D060C17
332F322D28393829120A100D0E14111428648F9B999DA4AAA7998E79451B19303320304E
463B403C45556568514A4A514D5B5246524D5241483543555052696F75585D7280503856
4A4F5B4A4F40384D4A4C5A543F435B3D2A485542505F5E60585C67694D536B4C625B598A
564B79797D63747A8061252F64381C34444C504A5051494A4C4B494150635B4F4858523C
40424D4F49505250524B434A514F4F4D4D574E3F4B6896CCD3CBCBA151170C0500040605
05060602
030405010706060804050709060506040405050604050E0B05030307060002070A090B0A
0B0A00020604000304040506090605040A0802030208000203040303020306020407162D
322F3123263A30130B110B0A19161D154490AB9789A1AAA19E9C9D986E402214291F2159
564D726A546A6B554A50625F4F696A6272695A4F4C3B5F5E5739404C5B5B5A6678635251
3E32415259544D444D5A525148486455487774494C5E7A4C404E5274594564385B735C93
7B506293907C51628073291B5C351D3853524F4F50484A4B504E493F4363654E49554136
484B4B4E4E4C4C4D4A4A4A494847484A4E555043486297C8CBC9C091421A0F0304060306
0400050B
0706020207050507030505020405030306040206060508050502010D0B05080504040504
0507060603000404040103070B0B0503040703070504040500040A0200060509040E1D36
2D362E203637280A0C0D0D15181C1B1E70A8AE968CA9A39298A8A99D835C3C2830291A3F
5A616863545C534B5A605D655C50666C614C2E5158335C655F312F5672725A617157454E
4331506561585B4C5C645C8079566060597F70443B2B574C5554325459405C565F6B5E79
68535F908282636A906D2D0F4A29244450494A4C4B444747484B4C403E57615555533D37
48525249484D51524C49484A4C4A47464D4F47434A69AFC8BEC6C28D39170F0608050604
01050907
0503030707080306090604050404040109080406030100020603050A0707080403020103
0306060308090405000309080B09030001030A0B0B0603040202070004040B0406182A26
2D2D222C392C1E0A0806151918250F3F98B3B19C94A29A9AA3AEA79887623E35403B1B1D
435554573F34475465694952644A5D5C4B515870602C47644D44454962765F4B60544E63
6B626B5E5A48394D715A507D735F6861596C60454C34536A79503564644553724A474B47
4D5B4D504862806D88663C0C411F24474A474C4D4D46484C4540434347504D4E5C5F5148
44484B44444B50504F4B454C524B4E4F4C4C433F4470BCC6B9C1BF882E0E0C0A06050507
0D0C0803
00030804050703050902060C050403050909050407040808040206070206040409080404
030504020607040704080904060404060A0A0E080508070304020504020106060B1B2C2D
312126393D280908040B141522162274ADB3B09F98A2A2A8A6A698998F6D584136341B1D
39324D6657404C5D4B5043576B4D4F524B596E67493F53544270806261775E365B5F5A57
654D3B5168563D465E4C475E565665716C5C5B66714E5461806040596066574E38534940
6B80513B57767262654A411E4D1A2440474D52564C424A4D4B453F454C49484A5E655A4D
454947474A49484B494947464C474A4B434C4E404479B9C0B9B5A46C200A090402020507
060A0806
050603040B07070805070608070506040405050606060C0C0503040404050105120E0603
0205060201040707030706030607070A040406040208120D070806050007040310253330
2A2F3F353C200706070B0A19220A4C97ABB3B3A0919FA6A49FAAA0A09D7658321F2F1814
2B294A5A5D4F4C58394A52624923435A473F6057678361575F51627460572B4691735645
534E3646554846475552494F4F58626D6052637775463F5772533D5054514B4C4E604743
575F656059685E5E423C2741501F253C45474D585245494545474543413946475468634B
444C47474A4A4E584C424946494B46484D534D404E7BB0BCB8BBA0592112080107060000
03070406
05060208080405060606020507030603020606050604060A090401050804030909060A06
03070402000103040402060506090606000805000303090A0A0906030807010421293827
1E37462F341305010E1213200F1C71A6A6B4B09C8F9FA29699A9A2949E96673033422419
1A304549465764534E6445404C3E5B6A5B5C7E576F905366793E58755F54212B7171786A
688158466049404F51505E5C494C5E6C55505E686E4F586F664E4D575535405B4E4A514B
53393D3B4847373920233C77482C333A41464C525B514740454A504D3F3245434B746640
404B4C4C47454C544C484947494C464B544F43404F80B2B3B4C3AC5D210F060007070707
02060804
04070804070602020402020204030103050505050803000306020607080B090A03050706
030302020202040603030101060D0201040806010101050305050203040703193C2E271E
212D3831260A04080E0F1615103C89A7A0B2AB98919D9E969A9DA4A092947C4A46442824
23303F47455D7A5D60602741695B6F69657C745B6C6A5251663E5962607B47194C474B69
625E3F3F58423E6657558771435266533E4C4D56613F49645753454A623E3951463B3E3A
483B2C132C20331F264376833D2A2B37464A504F4E4D514A4B4D5053422C403F4D745B3F
434F4F4846494C4E4E4B48474849424A4C4A4C4D4B7DB1B3BAC2A75E160207030606070B
03030702
04040405040602080C050701050404040705030403040708050602040606070804070003
0706010505060907050208050607010306090307000104040405030203051027342A2637
3725393A0F0D0F0B0E0F1311295C97A1A4B3A9928A9AA0A1A8A7ABA58B86826D61441A18
2834394755656D47435922375F5F77605F87737475646C4C573C49544C604F3757615470
6B4F3E3A3435385B5F5E826B3B54643D3B42394C4A39384C494C402F43322F4A361C2D30
22282A121A05103261697A66342822364C465150484A57514C4C4848433D3C3756795C45
495351484B504E504D44474D443E454F4B4543474A73A3BDC7BF984C0E0408040209030A
09070601
080704050403050C0C07070E04020907020205030209090605080A060503020305060200
0304020302070705080308060505050002060308080802010101070B0400122D2F373338
3224362808070D060A0E0E1D42749CA0AAAC9A8D89959C9EA5B0A79392978E7C7965300A
162D2A42525D44424846243950689586726D736967706F504E566F70513232414661554E
526369574649383E4B4E5750394A58394034344B2F2935302C2C3E26263131382B21362E
180B0D0C01164F6D726B6D5C2F23263B544D534E4D4E4C444B4E464847464038526F5140
434745494D4B4E52524D44484838404C50473D3E4C7A9FBCC6AF833A1409050403030103
0B090702
0506030707050B0C0405070B060102030405040405030304090804080906040805050706
06010205050401020405020404030708050405090B0A02040307060606071630292A3739
3A3B3A1B0D09100305030D2C5C809B9BA2A994837E8A9BA2A5A18F929FA2A4947A6C6137
16191F324D5139402C204072737183827F5D685A6362494B534C58505D41302E3C503D4C
5256594B45402B3E4C4A42403831362D2914112A1D19230E1811272C2E322216100C1114
150707253A5A7C706973746334262C47544D504A4B4E4C4E514D474D48423D2D4E635149
4343494E45404C555852494B4D42444D5550403B4D84A8B7C0AA853A1309090406020507
05050301
03080603040902090204090A0D06060806070203020108090203050E0A02000306030305
0606060603020303070202030A0606030B0402030305040702060500041118282B1C223E
443D34170C090508080F2137758997A4A9AD9780697E9C9EA79D90A2A39EA8A381656D57
230A0926371E2A32394360718F86646E7542496D74754730615A433036383B2E35464152
5C5C4941372A2E37394231273524151B190A0817271E0A07170A0C0F171811090D0D0808
091840646C70726B6A6B6B50311D345C494D5246444D4B4C474C4E4F4A4E3F2B595F4A48
4143474843444955564C4E4D4849494C4F4C3B36508AB1BBBDAB85300C0B0B0606050905
030A0306
03070701040504060D0606080A040505040405040102090A04020409080B0B0908070404
0404050505010306070305020C0D07080205070906020907040404000318272A342A0F3C
532F18080501060A0617264D8C959BA6A6A6988D6576999DAAA59BA4A8A9A5A39D83725D
391900051B131E3E5E5C603E495844474024336D595222335D52402B1C39674C383F5C58
4E4E33443C2D3E404043321F251B051217070509171003110F0D050711140A070C060A10
27415D6E6A6B606570584F4031174668454F50423D48514A414E4A48484E503860674540
4749404548494A5550494B4B433F4049514E3F3E5789ADBDBBAA7A270704030304020401
03100704
020902090800040A070A0D060500040B06070507090103060502020A07070D08080C0003
0601030807050002040808040A0A02040B0A0B0C0B0206060506030713222B212A3D3648
4E27110001040E0D0E112C709CA3A69FA1A495937885A3AAABA4A0ABB9B7A7A0A19A9090
8977501C0A090B38685A2D18263A464E43232D523527202D243B3A46413E6B6241415A34
2B36222F221E2A2D3E3925232D230A0C0D0B1307030C171909070B160A0908060F161F35
505B636F6961697365413E352713546446494C453F49564E464C4C4846496248666B4544
4142424743434A57534E4A4F493A404D575243405791ABB4B0A565180004070101000305
03040701
0306050406010303050806070802020404040805030303050A07030D07070A050B080205
020707050202010603080904030501020F0C080A14090000050806122830302C394D5C4C
26150D090803090C16144C8E9E9FA1969B9D9086778AA1ADB2A69BA2B7C0BFB59E8B8793
A09E8B653F18090A28462D17303E656F552A253B635762562A4447514B37525B494E4D26
2A272A200A172E3330201D262B29160C0D040A120900090F020A16130F1B1B181F363D48
57646665616D806F4A2F372E241A6E64454A4E49474F514D4C45464645465F5A7467424C
43494A4040484C4C4F4F4740413C49514A48443D5695B0B8B59F581B0B07080201020101
07020605
02070B0603070403050304090806060507060908000103000406050C0809060A0B070606
02080601060A060508080A050007020506080B040E07030B070D06173130333C535D694C
1E060B0A0D0F0606082C80A2A19FA6A19F9B957F7794A2A9AFA28E8BA3B6B8AF9A918C86
98A5A196867565411D0A0C11122C54787F604E274A556F885B4F565A524C505840394547
574741312932312C291D2122131209070E0611190E080E121523201D2D362D2D31454D56
5A6B6A687388867C55373A361F1A865F414A4C40444B4A4E4E4A4847474A59647B6D4247
484D45474A4E504B4C505445403E4448464C46416599ACBEBA9356220D06020702060802
01060307
01040406080302030302080B060209030A05060906040308070002080504010804030504
0302040A03040101020B07070E07020A090A0800090605060A060D2332372B455860653D
1F080B07090C0503074B949EA5A7ABAAA69A967B80AAB2A49D968086B2BCAEA6999A9D94
98A1A29A929BA49C6E2A2321000926517677744A40584C45322A3A3C2B1B304C40233A46
42453A31303A31222930181C1C050F1716212A2322312B2A2F2A232E3D3E383E49536472
645F5F819B8F84773C3836341733A15B43474B353E504C4C5358524D4B49496388744447
4744474F4F4B50514E484F48424443484D453D436C9CABC1B58A5928060809040303050A
03050402
0701010408040106060106040603050607040B06060201030C0801040102040203040301
0200020706030204020903070A0A0809080901010E09040709071A2A2834265A65696130
1E04060403030016407C9796AAB2A49B9B8A847D8AA8B0A497A18C789FBBAB9294ADB6AC
A29999988E8A8C8D7B462F36260F0C2F405154312E4245554B4B5F4A465340402A1C2A33
393528292F2C30352C2C222829162736364049463E3A3534373240494B534E5C6D666A76
746F636B93857F582E3B28361C55AD52484F503943564A4C53524B4C4B49465F896E4E48
404448403F48504D4C3F40413E40495452424041639DA8BAAF79451E080206040C020106
01080501
0302040302000102020604050509090C060807020300020B050608020700050707030404
0503020503010A070703060807050701060203070E050005030E192D2D242C59686B4B1D
1003030A080101426C8CA29FA9ADA19D9A897B849FA29B978A8B928A96BEB3664E829D99
A6A286737C8F999967151741502F180E3E41282026262E373E4C726A616C5C584955513F
3C2A212D373527262B2D353B353740454A4E4F54473A4B4539415761616163666E716D72
7D8170445E61543737312C512A62AD4A4B4C4840434B4B4E494A4749494E56617F615243
3D4B4742424C5B4E4845423F434448524E413F426F9E93AAAD6A38120802020001090B04
0606040A
0301010200040900050A0605060B0906040209070104050A05060106060C07090B010100
030307070305050305040C050503040709000905090A0903021726241F2235637A66310E
0309050A0500206D7E91A0A4A39CA0AC9F94878AA4A19D99887680979BB5A6491E5592A1
A8935A36394B4E553F13112D271B1E123B322F44301C2A241D22495D5D6F7E7D70746E58
49433B37363633383A35393E40474A4E564D45524F424D4942515A66746A706D6A654A47
5F6F6A403D3D353A342B394B3C77B242444B404043484C4B484B4D4B47475460795C5346
3D4642423F445752444948424A4A4A4F4740414967899AB6B1682E0D0606030608070504
03070603
0605030207040A05040506030005060302020705050702050609080D040705060C010404
07050301090B0107030706050203040F0E090F08040308030F1A2B1F21354F7E81501703
040A07060102548088A9A19C978FA2AA9B9B8D8CA3ABB1A28777839B96976B1A02389BBA
AD7B3D190F1601011D261B29210C1A37503E313315091A2626221C242E465F6F746D7275
6E6155514A414B4C3C404C4A4F55575D5C5150574F474C514B576565757777725B3E2727
334653403A2E35311B3C3D24337CB94A414E3E3D4B4A3E3F484E4E474F5252668060514F
3E3C4045404650594C4941424642494741444649578DB9BA9A5825110405050404030203
06020401
02020807050408080B070909040204030907090403030604080707030506050403010301
050708020807030203020309080809040B0909070A010506181C272139525F776D401304
05040604002382878EA7A4A296939FA0A0A2939AACA094968173949D7E71604C4F6A9FAF
964E0E080A2C3C3E38220B100A0910253B5A715E3418191A13140B0A0C141B31525F5E6B
7672716C605765645352565359606563584A48514C464A495067716C6E6E645B412B272D
263042403F37321F273B2B313D80BF4F424D3B3C4749474252534E4A525445618057464E
4A4A4748475256554A494045433E45494D464644619BB6BB904512110604060107090007
05060304
0B060A0203030C0003050608090304080B06030704060301060700050E0D0C0200020802
030606030A040501030D0706080306050D0D08030606070729232E1B4061646B51270C06
0705020211588D859B9FA49E94A5A8A9A5989BA6A99D92928285957253566B91A8A49D8A
581908204A737B796A5C615C3A2215070C24495A6F6E665C5B605D58412E211A3159675E
52586C706B6C71675F5651535253595E5B4A465658554D465A68646565645446392C2F44
3B303B4546371C12262851805579C059455446444B48554E52494C534E4C3B5F8C564145
484B4243464E50484A4B464E4644474A4442423A6E9FB5CE9C4413110B04020805040504
04070501
090406090400060708010503040102080203070A05030605050101020809040209040702
040002000405030408030B0607060401080C0A04050A030B2B27362235777765380C0808
070802002E808892A7A4A89491AEB2B4A88F9CAAA9AFAE93879E987E86918F9698928D78
504256667A817773706C6A695C523E191D2A3B507C8F96938F86828B878071615D6D7C77
5D49525A6470675B544F54575151595E5F5C58595C5C4E4D5B5E5E564E514C473B323248
4631374B442E2A37334C8BA26169C17248525047444C68534D4C4A504A5040588D5D4149
48444A4A4652594C4D48474B444A45444040353F7497B6CC993C19040406060703020606
03090705
060207090A050406020503020B05060A0804050507050709080005030409050106030307
030209010106090606020305030A0B010404010A0504061C2E27282B1E6362491A030204
0E0B010F5B857D99A39EA69A9CA9A8A4978492A6A19C93848E9F9F9998A19C9A96838690
A0B2A67F6B6657606E665F5445423812143962859087888989827C78787A797C7D76767A
786D695C55605D5A5C5E5E64695E575A575D635E58524D5356575A564C4244413D474445
40303F453736383F5295919A796DBC804A4A4E4A445669484C51495151584554875A424C
49424F4746525A504F4B494643463C40474437476894BBC593321A060907080507020307
03040509
090303030204070104070806060803050702040203040507060202030308070700020C03
02030C010804060506090403070302060808050B04080D2E2F262A08135252330C0B0903
0A0E003E8883879CA09D9A939DA7A78F767C8C9EA7A18D7D8C99999A9993879595808CA2
A79B8766534E4B565F5C5D4334330C1D3254687B7D79796E72747166686A6864656B6366
73777A796D696A6662697072776B6775736C6A666A6C5F585853505153514F493D3F3F40
393A4F4A3D3C284F93BA98A07B6CC1934B4B4A4C4D5052404B4F4D51525847558855464E
45405445444E4F4B504D48403F3F3E4248403E44729EB5C6842C1B060502060507020009
0402080F
02060100040409080402050803070208010A0806080D0807090303040B06030603020807
0103040804010608060703050A0900090F0B0B0906021A352B2540200C403F1F05060B06
03080561877F8F999F9F9997A4A8A79D919A999CAF9E78708BA2A19BA08B6C767971809A
9C8C7445475F676E604533292126203E4667746F645B5F5C59574E43505A59514F5B595D
6C747B7F7C746D6E6C6C7472737A78767474756D7681706C6E60554C555D504F473D3236
31445C4825195398A5AAA0A37054AEA6524A4946525657514D4D4F4648554A4B865C4A53
4E505C4A454C4E5151484A4247434C48463E424681A9B1BF7D361C070805070807050C07
05020608
02050A0701020209050201090508060803060C070608090509070101040001040A01030B
07080308040508070807060608100D0C0D08100409102735261B47532F343108090A0604
00002D8B888D958A959B90959E9DA8B6ADA6A2A19574687F9DB2AB979F8D5A47497193A4
A190724F4D4B42413B3540413A3431444A514C3F3C3A3B423C3330282820242D2F354545
4E5A646263655E5A5A565C5B575E5F5C646A71756F6D717C7F70635A5D5C4E5555452C2E
2A405242324394A9989D9EAE6A5297A35B4A4D474E4D4F5A4F5054484D56494A7D574F55
484E5045485050474C494842423A4C484D453D488CB3B5A86427170E0302040A0203050F
05010308
060609070603030605070308040406080402080202030304020B090401090B0A05000305
02090309070B0E0102030403000B0D0206040E05021C2E33222742542415201207020702
04005191829B9F8E9B978E90929FB5BCA798969686839396A0A89995AB8B381F2F587276
67554A462D1F272D424E524E49413535332820131A1E141D18160E09050706080D16291F
1C27383B393D3D38383A35333030404A4345535D585C6E7273747676706A625848473C31
253A43303A818D84A38787AB5B57798A5C404749514D4E49464B4D464C54484879553E47
41464F5248555C48514C49443A3D4C424941375593B2BA95562A1906090600050109040C
0201050D
020B02010503080603040307040305080208080903080203090507040803040F08030004
050E010606080405000704040800010410080606001D3526294B3B403A2D1A0601020608
001A737F819E9B949E938E808097A5A9A29D938998A7A49A949597948F671D1527263436
2C25293037363A3F40463D383C3623201D08060A050E130E030710080804060503060403
0A0D0F11162220171B272521241E25353230383C40495058636B7780807C736252574B40
383F402E47966D5A856C7996564C587B5B44554C51535848474142424651493A705B3C49
49434D5141484C4A5B4E464441484A43423D3F5F9BC2BF905B260404090F000302090203
03030508
0B05050B060501020806070A050702080605050D04030006090704030C00080906090A05
030402020604000301060702100C0A0B0708080E0A2A3729376548241F17130F08030007
003C86778798958B908B715D6880A1B5A68D7F8EABAC917E8CA19B816C44171511151806
193C404A503F373024292C251C1710130A14141F191D2332301B1E1E27170E1B1607100A
0B100D0A0D0B07081612090B1C1F1116201D181B2A31353D4759647181807B70665C4B45
454435333E6A57436B6F7D8360495F7F5B3B5041575453484C4748484C5353406D5A4444
3D394F53474B484F564B42414440424645424262A2B9A1864C2404020B04050305040505
0B01050B
040004060307030303050C070003030904030205080305090505030B0604060308020B06
07070401070906040C090A060405040B050304111832313A4D615C3C1A070B120A080400
106B8376939F8E75867B4B3C5D85ABB7A37E6B8FA59C928CA3AE81594B2F0C011935342E
4450504D392F2E26130614131D2127232A432B2D3B402F3641212D36353A333632202A1A
0F202024261B1E262C241717252A19182120221D15141C232C3E45536E71747A7D6E5F50
4A4C3C4041523739787E80795C4B5B6C643447435D575648474D4C48504D4F456C5F4940
443C5B55444C465250454546434743424A403F66A9A48C8E400E07060804080301030607
0402060D
060A0401000602050900050C050306050406000A0B0208090501050B03020507060C0404
070611030203050C0D020102050606030A0809051B30304C57646F54300D090F04020403
2E7A716D869D8966715F2D3172A1A9A594736B95A6A0AAAAA5997658442B1F17304A5349
4A4A432E161B1710080819151D1C2134404E414E483C2D2F391F2C362329332823302B1E
1A19203532282C353A332D30222328202328221A150F1115182736495C5762798381796C
5C5450534D6A333C7C88837259585B5571404350564D53524B444549525553496258494A
5042714E404E3D464B484849404844414C43406EA990999236120A030605080304030407
07060604
060207050904000304070205060A010207080505010302030404060505010A0907090602
020204050103040302050705070702030209070F382D264A516966462603050E07080516
55726979878A6D565F4126528DA1A599716F88929AA195888D9073350F152D4048524941
35261D15100E07041926262629202B42363A413C1E243F48472B203A3227282C33351D2E
3021243F3C3930292F34374438272D2C2D322522281A16100D161528423F4560676F7A81
71655B595056314174826C5C514B614B6F59424F545455555046484C5659544E625B4851
493C6645454E43484E4C4449403F40404A433A83976CA483250D01030407050A050A0A03
05070B05
050701030304060606010A0603070801020204080405040B000306040406090309050601
090C06010502060802070705040106000309031B362E2B4A54655030140A03050906002E
6155658B9184756E43224C829AA095776E908D74808263576E7243202F495C5F52482D20
1719180F0E1A12182218253D3A21171D27373933272F2F3539332B2F2D2E26354640282E
332B26272730312E39383B5550364446291A213834262F24191B0F1729262C47525E6F80
7C7873665246274164745D444A41544476773F4B585B4B4C4A44514E51544E4C5D5A4553
424163484E4E4D4C4E4B4B48484440464E413B827B71A56A1A09090506060405070B0A07
06010503
06010104040602060400030506090D0B040207050F090A120C0207040707060403020003
060804060702030507040907010203040906142A2B2B2C435A513A1B040A05080601074E
5C62869B8F817F6B4450849D9F8D75727F856B668079625D64513541585F6B5E3A241913
090B0F0E131A0B142522213040363533192B2B10162322311F182635413D2725333E2E34
423A403A2E341F264C433B4840384E462E272F362B2627231D1D1D1814171F2B333F4D67
757B806F5A483E4C5B7A62445F594A3B6C7E434E534F40414643474F5353514E5752414C
404D5B434D4948474A474B46495145494D433A4E629AB36B150909000607000103010905
0A020704
05030402050A04050205040506050E0D08000506040B0909040F020503040F0306000803
010A07030206060205030207000401010504262F222A2C42533521070504060F0D002B73
77859C9D92886F4F56859E998C786E7A755E5879927E665E483B4E676E5E554425100910
0F0D11281D211D283130262537363A3F14101110272A373A3D2D2C3F471C1C0F30392F3B
4540443B334826192C3037322E3D442B2335363532212029212123161317120E1A2F404B
576E7C746B4C4C57567966576C533F36657E4D58534D4B3D43413D495050554C514D474F
4558503F48434B4D4A4749443C4A45404C483F3C7BB69956130805060402060106030902
05040306
05070402020709020407090804080403071513050308030A0204070A040A0A0102060504
000304030A0506020300050104020100040820272A282045523014030505081205105C8E
92979A9192916853739FAA98776872827863657C83664A4B5263746E5F493117060B0505
1419152A2C221A3C37353C2A3644355733190B1532242623373618143E24201824243543
292740464754313535333B2C2C33353332393638474037352C3C3D23130E1D17051E2F30
39506871745E626053706F707C4D324076814D5B534649424A41454A4B4C5751524E4D4A
435D5240453E4448434747433C45423B4F46425785B0804214080C060505060404060603
00081209
0202010306070502090A04090303060503140B07050603050206060208090109090C0007
00030B01010506070306060204050409031F26273E3A3147402A0F0C02070B0E00337B92
948B8D93948065779BAEA2795B6F867670795B535D423D506471684F342011070B111311
1625231B201E1B2C2C141C2633402E433D27151520291E162619161C3516101A25232F26
132E4E324045273A3C28343840474645403C32344543322A292D2A24211520250A041529
22294B6F786E72675E6D71788465384983814F54554A48444A444D46464B4D4748505051
56614C444C44474F4B47413F43483E3B56423E7694AC8241130C06070603040B05050005
04060F08
0A050404030507020A0503070D00070B0A050304070D080909000D030607060D08030305
040A03030205050808070204000004020F291F2F413B444B3D21050504030A0109508F9B
9089939B95787599A49E92746F8383798B8B61534D4152676F685431160D0403080A0D12
19261C1E281518232C2A2C263433292A301028142A3D2A2A290E051530111B1125303324
2638403243423738343A3C3341453C454B3C3A4542413B2D333A3A3B393029211E0D0C1C
0D183C56656C7E75626C7A76786C30408F805248504B4841454047494C4848464E52474C
5962454045434B474040424749403E3F4A3D407E98A480370A040D030307050B06010306
05040D0B
06060707050706000B0402040E0F0907090105030409050903020809040C050805050304
050B04040C040103090C0907050806042033253F3D354C47381405000C070B0732779CA1
91999D9E99858AAFB28F79716D6B788886775C4D474D68786A49280C0907000E16151616
1D2620262F110E102A48320A1B2E384339132F21393E3B421C152114220F141936341813
37362F3842393C392A3C2E1C2E303540432C233A2D2F3A2D312A364437332F1523292623
0E1A2E35435A7B7D66637C77736A384A9C7D49495850443E494348525844544F4F524944
586845494E4344444A48484A453C41494C3E44809A9E7B2A0B070701040907020B050508
01040103
040502040507020210040705071405060406030707030B0C07010206050A040405030606
01050B030304040408070A04030604102A32394334394B42251211070C03031D5E909B9D
9A9A949888849AA99F857F7E6963787A716F5245596E7B66422916070B1410151F1C1011
201C131A17161B223138422025332D47262E472F201F344A210D331F1102021820170B14
1E0D16191B3330261E271F274848524B382C314231262A32341C2A423A3130292F353321
0B15150C21425E6A7379777E7B4935529680545A564C48434B485251534A584C49454645
6D6A3C494A47494C4E434E453E44434B533E4682ABA46E2A0A060A0A0905030705060908
0A060302
0F0C000A0601060304070D04040D040004020408070E04040600040305010B0305070A08
050A020305050A0708020507030509162B2736352E383832130B0F0D00090F35758A8A94
9C969291868E9C9E8E8681745046617276715A5F777E70471D0A0C0E13160E0C161B0F0D
262C252D241E2723311E312E2B221D54192036241A2124231E0924110D131C190E122832
251419070E3A2C1E2C40362F42463C323A3C3E3B3136373F383544423925192C3030251E
2B2C18080D2B4E5B687F797A7C4F3F598C714D554A474743434658514E4F49465046503D
72643A4A4046495148405348444C4B504C395A8BADA45E150D0C09080007030703060504
05050803
0807010F0D05030906031104061003080609070C04110C07020904050802030A08060503
04060706090403030303020206020E2131332A23292E32240D0306090B0A1B5D88848D9F
96898B8E93908896998A7667473F58606267626D7E663F1A0D0D01090E0D0B0D1B1E1213
1215171C140E2E303B3A33232134346426092C4E22221D1A190C201A19161E11122B3131
3128201D243230403824232529363733291F2B2A252C30332C2E322F403B2B40392A181E
352810090B263A465871807A725D45567C5E45544A423F40494852584D4D4F555049533B
75533E4F4449434C473F4C484645484B463C678BA79548080C0206020505080910080601
05020201
04050301030204060D020B0F070301080404040E1112040304020507060D040701020306
010108040602040701020605040211212B302B2F302D24170D0707020F0F2A6B8B8C95A0
938D8B8499907C8C9C9389896E5E6A665B61788273481B0A0D0F04000F150B0F1415161B
0E13181D2F1A1E311028532616414A5F484A3B5F3E22261F2E25211B181A1D1D19140E1A
2A261F162A271722171C1B2B4B423E382A3C3E333832303D3B46513D3E3D27374040393D
48382321180E182D4C698075605D4D5465544C5348373D404F54525343484D5B504E4747
80454545414B434A45464C43403E484B4F396590B78630160907070A0802020506080705
050A090A
0506070200040307060F100A070206030208020A05030901090507090206040503020505
0807050A0504030104060C06030C1335322839333032180C050506011A224E838F8E9794
8B8F9089A07A5B819C8C82826B5F61656873867E542A0F090C100C0E20210E0B1411100E
151619292519332C0E314516364928333A3A2C384E4F3E16071A243A221D18150F02120F
092C25032837231D07222E3348312C272032242C4237384241404247483A344247402F34
3E2930452C0D161F375C7E786A6253505E534841434243413F484E4C43504B53514C3E69
834049453F454F514746423F3D3B4C504B4284A1B9853718080D030B0603020303030403
08090201
01010B050403050304070D010207060405040809070304030806050E0304070E05070209
05010203060B090107080A0703121D3F301E3F3F393117070107000E1F326886888D9898
987F809AA44F3F80968C796B70655A6877807D5F35100205111510181C1208041626170D
1A0D182C23253120233929043B632614032A311F493D391C1A131B271B2B121024100F19
111F362329161B3F27151D38341C30321E162242443443504B494C554C4A515150403C43
34263F412313130827496E6F6E615D5466665343465744403E414D5A4F574B50544D3F59
6B4040474A48554B42413F403C3E494C3D43839DB284400B0D02050708060A0B08070706
0F050300
040704090908030909050A05020405020408090E0902080404030207040E05050D080202
0101010302060704020407020623262F2C2F4042402D10070304011B2A416D7C86989799
99758BAC8F3F457E8D82636E806D606B7C7B613B220A0311171F1B140F111B161C271C0C
120A0D1C3440402E35202B31275C60562229333C4B332C12041439240B34261B2B11000B
1906121E2717212E281D1C1F2B322D302E1D162A391D1A3330363D4246505D4D321F2B38
354036211F190F0E1D3B5F71715E5A50615A474B5A5F3C3C4D4A4F584F5647514E464450
513D444F55464A4245453F444644424C404E76959C6F400B0D0809060B0503090D0B0602
0A080D06
0304030C0704060D03030B08071010060809070A0E0809030E0704090B0608060C060708
040402080804010205010802083132262F3E33353D2B120605090B293A587E8895A6A5A6
8D749DA465485D728C7A6680806B6677816D441B0705101D110C1A28271B0C0E201F1916
1A1A0B15191E1C1D402026534C3B30586B66553D53490D0C3737321C072637251C131B1A
050B13240F1C3C3F22202F1A2A371E2732312C2036452F2E403C2E3E46424A3E33384141
332F304032160814102F46647262545261553C40605B4645594F4A524C53515748404A49
4741454645424649473E3B414844484C396288A7976038100E0A050E050404030F090603
0909120A
030109010608050404080904060B080B070603060B0C06080D090405040701060905090C
040508080607070501080B040C2D35293147433936271A0908070C2A406F8C918F95A5A8
76668D8D666A66647D676A7E76717A7F7759310B0102101E100F1E313116010C241C1A27
29281C15171F1B1835242D3E3F564A3E393032497044100414220F190B0B283321211D18
0F0D21221F0B1325242730102637141221292A1A1C322D365344343C312B373348554347
422F40593D20141B161E405568675952625E49486559504B5B5A4C52484B51503F445D4E
4744454B4E4D4650463C45474A4B4F4B386C91B29A5B2B0E05020109000902040B060A04
060C0D04
0509090A070D0C08050C02020C0A040607080908080C070505040503080B000804070706
0101060807040C090A120C001D30363337484E392316130D110E1828497880888E95A2A3
787894818090614F6061676C7079867F603D1805111F170C1A2D2013182224251C0F1E30
1F1131463D3A32161020272E21366344262C38455019385E291005360A08452E1E090209
1F1612151815050B24252C1B2E49351F2923010F2F3023314937282F232E413945402A35
554A443B221E1D160E1D464E5E63594B594E42537460514C5456494C464D4B4F4A4E5246
424042474B4B474C4443494848494C424B8897A792512109070106060706040A0902010B
0C080906
0308050807020502070F03100E06010007070501020A0605060700020C080302030C0701
000C050407030804030B05012734333041474036220B070B0E19263373918089999E938F
82899E919390564D6070797871737E714F290D0A10171C1C1F21211D191510191E1B3037
25101F34533D111116232A190D160C294D44210E2A20326B3F382B191F00425932350E18
14121F1C1B0A0A2A1F15120C222A1F353E25202C211C1E1A292C2C4048413B3F514D494E
44323D381E1F2D1B091E404F64645B49504C4A50706749494C5650514E4E4745535E5549
4448494544484D4D4446434543404C3B4F979AA8994B12050D05050A0C0609060B01040A
0705040B
0406030705020A020604070B02010100010605050808040803000308180F040404040A00
050404040204030C0608070E32373D38483C2E372C160D0F1021203F858F8081929E9287
8189A3A59C7F4C51617180766F7A79593517141D15141A20282824262217171B1E201D11
211915264648262215283853533947635B513E163E4222220A3447231E1046523948261A
20120D0F2227172D2A1E1D0F3039262C1905232E19283D281B262832363639414732384F
4F453C38422E2A190A1533476162564F4A4046444A51454449685C545D4C4544595D4C45
3E404245424247554E46424146464C3E5B96A1AA8E401B071004070603070A0C0D060301
04070202
0305050A09040B0A10010604080A090501020408070C0607040906090D0E0D0203060D00
03060507050A0A0507030C0E3133384049303145280D0D11112225568184878B999B847E
868E939798734F5F626D7B767B7F6F4214000F21282E221C22252C312517191B131D3231
191518272E45403124181A342B2D6065424C647941586E6F411D2D2D343D4C2C07112410
0D1519120F101B2E1A161E242F2D293526122126132337221B25251F243A433A374F543C
544B28343F33423621112945605E5452413F4C4A4B4C494C42685D465D51524C615B4B47
393C484A43474B4D434445414B514A447690A6A6843C1C090A020507051104050A070400
010B0F02
0601040A090B09060D090A03050406030B0702090807050705080908070408090503040D
040605080B06030607060B1536333148453B4538170C0F16151F326C8488928994977A7C
909491A1A56C5465627376737B7352210C131E2119171E25202028342E1920232424302D
171D372F1A180B0B19263F373639393E46312540375C5A62543F44224440312222162A2F
3E2B152B2F190818312B1F3441190F291C101F2A303A3030404C48292A2C1B2B394E6038
3D4B565C3F3C4B3A1A081D405B5E5C5340515C4D5749434F3D6764474E4A5C4A59554B48
3D3B404542494C493F44413E4C4C434A8B95BB9B6C351B0A040208050104070706070607
01060D05
02020803090806030A050502040201040100000301090100030505070907040502060503
00070A0B030305060B09112C4031303C3B414F2914130F1019274678908C948B94947B84
919295A9955B5963687A75787A6D4414081622231D1D22160B222C1F211A10121E241F1E
2136243F2F0E2130291C1D1D2C56492E4663463940201E3E474332213D4A3848604F5614
25502413161A0E164749212242340E070D182B2B374D483D2833391329330F2F4B405054
524744433B3E3B432107163B59645E56444D625C5A403846436F5A48514F59465E573E3D
41423D3E3B44474240403E403E53415F8F97C58F5A2C12020101060504050B0A02090D0A
09090503
020104020A01060505090506070406070207030C0B010003050A090B0807090600030805
02030B04000705060401142D3026403A31404D240D0915141D315D7F8993A07C7A857A7F
838A8B9E8050596F7B807F80715727070D181A1E292723221A24331709232C24202A2C25
2B2A414D37363C2A2E2C1A284A64501A264559553B1E1F345047110412312F4A443E602F
10403A1D102D463E1830351F351C02140C081C2D38311B1B202921052321022144415561
4D404B48433B384228021334516963574E5554494C41424E51785948504E4D3E61593C3E
4447403F3B4D4742434747433F5135737C93C09057250F07050A0A070806010502050700
0A090305
0404090803070D070603060C0703040602060409050408030200070A0503040501020405
060B0908040401060D11212F2B2D53462F4B440F10111A132A4D748587A4A6605A757179
7D7678886F5660707676807E664A1A0A1C1C1A1B22271F18171A222A1F1E32231A364424
1C2E40381C111F2828614532483F3121324C522C3A532E3E49734E482F474828332D3A25
0739282333302B3C1C222F293D341F1716252E313D31293E47342233413A252930444D46
41425B533C313A2E1B0A052D50626455525A4D4846424846446A54494A484D4461554747
43444341404B404B444444384A4F388372A8BB945B29120301080C0D010506070A030305
05030904
07020B0B0B0E070107030B0F0801000509080B0808070406050510060502090305090307
040C0804050501030422332F303B493F3154380F08191D1C375A767A7C999C5B54767369
645764735E585F6A7679837D57330D1423201F1F171F3C2C181C0F182D2C2E1C243E2C17
22181E40342A34302E3F2511272949463C5171524051465E4C674449423E4F43463A2A25
37312F27221A1022281D1B2A3A1D14251D2E462E2D394269531826483D3A3424254A433C
554049554E4F40181E1D1F2A45585F555758444943454A484C664D4F4C4C584C5D4C483F
4045463C454738444345403550404E947FAA9C9664280A040906100C02020A0B0C030609
0404060C
060606080A07070406030600090703030C0E01050605080301040A0708020A0D07080402
04030806020404080F2D2C232A4347343C4E29090C1B1C2B41677B81858277393960665B
594C5D725C6170787E7F81764E1E0519261D1F2C2118342E10232D12172F39302D212523
0718466F463C58384758230B292F4E512D384B4758803E454764322C0C0D3A2F313A2B10
191740390B3E330F1C282F302C101C331B29431F254936394737405A564237362D3E404C
644A4F565C664C322B1421293756575254543F444C4C4B4E54634E4D494E4B4B6B453E41
4B4E453D554B404343423B42552C6E918EA29596582A070007050605060507090A050101
04010505
050806080202000D0C060202080304090401070202030505040500070303020604080F07
000005010B02050F1F31312B314E4E3040401A0617221C35456E7B7A767D6F596E765E50
5959576B616878797B7E7A613C13061A211C1D2633302B241222260B2640393240353126
143A3D33323554272F6D53463C3C2E2830476E6B4052182A3F4F2C60533A6A6438241222
563E3E31173F3F1D091E2A120E0E080E333F2E2C48602A1745483929282F3A2F032B5A56
422E324B4A362B2E200F1A2F43616065555A49414D46464E4B5650554D50424E73434748
464D38425545484B44433A4A44248F808FACAE8C412712060803020A07060A0C09040502
02060804
01030D080306060E03020804070407000A0A08000A050D0E080701050303060C03060E09
0B09040D0B020B101627332F3848402F4537110A1D1C274B5877877D6A77756165755D45
5977766E5F676B6B797C73552B0F060E111921131D3C3423201D0F10344235232C413322
21303429353B33405260584E3830314C61461F4A3E261E40406270672B2E694424280425
59462C19381E10181B4A411C2120151E382E172E566C4C2E42442E30292640391E37372E
35333247473226301E0E1B30466C6C6655614E384E433F5557544B4D475041577744514E
4A442C574E47494642444954214EA36D87A0A484411306070404020B040D090A07070406
03080705
0803040204050A0C0203000409070302040202040C050A0A040506080307030702080901
0C04060B0301060C23242B2A3A4D4139472B0C0C1F1B1F517D8F92817F7A6D694B555856
606C796E646C646C7C796E542C05102521213234303C2B1D1F13161F3432152228405051
3322353040514F403D403C43414B55728B893E4F625B414027355A551E19553F1F354B32
19212E283C1E11130020473C2429231D1D3231223A4233304444354750495D4F3730222F
3E402B364A4931271B021F394E6D645A575A593C4245455453504D5152543D586E3E4247
56393F6A404449434441453F2390AA86A9B9B08E51140005060304110C0F0F0505040408
03090703
0E0B02070603020501070A0807090D020306040703060104060306000702040001030A04
02060202090B051731282D39455B3A3133150D17261621588083817D8C827F763C4A686D
6261818271685D6D77786A411B050F25251B213239332D363A2F353136452A232A1E1F22
1328301D3A49402E4447414851543D40506D745D404F57321E40572D283410180C2C3210
0D0D141B0A093333123246462A14111926352C1D4957393D484B49473A3C4D322529382D
2C3D4A4C3F37392319101D344D696955565C794F384D4C4D4F524E5353523F5B6A454542
492463633C4A4F4342433E1B62B5A7A3B8B9AC8A5C21010502070E110B0B160903090208
06030800
020E040305090708070505050A0605010A050A06010A0607060208020603040506050707
06050D040504061730333937445A333833120B232A1A3A6C86827E7E7B75816539526E6B
5E617E7E70665C6B7777613716090A192524242426242431342E38403A322F445034200F
163E434543312C2C62725C4D5D664B574E3A4A5450604B27234A5A4352583C5D2C3E6248
1F103343241D2F28134440312F1A1C2A2D25324C5E4B2B3F462B22222D55603433333A29
303E3F412E212A221F1D31394F63705950486B543F4B414E4C504B544F46365767424B49
3E206051474B44424046313EA4BBA3A7ACABB28B4B1500080306090C0B080B060709030C
00010306
06080301060806050106070302030A05040807010404080907010502080C01040A030805
0007080204041923343033314A4E2E3E30110F1F25133E7D8E867D79757986909584797B
6E62747063626475796C5A39130B1A272C302B21241E1C2420202C46522B133B52424036
42362D49494F5E54464F6B6D6760697566626D6D625D3B3F30436E66534729385448653C
24252E4C572A341D033F482D322D29413D1B1E2725343D486360362750654D3137444931
36362E312A211B1E172D4439525D5F5A5A5467543E484656434C4F534F48385D63404A46
2B2E544A4F45403E444C2572B6AC9EADB5B4BD8C370C0003010506050A06060805010407
03020401
090903000708080304050B0D030509060106060507050605050A06080608030707060E05
01020A0B03071528332833344E4B333F2A10172B2F0C37858A8B7B667E8E8DA8A98E7071
7C70706D616364757D745D340F09222D19203028241D263832281520453A25414C454C37
403D394E45545B462D2B3B3E4E4A4D646F69754D235A4B4A31486F8015132532280C2318
3138172B252C1A1D256151141F26172A30122C452D466E4E3342494D4630242E3834372A
3C3D3D4435322F1E1623383D5B635F5252636E5A3E4A464C414E4F4F4B483662573D5243
253D4F464E40483748443F9BB0A48EB0C0B3B7954512030C09010604030A0C040C020508
03020003
0807050308060705050C07030501020404030509020105030208060B060B030503020706
0507050A030D081E35363F31454D35362B191D282F193B8A847572718B8D869892896E6A
7E7A746E5B606A6F7A785732090F212E282A3B3D301A38503B2C202E38282733475F5638
434A3C3B252E3B465B6A434C565A54546370895E405D5C47243F3762251520362F19110B
1D2C4740161D171C242334424A34191D2C18294D384B785D3A3C464C413A2F234445323F
4D424A531C1C31170B1D384C6261614C4E69755A40464849474947564F4234685440563E
3C464F414B42493C4F306BB39AA495B1BDB5B6843010040609030D05060D09050404050E
02070100
080605070A070C06080906010B05030202050B0D01040C0806040B070C06080704070503
000605030A0C070A292A3C3C415036323218141D281C2F5D644A5C7F8D8A8F94888A7D7D
8B8A7E674E4F636C787254340911222426262B3A34243933191E283C3129383940483635
4339335D674B5F5A534420567B937E6E7362644F4D46496469666062613C0E0C06140924
45131D3F3B151F2A120C2D473B11001D28141B274758393A48505457573F32253F493938
40424E633624230C0225495D61645C4E526A83563E4C4D43424A4F574A463A664A465147
544B4F4048423E42482994AC95ACAEC8C2BAB97B24050C040201030B110801060301070C
04050704
01030702010A0C05040B07000A04050608050D0F090408020308070504050A0402040A03
0302060202120E092C1E2D3B404B2F36391E1517241B273E4F3C4A748079808980878780
808279604554666775725626040A2132312A2F3B3436442D1B21344E3D1F28434C43353E
5B533E565C394C4B40372A515D4937577A8785604E4B4E5D471744231B1C0E292D39402D
513327565A2F143A3B1116283023242E2A263336342C2B463F35425D6630263C44474130
40504138302F17070B21445E6266595256577D6F454E4A42454349473F4038623E475159
5A4D4B3C44403A4C3457BE9299ABA7BEB6B2A0682F0A040B0B0606060A09020C0400090A
04080307
0705000603060B04080706060506000C0801040302070C06050E0B0209080F0A03050509
0208020902070A15322730393D402F3E351E15121B14192B32213965746D6F77808A8377
747A6F67494C656A7675612C0414232520222C261B2C3934403E343433404A504F494349
5B5A4A4B534C4E464952718978424155395A795A3C464E44402A3E16352A273C4139201F
312A1A3649545831294A4735120D444A1B0021350B1E4033434D3C454A2C2A444D413942
43383D26192610070B2C4F6262625A4F5D53687C4C46434147424A40403C476D42484E57
514C4B4044343845218CBC85A3ABAABCAEAA976D4006060605060506080F0B0E03020406
08060601
03050308030300030C0402020201050105050C0B030607080306050808050B0507020507
050505010B040F10292C32393734343A2C19100D0E0C132717183E414F5C615B70807575
777869644F3E54686C6B5A3404181A142026313431352719242C353646654F3C3D404440
373A404E4D404240515859625B426085565273582E4F47485F6E6F6B682A0D2606112218
2D2A15150F1531202F5A413B1E0E1B0C1710165449385C534249575E574C494C4C452636
4013102A2F1A06000B2F5A68696C5A43575B6277534840474A424B42432B5C6640514C3E
3B4041423F29433854BDA195AFA79DADA8A0AC772F080A050305060C0405010408050002
03050C09
03090609090609070A0507050408090C0A090305040A040702080009010B0A0A0A060302
0706030606051A192D2C2B3C382B30362111100B09070C131124392E3C46524C50656373
73685E5A564D5E727673592E0C121A1E2523253A4B4B3D262E3F40587164534B42515146
4C40404D3D3C4F4936575F4C5C5C4D7280757F573254556D7261596A372E40593A5A5034
3F4042415A3A24233540182A37402809231E1C5057262E403F56564D524F3C45443D2421
40331117230E070C213D646C686A56505D5B67714B474053564742444135704F374D4343
4C4642493B33481E89BE8B9FA2939CA3999DB96E2208050602050C0F0907080B03070509
04040305
080404000101060C020805030406010A090D070309090F090308050401050E0403040106
090E0A03090124292C303041403A2C37190C150A08020E010A222F283347514C3A393A52
574E5962615E606F736E572B080A2B3C393A3444463C4A3218313E4443394C4A41635A44
4E475D65585D635C40586A4E6A7353658060515A4D405F927A687C6B584639545056452D
484B3B42666961615C50403F35321514271E25282C3542454A675A38292831382A212C35
372F1119250E0A182C4D6D6B62665B5E5F5564633D40414B4747474C40536D46484A404D
51473F47343F3537AFA595ADABA4A48B8CA7B4691C0C0902080A090F0C02081008020A09
06040702
0B020502060B080908070401050D0A050B08050306000A0400020405010305030005000A
040A09030111292B2F2E283B41412B2E11090E0100070705101E25203743454E2F242233
40404949434F4C57646F62360609293B31252840443B443518233647586067575D604750
55434B4B5258494E6A7B7A5F574F58606F736A5F5A6B7D82453C74675662514448474540
26193C3014283538403942543D5753111C453D221316445E3537463E41303B342F2C262D
3A270718120F1B1C2F54746D5D614E5564545B574344474F494A43443667634A504F4848
4B4D4B413C471173B994ACB4A9918195B7BDAD672B02060507050510060405090C070106
01050309
0704040707040904060A020207060A05090C0A090109050A060401060505030102080008
09040004050F2F2E3631323B35322C280806070604030A0015212F232D2D24270C172C1F
2830262B42545353687D6F400C04263A311A25444237313132363F3A495F5952594A4049
3A2D3A42505D53506257534D6D716D464D626761576E7458326880634C4E614C3D372B23
262B3228244146465E61414031375A4034350D1F40211E42626B55413C3837242A3A2C1D
1E2818080E0F15224C636F6C57564D586C4E4C4E4D4F524C4D4639333C674F4A504E4C55
594E4F4548291EA7B6A0AFB1A78AAACAC7BAB16C290B080706020A0803060B0C080A0603
01030206
0604070604050A08030404050104070400050909020602010804090A0803070304030708
06020208061233342D2B3C392C2E3219060C0407070A1010201833312D40462F14102123
170426405D61574F5D7169421A0E313C2B171B2C33454D47434B4E3D3E3E3B4B4B3A505D
403237404C4747473F444B4B6B6A60595C5C6267616372736A8E7C5A534C41352B2D3B4B
4E3F4348465D615154796F6F703121343D534017222716326C804B2F3040431D2D4F372F
1D110D130F0D1D3B6873675A4847535F684E454950484B47454644364D5D484A574D4258
60584A54410581C2A2A2B1AD9589BCBCBAAFB1691B070C06050A06040703040507060A04
03040A0D
0902000804000501060103030402090905020502090C050503020203090D0C0003000107
09050A0609122D322A2C393D3131340C040602090306031E2C172C302B241B2022141619
0B1F3F536E6456535868704F1B14282E302C1C1327393C493C374A5360625E4F3F34303C
4A40374153565E564D6A6D574F475975675254434D58627F707D70392D434E4C514D475C
4F403F415B6D67574D6E685B615553471F244D41252424243D5E4C3C413C4C434753382D
2E1F151D111E37486C77685351494D64604F494C594A4F564C4A40326459464C4E414962
5E5B4B4F1F4BC1B38FA8BFA490ABC6B7B3949C581911070B08090C0C0604080103020208
02050107
000402040401010602050E09030F08060603090502010502090103050A0B060307010102
040306040F0D292B20293942353B300A080505060F0F1A3B2913493C160B052F271B1D19
0F1A49647370624C516D7F632B110F18303D1E193828192E3A40473A2846603D375B442B
352C333E4F5F61615D6466776A5D616C7663615D5548454A4D5A494A484A4D586B5B3C5E
6F6550466B7F6E675E6A665656686E5D442C191F3E4C46321D23241310284A4939444939
3D32151C1138475E786F614B46454C5F56494B4F53484845403F3431645E4049423A555E
535448291F9DB79395BBB8A2A9C0C0B3B28B8A561F1102080A0B1108030706000B090904
03010400
010204070505040A0A090407040D0B0A02090C0404040202070A05090803060304030109
0605040E12232A2B2A2C2E4035432B110D0607080D0D1C1F2A213A3017171123101E2A30
2015445D6B76664D536265603C232B281D27261C26272C323E48413C2D2D2A2040513935
373540444666756A69594F6F6E7A7C7E896F7C8E795C4B3148553C4754544D4A5D6D6361
554852505E644952676E7B7B657A8B70514033282C2D2E332E120310171F28201B262C19
372B171D1C415673725F5444424C56566053484A4C4C493E3E37313A605E3E3F3C3A484C
4F3A1A2A80B49A8CA9BCADA5A6B9BDB4B89389642605090B090D0902060C020107060A05
03010305
0503040A0207080108070307030206070808090603050607040502060103040400030107
0A060401051E2F283B3C2F4039390B050705070A0A0E1C0B292B253D3E220E271D23171B
130E3F6274807158515D6C6E4B2625272C231B2A342629404647423F424748373A403D44
474A50696D7C826D817B757A788B8A79807F838585766D70705B6560645F5F6365705B4E
545861533F5A635040476166475E7B5F4A677E634E43323E4621233216343529352E2F22
230F070F384E6C78675F4B3F4A545F5153453E434452504242333044664C322723253338
2A143E88B8AA9A98B5BAB99AA1C3C4B6AE948C6225071108020606020408070612080108
0408020C
0009060602070A0606020207080A0B040707090609060203020502070608000305030406
030103020B21261F32293139372D060400030402101621273A38214152311A3421251207
010B2B536C747466545770704E26141B43442F261B284C553F33343B38344640313C4342
3D3B50666A736D5E706E757C77858B716859677B786B79835D4A65597265546C6A54424F
524A5757557B6A4447525C605566674A394C717769594E3F391E26423042514449323028
17181132566E8071594D424352585F554A3D45514B534D38312D45586939190B0D14150F
0B4090C2B19E8EA2B8AFA982A6C9B7B3AE81805D220605020705070809040405130A0406
0A040809
020A060104010003080606080D0D0407050203080B0A0205060104050806050802050101
05060B0621231E232F2D3F32331F070E07090807110C233F3333292540392E21041F1B06
0303245572706F715F4B5A6956292327322C271F1D384633313831424034444846433531
4244545E60707C6157647983726977737F5B71868879788772756E5D795F46555D535767
4B405D4E40544D566766776F6378673940666E7362536A4931464E4A40464A302D1D190C
040F1F425F7172655849404263625B56504A42404B4F45352D356A808153313F391C1125
5FA0C0B6A29687ABB2A7A086B3C2B0B7A7808F672C0F090D09080A090D08000705050605
0A070801
0A09030209020807050501070206080D030307060406060605070903020409070105020A
0503000C1B3024253133312A311403050708080801053140233B35244A402B2116221809
05001B4564706E6E67555960583226262F2E231C283535262E3426323628293E4C4E4A40
4644464D5867797169737487817372677F74827584947373696B6B6B74514D5C79754F52
4A49705B383A4051646062685B717C4A3D4C667A513F51433C3B3A56463F4A3E33231E1C
130C474F696A665F4E47404A6960504542443A3D53443C393C50808F8D75737559455368
9BC6B6A0A197ABBCAFA8A194B9BABFB7A497A45F1500090F0A050905130E080C04030602
06040301
0D070304040609070205040903070B0B09090B0503080905060208030302020305080602
09030808071A25273037413B2610050505070C0F0D12303732423B343B36303526241217
0905153F616D6F6D6554555B4E2C31372A24282E2D293333343A36333A3D37434B555E52
47425C5D54586368647D6D7E91806567746C807B878B5759696059506361726864564056
5A4B5C585A5F6163605348514F676C5668453E6853514639454048645C303D4830262A22
1B14515E7570624E343242676651504E423135434C3029294C7D979B9D99958277768494
ACB6AEB1A6A2C6B3A7B2989BBEB5C3B3ACA59E490A06070E0F0C0E050D050C0908050608
05050203
0A040302070505020203020D0606070E07030A05050303010B080F070608060912090602
070B050D1D2A262B362E363D240C0B0B0407090D11283C393C3D4257402E403927381C17
13000D3C59636F7877605463531E293E3019121F31353B43515E5D515664554C4D4C474C
444562605866736A5F7B766D7A807171766B727D99965B596C4552666D555D6E6B4D3F51
49363146625555584C5660494B6D4D356C6957634B65663B3036414557493A4B3B2A4026
0A32606C6D5951402F37557B58414A42463C3A403E2D2B386FA1A1A4B1AC95818F968F9A
ABA4ABB59EABAE7E8EB38EA8C6B4BAADA69B994A16050E0C020E0E090A05060605050706
0A0A0500
0A04050508050408040101080406060906080604070209060D040902050A000802040104
0402041A24261F1B3027293B2B0D0A0B060A070D14354826394F4451533D53411E251606
0806193E485666676F6954524E1717323B32242732404B495253484F60625C5853504546
3F484A3C566D6D6D6C7277807171726A727A75636379666F7D606A64665B4D5469675F5E
4E4140544626485D60777055677C575C7F5D4E5E514F4E393630323D5C67546B4E313C1B
1A4A6A72634B46373856726F47484333444340433847506394AE9EA3A8A0A0A19A8D919E
AFB4BA978DB0957599A98AB3B9B1B1A2A4938E4E14070709030E0B070C0A020301060B0D
08060302
09060C04080C03050B050307080A120D0A06080F08030800000408040001050001050504
0408041529231B1D3031312D21120F0B0801070E1240482340443A3D363F40221B141811
0D0915374D616A61666F62584C20212F2632251E34504F404C57535255565D62595B544D
4A4F50577275616D7A77737E7178745875877178808575798069655156605A55696D695D
514E556657546C62667763484E757264715131567356494D382D3E4F575E6B692A31360A
31606F6154514038476D7E59444B413B3B37373E425A6C9AB8B2A7A59A8E929188757A8F
A2BCC07F8FAD8689B89E89B2A8B4AEA1B08A755114070305060A07070508070405050303
03070705
05060D04070E0705050203090B0706050B050306070405040304040704080D0306080304
030802143225132D3E433431260E0D0D08030B0C1F4B5444453934373344432A301B180E
090811355056595A6064676A623B1F202740422E2437444755535957464F5B584E4E585C
5A5851505A716A656C7D7362608392737B8761758B726F6F59416971605B6E5A5568643C
3B546251384E5A546966574C53706051624E38556F51455E513E303B56505C6545482309
456C6A574744364250746C4D4C423E42323137425C6B80ABBDB2A695888076707251568B
96A6956D8B908AA3BD918EAFA4B2A5AAB19076551C0A060605020C0D0D05040201050803
00040C0A
060607010108090B000302080E0A070E0A060A0002010402070507080606080001030108
030507132A281E363B3F3034250B0C100B090A0C303F3D34434232344A444B45301B110B
0604173956555656555A6768686A3B18273C3B2E253D544F494050614F4A4F4B4B4B4A55
5C5B5C5C575C6674717D7E7E807D89867E80758A886381775D636D707B706A5668825B48
63694C3E4E645F6B80584D6D6C5237404B404E7280655358534F4A2D3336475C52371034
596450493B30455B617F60464B403E372A384352647098A3A5AAA096785D443531173677
9A9E8A8D93889AB3AF899DB3AAA6A0B59A95844C160B05090A090D010C070A0E04080D0B
06040703
02020E0B05050503010201030809051105060A0104030506040904040800020102050305
0704061827242F37363B342C130C0D02000600032A43353641444539453B382712150706
050A1839555857635F5660686B745E2B2835282935444E4A4847515D4F45515045464E58
5249595C555F617277797D8082798184818B7A80735B7255546A6D696A5C4D5C645F4B6A
7960434D5851555D694D4F696D745B373B5D6B6E736B6F6B584848210616201B2F1B1948
55514439393D616271724B3B3B3E36262C3F4E667B87A8A2A6A98C928052240E1610267C
A37F8AA4A8AEB0B0A48FA4B0A799ADBE8A8E85400E03000C070A06040E05050907050B0D
05080409
060A0404000307040500070A080807090707020402040504080E08090A06020704000307
03040910201E282C37312E2A11040405000302072C49343D3A353D2E273638290D0D0706
05051B475C555166645254606F7A6534293E31333C3B3E465552515A52474A514D51635C
494C58676A695E6A77726C646B787C697C9C6A765E497249455664615B6864634E4C424E
544F5D694E3754665F414A595D7D6B3A4165544B6A67594838332D211D0D1A2A524A3A52
4D3F34303E536559775E4045413C2A2B4149647A93A8B1A7B6AF8377726C402C2C355596
986E90ACAFAAB3B19F8A99A6A19FB3AA7D8878371506030A080F0D0906070400030A0A04
08080C09
0A0802070504050401080F080003030109040306080A050001090A020205090C0302040A
02090D232A272A2E3A3226190B02070B0504061A2B403C4840342D2E2A302027180B0609
08041D465C585664675C596578745D493537373C3A3D434B564140554D4142484D525D53
4D544D616F6A6C7A7165636F767E7B696D8B78826B568D7B615F6F73798976554A665658
55445B55414058636C62635A475A4F33405C5A4C5762573C2522354039416B6260574650
4338354450686163704D4440403A2B3A585B7994A7B1A99AAD957263414E61798EA6A4A8
9497AAADAFA8B1B79D7C959A98ABAEA6989863210B0F07010716170D040E090300080804
08070408
080505060403030604080300040D0B030505060B0C0702020A09010504040905010C0409
040A0C2B291E2234342C200600080504060B05232E2E393F42381C27342E150F0B0A0501
010B2140575A58676A5D5A64807C6655452A2F3D3B4246444840434F44454A3B415D6960
584E4A515C6D7A7C6679858B89756D857A768076715E6B4B33597E7E6E745B57656E5A60
4D38564B3E495C5163735F617469452F3F65786C524D3C2423265158595A66675E4D403C
2B355362707F6D7F633B49403E3E414A627995ABA8A4A19CB08F7568231A437F978FA3A5
91ABB6ADA6ADB1B48E77A2A5A1B0A3A2A89D5214070B06050C0F0F0F08100B040705080A
01020209
020609090503090304090507090F0A090A000005080505040C0B03050B08000505060507
06060E29230E253C3126200703020401050E082737374A414044262227180F0F0D050406
070F2A475356576B695E5960787A705E451A26413E3D3B40525555595355534246595F5B
544F5757657A767E67707E7A856D6D898B7269697B796247476B806552645E5F64624449
523B484E54597885705F4C51503639332B486367442D1A05264D6065715E4B4B4B3A2B20
23457176878176835D404D494B5A63637798A5ACA2A2A1969D92A39B5958637A80779997
A1ADADABACBDBBAB868AACA4A4A89D9F99854D1D070A0A0A0B0B0605070909030C050705
02060904
080D0102060604050C06010509050005080601071105040704060405040301040B040704
06071128221834383B34290907050206050A112237263F4E45402A2928180B0E12060410
070D2848535D5A646864546A766E766A4919244548403E44504A464B4C555A59625E504C
4B5873635A71686F595C7D6D6F7D877A818E716D6567715A5949595B6B7A6B6052595342
423A444D57495C746053606A51424E493F3D49431D17263F585F5D615D55432D1A11203A
5B727A8595757485624A46454E606B7285A9B09F9BA59A99A4A2B2B0938F78759EC1A497
A9A6A8AAB5C0BCA48E9299919D9EA6A997784F2405070604060A0A0407070305090B0A06
09050805
0D0C0103050407090E05040205070006050703020A06070B050004080301020406070906
060C0E282019302F2B2E2E0E06070509090C04152823383A43432B37342120100C090706
030A224459605C62675E465C6A656965552520343E37444D4C4F5C645B5D6151484F5254
4B4D66665B6672806B58607B7B7565778086807D706982693F2C536F808158585E5D5645
504E4A4C5B49495A51455D71665E3F364D2F1D21151E4054616C564B403F2F111932416C
878B8391936D8082685E56666A615F74869FA28FA0B1B1BCC0B9AF9C9B8B88A7CABE99A8
A8ADB0AEB7BAAF9B8E8F92949BA0A69C957E501F0407090B0C0A0E050006070602080503
04040704
050906030305070102040E09060304030304040203040708000004080205070202070B04
09131821212034412B2B250A0302090A0B0A0A312F313B44563D2B3C332C240805040A06
050D284A5A55575A6460484052584D5B5E281A253C39474F56534B605D4D524E4A575C54
5A675D5D665E6F8176604F7E87766276746266676357686F514D6870685C4E5A6F664449
5641403E4F57504D505154473E584C3E441A020E25404F4869714A3A352D1619405C7694
938683968D6A887A76776C89988E7772737E7F89A7A8B3BCB7AFA294A29696B8BD919AA1
9FA08DA4B7B19F928D949F9A97A0A59F8E764812070A0A131107050703050B08060E030A
05050C04
0907050502050602040607070702040003060607030304020503010105080404090C0607
0809171A1D1C3548392C11030C040403070518524B3C313D4F31373F322D150409020814
0B17354A534F51515E64664A404E4A575837161B3C404E4D534A2F4F6347424D616D553D
4B625051685B58636C70636F73837F796E7A77726E6B554F5268736C5E545D5850535154
4C49625F5E5C4C3239483E2D2B4A5C4C3817071E3B4D5047585E453330232951667E8EA2
A6968F998177907F88807D9A99989889726C6F899B9097A0A59D9AA7AB9AA2C9BD97AA9B
B5916598AAA2908A94A1A29793A3A69784714108030A0A0B080401070802030402070509
09090B07
080005070206070C090507090706000305060204060A040307060803090A010509050403
000E23251D1C3835342B120507030806060214484633373E4C352A2A1F10080F09060810
14143F4B4850504D504F6A653F475C605A461E213A434A3E434B48555A5D56404C61513F
4256615E615660705E6E797770787F8971807E8073706B6367686E727D7657444257635B
6D6E6F5A51452F2B4B4E4044464E442D1D111429414C4D513F312D2922296A7B8192989C
A3A19E9579869D94988A94AFA29A9B96877D7F8D9AA7A2969EABBFC0A59BAFCBAD99B1A7
B75C2B759AA49A8A91A4A89E909D987C877B3807010C0C02040201020004020303080404
08050307
08060504020403050B0A0705040A0703020406070807010306070705030702050B060402
031230251C314629292C1A0802050A0D0D070625382D313241493B231101081A0D0D0304
0E0D3B505255535657495C75564E686962431C24415746343A4D554C4754584443535750
40405660605F617768747A7781675D807B7A665E66565951605A546A836B535864574845
66664D4253483A516749475B47423D200905162F454B3C331609132936588C8A93A59FA7
A4968D848497A2A0A394A1B1AEAB9290938995989CB3ABA2ADC0CEC2A7ACBCC1989BB0AA
A0553F738F9B9A9294A5AEA28D93988A8C6E290703080902040402010207090906090601
09070302
09020304060603070E0C0201000B0E060600040808070607050602040600010305070303
07142920192C41303223070A0A07050204081333463C32272848481B150C0F1705100502
07113345535356615E515872675A6A635F411D173A594342433D3B48554F4D4F524D5358
3B3A5B666372667275706B6A847C655B647D745347586E4F506F5E5763476A644E3D445E
616066595B69695B5B48363F352C3121121C2736424929131726303F59849D878FA199A5
9D9187889CA7A8A5A098ADAFAEA4818EA698A4ABA5B4B2B2B9C6CBBEB2BCC6B390A7A39F
AFA28F90918E94929AADAA96909597978F6625040605050B080606030806051107040806
06030307
080304040404050A140C0006030708020404030508030303030706060904020405050303
061E261A22303F302E22040B09060804000E324F462F20200D1F461F16140704070C0304
09183A4A5250565A565D5D6867515A4F554C2B122D4C4348433C4B5D5C5D52485F554D57
4045515B67605C7C746B70636688784F6C888F8C70708E6F5E61585D5B3F544D424E605A
4A637F644A4F4940626D56402D2E2D1C0A1D31454A4027374C4B505A7D9A9C8BA0A9A1A2
93918792AAB1B2A4979FAFA5A4948494A6A2A7B3B5B6B4B6B9BDBFB2B4C4C39C96B89D96
B0AEA2A0968E948695B1A7949796898A895F180005060308080707090D08090D06030606
0701090D
05030100010604010E0A020909030302060B07070703020307080A0C0708080607070503
02172A18152C4732241D070505070808070D293E393B2D221A14300E0C1608060A080404
041C3A4B56575552575E586F743B302E414B2B182A4A474647445560535147405D61524B
464A3E4F64575F7B6A768176727F716E7C82838E937067655951687355495D5F604F4340
406478705C4140586A635F46293730120D2239584C33405D65696886A9ADA29EB6ADA29D
8E8B8292A9B1B8A59FA89EA1A1949FA4A3AAB0B3B9B5AEB1B9B4AFB9C0C1B095ADBFA1A1
A79E989589898F818DA7A48E93988D90804D100205090A0505080D0D0C08070507080306
06030A08
05080802050D0E050709050A07010503070B0808060405070705080903060A0405060402
081C2A1D1A3044342621080304060508100A1F4446533E32402C27041219070D0D070908
0924384C555E64646359597E6B2A212B38492E122745464C4D4951564D40425A6C675747
454D535E5A52667B6B757472848670766280946F8E765F7A555370765E667B5F463D4351
596B71715F51666C4D343C311E2B1C0A162A3E5950405A61708289AEBBACAFA8AFB1A697
89947B8CAAADB4A3ADB2969B9998A3ABACB1B7B2B4B9B9B7BAB5B1C1C8B6979DC3B8A2A8
9E969C9A88878F92989E9687939397A177350A0201090F0B0E0B05060C0B010507020404
02020506
02040707090C100E0B0B0D0F090604010605080903070804040508060001020604030700
0825281F2E403F312F1B090D080A0705090B1E38393D2A37473F3616271D0D0709030407
10233B54545764626259617E4F3F48503F443D162D3F3E504F474C535D4D3B53766F5F58
403F50595F5B566F7D80686474886B5A5C728C779683686C4C4E5E746F72735955756F58
5A5B5D6966555B685C3E2822242010101E35484B4345606F8090A9B9B5A7BFB9B0AF9D86
83A16984AEA6AFA1A7A899929AA49FA2B0B3B3B0B3BCB8AFB4BFC2C0C1AB97B0BAA2A1A5
9AA1A8A5968C949AA1A49DA6A6848E9A682401050706090809080403060A050002030001
03040404
050503060603050D120F120B020403050200060709070304040005090501040B05000203
071E29252C393A32371C0D150C080908020E1E283749404F4C403012190D140808080806
0B263D5355596155625B646F445B5F6C493A391825393C4A4E49545F675B41456C6C5243
3B443E415B6D6D727C8B6D6270866959756C75707A7B645B505E676158504E5C5D717158
5359686F4F445D69614F403B2A0B0109274A5643384A6B888B90B7B3B7B4BEB9ACA68F7B
8CA3627EA8A1A9A09B9D9D8E9597999AAFBDB5B7B7B2AAA9B8BFC3C1BC999ABBACA2AFA9
A1A498989D97A2A39FA9ADAB968086825F2C080C120903030103080B0701040605060201
06090606
090501040607070C120A0907040302060404050310090003050205060504070904020305
031027281C2B342C321C0E16100E0803020E283849553C403B2E120210090A091207190B
0D263B4F55565C5B68536D68496661775C44371A19323D4A463F565A48495D5B5E64584D
484D47444A5C62747A74606A7F836E70786E736171755C65566E764B5A5146665C576D6A
504E60563C5869495561422F18020715345D5A36385F7788969CA79CADB7B8AF9E9C8880
A09A6D70949EA0A39FA08B7782868D8DABBEB7B2A8A5A9B5BBB1B6C2B18091B4ABAAA7A2
A29E9D9A9C9FA39B92A1AC9A807C7C76582407080E070108050208070707040604020105
0804070F
0A0600030B0E0B0E12070A110A0606070606060A0C040103070605020509040405020606
000D2A26192E332327180B160D130B0200082E403831232F351E10111B0E15170D12120C
0B26434B62645E6668507F635A7762705E43361916323847453346534B47555557685C56
44385C564A5E44668F7E64717D8277797272736175765B4A304C5F577768475A5D61726C
494F60595556402E525A371C0B0B152C405C513349718994AFB39B98A7AEB0AD9A907884
A0847B7380999DA09D9568568490898FA6A7A8A196A2AEB2B1AFB6BB9F83A0B1B4B6A7A5
A29B9C8C90A29B949CAFAC9279768C8B531700010303040606060A050209080A06030405
0B07050D
060A06020908080C09040A0C040704010606030808050807060508070503050803000607
021B2F2429404029291C0C150C0E0B050306182D2E37282927111B1204051616040C0E11
0A1F3F405F6A5D6964557E5D72866871623730210E2336454C40434C4C4349515F70554C
4534594F53613B69918A69647787817B7480807B6F736C584854696F6B6E5F5D646E7056
3449635F5550434459524C3E0D021C373F4E4741636F8EA8AFA5969CA4ACA9A498896E8D
97808B86788A9A9A958246448F978F9AACA6A5A29DA1ABA6A3AEB7A88F96A5ADB8B1A1A2
A3A29F8892AD9F95A5B3A0857474968D47180804040405090A090A0B0600040B06040502
0408050B
000F0E0006070A1008050902040605020905070B0B090904000206070706020207060605
0B1F251B233E48382E1A11180A08070807091C3F42442F2E330C16120A0F120C0A010B11
0F1A35475361606761646D567A7B66655C32342700184044514F453E424E545A65664D44
546D6E3344614E6D6D77676A777F7C8B6D60737C737061657169765A4B635F668073635F
596266534D5750566C5E4E390B1133434C5F484160748B9D9A979A9E9CA29F968A878599
929299998D82838A9177384085A0A9AAB1ADA7A0A09B989DA2949E95899591A3AA9696A5
ABACA78990AE988495998E92998B8773330C050808040A0F070608090402080503040A09
04090604
090F100906080D150B0706040703060A0604080A0602040204010302070C0706090A0904
0B212E251E3240352C110F1E110C0A090106274235351D2033181E080D18180B10030C08
0F1B3555566064665A6C63506E6264634B323E2C0120464A4B404144536150516B6D665A
4B656C46515F585D5A706D6B6D7B777F6A657562647B6A5E6F7470617B7658637D70635E
5D5B6160584C3B496957321B0918353F4452434A5F8084888C93979C94949B8A7E8A9A98
969C9DA6A98E8189836A465783A6B4B6B5A9A2988C80879A8D6F8C89768A8D9F9C8B9FB5
B9AF9F8B94A9968289878DA2B7B18C683512090702020C0B0306060402040E0E08080D0D
0C0B0102
0D06090D0D0E0907080806090704030B07040203050903010507060500060C0B04010503
02152929203A45342F14040E0E09050507070C10010B0D0E1E1512040F130F080F040F0B
1220334E616567675568625B6A4C5C5C3C413F210A293B464D3A3E5252505361747B735F
5043426673564D4858747274757375627B8475605D7F83766E79766375727371626C7E64
535963625A565751503D1810080C2333404952667D898D8B838C8C96908A917F8A9DA59E
A2A1A4A8AC949999726165777E90A1A7A49E9585736775776D7398805880959A9D969FA9
B3ACA49E9B9D8B747D969F9EA7A887653809050506050104070702060A090C090502050B
0C060408
0B0406080D0D06010A0708010008020B0C0406080706070400070A02000304060D060303
041821201A3E513D35220D06050906060D0C0A181713201C1A100C1011130D020A0C1214
18233047636A6F6657675F655F4465503E5E49150B2F39415044404849515865706F5A43
545844575C5555425480797185737E768C7A737A5F5D666B62667561596162696069856E
67756D5B56636656574C200C0B17283651595D738772737B7B85858F8F838179969DA19E
9EA2AAA39F96A78C6552659180738F9388817773614B5C7B8C898F816E81919698939AA5
A49FA9A399998A7F90ACA79FA39A7A613700030A0F1007030407050B0E0E0C0306070505
07040810
0F06040B0F0D0C0A08010B04000E070A070208050C060C070203030104070A030A090505
071926261D3F553C31291409060B0F070206121D1C181929371F19200C0F220E0D11070E
141E364D5962675C5869616C625A724D4F5F4518091D374F463F443C455C525B6E65574E
5755576A615A5653567B79678A87706F8B7E839C7D624C576F585F5F58715E5F57466561
65675A5C514144474D441A060F192B3D545C627C8868525868707B888F8970779B989D95
979EA5A6978A8D7E755A6486765A747E705F4E52564F73A59F827B86979196AAA39398AA
A49DA9A29BA6A9A19FA5A4A1A5967B653202070D0D100A05050A07070A0706040B0C0A05
07060708
0A05080F1112090401050705030A0402000707030B0206080409080504050A0A06060303
030B1E2114344F3A312F130001050E0A010006151E1915344B3534260C1D270C120D050A
061A344D57615D5259685F756F635A4A5A533A1C15133451414A554D525B5C6562635549
5E4741696A5C566F767975727C86776E8060618B7D72665E746250524B6A6E5B57545B5F
5C4D59776039394344371000121D283349506984806C4D415A6A7F8D948E63829E999F97
9B9D9FABB08F6784928A847B8B836B6D645C5558728098AC8E74737C8E929DAEA4999CB0
B7B5B8B1ADB3B3A29A9EA0A2AA9479602000030401050508070A09060704040608050B08
08060A03
0B0A0D0C090E060502080608060203010007060204020104090B0803060404090A070602
000A111B0E2350442D321F05040707050100081B26200F263926281C17191E080E0A0704
0A212E465663604B5861587A766756555E5C43261808354D43515F5F554E5B6D6060493E
5C4B404B45515C606F75697C767986697061678F6B56736859706B66626F71504F685E4F
53516C7C625454545138120412323D2C40456F7D54311E203C657E8F9B906A8FA69D9BA4
A7A1A2AEBC90657D79949289B1B68890948C867C7E8EA4A3836A6A72808891A7AC9F93A3
B1B9C0A39FB0AA9FA0A7A4A6AE8D6C51140003030205070601070C0A0607040303060E0E
02030C09
10060A0C120A020603060305000A07020004050406030304080A02040403040306060904
000B0A1F1F1C434B332A2F18040A0908060106070F12011B29101D221D101912060E0501
0B1F394D58625E405555567B757063535056452E11003358473C4B514A5A5F63695D464C
54404148515C5A515A776B737B6E806E6F8775836C4E686E50606C66697474533B576557
59626F61515F59473F220C08185463322B40655F32110913195079919B857496AEA298A1
AEB3B0B7A27088917A94868EB19D86A2A893827A78869B91726978818E9296ADBBB4A1A1
ABB3C09E98A49B9F9EA4A7A89F795F4D140006020307090003080A08090E0801090C0B11
05080A07
0F0009111004030403050806010D08040306030609010307030807090203000508030806
06040A1F211827404127302507090E0B06030807151800111903192B1E1C14090D0B0104
08193C525D6352415F575E8168616951485B5A3A0E00214D4B3F404C4D625E596B6E523A
3D3D41575E4D5B72687F8074696180958193725E6E59586B4C576B5C56617160435C7F7B
5C5B7067554E433F351B0F0E235F784E2F40574C323C3C392A4B7D9A967986ADAB9A939C
A9BDB6AC91719AA4A8AF787DA68A87A4978071757E818D805E6E96A2AAABABB1AFB2ABA8
AEADAC9EA49F94A3A3A7A3A2916C5E4813030A050006060308060407090F0B050A100D10
0A08060A
130503060104080503040D0802070A07080C070704010207060005070501050A0503070E
0D060E1F1C2237404132322B0F070D0B06080805242E0F202807081E170F11070A161212
131236566A6C4C455E5F5F78635C604A486B5B3013081840504B4A626557525E63695E40
474B4A67583F5D776F7E7F7D686E84877F8A796377705C724A58746A545A75725D597177
665F6B5E44474139341C0A0D2E5B7665453F5A553F504A544A4E7999947D94AD9D958B99
A6B2B0A38D80999FB3AF737A95808B9A887C7271777D8B75587D9A9BA4A6AFA99EA8AEA3
959DABA0A7A39D9F9BB2AB9D9371603E0E110A0C0003090602050B0509030706040C0E0D
0B0D0806
0E0E0703020306030005080600060B07090608080606060B0D030203030104090404080B
060A0A2320244346403F32391B040F1315150600182C1B1D382A1824200F101311221716
0D0E34586C6943415166685F5B55514A4E6A4229170520494B3D45636C615D6D68565455
615A4A5A5746577171705C717E76776B716F6272717561695147756C495D756150557168
5761736040483A282E13010A345F79684D405F6049444559565C6C8B8E818FA09EA098A3
A9AEAA9C7B7F9DA0B3AA747C856E788782786B676B7881615B94A5A8AEA4B3B4ACAEB1A9
95A6C6B9AFA3A19A9CAFA5999A815D3C12090B0701040D0C06050E070D0403030802060D
0B0B0903
040E100C0606090400050502050A080B0B0408040A080C0C070404050102060907020703
0004051E27232A41463C263E2F0907181E130902021411041C2B221D1313130E181D010C
0F0E334C5557424659706E59594D4D4C4555443B1805173E43424C5961625765775D4A52
5B61584C4B49516A696A68778C7C73717B765E6C6672836F57537F704A5D6353545E776A
52617668453632413405050F3B6B84705D4E575C4B42484B5B695588928885A0A19898A3
A7AFA4968799A49CAEA7766A736363828871645D5D767B5466AEBCC0BAA7B4B7AEA8AFB1
AFB5BBB1B3A3A19FACABA49F9D905F3E14030503060503080A000704090404060F08040B
04050909
03100B0C050A0606020404040E0E05070808060004060804070605060505090704010604
060307101E2B1C38453F2B2D38140012160E1009000A272D150F201B050C191217180417
200B3351564F4A4E577371696352493D3B4851451C071B32374B564A4F544F6D7F5B474C
48535E514E595C60627883707F807A7E7A7370655B7797805274726B63665A52504F5055
6C7268553A34333A2E080B15426F7D65645E52605B4C4F4C61553F8E9C8F809792909596
9DABA397A2B2A5A6AC9A82655E61556E806C60525B80764F78B8BCBBB1A5AEAFA7ACBCB5
AFAFA7A8B9A8A2A1A5A9ADA49F885E400E100108040307010A0309000904010009060308
07120907
04120405030402010205060B100A080700050701000A06040A0907020607020303020805
05080A0E1B2A1F374A4E4321392605090C090B080209363D0C0420220E131613150E0F0E
12082F53604C434F4D718181685C50404947504A1F0913423F4B5F474D54586F725B4B51
53473E41515C6466687673687877728086777C6F5E7174775B7F6B525669686153636B6A
7577755D44534226270B0C32516A76665C65534C56555A5D5929518F918A797F8397999B
A5ACAA9EA4A197ACA08B8F756375655E6A615651687D5C4B86B7B4B2B1AAAAB7B0B8C1AF
A7A7A8AEAFA89FA09DAAB1A4A87F493C0E0C0B0207060A02090808030B0207070A000307
0A0D040D
090E0404020207010304090F08070C0B0406050302080705090702020205030504090704
0203060C1C21203A49484B2733380F01090B0A060600212D0F041522151B1F120E13190E
1A0C21545C493E4A56768187746853515A3E4147180B0B52505C674B4B495A5C5F614752
6A57383446506273797968698086716E848E837D717C666E656F805C4569716B6B6C8082
6669765649594C412A000E436678857A4D59583241575652302278938E72586C8198919C
B3ACADA3998C92A38E8B927C788D8268615A53556A6A46569BBBB7B2B6B5A1A9A0B3C3AE
A3A9A5A6ACB5A1A1A4ACB4A6AE8D442F1907080408080203060A060809030A0A09040107
0F0C0809
0C0E080A000704010200040B030B0D04070A0205050405050B04020503040808050C0505
0A010805162924333734444732332105050E0F0D0A02102520080E1816252D2214171316
230E1254594B3E416384878F877858595238403E1101104743595C4B4A49706D5B59444A
5D5954494251646B797E706F7C94776D777B6F7A737972645D6683775F7664485E5C6C72
54595C42585E3C40230016417D8E78645C5C52314046402D1C51858C8A695A77869A9498
ABA29C998E829094888E89757B969379615552526763415DA6B9B5B5B3AE969991A3B5A2
96A89C96A6AA96929AA3ACA3A49058260E050103010305000C0F050908060202060F0B05
0B0E0F01
0C0906070405010602050308060C0B0106080802050203040B0A08020203050806060803
050703010D2B1C2535323C4F392C2F11040B10180F0F1010190D1520232C2B29241E110E
0A0016404D4C3840648291947B79645C4039605516010C40475462544851707D67584C3B
404F5A574C596159656A687072877D777B716D807261767562647884756C635C5D57656E
5C4C494A635B2B2015061E4B849469567B583B3D453138204E838481797F878D939D9B9E
A29D93979581888E81747577778F926D4E4B50526B664567ABB1AAB5B1A4A2AC9F9FA096
96A6A2A5A69D948D979FA3A29E806527080B0A0202010D050A0803060508070A0D0A1009
02040F04
07020202050002080908110C0909080802030A0703070004081205020605090207010804
050805010F2A191548413E42442E251E0A0B0E150D1413081313131C171E212325161014
181314213A42384D67798D8E76745B503A46766F1D05123E4F51525051524D646E5B4F4F
524B44474C5966645B5F5F6B796F736E787E7B8073686B6A505F707C74585A6A4E445D73
6543475E5940342B10071B4E7A8A766D65453E473729353D798D93847C939C94999DA09C
99A3A49D978C837E71606A797480805546534E556B5B4878B4B2A8B0B5B0B9B9A4A6A8A0
A2A6ABB3A7968C818A90949C9873642D0A0B070604000909080107020507090B07010908
030A0E05
0A0402040104020708060E07030707070402040C04090306080D00090B050A0307010102
08030503081B1E15423F4853492C1A2F181316100112191015130B18262D2C251713211E
1510080E29353B536B7F867B79714742465B7578260710334E54424B606B68686558505E
5D49515A556675615169686D7A616B67777F6878736A545B5E6F68626A5D4A5B594A516A
6D5F5F594539382B0E071F5D838A836C43404434283223517083998085949F9A9BA1A599
99A39D8D8F957E6E6D68676B737F6F4646544B55644C4885B6AEA6A6AFB6C4BB9C9FA5A3
A9A9A6A6A19A8F747A808D9F886458290400020C010101030C0404040605010607070301
060B0709
0702060805040405040301020105070203030306070802030605040A0503040705050303
05060208030F2226383F4A6E5C432A2F27141B1B120809101A1312151822282620283124
1205030A1E31314054757F616A6D424E5059757A2D060B4455474254555B667560505054
5E5759605A6B766259737A73685B71636D7E5E685A60677D817C76645A5D5E727F5E545E
5660684735413716030B2F758A878759403F4225363C1E627891927B86959E9C9A9A9C9B
9B9486848E8971778575636C80866A404245445C5F414C9BB8ACB2B6B4B6C5B18B95ADB7
B8AC9B9FAAA99F868691A1AF7F665E2C11000508030707050B0905060308090D0B090906
09050008
03080B07090204030608070B080403020508040004070201030104040205080808030505
04090804080F2A2C3D584D6A6152481F2C18101E27120A090E11120A06060E182627181E
2C1E0A03172E2D3F485F74626A633D60555575742C090B424E454458514B4A655E4B565D
61584B4A5061636366697575635F6F696B7C655F656C73808481826948546C6A6A5A6562
484B5D5D46392F10010D3680888680524C454E3244302C7A86928B68739C9E9698919596
8B8581888F785E738C847A7C8587643E443D3D5D5C3856ADBDB0B4C1B6B7C2A592A4B8BD
B5AAA4A6ACA69A9A98A4B2B08B86723A1E090A020505040B0507060801060B0D0509150B
09050204
030A09010B070705060C0B0B060703050705040507020001030606060208090609010202
01020502070825183C6651585645592A182C131123251309070B0A0F1104070D191D090A
191508031121354E5A617071755D45695A5C6A692C0E0B303D4545514B575762675D6162
57596252485F61576265686C5D696E708079656A807170817F706B795C57645757586663
524A566B522F250E06144180858C6D535751431F26103D7881807C5E6D959C9D9C89918A
797A7F8A947868818D87827E86845F3E3D3A445C583A67B8C1B8ACB8ABADBEA093A6ADB4
A4A2B3ADA3ABA6A29AA0B2B4A097783E1A0906080A02000B0200020705040B0A05091107
03060205
0601030407080B0A06070705000407020602020A0D080706050A09090707010102030002
02040101050F2314314D484B5E525A4E192B1F09121B1515131207080F0E0B0111241C11
0E0D132423253A5464696E72745D5B6548565351220C093D4D4238494C4A566D695D585D
5B53595646586C565E6A6A5E4B717B5E6E71686F6D606E80665558816B5B695F6D64575F
57474B5141311F0E18173E7C858149404C4C22030919527E807569718896989995878279
737C83898A7679948F7A757F8C8157413D3C4A57533A77C0BAB9B1A6A7ABA99A92999DB1
ACABB3B1A6ABAD998E9CB4C0B79A6B37130A02080A0201070602070404090B0508070604
02030007
100B04030106060804040904050605050404090A05080604030403050402070605080005
090C050203101E1C1E274A506E72556A4B1B2A1A081224251E1E140D131612141D241513
1D090D32424750635D5F727C6E5F5E53344F515925070A46654F424857464E6B5F5C5859
6556475A5253765E54626D706A716C59606F73766F696F836B6E73766C636E68715B546D
6F6B5F47454723091C12397A7E682B16252605172D3C5483696F6E8197A0998F86807172
7B7F807D78788696836B7B8E8C7347423D37424B4C4085BDA9ACB39FAAB6A59DA09FA3A9
ACB4A4A7B2A7A29491A1B6C0BA9B6D42250D07080203090707040C0804040805080A0404
05000409
0A0C07030104040705080F0502070806010409070103070600010203040304090C0C0209
0B0B090103091A221D1A525A6D835F63732E292D1318272D27212521191C28382C1A0C11
1B0F13182D545E7263527389736B5636275466742F0506334A3F4E4B58544A5251656E59
5F664F575A5E7D6853617784886A5D646C6E7484857470907E79826F7072736F5A495765
6B73614D52431C0A0B11457D7D622E0A081A354E61584C6B506F7C8F9298948D7F706A7B
7F787B76757E869486697E978C623D3E34384449424895B3A4A5ACA99EB6B2A9A6A2B1AC
AEBAAEABAA90999E9EA9B9BBA4967F4F2E10050400070D0505060407090407090A090102
04040707
050A05000202080D06030603000509030304010606020C0A05050604050405080B0D0307
0E0A0C030905132030263F4464796A547343192A1D242B27231A242317212F3426203026
1B33412718394E6263577A8D786A584043646C772C0800354F45424051574D4B5463735D
565C48515F5A606064697F78756E767075767D82736E7C92735B778178766B6E534A5B59
605D4D585225050A06124D7A85724F343854777D78686175718285959696827776756D76
7772726D798386958A727E8D815941382D383E5146469EB5AEADADAD9BB2AEB5AF9BABAD
B2BBBCAF9E92A3A6A8B3B3BBA8A791401A170B010307060405040103070804050C0B0404
03060503
060806040202050809060101000403020605020809020303020305030300070A0B0B0001
0A0A080108070E1C313B392653565C5B755A1F2122252019201A1F251B212C2821203732
2B4A5848251E4052636E828A79626361666E717C2D13023F5D5443444D50595F675C5E62
6C6A4F565A4D5E71796C756761687678797E7C6A576C7C8B6B607A8277726772544C6355
5459534E40300E0306175A7B877B6C616B757D917E69797C7F8E93958E85777778776F6C
68686D798D939491808089816D4D453A2C353A554242A2BAB0B0AFACAAAEA6B8BBA7ACAF
B0B5BFB4ADAEA6A5AFB1A4AEA3A29145201A0C050B050609050207090504040207080307
06030202
070504040304010307090A06060702030402040604020305060804020504030408070109
070403040813191D1836452A4451515C748048222523101B2720242B282B31270E0B1225
40565E5535233849677F868778686F686A6D7E832B150C32424C494B525B696A70625E6E
77715A534C516E71797A6954656D6662677D7B7968656A87696F80616475796C4A556553
575C494348320D08091C5E848A7F78807D80888571687B6B728D95928479787E7575776C
6876838C93989A8C78777D856E443F3830323D543A5BB1B6A9AAA8AAAEACADB3B3A9AFB2
A8B0BBB5B3B3A7AAABA6A6AE9E948554281408060B06090B060504090500020407040003
09030006
0A07040104070207040507040B0703030509050302030808090705070708060304050709
0A05090D050B13271B1E434C5361605E6A8B612D2728191C1F20271C1E2B2B2014181323
475051564A3A353F5C798A867468696863607B792608081C2E5050494C546D706B655D68
6D5F5C5C515A605867706361716E695A6B857C8267696F846B69816B6B727C6758615452
5D4C416A6B22060708206B90897D7E8F888B97756870796B7B888487847D72726F767871
77848B878795917A6B6B76896F473B2D32354153407BB4ABA9AAA1A6A5A1A6A69D9CAAA9
9CA8AEA8B3B3B2B2A2A2A7B196766F5B260E0F090C060608090602090906040408090808
0707060B
040606020207090F0B04020203030502030B0A0604020407050307080403060702030804
06070A0B05000B2629263E6C7D626162517864312E34241A1F191E1C1C1C19191F293939
3F444F5E5239313D4E7191867C716F79685A75702505060F2848474E47445C5C545E5A62
69515D6A5C56576559445E80755E7375767262605F746A75756E7B7E7C6C675C5954535C
5045576E531302090D257494848084898988997E747F6C667F85827D7A736C79726A7076
7A7F83848D907C68676C7F8B6340392F3E44494B498CB2A8A9ACA4A4A0989D978892ABA0
93A9B39FA7AFAEABA7A68F837B77776031120B05060500030906000408090C100B080805
050A0C09
040C0A050203060506070607020408090703040402010405050402060600030703020707
030503070E030519231F286E9A68526F5762723A40441E1F2518151615080E100F3E6C55
40546D674B2E243743588B918080817D645F75782C09051B3A453F403C505F5C5B5D5861
5E59675D52555A614D577C8570556F73646769646971686F6D71807A6F707D684F546265
504C59503C15001316347A8F8289837E7E7B8F847F7C606E848A887F76666478736A727A
7E7F7E87958A78746E647D8856362F3440444E474F90B2A9989C9EA0A49C9C938A92AFAA
9FB4B28E8EAAADA6A99C7F8197A48E52250E020505040303090703040401080D05040502
070A0907
080A08030102030104040607070504050200050500050804040306080304070507080706
000203040A05031924152562958061786F4570403E3E161F1F1F1D0D0A0409100C488B68
4A6372654C362C35383A7196807E74695F606E762F05031C4751493E425A5F676E645C61
5D6A65444C646A615A7277716E5C5C6364746E676E745F5F6E6C75665C747F584E635657
5C4D4548471C051314418590888678808082897F7769576178796E6A666269717472757F
838287908C828B896F66877E48372C383D364D4D588EA5A398999D9E9E919094999FB3B7
ADA79792A2B2AEAAAE978CA7B3A48B531A08020B0C060C08090B09070400010405070101
09060509
0505040701010405050304030404030505070A070206040203050C0904080703080A0605
0001040403050712261F234B80857375754B72522C36231D21261F0D1114101406317B68
5064727448273E40334070907E786C6E6F6572803A0001154A5242495E5C5B5E55535A6F
7369554B606D6E70615B6471705D575E646F615E64836456745F58637870575262655455
55444458450D0B0E11488B8E8A806F7C727B807672736C5C635F5F68656A6F6B6F70717B
80858C938A86958D7070917E4D44383A3E3848485E919B95959AA3A18F7F89A0AFB6BAB7
A59495A9B5BAB4ACAB9892ADBBA88D6A2B09040408060605090A0808080402070D0C0209
0D070106
030304070602060200030204020409060606070406080202030608050403050403050808
040202060508060924231C386D867972806B76682E3635131C1F1E111317141101236768
525A6E7041213C4235497085797477797B6C728741020A1540483F405958575B534C5472
7760585858535E6C575A7269534E5D6A656B626760816C53626869757A5960826D424D61
584D4B523704060D15518C86847E70786E6D757777757B7676767B7A6D6E706D6E6E6A6B
7883898B8A888A80717E8F7954443A3337444E43639493909097A19E8486A8B8B6B3BCAD
8C92ABB4AFACAAA49A8E93A5B7B09676350D1006010303040B0B0406060602020508050B
0C060203
03050102050203060306060303060B040102050204050505010101070A07050602040705
0505080A0606080F20211E325E827E698080717E3722461008102A1E10191A080A2E605D
4F5965564A3F32323750727D7D7F8079806A6C8740000C102A3B433F525649525C5C565B
64717358525D584948616C6760666069646359615C7C5F4B5F7D7E78715F6B6B50495850
4760695327000E0B125584878676787D8780707E76637285939583746C71746E6A6E6B66
75868C87868A82767383896D504033323B49504C6F919197929497928AA5BAB3AFACBFB1
90A3B1B2B8A3949D927F91B1BEB29D80441A110C0800070907100506050206030004010A
04030403
0504020504020406080709070303080706080804000103070302020705090A0704020003
030406070505070C1C2024354E717E646F8B758440124D11030716171421210F1F285060
646C5E43525C3724314F6F777F83807D807177833D0005083648433243515A5F6061554D
54787652576A635E6C6D5D6771766C716967585F5F7B696A766F756C8475685C5A6E5B34
334F624B1D0411081464818485757C78857B717D676F828492896E686C6E6C64626A6E65
6B818B84797B7E8083817F6D504B3731404A4B53798B939798998989A3B8AA9FA7B3BEAB
96AAB0ADAA8A899E8C7382AFBCA6987948250C0A0B060C0F040B090D0903060501040604
04040204
01070108060708020005080D01060D0709060705000C0E06020A0A070002070307050404
03040408080608061428334250738978687B6F7547143E0907000712221A20251B023A76
6E6161565C6B43242D4462717A7978807A74757E3F0007073C534C43525A6357585D5B60
515E554456605D717C6E706A6472727363716A67656969716A57725F756E6F6C5455443D
3F2A383811030A0B2071847E78767D7575697471618387757F786767686B63606C717371
727C757376728283827E79684F4D3833424B4E57757B88969D8A7C8FAAAEAAADA1AEB6A5
A0A59F958B727EA093808AAAAC9694784427130B020A100F070F1110060A0A0509010804
08050204
0208040A0504070906040607060B060505020A0D03070A01020504030404010002050604
0406050606050A081828253C4D61888C7973706D5022370D0707020E191F27230B013263
58586F63586745272C3B586B70777D7B7074737A39000507405542515660695355555966
615340445C685B50535C7772666A5E646071755A6066636869656F5E6E736D56424A464E
4A3752582D0D0F15297480827571766C726F6A697489877E7E7A6B58596B6D6B6F6C747F
77737378827E80777B827C59494C3B364454565D706F899A9C898B9CAAA69EAFA2A3B3AC
AAA1958F8C8493B9B29B99A5998A9F8C3F171810030A120D0F150F0C0B11070308080706
08040604
05020A040B020505050406020704050308070509050100070300030203050B0901050302
02080401050605041720173B554C738F8574666C4D304010060903021426170B11263849
5361694D43553527363B5B7571797D716F7878733400020734543B443C546E574B475D63
593C3C5A5A5D604E5B6F6B615F5C57646C5A5C5562655A61616B646D7C6C655C5B60534E
41344E512A0C1315286D77757A73756A6770696A7983827C746D62525265757265677579
6B648085817F76718489825D4A4F464042585B5A67728A8E8E97A3A1AEA98C979FA5B7B2
A690807C746781B9B5A0A29E8E90A88C401F180F080B180D1614090B120E020705070506
06060C09
0707070104010205040304020B070203080408000507080A030706070307060603010A08
05030409050504020F211E35595865788378606E5541420806040A0F0D1D0F0819272E30
455C6647444F2729484B5E7474716A5A5765736C3B00041030574A5445435E5D5B475461
5A5557585651495474735A5B5A5E5F626F555C685C5E51635B6F72776D55747C5B4C514D
3D405446190A18102C6C83788170666556646D65696F696B6C6062655E5D696E5E607170
5D5D82857F807C767E7B776351433843454D515B6E819594939DA7A5AFA9969FA5A6AFBA
B6906D4D35284290A19CA6A6A6A9AA805331160E0604130913140B111006050906040800
07080707
020603050206060A040407050706040E0A02110A0305060604070406040302010602090B
0704050A03090A020C241F2D5465726E7D8A6D685E50410707060E0C041111131B161F14
344F6247474A2931465566717B7C76675D6A6F674000030B1E433F54595259595E4C566A
676D514D7169535E6E695D605E666E5D686669684D54466563665A5A5F4F6A684C47524B
3947574018080D08386A817E746B6C645E6B6A5B61615D6C7465605C575C666A65676D63
53688482787D80807B77645652433841454D506075899795A2B0AC9EA6AAA3A7A2A0AAB3
B4A08A736B6C7297A6A7A1A7B0ADA67F6434100C06040D1219150D0F0F09060B0A060906
0C02000C
02020506070408070103050501010908070106030708030505020502020201000305040A
0A0202070609080010292136565B787464827661615B4E0E080B0A04050B0A1323191419
3041583F40402E312F547276807C70697077706A40000409144041535D6066625A596061
59593F4E665B62625F6E6A645D5F7B6F6F776A5A424B4858524F4F5C68585E5352595552
41343E422107080F32666A78676066626D71625D6C6F697277685B5553595B5C6267675E
677A7E7E777E7E7E76776054524C4A423D5056687A879398A6ABA39FA7A49DA39D98A4AE
AAA2A7ACB3BAB4AFA6A59EAFB5B3AE82683B231A09080D15140D0D0B1711080D08080606
0A0C0907
0602050506060A040401060702040B0104050E05070A0003060B00090804090C03050609
070C0E0404060300112D20295861777B53697E756856602B07090806040F0F1219130E1E
2528444640323732225A73707E796B676C757B723C0009162E4E4E5354585F5F58625A53
565F5C564950635E646D605F57556D676066675F4A4F56555F606A625553575C6351414D
3F243B4413060911386D687E746661656E67687577716C7171695E4F47566361605F6359
667D80847D7C7D797180735F585251453E52586E798094A3A69FA3B2A98E94AAA79086A7
B0A4AAB0AEB1B7B5AA9F9AAAADB8B58876482410060712140B11100E1E1511110C050304
06080B05
0202080604040A0003030608010409010403060606050602060A02040301060703020704
060C0B07060D0C030A271F0D436372856E6E7E8179546342060905030C140F1515120B11
1A1A1F3F412F362F2F6577737E756D7166697B7940000819324A4036404D4B56625E5056
5F6259585F5C58606A6B6C7672645F5B5B595D685F5E5A52705B6463555D5050644D3C4B
382543380003030A3270737E6A5663656261737B746C6771746857494E656A686B615850
59787B7777767E7A798071625B4F464546565B6B6D77878F97989CA08D859AA3A6A08899
A8A6A8ACAFABAEB1AC9D9BA9B6B8B8997F4E200C0B0910171117131021110A120F0F0803
0B030202
040306060402060803070509040205070301000408060305030403040201040307020303
0708040806090902011B230C385A4F646E6B62647A605F521007040A0E0E09101718100E
1927182C45413639415F77737A77767359586B764700031325423E374A665A5D685C5965
625D4E5A6B51516F727479797A645B605961656A6456574C5E49536D5F62574D5D4C4450
31284C39000303032967727472524E59615D6C757171686C69554F57616A615C68605B78
787B7E7A74797E79837C66626151444444555C606D878F8F9A9997958183A4A69EA099A4
A8A4A8AEB8B6B7B1A49D99A0BFC0C6AB80542F1D120E0C13182120152211050E13160A04
0A060302
0907060607000309040603050305040708020208080B050400040308050A0A0102020009
0204030302070C0C0513241A3A7358485454565D6E584D4F1B0F0E0A0F0F121316191712
0D26251B3A473640475A6F676B676E6F51566B6F4200030E1C414A4A526C694C544E5961
4D4F51515B555B686C78756C6E6160686468655F6350514B40506072615758565E594D46
30263F3B0901080C40606B6B725D47515859697778756B6A594A5A625B5B5D64685F6686
807E807E777D8081807365615B4D46483B4C63677C9793939E9B9EA18B7C9BAAA0A6A6A8
AAACAEA8ACA6B3B4A7A59F9FB7B8C5AC846339211C140B13161C2625261D110C171D0E08
05040C0C
040909060604080602050401050301020305030705070002070805030105040400070107
04070101070A0808081228262B6870544F45464D5452412D0A0D15111412120E12191F1C
121A281E3B4E3E4A53615B5F70545E725A5E6E6F4000070921484F4E5156554F5B585A52
515654555D636263676B706C656A6A716A5E5D64655856644C64675D5D5557554B52503A
291A1E2C08040B17585C68685F524949455A6C737B6A5C5D525162625A5A606E635E7D82
747B7C7272777B817B7B695F5E5146433A4B5E6078908C8D989C9E9A9382828F95AAACA7
A6A6ADA7AEADB1B0A99D9CA0B2B4B7A68464402B21160D161F17182B2C1E1718201E130A
04050503
03050503050A0801020503010205040001080804050604030805050803000003050B090A
0C070509060705040720292026485D50553B363D33544B15151308121312110D0C0E1617
190D22323C3D3A56505A52677B5B647667636D7C4300080B26403C3F4F65636C70605542
59585464645F6B75665E70695B656C71615658696562595A5656524B575962624540554C
2F24251C070B0A22645660695A4E4741475D676571625451535E67645A5F6F715962827B
6F7179757474787B7C836D6563514440404D545D788B8E97A29F98999D8776859CA2A8B1
A79EAFADB6B6A698A6A1A1A7B7B7B2AF845E3F29181712101F272728231C1D25221A1A10
06040609
0405030309090100010102030704040501070E090B0A0702070606030604030308060A08
04030706020406010021241730445E616A513D4625384E262D21000F151410150E0E1012
1D06102F3E3234514A5A596A75667070676368794200020C3153484E586D6B6D6C595B5B
675F5859585C676D66646C6B6B6C66645E5D5A5B5A645541504D5F635C5E636151444548
45402C100B050822645A545A51473B3B4B4F535760595A615E5B5F5E535A6E6B617A7E6E
6F777A75757276797E795F58574641444951516082939095A09F949092897682A19B9DAB
A599A09EA6A9AA959CA3A0A7B8B9AC9C6B5B422A201D13142832332D2727272826231C0E
0400070A
0402040A080304030208060A1307000605050303040306050307080400010402060A090B
0A07040703020103001C1F0A2944586D7D7A565B4B27353C3A23000311170C0E0E0B0711
1B0E07172D363F555662616C71676662626367724000070E2240465C625E5E5A5B5B6F6F
6A6B6D5D546468687471655F646F6D6668665A50596151464B546F68586360554E43373A
4B401E07090510286D674F53544A3E464B40525F4E4B5D615B5A555459617164647E766A
65767A75767473797F6F5B534B383137435257627E94938E969E9C8F8F8E8090A19C9C9B
9E978C90A3A2A3A0AAAA96A1B6B6A0887A754E261A17131E2F2E2A3239363230302C140B
0C040202
030505080303060602090A0509070205020005050004080805060504030603020504070B
04020103000604030117290F1F53665C617B6C706B2E28433C260C0C161A120A140F0811
1C1B0E0E1F374C665F686F6D6A625E68756C646738000B151A333A51635C655D5C506062
575C5C545365706F6D68686B605F635C6369584A505A5951555F686557565455514F4E47
493C1A060C0B142C6B695C5152544047443E5A674E495C5D5553494C606974666D787074
6871726F6B6E707D805F524938343E484D4B4F5E7D99958F999A908A8F817B9AA5A59F9E
A29F95949DA5A8B1B39E8DA9B4B3B5B6A482592B14171A1C262C2C33383A3A343431160A
0B010100
0209050002080503070C0A03040707010304050705040707050503090F120E0502000509
000604060D080305030C1D12113D706B5A707672734A252E3E3D1F080F111911140E0E0D
090F09081B304E6B62606C66686F6F75776967673400090B1B4640455A585B4D65504F60
514F585D5B6575706868676B686B6C5E656E4C4C45495E4A4F64687266504F6160504A49
433212010705152C6261504647453C40434D5C5B4F505F63584A41485666686270736C75
7370727162717675735D55433640464C4F454C617D988F87958F83888E79799DA2A4A2A6
A39E9C968A99B1BEB29D96AFB5BCC0C4AB7B5E412417172030383433303B423D40351A0B
05040603
03040103030705050608040608080704080B080304080300070701040907070802080303
010508060C070205060E2716223F657860667D6F6C693C29384B3001091A21160F0E0A0C
0713080210194362605B6F6E615D6A6E64656A653C0A070917403F405F6B6B63706C5F5D
5D5C6D706058636166706968696968616360455C59444F343C59686B5144595C5444303A
45301407080F182E4F55433940414A40385D6656535C615C5346424A57645A616B686C69
726F6B705F656B68635C615549443F474F4D5A676F878B858A817E8C968481A8A2989AA0
9DA19E9E8E8CABB5ACAEA7A6B1C8CBC0AE805A49311716242F34353A2E39433D4235170D
020C0602
0701030301050A040808080907080406060B070306030405020407070504030206090201
04040605050602060507251B124267746E6B7C7A79774A2E324C3C090D22211C110E0A0D
061513090B0B395759596F71685157625A6163583708080A12404133596C66776B655351
63646260656368625B636367665B63676B664C4D59444B4B4D4F5B5A46445852413E3138
49381D0310151336514D372B37434C41334D5B514F5B5A463E414C5361604C6369627167
676E66636161625F5D5C5F4E4140424A4C525A5A6D8588837C7A85908A807B999C9098A7
9C9997A58D729AADA7A48F93B6D0C9B4AB8B5F4A3217131C303F3E403036434044381509
04060606
03070602040405010406080B070403020606030605000608010005080506080200030404
090B00040308040409001D2C0C25545E6D737A7A79795E3F424F3E191417142014060705
0315180C1010365A5B586A6E72564B5E5E645E523405070E143A3B3C565C536E6F635462
66645C546972706661685F59606770636B6E50495239465F574D56544D413F4B43383939
413721050E11133F4E4429273B423D26223D504C4C565249454E6258505653696D696E65
5E6464626463606167665F493C40484D444A5856687B7F7D7981888980797590988C939F
918F92A3956F8AA9A59C8586A9C1C0B3A27B5C543A211818354A43443E403E3C433C1D18
0F050C05
05030501060403040105050208040401030907040605020102020206090C080103060607
030203050507070504091B220C175565556382806F727950464938200F071021180A0B0A
070A0908101128525F51646E67594F5055665644310B070D172D3E606A5F5E696B5C475A
5861655A61625C626C695B5E6E6D6C57626D63665B434B5A525155454345475643374540
433F21040F0F14443A382E323F3C24051F494C454F504A555A525B5239486D6C67695F5D
615D565D5E5962686A66554342413F413B46585860717D777C80797F8B827181918D9197
95969B9B937F757E7E787784A3BBC0B79B796959321B1F1E354A464439393B414E4A3224
0E0D0505
06060306060906060004030509010903000A0C0705050507060303060402070702050400
0304050A090306040104181D182E4C5E544D707B6F6B78553F47422D130614221A0E0E0B
0702060A0D0B144463465A6E6A6C645B5D5E46423311100C173A4E6D7E6866635C5F4653
5B625A565F655B5E655D627A775D5E5E6B66656C5B4B3F4E54585640425154533F38473F
3E38180D13131338333B38393C331425464F4446463A404B4F5457502E387668575C5451
5857535959545E5D55554B4044423C3F475753596D6E6F707A80848B9787767883919599
9B93979A968E776E7B838690ABBEB9B1A3918260381D1F22374649473A44464850553E1B
0807070A
04050606040307050303050404050602020A0803050103080A0706090304040103030506
060A07070A0A070803061D25192E515E54577073695F6E6A4D5450361B10182525130401
080C080808040D2E61424E656264656765543B41350C10161C4A5F6B79626E66545B5148
5569555665655C6667606C7065666E646156575F615034465564674B3A424A4F433A423C
3433181815121934484C3A3B3C291A3B52433841403C47494D574F3F0E1E6E675957544E
5E4E4E5A584E53564C4F534A41373D47444A4A526B6B6C756E7386878E898B89858F908E
9194928E918E8593A6A79A92A7BCB2AFA9A08B50352C2C284352524833433F404A4D461F
14080A08
030507010208090906050705040703080204020702090802030401040A070504060E0D03
0407030206080202090C172114246A7B4E586F6C695F63725A574B32180D0E1B23180D05
0308040A0D07071C5F41375C5F5E646650454650370A111B1E4F68676E67736D67565249
53654B506A5E50656D65665C5B6E6C57566064565F4F38495C6C6049373C45443A343F3A
33320D1513141640504B394343202747463E403B404B433C494D4745111E5E5D504A4E4E
634F4E4F484D595647494D41362C3140404D585A6A6B6B726F6A757E817F8586818A918F
898F938D939B98A0A79D9CA0ABB7B7B2A3A082523923202542554D4C36352926475B4D18
14020A06
070A0005000806090705020C030503070008010304030503070405080804040301030505
060809050403000400061C211B235E795249656C66615C63595C483223180F1116160E01
040B040F130C051F604D3B575F6762695B4E596B430A0F181B4D686C7B7A75646B5A5755
4C5343465A5957625F5B6A6A5F707355505B6442464C4E5B5B6953434549424040393537
3D3000170F1212444C3B374A4A192943383F4E42363A38313E48464F41465D5A4B49484E
5A5153484755574C484B44352F323542464D5156626469697371707A7A777D827A788388
83858B8D898A939CA19B958D8DA0B9BAADA0816A4B2D2A2D3D58544C403C301B3E6E5F1E
0E060503
030204060704020406040303060407080C08070A0E0A05020404040B0603030404060101
05050A09040607050707181C0E1B4F79684F5C6D6B62595B545E583B24201B1415140D04
080D050A0B0E09194B4C374A5A655F6057464C633D0B13101046625B68696668615A544F
414C5855595557625C5A696C6669685450425140495654605A664E3D40403B3F423D3933
322C0C18141F1A3B3E30364C40212E3031444C3D2A2E3330353C3F404A53646961563A53
5E4843454B514F464240383B3E3C313944474E5461637171766C656F7579777876778082
848B8A939485909186919078809FB0ACA694817248332D24385B5A545A3E291E35656132
100B0A0B
070300040502040107020108010001020701040207080403000805050506090204060703
00010606030404040708141C0F204C6F705D55586F63564E474F604C2415161D2A231106
06100D080C0A060B3E4C2640596168615556555F3E13130E144767646A5A547269605047
4A5059555E5A55676A615E6261545A5D604C55494A56495E67705F50413231444B3B3536
33280E17131F223B34383A4331272D2534433B31333A2C2A3631322E435B666E6C5F344E
5F3D36454949403B494F45403E332D3B474B52515C63716E6E6867706F72757C80787880
8A918B7F75676B7676777974839CA59F9D92837D5443301B405B4A596E3D212039655433
1708030A
0708020405050C0A060803050505040905040503050302030306030406020A0602000303
090206050001040303000A190C17445E666E695166685A3632465B481F141C2329190906
030B0D050906040D2C451B34565C60594C5F606841161518234B6C6E6F5E526A58575344
4750534A4D59696D5E555660655E6A655D5A513D374D4E6375695742303134434A3A3536
3321121A131A20352C3A34381D1B2C2D3339373A3A312A262A302E26345264675D614646
553833484A40383F494037303437363B3D42464455626F66646A68666166696C76746C70
7C8582746967636B797A7E848397A7A4ABAA9A87615230204E5D51646F48242240675436
230F0505
080B030103060A0201060908050408010607020503030305030406030407080604050205
040003010002080600000C1F1317425B5B68674A4F574324262E4641241C191116150E11
0D06070808030612203C2A3647545C58424E536B431813182C5270665F5F535E584D494B
464E524D49475C685751575B60626C6156554A3C3C40444757544E403A403C3B392D2E2A
281D21231B1D19383431302E191E35363436363C3726282222372416344D626863615044
553F3146413235424A3E322825292833313C4851595A61635F5D5B5C5E67635D6B726D69
7581746052504C57657B9094919EAAA3AFB2A58B6555361F45575E6C6F52272149695C37
1A090207
0806060405040307090907040308040107080206070602090105020600040C040503000A
040406080C09020104031221161B43635F5F665C4C56422F3B3C49422A1809031E281819
13030104070C0A0612343636344C574F494F4D6B491811274053625E5F685958684E3A51
524E475256495168615556585C5A5E5849464E40433E4344424D53433938363833292626
261422271F1E083638323220142436352F2F323B311F281A1F3C251B303A4C5C60564340
563F27393C353A3C4245402C1E28292C31424D5353585A5959585755575F5F616A6A6A67
6C7D6B4D4852556F7E8A8D84858C9492A3A69587674E3D22405E6C75796133253F626E49
1A0B0601
02040306030104090A08070203010106070302030403030C050704030406020202000406
0107040205080305050713191112355C5C4F5864504F51474C4B514E3A1F15131F191112
0B020303040C07030C2C322A324B4637535C4C5E3D151D3B4B4C56594B4D505060513845
4E544A555C5B53545554556068554B493D38443C4646565D4C49422A212C383B35343225
231C22252B211031362D240E112B2E2926232B2F1F101E17262D20252D314755423D3D49
5938212F383F3B2F3A4035201E302C242A3C444A4B57544C4E5457555456565F675E5A5F
6563575A74827C84848A8B817C888D909F988A91805B3E233F66757D8372442840768D59
16070503
030804070903000505050502020304050403060702020607040903020406060303030301
05050408030206060000101D12143B544C3E465E5F4D4A5959504D4F40241B1A110D110F
06050D0C05090D0507252E263448413B575348623B1C2736444E5A5D454155544C493332
3D4D494A454C524D484D4F5A675A4A4344434C3F3942596251403A241C2C312F2D292923
2A272D282A1A152F31241D0D1D352A252820252215191E202A1E1C272E2F39463F3D383B
472E1F363E3E39303C3B271E2222292A2B333E4947504C4B514E50504649545456555664
685455687E84786F7084828083888793A19B9CA190693827466E7C7E82794F243F88985B
200D0502
010705070204010408020B0B000001060A06060500050302020703000305050A01050307
06050C0300060607050311190A1A454E403A3F4B575544504D4A474641251217191B160B
03060B0803050B040623332D33403D3F4E4B465C3B1B263841424A565050524D454C3740
434B504B48565E5147443E48615F483F443B433C2B2B3843422A282A212B201228322C1B
0F1133332C25202A292017121A2626212224251B141F171B261B1A1E25312C343A34282C
46391D2F3C3734303A342423221F2B26222D353F434A4A4D4F4B4749443F464E58616464
4C4B666E7979767275887F7584867E8D96989A9D9E77361E3C687B80867A593B4B808A5C
2004090C
080104020202020607040806010407040105050406020201020407040703010906000707
0704050809040306040C140C0A2148543C23233542554C4240484A48432B10030E1B1609
00030603040807030921322C394448434248475C37182D3E3F3D455151534E4240513E4F
4B464E4B4D5C53454D4B414C59564D4D5540414032292B3B3A2424272129221B31393224
192134302D2922212E2614131D2229281E2222171618141C1E141718141B28282D2C2B38
4935192A3B3A3733322B221F1B1F2926242E313641403F40424341484E474A5558575950
30486869747675767A787C757B807B8B8B869098976F392540768783897C6252658F9C6A
1F030F0C
0608040608060306070502030404020005040003060A07040B0502040303000207020506
0401030203090503050410160C21434728121A2A404D4A393A424547412D16080B131612
0A040707010A110807162F3036404B48424948623F23364240424A4B454A5241363E2F40
3F3A3F4142515346453E39464C4E4C474E4348424241373D342B322A232E302C312E2E2B
232A2F353627191F2A2416121B2128251A1A171412060A14140D0F11100F242925222031
412210343B363D382B24252A221416262B2B30343A393D4041413D404646495252423F3B
334F65646A706E686B646B6C6F7D79878F7F8390794D362D487E878A95897261759CAB6D
2D0F0903
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000102000206070301010306070706040506070705020100000101
00000000000002000001040505080A0A090A0A0E0A06090B09090A0A0A0B0B0909080609
0909090B0A0B0D0B0A090A0C0D0C0A0A0C0C0D0A090A080A0B0805040406070605060607
060606060804030504030201030403020302010201010201000001010001040605030104
070401060605070504040303030101030303030405050505050405050606060505040403
040707070808080706070707070808090908070807050403040707080807070607080804
01000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000102000206070301010206070706040506060605020100000100
0000000000000200000104050507090A080A0A0E0A06090B09090A0A0A0B0B0909080609
090A0A0B0A0B0D0C0A090A0C0D0C0A0A0C0C0D0A090A080B0C0805030406070605050607
060605060804030504030101030402020302010201020201000001010001040606030103
070401060605070504040303030101030303030405050505050405050606050505040403
040707070808080706070707070808090908070807050403040707080807070607080804
01000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{256, 256},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000600001P2000`400?l00000o`00003oA@000000
10010@400P8200820P010@420000000400@410061PH01PH600<30`80000000@00@4100@4100410@0
1@D50P061PH010071`L01PH600H61P0410@200D51@0300H61P051@D01@D500<01PH600<00`<30041
0@010@400`00000300410@@000000P010@430000000400820P010@400@41000000800@4100@01@D5
00H61P061PH01@D50P071`L010092@T020P800P8200820P200X:2P0400/;2`0=3@d03@d=00/;2`80
1PH600<020P800T92@092@T0100820P200T92@<030`<00@02@T900L71`071`L020P80P071`L01006
1PH02@T900T92@092@T200X:2P0400T92@0;2`/02`/;00`<30803@d=00@03Ph>00`<300<30`02PX:
0P092@T0100;2`/03Ph>00h>3P0>3Ph200d=3@0300`<300=3@d03@d=00<03@d=00@030`<00P82008
20P01@D50P092@T0100;2`/030`<00`<300<30`200P8200300D51@0410@010@400@01@D50P0410@3
00<30`<01@D500<010@400H61P061PH00`061PH00`071`L01@D500D51@0300D51@0300<30`010@40
0@4100<00@410`030`<010010@400000000000020P8300<30`800@4100@0000000410@010@400@41
0`00000200410@@000000P010@4010020P801PH600H61P0820P200H61P0400410@030`<00`<300P8
208010@400@00P8200H61P061PH010@40P051@D00`071`L010@400@4100400<30`800@4110020P88
00<30`@01@D50P061PH:00D51@8010@40`030`<300@4100400D51@061PH01PH600H61P<01`L70P06
1PH400L71`<020P81P071`L200P8200300T92@0820P020P800<01`L70`051@D0100410@00`<300<3
0`030`<200L71`@020P81P071`L300P820801@D500<00`<300410@010@400`00000004D0000000@0
0@4100820P020P800@410P000000100410@01PH600H61P030`<20000000400410@0410@010@400D5
1@801PH600@01`L700H61P061PH010@40P051@D00`061PH01@D500D51@0300H61P0300<30`010@40
0@4100<000000`010@44000000800@410`00000010020P800@4100410@00000200410@0400D51@06
1PH01PH600D51@801`L700@02@T900P8200820P020P80P0:2PX0100;2`/03@d=00d=3@0;2`/200H6
1P0300P820092@T02@T900@020P80P092@T300`<300400T92@071`L01`L700P820801`L700@01PH6
00T92@092@T02@T90P0:2PX010092@T02`/;00/;2`0<30`200d=3@0400h>3P0<30`030`<00X:2P80
2@T900@02`/;00h>3P0>3Ph03Ph>0P0=3@d00`0<30`03@d=00d=3@0300d=3@0400`<300820P020P8
00D51@802@T900@02`/;00`<300<30`030`<0P0820P00`051@D010@400@4100400D51@8010@40`03
0`<300D51@0300@410061PH01PH600<01PH600<01`L700D51@051@D00`051@D00`030`<00@410041
0@0300410@<00`<300@00@410000000000000P820`030`<200410@04000000010@400@4100410@<0
00000P010@44000000800@4100@00P8200H61P061PH020P80P061PH010010@400`<300<30`0820P2
00@4100400820P061PH01PH600@410801@D500<01`L700@4100410@010030`<200410@@00P822003
0`<400D51@801PH62P051@D200@410<00`<30`0410@010051@D01PH600H61P061PH300L71`801PH6
10071`L300P820H01`L70P0820P00`092@T020P800P8200300L71`<01@D500@010@400<30`030`<0
0`<30P071`L400P820H01`L70`0820P200D51@0300<30`010@400@4100<00000000010061PH01@D5
00D51@051@D200H61P<01@D50`0410@010030`<010@400@410030`<20000000400820P030`<00`<3
00820P801PH600@020P800L71`071`L01PH60P092@T0100820P01@D500D51@051@D200@4100400<3
0`000000000000820P801PH600@010@400H61P061PH010@40P051@D00`061PH01`L700L71`0300T9
2@0400410@061PH01PH600T92@801PH600<010@400D51@051@D00`020P80100000001PH600H61P0B
4Q8201TI6@04010@400<30`030`<034a<@80@d=300@08b<S00P8200820P0410@0P0[:b/0100j>SX0
?3`l03`l?011@D4203Xj>P0402PX:00a<C40<C4a03Ti>@80<S8b00@0?Cdm03Hf=P0f=SH07AdM0P0C
4a<010061PH01@D500D51@0;2`/200d=3@0400T92@030`<00`<300T92@803@d=00@01@D500P82008
20P04Q8B0P0<30`010010@402`/;00/;2`0Y:BT202d];@0402`/;00f=SH0=SHf04A4A080?clo00@0
>c/k04M7A`17AdL0CTi>0P1LG5`0101;Bd/0;Bd]02d];@0g=cL203hn?P0403Ph>00j>SX0>SXj03Ti
>@80@41000@0DU9B055AD@1ADE40@4100P0f=SH0100l?3`0<c<c03<c<`0Z:RX203lo?`0403hn?P12
@T80@T9203`l?080@d=300@0CDe=05ADE01DE5@0FUYJ0P1?Cdl01010@400>c/k03/k>`16ATH205MG
E`0405YJFP1CDe<0De=C04i>CP80DE5A00@0DU9B05EEE@1EEED0DE5A0P0l?3`0100X:2P0?Shn03hn
?P16ATH204m?C`0404e=C@0e=CD0=CDe02DU9@807alO00@08R8R02LW9`0W9bL08R8R0P0M7Ad0100I
6AT05aLG01LG5`0S8b<202HV9P0301dM7@0[:b/0:b/[00<0;Bd]00@0<c<c024Q8@0Q8B408b<S0P0U
9BD0100F5QH03@d=00d=3@0=3@d200l?3`0401HF5P0H61P061PH00d=3@801`L700@03Ph>01LG5`0G
5aL05aLG0P0?3`l010061PH03@d=00d=3@0;2`/200D51@0300L71`0=3@d03@d=00<01PH600@00P82
00d=3@0=3@d05aLG0P0`<3001011@D40<C4a034a<@0>3Ph2020P80040451@@0R8R808R8R01@D5080
<S8b00@08b<S02/[:`0[:b/0>c/k0P0R8R80100P82008R8R028R8P0N7Qh201<C4`<05aLG00@06ATI
020P800P82008B4Q0P0N7Qh0100O7al092@T02@T900b<S8203<c<`04038b<P0l?3`0?3`l03`l?080
>3Ph00<0?3`l03dm?@0m?Cd00`0n?Sh0100k>c/0<C4a034a<@0W9bL202h^;P0403Ti>@0e=CD0=CDe
0410@080De=C00@0CTi>05MGE`1GEeL0HV9R0P1EEED0101MGEd0G5aL05aLG01NGUh206][J`0406m_
K`1^KVh0KVi^06IVIP80J6QX00@0Lg=c07moO`1oOgl0R8R80P21PH40101fMWH0LG5a075aL@1QHF42
05QHF00405EEE@0k>c/0>c/k04I6AP80PH6100@0UIFE09NGU`2GUiL0UiNG0P2=SHd0102:RXX0RHV9
08V9R@2HV9P30:2PX080Lg=c00@0AdM702XZ:P0Z:RX00@410P051@D0000400<30`020P800P820082
0P802@T900@030`<00X:2P0:2PX010@40P030`<010020P800`<300<30`061PH200@4100300D51@02
0P800P8200<00`<300@00P8200410@010@400`<30P0410@00`051@D01PH600H61P0300H61P<00@41
0`020P8010010@401PH600H61P020P8200@4100400410@0410@010@400H61P80000000@00@4100D5
1@051@D01@D50P010@4300@4100400<30`0410@010@400<30`800@4100@04A4A01DE5@0E5AD030`<
0P0:2PX0100_;bl0?clo03lo?`0T92@201DE5@04020P800m?Cd0?Cdm04=3@`<0>SXj0P0k>c/0100c
<c<0;Bd]02d];@0];Bd202l_;`0403Xj>P0i>CT0>CTi02HV9P805QHF00@01@D500@4100410@01PH6
0P0>3Ph0100?3`l010@400@410030`<200P8200400@410000000000000410@800`<300@0000000X:
2P0:2PX0:b/[0P0/;2`0100Y:BT0;Rh^02h^;P0m?Cd203Ti>@0403Xj>P19BDT0BDU904];B`80CDe=
00@0@41002d];@0];Bd0;Rh^0`0c<c<203Ph>00403/k>`15ADD0ADE505QHF080EUIF00@0ATI604=3
@`13@d<0ADE50P0k>c/0100`<300?3`l03`l?00d=3@2034a<@0402d];@0h>3P0>3Ph04E5A@80B4Q8
00@0A4A403lo?`0o?cl0>3Ph0P0c<c<01010@400EEEE05EEE@1EEED2055AD@04051@D01:BTX0BTY:
04A4A080Bd];00@0E5AD055AD@1ADE40?Cdm0P11@D401019BDT0Bd];04];B`0o?cl202HV9P0401hN
7P0M7Ad07AdM024Q8@80:RXZ00@071`L00d=3@0=3@d04Q8B0P0G5aL0100U9BD0:2PX02PX:00N7Qh2
02l_;`0403<c<`0];Bd0;Bd]02XZ:P804Q8B00@08B4Q01dM7@0M7Ad0410@0P0>3Ph0100<30`04A4A
014A4@0:2PX200410@0400h>3P0?3`l03`l?00<30`802`/;00@04a<C00d=3@0=3@d00@410P071`L0
10092@T02`/;00/;2`092@T200l?3`<04a<C00@03@d=00/;2`0;2`/07AdM0P0g=cL0100h>3P0:b/[
02/[:`0H61P202@T900403<c<`0C4a<04a<C010@4080:b/[00@07AdM02d];@0];Bd0<C4a0P0J6QX0
100O7al09BDU02DU9@0O7al201HF5P04020P800N7Qh07QhN01PH6080820P00@07AdM01PH600H61P0
6QXJ0P0Q8B40100];Bd0:b/[02/[:`0Y:BT2030`<00403Hf=P0c<c<0<c<c02l_;`80<c<c00@0=3@d
030`<00`<300<30`0P0X:2P0100Y:BT0@4100410@01>CTh2051@D00405ADE01CDe<0De=C055AD@80
FEUI00@0I6AT05QHF01HF5P0EeMG0P1FEUH0101HF5P0HV9R069RHP1UIFD206IVIP04065QH@1NGUh0
GUiN07AdM080QXJ600@0P82007MgM`1gMgL0O7al0P1cLg<0101UIFD0L71`071`L01VIVH20410@004
04a<C01jNWX0NWYj08Z:RP<0TI6A0P2;Rh/0102CTi<0WinO09nOW`2WYjL20:FUY@040:j^[P27QhL0
QhN7051@D08092@T0@00000100@4104010@4000010030`<00P8200820P020P8200T92@0400`<300:
2PX02PX:00@410800`<300@00P8200<30`030`<01PH60P0410@00`051@D00P8200820P0300<30`04
00820P010@400@4100<30`8010@400<01@D500H61P061PH00`061PH300410@<00P8200@00@4100H6
1P061PH00P820P0410@010010@4010@400@410061PH20000000400410@051@D01@D500D51@800@41
0`0410@010030`<010@400@410030`<200410@04014A4@0E5AD05ADE00`<30802PX:00@0;bl_03lo
?`0o?cl092@T0P0E5AD0100P8200?Cdm03dm?@13@d<303Xj>P80>c/k00@0<c<c02d];@0];Bd0;Bd]
0P0_;bl0100j>SX0>CTi03Ti>@0V9RH201HF5P0400D51@0410@010@400H61P803Ph>00@03`l?00@4
100410@00`<30P0820P0100410@00000000000010@4200<30`040000000:2PX02PX:02/[:`80;2`/
00@0:BTY02h^;P0^;Rh0?Cdm0P0i>CT0100j>SX0BDU904U9B@1;Bd/204e=C@040410@00];Bd0;Bd]
02h^;P<0<c<c0P0h>3P0100k>c/0ADE504E5A@1HF5P205IFEP0404I6AP13@d<0@d=304E5A@80>c/k
00@0<30`03`l?00l?3`0=3@d0P0a<C40100];Bd0>3Ph03Ph>015ADD204Q8B00404A4A00o?cl0?clo
03Ph>080<c<c00@0@41005EEE@1EEED0EEEE0P1ADE40101@D500BTY:04Y:BP14A4@204];B`0405AD
E01ADE40DE5A03dm?@80@D5100@0BDU904];B`1;Bd/0?clo0P0V9RH0100N7Qh07AdM01dM7@0Q8B42
02XZ:P0401`L700=3@d03@d=018B4P805aLG00@09BDU02PX:00X:2P07QhN0P0_;bl0100c<c<0;Bd]
02d];@0Z:RX2018B4P04024Q8@0M7Ad07AdM010@40803Ph>00@030`<014A4@0A4A402PX:0P010@40
100>3Ph03`l?00l?3`030`<200/;2`0401<C4`0=3@d03@d=00410@801`L700@02@T900/;2`0;2`/0
2@T90P0?3`l301<C4`0400d=3@0;2`/02`/;01dM7@80=cLg00@0>3Ph02/[:`0[:b/061PH0P0T92@0
100c<c<04a<C01<C4`0@410202/[:`0401dM7@0];Bd0;Bd]034a<@806QXJ00@07alO02DU9@0U9BD0
7alO0P0F5QH0100P82007QhN01hN7P0H61P2020P800401dM7@0H61P061PH01XJ6P808B4Q00@0;Bd]
02/[:`0[:b/0:BTY0P0`<300100f=SH0<c<c03<c<`0_;bl203<c<`0403@d=00`<300<30`030`<080
:2PX00@0:BTY0410@010@400CTi>0P1@D500101DE5@0De=C05=CD`1ADE4205UIF@0406ATI01HF5P0
F5QH05MGE`80EUIF00@0F5QH069RHP1RHV80IFEU0P1VIVH0101QHF40GUiN05iNGP1dM7@208J6QP04
0820P01gMgL0MgMg07alO080Lg=c00@0IFEU071`L01`L700IVIV0P10@400101<C4`0NWYj07YjNP2:
RXX3096AT@80Rh^;00@0Ti>C09nOW`2OWil0YjNW0P2UYJD0102^[Zh0QhN708N7Q`1@D50202@T9040
00000@0410@100@4100000@01`L700<30`030`<01@D50P030`<010020P800@4100410@0410@20041
0@<00`<30`051@D010030`<01@D500D51@061PH200<30`040000000410@010@400@410800P8200@0
2@T900@4100410@00@410P051@D010030`<01@D500D51@0410@200H61P0300D51@0410@010@400<0
000000@01PH600/;2`0;2`/00@410P020P8010051@D00`<300<30`00000200L71`0400T92@030`<0
0`<300410@D00P8200@05QHF01`L700L71`02PX:0P0<30`0100W9bL0?Cdm03dm?@0g=cL2024Q8@04
02<S8`0h>3P0>3Ph03hn?P80>SXj00@0=SHf038b<P0b<S80;bl_0P0];Bd0100M7Ad09BDU02DU9@0d
=3@203Lg=`0402d];@0L71`071`L00d=3@802@T900@010@400P8200820P020P80`030`<200P82004
00H61P000000000000@410801`L700@0000000L71`071`L08b<S0P0Y:BT0100O7al08b<S02<S8`0i
>CT203/k>`0403De=@13@d<0@d=304m?C`80EEEE00@0?Cdm02@T900T92@08b<S0P0Z:RX0100b<S80
?Shn03hn?P12@T8204A4A00404];B`12@T80@T92034a<@80=cLg00@0=SHf034a<@0a<C40<c<c0P0e
=CD0100];Bd0>SXj03Xj>P0n?Sh20451@@0404M7A`19BDT0BDU904A4A080?3`l00@0=cLg03@d=00d
=3@0?Shn0P1@D500101EEED0CDe=04e=C@18B4P204M7A`0404];B`1DE5@0E5AD055AD@80Cdm?00@0
@d=303Lg=`0g=cL0?clo0P17AdL01018B4P0<c<c03<c<`0N7Qh201DE5@0401HF5P0P8200820P020P
80805ADE00@04A4A010@400@41005QHF0P0J6QX0100D51@0;bl_02l_;`0i>CT202XZ:P0402l_;`0N
7Qh07QhN01hN7P804a<C00@02`/;00`<300<30`02PX:0P0A4A40100C4a<02PX:00X:2P0E5AD201`L
700401@D500=3@d03@d=00/;2`804Q8B00@01@D500L71`071`L0410@0P0>3Ph0100A4A406ATI01TI
6@0D51@201HF5P0401dM7@0A4A404A4A024Q8@80@T9200@0>SXj02LW9`0W9bL04a<C0P0K6a/0100]
;Bd04a<C01<C4`0>3Ph2020P800401XJ6P0X:2P0:2PX02XZ:P8061PH00@04a<C01/K6`0K6a/071`L
0`0I6AT201/K6`0401XJ6P0M7Ad07AdM01/K6`808R8R00@09RHV02/[:`0[:b/0=CDe0P0_;bl0100X
:2P0;2`/02`/;00_;bl202d];@0402h^;P0a<C40<C4a030`<080;Rh^00@0;2`/02XZ:P0Z:RX0>CTi
0P1@D5000`1BDU80A4A404A4A003055AD@0404m?C`1BDU80DU9B05aLG080GEeM00@0FEUI05MGE`1G
EeL0F5QH0P1TI6@0101QHF40IFEU06EUI@1UIFD205eMG@0406i^KP1lO7`0O7al07EeM@80KVi^00@0
MGEe06i^KP1^KVh0IfMW0P1cLg<0101LG5`0>c/k03/k>`1TI6@208Z:RP0407moO`2<S8`0S8b<09FE
U@80TY:B00@0X:2P0:f][@2][Jd0][Jf0P2h^;P0102m_Kd0TY:B09:BTP10@40201<C4`4000000@06
1PH100H61P0000@010@400<30`030`<00P820P030`<010071`L01@D500D51@020P8200D51@0300L7
1`020P800P8200@00`<30P051@D0100000000P8200820P030`<500410@0400H61P0=3@d03@d=00T9
2@8010@400@02@T900@4100410@00@410P030`<010092@T01`L700L71`071`L200820P0400X:2P08
20P020P800P8208010@400@0000000D51@051@D02@T90P030`<010051@D01PH600H61P0820P50082
0P0400`<300D51@051@D00T92@802PX:00@09BDU03lo?`0o?cl0?Shn0P0d=3@0100i>CT0>3Ph03Ph
>00f=SH203De=@0403Hf=P0e=CD0=CDe02/[:`80;bl_00@07AdM01hN7P0N7Qh0;Rh^0P0h>3P0100X
:2P071`L01`L700F5QH200/;2`0400d=3@0>3Ph03Ph>00d=3@802@T900<020P800L71`071`L00`01
0@4010061PH02PX:00X:2P071`L200<30`04018B4P0U9BD09BDU020P80808R8R00@0<30`03Ph>00h
>3P0?Shn0P1:BTX01015ADD0CDe=04e=C@0m?Cd201dM7@0401hN7P0Z:RX0:RXZ02l_;`80?clo00@0
@d=303`l?00l?3`0@D510P10@403034a<@<0:BTY00@0;Bd]02l_;`0_;bl0=SHf0P17AdL0100i>CT0
=3@d03@d=00g=cL203Xj>P0404i>CP1@D500D51@03dm?@80>CTi00@0B4Q804i>CP1>CTh0ATI60P14
A4@01016ATH0@d=304=3@`17AdL205MGE`0405ADE01FEUH0EUIF04];B`80>3Ph00@0<c<c03Ti>@0i
>CT0@4100P0/;2`0100K6a/07AdM01dM7@0P820201@D500400d=3@0>3Ph03Ph>00h>3P805QHF00@0
7QhN01XJ6P0J6QX04Q8B0P0U9BD0100c<c<0;Bd]02d];@0c<c<202TY:@0401dM7@0G5aL05aLG01@D
50802PX:00@01`L700T92@092@T01`L70P0:2PX0100B4Q804A4A014A4@0=3@d200l?3`04018B4P0A
4A404A4A00/;2`8030`<00@03Ph>00l?3`0?3`l03@d=0P0H61P0100J6QX05aLG01LG5`0K6a/202DU
9@04024Q8@0m?Cd0?Cdm04I6AP80<S8b0`0D51@0100S8b<04A4A014A4@092@T201TI6@0401dM7@0W
9bL09bLW02PX:0805aLG00@04A4A01dM7@0M7Ad071`L0P0E5AD0100H61P07AdM01dM7@0P820202<S
8`0402HV9P0[:b/0:b/[02@T90809RHV00@0;2`/02TY:@0Y:BT09BDU0P0[:b/0100c<c<0?3`l03`l
?00l?3`202XZ:P0402@T900Z:RX0:RXZ030`<080?Cdm00@0ADE504M7A`17AdL0ATI60P10@400101:
BTX0C4a<04a<C01BDU82051@D0<0DE5A00@0De=C05UIF@1IFET0G5aL0P1XJ6P0101PH600GemO05mO
G`1IFET205EEE@0406][J`1gMgL0MgMg07=cL`<0L71`0P1[Jf/0101^KVh0LW9b079bLP1?Cdl203De
=@04071`L02JVYX0VYZJ09RHV080[:b/0`2e]KD0102i^KT0]kNg0;Ng]`2o_kl20<?3``040<;2`P2?
Shl0Shn?02l_;`801`L70@030`<100@4104010@40000100410@00`<300<30`020P8200<30`0400L7
1`051@D01@D500820P801@D500<01`L700820P020P8010030`<200D51@04000000020P800P8200<3
0`D00@4100@01PH600d=3@0=3@d02@T90P0410@010092@T010@400@410010@4200<30`0400T92@07
1`L01`L700L71`800P8200@02PX:00P8200820P020P80P0410@0100000001@D500D51@092@T200<3
0`0400D51@061PH01PH600P820D00P8200@030`<01@D500D51@02@T90P0:2PX0100U9BD0?clo03lo
?`0n?Sh203@d=00403Ti>@0h>3P0>3Ph03Hf=P80=CDe00@0=SHf03De=@0e=CD0:b/[0P0_;bl0100M
7Ad07QhN01hN7P0^;Rh203Ph>00402PX:00L71`071`L01HF5P802`/;00@03@d=00h>3P0>3Ph03@d=
0P092@T00`0820P01`L700L71`0300410@0400H61P0:2PX02PX:00L71`800`<300@04Q8B02DU9@0U
9BD0820P0P0R8R80100`<300>3Ph03Ph>00n?Sh204Y:BP0404E5A@1=CDd0CDe=03dm?@807AdM00@0
7QhN02XZ:P0Z:RX0;bl_0P0o?cl01013@d<0?3`l03`l?011@D420410@0<0<C4a0`0Y:BT0100];Bd0
;bl_02l_;`0f=SH204M7A`0403Ti>@0d=3@0=3@d03Lg=`80>SXj00@0CTi>051@D01@D500?Cdm0P0i
>CT01018B4P0CTi>04i>CP16ATH204A4A00404I6AP13@d<0@d=304M7A`80EeMG00@0E5AD05IFEP1F
EUH0Bd];0P0h>3P0100c<c<0>CTi03Ti>@10@40202`/;00401/K6`0M7Ad07AdM020P808051@D00@0
3@d=00h>3P0>3Ph03Ph>0P0F5QH0100N7Qh06QXJ01XJ6P0B4Q8202DU9@0403<c<`0];Bd0;Bd]03<c
<`80:BTY00@07AdM01LG5`0G5aL051@D0P0:2PX010071`L02@T900T92@071`L200X:2P04018B4P0A
4A404A4A00d=3@803`l?00@04Q8B014A4@0A4A402`/;0P0<30`0100>3Ph03`l?00l?3`0=3@d201PH
600401XJ6P0G5aL05aLG01/K6`809BDU00@08B4Q03dm?@0m?Cd0ATI60P0b<S8301@D500402<S8`0A
4A404A4A00T92@806ATI00@07AdM02LW9`0W9bL0:2PX0P0G5aL0100A4A407AdM01dM7@0L71`201DE
5@0401PH600M7Ad07AdM020P80808b<S00@09RHV02/[:`0[:b/092@T0P0V9RH0100/;2`0:BTY02TY
:@0U9BD202/[:`0403<c<`0l?3`0?3`l03`l?080:RXZ00@092@T02XZ:P0Z:RX0<30`0P0m?Cd01015
ADD0AdM704M7A`16ATH20410@00404Y:BP1<C4`0C4a<059BDP80D51@0`1ADE40101CDe<0FEUI05UI
F@1LG5`206QXJ004061PH01OGel0GemO05UIF@80EEEE00@0Jf][07MgM`1gMgL0Lg=c0`1`L70206][
J`0406i^KP1bLW80LW9b04m?C`80=CDe00@0L71`09ZJVP2JVYX0V9RH0P2/[:`30;Fe]@040;Vi^@2g
]kL0]kNg0;no_`80`l?300@0`/;208n?S`2?Shl0;bl_0P071`L100<30`4010@40@0410@0000400L7
1`0410@010@400410@800P820`0820P0100410@00P8200820P0410@200D51@0400X:2P071`L01`L7
000000801PH600@02@T900D51@051@D01@D50P030`<010051@D010@400@410071`L200820P0400H6
1P030`<00`<300P820<010@40P00000010061PH010@400@410020P8200D51@0400820P0000000000
00H61P802@T900@020P800820P020P8000000P0410@010051@D00`<300<30`030`<300820P8010@4
00<02`/;010@400@41000`0<30`0100T92@0>CTi03Ti>@0g=cL203Ph>00403Hf=P0Z:RX0:RXZ03Hf
=P80>CTi00@0<C4a02h^;P0^;Rh0;2`/0P0X:2P0100R8R808B4Q024Q8@0/;2`203/k>`0402HV9P0F
5QH05QHF01LG5`804A4A00@03@d=00h>3P0>3Ph03@d=0P0820P010051@D01`L700L71`0410@20082
0P0400T92@051@D01@D5000000802@T900@030`<01`L700L71`06QXJ0P0Q8B40100W9bL0;Bd]02d]
;@0k>c/204e=C@0404I6AP1BDU80DU9B05]KF`80?Cdm00@0;bl_02PX:00X:2P09BDU0P0d=3@0100f
=SH0<C4a034a<@0d=3@303Xj>P80;bl_00@0:2PX02<S8`0S8b<09bLW0P0Z:RX0100e=CD0ADE504E5
A@0a<C4203De=@0403/k>`0c<c<0<c<c04I6AP80CTi>00@0=cLg03@d=00d=3@0CDe=0P1?Cdl0100l
?3`0?Shn03hn?P16ATH203dm?@0403Ph>01@D500D51@055AD@80ADE500@0?Shn0410@010@400>CTi
0P0W9bL0100S8b<07AdM01dM7@0G5aL301HF5P804A4A00@02PX:00H61P061PH020P80P0?3`l0100G
5aL061PH01PH600B4Q8201@D500402DU9@0b<S80<S8b02`/;0809BDU00@0820P01LG5`0G5aL03@d=
0P0>3Ph0100E5AD06QXJ01XJ6P0D51@3018B4P80410@00@03@d=00l?3`0?3`l051@D0P0A4A40100<
30`02`/;00/;2`0>3Ph2010@400400T92@0H61P061PH028R8P807alO00@04Q8B020P800P82004A4A
0P0T92@0100m?Cd0<c<c03<c<`0I6AT201/K6`04028R8P0<30`030`<00H61P8051@D00@0820P02l_
;`0_;bl0:RXZ0P0K6a/0100I6AT071`L01`L700L71`201DE5@0402LW9`0S8b<08b<S024Q8@809BDU
00@09bLW02DU9@0U9BD08B4Q0`0X:2P202HV9P04028R8P0X:2P0:2PX02h^;P80=3@d00@0;bl_028R
8P0R8R808R8R0P0Y:BT0100b<S80>CTi03Ti>@0l?3`20492@P0404A4A013@d<0@d=304I6AP80C4a<
00@0FEUI05EEE@1EEED0E5AD0P1=CDd0101;Bd/0E5AD05ADE01BDU8205IFEP0405UIF@1TI6@0I6AT
06ATI080Fe]K00@0K6a/07=cL`1cLg<0JVYZ0P1YJFT0101WIfL0KFe]06e]K@1jNWX207UiN@0404m?
C`0o?cl0?clo07moO`80Y:BT00@0ZZZZ0;Rh^02h^;P0^KVi0P2j^[X01030`<00`L710<71`@30`<02
0<O7a`040<S8b01mOGd0OGem01TI6@801@D50@061PH100820P400P820000100410@0000000000002
0P8300<30`801@D500@010@400<30`030`<01@D50P0820P010071`L00@4100410@010@4200D51@04
00H61P0410@010@400H61P800`<300@01PH600X:2P0:2PX00P820P0:2PX010030`<01`L700L71`06
1PH200<30`0400H61P020P800P8200P8208010@400@01`L700@4100410@000000P030`<010000000
0`<300<30`0410@200<30`0400@410010@400@41000000800P8200@010@400L71`071`L00`<30P02
0P80100>3Ph04Q8B018B4P0<30`200d=3@0401XJ6P0U9BD09BDU02`/;080=3@d00@0<S8b02h^;P0^
;Rh0;bl_0P0f=SH0100d=3@0<C4a034a<@0d=3@202DU9@<08b<S00@0:2PX03<c<`0c<c<0:2PX0P0D
51@010092@T02PX:00X:2P0>3Ph201LG5`0401HF5P0820P020P800D51@802@T900@01@D500820P02
0P8030`<0P0=3@d010010@4010@400@4100?3`l201dM7@0401HF5P0I6AT06ATI02XZ:P80<30`00@0
?3`l04a<C01<C4`0AdM70P1EEED0101aLG40IfMW06MWI`1<C4`202h^;P04024Q8@0Y:BT0:BTY030`
<080=CDe00@0<S8b03Ph>00h>3P0=SHf0P0V9RH0100_;bl0<S8b038b<P0a<C4202/[:`0403@d=00g
=cL0=cLg038b<P80?clo00@0BTY:03Ti>@0i>CT0<C4a0P0f=SH0100^;Rh0;2`/02`/;00k>c/204];
B`0404a<C011@D40@D5104U9B@80De=C00@0B4Q804Y:BP1:BTX0@4100P0b<S80100c<c<0@T920492
@P10@40202<S8`0401<C4`0L71`071`L01XJ6P8051@D00@04a<C020P800P82006QXJ0P0820P0100;
2`/0410@010@400>3Ph300X:2P804a<C00@0;bl_03Ti>@0i>CT08B4Q0P0X:2P0100R8R8061PH01PH
600E5AD201@D5004014A4@0G5aL05aLG01XJ6P804Q8B00@0410@01`L700L71`07AdM0P0G5aL0100J
6QX06ATI01TI6@0B4Q8200h>3P0401@D500B4Q804Q8B010@40806QXJ00@071`L01PH600H61P06ATI
0P0<30`010010@4071`L01`L700i>CT203Xj>P0402LW9`0S8b<08b<S024Q8@80410@00@020P8014A
4@0A4A4092@T0P0^;Rh0100U9BD07QhN01hN7P0K6a/301dM7@8071`L00@0;2`/02DU9@0U9BD092@T
0P0[:b/00`0W9bL092@T02@T900402<S8`<0;Rh^0P0`<3000`0/;2`0:2PX02PX:00302@T900402`/
;00h>3P0>3Ph03Ti>@80<c<c00@0?Shn04A4A014A4@0>c/k0P0n?Sh0101;Bd/0CDe=04e=C@1?Cdl2
055AD@04059BDP1CDe<0De=C05ADE0<0FUYJ0P1@D500101HF5P0HF5Q065QH@1NGUh205EEE@04055A
D@1KFe/0Fe]K06ATI080GUiN00@0I6AT06i^KP1^KVh0KFe]0P1_Kfl01018B4P0>c/k03/k>`20P802
0:^[Z`040;>c/`2j^[X0^[Zj0;Rh^080_kno00@0bl_;0<S8b038b<P0_Kfm0P39bLT0103:b/X0K6a/
06a/K00A4A4200/;2`402@T90@030`<100<30`0000@010@40000000000000P820`030`<200D51@04
00@410030`<00`<300D51@8020P800@01`L700410@010@400@410P051@D010061PH010@400@41006
1PH200<30`0400H61P0:2PX02PX:00820P802PX:00@00`<300L71`071`L01PH60P030`<010061PH0
0P8200820P0820P200@4100400L71`0410@010@4000000800`<300@0000000<30`030`<010@40P03
0`<0100410@00@4100410@00000200820P0400@410071`L01`L700<30`800P8200@03Ph>018B4P0B
4Q8030`<0P0=3@d0100J6QX09BDU02DU9@0/;2`203@d=004038b<P0^;Rh0;Rh^02l_;`80=SHf00@0
=3@d034a<@0a<C40=3@d0P0U9BD302<S8`0402PX:00c<c<0<c<c02PX:08051@D00@02@T900X:2P0:
2PX03Ph>0P0G5aL0100F5QH020P800P820051@D200T92@0400D51@020P800P8200`<30803@d=00@0
0@4100@4100410@03`l?0P0M7Ad0100F5QH06ATI01TI6@0Z:RX2030`<00403`l?01<C4`0C4a<04M7
A`80EEEE00@0LG5a06MWI`1WIfL0C4a<0P0^;Rh0100Q8B40:BTY02TY:@0`<30203De=@04038b<P0h
>3P0>3Ph03Hf=P809RHV00@0;bl_038b<P0b<S80<C4a0P0[:b/0100d=3@0=cLg03Lg=`0b<S8203lo
?`0404Y:BP0i>CT0>CTi034a<@80=SHf00@0;Rh^02`/;00/;2`0>c/k0P1;Bd/0101<C4`0@D510451
@@19BDT205=CD`0404Q8B01:BTX0BTY:0410@080<S8b00@0<c<c0492@P12@T80@4100P0S8b<0100C
4a<071`L01`L700J6QX201@D500401<C4`0P8200820P01XJ6P8020P800@02`/;010@400@41003Ph>
0`0:2PX201<C4`0402l_;`0i>CT0>CTi024Q8@80:2PX00@08R8R01PH600H61P05ADE0P0D51@0100A
4A405aLG01LG5`0J6QX2018B4P04010@400L71`071`L01dM7@805aLG00@06QXJ01TI6@0I6AT04Q8B
0P0>3Ph0100D51@04Q8B018B4P0@410201XJ6P0401`L700H61P061PH01TI6@8030`<00@00@4101`L
700L71`0>CTi0P0j>SX0100W9bL08b<S02<S8`0Q8B42010@400400P8200A4A404A4A02@T9080;Rh^
00@09BDU01hN7P0N7Qh06a/K0`0M7Ad201`L700402`/;00U9BD09BDU02@T9080:b/[00<09bLW02@T
900T92@0100S8b<302h^;P80<30`00<0;2`/02PX:00X:2P00`0T92@0100/;2`0>3Ph03Ph>00i>CT2
03<c<`0403hn?P14A4@0A4A403/k>`80?Shn00@0Bd];04e=C@1=CDd0Cdm?0P1ADE40101BDU80De=C
05=CD`1DE5@305YJFP80D51@00@0F5QH065QH@1QHF40GUiN0P1EEED0101ADE40Fe]K05]KF`1TI6@2
05iNGP0406ATI01^KVh0KVi^06e]K@80Kfm_00@0B4Q803/k>`0k>c/0P8200P2[Zj/0102c/k<0^[Zj
0;Zj^P2h^;P20;no_`040<_;b`38b<P0b<S80;fm_@80bLW900@0b/[:06a/K01/K6`04A4A0P0;2`/1
00T92@400`<30@030`<0000400<30`071`L01`L700H61P800P8200@00@4100820P020P800`<30`05
1@D200820P0400<30`061PH01PH600@41080000000@00`<300L71`071`L01PH60P0:2PX00`010@40
0P8200820P0300@4100400D51@0410@010@400820P801@D500@00@4100P8200820P01@D50P0410@0
10030`<020P800P82000000200D51@0300/;2`061PH01PH600<00P8200<00@4100<30`030`<01003
0`<200/;2`0400d=3@051@D01@D500H61P803@d=0`0<30`0100N7Qh0;2`/02`/;00];Bd202/[:`03
02l_;`0j>SX0>SXj00<0;Rh^0`0_;bl0100[:b/08B4Q024Q8@0[:b/202TY:@0402HV9P0^;Rh0;Rh^
02/[:`806ATI00@010@400820P020P803@d=0P0H61P0100B4Q800`<300<30`051@D200X:2P@01`L7
0P092@T0100;2`/01`L700L71`0G5aL201hN7P0401dM7@0L71`071`L02PX:080;2`/00@0>CTi04e=
C@1=CDd0A4A40P1KFe/0101nOWh0IfMW06MWI`1<C4`20410@00402`/;00V9RH09RHV03<c<`80?Shn
00@0>CTi03Xj>P0j>SX0;Rh^0`0Q8B4202/[:`0403Ti>@0];Bd0;Bd]02h^;P80<C4a00@0@D510410
@010@400@d=30P0o?cl0100`<300;bl_02l_;`0j>SX20410@00403`l?018B4P0B4Q805QHF080ATI6
00@0CDe=05eMG@1MGEd0A4A40P12@T80100f=SH0=CDe03De=@0k>c/204M7A`0403lo?`0f=SH0=SHf
02`/;0806QXJ00<0410@01lO7`0O7al00`0N7Qh0100M7Ad061PH01PH600Q8B4202<S8`0401TI6@0@
4100410@00d=3@806ATI0`0g=cL0100T92@0;2`/02`/;00O7al202<S8`04024Q8@0I6AT06ATI01HF
5P805aLG00@06a/K01LG5`0G5aL05ADE0P0M7Ad00`0L71`05QHF01HF5P0301XJ6P0400l?3`0@4100
410@01XJ6P8071`L00@07AdM01hN7P0N7Qh071`L0P0H61P0100C4a<0410@010@400=3@d200H61P04
01dM7@0`<300<30`02XZ:P8092@T00@08R8R01`L700L71`0410@0P0;2`/0100G5aL07QhN01hN7P0J
6QX201@D5004010@400H61P061PH01`L708092@T00<0:BTY02LW9`0W9bL00`0[:b/301lO7`0402<S
8`0P8200820P02DU9@80<30`00@0;Rh^02`/;00/;2`08R8R0P0P8200100X:2P09RHV02HV9P0[:b/2
03dm?@0403Ti>@0c<c<0<c<c03hn?P80@41000@0>c/k03hn?P0n?Sh0ATI60P18B4P01014A4@0BTY:
04Y:BP1?Cdl2059BDP0404a<C01@D500D51@05MGE`80ATI600@0CDe=05IFEP1FEUH0De=C0P1;Bd/0
1018B4P0BDU904U9B@1FEUH2065QH@0406IVIP1/K6`0K6a/06=SH`80I6AT00@0@T9204m?C`1?Cdl0
TY:B0P2SXj<0102XZ:P0`<300<30`02n_[h20;fm_@<0alO700@0`L710=3@d03@d=00_[jn0P1ADE40
100:2PX03@d=00d=3@092@T200@4100000@00`<300P8200820P01PH60`051@D200<30`0400T92@06
1PH01PH600/;2`8030`<00@010@400820P020P8000000P030`<010010@4010@400@410030`<200X:
2P0300<30`092@T02@T900<020P800@0000000H61P061PH010@40P051@D010030`<01`L700L71`03
0`<200H61P0400L71`0410@010@400@410800P8200@0000000D51@051@D020P80P051@D010020P80
10@400@410051@D200H61P0400820P030`<00`<300P820802@T900@02PX:00L71`071`L01PH60P0<
30`0100L71`0<C4a034a<@0e=CD302h^;P80;Bd]00@0:RXZ02d];@0];Bd092@T0P0V9RH0100S8b<0
8B4Q024Q8@0a<C4202XZ:P04024Q8@0V9RH09RHV02@T90805aLG00@01@D500H61P061PH02@T90P0B
4Q80100A4A400@4100410@030`<200L71`0400/;2`0:2PX02PX:00<30`800@4100@00P8200@41004
10@0410@0P0I6AT0100M7Ad06QXJ01XJ6P0P820202/[:`0403Ti>@18B4P0B4Q80492@P80JVYZ00@0
T92@06UYJ@1YJFT0ATI60P11@D40100_;bl0820P020P800X:2P203Lg=`04038b<P0];Bd0;Bd]02d]
;@80=CDe00@0820P024Q8@0Q8B40=cLg0P0/;2`0100X:2P0=3@d03@d=011@D4203Ph>00403Xj>P14
A4@0A4A40410@080>c/k00@0@D5104a<C01<C4`0C4a<0`1>CTh20410@00404U9B@1@D500D51@0492
@P80D51@00@0A4A40492@P12@T80>c/k0P10@400100l?3`0=CDe03De=@0^;Rh201DE5@0400/;2`0I
6AT06ATI01LG5`8061PH00@0820P024Q8@0Q8B4071`L0P0G5aL0100M7Ad06ATI01TI6@0@410201/K
6`0402h^;P0j>SX0>SXj03Ti>@809bLW00@07alO02XZ:P0Z:RX0:BTY0P0T92@00`0R8R80820P020P
800301XJ6P0401PH600G5aL05aLG020P80807alO00@05QHF018B4P0B4Q804A4A0`0D51@201dM7@04
030`<00Z:RX0:RXZ02@T90805ADE00@02@T9024Q8@0Q8B407alO0P0820P0100B4Q808R8R028R8P0S
8b<201lO7`0401DE5@0C4a<04a<C01TI6@8051@D00@04Q8B01/K6`0K6a/071`L0P0E5AD0100D51@0
6QXJ01XJ6P0L71`2024Q8@04028R8P0V9RH09RHV02/[:`80:2PX00@08R8R020P800P82007alO0P0R
8R80100];Bd0<C4a034a<@0W9bL202HV9P0402@T900U9BD09BDU02XZ:P8092@T00@0:2PX03<c<`0c
<c<0;bl_0P0i>CT01015ADD0>SXj03Xj>P0c<c<203Ti>@030410@015ADD0ADE500<0@41000@0ADE5
0410@010@400>CTi0P17AdL0101;Bd/0@4100410@014A4@20492@P0404=3@`18B4P0B4Q804m?C`80
A4A400@0@d=305eMG@1MGEd0G5aL0P1TI6@0101PH600DE5A055AD@0e=CD205iNGP0409JFUP2QXJ40
XJ6Q0:j^[P80`<3000@0^k^k0;Vi^@2i^KT0d=3@0P3Hf=P0103?cll0bl_;0<_;b`2e]KD2065QH@04
01hN7P0D51@051@D00P820800000000010030`<020P800P820061PH300D51@800`<300@02@T900H6
1P061PH02`/;0P0<30`0100410@00P8200820P00000200<30`0400410@0410@010@400<30`802PX:
00<00`<300T92@092@T00`0820P0100000001PH600H61P0410@200D51@0400<30`071`L01`L700<3
0`801PH600@01`L700@4100410@010@40P020P80100000001@D500D51@0820P200D51@0400820P04
10@010@400D51@801PH600@00P8200<30`030`<020P80P092@T0100:2PX01`L700L71`061PH200`<
300401`L700a<C40<C4a03De=@<0;Rh^0P0];Bd0100Z:RX0;Bd]02d];@0T92@202HV9P0402<S8`0Q
8B408B4Q034a<@80:RXZ00@08B4Q02HV9P0V9RH092@T0P0G5aL010051@D01PH600H61P092@T2018B
4P04014A4@010@400@4100<30`801`L700@02`/;00X:2P0:2PX00`<30P010@4010020P8010@400@4
100@410201TI6@0401dM7@0J6QX06QXJ020P8080:b/[00@0>CTi04Q8B018B4P0@T920P1ZJVX0102@
T900JFUY06UYJ@16ATH20451@@0402l_;`0P8200820P02PX:080=cLg00@0<S8b02d];@0];Bd0;Bd]
0P0e=CD0100P82008B4Q024Q8@0g=cL202`/;00402PX:00d=3@0=3@d0451@@80>3Ph00@0>SXj04A4
A014A4@0@4100P0k>c/01011@D40C4a<04a<C01<C4`304i>CP80@41000@0BDU9051@D01@D500@T92
0P1@D5001014A4@0@T920492@P0k>c/20410@00403`l?00e=CD0=CDe02h^;P805ADE00@02`/;01TI
6@0I6AT05aLG0P0H61P0100P82008B4Q024Q8@0L71`201LG5`0401dM7@0I6AT06ATI010@40806a/K
00@0;Rh^03Xj>P0j>SX0>CTi0P0W9bL0100O7al0:RXZ02XZ:P0Y:BT202@T9003028R8P0P8200820P
00<06QXJ00@061PH01LG5`0G5aL0820P0P0O7al0100F5QH04Q8B018B4P0A4A4301@D50807AdM00@0
<30`02XZ:P0Z:RX092@T0P0E5AD010092@T08B4Q024Q8@0O7al200P82004018B4P0R8R808R8R02<S
8`807alO00@05ADE01<C4`0C4a<06ATI0P0D51@0100B4Q806a/K01/K6`0L71`201DE5@0401@D500J
6QX06QXJ01`L70808B4Q00@08R8R02HV9P0V9RH0:b/[0P0X:2P0100R8R80820P020P800O7al2028R
8P0402d];@0a<C40<C4a02LW9`809RHV00@092@T02DU9@0U9BD0:RXZ0P0T92@0100X:2P0<c<c03<c
<`0_;bl203Ti>@0404E5A@0j>SX0>SXj03<c<`80>CTi00<0@41004E5A@15ADD00`10@4001015ADD0
@4100410@00i>CT204M7A`0404];B`10@400@41004A4A080@T9200@0@d=304Q8B018B4P0Cdm?0P14
A4@01013@d<0GEeM05eMG@1LG5`206ATI004061PH01ADE40DE5A03De=@80GUiN00@0UYJF0:6QX@2Q
XJ40[Zj^0P30`<00102k^k/0^KVi0;Vi^@3@d=020=SHf0040<o?c`3;bl/0bl_;0;Fe]@80HF5Q00@0
7QhN01@D500D51@020P80P000000000400<30`010@400@4100<30`801PH600@01@D500820P020P80
0@410`061PH200<30`0400820P030`<00`<300<30`<01@D50P0410@010030`<030`<00`<30061PH2
00D51@04000000010@400@4100D51@8020P800@02`/;00820P020P801`L70`0:2PX200L71`0400@4
100:2PX02PX:00@410800@4100@010@400820P020P8000000P020P8010030`<02PX:00X:2P0;2`/2
00@4100400<30`020P800P8200820P801PH60`0410@010051@D03Ph>00h>3P0G5aL201hN7P0402/[
:`0Y:BT0:BTY02/[:`809RHV00@08R8R02<S8`0S8b<05QHF0P0Q8B40100V9RH0820P020P800[:b/2
02DU9@0401dM7@0R8R808R8R02PX:08061PH00@02@T900@4100410@00`<30P0?3`l0100C4a<01`L7
00L71`020P820000000400@410071`L01`L700L71`8010@400@00`<300T92@092@T020P80P0M7Ad0
100L71`0410@010@400O7al202h^;P0403Ph>00k>c/0>c/k03Lg=`80H61P00@0Ph>305UIF@1IFET0
<c<c0P0j>SX0100e=CD08R8R028R8P0O7al202TY:@<09RHV00@0;Rh^03@d=00d=3@0820P0P0T92@3
02XZ:P0402/[:`0e=CD0=CDe03De=@80<30`00@0=SHf03Lg=`0g=cL0?Cdm0P0j>SX01011@D40ATI6
04I6AP11@D4204Y:BP0404e=C@19BDT0BDU904];B`80@41000@0A4A404];B`1;Bd/0?Cdm0P0o?cl0
100n?Sh0@d=304=3@`11@D4202h^;P0402<S8`0O7al07alO01LG5`804A4A00@071`L02<S8`0S8b<0
7AdM0P0J6QX0100L71`07AdM01dM7@0J6QX2010@400401DE5@0/;2`0;2`/030`<080?3`l00@0@T92
02/[:`0[:b/0<30`0P0/;2`0100Z:RX0<C4a034a<@0a<C4202d];@0401XJ6P0F5QH05QHF01TI6@80
4a<C00@061PH024Q8@0Q8B407AdM0P0J6QX0100K6a/061PH01PH600D51@201XJ6P0402d];@0Y:BT0
:BTY02`/;0805QHF00@08B4Q02d];@0];Bd0:RXZ0P0O7al010020P805QHF01HF5P0N7Qh2018B4P04
010@400A4A404A4A010@408020P800@02PX:018B4P0B4Q805aLG0P0E5AD0100C4a<07AdM01dM7@0V
9RH202LW9`0402DU9@0P8200820P02<S8`808B4Q00@0:2PX02DU9@0U9BD0820P0P0O7al0100U9BD0
;bl_02l_;`0W9bL202HV9P0402DU9@0W9bL09bLW02TY:@808B4Q00@092@T02TY:@0Y:BT0;Rh^0P0h
>3P0100m?Cd0=3@d03@d=00^;Rh203`l?0<0C4a<00@0@T9203hn?P0n?Sh0@D510P10@4001011@D40
CDe=04e=C@16ATH203lo?`0404I6AP1;Bd/0Bd];04e=C@80CTi>00@0EEEE05iNGP1NGUh0BTY:0P1D
E5@0101FEUH0Hf=S06=SH`1SHf<2059BDP0403`l?01VIVH0IVIV096AT@80Zj^[00@0_Kfm0<W9b@39
bLT0c<c<0P32`/80103>c/h0aLG50<G5a@38b<P20;Jf]P040::RXP1aLG40LG5a02`/;0803`l?0@0<
30`100D51@401@D5000010051@D02@T900T92@051@D200P820<010@400<01PH600D51@051@D00`02
0P80100820P010@400@4100820P200820P0300D51@092@T02@T900<010@400@02`/;00T92@092@T0
0P820P0410@0100000001PH600H61P071`L200T92@0400D51@000000000000410@801`L700@010@4
00<30`030`<00`<30P0820P010092@T010@400@410061PH200D51@0400820P0410@010@400T92@80
1PH600@00@4100<30`030`<020P80P0<30`0100:2PX030`<00`<300=3@d200@4100401@D500M7Ad0
7AdM02<S8`808B4Q00@0:b/[02XZ:P0Z:RX07alO0P0L71`0100A4A408R8R028R8P0Q8B4201dM7@04
02@T900L71`071`L01TI6@808b<S00@09RHV01DE5@0E5AD01@D50P0410@010061PH020P800P8200=
3@d200X:2P0400410@000000000000820P802PX:1P051@D010020P80410@010@400A4A4201<C4`04
01XJ6P0L71`071`L02h^;P80@d=300@0@D5105aLG01LG5`0Ng]k0P1MGEd303<c<`0403De=@0P8200
820P01@D50807QhN00@0:2PX030`<00`<300;bl_0P0Z:RX0100G5aL0;Rh^02h^;P0_;bl202d];@04
02XZ:P0_;bl0;bl_03dm?@80>3Ph00@0<C4a02h^;P0^;Rh0@D510P0h>3P0100g=cL0AdM704M7A`15
ADD204I6AP0403dm?@0a<C40<C4a03dm?@80?3`l00@0ADE504I6AP16ATH0@T920P18B4P01012@T80
>3Ph03Ph>014A4@2030`<00401XJ6P0U9BD09BDU02LW9`805QHF00@07alO02DU9@0U9BD08b<S0P0O
7al0100I6AT0820P020P800G5aL200L71`0401/K6`0X:2P0:2PX02@T9080<c<c00@0@d=3038b<P0b
<S80;Rh^0P0];Bd0100Y:BT0=3@d03@d=00c<c<2030`<00401lO7`0F5QH05QHF01`L70807QhN00@0
6ATI01HF5P0F5QH06QXJ0P0M7Ad0100H61P05ADE01DE5@0I6AT202<S8`0402XZ:P0];Bd0;Bd]02TY
:@807alO00@0;bl_01lO7`0O7al0:BTY0P0/;2`0100;2`/05QHF01HF5P0O7al200h>3P04018B4P06
1PH01PH600X:2P802`/;00@02@T900h>3P0>3Ph051@D0P0C4a<0100D51@08B4Q024Q8@0S8b<202DU
9@0402HV9P0R8R808R8R02@T9080820P00@0:BTY02HV9P0V9RH0:2PX0P0S8b<0100P8200:2PX02PX
:00^;Rh202l_;`<092@T00@0;2`/02@T900T92@08R8R0P0W9bL0100`<300;bl_02l_;`0^;Rh2038b
<P0403De=@0n?Sh0?Shn04E5A@80A4A400@0@41003/k>`0k>c/0?Cdm0P11@D401013@d<0ADE504E5
A@18B4P204Y:BP0404e=C@1GEeL0EeMG05UIF@80E5AD00@0GUiN07EeM@1eMGD0HF5Q0P1@D500101?
Cdl0FUYJ05YJFP1RHV8205QHF0040410@01eMGD0MGEe09ZJVP80YjNW00@0`<300=;BdP3Bd]80c/k>
0P37alL0103GemL0]kNg0;Ng]`2e]KD20:f][@040:>SX`1eMGD0MGEe02HV9P800`<30@0=3@d100L7
1`401`L7000010051@D02@T900T92@051@D200P820<010@400<01PH600D51@051@D00`020P801008
20P010@400@4100820P200820P0300D51@092@T02@T900<010@400@02`/;00T92@092@T00P820P04
10@0100000001PH600H61P071`L200T92@0400D51@000000000000410@801`L700@010@400<30`03
0`<00`<30P0820P010092@T010@400@410061PH200D51@0400820P0410@010@400T92@801PH600@0
0@4100<30`030`<020P80P0<30`0100:2PX030`<00`<300=3@d200@4100401@D500M7Ad07AdM02<S
8`808B4Q00@0:b/[02XZ:P0Z:RX07alO0P0L71`0100A4A408R8R028R8P0Q8B4201dM7@0402@T900L
71`071`L01TI6@808b<S00@09RHV01DE5@0E5AD01@D50P0410@010061PH020P800P8200=3@d200X:
2P0400410@000000000000820P802PX:1P051@D010020P80410@010@400A4A4201<C4`0401XJ6P0L
71`071`L02h^;P80@d=300@0@D5105aLG01LG5`0Ng]k0P1MGEd303<c<`0403De=@0P8200820P01@D
50807QhN00@0:2PX030`<00`<300;bl_0P0Z:RX0100G5aL0;Rh^02h^;P0_;bl202d];@0402XZ:P0_
;bl0;bl_03dm?@80>3Ph00@0<C4a02h^;P0^;Rh0@D510P0h>3P0100g=cL0AdM704M7A`15ADD204I6
AP0403dm?@0a<C40<C4a03dm?@80?3`l00@0ADE504I6AP16ATH0@T920P18B4P01012@T80>3Ph03Ph
>014A4@2030`<00401XJ6P0U9BD09BDU02LW9`805QHF00@07alO02DU9@0U9BD08b<S0P0O7al0100I
6AT0820P020P800G5aL200L71`0401/K6`0X:2P0:2PX02@T9080<c<c00@0@d=3038b<P0b<S80;Rh^
0P0];Bd0100Y:BT0=3@d03@d=00c<c<2030`<00401lO7`0F5QH05QHF01`L70807QhN00@06ATI01HF
5P0F5QH06QXJ0P0M7Ad0100H61P05ADE01DE5@0I6AT202<S8`0402XZ:P0];Bd0;Bd]02TY:@807alO
00@0;bl_01lO7`0O7al0:BTY0P0/;2`0100;2`/05QHF01HF5P0O7al200h>3P04018B4P061PH01PH6
00X:2P802`/;00@02@T900h>3P0>3Ph051@D0P0C4a<0100D51@08B4Q024Q8@0S8b<202DU9@0402HV
9P0R8R808R8R02@T9080820P00@0:BTY02HV9P0V9RH0:2PX0P0S8b<0100P8200:2PX02PX:00^;Rh2
02l_;`<092@T00@0;2`/02@T900T92@08R8R0P0W9bL0100`<300;bl_02l_;`0^;Rh2038b<P0403De
=@0n?Sh0?Shn04E5A@80A4A400@0@41003/k>`0k>c/0?Cdm0P11@D401013@d<0ADE504E5A@18B4P2
04Y:BP0404e=C@1GEeL0EeMG05UIF@80E5AD00@0GUiN07EeM@1eMGD0HF5Q0P1@D500101?Cdl0FUYJ
05YJFP1RHV8205QHF0040410@01eMGD0MGEe09ZJVP80YjNW00@0`<300=;BdP3Bd]80c/k>0P37alL0
103GemL0]kNg0;Ng]`2e]KD20:f][@040:>SX`1eMGD0MGEe02HV9P800`<30@0=3@d100L71`401`L7
000010010@401PH600H61P071`L200D51@0400X:2P0820P020P800T92@8010@400@00P8200H61P06
1PH01@D50P0410@0100;2`/02PX:00X:2P010@4500H61P0400L71`000000000000<30`801PH600@0
000000@4100410@02PX:0P071`L010030`<010@400@410061PH200X:2P0400D51@000000000000H6
1P801`L700@01PH600L71`071`L01PH60P051@D0100410@01`L700L71`0820P200L71`0400D51@04
10@010@400H61P800`<300@030`<01DE5@0E5AD04A4A0P0:2PX0100K6a/07AdM01dM7@0K6a/201lO
7`0402DU9@0Q8B408B4Q01/K6`807AdM00@051@D020P800P82005aLG0P0C4a<0100P82007AdM01dM
7@0I6AT201dM7@0401/K6`0G5aL05aLG00d=3@800P8200@01`L7010@400@41004A4A0P092@T30000
000400410@0410@010@400D51@801PH600@01@D500410@010@401PH60P0?3`l0100E5AD071`L01`L
700E5AD201`L700403Hf=P14A4@0A4A404M7A`80H61P00@0Lg=c05eMG@1MGEd0>c/k0P0Y:BT0100T
92@061PH01PH600@410201hN7P0402TY:@0^;Rh0;Rh^03<c<`80<30`00@08B4Q02d];@0];Bd0<S8b
0P0];Bd0100V9RH0>3Ph03Ph>01<C4`203`l?00403Ti>@0g=cL0=cLg04U9B@80AdM700@0BDU9061P
H01PH600HV9R0P1BDU80100i>CT0;Rh^02h^;P1@D502061PH00405EEE@1IFET0FEUI05mOG`80De=C
00@0?Shn02PX:00X:2P0@4100P0a<C40100R8R80;Bd]02d];@0d=3@202h^;P0403Ph>00f=SH0=SHf
038b<P809bLW00@051@D01dM7@0M7Ad0820P0P0H61P0100R8R808B4Q024Q8@0W9bL202l_;`0404U9
B@0n?Sh0?Shn020P8080;2`/00@0;Rh^03Xj>P0j>SX0>c/k0P0`<3000`0W9bL092@T02@T900301PH
600401lO7`0M7Ad07AdM020P80808b<S00@061PH01@D500D51@0820P0P0Y:BT0100/;2`0<C4a034a
<@0W9bL3014A4@804Q8B00@09RHV03Hf=P0f=SH0;2`/0P0P8200100C4a<02`/;00/;2`061PH20000
000400T92@0@4100410@00X:2P803@d=00@0410@014A4@0A4A407AdM0P0S8b<0100T92@0;bl_02l_
;`0a<C4202TY:@0302HV9P0W9bL09bLW00<0<30`00@0;Rh^02DU9@0U9BD0:2PX0P0];Bd0100X:2P0
92@T02@T900X:2P202HV9P0402TY:@0];Bd0;Bd]02PX:080:b/[00@0;bl_02h^;P0^;Rh0<C4a0`0e
=CD203Lg=`0403Ph>00g=cL0=cLg03Xj>P80?Shn00@0@d=304I6AP16ATH0@D510P10@400101;Bd/0
DE5A055AD@18B4P204U9B@0404i>CP19BDT0BDU905=CD`80MGEe00@0HV9R05EEE@1EEED0DU9B0P1A
DE40101MGEd0F5QH05QHF015ADD207moO`040:6QX@2`/;00/;2`0<K6aP80cLg=00@0a<C40<S8b038
b<P0f=SH0P2l_;`0102^[Zh0^;Rh0;Rh^02e]KD206m_K`0402@T900820P020P800H61P800P820000
10051@D000000000000410@200H61P0400820P071`L01`L700T92@80000000@01@D5000000000000
0P820P061PH0100410@00000000000051@D200L71`0400<30`020P800P8200@410800P8200@01@D5
00410@010@4000000P0410@010051@D00`<300<30`020P8500<30`0400820P000000000000H61P80
1`L70`030`<010051@D02PX:00X:2P0820P200820P<00`<300@01PH600X:2P0:2PX02PX:0P020P80
10071`L03@d=00d=3@0<30`200D51@04018B4P0T92@092@T02HV9P8071`L00@05ADE01LG5`0G5aL0
6a/K0P0Q8B40100F5QH051@D01@D500D51@200h>3P0401TI6@0O7al07alO01/K6`8061PH00@06ATI
01XJ6P0J6QX03@d=0P00000010051@D03@d=00d=3@092@T300D51@8010@400<01`L700@4100410@0
100410@200<30`0300820P0>3Ph03Ph>00<05ADE00@03Ph>028R8P0R8R80=cLg0P0e=CD0101BDU80
MWIf07IfMP1VIVH204Y:BP0403lo?`0[:b/0:b/[01`L70806a/K00@071`L01dM7@0M7Ad07alO0P0U
9BD0100b<S80<30`030`<00E5AD2024Q8@0403Xj>P0h>3P0>3Ph02PX:080?3`l00@0Bd];02d];@0]
;Bd0@D510P1;Bd/01010@400B4Q804Q8B01IFET2069RHP0405iNGP1LG5`0G5aL05eMG@80Fe]K00@0
IfMW06m_K`1_Kfl0IfMW0P1YJFT0101ZJVX0I6AT06ATI01SHf<205MGE`0405UIF@16ATH0ATI603Xj
>P80>3Ph00@0<c<c01lO7`0O7al0<S8b0P0k>c/0100X:2P06ATI01TI6@0G5aL201XJ6P0400l?3`08
20P020P8018B4P805QHF00@07alO02h^;P0^;Rh0C4a<0P1DE5@0100i>CT0?Shn03hn?P0m?Cd20451
@@0404i>CP10@400@410030`<080<S8b00@09bLW02HV9P0V9RH0:2PX0P0U9BD0100V9RH08b<S02<S
8`0M7Ad2028R8P0402PX:00Y:BT0:BTY02l_;`80;Rh^00@0:RXZ01/K6`0K6a/07AdM0P0Z:RX0100[
:b/0:BTY02TY:@0Q8B4201hN7P0401/K6`0F5QH05QHF00d=3@800P8200@020P8014A4@0A4A402`/;
0P0=3@d300X:2P0401TI6@0Q8B408B4Q02HV9P<0<30`0`0X:2P202LW9`0402XZ:P0_;bl0;bl_030`
<080<C4a00@0>SXj03Ti>@0i>CT0:RXZ0P0T92@0100d=3@0;Rh^02h^;P0Y:BT2030`<00402l_;`0^
;Rh0;Rh^02XZ:P80:b/[0`0^;Rh0100Y:BT0<S8b038b<P0m?Cd203Xj>P0403Lg=`0o?cl0?clo04A4
A080@T9200@0ADE504Y:BP1:BTX0D51@0P1>CTh01015ADD0ATI604I6AP1<C4`204Y:BP0404];B`1F
EUH0EUIF04M7A`80De=C00@0DU9B04];B`1;Bd/0D51@0P16ATH0101<C4`0PH610861P@2PX:020;bl
_0040<C4a037alL0alO70<g=c@80d=3@00@0alO70<30`030`<00_[jn0P2d];@0102_[jl0J6QX06QX
J00N7Qh200/;2`4020P80@071`L100L71`0000@01@D500000000000010@40P061PH010020P801`L7
00L71`092@T20000000400D51@000000000000820P801PH600@010@40000000000001@D50P071`L0
10030`<00P8200820P0410@200820P0400D51@010@400@410000008010@400@01@D500<30`030`<0
0P821@030`<010020P800000000000061PH200L71`<00`<300@01@D500X:2P0:2PX020P80P020P83
00<30`0400H61P0:2PX02PX:00X:2P800P8200@01`L700d=3@0=3@d030`<0P051@D0100B4Q8092@T
02@T900V9RH201`L700401DE5@0G5aL05aLG01/K6`808B4Q00@05QHF01@D500D51@051@D0P0>3Ph0
100I6AT07alO01lO7`0K6a/201PH600401TI6@0J6QX06QXJ00d=3@80000000@01@D500d=3@0=3@d0
2@T90`051@D200@4100300L71`0410@010@400@010@40P030`<00`020P803Ph>00h>3P0301DE5@04
00h>3P0R8R808R8R03Lg=`80=CDe00@0DU9B07IfMP1fMWH0IVIV0P1:BTX0100o?cl0:b/[02/[:`0L
71`201/K6`0401`L700M7Ad07AdM01lO7`809BDU00@0<S8b030`<00`<3005ADE0P0Q8B40100j>SX0
>3Ph03Ph>00X:2P203`l?00404];B`0];Bd0;Bd]0451@@80Bd];00@0@41004Q8B018B4P0FEUI0P1R
HV80101NGUh0G5aL05aLG01MGEd205]KF`0406MWI`1_Kfl0Kfm_06MWI`80JFUY00@0JVYZ06ATI01T
I6@0Hf=S0P1GEeL0101IFET0ATI604I6AP0j>SX203Ph>00403<c<`0O7al07alO038b<P80>c/k00@0
:2PX01TI6@0I6AT05aLG0P0J6QX0100?3`l020P800P8200B4Q8201HF5P0401lO7`0^;Rh0;Rh^04a<
C080E5AD00@0>CTi03hn?P0n?Sh0?Cdm0P11@D40101>CTh0@4100410@00`<302038b<P0402LW9`0V
9RH09RHV02PX:0809BDU00@09RHV02<S8`0S8b<07AdM0P0R8R80100X:2P0:BTY02TY:@0_;bl202h^
;P0402XZ:P0K6a/06a/K01dM7@80:RXZ00@0:b/[02TY:@0Y:BT08B4Q0P0N7Qh0100K6a/05QHF01HF
5P0=3@d200820P0400P8200A4A404A4A00/;2`803@d=0`0:2PX0100I6AT08B4Q024Q8@0V9RH3030`
<0<0:2PX0P0W9bL0100Z:RX0;bl_02l_;`0`<302034a<@0403Xj>P0i>CT0>CTi02XZ:P8092@T00@0
=3@d02h^;P0^;Rh0:BTY0P0`<300100_;bl0;Rh^02h^;P0Z:RX202/[:`<0;Rh^00@0:BTY038b<P0b
<S80?Cdm0P0j>SX0100g=cL0?clo03lo?`14A4@20492@P0404E5A@1:BTX0BTY:051@D080CTi>00@0
ADE504I6AP16ATH0C4a<0P1:BTX0101;Bd/0EUIF05IFEP17AdL205=CD`04059BDP1;Bd/0Bd];051@
D080ATI600@0C4a<0861P@21PH40X:2P0P2l_;`01034a<@0alO70<O7a`3=cLd20=3@d0040<O7a`30
`<00`<300;jn_P80];Bd00@0[jn_06QXJ01XJ6P07QhN0P0;2`/100P820401`L70@071`L0000400D5
1@030`<00`<300L71`800`<30`0410@010061PH00@4100410@00000200<30`0400P820061PH01PH6
00820P800`<300<010@400H61P061PH010030`<200L71`0400<30`0410@010@400@410800`<300@0
2@T900P8200820P01PH60P00000300H61P0400410@000000000000P820802@T900@010@400H61P06
1PH00`<30P061PH010051@D00@4100410@061PH300D51@801PH60`0820P010061PH02PX:00X:2P09
2@T200@4100400l?3`0E5AD05ADE01lO7`8051@D00@06ATI01hN7P0N7Qh061PH0P0N7Qh0100M7Ad0
6ATI01TI6@0O7al201hN7P0401/K6`0I6AT06ATI01LG5`806QXJ00@07alO01`L700L71`03@d=0P02
0P8010051@D01`L700L71`061PH200L71`0400D51@071`L01`L700/;2`8010@40`051@D010010@40
0`<300<30`071`L2014A4@0401<C4`0?3`l03`l?00`<30807alO00@0<c<c03@d=00d=3@0F5QH0P1n
OWh0101^KVh0Bd];04];B`0d=3@2020P800401DE5@0D51@051@D01LG5`805QHF00@06QXJ020P800P
8200:BTY0P0X:2P0100I6AT0:RXZ02XZ:P0k>c/20410@004024Q8@0S8b<08b<S04Y:BP80?Cdm00@0
E5AD05mOG`1OGel0@d=30P11@D40101KFe/0EEEE05EEE@0i>CT204A4A004061PH01FEUH0EUIF04E5
A@80C4a<0`1fMWH0101VIVH0J6QX06QXJ01[Jf/205mOG`0405YJFP16ATH0ATI603/k>`80?3`l00@0
>3Ph03<c<`0c<c<0?Shn0P0f=SH0100L71`03Ph>00h>3P0A4A4201hN7P0401/K6`0?3`l03`l?00h>
3P804a<C00@071`L03De=@0e=CD0?clo0P1:BTX01018B4P0DE5A055AD@1ADE4204a<C00405MGE`1>
CTh0CTi>03`l?080=SHf00@0:BTY034a<@0a<C40=SHf0P0[:b/0100U9BD0820P020P800R8R82034a
<@04030`<00V9RH09RHV034a<@80=3@d00@0:b/[03Ph>00h>3P0BTY:0P0o?cl0100Q8B4030`<00`<
300;2`/2018B4P<07AdM00@07QhN01<C4`0C4a<02`/;0P0<30`0100410@030`<00`<300?3`l200P8
200401LG5`0a<C40<C4a03Ph>080<C4a00@09bLW020P800P82009RHV0`0[:b/202h^;P0402l_;`0b
<S80<S8b03Lg=`80<30`0`0X:2P0100b<S80;bl_02l_;`0Y:BT202d];@04038b<P0Z:RX0:RXZ02@T
9080;2`/00@0:RXZ02`/;00/;2`0:RXZ0P0^;Rh00`0k>c/0@4100410@00303dm?@0403/k>`0f=SH0
=SHf03hn?P80BDU900@0Cdm?04e=C@1=CDd0B4Q80P17AdL0101@D500DU9B059BDP18B4P203dm?@03
038b<P19BDT0BDU900@0Cdm?0P10@400101ADE40QXJ608J6QP2TY:@20;fm_@040<C4a03Cdm<0dm?C
0=OGe`80dM7A00@0bl_;0<;2`P32`/80aLG50P3=cLd0102o_kl0EeMG05MGE`0N7Qh200d=3@400`<3
0@051@D100D51@0000@01`L700X:2P0:2PX01PH60P0410@00`030`<02@T900T92@0300H61P0400@4
10051@D01@D500@410801`L70`051@D010030`<01PH600H61P0820P200L71`0400<30`061PH01PH6
00<30`800P8200@00@4100H61P061PH00@410P030`<400@4108020P800@02@T900<30`030`<010@4
0P071`L0100410@01`L700L71`071`L20000000400820P0410@010@400@410800`<300@010@400D5
1@051@D00`<30P020P8010051@D01PH600H61P061PH200<30`0400d=3@0820P020P801TI6@805ADE
00@05QHF01LG5`0G5aL05QHF0P0I6AT301DE5@0401TI6@0G5aL05aLG014A4@8030`<00@0410@01dM
7@0M7Ad07alO0P0B4Q8010061PH00@4100410@010@4200T92@0400h>3P0410@010@400<30`800P82
0`030`<010020P803@d=00d=3@051@D200/;2`0400L71`0C4a<04a<C01DE5@803`l?00@030`<01lO
7`0O7al0;2`/0P0^;Rh0101>CTh0LG5a075aL@1fMWH205]KF`0402l_;`0E5AD05ADE00h>3P802PX:
00@03`l?014A4@0A4A406QXJ0P0M7Ad0100U9BD0;Rh^02h^;P0Z:RX203De=@0402PX:00^;Rh0;Rh^
02DU9@80:2PX00@0CDe=03lo?`0o?cl0>CTi0P17AdL0101MGEd0G5aL05aLG01PH60205eMG@040451
@@18B4P0B4Q805]KF`80EEEE00@0DE5A05MGE`1GEeL0OGem0P1lO7`0101kNg/0MWIf07IfMP1TI6@2
04i>CP0404a<C013@d<0@d=304A4A080ATI600@0?3`l03Hf=P0f=SH0?3`l0P0k>c/0100`<300:2PX
02PX:00W9bL302`/;0807alO00@05aLG02<S8`0S8b<0:RXZ0P0c<c<0100`<300?Shn03hn?P1<C4`2
05MGE`0405ADE01BDU80DU9B05YJFP80FEUI00@0C4a<0410@010@400;Rh^0P0_;bl0100c<c<0;2`/
02`/;00Z:RX202TY:@0402HV9P0_;bl0;bl_03@d=080;Bd]00@0<C4a030`<00`<3009RHV0P1EEED0
101WIfL0:2PX02PX:00K6a/202`/;00403`l?00f=SH0=SHf02/[:`8092@T00@09BDU01TI6@0I6AT0
10@40P0820P0100=3@d030`<00`<30092@T200/;2`04020P800a<C40<C4a03<c<`80=CDe00@0<C4a
02`/;00/;2`0:RXZ0P0X:2P00`0d=3@0<c<c03<c<`0302/[:`0402l_;`0g=cL0=cLg03De=@80:b/[
00@0<S8b02l_;`0_;bl0820P0P0Z:RX0100f=SH0;Rh^02h^;P0/;2`3038b<P80=CDe0`0_;bl0100g
=cL0@T920492@P0o?cl203`l?0<0@D510`10@4001016ATH0CTi>04i>CP1=CDd205ADE00305UIF@1?
Cdl0Cdm?00<0@T9200@0AdM704A4A014A4@0C4a<0P1GEeL0101FEUH0@4100410@01LG5`209RHV004
0:BTY02][Jd0[Jf]0;no_`<0dm?C0P3Bd]80103@d=00a/K60<K6aP36a/H20=WIf@040:JVYP0h>3P0
>3Ph01HF5P8020P80`061PH0000400L71`0:2PX02PX:00H61P8010@400<00`<300T92@092@T00`06
1PH0100410@01@D500D51@0410@200L71`<01@D500@00`<300H61P061PH020P80P071`L010030`<0
1PH600H61P030`<200820P0400410@061PH01PH600410@800`<3100410@200P8200400T92@030`<0
0`<300@410801`L700@010@400L71`071`L01`L70P00000010020P8010@400@4100410@200<30`04
00@410051@D01@D500<30`800P8200@01@D500H61P061PH01PH60P030`<0100=3@d020P800P8200I
6AT201DE5@0401HF5P0G5aL05aLG01HF5P806ATI0`0E5AD0100I6AT05aLG01LG5`0A4A4200`<3004
010@400M7Ad07AdM01lO7`804Q8B00@01PH600410@010@400@410P092@T0100>3Ph010@400@41003
0`<200820P<00`<300@00P8200d=3@0=3@d01@D50P0;2`/010071`L04a<C01<C4`0E5AD200l?3`04
00`<300O7al07alO02`/;080;Rh^00@0CTi>075aL@1aLG40MWIf0P1KFe/0100_;bl05ADE01DE5@0>
3Ph200X:2P0400l?3`0A4A404A4A01XJ6P807AdM00@09BDU02h^;P0^;Rh0:RXZ0P0e=CD0100X:2P0
;Rh^02h^;P0U9BD202PX:00404e=C@0o?cl0?clo03Ti>@80AdM700@0GEeM05aLG01LG5`0H61P0P1M
GEd01011@D40B4Q804Q8B01KFe/205EEE@04055AD@1GEeL0EeMG07emO@80O7al00@0Ng]k07IfMP1f
MWH0I6AT0P1>CTh0101<C4`0@d=304=3@`14A4@204I6AP0403`l?00f=SH0=SHf03`l?080>c/k00@0
<30`02PX:00X:2P09bLW0`0/;2`201lO7`0401LG5`0S8b<08b<S02XZ:P80<c<c00@0<30`03hn?P0n
?Sh0C4a<0P1GEeL0101DE5@0DU9B059BDP1JFUX205UIF@0404a<C010@400@41002h^;P80;bl_00@0
<c<c02`/;00/;2`0:RXZ0P0Y:BT0100V9RH0;bl_02l_;`0d=3@202d];@04034a<@0`<300<30`02HV
9P80EEEE00@0IfMW02PX:00X:2P06a/K0P0/;2`0100l?3`0=SHf03Hf=P0[:b/202@T900402DU9@0I
6AT06ATI00@4108020P800@03@d=00`<300<30`02@T90P0;2`/0100P8200<C4a034a<@0c<c<203De
=@04034a<@0/;2`0;2`/02XZ:P80:2PX00<0=3@d03<c<`0c<c<00`0[:b/0100_;bl0=cLg03Lg=`0e
=CD202/[:`04038b<P0_;bl0;bl_020P8080:RXZ00@0=SHf02h^;P0^;Rh0;2`/0`0b<S8203De=@<0
;bl_00@0=cLg0492@P12@T80?clo0P0l?3`30451@@<0@41000@0ATI604i>CP1>CTh0CDe=0P1DE5@0
0`1IFET0Cdm?04m?C`030492@P0404M7A`14A4@0A4A404a<C080EeMG00@0EUIF0410@010@400G5aL
0P2HV9P0102TY:@0[Jf]0:f][@2o_kl30=?Cd`80d];B00@0d=3@0<K6aP36a/H0a/K60P3IfMT0102V
YZH0>3Ph03Ph>00F5QH200P820<01PH6000010051@D03@d=00d=3@0820P200H61P0400@410000000
000000D51@800@4100@010@400D51@051@D00P820`071`L200@4100300X:2P020P800P8200<020P8
00@01`L700D51@051@D01`L70P051@D010010@401PH600H61P061PH200T92@0400d=3@0820P020P8
00L71`801PH600@01@D500T92@092@T01`L71@030`<300L71`H01@D500@0000000L71`071`L01@D5
0`020P8300@4108000000`0@4100100G5aL05QHF01HF5P0B4Q8201@D500401TI6@0L71`071`L014A
4@803@d=00@0410@00h>3P0>3Ph02`/;0P092@T0100A4A406a/K01/K6`0K6a/2018B4P0400P82004
10@010@400D51@8030`<00@051@D00L71`071`L00P820P061PH010030`<020P800P820030`<200P8
200400L71`0820P020P800D51@804a<C00@05ADE00d=3@0=3@d03@d=0P0P8200100a<C40<30`030`
<016ATH206a/K00407]kN`1JFUX0FUYJ02LW9`803Ph>00@01@D500/;2`0;2`/051@D0P0A4A40100H
61P06ATI01TI6@0P8202034a<@0402`/;00h>3P0>3Ph02l_;`80=SHf00@0=CDe03@d=00d=3@0?Cdm
0P0f=SH01010@400Cdm?04m?C`1KFe/2055AD@04069RHP1lO7`0O7al06m_K`<0JVYZ0P1_Kfl0101g
MgL0Hf=S06=SH`1/K6`207QhN00408F5Q@1eMGD0MGEe05ADE080BTY:00@0HF5Q05mOG`1OGel0GUiN
0P1FEUH01010@400>3Ph03Ph>015ADD204m?C`0404E5A@0f=SH0=SHf02h^;P80<S8b00@0<30`01lO
7`0O7al061PH0`0O7al202/[:`0403De=@0m?Cd0?Cdm04a<C0<0GEeM0P1QHF40101/K6`0KFe]06e]
K@1GEeL204E5A@0403Lg=`0];Bd0;Bd]02d];@80:BTY00@0;Bd]038b<P0b<S80:b/[0P0/;2`0100a
<C40:RXZ02XZ:P0_;bl2034a<@0402/[:`1UIFD0IFEU051@D0807QhN00@0B4Q8065QH@1QHF40IFEU
0P1BDU801010@400<c<c03<c<`0V9RH2014A4@0400H61P0820P020P800d=3@8020P800@0000000l?
3`0?3`l0:BTY0P0_;bl0100[:b/0:BTY02TY:@0[:b/203<c<`<0:RXZ00@0?clo03Hf=P0f=SH0:b/[
0P0^;Rh0100_;bl0>c/k03/k>`0i>CT203Hf=P0403dm?@0f=SH0=SHf02XZ:P80;Rh^00@0=cLg02l_
;`0_;bl0<30`0P0h>3P0100k>c/0=CDe03De=@0_;bl203Xj>P0403Ti>@0m?Cd0?Cdm0492@P<0>c/k
0P16ATH01017AdL0?clo03lo?`12@T8304M7A`80CDe=00@0C4a<04M7A`17AdL0?Cdm0P15ADD0101N
GUh0AdM704M7A`12@T8205EEE@0405=CD`11@D40@D5106EUI@80Ti>C00@0T92@09fMW@2MWId0_;bl
0P3:b/X0103@d=00fMWI0=WIf@3:b/X20;Ng]`040<[:bP3=cLd0cLg=07AdM080<c<c00@05QHF00T9
2@092@T02`/;0P051@D0000400H61P0;2`/02`/;00T92@<010@40P010@40100410@00`<300<30`05
1@D200<30`<01`L700@010@400820P020P800@410P061PH010051@D01PH600H61P0820P300<30`80
1PH600@00`<300410@010@401PH60P0820P010051@D00P8200820P061PH200T92@0400@4100820P0
20P800T92@800@4100@0000000<30`030`<020P80P092@T300820P0400@4100;2`/02`/;00000080
0P820`071`L010020P802@T900T92@092@T200820P0400`<300B4Q804Q8B01<C4`803Ph>00@03`l?
014A4@0A4A402`/;0`0B4Q83014A4@803Ph>00@03`l?014A4@0A4A405ADE0P0H61P0100F5QH05ADE
01DE5@0>3Ph200D51@<020P800@030`<00H61P061PH00`<30P010@4300L71`0400@410020P800P82
00<30`801PH600@00`<300l?3`0?3`l03Ph>0P0:2PX0100?3`l08B4Q024Q8@0d=3@203Ph>00404U9
B@1cLg<0Lg=c07UiN@80@D5100@04a<C00d=3@0=3@d01PH60P0>3Ph0100B4Q805aLG01LG5`0Q8B43
01LG5`80<30`00@0;Rh^02/[:`0[:b/0:b/[0`10@40203`l?00404I6AP0m?Cd0?Cdm04Q8B080H61P
00@0FEUI04E5A@15ADD0Lg=c0P2;Rh/0101[Jf/0IFEU06EUI@1GEeL205mOG`0407QhN01QHF40HF5Q
06ATI080OWin00@0Ng]k07EeM@1eMGD0LG5a0P1kNg/0101mOGd0GEeM05eMG@1NGUh205QHF00404M7
A`1:BTX0BTY:04];B`80BTY:00@0CDe=03lo?`0o?cl0;2`/0P0`<3000`0f=SH0:2PX02PX:00401/K
6`80:RXZ00@0<30`03Hf=P0f=SH0BDU90P1MGEd0101WIfL0JVYZ06YZJP1aLG4207alO00406m_K`1M
GEd0GEeM04A4A080;Rh^0`0Z:RX0100`<300=SHf03Hf=P0b<S8203@d=004038b<P0^;Rh0;Rh^03@d
=0809bLW00@0=cLg07=cL`1cLg<0>SXj0P0^;Rh0101]KFd0RHV908V9R@29RHT207IfMP0405QHF00h
>3P0>3Ph02TY:@807QhN00@05QHF00d=3@0=3@d04Q8B0P0:2PX0100000003Ph>00h>3P0S8b<2038b
<P04034a<@0U9BD09BDU02PX:080=3@d00@0=SHf03Xj>P0j>SX0>c/k0P0a<C40100_;bl0<C4a034a
<@0g=cL2038b<P0402h^;P10@400@41003/k>`80;bl_00@0;Bd]02`/;00/;2`0>c/k0P0i>CT0100e
=CD0=cLg03Lg=`0j>SX203<c<`0403De=@11@D40@D5103`l?080@T9200@0BDU903dm?@0m?Cd0=SHf
0P10@4001017AdL0@T920492@P11@D4204I6AP0404U9B@1:BTX0BTY:04Q8B080AdM700@0>SXj0410
@010@400GUiN0P1;Bd/01014A4@0DE5A055AD@16ATH203`l?00406IVIP2IVIT0VIVI0:BTY080/[:b
00@0_kno0<o?c`3?cll0fMWI0P3GemL01033`l<0/k>c0;>c/`3Lg=`20;no_`0405ADE00m?Cd0?Cdm
01hN7P8030`<0@0@4101000000400000000010061PH02`/;00/;2`092@T300@410800@4100@010@4
00<30`030`<01@D50P030`<300L71`0400@410020P800P8200410@801PH600@01@D500H61P061PH0
20P80`030`<200H61P0400<30`010@400@4100H61P8020P800@01@D500820P020P801PH60P092@T0
100410@020P800P820092@T200410@04000000030`<00`<300P820802@T90`020P80100410@02`/;
00/;2`00000200820P<01`L700@00P8200T92@092@T02@T90P020P80100<30`04Q8B018B4P0C4a<2
00h>3P0400l?3`0A4A404A4A00/;2`<04Q8B0`0A4A4200h>3P0400l?3`0A4A404A4A01DE5@8061PH
00@05QHF01DE5@0E5AD03Ph>0P051@D300P8200400`<30061PH01PH600<30`800@410`071`L01004
10@00P8200820P030`<200H61P0400<30`0?3`l03`l?00h>3P802PX:00@03`l?024Q8@0Q8B40=3@d
0P0h>3P01019BDT0Lg=c07=cL`1iNGT20451@@0401<C4`0=3@d03@d=00H61P803Ph>00@04Q8B01LG
5`0G5aL08B4Q0`0G5aL2030`<00402h^;P0[:b/0:b/[02/[:`<0@4100P0l?3`01016ATH0?Cdm03dm
?@18B4P2061PH00405UIF@15ADD0ADE507=cL`80Rh^;00@0Jf][06EUI@1UIFD0EeMG0P1OGel0101h
N7P0HF5Q065QH@1TI6@207inOP0407]kN`1eMGD0MGEe075aL@80Ng]k00@0OGem05eMG@1MGEd0GUiN
0P1HF5P01017AdL0BTY:04Y:BP1;Bd/204Y:BP0404e=C@0o?cl0?clo02`/;080<30`00<0=SHf02PX
:00X:2P0100K6a/202XZ:P04030`<00f=SH0=SHf04U9B@80GEeM00@0IfMW06YZJP1ZJVX0LG5a0P1l
O7`0101_Kfl0GEeM05eMG@14A4@202h^;P<0:RXZ00@0<30`03Hf=P0f=SH0<S8b0P0d=3@0100b<S80
;Rh^02h^;P0d=3@202LW9`0403Lg=`1cLg<0Lg=c03Xj>P80;Rh^00@0KFe]08V9R@29RHT0RHV90P1f
MWH0101HF5P0>3Ph03Ph>00Y:BT201hN7P0401HF5P0=3@d03@d=018B4P802PX:00@0000000h>3P0>
3Ph08b<S0P0b<S80100a<C409BDU02DU9@0X:2P203@d=00403Hf=P0j>SX0>SXj03/k>`80<C4a00@0
;bl_034a<@0a<C40=cLg0P0b<S80100^;Rh0@4100410@00k>c/202l_;`0402d];@0/;2`0;2`/03/k
>`80>CTi00@0=CDe03Lg=`0g=cL0>SXj0P0c<c<0100e=CD0@D510451@@0l?3`20492@P0404U9B@0m
?Cd0?Cdm03Hf=P80@41000@0AdM70492@P12@T80@D510P16ATH01019BDT0BTY:04Y:BP18B4P204M7
A`0403Xj>P10@400@41005iNGP80Bd];00@0A4A4055AD@1ADE40ATI60P0l?3`0101VIVH0VIVI09VI
V@2TY:@20;:b/P040;no_`3?cll0clo?0=WIf@80emOG00@0`l?30;>c/`2c/k<0g=cL0P2o_kl0101D
E5@0?Cdm03dm?@0N7Qh200`<3040410@0@0000010000000000@01@D500<30`030`<01PH60P0820P0
10051@D00@4100410@030`<200D51@0400T92@051@D01@D500/;2`<01PH60P00000010010@401@D5
00D51@051@D200X:2P0400P820071`L01`L700P820801@D500<00@4100<30`030`<010051@D200@4
100400H61P0820P020P800D51@8010@40`061PH010010@4010@400@4100<30`200L71`0400820P07
1`L01`L700L71`801PH600@00`<300D51@051@D00P820P0;2`/0100410@01@D500D51@0820P200@4
10030000000=3@d03@d=00<0410@00<05aLG01PH600H61P00`0?3`l0100=3@d0410@010@400B4Q82
014A4@0400d=3@0:2PX02PX:00/;2`802PX:00@03@d=01<C4`0C4a<030`<0P00000010051@D02`/;
00/;2`0820P300@410802@T900<020P800820P020P800`051@D0100000001PH600H61P020P8200`<
30<03`l?00@07AdM02l_;`0_;bl0<c<c0P0j>SX0101NGUh0O7al07alO01TI6@2030`<004014A4@0;
2`/02`/;00@410<01@D50P0L71`0100S8b<05aLG01LG5`0J6QX202l_;`0403hn?P14A4@0A4A403hn
?P80F5QH00@0EUIF04E5A@15ADD0EeMG0P1KFe/0101<C4`0EEEE05EEE@1ADE4203/k>`0405UIF@1J
FUX0FUYJ03<c<`80ATI600@0Bd];05ADE01DE5@0MGEe0P21PH401025QHD0RHV908V9R@1kNg/208:2
PP0408J6QP22PX80PX:206=SH`80>CTi00@0GemO071`L01`L700De=C0P1HF5P0101OGel0F5QH05QH
F01<C4`203lo?`0403Lg=`0_;bl0;bl_02l_;`80<30`00@09RHV01lO7`0O7al08R8R0P0[:b/0100W
9bL0<30`030`<014A4@205QHF00406IVIP1YJFT0JFUY079bLP80QXJ600@0Ng]k06UYJ@1YJFT0EEEE
0P0f=SH00`0[:b/0=CDe03De=@030410@00403Ph>00i>CT0>CTi03De=@80=cLg00@0=SHf01hN7P0N
7Qh0BDU90P1UIFD0100/;2`0F5QH05QHF024Q8@208V9R@04071`L01JFUX0FUYJ05EEE@80?Cdm00@0
:RXZ02/[:`0[:b/0820P0P0A4A40100J6QX02PX:00X:2P00000201XJ6P0402d];@0f=SH0=SHf03Ph
>080=CDe00@0?3`l03/k>`0k>c/0>CTi0P0k>c/0100d=3@0>3Ph03Ph>00k>c/203<c<`04030`<00T
92@092@T02l_;`80?Cdm00@0=CDe038b<P0b<S80=3@d0P0[:b/0100d=3@0>CTi03Ti>@0c<c<203@d
=00403`l?00d=3@0=3@d038b<P<0=CDe0P0o?cl30410@00403dm?@0i>CT0>CTi0410@080B4Q800@0
BDU904A4A014A4@0?clo0P15ADD01019BDT0@T920492@P0l?3`204Y:BP0405MGE`1:BTX0BTY:04e=
C@80D51@00@0?Cdm0410@010@400Ogmo0P2^[Zh0102[Zj/0/K6a0;6a/@2j^[X20<c<c0040=3@d035
aLD0aLG50;Bd]080Z:RX00@0_[jn09bLW02LW9`0HV9R0P12@T80100H61P01PH600H61P071`L200X:
2P0000@00P8200D51@051@D00@410P0<30`010061PH01`L700L71`051@D200820P03000000061PH0
1PH600<00`<300@00P8200410@010@400@410P0:2PX0100820P01@D500D51@010@4200820P<03@d=
00@01PH600D51@051@D010@40P061PH010030`<010@400@410061PH200410@0400<30`0410@010@4
00L71`8020P800@010@400410@010@400`<30P051@D0100820P01`L700L71`0410@200410@0400H6
1P051@D01@D500820P8010@400@00`<300D51@051@D00P820P051@D0100820P00@4100410@000002
00h>3P03014A4@0>3Ph03Ph>00<030`<00<0410@00l?3`0?3`l00`0;2`/010061PH01@D500D51@0@
4102014A4@04010@400D51@051@D00`<3080000000@01@D500d=3@0=3@d00`<30P020P800`030`<0
1PH600H61P0400L71`802`/;00@00P8200@4100410@01PH60P0D51@0100:2PX03`l?00l?3`0P8203
030`<080?3`l00@0Kfm_07YjNP1jNWX0C4a<0P0Z:RX0100E5AD01`L700L71`00000200D51@0400L7
1`0G5aL05aLG01hN7P<071`L0P0[:b/01011@D40D51@051@D014A4@2059BDP0405=CD`15ADD0ADE5
04i>CP80HF5Q00@0GUiN05mOG`1OGel0EeMG0P1;Bd/0101EEED0DU9B059BDP17AdL205aLG004075a
L@1hN7P0N7Qh08V9R@80Ti>C00@0MgMg07IfMP1fMWH0PH610P24Q8@01020P800QhN708N7Q`1gMgL2
061PH00406YZJP1/K6`0K6a/051@D080@D5100@0BTY:05QHF01HF5P0FEUI0P1OGel0101BDU80:2PX
02PX:00N7Qh203Hf=P0402/[:`0H61P061PH020P8080<30`00@0<C4a030`<00`<300>SXj0P1ADE40
101MGEd0Hf=S06=SH`1_Kfl208^;R`0407moO`1/K6`0K6a/05iNGP80?clo00@0;bl_03Lg=`0g=cL0
>CTi0P0h>3P0100e=CD0>c/k03/k>`0l?3`203Xj>P04038b<P0/;2`0;2`/05YJFP80DE5A00@0?3`l
06a/K01/K6`0M7Ad0P1kNg/0101/K6`0HF5Q065QH@1QHF42055AD@0403<c<`0S8b<08b<S020P8080
5aLG00@07QhN01XJ6P0J6QX03Ph>0P0M7Ad0100];Bd0;bl_02l_;`0h>3P203hn?P0404A4A00o?cl0
?clo03Ti>@80?Cdm00@0=cLg03Ph>00h>3P0?Cdm0P0i>CT0100c<c<0<S8b038b<P10@40203`l?004
03Lg=`0i>CT0>CTi03Lg=`80=SHf00@0>3Ph03Ti>@0i>CT0<C4a0P0j>SX01010@400;Bd]02d];@0Y
:BT2038b<P0403Ph>012@T80@T920410@080@d=300@0ATI60410@010@400?clo0P15ADD01017AdL0
@T920492@P0o?cl204A4A00404E5A@10@400@4100410@080Bd];00@0BDU90410@010@400Bd];0P1:
BTX0100f=SH0@4100410@022PX820:NWY`0409^KV`2[Zj/0Zj^[0;Zj^P80a/K600@0b/[:0;Vi^@2i
^KT0YJFU0P2[Zj/0102k^k/0YZJV0:JVYP20P80203/k>`0400/;2`051@D01@D500P820802@T90000
10020P801@D500D51@010@4200`<300400H61P071`L01`L700D51@800P8200<0000000H61P061PH0
0`030`<010020P800@4100410@010@4200X:2P0400P820051@D01@D500410@800P820`0=3@d01006
1PH01@D500D51@0410@200H61P0400<30`0410@010@400H61P800@4100@00`<300@4100410@01`L7
0P0820P0100410@00@4100410@030`<200D51@0400P820071`L01`L700@410800@4100@01PH600D5
1@051@D00P820P0410@010030`<01@D500D51@020P8200D51@0400P820010@400@41000000803Ph>
00<04A4A00h>3P0>3Ph00`0<30`00`0@41003`l?00l?3`0300/;2`0400H61P051@D01@D5010@4080
4A4A00@0410@01@D500D51@030`<0P00000010051@D03@d=00d=3@030`<200820P0300<30`061PH0
1PH600@01`L70P0;2`/010020P8010@400@410061PH201@D500400X:2P0?3`l03`l?020P80<0<30`
0P0l?3`0101_Kfl0NWYj07YjNP1<C4`202XZ:P0401DE5@071`L01`L7000000801@D500@01`L701LG
5`0G5aL07QhN0`0L71`202/[:`040451@@1@D500D51@04A4A080DU9B00@0De=C04E5A@15ADD0CTi>
0P1QHF40101NGUh0GemO05mOG`1GEeL204];B`0405EEE@1BDU80DU9B04M7A`80G5aL00@0LG5a07Qh
N01hN7P0RHV90P2CTi<0101gMgL0MWIf07IfMP21PH4208B4Q0040820P027QhL0QhN707MgM`80H61P
00@0JVYZ06a/K01/K6`0D51@0P11@D40101:BTX0F5QH05QHF01IFET205mOG`04059BDP0X:2P0:2PX
01hN7P80=SHf00@0:b/[01PH600H61P0820P0P0`<300100a<C40<30`030`<00j>SX2055AD@0405eM
G@1SHf<0Hf=S06m_K`80Rh^;00@0Ogmo06a/K01/K6`0GUiN0P0o?cl0100_;bl0=cLg03Lg=`0i>CT2
03Ph>00403De=@0k>c/0>c/k03`l?080>SXj00@0<S8b02`/;00/;2`0FUYJ0P1ADE40100l?3`0K6a/
06a/K01dM7@207]kN`0406a/K01QHF40HF5Q065QH@80DE5A00@0<c<c02<S8`0S8b<0820P0P0G5aL0
100N7Qh06QXJ01XJ6P0>3Ph201dM7@0402d];@0_;bl0;bl_03Ph>080?Shn00@0A4A403lo?`0o?cl0
>CTi0P0m?Cd0100g=cL0>3Ph03Ph>00m?Cd203Ti>@0403<c<`0b<S80<S8b0410@080?3`l00@0=cLg
03Ti>@0i>CT0=cLg0P0f=SH0100h>3P0>CTi03Ti>@0a<C4203Xj>P040410@00];Bd0;Bd]02TY:@80
<S8b00@0>3Ph0492@P12@T80@4100P13@d<01016ATH0@4100410@00o?cl204E5A@0404M7A`12@T80
@T9203lo?`80A4A400@0ADE50410@010@400@4100P1;Bd/01019BDT0@4100410@01;Bd/204Y:BP04
03Hf=P10@400@41008:2PP80YjNW00@0Vi^K0:^[Z`2[Zj/0^[Zj0P36a/H0103:b/X0^KVi0;Vi^@2U
YJD20:^[Z`040;^k^`2VYZH0YZJV0820P080>c/k00@02`/;00D51@051@D020P80P092@T0000400H6
1P051@D01@D500410@802PX:00@01`L700H61P061PH01PH60P051@D0100000001@D500D51@092@T2
00H61P<01`L700@010@400410@010@4020P80P092@T300H61P0400`<300@4100410@00P820<010@4
0P020P8010051@D01`L700L71`071`L200@410@01PH60`030`<200820P0400D51@010@400@4100H6
1P800P8200@010@40000000000001`L70`020P8200D51@0400820P071`L01`L700D51@802PX:00@0
4Q8B00@4100410@000000P0<30`010071`L020P800P8200<30`200H61P0401@D500G5aL05aLG00L7
1`802@T900@03@d=00L71`071`L030`<0P0F5QH0100B4Q8030`<00`<300:2PX200820P0400D51@09
2@T02@T900410@802@T900@01@D500410@010@401@D50P020P8010051@D030`<00`<300410@20082
0P0400@4100D51@051@D00T92@80410@00@09BDU03<c<`0c<c<0?3`l0P12@T80101QHF40KVi^06i^
KP1<C4`202DU9@0400h>3P0<30`030`<00H61P801`L700@02`/;01dM7@0M7Ad08b<S0P0N7Qh0100S
8b<0?Shn03hn?P14A4@204=3@`0403Ti>@18B4P0B4Q805ADE080D51@00@0Cdm?04U9B@19BDT0?Shn
0P1BDU8306EUI@0407AdM020P800P82007QhN080OGem00@0S8b<08>3P`23Ph<0MGEe0P2;Rh/01025
QHD0P8200820P025QHD20820P00406][J`1`L700L71`071`L080LW9b00@0IVIV05]KF`1KFe/0CTi>
0P0n?Sh01012@T80BDU904U9B@1:BTX2051@D00404];B`0a<C40<C4a02<S8`80:BTY00@09bLW02HV
9P0V9RH09RHV0P0U9BD0100R8R80;Rh^02h^;P0j>SX203hn?P0404e=C@1OGel0GemO061PH080OGem
00@0OWin07AdM01dM7@0H61P0P18B4P0100g=cL0<C4a034a<@0Y:BT2038b<P0403`l?00o?cl0?clo
03`l?080>SXj00@0=3@d04Q8B018B4P0KVi^0P1<C4`0101BDU80LG5a075aL@1eMGD207moO`0406a/
K01UIFD0IFEU069RHP80Fe]K00@0Bd];020P800P82005ADE0P0R8R80100U9BD08R8R028R8P0F5QH2
010@400302<S8`0_;bl0;bl_00<0=cLg00@0@4100492@P12@T80?Cdm0P0o?cl0100n?Sh0>3Ph03Ph
>00e=CD2034a<@0403<c<`10@400@41004Q8B080@T9200@0?Shn03De=@0e=CD0<30`0P0j>SX0100g
=cL0=SHf03Hf=P0^;Rh203Ph>00403Xj>P0`<300<30`034a<@80=SHf00@0>SXj03hn?P0n?Sh0@T92
0P15ADD01011@D40@4100410@00n?Sh20410@0<0A4A400@0ADE504e=C@1=CDd0CDe=0P15ADD00`0i
>CT0?Cdm03dm?@030410@00404Y:BP18B4P0B4Q8030`<080A4A400@0TI6A0:RXZ02XZ:P0Xj>S0P2l
_;`01031`L40`l?30<?3``2i^KT209nOW`040:RXZ032`/80`/;20=[JfP80g]kN00@0XJ6Q03De=@0e
=CD01`L70P0410@100820P4020P80@0820P000<00`<300@01@D500L71`071`L030`<0P030`<30082
0P0400D51@020P800P8200<30`<01@D50P0410@010010@4010@400@410061PH200@4100400820P05
1@D01@D500L71`8010@40`030`<010051@D010@400@410030`<200H61P0400/;2`030`<00`<300T9
2@<010@40P061PH010010@401PH600H61P092@T200820P0400D51@0410@010@400@410800`<300@0
1@D500<30`030`<00@410P0410@010051@D010@400@410061PH200<30`0400H61P0410@010@40082
0P801PH600@02@T900P8200820P02@T90P051@D00`0>3Ph04Q8B018B4P0300T92@0400`<30061PH0
1PH600P820<04Q8B0P0=3@d010092@T01PH600H61P051@D200/;2`0400P8200?3`l03`l?00L71`80
10@400@00P8200@4100410@00@410P061PH0100410@01PH600H61P030`<300/;2`806QXJ00@09bLW
02l_;`0_;bl0>SXj0P0o?cl0101@D500GUiN05iNGP19BDT202<S8`0400D51@092@T02@T900`<3080
2PX:00@04a<C01hN7P0N7Qh07alO0P0X:2P0100^;Rh0>c/k03/k>`16ATH205QHF00405=CD`1BDU80
DU9B05=CD`80Cdm?00@0F5QH05eMG@1MGEd0@D510P1GEeL0101eMGD0HV9R069RHP1^KVh208R8R004
079bLP1YJFT0JFUY08F5Q@80RHV900@0IFEU07EeM@1eMGD0Xj>S0P2LW9`0102<S8`0RHV908V9R@1U
IFD2051@D00404m?C`1aLG40LG5a07IfMP80JVYZ00@0Kfm_071`L01`L700GemO0P1ADE40101CDe<0
AdM704M7A`0k>c/203@d=0<09BDU00@0=CDe03@d=00d=3@09RHV0P0Z:RX0100M7Ad0;2`/02`/;00k
>c/2038b<P0404E5A@1JFUX0FUYJ05mOG`80MGEe00@0QXJ607YjNP1jNWX0FUYJ0P1EEED01010@400
9RHV02HV9P0V9RH203dm?@0404e=C@13@d<0@d=303Ti>@80=3@d00@0;2`/04];B`1;Bd/0Fe]K0P0g
=cL0101CDe<0I6AT06ATI01`L70207EeM@04065QH@1JFUX0FUYJ05ADE080AdM700@0CTi>03@d=00d
=3@03Ph>0P0Z:RX0100^;Rh061PH01PH600B4Q8201LG5`0402DU9@0j>SX0>SXj0492@P<0>c/k0P10
@400100n?Sh0>c/k03/k>`0l?3`20410@00403hn?P0e=CD0=CDe03Ti>@<0@4100P0o?cl0100n?Sh0
>SXj03Xj>P0e=CD203hn?P0403`l?00h>3P0>3Ph030`<0<0=CDe0P0g=cL0100i>CT0=cLg03Lg=`0l
?3`203Xj>P0403hn?P14A4@0A4A403dm?@80@41000@0B4Q804M7A`17AdL0@d=30P0o?cl01012@T80
CDe=04e=C@16ATH20410@00403Ph>00k>c/0>c/k03hn?P80?3`l00@0Bd];05YJFP1JFUX0>CTi0P1C
De<0102UYJD0WinO09nOW`2NWYh20<30`0@0^k^k0P2j^[X01035aLD0b<S80<S8b03Ti>@20>WYj@04
08B4Q00H61P061PH00P8208000000`030`<000<00`<300@01@D500L71`071`L030`<0P030`<30082
0P0400D51@020P800P8200<30`<01@D50P0410@010010@4010@400@410061PH200@4100400820P05
1@D01@D500L71`8010@40`030`<010051@D010@400@410030`<200H61P0400/;2`030`<00`<300T9
2@<010@40P061PH010010@401PH600H61P092@T200820P0400D51@0410@010@400@410800`<300@0
1@D500<30`030`<00@410P0410@010051@D010@400@410061PH200<30`0400H61P0410@010@40082
0P801PH600@02@T900P8200820P02@T90P051@D00`0>3Ph04Q8B018B4P0300T92@0400`<30061PH0
1PH600P820<04Q8B0P0=3@d010092@T01PH600H61P051@D200/;2`0400P8200?3`l03`l?00L71`80
10@400@00P8200@4100410@00@410P061PH0100410@01PH600H61P030`<300/;2`806QXJ00@09bLW
02l_;`0_;bl0>SXj0P0o?cl0101@D500GUiN05iNGP19BDT202<S8`0400D51@092@T02@T900`<3080
2PX:00@04a<C01hN7P0N7Qh07alO0P0X:2P0100^;Rh0>c/k03/k>`16ATH205QHF00405=CD`1BDU80
DU9B05=CD`80Cdm?00@0F5QH05eMG@1MGEd0@D510P1GEeL0101eMGD0HV9R069RHP1^KVh208R8R004
079bLP1YJFT0JFUY08F5Q@80RHV900@0IFEU07EeM@1eMGD0Xj>S0P2LW9`0102<S8`0RHV908V9R@1U
IFD2051@D00404m?C`1aLG40LG5a07IfMP80JVYZ00@0Kfm_071`L01`L700GemO0P1ADE40101CDe<0
AdM704M7A`0k>c/203@d=0<09BDU00@0=CDe03@d=00d=3@09RHV0P0Z:RX0100M7Ad0;2`/02`/;00k
>c/2038b<P0404E5A@1JFUX0FUYJ05mOG`80MGEe00@0QXJ607YjNP1jNWX0FUYJ0P1EEED01010@400
9RHV02HV9P0V9RH203dm?@0404e=C@13@d<0@d=303Ti>@80=3@d00@0;2`/04];B`1;Bd/0Fe]K0P0g
=cL0101CDe<0I6AT06ATI01`L70207EeM@04065QH@1JFUX0FUYJ05ADE080AdM700@0CTi>03@d=00d
=3@03Ph>0P0Z:RX0100^;Rh061PH01PH600B4Q8201LG5`0402DU9@0j>SX0>SXj0492@P<0>c/k0P10
@400100n?Sh0>c/k03/k>`0l?3`20410@00403hn?P0e=CD0=CDe03Ti>@<0@4100P0o?cl0100n?Sh0
>SXj03Xj>P0e=CD203hn?P0403`l?00h>3P0>3Ph030`<0<0=CDe0P0g=cL0100i>CT0=cLg03Lg=`0l
?3`203Xj>P0403hn?P14A4@0A4A403dm?@80@41000@0B4Q804M7A`17AdL0@d=30P0o?cl01012@T80
CDe=04e=C@16ATH20410@00403Ph>00k>c/0>c/k03hn?P80?3`l00@0Bd];05YJFP1JFUX0>CTi0P1C
De<0102UYJD0WinO09nOW`2NWYh20<30`0@0^k^k0P2j^[X01035aLD0b<S80<S8b03Ti>@20>WYj@04
08B4Q00H61P061PH00P8208000000`030`<0000400T92@071`L01`L700@410802@T900@01`L700D5
1@051@D010@40P051@D00`0:2PX020P800P8200300410@0400<30`000000000000<30`802`/;00@0
1`L700<30`030`<00P820`030`<200820P<01PH600@020P800L71`071`L01@D50P0=3@d0100>3Ph0
1`L700L71`061PH200820P<00`<300@010@400P8200820P00@410P0410@010030`<01@D500D51@06
1PH200<30`0300H61P051@D01@D500<01@D500@01PH600L71`071`L020P80P020P80100410@00P82
00820P051@D200<30`0400L71`0>3Ph03Ph>00d=3@801`L700@010@400P8200820P02`/;0P0=3@d0
0`0<30`02`/;00/;2`0300T92@04014A4@0>3Ph03Ph>00820P802PX:00@020P800X:2P0:2PX01@D5
0`071`L200D51@0400<30`0820P020P800L71`800`<300@00@4100<30`030`<00P820P061PH01007
1`L07QhN01hN7P0T92@202TY:@0403Ph>012@T80@T9205=CD`80AdM700@09bLW01TI6@0I6AT010@4
0`010@4200@4100400h>3P0O7al07alO02PX:080=CDe00@0<C4a03Ti>@0i>CT0ATI60`1EEED205=C
D`0405ADE01RHV80HV9R061PH080Lg=c00@0IfMW069RHP1RHV80MGEe0P1SHf<0101ADE40I6AT06AT
I01bLW8206m_K`0406=SH`1^KVh0KVi^08B4Q080Lg=c00@0Rh^;09ZJVP2JVYX0TI6A0P2>SXh01024
Q8@0M7Ad07AdM016ATH20410@00405EEE@1PH600H61P069RHP80Jf][00@0J6QX05eMG@1MGEd0F5QH
0P1BDU801018B4P0@T920492@P0o?cl203Lg=`04030`<00W9bL09bLW02<S8`809bLW00@071`L02l_
;`0_;bl0>CTi0P0W9bL0100e=CD0AdM704M7A`1GEeL206UYJ@0408N7Q`1cLg<0Lg=c05ADE080G5aL
00@0Cdm?02XZ:P0Z:RX0:RXZ0P0k>c/01013@d<0?3`l03`l?010@40202l_;`0401XJ6P1;Bd/0Bd];
069RHP80Cdm?00@0HV9R05iNGP1NGUh0IfMW0P1NGUh0101ADE40D51@051@D015ADD203hn?P0404Q8
B01>CTh0CTi>02HV9P80820P00@0<C4a01TI6@0I6AT04a<C0P0N7Qh0100U9BD0?Cdm03dm?@1;Bd/2
04=3@`0403Ph>00d=3@0=3@d0410@080B4Q800@0?Shn03lo?`0o?cl0@T920P0l?3`01013@d<0@T92
0492@P0j>SX203lo?`0403dm?@0l?3`0?3`l03hn?P80@41000@0?clo03Lg=`0g=cL0=SHf0`0h>3P2
03Ti>@0403/k>`0e=CD0=CDe03/k>`80?Cdm00@0>SXj03hn?P0n?Sh0@D510`14A4@20410@0040451
@@12@T80@T9204Y:BP80CTi>00@0@T920410@010@400@4100P13@d<30410@00405=CD`1MGEd0GEeM
03Lg=`80HF5Q00@0Z:RX09JFUP2FUYH0XZ:R0P2n_[h0102e]KD0b<S80<S8b03Lg=`20=SHf0040=3@
d03Kfm/0fm_K0?[jnP80e]KF00@0EeMG018B4P0B4Q805aLG0P020P8100D51@4010@40@0410@00004
00@410020P800P8200H61P802`/;0`0410@010071`L01@D500D51@020P8200D51@0400L71`0410@0
10@400@410800@4100@030`<010@400@41001@D50P0410@010030`<01@D500D51@061PH200L71`03
00P8200410@010@400<010@400@01PH600D51@051@D01@D50P061PH010030`<00P8200820P010@42
00L71`0400D51@0820P020P800410@8010@400<00P8200@4100410@00`030`<0100410@01PH600H6
1P071`L200H61P<00`<300@02PX:00H61P061PH00`<30P051@D0100:2PX010@400@410061PH201<C
4`04018B4P092@T02@T900@410801@D500@02PX:00h>3P0>3Ph02`/;0P0:2PX0100;2`/00`<300<3
0`0>3Ph200l?3`0400410@092@T02@T900P8208010@40`030`<010010@400`<300<30`030`<20082
0P0300H61P092@T02@T900@00`<30P0;2`/010071`L05QHF01HF5P0U9BD2030`<00403hn?P18B4P0
B4Q804];B`80<c<c00@05aLG00l?3`0?3`l00`<30P051@D010071`L00P8200820P0<30`201lO7`04
02LW9`0Y:BT0:BTY02`/;080>CTi00@0@D5104];B`1;Bd/0D51@0P1TI6@0101MGEd0FEUI05UIF@0m
?Cd204e=C@0407AdM01WIfL0IfMW05]KF`80JFUY00@0IfMW05aLG01LG5`0IVIV0P1nOWh0101dM7@0
KVi^06i^KP2HV9P207IfMP0406i^KP28R8P0R8R808:2PP80NWYj00@0Ogmo07EeM@1eMGD0BDU90P0N
7Qh0100T92@0ADE504E5A@1JFUX206][J`0406m_K`1WIfL0IfMW05IFEP80Cdm?00@0D51@05YJFP1J
FUX0Fe]K0P10@40302`/;00402l_;`0a<C40<C4a02PX:080<S8b00@0>3Ph02/[:`0[:b/0=SHf0P0o
?cl0101;Bd/0GUiN05iNGP1mOGd206MWI`0405QHF01KFe/0Fe]K05=CD`80?clo00@0=SHf03Ti>@0i
>CT0@4100P0o?cl01017AdL0;Rh^02h^;P0Q8B42055AD@0405eMG@1NGUh0GUiN07=cL`80JFUY00@0
I6AT05YJFP1JFUX0G5aL0P1:BTX0100_;bl0;2`/02`/;00i>CT205=CD`0404Y:BP0R8R808R8R024Q
8@80;2`/00@092@T01<C4`0C4a<09BDU0P13@d<00`18B4P0?Cdm03dm?@030410@00303lo?`12@T80
@T9200<0?Cdm00@0@41003Xj>P0j>SX0>c/k0P0j>SX0100i>CT0?Cdm03dm?@0g=cL203Ti>@040410
@00f=SH0=SHf034a<@80>3Ph00@0?3`l03Hf=P0f=SH0=CDe0P0m?Cd0100o?cl0=3@d03@d=00n?Sh2
04A4A00403lo?`0h>3P0>3Ph0410@080@d=300@0@D510410@010@400A4A40P15ADD00`19BDT0ATI6
04I6AP0303lo?`0403dm?@11@D40@D5103lo?`80>SXj00@0D51@059BDP1BDU80>CTi0P22PX80102Z
ZZX0Rh^;08^;R`2_[jl20<W9b@040<30`03:b/X0b/[:0=;BdP80clo?00@0a/K60=WIf@3IfMT0oooo
0P3=cLd0101CDe<06a/K01/K6`0>3Ph2000000400P820@061PH100H61P0000@010@400820P020P80
1PH60P0;2`/300@4100400L71`051@D01@D500820P801@D500@01`L700@4100410@010@40P010@40
100<30`0410@010@40051@D200@4100400<30`051@D01@D500H61P801`L700<020P800@4100410@0
0`0410@010061PH01@D500D51@051@D200H61P0400<30`020P800P8200410@801`L700@01@D500P8
200820P00@410P0410@00`020P8010@400@4100300<30`0400@410061PH01PH600L71`801PH60`03
0`<0100:2PX01PH600H61P030`<200D51@0400X:2P0410@010@400H61P804a<C00@04Q8B00T92@09
2@T010@40P051@D0100:2PX03Ph>00h>3P0;2`/200X:2P0400/;2`030`<00`<300h>3P803`l?00@0
0@4100T92@092@T020P80P0410@300<30`0400410@030`<00`<300<30`800P8200<01PH600T92@09
2@T010030`<200/;2`0400L71`0F5QH05QHF02DU9@80<30`00@0?Shn04Q8B018B4P0Bd];0P0c<c<0
100G5aL03`l?00l?3`030`<200D51@0400L71`020P800P8200`<30807alO00@09bLW02TY:@0Y:BT0
;2`/0P0i>CT01011@D40Bd];04];B`1@D50206ATI00405eMG@1IFET0FEUI03dm?@80CDe=00@0M7Ad
06MWI`1WIfL0Fe]K0P1YJFT0101WIfL0G5aL05aLG01VIVH207inOP0407AdM01^KVh0KVi^09RHV080
MWIf00@0KVi^08R8R028R8P0PX:20P1jNWX0101oOgl0MGEe07EeM@19BDT201hN7P0402@T9015ADD0
ADE505YJFP80Jf][00@0Kfm_06MWI`1WIfL0EUIF0P1?Cdl0101@D500FUYJ05YJFP1KFe/20410@0<0
;2`/00@0;bl_034a<@0a<C40:2PX0P0b<S80100h>3P0:b/[02/[:`0f=SH203lo?`0404];B`1NGUh0
GUiN07emO@80IfMW00@0F5QH05]KF`1KFe/0De=C0P0o?cl0100f=SH0>CTi03Ti>@10@40203lo?`04
04M7A`0^;Rh0;Rh^024Q8@80DE5A00@0GEeM05iNGP1NGUh0Lg=c0P1YJFT0101TI6@0FUYJ05YJFP1L
G5`204Y:BP0402l_;`0/;2`0;2`/03Ti>@80De=C00@0BTY:028R8P0R8R808B4Q0P0/;2`0100T92@0
4a<C01<C4`0U9BD204=3@`0304Q8B00m?Cd0?Cdm00<0@41000<0?clo0492@P12@T800`0m?Cd01010
@400>SXj03Xj>P0k>c/203Xj>P0403Ti>@0m?Cd0?Cdm03Lg=`80>CTi00@0@41003Hf=P0f=SH0<C4a
0P0h>3P0100l?3`0=SHf03Hf=P0e=CD203dm?@0403lo?`0d=3@0=3@d03hn?P80A4A400@0?clo03Ph
>00h>3P0@4100P13@d<01011@D40@4100410@014A4@204E5A@0304U9B@16ATH0ATI600<0?clo00@0
?Cdm0451@@11@D40?clo0P0j>SX0101@D500DU9B059BDP0i>CT208:2PP040:ZZZP2;Rh/0Rh^;0:n_
[`80bLW900@0`<300<[:bP3:b/X0d];B0P3?cll01036a/H0fMWI0=WIf@3oool20<g=c@0405=CD`0K
6a/06a/K00h>3P8000000@020P8100H61P401PH60000100000001@D500D51@0820P200820P040000
00051@D01@D500H61P801@D510061PH300410@800P8200@00`<300D51@051@D00P820P051@D300<3
0`0300/;2`020P800P8200<00`<300<00P8200H61P061PH00`0410@00`020P802@T900T92@0300<3
0`0400@410051@D01@D500H61P801`L700@01PH600T92@092@T010@40P071`L010051@D00@410041
0@051@D200P8200400@410061PH01PH600820P800`<300@02PX:00P8200820P00@410P071`L01006
1PH00P8200820P0410@200X:2P0300/;2`092@T02@T900<02@T900@02PX:00T92@092@T010@40P07
1`L00`0<30`00P8200820P0300D51@0400<30`0410@010@400@41080000000@00P8200T92@092@T0
1@D50P071`L010020P801PH600H61P010@4200L71`0400P8200;2`/02`/;00@410802@T900@03@d=
01hN7P0N7Qh0;Rh^0P0`<300100e=CD0@d=304=3@`17AdL203Ti>@0402<S8`0<30`030`<00<30`<0
1`L70P0410@0100H61P08B4Q024Q8@0R8R8202PX:0<0=3@d00@0?Shn04Q8B018B4P0C4a<0P1YJFT0
101UIFD0BDU904U9B@0/;2`203<c<`0405YJFP1MGEd0GEeM05UIF@80JVYZ00@0OWin08R8R028R8P0
N7Qh0P1kNg/01026QXH0K6a/06a/K02:RXX208R8R00407QhN01eMGD0MGEe08>3P`80M7Ad00@0L71`
06YZJP1ZJVX0FUYJ0P1GEeL0101CDe<0Kfm_06m_K`27QhL20861P@0406IVIP1QHF40HF5Q06MWI`80
JFUY00@0IFEU05QHF01HF5P0@4100P0a<C40100d=3@0>SXj03Xj>P16ATH204E5A@04038b<P0_;bl0
;bl_02TY:@80;2`/00@0<30`02h^;P0^;Rh0@4100P1>CTh0101RHV80E5AD05ADE01JFUX205eMG@03
059BDP1;Bd/0Bd];00<0>CTi00@0BDU904e=C@1=CDd0AdM70P0/;2`01011@D40L71`071`L01RHV82
06ATI0040861P@1fMWH0MWIf05mOG`80H61P00@0JVYZ04e=C@1=CDd0;bl_0P0N7Qh0100V9RH0=CDe
03De=@16ATH20492@P0402l_;`0];Bd0;Bd]02/[:`8071`L00@0;Rh^04M7A`17AdL0A4A40P0e=CD0
0`17AdL0ATI604I6AP0303Ti>@0403hn?P11@D40@D510451@@<0?clo0P10@4001011@D40?clo03lo
?`0l?3`20410@0040451@@0g=cL0=cLg03Ti>@80@41000@0>SXj03Lg=`0g=cL0;Rh^0P0k>c/01012
@T80>c/k03/k>`12@T8304I6AP80@41000@0?clo03hn?P0n?Sh0AdM70`14A4@30492@P80AdM70`12
@T801015ADD0@T920492@P0m?Cd2038b<P0404m?C`1=CDd0CDe=03`l?080V9RH00@0XZ:R08N7Q`27
QhL0/k>c0P2b/[80102g]kL0b/[:0<[:bP38b<P20<O7a`040;jn_P3EeMD0eMGE0?3`l080Z:RX00@0
@D5101TI6@0I6AT030`<0P051@D100L71`401@D50@051@D0000400D51@061PH01PH600P8208010@4
00@00P8200<30`030`<000000P030`<0100;2`/02@T900T92@020P8200410@0300H61P071`L01`L7
00<0000000@010@400D51@051@D000000P020P8300@4100400<30`020P800P8200L71`8010@400@0
0P8200P8200820P00`<30P051@D0100410@00`<300<30`0410@200820P0400P820051@D01@D500X:
2P800`<30`051@D010061PH01@D500D51@092@T200P8200400@410092@T02@T900H61P800@4100@0
30`<00T92@092@T01@D50P061PH0100820P01PH600H61P020P8200@4100400T92@0820P020P800P8
20803@d=00@02@T900@4100410@01`L70P061PH0100;2`/02PX:00X:2P0=3@d200L71`0400<30`04
10@010@400T92@8010@400@020P800X:2P0:2PX01PH60P0:2PX010061PH00000000000030`<500@4
100400T92@0820P020P8018B4P808R8R00@09bLW02HV9P0V9RH0;2`/0P11@D40101<C4`0=3@d03@d
=00E5AD200D51@0400T92@0:2PX02PX:00820P8030`<00@07AdM01`L700L71`05aLG0P0S8b<0100f
=SH0?Cdm03dm?@1=CDd204];B`040492@P1CDe<0De=C05IFEP80E5AD00@0DU9B03/k>`0k>c/0ADE5
0P1OGel0101dM7@0J6QX06QXJ01FEUH208B4Q00409ZJVP20P800P82006QXJ080A4A400@0RHV909ZJ
VP2JVYX0Ogmo0P1/K6`0102:RXX0U9BD09BDU026QXH206i^KP04069RHP20P800P82008b<S080Q8B4
00@0R8R807MgM`1gMgL0IFEU0P1XJ6P0101TI6@0Hf=S06=SH`1@D50203hn?P0404M7A`1ADE40DE5A
04I6AP80?Cdm00@0E5AD051@D01@D500<S8b0P0e=CD0100[:b/0:BTY02TY:@0[:b/202h^;P0403De
=@0[:b/0:b/[03Xj>P80ATI600@0GEeM06][J`1[Jf/0G5aL0P1FEUH01014A4@0>c/k03/k>`13@d<2
04M7A`040410@00/;2`0;2`/05=CD`80Ng]k00@0IVIV06ATI01TI6@0Kfm_0P1^KVh0101PH600GEeM
05eMG@1SHf<205aLG00404Y:BP0W9bL09bLW020P80808R8R00@09RHV0492@P12@T80ADE50P0Y:BT0
100[:b/0=CDe03De=@0a<C4203@d=00404=3@`17AdL0AdM704M7A`80@D5100@0?Cdm03Ti>@0i>CT0
?Cdm1P11@D4304A4A080?Cdm00@0?3`l0410@010@400>SXj0P0e=CD303lo?`0403/k>`0o?cl0?clo
034a<@80>3Ph00@0B4Q80492@P12@T80@T920P0m?Cd00`0n?Sh0@4100410@0030410@00404=3@`0l
?3`0?3`l04A4A080AdM700@0A4A404Y:BP1:BTX0@4100P0o?cl0101=CDd0@T920492@P11@D420410
@00405aLG010@400@41003lo?`80X:2P00@0Shn?08>3P`23Ph<0Z:RX0P2OWil01031`L40e]KF0=KF
eP3<c<`20<O7a`040;Jf]P3=cLd0cLg=0<_;b`80MgMg00@0=3@d01LG5`0G5aL02PX:0P071`L300D5
1@0000@01@D500H61P061PH020P80P0410@010020P800`<300<30`00000200<30`0400/;2`092@T0
2@T900820P800@4100<01PH600L71`071`L00`000000100410@01@D500D51@00000200820P<010@4
00@00`<300820P020P801`L70P0410@010020P8020P800P820030`<200D51@0400@410030`<00`<3
00@410800P8200@020P800D51@051@D02PX:0P030`<300D51@0400H61P051@D01@D500T92@8020P8
00@010@400T92@092@T01PH60P010@40100<30`02@T900T92@051@D200H61P0400P820061PH01PH6
00820P8010@400@02@T900P8200820P020P80P0=3@d010092@T010@400@410071`L200H61P0400/;
2`0:2PX02PX:00d=3@801`L700@00`<300@4100410@02@T90P0410@0100820P02PX:00X:2P061PH2
00X:2P0400H61P000000000000<30`D010@400@02@T900P8200820P04Q8B0P0R8R80100W9bL09RHV
02HV9P0/;2`20451@@0404a<C00d=3@0=3@d01DE5@801@D500@02@T900X:2P0:2PX00P820P0<30`0
100M7Ad071`L01`L700G5aL202<S8`0403Hf=P0m?Cd0?Cdm04e=C@80Bd];00@0@T9205=CD`1CDe<0
EUIF0P1DE5@0101BDU80>c/k03/k>`15ADD205mOG`0407AdM01XJ6P0J6QX05IFEP80Q8B400@0VYZJ
0820P020P800J6QX0P14A4@01029RHT0VYZJ09ZJVP1oOgl206a/K00408Z:RP2DU9@0U9BD08J6QP80
KVi^00@0HV9R0820P020P800S8b<0P24Q8@01028R8P0MgMg07MgM`1UIFD206QXJ00406ATI01SHf<0
Hf=S051@D080?Shn00@0AdM7055AD@1ADE40ATI60P0m?Cd0101DE5@0D51@051@D00b<S8203De=@04
02/[:`0Y:BT0:BTY02/[:`80;Rh^00@0=CDe02/[:`0[:b/0>SXj0P16ATH0101MGEd0Jf][06][J`1L
G5`205IFEP0404A4A00k>c/0>c/k04=3@`80AdM700@0@41002`/;00/;2`0De=C0P1kNg/0101VIVH0
I6AT06ATI01_Kfl206i^KP04061PH01MGEd0GEeM06=SH`80G5aL00@0BTY:02LW9`0W9bL0820P0P0R
8R80100V9RH0@T920492@P15ADD202TY:@0402/[:`0e=CD0=CDe034a<@80=3@d00@0@d=304M7A`17
AdL0AdM70P11@D40100m?Cd0>CTi03Ti>@0m?Cd60451@@<0A4A40P0m?Cd0100l?3`0@4100410@00j
>SX203De=@<0?clo00@0>c/k03lo?`0o?cl0<C4a0P0h>3P01018B4P0@T920492@P12@T8203dm?@03
03hn?P10@400@41000<0@41000@0@d=303`l?00l?3`0A4A40P17AdL01014A4@0BTY:04Y:BP10@402
03lo?`0404e=C@12@T80@T920451@@80@41000@0G5aL0410@010@400?clo0P2PX:00102?Shl0Ph>3
08>3P`2XZ:P209nOW`040<71`@3Fe]H0e]KF0<c<c080alO700@0][Jf0<g=c@3=cLd0bl_;0P1gMgL0
100d=3@05aLG01LG5`0:2PX200L71`<01@D50000100820P010@400@410030`<200@4100400H61P07
1`L01`L700D51@800P8200<00@4100@4100410@00`061PH0100820P010@400@41000000200820P<0
1@D500@010@400D51@051@D010@40P071`L300@4100400820P051@D01@D500D51@801`L700@00@41
00820P020P8010@40P051@D300820P0400D51@071`L01`L700H61P801@D500<00`<300T92@092@T0
0`051@D300<30`0400H61P0<30`030`<00/;2`8010@40`051@D0100410@020P800P820092@T200<3
0`0400820P0;2`/02`/;00l?3`801@D500@00P8200H61P061PH01@D50P071`L0100:2PX010@400@4
10061PH200X:2P0400d=3@071`L01`L700D51@800P8200@02PX:00`<300<30`0410@0P010@401003
0`<010@400@4100410@200<30`04000000061PH01PH600H61P8010@400@020P800H61P061PH0410@
0P0S8b<0100[:b/0;bl_02l_;`0i>CT304a<C080:BTY00@0410@00P8200820P00`<30P0;2`/01004
10@03@d=00d=3@0K6a/2024Q8@0402@T900X:2P0:2PX03lo?`80@41000@0BTY:05UIF@1IFET0Fe]K
0P1MGEd0101VIVH0HF5Q065QH@1IFET205YJFP0406m_K`1QHF40HF5Q05YJFP80GUiN00@0?3`l059B
DP1BDU80Ph>30P1hN7P0101_Kfl0D51@051@D01hN7P207IfMP04065QH@1[Jf/0Jf][07AdM080P820
00@0NGUi05eMG@1MGEd0JFUY0P29RHT01026QXH0L71`071`L01`L70206a/K00407YjNP23Ph<0Ph>3
06][J`80GemO00@0F5QH061PH01PH600K6a/0P1SHf<0101KFe/0CTi>04i>CP1BDU82051@D00403dm
?@0h>3P0>3Ph02LW9`80:RXZ00@0:b/[02DU9@0U9BD06a/K0P0P8200100f=SH0BTY:04Y:BP1/K6`2
07YjNP0405eMG@1@D500D51@051@D080@T9200@0?Shn03lo?`0o?cl0A4A40P0h>3P0101IFET0MGEe
07EeM@1OGel206UYJ@0407AdM01VIVH0IVIV05ADE080De=C00@0F5QH05MGE`1GEeL0CDe=0P0l?3`0
100_;bl0:2PX02PX:00/;2`202/[:`0403lo?`0m?Cd0?Cdm038b<P80ATI600@0?Cdm038b<P0b<S80
A4A40P1ADE401013@d<0@D510451@@10@40203Ti>@<0@41000<0@T9204];B`1;Bd/00`17AdL01015
ADD0>CTi03Ti>@0k>c/20492@P0403hn?P0o?cl0?clo04I6AP<0@4100P14A4@01011@D40@T920492
@P19BDT20492@P040451@@0l?3`0?3`l03Xj>P80?Shn00@0ADE504Q8B018B4P0A4A40P0h>3P0100n
?Sh0AdM704M7A`11@D4204U9B@040410@014A4@0A4A404e=C@80@41000@0@T9204a<C01<C4`0Hf=S
0P0W9bL0101@D500[jn_0:n_[`1mOGd20820P0040:JVYP2[Zj/0Zj^[0<C4a080b/[:00@0d=3@0<o?
c`3?cll0^[Zj0P32`/80102k^k/0RHV908V9R@1ADE4202<S8`0400X:2P0410@010@400@410801PH6
000010030`<01@D500D51@051@D200<30`0300P820051@D01@D500<01@D500@010@400H61P061PH0
10@40P071`L00`051@D00`<300<30`0300410@040000000410@010@400H61P801@D500@00P8200/;
2`0;2`/00@410`020P8200410@0300<30`051@D01@D500<01@D500@010@400T92@092@T010@40P07
1`L010051@D01PH600H61P071`L200@4100400820P061PH01PH6000000802@T900@00`<300@41004
10@01`L70P0:2PX010051@D020P800P820051@D200820P0400H61P030`<00`<300H61P802`/;00@0
20P800T92@092@T020P80P0410@010092@T02`/;00/;2`030`<200D51@0400T92@071`L01`L700L7
1`8010@400@02PX:00@4100410@00@410P020P8010051@D020P800P820092@T200D51@0400<30`02
0P800P8200<30`801@D50`030`<010092@T01@D500D51@051@D200T92@0401@D500X:2P0:2PX03Ph
>080=cLg00@0<c<c04M7A`17AdL0D51@0P0[:b/0100<30`01`L700L71`061PH200D51@0400<30`0>
3Ph03Ph>01@D50807QhN00@0;bl_038b<P0b<S80@D510P10@4001012@T80EUIF05IFEP1/K6`206i^
KP0407=cL`1^KVh0KVi^06ATI080KVi^00@0Ph>306YZJP1ZJVX0Cdm?0P1[Jf/0101YJFT0F5QH05QH
F01EEED204=3@`0405MGE`1JFUX0FUYJ07IfMP80Lg=c00@0IFEU07inOP1nOWh0OWin0P1lO7`0101k
Ng/0IfMW06MWI`1SHf<207]kN`0408N7Q`20P800P82007emO@80Ng]k00@0MWIf06][J`1[Jf/0IfMW
0P1eMGD0101mOGd0O7al07alO01SHf<205IFEP0405iNGP1<C4`0C4a<04m?C`80FEUI00@0ADE502h^
;P0^;Rh071`L0P0X:2P0100_;bl09RHV02HV9P0F5QH202HV9P0403<c<`10@400@41005MGE`80Lg=c
00@0K6a/04U9B@19BDT0CDe=0P1;Bd/0100l?3`0@4100410@019BDT202l_;`0405=CD`1nOWh0OWin
06][J`80NWYj00@0QXJ605]KF`1KFe/0?clo0P1=CDd0101NGUh0E5AD05ADE013@d<203Xj>P0403De
=@0[:b/0:b/[024Q8@80:BTY00@0<30`03Lg=`0g=cL0?3`l0P1@D500101:BTX0?Cdm03dm?@1=CDd2
05ADE0040451@@0k>c/0>c/k03lo?`80@D5100@0ATI603lo?`0o?cl0?clo0P1:BTX0101=CDd0B4Q8
04Q8B011@D4203/k>`0403hn?P12@T80@T920410@080ADE500<0BTY:0492@P12@T800`0o?cl01010
@400ADE504E5A@17AdL203lo?`0403hn?P10@400@41004M7A`<0BDU90P1;Bd/0101:BTX0@4100410
@00n?Sh203lo?`0403Lg=`13@d<0@d=30410@080BDU900@0@T9203lo?`0o?cl0@T920P19BDT0101K
Fe/05aLG01LG5`1gMgL20;Ng]`0406YZJP2>SXh0SXj>0:BTY080ZZZZ00@0_kno0<G5a@35aLD0c/k>
0P33`l<01037alL0aLG50<G5a@30`<020:f][@0405YJFP0E5AD05ADE00D51@D010@4000010030`<0
1@D500D51@051@D200<30`0300P820051@D01@D500<01@D500@010@400H61P061PH010@40P071`L0
0`051@D00`<300<30`0300410@040000000410@010@400H61P801@D500@00P8200/;2`0;2`/00@41
0`020P8200410@0300<30`051@D01@D500<01@D500@010@400T92@092@T010@40P071`L010051@D0
1PH600H61P071`L200@4100400820P061PH01PH6000000802@T900@00`<300@4100410@01`L70P0:
2PX010051@D020P800P820051@D200820P0400H61P030`<00`<300H61P802`/;00@020P800T92@09
2@T020P80P0410@010092@T02`/;00/;2`030`<200D51@0400T92@071`L01`L700L71`8010@400@0
2PX:00@4100410@00@410P020P8010051@D020P800P820092@T200D51@0400<30`020P800P8200<3
0`801@D50`030`<010092@T01@D500D51@051@D200T92@0401@D500X:2P0:2PX03Ph>080=cLg00@0
<c<c04M7A`17AdL0D51@0P0[:b/0100<30`01`L700L71`061PH200D51@0400<30`0>3Ph03Ph>01@D
50807QhN00@0;bl_038b<P0b<S80@D510P10@4001012@T80EUIF05IFEP1/K6`206i^KP0407=cL`1^
KVh0KVi^06ATI080KVi^00@0Ph>306YZJP1ZJVX0Cdm?0P1[Jf/0101YJFT0F5QH05QHF01EEED204=3
@`0405MGE`1JFUX0FUYJ07IfMP80Lg=c00@0IFEU07inOP1nOWh0OWin0P1lO7`0101kNg/0IfMW06MW
I`1SHf<207]kN`0408N7Q`20P800P82007emO@80Ng]k00@0MWIf06][J`1[Jf/0IfMW0P1eMGD0101m
OGd0O7al07alO01SHf<205IFEP0405iNGP1<C4`0C4a<04m?C`80FEUI00@0ADE502h^;P0^;Rh071`L
0P0X:2P0100_;bl09RHV02HV9P0F5QH202HV9P0403<c<`10@400@41005MGE`80Lg=c00@0K6a/04U9
B@19BDT0CDe=0P1;Bd/0100l?3`0@4100410@019BDT202l_;`0405=CD`1nOWh0OWin06][J`80NWYj
00@0QXJ605]KF`1KFe/0?clo0P1=CDd0101NGUh0E5AD05ADE013@d<203Xj>P0403De=@0[:b/0:b/[
024Q8@80:BTY00@0<30`03Lg=`0g=cL0?3`l0P1@D500101:BTX0?Cdm03dm?@1=CDd205ADE0040451
@@0k>c/0>c/k03lo?`80@D5100@0ATI603lo?`0o?cl0?clo0P1:BTX0101=CDd0B4Q804Q8B011@D42
03/k>`0403hn?P12@T80@T920410@080ADE500<0BTY:0492@P12@T800`0o?cl01010@400ADE504E5
A@17AdL203lo?`0403hn?P10@400@41004M7A`<0BDU90P1;Bd/0101:BTX0@4100410@00n?Sh203lo
?`0403Lg=`13@d<0@d=30410@080BDU900@0@T9203lo?`0o?cl0@T920P19BDT0101KFe/05aLG01LG
5`1gMgL20;Ng]`0406YZJP2>SXh0SXj>0:BTY080ZZZZ00@0_kno0<G5a@35aLD0c/k>0P33`l<01037
alL0aLG50<G5a@30`<020:f][@0405YJFP0E5AD05ADE00D51@D010@4000010051@D020P800P8200;
2`/200D51@0400H61P0820P020P800<30`<01`L70P051@D00`030`<010@400@4100300D51@0400@4
10030`<00`<300410@8010@400@01PH600P8200820P000000P051@D0100410@020P800P820030`<2
00L71`0400D51@0820P020P800P820800P8200@010@40000000000001@D50`0410@200410@<010@4
00@01PH600@4100410@00`<30P051@D010030`<02@T900T92@0:2PX200H61P0400820P051@D01@D5
00D51@D010@400@02PX:00`<300<30`02`/;0P0410@0100000002PX:00X:2P0>3Ph200T92@0400<3
0`061PH01PH600@4108020P800@03Ph>00L71`071`L02PX:0P0820P300@4100400<30`0410@010@4
00410@800`<300@01@D500L71`071`L01`L70P000000100410@00P8200820P061PH200D51@<01PH6
00@05QHF02LW9`0W9bL0<C4a0P0b<S80100S8b<0>CTi03Ti>@1>CTh202HV9P0400410@071`L01`L7
00`<30800`<300<01PH601DE5@0E5AD00`0H61P0100W9bL0;Rh^02h^;P0k>c/204I6AP040492@P10
@400@41004m?C`80GEeM00@0HF5Q07=cL`1cLg<0NWYj0P1MGEd0101LG5`0Lg=c07=cL`1[Jf/207=c
L`0408f=S@1mOGd0OGem05UIF@80D51@00@0HV9R06e]K@1]KFd0QXJ60P2CTi<01026QXH0Rh^;08^;
R`2@T90207UiN@0406MWI`1XJ6P0J6QX06e]K@80P82000@0MgMg06][J`1[Jf/0LW9b0P1eMGD0101V
IVH0IFEU06EUI@20P80208b<S00407]kN`1WIfL0IfMW06EUI@80MWIf00@0Ng]k06EUI@1UIFD0De=C
0P16ATH0100k>c/0=SHf03Hf=P0k>c/203`l?004030`<00c<c<0<c<c02/[:`80:BTY00@092@T03Ph
>00h>3P0<30`0P1GEeL0101lO7`0DU9B059BDP1:BTX204Q8B00403<c<`0m?Cd0?Cdm04Q8B080=3@d
00@0GEeM08F5Q@25QHD0M7Ad0P1mOGd00`23Ph<0HV9R069RHP0304M7A`0405EEE@1CDe<0De=C04M7
A`80?Cdm00@0>SXj038b<P0b<S8092@T0P0V9RH302TY:@0403Ti>@1ADE40DE5A04=3@`80=SHf00@0
CTi>051@D01@D500@4100P0o?cl0101:BTX0Bd];04];B`0n?Sh203/k>`0403dm?@14A4@0A4A404e=
C@80B4Q80`13@d<30492@P0404A4A01;Bd/0Bd];04];B`80@D5100@0@d=304A4A014A4@0@4100P17
AdL0101=CDd0B4Q804Q8B013@d<20451@@0404e=C@18B4P0B4Q804M7A`<0CDe=0P11@D401010@400
@d=304=3@`13@d<304M7A`80BTY:00@0?clo0492@P12@T80@D510P16ATH01019BDT071`L01`L702F
UYH209nOW`0405iNGP2KVi/0Vi^K09VIV@80Xj>S00@0_kno0<71`@31`L40alO70P2n_[h0103@d=00
`l?30<?3``34a<@20;Fe]@0404E5A@000000000000@410801`L70@0410@100820P400P82000300@4
100400<30`092@T02@T900<30`800@4100@00`<300D51@051@D01@D50P020P8010010@401PH600H6
1P061PH200@4100400D51@071`L01`L700<30`801PH600<01@D500410@010@400`051@D300H61P04
00410@0;2`/02`/;00`<30<010@40P030`<010071`L00`<300<30`0410@200410@0300@410010@40
0@4100<01`L700@01@D500H61P061PH00`<30P0;2`/010092@T00000000000020P8200D51@0300H6
1P0410@010@400<020P800@00P8200L71`071`L01@D50P00000010020P800`<300<30`051@D200T9
2@0400<30`000000000000P820802PX:00@00@4100L71`071`L02@T90P0410@0100820P030`<00`<
300<30`200T92@0400D51@0820P020P800X:2P<01@D50P030`<010051@D02@T900T92@061PH200L7
1`0400H61P051@D01@D500@41080000000@05aLG02PX:00X:2P0:RXZ0P0a<C40100/;2`0;Rh^02h^
;P0h>3P202PX:004014A4@0?3`l03`l?00X:2P800`<300@02PX:00h>3P0>3Ph04A4A0P0L71`0100T
92@0;Rh^02h^;P18B4P205MGE`040492@P0d=3@0=3@d04E5A@80G5aL00@0FUYJ06=SH`1SHf<0JFUY
0P1MGEd0101BDU80KFe]06e]K@20P80207=cL`0407]kN`1gMgL0MgMg05]KF`80M7Ad00@0PX:207Qh
N01hN7P0Ng]k0P1eMGD0101/K6`0PX:208:2PP2CTi<2079bLP0406EUI@1bLW80LW9b0820P080R8R8
00@0JVYZ079bLP1bLW80PH610P1hN7P0101WIfL0MWIf07IfMP29RHT208>3P`03079bLP1[Jf/0Jf][
00<0LG5a00@0KFe]06m_K`1_Kfl0JVYZ0P1WIfL0101VIVH0BTY:04Y:BP1<C4`203/k>`0402DU9@0Y
:BT0:BTY030`<080:b/[00@08B4Q03Xj>P0j>SX0<c<c0P0m?Cd0101WIfL0EeMG05MGE`10@40204E5
A@0403dm?@0k>c/0>c/k04A4A080ADE500@0H61P07moO`1oOgl0LW9b0P1]KFd0101cLg<0IfMW06MW
I`1FEUH204M7A`0404m?C`1FEUH0EUIF04Q8B080@D5100@0?clo03@d=00d=3@0<C4a0P0c<c<0100_
;bl0<S8b038b<P0l?3`204m?C`040492@P0j>SX0>SXj04U9B@80@D5100@0@41004A4A014A4@0ATI6
0P15ADD0100j>SX0?3`l03`l?00m?Cd20492@P0404e=C@1:BTX0BTY:04Y:BP80Cdm?00@0C4a<0492
@P12@T80?clo0P13@d<01017AdL0BTY:04Y:BP1<C4`304I6AP80BDU900@0AdM704];B`1;Bd/0CDe=
0P13@d<01019BDT0Bd];04];B`1;Bd/2055AD@0404e=C@11@D40@D5104A4A080B4Q80`19BDT01017
AdL0B4Q804Q8B014A4@204Q8B0040451@@1=CDd0CDe=03@d=080:b/[00@0/K6a08j>SP2>SXh0Hf=S
0P2DU9@0102GUiL0WIfM09fMW@2`/;020;no_`040<K6aP39bLT0bLW90=SHf080d=3@00@0g]kN0;no
_`2o_kl0?clo0`051@D500<30`000`0410@010030`<02@T900T92@030`<200410@0400<30`051@D0
1@D500D51@800P8200@00@4100H61P061PH01PH60P0410@010051@D01`L700L71`030`<200H61P03
00D51@010@400@4100<01@D50`061PH010010@402`/;00/;2`0<30`300@410800`<300@01`L700<3
0`030`<010@40P010@400`0410@00@4100410@0300L71`0400D51@061PH01PH600<30`802`/;00@0
2@T90000000000000P820P051@D00`061PH010@400@4100300P8200400820P071`L01`L700D51@80
000000@00P8200<30`030`<01@D50P092@T010030`<000000000000820P200X:2P0400410@071`L0
1`L700T92@8010@400@020P800`<300<30`030`<0P092@T010051@D020P800P8200:2PX300D51@80
0`<300@01@D500T92@092@T01PH60P071`L010061PH01@D500D51@0410@20000000401LG5`0X:2P0
:2PX02XZ:P80<C4a00@0;2`/02h^;P0^;Rh0>3Ph0P0X:2P0100A4A403`l?00l?3`0:2PX200<30`04
00X:2P0>3Ph03Ph>014A4@8071`L00@092@T02h^;P0^;Rh0B4Q80P1GEeL01012@T80=3@d03@d=015
ADD205aLG00405YJFP1SHf<0Hf=S06UYJ@80GEeM00@0DU9B06e]K@1]KFd0P8200P1cLg<0101kNg/0
MgMg07MgM`1KFe/207AdM00408:2PP1hN7P0N7Qh07]kN`80MGEe00@0K6a/08:2PP22PX80Ti>C0P1b
LW80101UIFD0LW9b079bLP20P80208R8R00406YZJP1bLW80LW9b0861P@80N7Qh00@0IfMW07IfMP1f
MWH0RHV90P23Ph<00`1bLW80Jf][06][J`03075aL@0406e]K@1_Kfl0Kfm_06YZJP80IfMW00@0IVIV
04Y:BP1:BTX0C4a<0P0k>c/0100U9BD0:BTY02TY:@0`<30202/[:`04024Q8@0j>SX0>SXj03<c<`80
?Cdm00@0IfMW05MGE`1GEeL0@4100P15ADD0100m?Cd0>c/k03/k>`14A4@204E5A@04061PH01oOgl0
Ogmo079bLP80KFe]00@0Lg=c06MWI`1WIfL0EUIF0P17AdL0101?Cdl0EUIF05IFEP18B4P20451@@04
03lo?`0d=3@0=3@d034a<@80<c<c00@0;bl_038b<P0b<S80?3`l0P1?Cdl01012@T80>SXj03Xj>P19
BDT20451@@040410@014A4@0A4A404I6AP80ADE500@0>SXj03`l?00l?3`0?Cdm0P12@T80101=CDd0
BTY:04Y:BP1:BTX204m?C`0404a<C012@T80@T9203lo?`80@d=300@0AdM704Y:BP1:BTX0C4a<0`16
ATH204U9B@0404M7A`1;Bd/0Bd];04e=C@80@d=300@0BDU904];B`1;Bd/0Bd];0P1ADE40101=CDd0
@D510451@@14A4@204Q8B0<0BDU900@0AdM704Q8B018B4P0A4A40P18B4P01011@D40CDe=04e=C@0d
=3@202/[:`040;6a/@2>SXh0SXj>06=SH`80U9BD00@0UiNG09fMW@2MWId0/;2`0P2o_kl01036a/H0
bLW90<W9b@3Hf=P20=3@d0040=kNgP2o_kl0_kno03lo?`<01@D51@030`<000<01@D500@00P8200L7
1`071`L01@D50P0410@00`051@D00P8200820P0300H61P0400<30`071`L01`L700410@8010@400@0
1@D500L71`071`L000000P061PH010092@T020P800P8200820P200D51@030000000<30`030`<00<0
0P8200@01PH600@4100410@00@410P030`<010092@T00`<300<30`092@T200@4100400H61P010@40
0@4100D51@800@4100@00`<300@4100410@01PH60P092@T00`051@D00`<300<30`0300820P<00`<3
00@010@400<30`030`<01@D50P0:2PX010071`L01PH600H61P0820P200@4100400X:2P092@T02@T9
00820P800@4100@010@400P8200820P010@40P071`L0100=3@d01`L700L71`0410@200D51@0400/;
2`0820P020P800P820<01@D50P061PH300D51@0400H61P0<30`030`<00L71`<00`<30P020P801001
0@400`<300<30`0H61P202`/;00402h^;P0g=cL0=cLg04I6AP80?clo00@09BDU028R8P0R8R8051@D
0P071`L010051@D02`/;00/;2`0:2PX200H61P0400/;2`0U9BD09BDU02TY:@806a/K00@0=CDe0492
@P12@T80=3@d0P0c<c<0101EEED0LG5a075aL@1ZJVX206ATI00406=SH`1KFe/0Fe]K04e=C@80Fe]K
00@0RHV908Z:RP2:RXX0Kfm_0P1UIFD0101HF5P0KFe]06e]K@20P80206IVIP0405iNGP1nOWh0OWin
08^;R`80RHV900@0NWYj06a/K01/K6`0O7al0P1cLg<0101gMgL0N7Qh07QhN01_Kfl208B4Q00407mo
O`1mOGd0OGem08F5Q@80Ng]k00@0KVi^06IVIP1VIVH0JVYZ0P1/K6`0101^KVh0OWin07inOP1iNGT2
069RHP0406e]K@20P800P820071`L080D51@00@0H61P04A4A014A4@0:b/[0`0b<S8202HV9P0401dM
7@0R8R808R8R03Hf=P80:2PX00@0Bd];06ATI01TI6@0@d=30P15ADD0101;Bd/0@4100410@012@T82
04I6AP04059BDP1nOWh0OWin07]kN`80NGUi00@0QhN7075aL@1aLG40H61P0P1@D5000`1>CTh0EUIF
05IFEP0304E5A@040410@00g=cL0=cLg03Lg=`80>CTi00@0>SXj03Ti>@0i>CT0@D510P1?Cdl01013
@d<0>CTi03Ti>@0l?3`203Xj>P0303/k>`0m?Cd0?Cdm00<0@41000@0?clo04E5A@15ADD0BTY:0P1?
Cdl0101:BTX0@T920492@P18B4P204e=C@0404U9B@10@400@4100410@080ADE500@0A4A404i>CP1>
CTh0C4a<0P10@4001018B4P0BDU904U9B@13@d<204Q8B004059BDP1:BTX0BTY:04];B`80CDe=00@0
BDU904e=C@1=CDd0ATI60P15ADD00`17AdL0@d=304=3@`0304];B`040410@016ATH0ATI604a<C080
@d=300@0?3`l059BDP1BDU80:BTY0P10@4001030`<00Ng]k07]kN`1/K6`20::RXP040:b/[02WYjL0
YjNW0;Fe]@80cLg=00@0c/k>0=;BdP3Bd]80d];B0P3MgMd0103Vi^H0YJFU0:FUY@0i>CT200P82004
00D51@061PH01PH600/;2`801`L7000010030`<010@400@41000000200<30`0400H61P020P800P82
00410@801`L700@010@400H61P061PH00`<30P061PH010030`<01@D500D51@061PH200D51@<00P82
00<010@400X:2P0:2PX010020P8200P8200400820P030`<00`<300<30`800@4100@00P8200@41004
10@01PH60P051@D010030`<01@D500D51@030`<200820P0400<30`020P800P8200H61P801`L700@0
2`/;00<30`030`<01@D50P071`L00`030`<00P8200820P0300@410<00`<300<00P8200@4100410@0
0`051@D0100<30`02@T900T92@061PH200L71`0400410@071`L01`L700L71`801PH600@00`<300@4
100410@02@T90P0<30`0100000000@4100410@051@D200H61P0400@410030`<00`<300410@8010@4
00@01PH600D51@051@D00`<30P061PH010051@D00`<300<30`0410@200<30`040000000410@010@4
014A4@8092@T00@0=CDe0451@@11@D40De=C0P16ATH0100P82005aLG01LG5`0=3@d200L71`0400P8
200=3@d03@d=00L71`801PH600@030`<01XJ6P0J6QX09RHV0P0Z:RX0100e=CD0;Bd]02d];@0];Bd2
030`<00404a<C01TI6@0I6AT06MWI`<0Jf][0P1RHV80101?Cdl0CDe=04e=C@1eMGD20820P00405MG
E`1ADE40DE5A06IVIP80IfMW0`1YJFT0101TI6@0Ph>308>3P`20P80206QXJ004065QH@1cLg<0Lg=c
07alO080IFEU00@0J6QX05eMG@1MGEd0HV9R0P1bLW80101ZJVX0O7al07alO027QhL2071`L00406][
J`1lO7`0O7al08B4Q080MWIf00@0LG5a09:BTP2BTY80UiNG0P1/K6`0101SHf<0L71`071`L01SHf<2
069RHP0407EeM@1XJ6P0J6QX055AD@80>SXj00@08b<S028R8P0R8R809BDU0P0A4A40100^;Rh0:2PX
02PX:00^;Rh205aLG00404a<C015ADD0ADE504];B`<0@4100P18B4P0100l?3`0IVIV06IVIP21PH42
08f=S@0409bLW01nOWh0OWin06a/K080HF5Q00@0C4a<04m?C`1?Cdl0Bd];0P17AdL0100k>c/0>CTi
03Ti>@0d=3@203Lg=`040410@00l?3`0?3`l04=3@`80B4Q800@0?Cdm03Ph>00h>3P0=SHf0`17AdL2
03hn?P040492@P15ADD0ADE504Y:BP80BDU900@0Bd];04a<C01<C4`0A4A40P16ATH0101;Bd/0ATI6
04I6AP13@d<204M7A`0404a<C016ATH0ATI604I6AP80Bd];00@0@T9204A4A014A4@0CDe=0P18B4P0
101:BTX0Cdm?04m?C`1<C4`204I6AP0404Q8B019BDT0BDU904E5A@80B4Q800@0@T9204A4A014A4@0
@4100P0j>SX01014A4@0@d=304=3@`13@d<204M7A`0404a<C018B4P0B4Q80451@@80CDe=00@0820P
05IFEP1FEUH0/[:b0P1UIFD0101eMGD0[Zj^0:j^[P2][Jd20;Jf]P040<W9b@3AdM40dM7A0=7Ad@80
g]kN00@0eMGE0>[ZjP3Zj^X0f][J0P1mOGd0100d=3@04A4A014A4@0820P200<30`402@T90@0;2`/1
00/;2`0000@00`<300@4100410@000000P030`<010061PH00P8200820P010@4200L71`0400@41006
1PH01PH600<30`801PH600@00`<300D51@051@D01PH60P051@D300820P0300@4100:2PX02PX:00@0
0P820P0820P010020P800`<300<30`030`<200410@0400820P0410@010@400H61P801@D500@00`<3
00D51@051@D00`<30P020P8010030`<00P8200820P061PH200L71`0400/;2`030`<00`<300D51@80
1`L700<00`<300820P020P800`0410@300<30`0300820P0410@010@400<01@D500@030`<00T92@09
2@T01PH60P071`L010010@401`L700L71`071`L200H61P0400<30`0410@010@400T92@8030`<00@0
000000410@010@401@D50P061PH0100410@00`<300<30`010@4200@4100400H61P051@D01@D500<3
0`801PH600@01@D500<30`030`<010@40P030`<01000000010@400@4100A4A4202@T900403De=@11
@D40@D5105=CD`80ATI600@0820P01LG5`0G5aL03@d=0P071`L0100820P03@d=00d=3@071`L200H6
1P0400`<300J6QX06QXJ02HV9P80:RXZ00@0=CDe02d];@0];Bd0;Bd]0P0`<300101<C4`0I6AT06AT
I01WIfL306][J`80HV9R00@0Cdm?04e=C@1=CDd0MGEe0P20P800101GEeL0DE5A055AD@1VIVH206MW
I`<0JFUY00@0I6AT08>3P`23Ph<0P8200P1XJ6P0101QHF40Lg=c07=cL`1lO7`206EUI@0406QXJ01M
GEd0GEeM069RHP80LW9b00@0JVYZ07alO01lO7`0QhN70P1`L700101[Jf/0O7al07alO024Q8@207If
MP04075aL@2BTY80TY:B09NGU`80K6a/00@0Hf=S071`L01`L700Hf=S0P1RHV80101eMGD0J6QX06QX
J01ADE4203Xj>P0402<S8`0R8R808R8R02DU9@804A4A00@0;Rh^02PX:00X:2P0;Rh^0P1LG5`0101<
C4`0ADE504E5A@1;Bd/30410@080B4Q800@0?3`l06IVIP1VIVH0PH610P2=SHd0102LW9`0OWin07in
OP1/K6`2065QH@0404a<C01?Cdl0Cdm?04];B`80AdM700@0>c/k03Ti>@0i>CT0=3@d0P0g=cL01010
@400?3`l03`l?013@d<204Q8B00403dm?@0h>3P0>3Ph03Hf=P<0AdM70P0n?Sh01012@T80ADE504E5
A@1:BTX204U9B@0404];B`1<C4`0C4a<04A4A080ATI600@0Bd];04I6AP16ATH0@d=30P17AdL0101<
C4`0ATI604I6AP16ATH204];B`040492@P14A4@0A4A404e=C@80B4Q800@0BTY:04m?C`1?Cdl0C4a<
0P16ATH01018B4P0BDU904U9B@15ADD204Q8B0040492@P14A4@0A4A40410@080>SXj00@0A4A404=3
@`13@d<0@d=30P17AdL0101<C4`0B4Q804Q8B011@D4204e=C@04020P801FEUH0EUIF0;:b/P80IFEU
00@0MGEe0:j^[P2^[Zh0[Jf]0P2f][H01039bLT0dM7A0=7Ad@3AdM420=kNgP040=GEe@3Zj^X0j^[Z
0=[JfP80OGem00@0=3@d014A4@0A4A4020P80P030`<100T92@402`/;0@0;2`/0000400@410020P80
0P8200L71`8010@400@01PH600<30`030`<00@410P071`L00`030`<00@4100410@0300H61P0400L7
1`0410@010@400@410<01PH60P030`<0100820P010@400@410030`<200@4100400H61P010@400@41
00H61P8010@400@01@D500<30`030`<020P80`061PH200L71`0400<30`000000000000<30`801@D5
00@00P8200H61P061PH00@410P051@D0100820P00P8200820P0410@200D51@0400H61P0820P020P8
00D51@8010@400@00P8200<30`030`<01PH60P051@D010061PH00@4100410@010@4200D51@0400<3
0`000000000000410@8020P800@030`<00D51@051@D00`<30P0410@010071`L03Ph>00h>3P030`<2
00D51@0400@410051@D01@D500D51@801PH60`0410@010092@T010@400@410010@4200<30`0400@4
10092@T02@T900X:2P801@D50`061PH0100A4A409bLW02LW9`0i>CT204Q8B00404e=C@0k>c/0>c/k
02@T908051@D00@03@d=018B4P0B4Q801`L70P0820P0100;2`/02@T900T92@092@T200`<300401`L
700V9RH09RHV02`/;080:RXZ00@0A4A404i>CP1>CTh0EEEE0P1BDU80101DE5@0FEUI05UIF@1FEUH2
05mOG`0405iNGP1LG5`0G5aL06YZJP80M7Ad00@0IVIV04U9B@19BDT0E5AD0P1/K6`0101PH600NGUi
07UiN@1kNg/207emO@0408R8R024Q8@0Q8B408J6QP80Lg=c00@0H61P06a/K01/K6`0JVYZ0P1WIfL0
1028R8P0QhN708N7Q`1gMgL206i^KP0406UYJ@1bLW80LW9b0861P@80TI6A00@0U9BD07QhN01hN7P0
I6AT0P1iNGT01020P800Kfm_06m_K`1dM7@2079bLP0406QXJ025QHD0QHF508:2PP80IfMW00@0F5QH
05ADE01DE5@0A4A40P0f=SH0100K6a/061PH01PH600[:b/2038b<P0401`L700c<c<0<c<c0492@P80
AdM700@0C4a<04=3@`13@d<0@4100P1BDU801012@T80Bd];04];B`1hN7P208f=S@0409fMW@2@T900
T92@07=cL`80K6a/00@0FEUI04U9B@19BDT0ADE50P12@T800`0j>SX0=cLg03Lg=`0303De=@0403hn
?P0l?3`0?3`l0451@@80BDU900@0@T9204M7A`17AdL0<c<c0P10@4001019BDT0>SXj03Xj>P0k>c/2
04E5A@0405EEE@1;Bd/0Bd];0451@@80@T9200@0C4a<055AD@1ADE40Bd];0P12@T801016ATH0BDU9
04U9B@13@d<203hn?P0404i>CP1?Cdl0Cdm?0410@080BTY:00@0BDU903lo?`0o?cl0BTY:0P1BDU80
101;Bd/0B4Q804Q8B01;Bd/204Y:BP0304E5A@19BDT0BDU900<0ATI600@0@T9204A4A014A4@0B4Q8
0P19BDT0101DE5@0BDU904U9B@17AdL204Y:BP0404I6AP0m?Cd0?Cdm01lO7`80Lg=c00@0VYZJ05eM
G@1MGEd0Ogmo0P2[Zj/00`2WYjL0`<300<30`0030=cLg0040=CDe03Kfm/0fm_K0=GEe@80inOW00@0
_;bl05YJFP1JFUX0<S8b0P0D51@010071`L01PH600H61P092@T200l?3`0000@00`<300410@010@40
20P80P010@4300D51@0400P820030`<00`<300<30`801@D500@01PH600P8200820P01`L70P030`<0
100410@00`<300<30`061PH200L71`0400/;2`030`<00`<300@410803@d=00@010@400P8200820P0
20P80`051@D500<30`<01@D500<02PX:00L71`071`L00`051@D300X:2P0400H61P092@T02@T900P8
20801@D500@00@4100D51@051@D02PX:0P0820P00`051@D010@400@4100300@4100400X:2P071`L0
1`L700D51@801PH600<00P8200@4100410@00`030`<0100000000P8200820P051@D200820P040041
0@000000000000410@801PH600@00`<300D51@051@D00`<30P061PH010051@D00`<300<30`020P82
00<30`0400D51@030`<00`<300820P8010@400@01@D500/;2`0;2`/02PX:0P030`<010092@T03`l?
00l?3`0I6AT202`/;00403Lg=`16ATH0ATI604I6AP80=SHf00@09bLW014A4@0A4A400P820P0=3@d0
100;2`/01`L700L71`0;2`/200<30`0400D51@0A4A404A4A01lO7`809RHV0`0[:b/0100l?3`0@410
0410@019BDT2051@D00405UIF@1KFe/0Fe]K05QHF080H61P00@0Jf][07YjNP1jNWX0LG5a0P1XJ6P0
1020P800Lg=c07=cL`1VIVH208:2PP0407=cL`1fMWH0MWIf07YjNP80RHV900@0WinO08:2PP22PX80
N7Qh0P1PH600101WIfL0KVi^06i^KP1bLW8306m_K`80JFUY00@0GUiN06QXJ01XJ6P0PH610P2CTi<0
1027QhL0MgMg07MgM`1eMGD206QXJ00405iNGP1^KVh0KVi^07IfMP<0JVYZ0P1UIFD0101XJ6P0Shn?
08n?S`1lO7`205eMG@0405MGE`1ADE40DE5A05MGE`80@D5100@02`/;018B4P0B4Q804Q8B0P0Q8B40
100K6a/071`L01`L700h>3P20410@00404M7A`19BDT0BDU903Xj>P80ADE500@0F5QH04a<C01<C4`0
IFEU0P25QHD0102KVi/0WinO09nOW`1kNg/206IVIP0405]KF`16ATH0ATI60451@@80?3`l00@0>3Ph
03/k>`0k>c/0@d=30P0m?Cd0100i>CT0?Cdm03dm?@14A4@204a<C00403lo?`12@T80@T9203@d=080
<S8b00@0?Cdm03De=@0e=CD0@4100P13@d<00`1<C4`0Bd];04];B`0304Y:BP04059BDP1@D500D51@
04M7A`80BDU900@0DE5A04U9B@19BDT0@T920P14A4@0101;Bd/0B4Q804Q8B01<C4`205ADE00404Y:
BP16ATH0ATI604];B`80CTi>00@0Bd];04Q8B018B4P0Bd];0P19BDT01016ATH0Bd];04];B`17AdL2
04Q8B00404U9B@1:BTX0BTY:04M7A`80Bd];00@0DE5A04E5A@15ADD0ATI60P13@d<01014A4@0=SHf
03Hf=P0`<30208j>SP0408n?S`1JFUX0FUYJ08f=S@80/;2`00@0YJFU0<;2`P32`/80g]kN0P3IfMT0
103GemL0cLg=0<g=c@39bLT20=SHf0040;Vi^@1TI6@0I6AT03De=@805ADE00@010@400L71`071`L0
1`L70P061PH0000400<30`010@400@4100P820800@410`051@D0100820P00`<300<30`030`<200D5
1@0400H61P0820P020P800L71`800`<300@010@400<30`030`<01PH60P071`L0100;2`/00`<300<3
0`0410@200d=3@0400@4100820P020P800P820<01@D51@030`<300D51@0300X:2P071`L01`L700<0
1@D50`0:2PX010061PH02@T900T92@0820P200D51@0400410@051@D01@D500X:2P8020P800<01@D5
00@4100410@00`0410@0100:2PX01`L700L71`051@D200H61P0300820P0410@010@400<00`<300@0
000000820P020P801@D50P020P8010010@400000000000010@4200H61P0400<30`051@D01@D500<3
0`801PH600@01@D500<30`030`<00P820P030`<010051@D00`<300<30`020P8200@4100400D51@0;
2`/02`/;00X:2P800`<300@02@T900l?3`0?3`l06ATI0P0/;2`0100g=cL0ATI604I6AP16ATH203Hf
=P0402LW9`0A4A404A4A00820P803@d=00@02`/;00L71`071`L02`/;0P030`<010051@D04A4A014A
4@0O7al202HV9P<0:b/[00@0?3`l0410@010@400BDU90P1@D500101IFET0Fe]K05]KF`1HF5P2061P
H00406][J`1jNWX0NWYj075aL@80J6QX00@0P82007=cL`1cLg<0IVIV0P22PX80101cLg<0MWIf07If
MP1jNWX208V9R@0409nOW`22PX80PX:207QhN080H61P00@0IfMW06i^KP1^KVh0LW9b0`1_Kfl206UY
J@0405iNGP1XJ6P0J6QX0861P@80Ti>C00@0QhN707MgM`1gMgL0MGEe0P1XJ6P0101NGUh0KVi^06i^
KP1fMWH306YZJP80IFEU00@0J6QX08n?S`2?Shl0O7al0P1MGEd0101GEeL0DE5A055AD@1GEeL20451
@@0400/;2`0B4Q804Q8B018B4P808B4Q00@06a/K01`L700L71`0>3Ph0P10@4001017AdL0BDU904U9
B@0j>SX204E5A@0405QHF01<C4`0C4a<06EUI@80QHF500@0Vi^K09nOW`2OWil0Ng]k0P1VIVH0101K
Fe/0ATI604I6AP11@D4203`l?00403Ph>00k>c/0>c/k04=3@`80?Cdm00@0>CTi03dm?@0m?Cd0A4A4
0P1<C4`0100o?cl0@T920492@P0d=3@2038b<P0403dm?@0e=CD0=CDe0410@080@d=300<0C4a<04];
B`1;Bd/00`1:BTX0101BDU80D51@051@D017AdL204U9B@04055AD@19BDT0BDU90492@P80A4A400@0
Bd];04Q8B018B4P0C4a<0P1DE5@0101:BTX0ATI604I6AP1;Bd/204i>CP0404];B`18B4P0B4Q804];
B`80BDU900@0ATI604];B`1;Bd/0AdM70P18B4P01019BDT0BTY:04Y:BP17AdL204];B`04055AD@15
ADD0ADE504I6AP80@d=300@0A4A403Hf=P0f=SH0<30`0P2>SXh0102?Shl0FUYJ05YJFP2=SHd20;2`
/0040:FUY@32`/80`/;20=kNgP80fMWI00@0emOG0<g=c@3=cLd0bLW90P3Hf=P0102i^KT0I6AT06AT
I00e=CD201DE5@0400@410071`L01`L700L71`801PH600000`0000000P8200820P0300<30`0400H6
1P010@400@4100d=3@801PH600@01@D500000000000000000`0:2PX200@4100400<30`0000000000
00@410800@4100@0000000H61P061PH00@410P051@D010020P801@D500D51@0820P200@410040000
000410@010@400D51@<01PH60P030`<300H61P0400D51@061PH01PH600T92@801`L700@02@T900H6
1P061PH000000P051@D010071`L01PH600H61P0820P200H61P@010@40P051@D010030`<00@410041
0@0410@300L71`800@4100@01@D500820P020P800P820P010@400`020P801@D500D51@0600@410<0
0`<300@01@D500000000000020P80P030`<400H61P801@D50`061PH0100820P01@D500D51@010@43
00H61P804A4A00@0:2PX038b<P0b<S80=CDe0P0i>CT01010@400>CTi03Ti>@0M7Ad200h>3P0400L7
1`0?3`l03`l?018B4P803@d=00@020P80000000000000P820P092@T0100F5QH0:RXZ02XZ:P0f=SH2
030`<00402TY:@0V9RH09RHV03lo?`80C4a<00@0@4100451@@11@D40CDe=0P17AdL0101CDe<0M7Ad
07AdM01iNGT2075aL@030861P@2=SHd0SHf=00<0Q8B400@0SXj>09:BTP2BTY80Ph>30P1gMgL0101h
N7P0H61P061PH01UIFD207QhN00408J6QP1IFET0FEUI06IVIP80N7Qh00@0FUYJ069RHP1RHV80KVi^
0P1mOGd01026QXH0NWYj07YjNP1VIVH206QXJ00407YjNP1fMWH0MWIf065QH@80IFEU00@0Ogmo08>3
P`23Ph<0Kfm_0P1RHV80101gMgL0TY:B09:BTP1fMWH207=cL`0407inOP1KFe/0Fe]K055AD@80?clo
00@05QHF01@D500D51@03`l?0P0@4100100G5aL061PH01PH600^;Rh203`l?00404A4A01<C4`0C4a<
03`l?080?Shn00@0K6a/07UiN@1iNGT0JFUY0P1hN7P0102CTi<0WYjN09jNWP2:RXX2079bLP04065Q
H@1?Cdl0Cdm?04=3@`80<S8b00@0;Rh^03Ti>@0i>CT0ATI60P18B4P01010@400?Shn03hn?P14A4@2
04a<C0040410@00o?cl0?clo04A4A080>CTi0`10@4001016ATH0AdM704M7A`18B4P20492@P040451
@@17AdL0AdM704U9B@<0ADE50P1;Bd/0101@D500BDU904U9B@11@D4204M7A`0404m?C`1;Bd/0Bd];
04e=C@80Cdm?0`1<C4`01014A4@0ADE504E5A@1>CTh204e=C@0404I6AP10@400@41004A4A080B4Q8
00<0ATI604U9B@19BDT00`16ATH30410@00404e=C@17AdL0AdM704Q8B080A4A400@0@d=3034a<@0a
<C40@D510P2@T9001021PH40H61P061PH02EUID20;6a/@040:2PX034a<@0a<C40=[JfP80e=CD00@0
dM7A0<o?c`3?cll0dm?C0P3Hf=P01030`<00IVIV06IVIP0_;bl2014A4@0400<30`071`L01`L700X:
2P8010@4000010010@400P8200820P0410@200820P04000000030`<00`<300@410801@D500@00000
00H61P061PH00P820`0820P200820P04000000010@400@4100410@800`<300@0000000@4100410@0
1PH60P0410@300D51@0400410@030`<00`<300820P801@D500@02PX:00T92@092@T00P820P030`<0
100410@00`<300<30`071`L200X:2P0400L71`020P800P8200D51@801PH610051@D300L71`<01PH6
0P092@T0100820P02@T900T92@071`L200820P0400D51@0820P020P800L71`80000000@00`<300@4
100410@00`<30P010@40100410@01`L700L71`051@D200P820<010@400@00P8200410@010@402`/;
0P030`<010071`L02`/;00/;2`071`L200T92@0400D51@020P800P8200820P801@D500@01PH600D5
1@051@D010@40P092@T010030`<02`/;00/;2`0[:b/2038b<P0402/[:`0e=CD0=CDe04a<C080?Shn
00@05ADE00D51@051@D01PH60P0=3@d0100>3Ph03@d=00d=3@0;2`/200T92@0400l?3`0F5QH05QHF
00d=3@8071`L00@0<c<c038b<P0b<S80>CTi0P0l?3`0101CDe<0DE5A055AD@11@D4204E5A@04069R
HP1QHF40HF5Q05UIF@80K6a/00@0L71`06EUI@1UIFD0IFEU0P1]KFd0101dM7@0NWYj07YjNP1lO7`2
06i^KP0406a/K01KFe/0Fe]K06a/K080KVi^00@0NGUi08Z:RP2:RXX0QHF50P1/K6`0101kNg/0QhN7
08N7Q`1hN7P208>3P`040820P01eMGD0MGEe06MWI`80KFe]00@0KVi^06UYJ@1YJFT0PH610P2>SXh0
1020P800L71`071`L01eMGD208R8R00308J6QP1jNWX0NWYj00<0Ng]k00@0KFe]07QhN01hN7P0RXZ:
0P1gMgL0101DE5@0@4100410@00/;2`2020P800401LG5`0?3`l03`l?01XJ6P806a/K00@09BDU03Xj
>P0j>SX0>c/k0P10@4001016ATH0@D510451@@1LG5`208f=S@0407IfMP1`L700L71`08Z:RP80UiNG
00@0U9BD07alO01lO7`0GUiN0P1:BTX0100n?Sh0=CDe03De=@0g=cL203/k>`040410@01:BTX0BTY:
04Y:BP80ATI600@0C4a<059BDP1BDU80CTi>0`15ADD204I6AP0404m?C`1EEED0EEEE04e=C@80Bd];
00@0AdM703/k>`0k>c/0?clo0P13@d<01016ATH0CDe=04e=C@1:BTX204U9B@0304E5A@19BDT0BDU9
00<0ADE500@0Cdm?04Y:BP1:BTX0BDU90P1>CTh0101:BTX0ATI604I6AP17AdL204a<C0<0CTi>00@0
AdM70410@010@400ADE50P11@D40100n?Sh0@4100410@00o?cl30492@P80@d=300@0Cdm?04i>CP1>
CTh0B4Q80P12@T80100o?cl0;bl_02l_;`1DE5@208^;R`04075aL@1WIfL0IfMW09RHV080Zj^[00@0
YZJV0<g=c@3=cLd0gmoO0P3MgMd01039bLT0c/k>0<k>cP3=cLd20<S8b00409ZJVP0e=CD0=CDe01hN
7P803@d=00@010@400P8200820P00`<30P0=3@d0000400410@020P800P8200@410800P8200@00000
00<30`030`<010@40P051@D0100000001PH600H61P020P8300P820800P8200@0000000410@010@40
0@410P030`<01000000010@400@410061PH200@410<01@D500@00@4100<30`030`<00P820P051@D0
100:2PX02@T900T92@020P8200<30`0400@410030`<00`<300L71`802PX:00@01`L700820P020P80
1@D50P061PH400D51@<01`L70`061PH200T92@0400P820092@T02@T900L71`800P8200@01@D500P8
200820P01`L70P00000010030`<010@400@410030`<200410@0400@410071`L01`L700D51@8020P8
0`0410@010020P800@4100410@0;2`/200<30`0400L71`0;2`/02`/;00L71`802@T900@01@D50082
0P020P800P820P051@D010061PH01@D500D51@0410@200T92@0400<30`0;2`/02`/;02/[:`80<S8b
00@0:b/[03De=@0e=CD0C4a<0P0n?Sh0100E5AD01@D500D51@061PH200d=3@0400h>3P0=3@d03@d=
00/;2`802@T900@03`l?01HF5P0F5QH03@d=0P0L71`0100c<c<0<S8b038b<P0i>CT203`l?00405=C
D`1ADE40DE5A0451@@80ADE500@0HV9R065QH@1QHF40FEUI0P1/K6`0101`L700IFEU06EUI@1UIFD2
06e]K@0407AdM01jNWX0NWYj07alO080KVi^00@0K6a/05]KF`1KFe/0K6a/0P1^KVh0101iNGT0RXZ:
08Z:RP25QHD206a/K00407]kN`27QhL0QhN707QhN080Ph>300@0P82007EeM@1eMGD0IfMW0P1]KFd0
101^KVh0JFUY06UYJ@21PH4208j>SP040820P01`L700L71`07EeM@80R8R800<0QXJ607YjNP1jNWX0
0`1kNg/0101]KFd0N7Qh07QhN02:RXX207MgM`0405ADE010@400@41002`/;080820P00@05aLG00l?
3`0?3`l06QXJ0P0K6a/0100U9BD0>SXj03Xj>P0k>c/20410@00404I6AP11@D40@D5105aLG080SHf=
00@0MWIf071`L01`L700RXZ:0P2GUiL0102DU9@0O7al07alO01NGUh204Y:BP0403hn?P0e=CD0=CDe
03Lg=`80>c/k00@0@41004Y:BP1:BTX0BTY:0P16ATH0101<C4`0DU9B059BDP1>CTh304E5A@80ATI6
00@0Cdm?05EEE@1EEED0CDe=0P1;Bd/01017AdL0>c/k03/k>`0o?cl204=3@`0404I6AP1=CDd0CDe=
04Y:BP80BDU900<0ADE504U9B@19BDT00`15ADD0101?Cdl0BTY:04Y:BP19BDT204i>CP0404Y:BP16
ATH0ATI604M7A`80C4a<0`1>CTh01017AdL0@4100410@015ADD20451@@0403hn?P10@400@41003lo
?`<0@T920P13@d<0101?Cdl0CTi>04i>CP18B4P20492@P0403lo?`0_;bl0;bl_05ADE080Rh^;00@0
LG5a06MWI`1WIfL0V9RH0P2[Zj/0102VYZH0cLg=0<g=c@3Ogml20=gMg@040<W9b@3>c/h0c/k>0<g=
c@80b<S800@0VYZJ03De=@0e=CD07QhN0P0=3@d0100410@020P800P820030`<200d=3@0000@010@4
00820P020P800@410P0410@010061PH00`<300<30`00000200820P0400H61P0;2`/02`/;00820P80
1PH600@010@400<30`030`<00P821@0410@300820P0400`<30071`L01`L700P820800P8200@010@4
00820P020P800@410P030`<010020P8010@400@4100410@200820P0400<30`061PH01PH600@41080
0P8200@00`<30000000000001PH60P071`L300H61P0400@410071`L01`L700H61P8010@400@01PH6
00D51@051@D00@410P020P8010092@T0000000000000000200@4100300410@030`<00`<300<01`L7
00@010@400H61P061PH01@D50P030`<300L71`0400D51@030`<00`<300<30`802PX:00@01@D500<3
0`030`<010@40P092@T00`0410@00`<300<30`0300D51@0400H61P0410@010@400410@801`L700@0
2@T900820P020P800`<30P0B4Q80100Y:BT0;Bd]02d];@0W9bL20492@P0405eMG@0m?Cd0?Cdm01hN
7P803@d=0`092@T0100@41004A4A014A4@0>3Ph201DE5@0401PH600M7Ad07AdM01DE5@80:b/[00@0
?Cdm03Hf=P0f=SH0?clo0P17AdL305YJFP0405aLG01GEeL0EeMG06MWI`<0O7al0P24Q8@0101hN7P0
GUiN05iNGP1[Jf/206i^KP0406IVIP1gMgL0MgMg06m_K`80FUYJ00@0Kfm_06a/K01/K6`0Q8B40P1e
MGD0101_Kfl0Ogmo07moO`1oOgl209JFUP0409FEU@22PX80PX:20820P080O7al00@0KVi^07IfMP1f
MWH0MWIf0P22PX80102?Shl0OGem07emO@1dM7@206YZJP0406MWI`1eMGD0MGEe07]kN`80MgMg00@0
MWIf08:2PP22PX80QHF50P1gMgL0101^KVh0KFe]06e]K@1iNGT207alO00406EUI@1FEUH0EUIF04];
B`80;bl_00@06QXJ01<C4`0C4a<0410@0P0820P0100C4a<09BDU02DU9@0V9RH202d];@0404m?C`13
@d<0@d=303`l?080O7al00@0OGem06][J`1[Jf/0QhN70P2GUiL0102BTY80MGEe07EeM@1BDU8204M7
A`040451@@0j>SX0>SXj03De=@80=SHf00@0?Shn04M7A`17AdL0De=C0P1<C4`0101@D500EEEE05EE
E@1<C4`304E5A@80E5AD00@0Cdm?04a<C01<C4`0BDU90P17AdL30410@00404Y:BP14A4@0A4A404I6
AP80Cdm?00@0BTY:059BDP1BDU80BDU90P18B4P01019BDT0BTY:04Y:BP19BDT203dm?@0404];B`1F
EUH0EUIF04i>CP80C4a<00@0DU9B04m?C`1?Cdl0BDU90P1;Bd/01015ADD0@D510451@@16ATH204E5
A@0404A4A018B4P0B4Q804E5A@80@d=300@0ADE50451@@11@D40@D510P15ADD01013@d<0@D510451
@@0l?3`203De=@04065QH@22PX80PX:206][J`80L71`00@0SXj>09VIV@2IVIT0Y:BT0P37alL0103I
fMT0dM7A0=7Ad@37alL20<S8b0040;^k^`2b/[80/[:b071`L080820P00@04A4A00@4100410@00`<3
0P0820P100820P400@410@010@40000400D51@061PH01PH600<30`<01PH60P010@4300@4100400H6
1P071`L01`L700D51@801PH600@00P8200@4100410@02`/;0P051@D010061PH00`<300<30`051@D2
00<30`0400@410010@400@4100P820<01@D50P020P80100000001PH600H61P0:2PX200L71`0400@4
10051@D01@D500H61P800P8200@00@4100D51@051@D00`<30P010@4010030`<010@400@4100410@2
00410@0400H61P092@T02@T900H61P8010@400@01@D500@4100410@000000P010@4300H61P040041
0@020P800P8200D51@<020P80P030`<010051@D01`L700L71`061PH200D51@0400P8200410@010@4
00D51@802@T90`061PH010051@D020P800P8200410@200820P0300@410030`<00`<300<010@400<0
1@D500L71`071`L00`071`L010030`<000000000000820P201LG5`0402DU9@0^;Rh0;Rh^030`<080
AdM700@0D51@02LW9`0W9bL061PH0P0C4a<00`0?3`l02`/;00/;2`0300/;2`0400P8200=3@d03@d=
00h>3P806QXJ00@08B4Q03Ph>00h>3P0>SXj0P0e=CD0100b<S80=CDe03De=@1;Bd/205=CD`0406QX
J01ZJVX0JVYZ065QH@80Lg=c00@0M7Ad07IfMP1fMWH0Ng]k0`1]KFd206EUI@0406QXJ01fMWH0MWIf
079bLP80OWin00@0U9BD08:2PP22PX80PX:20P1lO7`0101/K6`0PX:208:2PP23Ph<20820P00408B4
Q026QXH0QXJ607moO`80Ng]k00@0MGEe08B4Q024Q8@0Shn?0`20P80208J6QP0407moO`1WIfL0IfMW
06EUI@80PX:200@0T92@0861P@21PH40MWIf0P1eMGD0101mOGd0Ph>308>3P`20P80206UYJ@0406YZ
JP1iNGT0NGUi07IfMP80HV9R00@0C4a<03hn?P0n?Sh07alO0P0?3`l010030`<000000000000H61P2
02TY:@0402d];@0P8200820P03Xj>P80@D5100@0?3`l06UYJ@1YJFT0PX:20P1]KFd0101_Kfl0MGEe
07EeM@1jNWX207QhN004061PH01DE5@0E5AD04Y:BP80?clo00@0>CTi03Ph>00h>3P0A4A40P11@D40
101;Bd/0ATI604I6AP18B4P204e=C@0404Q8B01;Bd/0Bd];04];B`80E5AD00@0BDU90410@010@400
B4Q80P16ATH01018B4P0Bd];04];B`17AdL20492@P0404I6AP17AdL0AdM704E5A@80DE5A00@0De=C
059BDP1BDU80BDU90P1=CDd01011@D40>3Ph03Ph>01=CDd304m?C`80DU9B00<0C4a<04M7A`17AdL0
0`1;Bd/01018B4P0Bd];04];B`1:BTX204M7A`0404U9B@1BDU80DU9B051@D080B4Q800@0ADE504I6
AP16ATH0BTY:0P1;Bd/01016ATH0@T920492@P0k>c/203`l?004065QH@1fMWH0MWIf06QXJ080Kfm_
00@0QXJ609JFUP2FUYH0[:b/0P30`<00103Bd]80alO70<O7a`3:b/X20<o?c`040<O7a`2_[jl0[jn_
06MWI`80?Shn00@071`L00/;2`0;2`/00P820P092@T100L71`401@D50@051@D0000400D51@061PH0
1PH600<30`<01PH60P010@4300@4100400H61P071`L01`L700D51@801PH600@00P8200@4100410@0
2`/;0P051@D010061PH00`<300<30`051@D200<30`0400@410010@400@4100P820<01@D50P020P80
100000001PH600H61P0:2PX200L71`0400@410051@D01@D500H61P800P8200@00@4100D51@051@D0
0`<30P010@4010030`<010@400@4100410@200410@0400H61P092@T02@T900H61P8010@400@01@D5
00@4100410@000000P010@4300H61P0400410@020P800P8200D51@<020P80P030`<010051@D01`L7
00L71`061PH200D51@0400P8200410@010@400D51@802@T90`061PH010051@D020P800P8200410@2
00820P0300@410030`<00`<300<010@400<01@D500L71`071`L00`071`L010030`<0000000000008
20P201LG5`0402DU9@0^;Rh0;Rh^030`<080AdM700@0D51@02LW9`0W9bL061PH0P0C4a<00`0?3`l0
2`/;00/;2`0300/;2`0400P8200=3@d03@d=00h>3P806QXJ00@08B4Q03Ph>00h>3P0>SXj0P0e=CD0
100b<S80=CDe03De=@1;Bd/205=CD`0406QXJ01ZJVX0JVYZ065QH@80Lg=c00@0M7Ad07IfMP1fMWH0
Ng]k0`1]KFd206EUI@0406QXJ01fMWH0MWIf079bLP80OWin00@0U9BD08:2PP22PX80PX:20P1lO7`0
101/K6`0PX:208:2PP23Ph<20820P00408B4Q026QXH0QXJ607moO`80Ng]k00@0MGEe08B4Q024Q8@0
Shn?0`20P80208J6QP0407moO`1WIfL0IfMW06EUI@80PX:200@0T92@0861P@21PH40MWIf0P1eMGD0
101mOGd0Ph>308>3P`20P80206UYJ@0406YZJP1iNGT0NGUi07IfMP80HV9R00@0C4a<03hn?P0n?Sh0
7alO0P0?3`l010030`<000000000000H61P202TY:@0402d];@0P8200820P03Xj>P80@D5100@0?3`l
06UYJ@1YJFT0PX:20P1]KFd0101_Kfl0MGEe07EeM@1jNWX207QhN004061PH01DE5@0E5AD04Y:BP80
?clo00@0>CTi03Ph>00h>3P0A4A40P11@D40101;Bd/0ATI604I6AP18B4P204e=C@0404Q8B01;Bd/0
Bd];04];B`80E5AD00@0BDU90410@010@400B4Q80P16ATH01018B4P0Bd];04];B`17AdL20492@P04
04I6AP17AdL0AdM704E5A@80DE5A00@0De=C059BDP1BDU80BDU90P1=CDd01011@D40>3Ph03Ph>01=
CDd304m?C`80DU9B00<0C4a<04M7A`17AdL00`1;Bd/01018B4P0Bd];04];B`1:BTX204M7A`0404U9
B@1BDU80DU9B051@D080B4Q800@0ADE504I6AP16ATH0BTY:0P1;Bd/01016ATH0@T920492@P0k>c/2
03`l?004065QH@1fMWH0MWIf06QXJ080Kfm_00@0QXJ609JFUP2FUYH0[:b/0P30`<00103Bd]80alO7
0<O7a`3:b/X20<o?c`040<O7a`2_[jl0[jn_06MWI`80?Shn00@071`L00/;2`0;2`/00P820P092@T1
00L71`401@D50@051@D0000400H61P0:2PX02PX:00820P800`<300@01@D50000000000001PH60P08
20P010030`<00P8200820P0;2`/200P8200400820P000000000000d=3@801PH600@01@D500<30`03
0`<00P820P010@4010051@D00P8200820P061PH200D51@0400<30`071`L01`L700<30`802`/;00@0
3@d=00D51@051@D010@41@051@D0100410@01PH600H61P051@D200@4100400820P061PH01PH600/;
2`801PH610051@D200@4100400<30`071`L01`L700D51@8010@400@01`L700H61P061PH010@40P07
1`L010061PH020P800P8200410@200P8200400D51@0410@010@400<30`8010@400@020P800@41004
10@00`<30P0;2`/0100<30`00P8200820P092@T200P8200400@410030`<00`<300H61P8010@400@0
0`<300820P020P8010@40P071`L010061PH00`<300<30`030`<200@4100400/;2`0L71`071`L02PX
:080<S8b00@0?clo04a<C01<C4`0@d=30P0T92@0100>3Ph02PX:00X:2P0820P200H61P<01@D500@0
2PX:00d=3@0=3@d020P80P0D51@0100@4100<c<c03<c<`0o?cl20410@00403dm?@0g=cL0=cLg04];
B`80Cdm?00@0E5AD05UIF@1IFET0FUYJ0P1eMGD0101]KFd0GEeM05eMG@1`L70206m_K`0406][J`1c
Lg<0Lg=c0820P080Ogmo00@0P8200861P@21PH40QhN70P1mOGd0101WIfL0Ogmo07moO`1lO7`208:2
PP0408n?S`1`L700L71`06ATI080JFUY00<0JVYZ07emO@1mOGd00`1dM7@01026QXH0PH610861P@23
Ph<208^;R`0407MgM`1UIFD0IFEU07alO080P82000@0Hf=S069RHP1RHV80MgMg0P1eMGD0101]KFd0
OWin07inOP2<S8`207MgM`0406e]K@1`L700L71`071`L080JFUY00@0F5QH04E5A@15ADD0;bl_0P09
2@T0100410@02@T900T92@0@410202DU9@0403@d=00Y:BT0:BTY01lO7`80<30`00<0@41005UIF@1I
FET00`1jNWX0101MGEd0De=C05=CD`1iNGT208j>SP04079bLP1HF5P0F5QH04];B`80?clo00@0=CDe
03<c<`0c<c<0@4100P0n?Sh304E5A@0404A4A01:BTX0BTY:04a<C0<0Cdm?0P1ADE40101:BTX0AdM7
04M7A`1=CDd204A4A00404i>CP19BDT0BDU90410@080ADE50`17AdL01018B4P0@T920492@P1:BTX2
05IFEP0404Q8B019BDT0BDU90410@080ADE500@0DU9B04];B`1;Bd/0DE5A0P1BDU801019BDT0Bd];
04];B`1;Bd/204E5A@0404M7A`1=CDd0CDe=04];B`<0@D510P1=CDd0101:BTX0@4100410@015ADD2
04i>CP04055AD@1>CTh0CTi>04I6AP80?3`l00@0=3@d0410@010@400G5aL0P1]KFd0101NGUh0JVYZ
06YZJP2:RXX2096AT@040:NWY`32`/80`/;20=SHf080bLW900@0a<C40<_;b`3;bl/0dm?C0P2m_Kd0
101jNWX0@4100410@00E5AD500D51@4010@40@061PH100H61P0000@00P8200l?3`0?3`l010@40P00
000010051@D00`<300<30`071`L300820P800@4100@02@T900P8200820P01PH60P020P80100;2`/0
20P800P820020P8200@4100400410@071`L01`L700L71`800P820`051@D0100410@030`<00`<3007
1`L200820P040000000410@010@400L71`800`<300@010@400D51@051@D00P820P030`<010051@D0
20P800P820061PH200<30`0400L71`092@T02@T900H61P8010@40`061PH400D51@8010@400<01@D5
00410@010@400`030`<0100410@00`<300<30`061PH200@4100400T92@030`<00`<300D51@800P82
00@01@D500<30`030`<00P820`0820P300L71`802@T900@020P800D51@051@D010@40P020P801004
10@01PH600H61P051@D200410@04000000020P800P8200H61P801@D500@02PX:01dM7@0M7Ad0;2`/
0P0d=3@01010@400Bd];04];B`11@D42030`<00400`<300410@010@400L71`801@D500@030`<00P8
200820P02@T90P0D51@0100;2`/03@d=00d=3@0?3`l202h^;P0404E5A@19BDT0BDU904I6AP80?Cdm
00@0AdM70410@010@400=3@d0P1;Bd/0101[Jf/0Ogmo07moO`1XJ6P205iNGP04075aL@1PH600H61P
06=SH`80Ogmo00@0P82007UiN@1iNGT0Rh^;0P22PX80101TI6@0IFEU06EUI@1JFUX206UYJ@0407em
O@1fMWH0MWIf0861P@80OWin00@0HV9R061PH01PH600JFUY0P1fMWH01024Q8@0Ogmo07moO`1oOgl2
08J6QP0408b<S02;Rh/0Rh^;07IfMP80J6QX00@0MWIf071`L01`L700G5aL0P1YJFT01020P800M7Ad
07AdM01GEeL206=SH`0407QhN01WIfL0IfMW06MWI`80IFEU00@0IfMW06EUI@1UIFD0I6AT0P1FEUH0
100i>CT051@D01@D500?3`l2018B4P0400<30`0<30`030`<02`/;080?Shn00@08R8R02PX:00X:2P0
A4A40P1UIFD01022PX80T92@092@T01VIVH203hn?P0406EUI@29RHT0RHV906QXJ080B4Q800@0A4A4
0410@010@400<C4a0P0`<3001012@T80@4100410@00m?Cd203hn?P040410@01:BTX0BTY:04m?C`80
Bd];00@0C4a<04m?C`1?Cdl0CTi>0P18B4P01013@d<0A4A404A4A01;Bd/204A4A00403lo?`10@400
@41004E5A@80AdM700@0Cdm?04];B`1;Bd/0B4Q80P1@D50304a<C0040451@@1ADE40DE5A05EEE@80
B4Q800<0BDU904a<C01<C4`00`1?Cdl304];B`0404M7A`11@D40@D5104E5A@80@T9200@0?Shn0492
@P12@T80?clo0P0h>3P01014A4@0C4a<04a<C016ATH304M7A`<0?Shn0P1@D500101LG5`0J6QX06QX
J01TI6@207MgM`0408R8R022PX80PX:20:NWY`80c<c<00@0e=CD0<c<c03<c<`0aLG50P32`/80103?
cll0b/[:0<[:bP21PH4202d];@0400d=3@000000000000H61P802@T90@0410@100<30`400`<30000
10020P803`l?00l?3`0410@20000000400D51@030`<00`<300L71`<00P820P010@4010092@T020P8
00P820061PH200820P0400/;2`0820P020P800820P8010@400@00@4100L71`071`L01`L70P020P83
00D51@0400@4100<30`030`<00L71`800P8200@0000000@4100410@01`L70P030`<0100410@01@D5
00D51@020P8200<30`0400D51@0820P020P800H61P800`<300@01`L700T92@092@T01PH60P0410@3
00H61P@01@D50P0410@00`051@D00@4100410@0300<30`0400@410030`<00`<300H61P8010@400@0
2@T900<30`030`<01@D50P020P8010051@D00`<300<30`020P8300P820<01`L70P092@T0100820P0
1@D500D51@0410@200820P0400@410061PH01PH600D51@800@4100@0000000820P020P801PH60P05
1@D0100:2PX07AdM01dM7@0/;2`203@d=0040410@01;Bd/0Bd];0451@@80<30`00@030`<00@41004
10@01`L70P051@D0100<30`020P800P820092@T201@D500400/;2`0=3@d03@d=00l?3`80;Rh^00@0
ADE504U9B@19BDT0ATI60P0m?Cd01017AdL0@4100410@00d=3@204];B`0406][J`1oOgl0Ogmo06QX
J080GUiN00@0LG5a061PH01PH600Hf=S0P1oOgl01020P800NGUi07UiN@2;Rh/208:2PP0406ATI01U
IFD0IFEU05YJFP80JFUY00@0OGem07IfMP1fMWH0PH610P1nOWh0101RHV80H61P061PH01YJFT207If
MP0408B4Q01oOgl0Ogmo07moO`80QXJ600@0S8b<08^;R`2;Rh/0MWIf0P1XJ6P0101fMWH0L71`071`
L01LG5`206UYJ@040820P01dM7@0M7Ad05MGE`80Hf=S00@0N7Qh06MWI`1WIfL0IfMW0P1UIFD0101W
IfL0IFEU06EUI@1TI6@205IFEP0403Ti>@0D51@051@D00l?3`804Q8B00@00`<300`<300<30`0;2`/
0P0n?Sh0100R8R80:2PX02PX:014A4@206EUI@0408:2PP2@T900T92@06IVIP80?Shn00@0IFEU08V9
R@29RHT0J6QX0P18B4P01014A4@0@4100410@00a<C42030`<0040492@P10@400@41003dm?@80?Shn
00@0@41004Y:BP1:BTX0Cdm?0P1;Bd/0101<C4`0Cdm?04m?C`1>CTh204Q8B00404=3@`14A4@0A4A4
04];B`80A4A400@0?clo0410@010@400ADE50P17AdL0101?Cdl0Bd];04];B`18B4P2051@D0<0C4a<
00@0@D51055AD@1ADE40EEEE0P18B4P00`19BDT0C4a<04a<C00304m?C`<0Bd];00@0AdM70451@@11
@D40ADE50P12@T80100n?Sh0@T920492@P0o?cl203Ph>00404A4A01<C4`0C4a<04I6AP<0AdM70`0n
?Sh2051@D00405aLG01XJ6P0J6QX06ATI080MgMg00@0R8R808:2PP22PX80YjNW0P3<c<`0103De=@0
c<c<0<c<c035aLD20<;2`P040<o?c`3:b/X0b/[:0861P@80;Bd]00@03@d=0000000000001PH60P09
2@T100@410400`<30@030`<0000400@410092@T02@T900T92@801PH600@01@D500410@010@401PH6
0P071`L0100410@00P8200820P0410@300H61P800`<300@03`l?00d=3@0=3@d00`<30P0410@01002
0P801`L700L71`061PH300@410801@D500@00P8200D51@051@D01`L70P010@40100000000`<300<3
0`061PH200@4100300D51@061PH01PH600<00P8200@01PH600P8200820P00`<30P0000000`010@40
1PH600H61P0300<30`0400L71`092@T02@T900L71`80000000@00P8200@4100410@02@T90`051@D2
00820P0400H61P051@D01@D500H61P800P820`051@D300T92@0400D51@071`L01`L700H61P800`<3
00@0000000D51@051@D010@40P051@D010020P801`L700L71`061PH200@4100300P820061PH01PH6
00<00P820`051@D010020P801@D500D51@0A4A42028R8P0402l_;`0f=SH0=SHf03hn?P80BDU900@0
>SXj02l_;`0_;bl03@d=0P030`<300L71`04018B4P071`L01`L700T92@804a<C00@0410@00l?3`0?
3`l05QHF0P0[:b/01015ADD0ATI604I6AP0o?cl203Lg=`0403Ph>00b<S80<S8b038b<P80BDU900@0
DU9B05aLG01LG5`0GEeM0P1XJ6P0101cLg<0FUYJ05YJFP1UIFD207IfMP0406e]K@1UIFD0IFEU06UY
J@80OWin00@0KVi^07UiN@1iNGT0Q8B40P20P800102<S8`0MGEe07EeM@1aLG4208N7Q`0407QhN01f
MWH0MWIf07emO@80M7Ad00@0Q8B408>3P`23Ph<0Q8B40P29RHT01023Ph<0R8R808R8R028R8P20861
P@0407MgM`1jNWX0NWYj08N7Q`80PH6100@0N7Qh07YjNP1jNWX0OWin0P1kNg/0101TI6@0G5aL05aL
G01fMWH206][J`04069RHP1FEUH0EUIF05IFEP80DU9B00@0Cdm?03Hf=P0f=SH08b<S0P0F5QH01007
1`L000000000000O7al2038b<P0402HV9P0R8R808R8R03Xj>P80IFEU00@0Shn?09VIV@2IVIT0L71`
0P0h>3P0101EEED0QHF508F5Q@1]KFd204e=C@0304a<C019BDT0BDU900<0>SXj00<0AdM704=3@`13
@d<00`10@400100l?3`0@D510451@@18B4P204E5A@0404M7A`1<C4`0C4a<051@D080B4Q800@0?3`l
04=3@`13@d<0ATI60P19BDT0100n?Sh0;Bd]02d];@0k>c/20410@00404Q8B01?Cdl0Cdm?05=CD`<0
BTY:0P18B4P0100n?Sh0DE5A055AD@1GEeL204U9B@0404E5A@1:BTX0BTY:04m?C`80BDU900@0BTY:
05MGE`1GEeL0De=C0P15ADD01016ATH0D51@051@D01;Bd/20451@@0403/k>`0^;Rh0;Rh^03De=@80
ATI600@0C4a<04e=C@1=CDd0A4A40P11@D401017AdL0BTY:04Y:BP1BDU82065QH@03069RHP1cLg<0
Lg=c00<0OGem00@0WYjN0;Zj^P2j^[X0_kno0P39bLT0103>c/h0a<C40<C4a034a<@20;Vi^@0406EU
I@0T92@092@T01HF5P801@D500@00@4100@4100410@00`<30P061PH0000400<30`0410@010@400P8
20801@D50`020P80100410@02`/;00/;2`092@T200@4100300<30`0410@010@400<01@D500@020P8
00<30`030`<010@40P061PH010071`L01PH600H61P0:2PX200H61P040000000410@010@400@410D0
1@D500@02@T900D51@051@D000000`030`<200@4100400L71`051@D01@D500H61P801`L700@00000
00410@010@400`<30`010@4200820P04000000020P800P8200P8208010@40`030`<400L71`800P82
00@010@400820P020P802PX:0P051@D010030`<010@400@4100;2`/200P8200400@4100:2PX02PX:
00P820801@D50`010@4010051@D020P800P820030`<300@410801`L700@02`/;00L71`071`L00P82
0P030`<0100820P01`L700L71`00000200H61P0401dM7@0`<300<30`034a<@80<S8b00@0@410051@
D01@D500=SHf0P0X:2P0100:2PX00@4100410@0:2PX200L71`0400`<30030`<00`<300X:2P801`L7
00@04Q8B00h>3P0>3Ph03`l?0P0Y:BT0100l?3`0Bd];04];B`14A4@203Lg=`0403@d=00`<300<30`
03/k>`80E5AD00@0EEEE06QXJ01XJ6P0NWYj0P1[Jf/0101WIfL0J6QX06QXJ01[Jf/206a/K00407=c
L`1_Kfl0Kfm_06EUI@80Ng]k00@0NGUi08J6QP26QXH0PH610P1kNg/0101bLW80HF5Q065QH@1iNGT2
08Z:RP0406m_K`1UIFD0IFEU07YjNP80J6QX00@0LG5a07inOP1nOWh0QXJ60P29RHT01025QHD0SHf=
08f=S@26QXH207inOP04079bLP1_Kfl0Kfm_07]kN`80NWYj00@0MGEe0820P020P800TI6A0P23Ph<0
101YJFT0M7Ad07AdM01iNGT206][J`0406a/K01LG5`0G5aL05eMG@80HV9R00@0GemO03`l?00l?3`0
;Bd]0P0U9BD0100<30`020P800P8200>3Ph2020P800402`/;00D51@051@D02HV9P80EeMG00@0PX:2
0820P020P800GemO0P0e=CD0101CDe<0NWYj07YjNP1`L70205iNGP0404i>CP11@D40@D5103Ti>@80
>SXj00@0A4A404M7A`17AdL0AdM70P12@T80100i>CT0>SXj03Xj>P19BDT204a<C00404M7A`1:BTX0
BTY:04U9B@80B4Q800@0?3`l04=3@`13@d<0AdM70P18B4P01012@T80;Bd]02d];@0m?Cd30451@@80
Bd];00@0De=C04e=C@1=CDd0D51@0P14A4@01012@T80G5aL05aLG01BDU8204A4A00404M7A`1<C4`0
C4a<055AD@80Cdm?00@0CDe=051@D01@D500FEUI0P1>CTh01015ADD0E5AD05ADE01@D5020410@004
03`l?00j>SX0>SXj04=3@`80BTY:00@0C4a<04I6AP16ATH0@4100P18B4P01013@d<0?Cdm03dm?@1B
DU82069RHP0405aLG01^KVh0KVi^07alO080Q8B400@0X:2P0;bl_02l_;`0^KVi0P2h^;P01039bLT0
`l?30<?3``2i^KT20:ZZZP0404Y:BP0G5aL05aLG01HF5P800`<300@00@4100<30`030`<02@T90P0<
30`0000400<30`0410@010@400P820801@D50`020P80100410@02`/;00/;2`092@T200@4100300<3
0`0410@010@400<01@D500@020P800<30`030`<010@40P061PH010071`L01PH600H61P0:2PX200H6
1P040000000410@010@400@410D01@D500@02@T900D51@051@D000000`030`<200@4100400L71`05
1@D01@D500H61P801`L700@0000000410@010@400`<30`010@4200820P04000000020P800P8200P8
208010@40`030`<400L71`800P8200@010@400820P020P802PX:0P051@D010030`<010@400@4100;
2`/200P8200400@4100:2PX02PX:00P820801@D50`010@4010051@D020P800P820030`<300@41080
1`L700@02`/;00L71`071`L00P820P030`<0100820P01`L700L71`00000200H61P0401dM7@0`<300
<30`034a<@80<S8b00@0@410051@D01@D500=SHf0P0X:2P0100:2PX00@4100410@0:2PX200L71`04
00`<30030`<00`<300X:2P801`L700@04Q8B00h>3P0>3Ph03`l?0P0Y:BT0100l?3`0Bd];04];B`14
A4@203Lg=`0403@d=00`<300<30`03/k>`80E5AD00@0EEEE06QXJ01XJ6P0NWYj0P1[Jf/0101WIfL0
J6QX06QXJ01[Jf/206a/K00407=cL`1_Kfl0Kfm_06EUI@80Ng]k00@0NGUi08J6QP26QXH0PH610P1k
Ng/0101bLW80HF5Q065QH@1iNGT208Z:RP0406m_K`1UIFD0IFEU07YjNP80J6QX00@0LG5a07inOP1n
OWh0QXJ60P29RHT01025QHD0SHf=08f=S@26QXH207inOP04079bLP1_Kfl0Kfm_07]kN`80NWYj00@0
MGEe0820P020P800TI6A0P23Ph<0101YJFT0M7Ad07AdM01iNGT206][J`0406a/K01LG5`0G5aL05eM
G@80HV9R00@0GemO03`l?00l?3`0;Bd]0P0U9BD0100<30`020P800P8200>3Ph2020P800402`/;00D
51@051@D02HV9P80EeMG00@0PX:20820P020P800GemO0P0e=CD0101CDe<0NWYj07YjNP1`L70205iN
GP0404i>CP11@D40@D5103Ti>@80>SXj00@0A4A404M7A`17AdL0AdM70P12@T80100i>CT0>SXj03Xj
>P19BDT204a<C00404M7A`1:BTX0BTY:04U9B@80B4Q800@0?3`l04=3@`13@d<0AdM70P18B4P01012
@T80;Bd]02d];@0m?Cd30451@@80Bd];00@0De=C04e=C@1=CDd0D51@0P14A4@01012@T80G5aL05aL
G01BDU8204A4A00404M7A`1<C4`0C4a<055AD@80Cdm?00@0CDe=051@D01@D500FEUI0P1>CTh01015
ADD0E5AD05ADE01@D5020410@00403`l?00j>SX0>SXj04=3@`80BTY:00@0C4a<04I6AP16ATH0@410
0P18B4P01013@d<0?Cdm03dm?@1BDU82069RHP0405aLG01^KVh0KVi^07alO080Q8B400@0X:2P0;bl
_02l_;`0^KVi0P2h^;P01039bLT0`l?30<?3``2i^KT20:ZZZP0404Y:BP0G5aL05aLG01HF5P800`<3
00@00@4100<30`030`<02@T90P0<30`0000400820P051@D01@D500H61P<00@410`0410@200H61P<0
1`L700@010@400D51@051@D01@D50P061PH0100410@00@4100410@030`<200H61P0400T92@071`L0
1`L700L71`8010@400@00`<300D51@051@D01PH60P0820P00`071`L01@D500D51@0300/;2`030082
0P010@400@4100<010@400@01`L700/;2`0;2`/01PH60`051@D200L71`0400T92@051@D01@D500L7
1`800`<30`020P80100410@01@D500D51@010@4200H61P0400L71`061PH01PH600/;2`8020P800@0
0@4100@4100410@02`/;0`0410@200L71`0400T92@051@D01@D500D51@801`L700@01@D500410@01
0@4000000`020P8200X:2P0400L71`0410@010@400L71`8010@400@02@T900/;2`0;2`/00`<30P01
0@40100410@00`<300<30`00000200L71`0401/K6`0^;Rh0;Rh^03<c<`80=3@d00@0?3`l04];B`1;
Bd/0=cLg0P0O7al0100:2PX02@T900T92@092@T300L71`802PX:00@04Q8B00P8200820P05ADE0P09
2@T0100P8200<c<c03<c<`0];Bd2051@D00404Q8B00_;bl0;bl_03Lg=`80ADE500@0ATI604a<C01<
C4`0I6AT0P28R8P01022PX80G5aL05aLG01PH602075aL@0406a/K01^KVh0KVi^07]kN`80MGEe00@0
LW9b07alO01lO7`0KFe]0P1_Kfl0101SHf<0Kfm_06m_K`1`L70206UYJ@0407MgM`20P800P82006QX
J080IFEU00@0LW9b05mOG`1OGel0JFUY0P1lO7`0101jNWX0OWin07inOP25QHD208N7Q`0408:2PP24
Q8@0Q8B407MgM`80IfMW00@0JVYZ07AdM01dM7@0PH610P28R8P0101oOgl0Kfm_06m_K`1^KVh207Ee
M@0406=SH`1NGUh0GUiN06IVIP80Fe]K00@0HF5Q07AdM01dM7@0JFUY0`1:BTX202`/;00401@D500C
4a<04a<C00X:2P806ATI00@0:2PX01/K6`0K6a/07AdM0P0l?3`0101LG5`0C4a<04a<C00X:2P201@D
500403/k>`1KFe/0Fe]K05aLG080E5AD00@0B4Q804A4A014A4@0?clo0P0i>CT01014A4@0CDe=04e=
C@13@d<203Hf=P0402d];@0d=3@0=3@d04];B`80CDe=00@0AdM704e=C@1=CDd0ATI60P1=CDd01013
@d<0ADE504E5A@1;Bd/20492@P0403hn?P0_;bl0;bl_03hn?P80>SXj00@0@41004];B`1;Bd/0BTY:
0P1>CTh0101IFET0>c/k03/k>`13@d<2065QH@0404e=C@15ADD0ADE505=CD`80DU9B00@0C4a<05=C
D`1CDe<0DE5A0P18B4P0101GEeL0DE5A055AD@14A4@204i>CP0404];B`14A4@0A4A404=3@`80E5AD
00@0IfMW05EEE@1EEED0BDU90P15ADD01012@T80CTi>04i>CP1:BTX20492@P0405EEE@1MGEd0GEeM
05]KF`80K6a/00@0Ng]k08J6QP26QXH0WinO0P34a<@0103:b/X0_[jn0;jn_P32`/820;Vi^@040<30
`02i^KT0^KVi051@D080410@00@03@d=00<30`030`<01PH60P020P8100H61P400`<30@030`<00004
00820P030`<00`<300/;2`801PH600@010@400820P020P8010@40P030`<010071`L02@T900T92@03
0`<200H61P0400D51@030`<00`<300<30`801@D500@00`<300D51@051@D01PH60P051@D0100410@0
1`L700L71`0820P300H61P800`<300@01@D500@4100410@00P820`061PH200@4100400H61P051@D0
1@D500@410801`L70`020P8010071`L01PH600H61P0<30`200X:2P0400T92@0410@010@400@41080
0`<300@00P8200D51@051@D00@410P0820P300D51@0400820P0410@010@400L71`801PH600@02@T9
00P8200820P00`<30P051@D00`010@400P8200820P0300820P<010@400<00@4100P8200820P00`03
0`<0100410@01`L700L71`0>3Ph200H61P0400L71`0820P020P800<30`801`L700@01PH600<30`03
0`<01PH60P0;2`/0100K6a/0<30`030`<00d=3@2030`<00403De=@13@d<0@d=303Ph>0807AdM00@0
3`l?010@400@41002`/;0P092@T0100;2`/03@d=00d=3@0;2`/200T92@0401<C4`071`L01`L701/K
6`80<c<c00@0<30`04U9B@19BDT0Bd];0P0m?Cd0100c<c<0CTi>04i>CP1HF5P20410@00404];B`1_
Kfl0Kfm_079bLP80IVIV00@0K6a/07AdM01dM7@0Ng]k0P23Ph<0101hN7P0IFEU06EUI@1IFET207=c
L`0407MgM`1`L700L71`06][J`80LW9b00@0R8R808>3P`23Ph<0LW9b0P1iNGT00`1/K6`0MWIf07If
MP0307MgM`0407]kN`24Q8@0Q8B407QhN080P82000@0T92@08n?S`2?Shl0OWin0P1cLg<0101bLW80
MgMg07MgM`1bLW8206YZJP0407MgM`22PX80PX:207]kN`80IVIV00@0H61P06][J`1[Jf/0LW9b0P1a
LG40101NGUh0D51@051@D017AdL2075aL@0405eMG@13@d<0@d=306ATI080GUiN00<0=cLg00`<300<
30`00`0@4100100O7al0<C4a034a<@0R8R8203@d=00404i>CP14A4@0A4A402PX:0808B4Q00@0<c<c
05ADE01DE5@0IVIV0P1FEUH01017AdL0B4Q804Q8B014A4@20410@00404Q8B01?Cdl0Cdm?04E5A@80
<c<c00@08B4Q02LW9`0W9bL0@d=30P18B4P01014A4@0BDU904U9B@19BDT205IFEP0404];B`0k>c/0
>c/k04Y:BP80ADE500@0?Shn03`l?00l?3`0@4100P0i>CT0101?Cdl0De=C05=CD`18B4P205=CD`04
05ADE00h>3P0>3Ph04Q8B080FEUI00@0CTi>051@D01@D500FUYJ0P1ADE40101>CTh0De=C05=CD`1;
Bd/204I6AP04059BDP1CDe<0De=C04Q8B080CDe=0`1>CTh0101=CDd0FEUI05UIF@1VIVH204e=C@04
0492@P17AdL0AdM70410@080AdM700<0C4a<04I6AP16ATH00`1ADE40101DE5@0JFUY06UYJ@1gMgL2
08J6QP0409fMW@2i^KT0^KVi0<C4a080a/K600@0b<S80<30`030`<00];Bd0P2CTi<0101BDU806ATI
01TI6@030`<200@4100400L71`0410@010@400820P800`<3000010020P800`<300<30`0;2`/200H6
1P0400@410020P800P8200@410800`<300@01`L700T92@092@T00`<30P061PH010051@D00`<300<3
0`030`<200D51@0400<30`051@D01@D500H61P801@D500@010@400L71`071`L020P80`061PH200<3
0`0400D51@0410@010@400820P<01PH60P0410@010061PH01@D500D51@0410@200L71`<00P8200@0
1`L700H61P061PH030`<0P0:2PX010092@T010@400@4100410@200<30`0400820P051@D01@D50041
0@8020P80`051@D010020P8010@400@410071`L200H61P0400T92@0820P020P800<30`801@D500<0
0@4100820P020P800`020P8300@4100300410@0820P020P800<00`<300@010@400L71`071`L03Ph>
0P061PH010071`L020P800P820030`<200L71`0400H61P030`<00`<300H61P802`/;00@06a/K030`
<00`<300=3@d0P0`<300100e=CD0@d=304=3@`0h>3P201dM7@0400l?3`0@4100410@00/;2`802@T9
00@02`/;00d=3@0=3@d02`/;0P092@T0100C4a<01`L700L71`0K6a/203<c<`04030`<019BDT0BDU9
04];B`80?Cdm00@0<c<c04i>CP1>CTh0F5QH0P10@400101;Bd/0Kfm_06m_K`1bLW8206IVIP0406a/
K01dM7@0M7Ad07]kN`80Ph>300@0N7Qh06EUI@1UIFD0FEUI0P1cLg<0101gMgL0L71`071`L01[Jf/2
079bLP0408R8R023Ph<0Ph>3079bLP80NGUi00<0K6a/07IfMP1fMWH00`1gMgL0101kNg/0Q8B408B4
Q01hN7P20820P004092@T02?Shl0Shn?07inOP80Lg=c00@0LW9b07MgM`1gMgL0LW9b0P1ZJVX0101g
MgL0PX:208:2PP1kNg/206IVIP04061PH01[Jf/0Jf][079bLP80LG5a00@0GUiN051@D01@D500AdM7
0P1aLG40101MGEd0@d=304=3@`1TI6@205iNGP0303Lg=`0<30`030`<00<0410@00@07alO034a<@0a
<C408R8R0P0d=3@0101>CTh0A4A404A4A00X:2P2024Q8@0403<c<`1DE5@0E5AD06IVIP80EUIF00@0
AdM704Q8B018B4P0A4A40P10@4001018B4P0Cdm?04m?C`15ADD203<c<`04024Q8@0W9bL09bLW04=3
@`80B4Q800@0A4A404U9B@19BDT0BDU90P1FEUH0101;Bd/0>c/k03/k>`1:BTX204E5A@0403hn?P0l
?3`0?3`l0410@080>CTi00@0Cdm?05=CD`1CDe<0B4Q80P1CDe<0101DE5@0>3Ph03Ph>018B4P205UI
F@0404i>CP1@D500D51@05YJFP80DE5A00@0CTi>05=CD`1CDe<0Bd];0P16ATH0101BDU80De=C05=C
D`18B4P204e=C@<0CTi>00@0CDe=05UIF@1IFET0IVIV0P1=CDd01012@T80AdM704M7A`10@40204M7
A`0304a<C016ATH0ATI600<0DE5A00@0E5AD06UYJ@1YJFT0MgMg0P26QXH0102MWId0^KVi0;Vi^@34
a<@20<K6aP040<S8b030`<00`<300;Bd]080Ti>C00@0DU9B01TI6@0I6AT00`<30P0410@010071`L0
10@400@410020P8200<30`0000@00P8200000000000010@40P051@D010071`L01@D500D51@030`<2
00D51@<020P800@00P8200L71`071`L01PH60P030`<300820P0400<30`051@D01@D500X:2P801PH6
00@00P8200L71`071`L01`L70P030`<010010@401@D500D51@051@D200@4100400820P010@400@41
00H61P802@T900@01@D500<30`030`<00P820P092@T300@41004000000010@400@4100P820802@T9
10030`<200@4100300H61P030`<00`<300<00`<300@00P8200D51@051@D00`<30P0410@0100;2`/0
0`<300<30`0410@200d=3@0400H61P030`<00`<300410@800`<300@00P8200@4100410@010@40P08
20P010051@D020P800P820092@T200<30`@01@D50P0820P010092@T00`<300<30`020P8200L71`04
00<30`010@400@4100H61P802`/;00@06QXJ03De=@0e=CD0<C4a0P0S8b<0100c<c<0@T920492@P0e
=CD201TI6@0400d=3@0C4a<04a<C01@D50804A4A00@03`l?00`<300<30`02PX:0P0?3`l0100G5aL0
3`l?00l?3`0;2`/202DU9@0403`l?00f=SH0=SHf04E5A@80CTi>00@0<C4a03Lg=`0g=cL0CTi>0P18
B4P0101;Bd/0EUIF05IFEP1QHF4206][J`0406a/K01ZJVX0JVYZ06][J`80P82000@0Lg=c06EUI@1U
IFD0H61P0P1`L700101iNGT0N7Qh07QhN020P80207emO@0408B4Q01lO7`0O7al0820P080Ph>300@0
Hf=S07]kN`1kNg/0O7al0P1oOgl0102<S8`0Shn?08n?S`2:RXX209jNWP040:NWY`2>SXh0SXj>06e]
K@80L71`00@0PH6108f=S@2=SHd0RHV90P1jNWX0101lO7`0PX:208:2PP1nOWh207alO00407inOP1c
Lg<0Lg=c06ATI080J6QX00@0Hf=S05EEE@1EEED0@D510P1NGUh01013@d<0@4100410@01HF5P205MG
E`0404E5A@0P8200820P00P820803@d=00@051@D03<c<`0c<c<07AdM0P0T92@0101@D500DU9B059B
DP15ADD204Y:BP0403`l?01?Cdl0Cdm?07inOP80JVYZ00@0@D5103dm?@0m?Cd0?Shn0P11@D40101<
C4`0CDe=04e=C@15ADD203Hf=P04028R8P0P8200820P03`l?080CDe=00@0BTY:04Q8B018B4P0B4Q8
0P1DE5@0101CDe<0=CDe03De=@16ATH205MGE`04055AD@19BDT0BDU904=3@`80@41000@0D51@04e=
C@1=CDd0@4100P1DE5@0101:BTX0@4100410@01CDe<204e=C@0404=3@`1FEUH0EUIF05UIF@80DU9B
00@0FUYJ05MGE`1GEeL0CDe=0`1>CTh2055AD@0404m?C`1CDe<0De=C059BDP80CDe=00@0C4a<05UI
F@1IFET0IFEU0P1>CTh01012@T80A4A404A4A017AdL204a<C00404A4A015ADD0ADE5059BDP80Bd];
00@0EEEE071`L01`L700LW9b0P1nOWh0102SXj<0[Zj^0:j^[P2_[jl20<;2`P040=KFeP3Kfm/0fm_K
09^KV`80E5AD00@0@41002<S8`0S8b<01`L70P010@4010051@D01`L700L71`030`<200P8200000@0
0`<300820P020P800@410P030`<0100820P02PX:00X:2P071`L200<30`0400@410061PH01PH60082
0P801@D500@02@T900L71`071`L010@40P010@4010020P8010@400@4100820P200D51@0400820P05
1@D01@D500H61P8010@400@01@D500X:2P0:2PX01`L70P030`<0100410@01@D500D51@051@D200<3
0`0400410@061PH01PH600D51@801`L70`061PH0100410@01PH600H61P030`<200D51@0300<30`01
0@400@4100<01@D500@020P800820P020P801`L70P0820P010061PH01@D500D51@071`L200X:2P04
00H61P030`<00`<300@410801PH60`071`L010061PH0000000000000000200H61P0400820P061PH0
1PH600X:2P801`L700@00`<30000000000001@D50P071`L0100820P02PX:00X:2P0:2PX200@41003
00410@020P800P8200<010@400@00P82010@400@41008B4Q0P0];Bd0100/;2`0:BTY02TY:@0n?Sh2
0451@@0402XZ:P0C4a<04a<C00l?3`8061PH00<07QhN010@400@41000`061PH0100F5QH04a<C01<C
4`0B4Q82014A4@0400T92@0H61P061PH02h^;P80:RXZ00@0?Shn04];B`1;Bd/0=CDe0P0Z:RX0100m
?Cd0D51@051@D01EEED2051@D00305UIF@1QHF40HF5Q00<0J6QX00@0FEUI075aL@1aLG40NWYj0P21
PH401027QhL0NGUi07UiN@1]KFd2079bLP0408B4Q01mOGd0OGem07YjNP80J6QX00@0HF5Q075aL@1a
LG40HF5Q0P1oOgl0101iNGT0MgMg07MgM`2;Rh/207moO`0407]kN`22PX80PX:208>3P`80LG5a00@0
K6a/09>CT`2CTi<0UiNG0P2?Shl0102<S8`0MGEe07EeM@1^KVh2079bLP0407EeM@23Ph<0Ph>308F5
Q@80KVi^00@0E5AD06QXJ01XJ6P0LG5a0P1JFUX0101MGEd0HF5Q065QH@1EEED206MWI`0406ATI01;
Bd/0Bd];04M7A`80?Cdm00@05aLG00L71`071`L04A4A0P0N7Qh0100C4a<02@T900T92@0S8b<203Ti
>@0403Hf=P0h>3P0>3Ph02l_;`80?Cdm00@0LW9b05eMG@1MGEd0;2`/0P0c<c<0100k>c/0?3`l03`l
?016ATH204Y:BP0404Q8B00h>3P0>3Ph01XJ6P804Q8B00@0:RXZ0492@P12@T80BDU90P1>CTh0101?
Cdl0EeMG05MGE`1GEeL203dm?@0404M7A`1LG5`0G5aL059BDP80@T9200@0CTi>04I6AP16ATH0=SHf
0P0o?cl0100l?3`0D51@051@D012@T820451@@0405iNGP1>CTh0CTi>0451@@80DE5A00@0CTi>05AD
E01DE5@0F5QH0P1BDU8304e=C@0404a<C01=CDd0CDe=04e=C@80BDU900@0Bd];04e=C@1=CDd0Cdm?
0`1PH60204U9B@040410@011@D40@D51055AD@80DU9B00@0?clo0492@P12@T80CTi>0P19BDT0101E
EED0KVi^06i^KP1ZJVX207AdM0040:>SX`2b/[80/[:b0;Zj^P80alO700@0fMWI0=cLg03Lg=`0TY:B
0P1CDe<0100d=3@04a<C01<C4`092@T200D51@0400T92@0820P020P800D51@802@T9000010030`<0
0P8200820P010@4200<30`0400P8200:2PX02PX:00L71`800`<300@010@400H61P061PH00P820P05
1@D010092@T01`L700L71`0410@200410@0400820P0410@010@400P820801@D500@00P8200D51@05
1@D01PH60P0410@010051@D02PX:00X:2P071`L200<30`0400@410051@D01@D500D51@800`<300@0
0@4100H61P061PH01@D50P071`L300H61P0400@410061PH01PH600<30`801@D500<00`<300410@01
0@400`051@D0100820P00P8200820P071`L200P8200400H61P051@D01@D500L71`802PX:00@01PH6
00<30`030`<010@40P061PH300L71`0400H61P0000000000000000801PH600@00P8200H61P061PH0
2PX:0P071`L010030`<00000000000051@D200L71`0400P8200:2PX02PX:00X:2P8010@400<00@41
00820P020P800`0410@010020P80410@010@400Q8B4202d];@0402`/;00Y:BT0:BTY03hn?P80@D51
00@0:RXZ01<C4`0C4a<03`l?0P0H61P00`0N7Qh0410@010@400300H61P0401HF5P0C4a<04a<C018B
4P804A4A00@02@T901PH600H61P0;Rh^0P0Z:RX0100n?Sh0Bd];04];B`0e=CD202XZ:P0403dm?@1@
D500D51@05EEE@80D51@00<0FEUI065QH@1QHF400`1XJ6P0101IFET0LG5a075aL@1jNWX20861P@04
08N7Q`1iNGT0NGUi06e]K@80LW9b00@0Q8B407emO@1mOGd0NWYj0P1XJ6P0101QHF40LG5a075aL@1Q
HF4207moO`0407UiN@1gMgL0MgMg08^;R`80Ogmo00@0Ng]k08:2PP22PX80Ph>30P1aLG40101/K6`0
Ti>C09>CT`2GUiL208n?S`0408b<S01eMGD0MGEe06i^KP80LW9b00@0MGEe08>3P`23Ph<0QHF50P1^
KVh0101DE5@0J6QX06QXJ01aLG4205YJFP0405eMG@1QHF40HF5Q05EEE@80IfMW00@0I6AT04];B`1;
Bd/0AdM70P0m?Cd0100G5aL01`L700L71`0A4A4201hN7P0401<C4`092@T02@T902<S8`80>CTi00@0
=SHf03Ph>00h>3P0;bl_0P0m?Cd0101bLW80GEeM05eMG@0/;2`203<c<`0403/k>`0l?3`0?3`l04I6
AP80BTY:00@0B4Q803Ph>00h>3P06QXJ0P0B4Q80100Z:RX0@T920492@P19BDT204i>CP0404m?C`1G
EeL0EeMG05MGE`80?Cdm00@0AdM705aLG01LG5`0DU9B0P12@T80101>CTh0ATI604I6AP0f=SH203lo
?`0403`l?01@D500D51@0492@P80@D5100@0GUiN04i>CP1>CTh0@D510P1ADE40101>CTh0E5AD05AD
E01HF5P2059BDP<0CDe=00@0C4a<04e=C@1=CDd0CDe=0P19BDT0101;Bd/0CDe=04e=C@1?Cdl3061P
H080BDU900@0@4100451@@11@D40DE5A0P1BDU80100o?cl0@T920492@P1>CTh204U9B@0405EEE@1^
KVh0KVi^06YZJP80M7Ad00@0Xj>S0;:b/P2b/[80^[Zj0P37alL0103IfMT0g=cL0=cLg02BTY8205=C
D`0403@d=00C4a<04a<C00T92@801@D500@02@T900P8200820P01@D50P092@T0000400P820061PH0
1PH600820P801@D500<030`<00/;2`0;2`/010051@D300@410800P8200<01`L700T92@092@T00`03
0`<010071`L01PH600H61P00000200410@0300L71`0820P020P800<01@D500@01`L700@4100410@0
1PH60P020P8010030`<010@400@410051@D200H61P0400820P061PH01PH600@410800`<300@010@4
00<30`030`<010@40P0:2PX010061PH01@D500D51@061PH20000000400@410010@400@4100820P80
10@40`051@D010071`L00@4100410@0410@200T92@0400H61P010@400@4100<30`801@D50`030`<0
100410@01@D500D51@010@4500<30`0400@410010@400@4100L71`801PH600@00P8200D51@051@D0
1PH60`030`<200D51@0400410@000000000000D51@802PX:00@01PH601`L700L71`0<C4a0P0_;bl0
100/;2`0;bl_02l_;`15ADD203dm?@0401dM7@0A4A404A4A01<C4`8061PH00@071`L00h>3P0>3Ph0
2`/;0P0=3@d0100D51@04a<C01<C4`092@T200l?3`0400T92@0:2PX02PX:02@T9080>CTi00@0?3`l
03dm?@0m?Cd0>CTi0P0^;Rh0100m?Cd0CTi>04i>CP1:BTX204I6AP0405IFEP1PH600H61P06ATI080
J6QX00@0G5aL065QH@1QHF40L71`0P1iNGT0101WIfL0JVYZ06YZJP1]KFd206][J`0406i^KP1UIFD0
IFEU06QXJ080LG5a00@0H61P07]kN`1kNg/0Shn?0P2ATI401021PH40OGem07emO@24Q8@306e]K@<0
MgMg0P1/K6`0101WIfL0P8200820P01lO7`207EeM@0407YjNP1bLW80LW9b06MWI`80Fe]K00@0HF5Q
06UYJ@1YJFT0IfMW0P1_Kfl0101dM7@0PH610861P@1]KFd205QHF00407moO`20P800P82006e]K@80
IVIV00@0JFUY06IVIP1VIVH0E5AD0P15ADD0100h>3P05ADE01DE5@0=3@d200`<300401TI6@0A4A40
4A4A00P820808R8R00@0<S8b02d];@0];Bd07alO0P0T92@0101IFET0FUYJ05YJFP0b<S8202PX:004
038b<P0j>SX0>SXj0410@080@d=300@0C4a<0410@010@4005QHF0P0<30`0100U9BD0>c/k03/k>`14
A4@204m?C`0405ADE01@D500D51@04m?C`80Bd];00@0BTY:05]KF`1KFe/0EEEE0P16ATH0101IFET0
Bd];04];B`0/;2`202/[:`04038b<P0m?Cd0?Cdm03/k>`80=cLg00@0CDe=055AD@1ADE40Cdm?0P1@
D5001017AdL0D51@051@D01ADE4204m?C`0404E5A@14A4@0A4A404e=C@<0D51@0P1<C4`01019BDT0
C4a<04a<C01BDU8205ADE00404A4A00l?3`0?3`l03dm?@80?clo00@0C4a<04e=C@1=CDd0@d=30P14
A4@0101;Bd/0CDe=04e=C@1HF5P206=SH`0405aLG01cLg<0Lg=c0:BTY080^KVi00@0`l?30<O7a`37
alL0f=SH0P30`<00101GEeL0>CTi03Ti>@0j>SX200h>3P0400@4100<30`030`<00T92@8020P80@0;
2`/100X:2P402PX:000010051@D010@400@4100410@200D51@0400P8200410@010@400<30`802@T9
00@020P800L71`071`L02PX:0P030`<010020P801@D500D51@030`<200410@0400H61P092@T02@T9
00410@800P8200@01@D500<30`030`<01PH60P0410@010020P800`<300<30`051@D200410@030082
0P010@400@4100<020P80`030`<300@4100400H61P071`L01`L700820P802@T900@01@D500820P02
0P800`<30P0410@010051@D00P8200820P030`<200@4100400820P000000000000<30`8010@400@0
0`<300D51@051@D01@D50P030`<010051@D00`<300<30`051@D200L71`0400820P071`L01`L700D5
1@<010@40P010@4010020P800`<300<30`0:2PX200T92@0400L71`0410@010@4000000801@D500@0
1`L700D51@051@D010@40P00000010020P801PH600H61P0;2`/201XJ6P0403<c<`0_;bl0;bl_03@d
=080>3Ph00@0AdM703hn?P0n?Sh07alO0`0A4A42018B4P0400l?3`0@4100410@01@D50804Q8B00@0
1`L701<C4`0C4a<05aLG0P0I6AT0100820P00P8200820P0E5AD202h^;P0404A4A01CDe<0De=C04E5
A@80;2`/00@0=SHf04];B`1;Bd/0EUIF0P1IFET0101NGUh0HV9R069RHP1UIFD207QhN00407EeM@1T
I6@0I6AT06MWI`80Jf][00@0G5aL075aL@1aLG40Ph>30P25QHD0101ZJVX0K6a/06a/K01cLg<208F5
Q@0408J6QP2BTY80TY:B09fMW@80QHF500@0R8R808f=S@2=SHd0TI6A0P1jNWX0101/K6`0O7al07al
O023Ph<208^;R`0407alO01]KFd0KFe]07AdM080Ogmo00@0Ph>308F5Q@25QHD0OWin0P1hN7P01024
Q8@0P8200820P01[Jf/206QXJ00406MWI`1YJFT0JFUY06MWI`80GEeM00@0Kfm_065QH@1QHF40GemO
0P1BDU80101DE5@0Hf=S06=SH`1EEED2055AD@0404i>CP0l?3`0?3`l00T92@800@4100@03Ph>00d=
3@0=3@d020P80P0I6AT0100o?cl0>CTi03Ti>@0W9bL203De=@<0@41000@0@T9202LW9`0W9bL07QhN
0P0e=CD01011@D40A4A404A4A01;Bd/204A4A00401hN7P0;2`/02`/;01lO7`80=cLg00@0ADE504Y:
BP1:BTX0Bd];0P16ATH0101>CTh0DE5A055AD@0j>SX204Q8B00405MGE`1=CDd0CDe=05EEE@80DU9B
00@0?clo02DU9@0U9BD0:2PX0P0D51@01011@D40CDe=04e=C@0k>c/204e=C@04051@D01>CTh0CTi>
04M7A`80Bd];00@0CDe=059BDP1BDU80BTY:0P16ATH01019BDT0CDe=04e=C@1ADE4205EEE@0404Q8
B012@T80@T9204M7A`80?Cdm00@0<30`0410@010@400@d=30P11@D4304m?C`0404Y:BP19BDT0BDU9
04M7A`80C4a<00@0EeMG05eMG@1MGEd0FUYJ0P1`L700102MWId0`/;20<;2`P32`/820;Zj^P040<[:
bP2g]kL0]kNg075aL@80EeMG00@0BDU901LG5`0G5aL01`L70P0820P010010@402@T900T92@0<30`2
00P8200000@01@D500@4100410@010@40P051@D0100820P010@400@410030`<200T92@0400P82007
1`L01`L700X:2P800`<300@00P8200D51@051@D00`<30P010@4010061PH02@T900T92@010@420082
0P0400D51@030`<00`<300H61P8010@400@00P8200<30`030`<01@D50P010@400`020P800@410041
0@0300P820<00`<30`0410@010061PH01`L700L71`020P8200T92@0400D51@020P800P8200<30`80
10@400@01@D500820P020P800`<30P0410@010020P800000000000030`<200@4100400<30`051@D0
1@D500D51@800`<300@01@D500<30`030`<01@D50P071`L010020P801`L700L71`051@D300@41080
0@4100@00P8200<30`030`<02PX:0P092@T010071`L010@400@41000000200D51@0400L71`051@D0
1@D500@41080000000@00P8200H61P061PH02`/;0P0J6QX0100c<c<0;bl_02l_;`0d=3@203Ph>004
04M7A`0n?Sh0?Shn01lO7`<04A4A0P0B4Q80100?3`l0410@010@400D51@2018B4P0400L71`0C4a<0
4a<C01LG5`806ATI00@020P800820P020P805ADE0P0^;Rh01014A4@0De=C05=CD`15ADD202`/;004
03Hf=P1;Bd/0Bd];05IFEP80FEUI00@0GUiN069RHP1RHV80IFEU0P1hN7P0101eMGD0I6AT06ATI01W
IfL206][J`0405aLG01aLG40LG5a08>3P`80QHF500@0JVYZ06a/K01/K6`0Lg=c0P25QHD01026QXH0
TY:B09:BTP2MWId208F5Q@0408R8R02=SHd0SHf=096AT@80NWYj00@0K6a/07alO01lO7`0Ph>30P2;
Rh/0101lO7`0KFe]06e]K@1dM7@207moO`0408>3P`25QHD0QHF507inOP80N7Qh00@0Q8B40820P020
P800Jf][0P1XJ6P0101WIfL0JFUY06UYJ@1WIfL205eMG@0406m_K`1QHF40HF5Q05mOG`80DU9B00@0
E5AD06=SH`1SHf<0EEEE0P1ADE40101>CTh0?3`l03`l?0092@T200410@0400h>3P0=3@d03@d=00P8
20806ATI00@0?clo03Ti>@0i>CT09bLW0P0e=CD30410@0040492@P0W9bL09bLW01hN7P80=CDe00@0
@D5104A4A014A4@0Bd];0P14A4@0100N7Qh02`/;00/;2`0O7al203Lg=`0404E5A@1:BTX0BTY:04];
B`80ATI600@0CTi>055AD@1ADE40>SXj0P18B4P0101GEeL0CDe=04e=C@1EEED2059BDP0403lo?`0U
9BD09BDU02PX:08051@D00@0@D5104e=C@1=CDd0>c/k0P1=CDd0101@D500CTi>04i>CP17AdL204];
B`0404e=C@1BDU80DU9B04Y:BP80ATI600@0BDU904e=C@1=CDd0DE5A0P1EEED01018B4P0@T920492
@P17AdL203dm?@04030`<010@400@41004=3@`80@D510`1?Cdl0101:BTX0BDU904U9B@17AdL204a<
C00405MGE`1MGEd0GEeM05YJFP80L71`00@0WIfM0<;2`P32`/80`/;20P2j^[X0103:b/X0]kNg0;Ng
]`1aLG4205MGE`0404U9B@0G5aL05aLG00L71`8020P800@00@4100T92@092@T030`<0P0820P00004
00D51@030`<00`<300@410801PH600<02@T900H61P061PH00`071`L010010@401PH600H61P0=3@d2
00D51@0300H61P051@D01@D500@01PH60P092@T0100410@00`<300<30`051@D200H61P0400L71`05
1@D01@D500H61P800P8200@01@D500P8200820P02@T90P0410@010020P800@4100410@030`<20041
0@0400<30`0410@010@400/;2`8020P800@00`<300T92@092@T00`<30P0410@010010@402@T900T9
2@051@D20000000400410@020P800P8200@4108020P800@010@400H61P061PH00P820P0410@01003
0`<01PH600H61P061PH200820P0400D51@0820P020P800D51@801`L70`061PH010051@D010@400@4
10071`L200T92@0400H61P020P800P8200820P<010@40P0820P010092@T01PH600H61P0410@300L7
1`802@T900@03`l?01@D500D51@0:b/[0P0Y:BT0100_;bl0>CTi03Ti>@15ADD20451@@0402TY:@0C
4a<04a<C00l?3`802@T900@01`L700h>3P0>3Ph03`l?0P0<30`010092@T04Q8B018B4P0W9bL202l_
;`04010@400;2`/02`/;01<C4`806ATI00@0?3`l069RHP1RHV80FEUI0P0j>SX0100e=CD0AdM704M7
A`1KFe/305eMG@80HF5Q00@0I6AT07IfMP1fMWH0NGUi0P1bLW80101YJFT0MgMg07MgM`20P80207Ee
M@0407alO01kNg/0Ng]k065QH@80JFUY00@0OGem08^;R`2;Rh/0Rh^;0P2?Shl0101gMgL0Fe]K05]K
F`1lO7`208F5Q@0408^;R`1kNg/0Ng]k06][J`80Ogmo00@0RXZ:096AT@2ATI40RXZ:0P1hN7P01020
P800S8b<08b<S02;Rh/208B4Q00407alO022PX80PX:209BDU080SHf=00@0MWIf06a/K01/K6`0HV9R
0P1YJFT0101hN7P0H61P061PH01HF5P204a<C00405YJFP1OGel0GemO05EEE@80GemO00@0De=C04Q8
B018B4P0D51@0P1GEeL0100U9BD03@d=00d=3@0=3@d201HF5P0400X:2P0>3Ph03Ph>038b<P<0?Cdm
0P1;Bd/0100e=CD0:RXZ02XZ:P1ADE4204A4A00401hN7P0Y:BT0:BTY03hn?P80A4A400@0BDU904M7
A`17AdL0:BTY0P0:2PX0100I6AT0=SHf03Hf=P12@T8204=3@`0404I6AP1?Cdl0Cdm?05MGE`80C4a<
00@0;Bd]03Ph>00h>3P0EeMG0P1IFET0101FEUH0De=C05=CD`14A4@203Hf=P04030`<00H61P061PH
06m_K`80Ng]k00@0ADE504=3@`13@d<0AdM70P1=CDd0101?Cdl0DU9B059BDP1>CTh205ADE00404a<
C015ADD0ADE504I6AP80DU9B0`1?Cdl01018B4P0@d=304=3@`0j>SX303lo?`80ADE500@0@d=304U9
B@19BDT0FEUI0P1ADE40101>CTh0C4a<04a<C013@d<204i>CP0405QHF01GEeL0EeMG05aLG080K6a/
00@0VIVI0<_;b`3;bl/0b<S80P2e]KD0102ZZZX0Zj^[0:^[Z`36a/H209nOW`0403hn?P0:2PX02PX:
00L71`801@D500@0000000D51@051@D01`L70P0820P0000400L71`0:2PX02PX:00P8208010@400@0
20P800L71`071`L00`<30P0410@010051@D010@400@410051@D200@4100300D51@092@T02@T900<0
1PH600@020P800X:2P0:2PX01PH60P0410@010051@D02@T900T92@030`<200L71`0400T92@0410@0
10@400T92@<020P80P051@D010030`<00@4100410@00000200@4100400410@030`<00`<300@41080
0P8200@01`L700@4100410@00`<30P071`L010061PH010@400@410051@D200<30`0400H61P010@40
0@4100410@8020P800@01PH600L71`071`L00@410P0410@010020P8010@400@4100410@200D51@04
0000000410@010@400/;2`803Ph>00@00`<300410@010@400P820P0410@300D51@0400H61P0410@0
10@4000000800`<300@02PX:00H61P061PH00`<30`061PH300/;2`804A4A00@08B4Q02LW9`0W9bL0
:2PX0P0];Bd0100b<S80@4100410@015ADD203/k>`0402TY:@0Q8B408B4Q01LG5`803@d=00@04Q8B
01PH600H61P051@D0P0E5AD00`0I6AT0820P020P800302d];@0401PH600<30`030`<02<S8`80=3@d
00@0>SXj04m?C`1?Cdl0G5aL0P1JFUX0101:BTX0?3`l03`l?018B4P205ADE00405UIF@1TI6@0I6AT
061PH080EUIF00@0I6AT07UiN@1iNGT0IfMW0P1/K6`0101^KVh0IfMW06MWI`1eMGD2071`L00407Mg
M`1cLg<0Lg=c06][J`80OGem00@0Kfm_07AdM01dM7@0Jf][0P1ZJVX01021PH40O7al07alO01mOGd2
0820P00307IfMP1bLW80LW9b00<0Ng]k00@0OGem07EeM@1eMGD0M7Ad0P1iNGT0101fMWH0LW9b079b
LP1`L70207MgM`0408R8R023Ph<0Ph>306IVIP80HV9R00@0LW9b08>3P`23Ph<0L71`0P16ATH0101G
EeL0H61P061PH01TI6@206IVIP0405QHF01UIFD0IFEU05iNGP80<C4a00@0=3@d05EEE@1EEED0>CTi
0P0`<300100i>CT0:BTY02TY:@0C4a<200820P0400h>3P0b<S80<S8b05ADE080@41000@09BDU02h^
;P0^;Rh0F5QH0P1/K6`0100o?cl09bLW02LW9`0d=3@20410@0040492@P13@d<0@d=3038b<P804A4A
00@05aLG030`<00`<300@4100P1;Bd/01018B4P0CDe=04e=C@1CDe<204Y:BP0403hn?P0m?Cd0?Cdm
04Y:BP80HV9R00@0EUIF04M7A`17AdL0>3Ph0P0l?3`0100m?Cd0BDU904U9B@2FUYH207]kN`04051@
D00o?cl0?clo04Q8B080CTi>00@0DE5A05IFEP1FEUH0DU9B0P1DE5@0101;Bd/0ATI604I6AP1:BTX2
05EEE@0405ADE01=CDd0CDe=04=3@`80?Shn00@0@41006IVIP1VIVH0Hf=S0P19BDT01012@T80Cdm?
04m?C`1EEED204M7A`0404a<C019BDT0BDU903lo?`80CDe=00@0DE5A04I6AP16ATH0EeMG0P1aLG40
102QXJ40clo?0<o?c`3>c/h20;fm_@040:n_[`2TY:@0Y:BT0;2`/080QHF500@0:2PX000000000000
10@40P0820P0100410@00P8200820P00000200D51@0000@01`L700X:2P0:2PX020P80P0410@01008
20P01`L700L71`030`<200@4100400D51@0410@010@400D51@8010@400<01@D500T92@092@T00`06
1PH0100820P02PX:00X:2P061PH200@4100400D51@092@T02@T900<30`801`L700@02@T900@41004
10@02@T90`0820P200D51@0400<30`010@400@410000008010@400@00@4100<30`030`<010@40P02
0P8010071`L010@400@410030`<200L71`0400H61P0410@010@400D51@800`<300@01PH600410@01
0@400@410P0820P010061PH01`L700L71`010@4200@4100400820P0410@010@400@410801@D500@0
000000@4100410@02`/;0P0>3Ph010030`<00@4100410@020P8200@410<01@D500@01PH600@41004
10@000000P030`<0100:2PX01PH600H61P030`<300H61P<02`/;0P0A4A40100Q8B409bLW02LW9`0X
:2P202d];@04038b<P10@400@41004E5A@80>c/k00@0:BTY024Q8@0Q8B405aLG0P0=3@d0100B4Q80
61PH01PH600D51@201DE5@0301TI6@0P8200820P00<0;Bd]00@061PH00`<300<30`08b<S0P0d=3@0
100j>SX0Cdm?04m?C`1LG5`205YJFP0404Y:BP0l?3`0?3`l04Q8B080E5AD00@0FEUI06ATI01TI6@0
H61P0P1FEUH0101TI6@0NGUi07UiN@1WIfL206a/K00406i^KP1WIfL0IfMW07EeM@80L71`00@0MgMg
07=cL`1cLg<0Jf][0P1mOGd0101_Kfl0M7Ad07AdM01[Jf/206YZJP040861P@1lO7`0O7al07emO@80
P82000<0MWIf079bLP1bLW800`1kNg/0101mOGd0MGEe07EeM@1dM7@207UiN@0407IfMP1bLW80LW9b
071`L080MgMg00@0R8R808>3P`23Ph<0IVIV0P1RHV80101bLW80Ph>308>3P`1`L70204I6AP0405MG
E`1PH600H61P06ATI080IVIV00@0F5QH06EUI@1UIFD0GUiN0P0a<C40100d=3@0EEEE05EEE@0i>CT2
030`<00403Ti>@0Y:BT0:BTY01<C4`800P8200@03Ph>038b<P0b<S80E5AD0P10@400100U9BD0;Rh^
02h^;P1HF5P206a/K00403lo?`0W9bL09bLW03@d=080@41000@0@T9204=3@`13@d<0<S8b0P0A4A40
100G5aL0<30`030`<010@40204];B`0404Q8B01=CDd0CDe=05=CD`80BTY:00@0?Shn03dm?@0m?Cd0
BTY:0P1RHV80101FEUH0AdM704M7A`0h>3P203`l?00403dm?@19BDT0BDU909JFUP80Ng]k00@0D51@
03lo?`0o?cl0B4Q80P1>CTh0101ADE40EUIF05IFEP1BDU8205ADE00404];B`16ATH0ATI604Y:BP80
EEEE00@0E5AD04e=C@1=CDd0@d=30P0n?Sh01010@400IVIV06IVIP1SHf<204U9B@040492@P1?Cdl0
Cdm?05EEE@80AdM700@0C4a<04U9B@19BDT0?clo0P1=CDd0101ADE40ATI604I6AP1GEeL2075aL@04
0:6QX@3?cll0clo?0<k>cP80_Kfm00@0[jn_0:BTY02TY:@0/;2`0P25QHD0100X:2P0000000000004
10@200P8200400@410020P800P82000000801@D5000010061PH020P800P8200820P200820P0400D5
1@071`L01`L700<30`800P820`061PH300820P0400D51@061PH01PH600D51@801`L700@01PH60082
0P020P801PH60P0410@010010@4010@400@410020P8300L71`800`<300@02`/;00D51@051@D01PH6
0P020P8010051@D00`<300<30`010@4200@4100400H61P0820P020P800D51@800`<300@01@D500H6
1P061PH01@D50P0820P010061PH010@400@410061PH200D51@0400L71`010@400@4100@410800@41
00@0000000P8200820P00@410P0410@010020P801@D500D51@051@D200H61P0400820P0410@010@4
00L71`802PX:00<01@D500<30`030`<00`030`<010010@400000000000020P8200@4100400D51@04
10@010@400D51@801`L700@00`<300H61P061PH02PX:0P071`L010061PH03@d=00d=3@0T92@202`/
;00402HV9P0b<S80<S8b03Xj>P80BDU900@0B4Q8034a<@0a<C406QXJ0P0L71`0100G5aL05ADE01DE
5@0E5AD201<C4`04018B4P0C4a<04a<C01DE5@80;2`/00@0=SHf02XZ:P0Z:RX06a/K0P0E5AD0100a
<C40>SXj03Xj>P0i>CT204Y:BP0405EEE@1JFUX0FUYJ06ATI080BTY:00@0?3`l05EEE@1EEED0HF5Q
0P1VIVH0101UIFD0FEUI05UIF@1WIfL207inOP0407alO01nOWh0OWin07MgM`80Kfm_00@0NGUi07Ee
M@1eMGD0O7al0P21PH40101WIfL0KVi^06i^KP1]KFd206i^KP0406IVIP1]KFd0KFe]07UiN@80OGem
00@0NWYj08B4Q024Q8@0P8200P1[Jf/0101mOGd0QhN708N7Q`1gMgL206e]K@0408:2PP2BTY80TY:B
08B4Q080LG5a00<0Kfm_07EeM@1eMGD00`1kNg/0101`L700Jf][06][J`1aLG4207inOP0406EUI@16
ATH0ATI6051@D080DU9B00@0AdM704i>CP1>CTh0F5QH0`1;Bd/203Xj>P0403Hf=P0k>c/0>c/k05AD
E080C4a<00@0BTY:03`l?00l?3`0:2PX0P061PH0100000004a<C01<C4`1RHV8205mOG`0402HV9P0[
:b/0:b/[04M7A`80HF5Q00@0BDU902d];@0];Bd0>CTi0P15ADD01011@D40ADE504E5A@0n?Sh201dM
7@0401@D500Y:BT0:BTY04=3@`80E5AD00@0BTY:04Q8B018B4P0Cdm?0P1:BTX0101<C4`0A4A404A4
A00];Bd205QHF00405]KF`1<C4`0C4a<04I6AP80@41000@0>SXj05QHF01HF5P0TI6A0P1XJ6P0101F
EUH0ADE504E5A@1=CDd204];B`<0CTi>00<0C4a<04e=C@1=CDd00`1;Bd/0101DE5@0Fe]K05]KF`1E
EED204M7A`040410@00m?Cd0?Cdm04a<C080K6a/00<0G5aL04i>CP1>CTh0101:BTX204I6AP0404];
B`12@T80@T920451@@80BTY:00@0BDU904Q8B018B4P0Fe]K0P1cLg<0102[Zj/0f][J0=[JfP3;bl/2
0;Vi^@040<G5a@3<c<`0c<c<0:FUY@80EeMG00@05QHF00<30`030`<01PH60P0820P010092@T01@D5
00D51@061PH200P8200000@01PH600P8200820P00P820P00000300D51@<01PH600<02@T900D51@05
1@D00`051@D0100<30`00`<300<30`051@D200`<300400P820071`L01`L700H61P801@D500@00P82
00@4100410@00P820P061PH0100:2PX00000000000071`L200P8200400/;2`030`<00`<300000080
1PH600@01`L700820P020P8030`<0P051@D0100820P01`L700L71`0410@200H61P0400@410051@D0
1@D500<30`<01PH60P010@4010020P800`<300<30`0:2PX200@4100400H61P030`<00`<300820P80
0`<300@00P8200D51@051@D02PX:0P0410@010030`<0000000000000000200P8200400X:2P061PH0
1PH600820P800@4100@00`<300820P020P800P820P0820P0100>3Ph020P800P820020P8200L71`04
00P820071`L01`L700L71`<01@D50P061PH0100B4Q809BDU02DU9@0X:2P202l_;`0403dm?@1:BTX0
BTY:03lo?`80:2PX00@051@D014A4@0A4A4051@D0P0N7Qh0100A4A4020P800P8200A4A4200d=3@04
00H61P0a<C40<C4a03lo?`80;bl_00@030`<01hN7P0N7Qh0=cLg0P0c<c<0100m?Cd0Cdm?04m?C`1F
EUH204U9B@0405YJFP1DE5@0E5AD03`l?080De=C00@0Fe]K05QHF01HF5P0Hf=S0P1UIFD0101dM7@0
NWYj07YjNP1nOWh208B4Q00407UiN@1RHV80HV9R06UYJ@80Jf][00@0JVYZ07IfMP1fMWH0KFe]0P1W
IfL0101eMGD0L71`071`L01PH60207UiN@0408R8R024Q8@0Q8B407QhN080QHF500@0UYJF08b<S02<
S8`0QhN70P2JVYX0102BTY80Q8B408B4Q027QhL209:BTP0409BDU024Q8@0Q8B40820P080QXJ600@0
Q8B407moO`1oOgl0OGem0P20P800101iNGT0IfMW06MWI`1BDU8205=CD`0405eMG@1JFUX0FUYJ04i>
CP80Fe]K00@0JFUY03Ti>@0i>CT0>3Ph0P1BDU80101PH600?clo03lo?`1EEED205IFEP0403Lg=`1D
E5@0E5AD04Y:BP8051@D00@030`<00820P020P80Bd];0P2?Shl0100e=CD09BDU02DU9@0e=CD204M7
A`0403/k>`0X:2P0:2PX03Ph>080?Shn00@0=SHf04A4A014A4@0ADE50P0Y:BT0100P8200<S8b038b
<P17AdL204m?C`0404Y:BP1<C4`0C4a<051@D080C4a<00@0EeMG05QHF01HF5P08R8R0P0c<c<0101K
Fe/0D51@051@D019BDT204=3@`0403`l?01IFET0FEUI08N7Q`80J6QX00@0FUYJ04U9B@19BDT0A4A4
0P1;Bd/0101DE5@0CDe=04e=C@19BDT204Y:BP0404A4A01;Bd/0Bd];05MGE`80F5QH00@0Bd];03lo
?`0o?cl0@4100P16ATH0101DE5@0EUIF05IFEP16ATH204m?C`03059BDP1<C4`0C4a<00<0C4a<00<0
@D510410@010@400101>CTh3055AD@80MgMg00@0_[jn0=WIf@3IfMT0`<300P2i^KT0103<c<`0h^;R
0>;RhP2DU9@203De=@0401XJ6P0?3`l03`l?00L71`80000000@02PX:00P8200820P03Ph>0P0:2PX0
000400H61P0820P020P800820P8000000`051@D300H61P0300T92@051@D01@D500<01@D500@030`<
00<30`030`<01@D50P0<30`0100820P01`L700L71`061PH200D51@0400820P0410@010@400820P80
1PH600@02PX:0000000000001`L70P0820P0100;2`/00`<300<30`00000200H61P0400L71`020P80
0P8200`<30801@D500@020P800L71`071`L010@40P061PH0100410@01@D500D51@030`<300H61P80
0@4100@00P8200<30`030`<02PX:0P0410@010061PH00`<300<30`020P8200<30`0400820P051@D0
1@D500X:2P8010@400@00`<300000000000000000P0820P0100:2PX01PH600H61P020P8200410@04
00<30`020P800P8200820P8020P800@03Ph>00P8200820P00P820P071`L0100820P01`L700L71`07
1`L300D51@801PH600@04Q8B02DU9@0U9BD0:2PX0P0_;bl0100m?Cd0BTY:04Y:BP0o?cl202PX:004
01@D500A4A404A4A01@D50807QhN00@04A4A00P8200820P04A4A0P0=3@d010061PH0<C4a034a<@0o
?cl202l_;`0400`<300N7Qh07QhN03Lg=`80<c<c00@0?Cdm04m?C`1?Cdl0EUIF0P19BDT0101JFUX0
E5AD05ADE00l?3`205=CD`0405]KF`1HF5P0F5QH06=SH`80IFEU00@0M7Ad07YjNP1jNWX0OWin0P24
Q8@0101iNGT0HV9R069RHP1YJFT206][J`0406YZJP1fMWH0MWIf06e]K@80IfMW00@0MGEe071`L01`
L700H61P0P1iNGT01028R8P0Q8B408B4Q01hN7P208F5Q@0409JFUP2<S8`0S8b<08N7Q`80VYZJ00@0
TY:B08B4Q024Q8@0QhN70P2BTY80102DU9@0Q8B408B4Q020P80208J6QP0408B4Q01oOgl0Ogmo07em
O@80P82000@0NGUi06MWI`1WIfL0DU9B0P1CDe<0101MGEd0FUYJ05YJFP1>CTh205]KF`0406UYJ@0i
>CT0>CTi03Ph>080DU9B00@0H61P03lo?`0o?cl0EEEE0P1FEUH0100g=cL0E5AD05ADE01:BTX201@D
500400`<30020P800P8204];B`80Shn?00@0=CDe02DU9@0U9BD0=CDe0P17AdL0100k>c/0:2PX02PX
:00h>3P203hn?P0403Hf=P14A4@0A4A404E5A@80:BTY00@0820P038b<P0b<S80AdM70P1?Cdl0101:
BTX0C4a<04a<C01@D50204a<C00405MGE`1HF5P0F5QH028R8P80<c<c00@0Fe]K051@D01@D500BDU9
0P13@d<0100l?3`0FEUI05UIF@27QhL206QXJ00405YJFP19BDT0BDU904A4A080Bd];00@0E5AD04e=
C@1=CDd0BDU90P1:BTX01014A4@0Bd];04];B`1GEeL205QHF00404];B`0o?cl0?clo0410@080ATI6
00@0E5AD05IFEP1FEUH0ATI60P1?Cdl00`1BDU80C4a<04a<C00304a<C0030451@@10@400@41000@0
CTi>0`1ADE4207MgM`040;jn_P3IfMT0fMWI0<30`080^KVi00@0c<c<0>;RhP3Rh^80U9BD0P0e=CD0
100J6QX03`l?00l?3`071`L20000000400X:2P0820P020P800h>3P802PX:0000100410@02`/;00/;
2`071`L200@41004000000020P800P8200L71`802PX:00@020P800410@010@4010@40P061PH0100<
30`010@400@4100=3@d200L71`0400H61P071`L01`L700T92@801@D500@00P8200H61P061PH00P82
0P051@D00`030`<010@400@4100300@4100400D51@0410@010@400410@801`L700<02@T900<30`03
0`<00`030`<010010@400`<300<30`051@D200H61P0300<30`020P800P8200<00P8200@00`<300@4
100410@00@410P0410@0100820P00`<300<30`071`L200H61P0400X:2P0410@010@400410@800000
0`051@D010020P8010@400@4100410@200P8200300L71`030`<00`<300<00`<300@02PX:00/;2`0;
2`/00`<30P051@D0100820P01PH600H61P051@D200L71`<03@d=00@020P800h>3P0>3Ph03Ph>0P06
1PH0100M7Ad0:BTY02TY:@0X:2P202h^;P0403hn?P15ADD0ADE503<c<`807AdM00@05QHF00h>3P0>
3Ph0410@0P0I6AT0100<30`01PH600H61P0A4A4200l?3`0400/;2`0j>SX0>SXj0410@080;Rh^00@0
2`/;01lO7`0O7al0<C4a0P0c<c<01018B4P0DU9B059BDP1RHV8205iNGP0404a<C00e=CD0=CDe02d]
;@80BDU900@0F5QH05iNGP1NGUh0Hf=S0P1XJ6P0101`L700IFEU06EUI@1RHV8207=cL`0406QXJ01F
EUH0EUIF06a/K080O7al00@0QhN707alO01lO7`0Ogmo0P1iNGT0101ZJVX0LG5a075aL@1cLg<208^;
R`0409VIV@2EUID0UIFE09>CT`80PX:200@0QhN708j>SP2>SXh0OWin0P2BTY80102NWYh0UYJF09JF
UP1oOgl207]kN`0407UiN@1gMgL0MgMg08R8R080Shn?00@0Ti>C08f=S@2=SHd0JVYZ0P1VIVH01020
P800MGEe07EeM@1GEeL205=CD`<0GUiN00@0Hf=S06][J`1[Jf/0L71`0P1IFET01018B4P0ADE504E5
A@1YJFT205ADE004055AD@1HF5P0F5QH04I6AP80FEUI00@0I6AT038b<P0b<S807alO0P0<30`0100A
4A40K6a/06a/K00i>CT201dM7@04020P800^;Rh0;Rh^02h^;P80:2PX00@0<C4a03Lg=`0g=cL0<C4a
0P11@D40101@D500?3`l03`l?00V9RH203@d=004051@D01CDe<0De=C04e=C@80C4a<00@0Cdm?05=C
D`1CDe<0F5QH0P1TI6@01016ATH09BDU02DU9@1;Bd/204Q8B00404U9B@1<C4`0C4a<03`l?080Cdm?
00@0Ng]k06UYJ@1YJFT0HF5Q0P1>CTh01017AdL0Bd];04];B`1?Cdl204e=C@0404Y:BP1>CTh0CTi>
04I6AP<0BTY:0P17AdL01015ADD0A4A404A4A014A4@204m?C`0405QHF01<C4`0C4a<04a<C080DE5A
101?Cdl204e=C@0403Ti>@10@400@410051@D080BDU900@0B4Q804Y:BP1:BTX0C4a<0P21PH400`31
`L40d=3@0=3@d0030<G5a@040=3@d03Fe]H0e]KF07=cL`80;Rh^00@08b<S018B4P0B4Q800`<30P00
000010071`L01PH600H61P061PH200<30`0000@00`<300L71`071`L02PX:0P051@D010010@4010@4
00@410092@T200L71`04000000010@400@4100820P801@D500@03@d=00H61P061PH01PH60P010@40
10051@D00P8200820P071`L200P8200400<30`051@D01@D500<30`<01@D50P061PH300820P030000
000410@010@400<01@D500@01`L700<30`030`<000000P061PH010030`<00P8200820P051@D200H6
1P040000000820P020P800<30`<00P820P061PH0100000001@D500D51@051@D200820P0400000007
1`L01`L700X:2PD010@400@0000000D51@051@D00@410P0820P010051@D00@4100410@020P8200<3
0`<01@D50`0:2PX300H61P<0000000@01PH600L71`071`L030`<0P0:2PX0100410@04a<C01<C4`0L
71`201<C4`0402DU9@0W9bL09bLW02DU9@80=3@d00@0@41004I6AP16ATH0?Cdm0P0P8200100B4Q80
30`<00`<300>3Ph2014A4@0400T92@071`L01`L700d=3@802@T900@0410@03/k>`0k>c/0BTY:0P0a
<C40100B4Q804A4A014A4@0V9RH203Xj>P0305=CD`1>CTh0CTi>00<0B4Q800<0?clo03Lg=`0g=cL0
0`0c<c<01014A4@0F5QH05QHF01ADE4205YJFP0406][J`1TI6@0I6AT05MGE`80GUiN00@0Hf=S06IV
IP1VIVH0MgMg0P1fMWH01029RHT0P8200820P01jNWX207IfMP0406QXJ027QhL0QhN708J6QP80Ogmo
00@0UIFE09ZJVP2JVYX0TY:B0P1gMgL0101eMGD0S8b<08b<S02ATI4209nOW`0409bLW028R8P0R8R8
07YjNP80RHV900@0Ng]k071`L01`L700Shn?0P2KVi/0102PX:00Vi^K09^KV`1eMGD206QXJ00408B4
Q020P800P82006e]K@<0IfMW0P1EEED0101BDU80G5aL05aLG01OGel205=CD`04059BDP15ADD0ADE5
06ATI080AdM700@0DU9B06EUI@1UIFD0JFUY0P1KFe/0101;Bd/0CTi>04i>CP0b<S82018B4P0400@4
100R8R808R8R02@T90803@d=00@02`/;01PH600H61P0<30`0P0i>CT0100X:2P0<S8b038b<P0g=cL2
03Hf=P0404U9B@1=CDd0CDe=038b<P80=3@d00@0DE5A05IFEP1FEUH0DE5A0P1=CDd0101>CTh0EUIF
05IFEP1:BTX205ADE00407=cL`0o?cl0?clo01/K6`80>CTi00@0BTY:05=CD`1CDe<0>SXj0P17AdL0
101RHV80GUiN05iNGP1RHV8305QHF080Bd];00@0Cdm?04i>CP1>CTh0B4Q80P1:BTX01019BDT0CDe=
04e=C@19BDT204a<C00404M7A`1;Bd/0Bd];04M7A`80DU9B00@0FEUI04m?C`1?Cdl0EeMG0P1CDe<0
1015ADD0Bd];04];B`1<C4`204Q8B00403Ti>@17AdL0AdM7059BDP80B4Q800@0@T9204M7A`17AdL0
EEEE0P21PH40102h^;P0f=SH0=SHf03Bd]820<G5a@040<k>cP3Hf=P0f=SH07alO080=SHf00@05aLG
00`<300<30`010@40P010@4010020P801@D500D51@010@420000000000@00`<300L71`071`L02PX:
0P051@D010010@4010@400@410092@T200L71`04000000010@400@4100820P801@D500@03@d=00H6
1P061PH01PH60P010@4010051@D00P8200820P071`L200P8200400<30`051@D01@D500<30`<01@D5
0P061PH300820P030000000410@010@400<01@D500@01`L700<30`030`<000000P061PH010030`<0
0P8200820P051@D200H61P040000000820P020P800<30`<00P820P061PH0100000001@D500D51@05
1@D200820P04000000071`L01`L700X:2PD010@400@0000000D51@051@D00@410P0820P010051@D0
0@4100410@020P8200<30`<01@D50`0:2PX300H61P<0000000@01PH600L71`071`L030`<0P0:2PX0
100410@04a<C01<C4`0L71`201<C4`0402DU9@0W9bL09bLW02DU9@80=3@d00@0@41004I6AP16ATH0
?Cdm0P0P8200100B4Q8030`<00`<300>3Ph2014A4@0400T92@071`L01`L700d=3@802@T900@0410@
03/k>`0k>c/0BTY:0P0a<C40100B4Q804A4A014A4@0V9RH203Xj>P0305=CD`1>CTh0CTi>00<0B4Q8
00<0?clo03Lg=`0g=cL00`0c<c<01014A4@0F5QH05QHF01ADE4205YJFP0406][J`1TI6@0I6AT05MG
E`80GUiN00@0Hf=S06IVIP1VIVH0MgMg0P1fMWH01029RHT0P8200820P01jNWX207IfMP0406QXJ027
QhL0QhN708J6QP80Ogmo00@0UIFE09ZJVP2JVYX0TY:B0P1gMgL0101eMGD0S8b<08b<S02ATI4209nO
W`0409bLW028R8P0R8R807YjNP80RHV900@0Ng]k071`L01`L700Shn?0P2KVi/0102PX:00Vi^K09^K
V`1eMGD206QXJ00408B4Q020P800P82006e]K@<0IfMW0P1EEED0101BDU80G5aL05aLG01OGel205=C
D`04059BDP15ADD0ADE506ATI080AdM700@0DU9B06EUI@1UIFD0JFUY0P1KFe/0101;Bd/0CTi>04i>
CP0b<S82018B4P0400@4100R8R808R8R02@T90803@d=00@02`/;01PH600H61P0<30`0P0i>CT0100X
:2P0<S8b038b<P0g=cL203Hf=P0404U9B@1=CDd0CDe=038b<P80=3@d00@0DE5A05IFEP1FEUH0DE5A
0P1=CDd0101>CTh0EUIF05IFEP1:BTX205ADE00407=cL`0o?cl0?clo01/K6`80>CTi00@0BTY:05=C
D`1CDe<0>SXj0P17AdL0101RHV80GUiN05iNGP1RHV8305QHF080Bd];00@0Cdm?04i>CP1>CTh0B4Q8
0P1:BTX01019BDT0CDe=04e=C@19BDT204a<C00404M7A`1;Bd/0Bd];04M7A`80DU9B00@0FEUI04m?
C`1?Cdl0EeMG0P1CDe<01015ADD0Bd];04];B`1<C4`204Q8B00403Ti>@17AdL0AdM7059BDP80B4Q8
00@0@T9204M7A`17AdL0EEEE0P21PH40102h^;P0f=SH0=SHf03Bd]820<G5a@040<k>cP3Hf=P0f=SH
07alO080=SHf00@05aLG00`<300<30`010@40P010@4010020P801@D500D51@010@420000000000@0
0`<300D51@051@D01`L70P020P8400D51@8010@400@00P8200@4100410@00P820P0:2PX0100?3`l0
1`L700L71`020P8200410@0400@410061PH01PH600D51@801`L700@01@D500820P020P800`<30P04
10@00`071`L000000000000400820P8020P800@02PX:00410@010@400`<30P051@D010020P801@D5
00D51@071`L200H61P0400D51@061PH01PH600<30`8020P800<01PH600L71`071`L00`030`<01000
00001@D500D51@0410@200D51@0300H61P030`<00`<300<010@400@01@D500H61P061PH010@40P05
1@D400<30`8010@400@01@D500@4100410@010@40`061PH200<30`0300@4100820P020P800<01`L7
00<01PH600<30`030`<00`0410@010010@402@T900T92@0V9RH202`/;004020P800K6a/06a/K02l_
;`80?clo00@0AdM704Q8B018B4P0@d=30P0Y:BT0100C4a<02PX:00X:2P092@T200X:2P0400T92@0:
2PX02PX:018B4P801`L700@04Q8B03De=@0e=CD0EUIF0P0h>3P0100M7Ad07QhN01hN7P0I6AT203`l
?00405iNGP1=CDd0CDe=03lo?`80@T9200@0@41004A4A014A4@0Bd];0P11@D40100n?Sh0@4100410
@00o?cl204];B`0406EUI@1ZJVX0JVYZ06QXJ080K6a/00@0KVi^06a/K01/K6`0OGem0P1gMgL0101a
LG40JFUY06UYJ@1]KFd207EeM@0407QhN01iNGT0NGUi07]kN`80Q8B400@0Ti>C08J6QP26QXH0NGUi
0P23Ph<01024Q8@0R8R808R8R02BTY8209VIV@04092@T01oOgl0Ogmo07EeM@80TI6A00@0SHf=08B4
Q024Q8@0WinO0P2UYJD0102BTY80Rh^;08^;R`1oOgl206m_K`0407]kN`1aLG40LG5a05eMG@80IfMW
00@0K6a/05YJFP1JFUX0BTY:0P1GEeL0101WIfL0Cdm?04m?C`1EEED204I6AP0405ADE00k>c/0>c/k
04U9B@80DE5A00@0FEUI06EUI@1UIFD0=CDe0P18B4P0100h>3P09bLW02LW9`0>3Ph20000000400/;
2`061PH01PH6018B4P8051@D00@06a/K02HV9P0V9RH05QHF0P0W9bL0100j>SX0<30`030`<00j>SX2
059BDP0404E5A@0j>SX0>SXj04Y:BP<0E5AD0P1:BTX01018B4P0De=C05=CD`1;Bd/204m?C`040820
P01LG5`0G5aL00T92@80;2`/00@0>CTi03hn?P0n?Sh0>CTi0P17AdL0101?Cdl0EEEE05EEE@1EEED2
04m?C`0305=CD`14A4@0A4A400<0EUIF0`1:BTX00`1?Cdl0E5AD05ADE00304i>CP0404Y:BP1@D500
D51@059BDP80DE5A00@0De=C04Y:BP1:BTX0Cdm?0P1=CDd01013@d<0Cdm?04m?C`1=CDd204A4A004
03hn?P1?Cdl0Cdm?055AD@80Bd];00@0ADE504A4A014A4@0EeMG0P29RHT0102n_[h0fMWI0=WIf@39
bLT20<C4a0040<W9b@3IfMT0fMWI08f=S@80=SHf00<05QHF00T92@092@T00`061PH010010@4030`<
00`<30061PH200L71`0000@0000000<30`030`<01@D50P010@4300@4100400<30`010@400@4100D5
1@<01`L70P0820P010092@T01@D500D51@061PH200@4100400D51@0410@010@400D51@8010@400@0
1@D500@4100410@01PH60P020P8300410@<0000000@01@D500H61P061PH02`/;0P010@4010020P80
1@D500D51@0410@200410@0400@410030`<00`<300<30`801`L700@01PH600D51@051@D00P820P09
2@T010061PH01@D500D51@010@4200@4100400H61P030`<00`<300<30`<01PH60`0410@200<30`04
00@410030`<00`<300<30`<00P820P030`<0100820P00`<300<30`010@4200H61P0400@410020P80
0P8200410@8010@400@01PH600D51@051@D01PH60P071`L00`061PH020P800P8200300T92@0401`L
700b<S80<S8b02LW9`8071`L00<0;Rh^03lo?`0o?cl00`14A4@0100l?3`0:RXZ02XZ:P0G5aL200`<
300400410@051@D01@D500l?3`804Q8B00@05aLG00T92@092@T07AdM0P0m?Cd0101FEUH0?Cdm03dm
?@0];Bd2030`<00401lO7`0^;Rh0;Rh^0451@@80@d=300@0F5QH05]KF`1KFe/0DE5A0P13@d<01019
BDT0GemO05mOG`1@D50204=3@`03055AD@1TI6@0I6AT00<0IfMW00@0O7al0820P020P800M7Ad0P1T
I6@0101dM7@0MWIf07IfMP1OGel206MWI`040820P029RHT0RHV90820P080HF5Q00@0M7Ad08f=S@2=
SHd0T92@0P2;Rh/01029RHT0Shn?08n?S`2<S8`208R8R00408b<S02@T900T92@08b<S080RHV900@0
MgMg07moO`1oOgl0P8200P1nOWh3092@T00406e]K@1PH600H61P07EeM@80Kfm_00@0JVYZ06][J`1[
Jf/0HF5Q0P1XJ6P0101VIVH0FUYJ05YJFP1?Cdl205=CD`<0IFEU00@0KFe]04e=C@1=CDd0GemO0P1W
IfL01018B4P0?3`l03`l?012@T8206IVIP0405ADE00n?Sh0?Shn038b<P80@41000@04a<C010@400@
41002`/;0P092@T0100K6a/03Ph>00h>3P00000200H61P0400L71`0L71`071`L03@d=080<c<c00@0
=cLg04U9B@19BDT0C4a<0P19BDT0101?Cdl0EEEE05EEE@1EEED2051@D00404];B`1@D500D51@04i>
CP80Bd];00@0MGEe07QhN01hN7P0<C4a0P0Q8B40100H61P08B4Q024Q8@13@d<205QHF00404E5A@1C
De<0De=C059BDP80B4Q800@0BDU904E5A@15ADD0DU9B0P1CDe<00`1:BTX0ADE504E5A@0304Q8B004
04A4A013@d<0@d=304a<C080DE5A00<0FEUI04];B`1;Bd/00`15ADD0101>CTh0ADE504E5A@12@T82
059BDP0404i>CP16ATH0ATI60492@P80CDe=00@0ADE504Q8B018B4P0A4A40P12@T80101@D500TY:B
09:BTP3<c<`20=3@d0040<30`03<c<`0c<c<0<c<c080c/k>00@0U9BD03lo?`0o?cl07AdM0P061PH0
100410@01@D500D51@030`<300H61P802@T90000100000000`<300<30`051@D200410@<010@400@0
0`<300410@010@401@D50`071`L200P8200400T92@051@D01@D500H61P8010@400@01@D500@41004
10@01@D50P0410@010051@D010@400@410061PH200820P<00@410`00000010051@D01PH600H61P0;
2`/200410@0400820P051@D01@D500@410800@4100@010@400<30`030`<00`<30P071`L010061PH0
1@D500D51@020P8200T92@0400H61P051@D01@D500410@8010@400@01PH600<30`030`<00`<30`06
1PH300@410800`<300@010@400<30`030`<00`<30`020P8200<30`0400P820030`<00`<300410@80
1PH600@010@400820P020P800@410P0410@010061PH01@D500D51@061PH200L71`0300H61P0820P0
20P800<02@T900@071`L038b<P0b<S809bLW0P0L71`00`0^;Rh0?clo03lo?`0304A4A00403`l?00Z
:RX0:RXZ01LG5`8030`<00@00@4100D51@051@D03`l?0P0B4Q80100G5aL02@T900T92@0M7Ad203dm
?@0405IFEP0m?Cd0?Cdm02d];@80<30`00@07alO02h^;P0^;Rh0@D510P13@d<0101HF5P0Fe]K05]K
F`1ADE4204=3@`0404U9B@1OGel0GemO051@D080@d=300<0DE5A06ATI01TI6@00`1WIfL0101lO7`0
P8200820P01dM7@206ATI00407AdM01fMWH0MWIf05mOG`80IfMW00@0P82008V9R@29RHT0P8200P1Q
HF40101dM7@0SHf=08f=S@2@T90208^;R`0408V9R@2?Shl0Shn?08b<S080R8R800@0S8b<092@T02@
T900S8b<0P29RHT0101gMgL0Ogmo07moO`20P80207inOP<0T92@00@0KFe]061PH01PH600MGEe0P1_
Kfl0101ZJVX0Jf][06][J`1QHF4206QXJ00406IVIP1JFUX0FUYJ04m?C`80De=C0`1UIFD0101]KFd0
CDe=04e=C@1OGel206MWI`0404Q8B00l?3`0?3`l0492@P80IVIV00@0E5AD03hn?P0n?Sh0<S8b0P10
@400100C4a<0410@010@400;2`/200T92@0401/K6`0>3Ph03Ph>000000801PH600@01`L701`L700L
71`0=3@d0P0c<c<0100g=cL0BDU904U9B@1<C4`204U9B@0404m?C`1EEED0EEEE05EEE@80D51@00@0
Bd];051@D01@D500CTi>0P1;Bd/0101eMGD0N7Qh07QhN00a<C42024Q8@0401PH600Q8B408B4Q04=3
@`80F5QH00@0ADE505=CD`1CDe<0DU9B0P18B4P01019BDT0ADE504E5A@1BDU8205=CD`0304Y:BP15
ADD0ADE500<0B4Q800@0A4A404=3@`13@d<0C4a<0P1ADE400`1IFET0Bd];04];B`0304E5A@0404i>
CP15ADD0ADE50492@P80DU9B00@0CTi>04I6AP16ATH0@T920P1=CDd01015ADD0B4Q804Q8B014A4@2
0492@P04051@D02BTY80TY:B0<c<c080d=3@00@0`<300<c<c03<c<`0c<c<0P3>c/h0102DU9@0?clo
03lo?`0M7Ad200H61P0400@410051@D01@D500<30`<01PH60P092@T0000400410@020P800P8200<3
0`80000000@010@400D51@051@D01@D50P020P80100000000`<300<30`051@D200410@0400@41006
1PH01PH600D51@8010@400@01PH600820P020P8020P80P0;2`/010020P8010@400@410061PH200@4
100300820P030`<00`<300<010@400@01@D500@4100410@01PH60P071`L010061PH010@400@41003
0`<20000000400H61P051@D01@D500H61P8010@400@00`<300D51@051@D000000P061PH010071`L0
20P800P8200410@200P8200400/;2`051@D01@D500410@8010@400@02@T900H61P061PH00P820`07
1`L300820P<010@40P030`<010051@D00`<300<30`020P8200<30`0400410@000000000000000080
10@400@00P8200000000000010@40P092@T300P8200400L71`0;2`/02`/;01DE5@809RHV00@0;Rh^
02TY:@0Y:BT0:BTY0P0g=cL01013@d<0@T920492@P0g=cL2028R8P0401DE5@0=3@d03@d=00X:2P80
3`l?00@06ATI01PH600H61P06ATI0P0?3`l0100_;bl0H61P061PH01ZJVX204=3@`0402DU9@0[:b/0
:b/[0410@080?clo00@0>CTi04A4A014A4@0FEUI0P15ADD01016ATH0Cdm?04m?C`1<C4`2069RHP04
05aLG01EEED0EEEE05=CD`80GEeM00@0IVIV06a/K01/K6`0OWin0P1jNWX0101gMgL0MWIf07IfMP1g
MgL2079bLP0408:2PP2;Rh/0Rh^;08f=S@80TI6A00@0QXJ6075aL@1aLG40Ogmo0P20P800101gMgL0
Rh^;08^;R`2ATI4208>3P`0408B4Q02:RXX0RXZ:09JFUP80U9BD00@0QhN708^;R`2;Rh/0T92@0P2F
UYH0102=SHd0OGem07emO@23Ph<208N7Q`0407QhN01mOGd0OGem09VIV@80SXj>00@0Kfm_06i^KP1^
KVh0J6QX0P1]KFd0101/K6`0EeMG05MGE`1CDe<205iNGP04061PH01=CDd0CDe=05YJFP80EeMG00@0
JFUY06YZJP1ZJVX0DU9B0P1CDe<0101BDU80De=C05=CD`1JFUX20410@00403@d=016ATH0ATI603/k
>`80<C4a00@0;Rh^020P800P82003@d=0P0410@0100?3`l02@T900T92@051@D200`<300402XZ:P0g
=cL0=cLg034a<@80<c<c00@0A4A4051@D01@D500Cdm?0`1DE5@204i>CP0404m?C`1BDU80DU9B04i>
CP80@41000@0HF5Q0861P@21PH40C4a<0P0P8200100G5aL0;Rh^02h^;P1^KVh206m_K`040492@P1B
DU80DU9B05iNGP80CTi>00@0@D5104U9B@19BDT0D51@0P18B4P01016ATH0@d=304=3@`11@D4203dm
?@0304=3@`1;Bd/0Bd];00<0E5AD00@0F5QH04M7A`17AdL0@D510P1;Bd/0101BDU80>c/k03/k>`0n
?Sh204Y:BP0404A4A018B4P0B4Q804I6AP80AdM700<0@d=304i>CP1>CTh00`10@400101IFET0V9RH
09RHV038b<P20<c<c0040<O7a`3Cdm<0dm?C0<S8b080alO700@0X:2P04U9B@19BDT071`L0P061PH0
10030`<00P8200820P0410@200820P401@D50@092@T100T92@000`030`<010071`L02@T900T92@03
0`<200@4100400H61P0410@010@400D51@<00`<30P0410@010071`L01@D500D51@020P8300D51@80
0`<310061PH200410@0400<30`0820P020P800820P801@D500@02@T900D51@051@D010@40P051@D0
10020P8020P800P8200820P2000000<010@400@01@D500H61P061PH010@40P00000010010@400P82
00820P020P8200P8200300@410020P800P8200@01`L70`0410@300P820800`<300@010@400X:2P0:
2PX02PX:0P020P8010030`<01PH600H61P051@D200H61P0400L71`051@D01@D500<30`800@4100<0
000000820P020P800`030`<0100410@00@4100410@010@4200@4100400D51@071`L01`L700P82080
2PX:00@071`L02PX:00X:2P0>3Ph0P0d=3@0100f=SH0?Cdm03dm?@10@40203<c<`0402LW9`0F5QH0
5QHF010@40803`l?00@051@D01TI6@0I6AT08B4Q0P0K6a/0100L71`05QHF01HF5P10@40207MgM`04
07YjNP15ADD0ADE501DE5@80;Rh^00@0Bd];0410@010@400?Cdm0P1<C4`0101QHF40C4a<04a<C013
@d<204e=C@0403Ti>@0f=SH0=SHf055AD@80IFEU00@0C4a<03/k>`0k>c/0CTi>0P1SHf<0101[Jf/0
LW9b079bLP1hN7P20861P@0408Z:RP1nOWh0OWin096AT@80PH6100@0KVi^07=cL`1cLg<0Ng]k0P1d
M7@0101^KVh0MgMg07MgM`1`L70208>3P`0408B4Q021PH40PH6109>CT`80UiNG00@0Vi^K09NGU`2G
UiL0PX:20P1dM7@0101oOgl0SXj>08j>SP2<S8`208^;R`0408V9R@1iNGT0NGUi07inOP80U9BD00@0
UiNG08^;R`2;Rh/0O7al0P1cLg<0101]KFd0L71`071`L01OGel204=3@`04055AD@1VIVH0IVIV06a/
K080CTi>00@0BDU9059BDP1BDU80G5aL0P1ADE40101?Cdl0EeMG05MGE`1>CTh3038b<P80?clo00@0
BTY:03Hf=P0f=SH0@4100P0_;bl01017AdL0@D510451@@0K6a/2014A4@0400/;2`0=3@d03@d=00X:
2P800P8200@06ATI02PX:00X:2P092@T0P0];Bd01013@d<0C4a<04a<C01;Bd/205MGE`0305=CD`18
B4P0B4Q800<0CDe=00@0BTY:0451@@11@D40E5AD0P1kNg/0101JFUX0;Bd]02d];@0f=SH205aLG004
08N7Q`1eMGD0MGEe05]KF`80GEeM00@0F5QH04A4A014A4@0@4100P18B4P0101=CDd0@T920492@P11
@D4204Y:BP0404U9B@10@400@41004U9B@80De=C00@0EeMG061PH01PH600G5aL0P14A4@01015ADD0
CDe=04e=C@1;Bd/20410@00404Q8B01=CDd0CDe=04=3@`<0BTY:0P14A4@01018B4P0DE5A055AD@0o
?cl20451@@0406m_K`2RXZ80XZ:R0<G5a@80bl_;0`37alL01030`<00b/[:0<[:bP2DU9@203Hf=P04
010@40092@T02@T900820P800`<300@010@400410@010@400P820P051@D000<00`<300@01`L700T9
2@092@T00`<30P0410@010061PH010@400@410051@D300<30`8010@400@01`L700D51@051@D00P82
0`051@D200<30`@01PH60P010@4010030`<020P800P820020P8200D51@0400T92@051@D01@D500@4
10801@D500@00P8200P8200820P020P80P00000300@4100400D51@061PH01PH600@41080000000@0
0@4100820P020P800P820P0820P00`0410@00P8200820P0400L71`<010@40`0820P200<30`0400@4
100:2PX02PX:00X:2P800P8200@00`<300H61P061PH01@D50P061PH010071`L01@D500D51@030`<2
00410@03000000020P800P8200<00`<300@010@400410@010@400@410P0410@010051@D01`L700L7
1`0820P200X:2P0401`L700X:2P0:2PX03Ph>080=3@d00@0=SHf03dm?@0m?Cd0@4100P0c<c<0100W
9bL05QHF01HF5P0@410200l?3`0401@D500I6AT06ATI024Q8@806a/K00@071`L01HF5P0F5QH0@410
0P1gMgL0101jNWX0ADE504E5A@0E5AD202h^;P0404];B`10@400@41003dm?@80C4a<00@0HF5Q04a<
C01<C4`0@d=30P1=CDd0100i>CT0=SHf03Hf=P1ADE4206EUI@0404a<C00k>c/0>c/k04i>CP80Hf=S
00@0Jf][079bLP1bLW80N7Qh0P21PH40102:RXX0OWin07inOP2ATI420861P@0406i^KP1cLg<0Lg=c
07]kN`80M7Ad00@0KVi^07MgM`1gMgL0L71`0P23Ph<01024Q8@0PH610861P@2CTi<209NGU`0409^K
V`2GUiL0UiNG08:2PP80M7Ad00@0Ogmo08j>SP2>SXh0S8b<0P2;Rh/01029RHT0NGUi07UiN@1nOWh2
09BDU00409NGU`2;Rh/0Rh^;07alO080Lg=c00@0KFe]071`L01`L700GemO0P13@d<0101ADE40IVIV
06IVIP1/K6`204i>CP0404U9B@1BDU80DU9B05aLG080DE5A00@0Cdm?05MGE`1GEeL0CTi>0`0b<S82
03lo?`0404Y:BP0f=SH0=SHf0410@080;bl_00@0AdM70451@@11@D406a/K0P0A4A40100;2`/03@d=
00d=3@0:2PX200820P0401TI6@0X:2P0:2PX02@T9080;Bd]00@0@d=304a<C01<C4`0Bd];0P1GEeL0
0`1CDe<0B4Q804Q8B00304e=C@0404Y:BP11@D40@D5105ADE080Ng]k00@0FUYJ02d];@0];Bd0=SHf
0P1LG5`01027QhL0MGEe07EeM@1KFe/205eMG@0405QHF014A4@0A4A40410@080B4Q800@0CDe=0492
@P12@T80@D510P1:BTX01019BDT0@4100410@019BDT205=CD`0405MGE`1PH600H61P05aLG080A4A4
00@0ADE504e=C@1=CDd0Bd];0P10@4001018B4P0CDe=04e=C@13@d<304Y:BP80A4A400@0B4Q8055A
D@1ADE40?clo0P11@D40101_Kfl0XZ:R0::RXP35aLD20<_;b`<0alO700@0`<300<[:bP3:b/X0U9BD
0P0f=SH0100@41002@T900T92@020P8200<30`0400@410010@400@4100820P801@D5000010030`<0
20P800P820030`<200d=3@030000000410@010@400<00`<300@020P800H61P061PH01@D50`071`L2
00410@0400820P061PH01PH600P820800@4100@0000000410@010@4010@40P071`L00`092@T010@4
00@4100300@4100400H61P0410@010@400D51@800@4100@0000000D51@051@D01@D50P0410@00`07
1`L01PH600H61P0300410@0400@410071`L01`L700<30`8010@40`061PH010051@D00`<300<30`05
1@D300820P800@4100@00P8200X:2P0:2PX01@D50P061PH010071`L00`<300<30`0<30`200/;2`04
00@410020P800P8200@410801`L700@020P800T92@092@T00`<30P00000010061PH02PX:00X:2P06
1PH200<30`<020P80`0000000`030`<02@T900T92@03018B4P0401lO7`0^;Rh0;Rh^03`l?080<S8b
00@0?Shn0410@010@400=SHf0P0N7Qh0100G5aL03Ph>00h>3P0H61P202DU9@0402LW9`0Y:BT0:BTY
02`/;080:2PX00@09BDU01hN7P0N7Qh0<c<c0P18B4P0100l?3`08B4Q024Q8@0>3Ph202@T900403`l
?01EEED0EEEE05UIF@80C4a<00@0DU9B04Y:BP1:BTX0=cLg0`0m?Cd203Xj>P04059BDP1YJFT0JFUY
06MWI`80De=C00@0@410059BDP1BDU80IVIV0P1dM7@0101hN7P0OGem07emO@2;Rh/208F5Q@0408>3
P`20P800P82007=cL`80LG5a0`1gMgL0101WIfL0Ti>C09>CT`2JVYX208f=S@040820P01iNGT0NGUi
08j>SP80X:2P00@0XJ6Q09RHV02HV9P0Shn?0P1kNg/0101fMWH0Kfm_06m_K`1hN7P209NGU`0409JF
UP25QHD0QHF508b<S080R8R800@0LG5a07MgM`1gMgL0P8200P1PH600101LG5`0NWYj07YjNP1NGUh2
0451@@0405YJFP1HF5P0F5QH05YJFP80GUiN00@0HV9R04a<C01<C4`0DE5A0P13@d<0100a<C40@T92
0492@P1CDe<204M7A`040451@@1:BTX0BTY:055AD@80<C4a00@0:BTY01@D500D51@0;Rh^0P0d=3@0
100Y:BT0@4100410@00`<30201HF5P0400<30`051@D01@D5014A4@805ADE00@061PH02`/;00/;2`0
@4100P1;Bd/0101?Cdl0D51@051@D01=CDd204a<C00404i>CP16ATH0ATI604M7A`80B4Q800@0DU9B
07=cL`1cLg<0FEUI0P0_;bl01010@400JVYZ06YZJP26QXH207moO`04071`L01QHF40HF5Q04m?C`80
ADE50`1?Cdl0101;Bd/0@d=304=3@`10@40204Y:BP<0Bd];00@0DU9B05=CD`1CDe<0E5AD0P1NGUh0
101MGEd0ATI604I6AP1>CTh205=CD`0404];B`1>CTh0CTi>04m?C`80DU9B00@0C4a<04e=C@1=CDd0
CTi>0P16ATH0101:BTX0B4Q804Q8B014A4@204Y:BP0406][J`2VYZH0YZJV0<[:bP80`L7100@0_kno
0<S8b038b<P0c<c<0P3=cLd0101hN7P09RHV02HV9P0>3Ph200`<300400H61P071`L01`L700T92@80
0`<30@010@4100<30`400`<30000100410@020P800P820030`<200@410<020P800<010@400820P02
0P8010061PH200@4100400H61P010@400@4100D51@800P8200@020P800000000000000000P0:2PX0
10010@402@T900T92@0;2`/200L71`0300@410020P800P8200<00`<300@00P820000000000000@41
0P071`L0100410@01`L700L71`061PH300D51@800@4100@00`<300X:2P0:2PX01@D51@020P800`05
1@D01`L700L71`0300@410<00@4100@0000000<30`030`<01`L70P051@D010030`<01PH600H61P09
2@T200X:2P0400D51@020P800P8200H61P802PX:00@01@D500820P020P8010@40P061PH0100820P0
1@D500D51@0820P200/;2`0300P820071`L01`L700@01@D50P0<30`0100D51@0:RXZ02XZ:P0W9bL2
02`/;003030`<00];Bd0;Bd]00<0@41000@0;Bd]01<C4`0C4a<03Ph>0P0;2`/00`0K6a/0<30`030`
<003030`<00402l_;`0[:b/0:b/[02`/;080:RXZ00@05ADE00X:2P0:2PX020P80P071`L0100D51@0
:BTY02TY:@0m?Cd2069RHP0406QXJ01;Bd/0Bd];03lo?`80=cLg00@0;2`/03Xj>P0j>SX0BTY:0P1C
De<0101UIFD0LG5a075aL@1gMgL206YZJP04059BDP1JFUX0FUYJ065QH@80Kfm_00@0PH6108B4Q024
Q8@0OWin0P24Q8@0102<S8`0SXj>08j>SP20P8020861P@0407emO@24Q8@0Q8B408B4Q080VYZJ00@0
TY:B08^;R`2;Rh/0S8b<0P1nOWh0102;Rh/0X:2P0:2PX02IVIT207alO0040820P02EUID0UIFE09VI
V@80MgMg00@0Lg=c08f=S@2=SHd0QXJ60P24Q8@0102<S8`0QhN708N7Q`20P80207QhN004075aL@1F
EUH0EUIF04m?C`80M7Ad00@0HV9R04=3@`13@d<0IFEU0P1TI6@0101DE5@0GEeM05eMG@1TI6@204E5
A@0404Q8B016ATH0ATI603Xj>P80Cdm?00@0FUYJ05QHF01HF5P0EEEE0P1;Bd/0100_;bl09bLW02LW
9`0b<S8202/[:`0403De=@0X:2P0:2PX03@d=080De=C00@0CTi>03Lg=`0g=cL092@T0P0C4a<0100=
3@d02PX:00X:2P0B4Q8202TY:@0303/k>`12@T80@T9200<0Bd];00@0BTY:04];B`1;Bd/0CTi>0P1=
CDd0101;Bd/0ADE504E5A@1=CDd206m_K`0405EEE@0b<S80<S8b04];B`80JVYZ00@0PH610820P020
P800KFe]0P1RHV80101KFe/0CTi>04i>CP1=CDd204i>CP0404E5A@0o?cl0?clo0492@P80CDe=00@0
AdM704e=C@1=CDd0E5AD0P1EEED0101IFET0EEEE05EEE@1HF5P204e=C@04059BDP1HF5P0F5QH05AD
E080Bd];00@0C4a<051@D01@D500C4a<0P1;Bd/0101>CTh0@4100410@016ATH204M7A`0404I6AP1=
CDd0CDe=07AdM080/K6a00@0b<S80;jn_P2n_[h0`<300P37alL0103:b/X0`<300<30`01QHF4201hN
7P0400h>3P0410@010@400T92@8010@400<02@T900H61P061PH00`0410@0000400@4100820P020P8
00<30`8010@40`0820P00`0410@00P8200820P0400H61P8010@400@01PH600410@010@401@D50P02
0P80100820P0000000000000000200X:2P0400410@092@T02@T900/;2`801`L700<010@400820P02
0P800`030`<010020P800000000000010@4200L71`0400@410071`L01`L700H61P<01@D50P010@40
10030`<02PX:00X:2P051@D500820P0300D51@071`L01`L700<010@40`010@40100000000`<300<3
0`071`L200D51@0400<30`061PH01PH600T92@802PX:00@01@D500820P020P801PH60P0:2PX01005
1@D00P8200820P0410@200H61P0400P820051@D01@D500P820802`/;00<020P800L71`071`L01005
1@D200`<300401@D500Z:RX0:RXZ02LW9`80;2`/00<0<30`02d];@0];Bd00`10@400100];Bd04a<C
01<C4`0>3Ph200/;2`0301/K6`0`<300<30`00<0<30`00@0;bl_02/[:`0[:b/0;2`/0P0Z:RX0100E
5AD02PX:00X:2P0820P200L71`0401@D500Y:BT0:BTY03dm?@80HV9R00@0J6QX04];B`1;Bd/0?clo
0P0g=cL0100/;2`0>SXj03Xj>P1:BTX205=CD`0406EUI@1aLG40LG5a07MgM`80JVYZ00@0DU9B05YJ
FP1JFUX0HF5Q0P1_Kfl01021PH40Q8B408B4Q01nOWh208B4Q00408b<S02>SXh0SXj>0820P080PH61
00@0OGem08B4Q024Q8@0Q8B40P2JVYX0102BTY80Rh^;08^;R`2<S8`207inOP0408^;R`2PX:00X:2P
09VIV@80O7al00@0P82009FEU@2EUID0VIVI0P1gMgL0101cLg<0SHf=08f=S@26QXH208B4Q00408b<
S027QhL0QhN70820P080N7Qh00@0LG5a05IFEP1FEUH0Cdm?0P1dM7@0101RHV80@d=304=3@`1UIFD2
06ATI00405ADE01MGEd0GEeM06ATI080ADE500@0B4Q804I6AP16ATH0>SXj0P1?Cdl0101JFUX0F5QH
05QHF01EEED204];B`0402l_;`0W9bL09bLW038b<P80:b/[00@0=CDe02PX:00X:2P0=3@d0P1CDe<0
101>CTh0=cLg03Lg=`0T92@201<C4`0400d=3@0:2PX02PX:018B4P80:BTY00<0>c/k0492@P12@T80
0`1;Bd/0101:BTX0Bd];04];B`1>CTh204e=C@0404];B`15ADD0ADE504e=C@80Kfm_00@0EEEE038b
<P0b<S80Bd];0P1ZJVX01021PH40P8200820P01]KFd2069RHP0405]KF`1>CTh0CTi>04e=C@80CTi>
00@0ADE503lo?`0o?cl0@T920P1=CDd01017AdL0CDe=04e=C@1DE5@205EEE@0405UIF@1EEED0EEEE
05QHF080CDe=00@0DU9B05QHF01HF5P0E5AD0P1;Bd/0101<C4`0D51@051@D01<C4`204];B`0404i>
CP10@400@41004I6AP80AdM700@0ATI604e=C@1=CDd0M7Ad0P2a/K401038b<P0_[jn0;jn_P30`<02
0<O7a`040<[:bP30`<00`<30065QH@807QhN00@03Ph>00@4100410@02@T90P0410@00`092@T01PH6
00H61P0300@4100000@010@400<30`030`<01`L70P0410@0100:2PX01`L700L71`061PH200P82004
00<30`0820P020P800H61P801`L700@010@400<30`030`<01PH60P030`<010051@D00P8200820P02
0P8200P8200400<30`020P800P8200D51@801PH600@020P800820P020P801@D50P030`<010000000
0P8200820P020P8200H61P0400@410030`<00`<300D51@800`<300@010@400410@010@400@410P05
1@D010030`<00@4100410@020P820000000400D51@071`L01`L700L71`801@D500@00`<300D51@05
1@D010@40P0820P010071`L00`<300<30`010@4200P8200300D51@020P800P8200<02@T900<01`L7
00H61P061PH00`0410@010030`<01PH600H61P061PH20000000400H61P071`L01`L700<30`800000
00@00`<300L71`071`L01PH60P092@T0100B4Q80<S8b038b<P0];Bd202h^;P0402PX:00a<C40<C4a
04Q8B080?Cdm00@0:2PX010@400@41001`L70P0>3Ph0100B4Q80820P020P800W9bL202h^;P0402HV
9P0S8b<08b<S02PX:0805ADE00@0410@02XZ:P0Z:RX0ADE50P0e=CD0100];Bd0<S8b038b<P0a<C42
04I6AP0404Y:BP10@400@41004A4A080@T9200@0@41004I6AP16ATH0@4100P12@T80101GEeL0H61P
061PH01FEUH203dm?@04055AD@1NGUh0GUiN04A4A080EUIF00<0Kfm_07emO@1mOGd00`28R8P0101m
OGd0MgMg07MgM`1`L70207YjNP0407=cL`1bLW80LW9b07MgM`80Ng]k00@0MgMg0820P020P800P820
0P25QHD0102JVYX0WIfM09fMW@2DU9@208B4Q00408J6QP2CTi<0Ti>C08n?S`80Ng]k00@0P820096A
T@2ATI40PH610P20P800102=SHd0RXZ:08Z:RP25QHD207]kN`0407=cL`1XJ6P0J6QX05eMG@80K6a/
00@0HF5Q04U9B@19BDT0HF5Q0P1WIfL0101ADE40HV9R069RHP1PH60204U9B@0405]KF`1ZJVX0JVYZ
05]KF`80G5aL00@0C4a<04e=C@1=CDd0BTY:0P1>CTh01010@400=cLg03Lg=`1EEED205QHF0040492
@P0P8200820P0410@080GUiN00@0@T9204=3@`13@d<0ADE50P0O7al0100G5aL02@T900T92@092@T2
02PX:00403Ph>00i>CT0>CTi04Y:BP80EUIF00@0D51@0451@@11@D40@d=30`1;Bd/20451@@04051@
D01/K6`0K6a/05ADE080?clo00@0E5AD06i^KP1^KVh0O7al0P1bLW80101[Jf/0IfMW06MWI`1PH602
04Y:BP0404U9B@1BDU80DU9B04Q8B080ADE500@0AdM704U9B@19BDT0?Shn0P14A4@0101EEED0GUiN
05iNGP1FEUH204Y:BP0404m?C`1@D500D51@04i>CP80C4a<00@0CTi>04I6AP16ATH0EeMG0P1HF5P0
101:BTX0AdM704M7A`1>CTh203lo?`0404M7A`1>CTh0CTi>04Y:BP80D51@00@0NWYj0:b/[02/[:`0
a/K60P30`<001034a<@0`L710<71`@2n_[h20:^[Z`04051@D00N7Qh07QhN00h>3P800P8200@01@D5
00000000000010@40P061PH100L71`400P820@020P80000400T92@0820P020P800L71`800P821006
1PH200@410<01PH600@00@4100D51@051@D00@410P061PH00`0820P00P8200820P0300<30`0400T9
2@030`<00`<300<30`8010@400@00P8200@4100410@01PH60P092@T010061PH01`L700L71`0410@2
00/;2`0400P820061PH01PH600<30`801PH600@020P800H61P061PH020P80P030`<300H61P040041
0@030`<00`<300T92@D01@D500@010@400820P020P8010@40P030`<010051@D03@d=00d=3@0<30`2
00H61P0300<30`061PH01PH600<01PH600@01`L700H61P061PH01@D50P0410@300D51@0400<30`04
10@010@400H61P8010@410030`<300410@801PH600@010@400l?3`0?3`l07QhN0P0Y:BT0100_;bl0
=SHf03Hf=P0a<C4203Hf=P0404A4A00h>3P0>3Ph020P808030`<00@01@D501<C4`0C4a<02`/;0P0A
4A40100S8b<092@T02@T900I6AT202@T900400l?3`0820P020P803lo?`80O7al00@0Ti>C06ATI01T
I6@0@4100P0];Bd0100T92@0Bd];04];B`1BDU8203Hf=P0402l_;`19BDT0BDU906=SH`80FUYJ00@0
Cdm?04e=C@1=CDd0ATI60P1=CDd0101@D500?3`l03`l?01PH60207QhN00405=CD`1@D500D51@04I6
AP80F5QH00@0Rh^;08n?S`2?Shl0NWYj0P24Q8@01022PX80P8200820P01fMWH2079bLP0407EeM@29
RHT0RHV908V9R@80P82000@0L71`07moO`1oOgl0UiNG0`2BTY8209RHV004096AT@2@T900T92@096A
T@80R8R800<0S8b<09JFUP2FUYH00`2>SXh00`2MWId0U9BD09BDU00307EeM@0407alO01RHV80HV9R
061PH080JVYZ00@0FEUI05MGE`1GEeL0H61P0P1LG5`0101GEeL0Kfm_06m_K`1WIfL204e=C@0405]K
F`1OGel0GemO04M7A`<0Cdm?0P1UIFD0101;Bd/0Cdm?04m?C`1WIfL205MGE`0406e]K@1FEUH0EUIF
03hn?P807alO00@09bLW04E5A@15ADD0:RXZ0P0R8R80100U9BD06ATI01TI6@0D51@200/;2`0400`<
300R8R808R8R03@d=080>SXj00@0AdM7055AD@1ADE40C4a<0P11@D401013@d<0ATI604I6AP15ADD2
0410@00404i>CP1OGel0GemO051@D080@T9200@0Bd];06YZJP1ZJVX0MgMg0P1/K6`0101WIfL0IVIV
06IVIP1LG5`204A4A00404I6AP1BDU80DU9B04a<C080De=C00@0D51@04=3@`13@d<0>SXj0P16ATH0
101HF5P0GEeM05eMG@1>CTh204Y:BP04051@D01ADE40DE5A04e=C@80A4A40`18B4P0101CDe<0E5AD
05ADE01:BTX204I6AP0404Q8B013@d<0@d=304e=C@80BTY:00@0AdM704e=C@1=CDd0MGEe0P2YZJT0
103?cll0aLG50<G5a@36a/H30<O7a`80V9RH00@0?Shn01lO7`0O7al03`l?0P000000100410@01`L7
00L71`061PH200T92@401@D50@020P8100820P0000@02@T900P8200820P01`L70P020P8400H61P80
10@40`061PH010010@401@D500D51@010@4200H61P0300P820020P800P8200<00`<300@02@T900<3
0`030`<00`<30P0410@010020P8010@400@410061PH200T92@0400H61P071`L01`L700@410802`/;
00@020P800H61P061PH00`<30P061PH0100820P01PH600H61P0820P200<30`<01PH600@00@4100<3
0`030`<02@T91@051@D0100410@00P8200820P0410@200<30`0400D51@0=3@d03@d=00`<30801PH6
00<00`<300H61P061PH00`061PH010071`L01PH600H61P051@D200@410<01@D500@00`<300@41004
10@01PH60P0410@400<30`<00@410P061PH0100410@03`l?00l?3`0N7Qh202TY:@0402l_;`0f=SH0
=SHf034a<@80=SHf00@0A4A403Ph>00h>3P0820P0P0<30`010051@D04a<C01<C4`0;2`/2014A4@04
02<S8`0T92@092@T01TI6@8092@T00@03`l?00P8200820P0?clo0P1lO7`0102CTi<0I6AT06ATI010
@40202d];@0402@T901;Bd/0Bd];059BDP80=SHf00@0;bl_04U9B@19BDT0Hf=S0P1JFUX0101?Cdl0
CDe=04e=C@16ATH204e=C@04051@D00l?3`0?3`l061PH080N7Qh00@0De=C051@D01@D500ATI60P1H
F5P0102;Rh/0Shn?08n?S`1jNWX208B4Q00408:2PP20P800P82007IfMP80LW9b00@0MGEe08V9R@29
RHT0RHV90P20P800101`L700Ogmo07moO`2GUiL309:BTP80V9RH00@0TI6A092@T02@T900TI6A0P28
R8P00`2<S8`0UYJF09JFUP0308j>SP0309fMW@2DU9@0U9BD00<0MGEe00@0O7al069RHP1RHV80H61P
0P1ZJVX0101IFET0EeMG05MGE`1PH60205aLG00405MGE`1_Kfl0Kfm_06MWI`80CDe=00@0Fe]K05mO
G`1OGel0AdM70`1?Cdl206EUI@0404];B`1?Cdl0Cdm?06MWI`80EeMG00@0KFe]05IFEP1FEUH0?Shn
0P0O7al0100W9bL0ADE504E5A@0Z:RX2028R8P0402DU9@0I6AT06ATI01@D50802`/;00@030`<028R
8P0R8R80=3@d0P0j>SX01017AdL0DE5A055AD@1<C4`20451@@0404=3@`16ATH0ATI604E5A@80@410
00@0CTi>05mOG`1OGel0D51@0P12@T80101;Bd/0JVYZ06YZJP1gMgL206a/K00406MWI`1VIVH0IVIV
05aLG080A4A400@0ATI6059BDP1BDU80C4a<0P1CDe<0101@D500@d=304=3@`0j>SX204I6AP0405QH
F01MGEd0GEeM04i>CP80BTY:00@0D51@055AD@1ADE40CDe=0P14A4@304Q8B00405=CD`1DE5@0E5AD
04Y:BP80ATI600@0B4Q804=3@`13@d<0CDe=0P1:BTX01017AdL0CDe=04e=C@1eMGD20:VYZ@040<o?
c`35aLD0aLG50<K6aP<0alO70P2HV9P0100n?Sh07alO01lO7`0?3`l20000000400@410071`L01`L7
00H61P802@T90@051@D100820P400P820000100<30`01PH600H61P0410@20000000400H61P030`<0
0`<300820P8010@400@020P800D51@051@D010@40P020P8300L71`0400H61P051@D01@D500@41080
000000@03Ph>00H61P061PH00P820P061PH010030`<01@D500D51@00000200T92@0400820P0410@0
10@400T92@<02PX:0P071`L010030`<010@400@4100410@200X:2P0400T92@030`<00`<300L71`80
10@400@00P8200@4100410@01@D50P071`L010020P800@4100410@061PH200D51@0400820P010@40
0@4100D51@802PX:00@030`<00@4100410@00`<30P071`L300<30`0300@410030`<00`<300<01@D5
0`071`L0100410@00`<300<30`030`<200P8200400H61P010@400@4100410@801PH600@020P800D5
1@051@D01`L70P0F5QH0100[:b/0:RXZ02XZ:P0c<c<203lo?`0403dm?@0d=3@0=3@d03<c<`80;Rh^
00@071`L00`<300<30`00P820P0<30`0100>3Ph05QHF01HF5P0O7al2024Q8@0401XJ6P0>3Ph03Ph>
00`<3080=CDe00@0O7al0::RXP2RXZ80TY:B0P1JFUX0100`<3009BDU02DU9@0[:b/204M7A`0405EE
E@0n?Sh0?Shn02/[:`80@T9200@0EEEE059BDP1BDU80HF5Q0P1IFET0100h>3P0CTi>04i>CP1/K6`2
05YJFP0406MWI`1lO7`0O7al06YZJP80H61P00@0De=C05YJFP1JFUX0QXJ60P2>SXh0101hN7P0S8b<
08b<S024Q8@207]kN`0407emO@29RHT0RHV908j>SP80VYZJ0`2?Shl01026QXH0OWin07inOP26QXH2
07moO`0408^;R`2MWId0WIfM09^KV`80VYZJ00@0VIVI09BDU02DU9@0UYJF0P2ATI401027QhL0Ogmo
07moO`26QXH209>CT`040861P@1mOGd0OGem0861P@80Jf][00@0JVYZ06EUI@1UIFD0CTi>0P1NGUh0
101QHF40G5aL05aLG01OGel206e]K@0407moO`1]KFd0KFe]05MGE`80Fe]K00@0D51@05QHF01HF5P0
G5aL0P1SHf<0101HF5P0EEEE05EEE@1IFET204m?C`0405MGE`0d=3@0=3@d02l_;`80=cLg00@0:RXZ
034a<@0a<C40<c<c0P10@400100_;bl051@D01@D500A4A4201<C4`04010@400F5QH05QHF02@T9080
<30`00@0ATI604];B`1;Bd/0ADE50`13@d<204U9B@0404a<C013@d<0@d=304U9B@80FEUI00@0DU9B
04Y:BP1:BTX0EEEE0P1YJFT0101aLG40J6QX06QXJ01NGUh206=SH`04069RHP1;Bd/0Bd];04M7A`80
BTY:00@0ADE504U9B@19BDT0CDe=0P16ATH01013@d<0EEEE05EEE@1GEeL204e=C@0404U9B@1EEED0
EEEE05EEE@80E5AD00<0DU9B04U9B@19BDT00`19BDT404a<C080AdM700@0?clo03hn?P0n?Sh0C4a<
0P14A4@0100h>3P0Bd];04];B`20P8020;:b/P040=7Ad@3:b/X0b/[:0<O7a`80_kno00@0`/;208B4
Q024Q8@0=CDe0P0P8200100:2PX01@D500D51@051@D200h>3P0400/;2`061PH01PH6000000800@41
0000100410@01PH600H61P0410@200820P0400<30`000000000000D51@800`<300@010@400D51@05
1@D02@T90P030`<0100410@01@D500D51@020P8200T92@0400P820030`<00`<300X:2P801PH60`03
0`<0100820P01@D500D51@071`L200820P0400L71`061PH01PH600D51@800@4100@010@400820P02
0P800P820P00000010020P802@T900T92@092@T200D51@0400@410020P800P8200@410<00P820P08
20P300410@0400P820061PH01PH600<30`801PH600@02@T900D51@051@D01`L70P092@T00`0410@0
1PH600H61P0300D51@0400H61P020P800P8200@410800P8200<010@400L71`071`L010030`<200D5
1@0400H61P0820P020P800L71`801PH600@02`/;00820P020P803`l?0P0Q8B40100Y:BT0;bl_02l_
;`0j>SX20410@00403Ti>@0g=cL0=cLg03/k>`80;Rh^00@06QXJ00/;2`0;2`/00@410P061PH0100=
3@d04a<C01<C4`0B4Q8202HV9P0401DE5@0410@010@402d];@80FUYJ00@0UYJF0:n_[`2_[jl0PX:2
0P1CDe<0100/;2`0820P020P800`<30203`l?0040410@00f=SH0=SHf03Hf=P80@D510`10@400101F
EUH0GUiN05iNGP16ATH2059BDP04069RHP1KFe/0Fe]K05UIF@80EUIF00@0HV9R07inOP1nOWh0OGem
0P1VIVH0101_Kfl0QHF508F5Q@1gMgL208>3P`040861P@1kNg/0Ng]k08>3P`80R8R800@0Ogmo09>C
T`2CTi<0UYJF0P2GUiL0102<S8`0Q8B408B4Q02>SXh208>3P`0409NGU`2NWYh0WYjN09^KV`80YJFU
00@0X:2P09:BTP2BTY80SXj>0P2BTY80102<S8`0Ph>308>3P`29RHT20861P@0407QhN01jNWX0NWYj
07YjNP80Ogmo00@0LW9b05UIF@1IFET0FEUI0P1]KFd0101TI6@0HV9R069RHP1XJ6P2065QH@0407em
O@1]KFd0KFe]05aLG080J6QX00@0GemO05]KF`1KFe/0CDe=0P11@D40101XJ6P0IfMW06MWI`18B4P2
04=3@`0404];B`0m?Cd0?Cdm03<c<`80>c/k00@0=CDe04U9B@19BDT0GUiN0P1_Kfl0101BDU809RHV
02HV9P0N7Qh202@T900402<S8`0@4100410@00/;2`809BDU00@0@d=304m?C`1?Cdl0AdM70P0o?cl0
1014A4@0CDe=04e=C@17AdL203dm?@0404];B`1MGEd0GEeM05EEE@80CTi>00@0EeMG06EUI@1UIFD0
J6QX0P1TI6@0101OGel0H61P061PH01RHV8205IFEP0404a<C01;Bd/0Bd];04i>CP80@D5100@0@410
04=3@`13@d<0Bd];0P1MGEd0101IFET0Bd];04];B`1>CTh205QHF004055AD@1;Bd/0Bd];04a<C080
CTi>00@0CDe=04m?C`1?Cdl0DU9B0P1?Cdl0101:BTX0@d=304=3@`0m?Cd203hn?P0404U9B@15ADD0
ADE503Xj>P80De=C00@0QHF50;>c/`2c/k<0alO70P34a<@0103?cll0a<C40<C4a02g]kL20861P@04
04m?C`0X:2P0:2PX00<30`80410@00@00`<300H61P061PH02`/;0P061PH100<30`4010@40@0410@0
000400@410061PH01PH600@410800P8200@00`<30000000000001@D50P030`<0100410@01@D500D5
1@092@T200<30`0400@410051@D01@D500820P802@T900@020P800<30`030`<02PX:0P061PH300<3
0`0400P820051@D01@D500L71`800P8200@01`L700H61P061PH01@D50P010@40100410@00P820082
0P020P820000000400820P092@T02@T900T92@801@D500@010@400820P020P8010@40`020P8200P8
20<00@4100@020P800H61P061PH00`<30P061PH010092@T01@D500D51@071`L200T92@0300@41006
1PH01PH600<01@D500@01PH600820P020P8010@40P020P800`0410@01`L700L71`0400<30`801@D5
00@01PH600P8200820P01`L70P061PH0100;2`/00P8200820P0?3`l2024Q8@0402TY:@0_;bl0;bl_
03Xj>P80@41000@0>CTi03Lg=`0g=cL0>c/k0P0^;Rh0100J6QX02`/;00/;2`010@4200H61P0400d=
3@0C4a<04a<C018B4P809RHV00@05ADE00@4100410@0;Bd]0P1JFUX0102FUYH0[jn_0:n_[`22PX82
05=CD`0402`/;00P8200820P030`<080?3`l00@0@41003Hf=P0f=SH0=SHf0P11@D430410@00405IF
EP1NGUh0GUiN04I6AP80DU9B00@0HV9R05]KF`1KFe/0FEUI0P1FEUH0101RHV80OWin07inOP1mOGd2
06IVIP0406m_K`25QHD0QHF507MgM`80Ph>300@0PH6107]kN`1kNg/0Ph>30P28R8P0101oOgl0Ti>C
09>CT`2FUYH209NGU`0408b<S024Q8@0Q8B408j>SP80Ph>300@0UiNG09jNWP2NWYh0Vi^K0P2UYJD0
102PX:00TY:B09:BTP2>SXh209:BTP0408b<S023Ph<0Ph>308V9R@80PH6100@0N7Qh07YjNP1jNWX0
NWYj0P1oOgl0101bLW80FEUI05UIF@1IFET206e]K@0406ATI01RHV80HV9R06QXJ080HF5Q00@0OGem
06e]K@1]KFd0G5aL0P1XJ6P0101OGel0Fe]K05]KF`1=CDd20451@@0406QXJ01WIfL0IfMW04Q8B080
@d=300@0Bd];03dm?@0m?Cd0<c<c0P0k>c/0100e=CD0BDU904U9B@1NGUh206m_K`04059BDP0V9RH0
9RHV01hN7P8092@T00@08b<S010@400@41002`/;0P0U9BD01013@d<0Cdm?04m?C`17AdL203lo?`04
04A4A01=CDd0CDe=04M7A`80?Cdm00@0Bd];05eMG@1MGEd0EEEE0P1>CTh0101GEeL0IFEU06EUI@1X
J6P206ATI00405mOG`1PH600H61P069RHP80EUIF00@0C4a<04];B`1;Bd/0CTi>0P11@D401010@400
@d=304=3@`1;Bd/205eMG@0405UIF@1;Bd/0Bd];04i>CP80F5QH00@0DE5A04];B`1;Bd/0C4a<0P1>
CTh0101=CDd0Cdm?04m?C`1BDU8204m?C`0404Y:BP13@d<0@d=303dm?@80?Shn00@0BDU904E5A@15
ADD0>SXj0P1CDe<01025QHD0/k>c0;>c/`37alL20<C4a0040<o?c`34a<@0a<C40;Ng]`80PH6100@0
Cdm?02PX:00X:2P00`<30P0@410010030`<01PH600H61P0;2`/200H61P400`<30@0410@100@41000
00@010@400d=3@0=3@d01`L70P051@D010030`<010@400@4100410@200410@0400@410061PH01PH6
00D51@800`<300@0000000P8200820P01PH60P0820P010071`L00`<300<30`030`<300D51@800`<3
00@01PH600L71`071`L020P80P030`<00`0:2PX01PH600H61P0300820P0400<30`061PH01PH600@4
10800`<30`051@D010061PH00`<300<30`030`<200820P0400410@020P800P8200820P8010@40`05
1@D300<30`0400H61P0820P020P800/;2`<00`<30P092@T010030`<010@400@410061PH200D51@04
00L71`051@D01@D500410@800P8200@01@D500410@010@4000000P030`<300@4100400H61P0:2PX0
2PX:00L71`<01PH60P0410@0100>3Ph07AdM01dM7@0Q8B4203<c<`0403Hf=P0h>3P0>3Ph03Lg=`80
>CTi00@0@d=302h^;P0^;Rh05aLG0P061PH010010@403@d=00d=3@0@4102018B4P04014A4@0N7Qh0
7QhN00l?3`80820P00@0D51@07UiN@1iNGT0WYjN0P2/[:`0102;Rh/0IfMW06MWI`0n?Sh202@T9004
02LW9`0h>3P0>3Ph03dm?@80<c<c00@0>3Ph04a<C01<C4`0C4a<0P0k>c/01018B4P0Hf=S06=SH`1S
Hf<205ADE00404=3@`1EEED0EEEE06e]K@80K6a/00@0JFUY07IfMP1fMWH0P8200P1/K6`01015ADD0
L71`071`L029RHT208B4Q00308R8R01mOGd0OGem00<0Ogmo00@0JVYZ075aL@1aLG40OWin0P22PX80
1023Ph<0Shn?08n?S`2HV9P208j>SP0409nOW`2FUYH0UYJF09FEU@80Xj>S00@0VIVI08R8R028R8P0
Q8B40P2HV9P0102CTi<0R8R808R8R02MWId208j>SP0407]kN`1dM7@0M7Ad079bLP80Ph>300@0N7Qh
06e]K@1]KFd0KVi^0P1[Jf/0101OGel0EEEE05EEE@1UIFD2065QH@0406EUI@1>CTh0CTi>05ADE080
HV9R0`1UIFD0101NGUh0F5QH05QHF01LG5`205ADE00404U9B@18B4P0B4Q805iNGP80HF5Q0`17AdL0
1012@T80Cdm?04m?C`1=CDd205ADE00405YJFP1CDe<0De=C04I6AP80<30`00@0:2PX01`L700L71`0
1PH60P0G5aL0100g=cL0DU9B059BDP1=CDd20492@P0404e=C@1<C4`0C4a<0410@080@T9200@0Cdm?
05EEE@1EEED0D51@0P17AdL00`1<C4`0GEeM05eMG@03061PH004065QH@1LG5`0G5aL05]KF`80EUIF
00@0CTi>04];B`1;Bd/0DE5A0P19BDT01011@D40@d=304=3@`1?Cdl205EEE@<0CTi>00@0EeMG05=C
D`1CDe<0CDe=0P1>CTh0101?Cdl0CDe=04e=C@18B4P204e=C@0405EEE@1BDU80DU9B04U9B@80@410
00@0?Cdm04I6AP16ATH0BTY:0P16ATH01015ADD0F5QH05QHF02<S8`20<30`0040<;2`P34a<@0a<C4
0=KFeP80b<S800@0]KFe08f=S@2=SHd0EUIF0P0C4a<0100000002@T900T92@010@4200D51@0400P8
20061PH01PH600L71`800`<300000`0820P01`L700L71`0300820P0400@410092@T02@T900410@80
000000@010@400410@010@401`L70P030`<010010@402@T900T92@061PH200<30`0400D51@000000
000000<30`800P8200@00@410000000000000`<30`061PH200D51@0400<30`020P800P8200L71`80
10@400@00`<300h>3P0>3Ph02@T90P071`L010061PH00`<300<30`0410@200<30`0400@410020P80
0P820000008010@400@01PH600<30`030`<02PX:0P0820P0100000000P8200820P051@D200<30`04
00D51@092@T02@T900D51@<000000`0410@20000000400<30`0410@010@400<30`801@D500@00P82
00@4100410@01`L70`051@D200<30`<010@400@00@4100P8200820P01PH60P020P8010051@D0410@
010@400U9BD2034a<@0302`/;00];Bd0;Bd]00<0?3`l00@0>SXj02@T900T92@05ADE0P092@T01006
1PH02@T900T92@0<30`2018B4P04014A4@0@4100410@01/K6`80=cLg00@0IfMW0:2PX02PX:00Z:RX
0P2LW9`0102IVIT0NWYj07YjNP14A4@202LW9`0401hN7P0i>CT0>CTi04a<C080@41000@0<C4a04=3
@`13@d<0Bd];0P0h>3P01018B4P0EEEE05EEE@1FEUH2051@D00404M7A`1HF5P0F5QH06QXJ080LW9b
00@0H61P05YJFP1JFUX0LW9b0P1jNWX0101KFe/0DU9B059BDP1UIFD207EeM@0409FEU@1oOgl0Ogmo
06e]K@80OGem00@0KVi^05IFEP1FEUH0F5QH0P1MGEd0101iNGT0V9RH09RHV02?Shl208V9R@0409JF
UP2DU9@0U9BD09fMW@80XZ:R00@0V9RH09FEU@2EUID0QhN70P2=SHd0102DU9@0P8200820P023Ph<2
08f=S@0407moO`1XJ6P0J6QX06][J`80NWYj00@0O7al07]kN`1kNg/0G5aL0P1PH600101SHf<0@T92
0492@P1CDe<2051@D0040410@00e=CD0=CDe04Y:BP80E5AD00@0J6QX06IVIP1VIVH0GemO0P1XJ6P0
1017AdL0?clo03lo?`1CDe<204U9B@0405ADE01JFUX0FUYJ04a<C080DU9B00@0CTi>04m?C`1?Cdl0
@D510P18B4P0101ADE40De=C05=CD`1GEeL2051@D00403@d=00X:2P0:2PX01hN7P8030`<00@0820P
04M7A`17AdL0CDe=0P16ATH0101=CDd0C4a<04a<C017AdL204U9B@0404M7A`18B4P0B4Q804i>CP80
BDU900@0BTY:05YJFP1JFUX0H61P0P1KFe/0101LG5`0GemO05mOG`1KFe/205QHF004055AD@18B4P0
B4Q804m?C`80DU9B00@0C4a<04];B`1;Bd/0EEEE0P1DE5@01019BDT0B4Q804Q8B01DE5@2059BDP04
04e=C@1DE5@0E5AD05IFEP80BTY:00@0?clo04I6AP16ATH0Cdm?0P1<C4`01018B4P0@4100410@00l
?3`204];B`0404a<C016ATH0ATI604A4A080F5QH00@0Ti>C0;:b/P2b/[80ZZZZ0P31`L40103?cll0
`/;20<;2`P2f][H208Z:RP0403`l?0061PH01PH6000000801PH600@02`/;00h>3P0>3Ph01`L70P06
1PH100P8204000000@000000000300P820071`L01`L700<00P8200@010@400T92@092@T00@410P00
0000100410@00@4100410@071`L200<30`0400410@092@T02@T900H61P800`<300@01@D500000000
00000`<30P020P8010010@400000000000030`<300H61P801@D500@00`<300820P020P801`L70P04
10@010030`<03Ph>00h>3P092@T200L71`0400H61P030`<00`<300@410800`<300@010@400820P02
0P8000000P0410@010061PH00`<300<30`0:2PX200P82004000000020P800P8200D51@800`<300@0
1@D500T92@092@T01@D50`00000300@41080000000@00`<300@4100410@00`<30P051@D010020P80
10@400@410071`L300D51@800`<30`0410@010010@4020P800P820061PH200820P0400D51@0@4100
410@02DU9@80<C4a00<0;2`/02d];@0];Bd00`0l?3`0100j>SX092@T02@T900E5AD200T92@0400H6
1P092@T02@T900`<30804Q8B00@04A4A010@400@41006a/K0P0g=cL0101WIfL0X:2P0:2PX02XZ:P2
09bLW00409VIV@1jNWX0NWYj04A4A0809bLW00@07QhN03Ti>@0i>CT0C4a<0P10@400100a<C40@d=3
04=3@`1;Bd/203Ph>00404Q8B01EEED0EEEE05IFEP80D51@00@0AdM705QHF01HF5P0J6QX0P1bLW80
101PH600FUYJ05YJFP1bLW8207YjNP0405]KF`1BDU80DU9B06EUI@80MGEe00@0UIFE07moO`1oOgl0
KFe]0P1mOGd0101^KVh0EUIF05IFEP1HF5P205eMG@0407UiN@2HV9P0V9RH08n?S`80RHV900@0UYJF
09BDU02DU9@0WIfM0P2RXZ80102HV9P0UIFE09FEU@27QhL208f=S@0409BDU020P800P82008>3P`80
SHf=00@0Ogmo06QXJ01XJ6P0Jf][0P1jNWX0101lO7`0Ng]k07]kN`1LG5`2061PH00406=SH`12@T80
@T9205=CD`80D51@00@0@41003De=@0e=CD0BTY:0P1DE5@0101XJ6P0IVIV06IVIP1OGel206QXJ004
04M7A`0o?cl0?clo05=CD`80BDU900@0E5AD05YJFP1JFUX0C4a<0P1BDU80101>CTh0Cdm?04m?C`11
@D4204Q8B004055AD@1CDe<0De=C05MGE`80D51@00@0=3@d02PX:00X:2P07QhN0P0<30`0100P8200
AdM704M7A`1=CDd204I6AP0404e=C@1<C4`0C4a<04M7A`80BDU900@0AdM704Q8B018B4P0CTi>0P19
BDT0101:BTX0FUYJ05YJFP1PH60205]KF`0405aLG01OGel0GemO05]KF`80F5QH00@0DE5A04Q8B018
B4P0Cdm?0P1BDU80101<C4`0Bd];04];B`1EEED205ADE00404U9B@18B4P0B4Q805ADE080DU9B00@0
CDe=05ADE01DE5@0EUIF0P1:BTX0100o?cl0ATI604I6AP1?Cdl204a<C00404Q8B010@400@41003`l
?080Bd];00@0C4a<04I6AP16ATH0A4A40P1HF5P0102CTi<0/[:b0;:b/P2ZZZX20<71`@040<o?c`32
`/80`/;20;Jf]P80RXZ:00@0?3`l00H61P061PH000000P061PH0100;2`/03Ph>00h>3P071`L200H6
1P4020P80@0000010000000000@00`<300H61P061PH00P820`071`L200D51@0400820P061PH01PH6
00@41080000000@01`L700D51@051@D01`L70P051@D300L71`0400D51@0410@010@400<30`8020P8
00@00`<300@4100410@00P820P0000000`0<30`01`L700L71`0300D51@0400T92@051@D01@D500H6
1P8030`<00@01@D500P8200820P01@D50P020P800`061PH01@D500D51@0400@410800`<300@01PH6
00T92@092@T02`/;0P030`<00`00000010@400@4100600H61P<02PX:00@01`L700<30`030`<00`<3
0P061PH400<30`801@D500@010@400P8200820P02@T90P071`L0100410@00P8200820P071`L200D5
1@03000000071`L01`L700<00P8200@03`l?020P800P8200=3@d0P0];Bd0100Y:BT0;Rh^02h^;P0i
>CT203lo?`04034a<@0K6a/06a/K010@40802PX:00@010@400000000000010@40P0@4100100A4A40
4Q8B018B4P0_;bl205EEE@0408B4Q02a/K40/K6a0:>SX`80U9BD00@0X:2P08F5Q@25QHD0CTi>0P0V
9RH0100R8R80>SXj03Xj>P10@40203De=@0401/K6`0b<S80<S8b05IFEP80BTY:00@0CDe=04A4A014
A4@0@4100P12@T800`13@d<0D51@051@D003055AD@0405EEE@1ZJVX0JVYZ06QXJ080IVIV00@0K6a/
04U9B@19BDT0@T920P1HF5P0101nOWh0L71`071`L01KFe/206YZJP0406i^KP1GEeL0EeMG06UYJ@80
GEeM00@0JFUY08J6QP26QXH0N7Qh0P1fMWH0101hN7P0QXJ608J6QP2;Rh/208:2PP0409NGU`2@T900
T92@07AdM080K6a/00@0MgMg071`L01`L700FEUI0P1FEUH0101QHF40EeMG05MGE`1ADE4205EEE@<0
FEUI00@0AdM705mOG`1OGel0I6AT0P15ADD01012@T80=CDe03De=@0^;Rh203Hf=P0403lo?`0a<C40
<C4a0410@080ATI600@0@d=305MGE`1GEeL0B4Q80P0n?Sh0101@D500?3`l03`l?01<C4`205YJFP04
04Q8B01:BTX0BTY:04];B`80EUIF00@0DU9B04=3@`13@d<0A4A40P1DE5@0101QHF40MGEe07EeM@15
ADD202TY:@04030`<0071`L01`L701DE5@80>SXj00@0B4Q804M7A`17AdL0Bd];0P1:BTX01014A4@0
@T920492@P11@D4204];B`04051@D01;Bd/0Bd];04m?C`80GEeM00@0H61P05ADE01DE5@0De=C0P1S
Hf<0101WIfL0GEeM05eMG@1>CTh204U9B@0405IFEP1CDe<0De=C051@D080DU9B00@0EEEE05ADE01D
E5@0Cdm?0P18B4P0101EEED0F5QH05QHF01=CDd204Y:BP0304i>CP1<C4`0C4a<00<0C4a<00@0BTY:
04M7A`17AdL0@4100P0k>c/01013@d<0ADE504E5A@12@T8204E5A@0403lo?`1?Cdl0Cdm?08Z:RP80
YJFU00@0/K6a0<W9b@39bLT0c<c<0P31`L40102][Jd0MGEe07EeM@0X:2P200`<300400L71`092@T0
2@T900T92@801`L700@010@400P8200820P03@d=0P020P80000400L71`061PH01PH600<30`801`L7
00@01@D500L71`071`L01`L70P061PH010010@400P8200820P0410@200410@0400P8200410@010@4
00H61P801`L700@010@400D51@051@D00P820P092@T0100820P02@T900T92@092@T200D51@0400T9
2@0;2`/02`/;00P8208010@400<020P800/;2`0;2`/00`051@D0100410@01@D500D51@051@D30082
0P8010@400@00P8200D51@051@D01`L70P0410@00`061PH01`L700L71`0300P8200400D51@020P80
0P8200@410801`L700@010@400410@010@401PH60P092@T010071`L01@D500D51@071`L200D51@04
00@410061PH01PH600D51@<00P820P0410@010061PH00P8200820P030`<200820P0400P820051@D0
1@D500D51@801`L700@01PH600<30`030`<030`<0P0X:2P0100c<c<0:b/[02/[:`0Z:RX303De=@80
>3Ph00<0;bl_01TI6@0I6AT00`0;2`/0100820P01@D500D51@0:2PX201HF5P04014A4@0T92@092@T
04M7A`80NWYj00@0Xj>S0:j^[P2^[Zh0WinO0P2QXJ40102VYZH0R8R808R8R01LG5`202l_;`0401hN
7P0[:b/0:b/[02l_;`80;Bd]00@08R8R03Xj>P0j>SX0H61P0P1GEeL01015ADD0@4100410@019BDT2
05ADE004061PH01SHf<0Hf=S05QHF080DU9B00@0Fe]K075aL@1aLG40GUiN0P1HF5P306MWI`0406QX
J01GEeL0EeMG05YJFP80Fe]K00@0ATI604Y:BP1:BTX0FEUI0P17AdL0101VIVH0Hf=S06=SH`1;Bd/2
05UIF@04059BDP1NGUh0GUiN05UIF@<0LG5a0P1FEUH0101^KVh0HV9R069RHP1PH60205]KF`04055A
D@1MGEd0GEeM051@D080AdM700@0CTi>04Q8B018B4P0Bd];0P1BDU80101@D500C4a<04a<C01GEeL2
06=SH`0405MGE`1BDU80DU9B04M7A`80BTY:00@0J6QX06i^KP1^KVh0De=C0P0c<c<0100m?Cd0A4A4
04A4A012@T82051@D00404e=C@15ADD0ADE504Y:BP80@d=300@0EUIF05ADE01DE5@0?Cdm0P1BDU83
04a<C004055AD@18B4P0B4Q8055AD@80HF5Q00@0IFEU07moO`1oOgl0GEeM0P0g=cL0101@D500=SHf
03Hf=P0D51@2034a<@<0BDU900@0B4Q804];B`1;Bd/0AdM70P14A4@01011@D40A4A404A4A011@D42
04E5A@0405=CD`1HF5P0F5QH05EEE@80D51@00@0C4a<05YJFP1JFUX0K6a/0P1RHV80101:BTX0ATI6
04I6AP1?Cdl2051@D00405UIF@1FEUH0EUIF04e=C@<0BDU90P1:BTX0101@D500CTi>04i>CP1;Bd/2
059BDP0404];B`0o?cl0?clo04U9B@80C4a<00<0CTi>04m?C`1?Cdl00`10@4000`1>CTh0AdM704M7
A`0304E5A@040410@01>CTh0CTi>08^;R`80]KFe00@0`L710<W9b@39bLT0b/[:0P33`l<0102KVi/0
GEeM05eMG@0R8R82010@400400/;2`051@D01@D5000000800`<300@01@D500L71`071`L01`L70P01
0@40000400L71`061PH01PH600<30`801`L700@01@D500L71`071`L01`L70P061PH010010@400P82
00820P0410@200410@0400P8200410@010@400H61P801`L700@010@400D51@051@D00P820P092@T0
100820P02@T900T92@092@T200D51@0400T92@0;2`/02`/;00P8208010@400<020P800/;2`0;2`/0
0`051@D0100410@01@D500D51@051@D300820P8010@400@00P8200D51@051@D01`L70P0410@00`06
1PH01`L700L71`0300P8200400D51@020P800P8200@410801`L700@010@400410@010@401PH60P09
2@T010071`L01@D500D51@071`L200D51@0400@410061PH01PH600D51@<00P820P0410@010061PH0
0P8200820P030`<200820P0400P820051@D01@D500D51@801`L700@01PH600<30`030`<030`<0P0X
:2P0100c<c<0:b/[02/[:`0Z:RX303De=@80>3Ph00<0;bl_01TI6@0I6AT00`0;2`/0100820P01@D5
00D51@0:2PX201HF5P04014A4@0T92@092@T04M7A`80NWYj00@0Xj>S0:j^[P2^[Zh0WinO0P2QXJ40
102VYZH0R8R808R8R01LG5`202l_;`0401hN7P0[:b/0:b/[02l_;`80;Bd]00@08R8R03Xj>P0j>SX0
H61P0P1GEeL01015ADD0@4100410@019BDT205ADE004061PH01SHf<0Hf=S05QHF080DU9B00@0Fe]K
075aL@1aLG40GUiN0P1HF5P306MWI`0406QXJ01GEeL0EeMG05YJFP80Fe]K00@0ATI604Y:BP1:BTX0
FEUI0P17AdL0101VIVH0Hf=S06=SH`1;Bd/205UIF@04059BDP1NGUh0GUiN05UIF@<0LG5a0P1FEUH0
101^KVh0HV9R069RHP1PH60205]KF`04055AD@1MGEd0GEeM051@D080AdM700@0CTi>04Q8B018B4P0
Bd];0P1BDU80101@D500C4a<04a<C01GEeL206=SH`0405MGE`1BDU80DU9B04M7A`80BTY:00@0J6QX
06i^KP1^KVh0De=C0P0c<c<0100m?Cd0A4A404A4A012@T82051@D00404e=C@15ADD0ADE504Y:BP80
@d=300@0EUIF05ADE01DE5@0?Cdm0P1BDU8304a<C004055AD@18B4P0B4Q8055AD@80HF5Q00@0IFEU
07moO`1oOgl0GEeM0P0g=cL0101@D500=SHf03Hf=P0D51@2034a<@<0BDU900@0B4Q804];B`1;Bd/0
AdM70P14A4@01011@D40A4A404A4A011@D4204E5A@0405=CD`1HF5P0F5QH05EEE@80D51@00@0C4a<
05YJFP1JFUX0K6a/0P1RHV80101:BTX0ATI604I6AP1?Cdl2051@D00405UIF@1FEUH0EUIF04e=C@<0
BDU90P1:BTX0101@D500CTi>04i>CP1;Bd/2059BDP0404];B`0o?cl0?clo04U9B@80C4a<00<0CTi>
04m?C`1?Cdl00`10@4000`1>CTh0AdM704M7A`0304E5A@040410@01>CTh0CTi>08^;R`80]KFe00@0
`L710<W9b@39bLT0b/[:0P33`l<0102KVi/0GEeM05eMG@0R8R82010@400400/;2`051@D01@D50000
00800`<300@01@D500L71`071`L01`L70P010@40000400P820071`L01`L700410@8010@400@00P82
00<30`030`<00`<30P0410@010051@D01PH600H61P0410@200P8200400X:2P051@D01@D500000080
1@D500@00`<300820P020P8000000P030`<400H61P801`L700@010@400L71`071`L00`<30P051@D0
10071`L02@T900T92@061PH300D51@8010@400<01`L700@4100410@00`020P8010030`<01PH600H6
1P0410@200820P0400<30`010@400@4100@4108030`<00@020P800<30`030`<010@40P071`L00`04
10@00@4100410@0300D51@04000000061PH01PH600X:2P<00`<30P051@D00`061PH0000000000003
00410@0300820P010@400@4100<01PH600<010@400<30`030`<00`071`L0100@410010@400@4100H
61P202PX:00402l_;`0c<c<0<c<c02XZ:P80>3Ph00@0>c/k03Ph>00h>3P0:RXZ0P0B4Q80100;2`/0
2PX:00X:2P0820P200`<30<051@D00@02`/;02d];@0];Bd0EeMG0P2@T900102^[Zh0YZJV0:JVYP2U
YJD20:^[Z`040:RXZ02BTY80TY:B06QXJ080<C4a00@05QHF02PX:00X:2P0;bl_0P0P8200100];Bd0
@D510451@@1;Bd/204e=C@040451@@17AdL0AdM7059BDP80E5AD00@0EeMG05=CD`1CDe<0F5QH0P1X
J6P0101JFUX0CTi>04i>CP1@D50205eMG@0406][J`1WIfL0IfMW07AdM080LW9b00@0KVi^071`L01`
L700Bd];0P17AdL0101:BTX0ATI604I6AP1eMGD206UYJ@0405MGE`1^KVh0KVi^05]KF`80IFEU00@0
IfMW06e]K@1]KFd0GemO0P1>CTh0101@D500@d=304=3@`1CDe<204E5A@04055AD@1SHf<0Hf=S051@
D080E5AD00@0DE5A04Y:BP1:BTX0FEUI0P1TI6@0101`L700K6a/06a/K01RHV82061PH004055AD@1O
Gel0GemO06e]K@80LG5a00@0Ogmo08V9R@29RHT0MWIf0P1;Bd/0101FEUH0G5aL05aLG010@40203`l
?00304A4A017AdL0AdM700<0@T9200@0@41003Hf=P0f=SH0=3@d0P1:BTX01018B4P0DE5A055AD@1B
DU8206EUI@0406MWI`1LG5`0G5aL05YJFP80R8R800@0Ogmo04i>CP1>CTh0LG5a0P1^KVh0100N7Qh0
9RHV02HV9P16ATH204];B`0404=3@`19BDT0BDU904U9B@80A4A400@0@D5103/k>`0k>c/0?Shn0P15
ADD0101:BTX0CTi>04i>CP1ADE4204i>CP0404e=C@1HF5P0F5QH069RHP80GemO00@0E5AD04I6AP16
ATH0@D510P1<C4`0101MGEd0E5AD05ADE016ATH204Q8B00404i>CP1=CDd0CDe=04U9B@80B4Q800@0
AdM7059BDP1BDU80CDe=0`0l?3`20410@00404e=C@1@D500D51@0410@080?Cdm00@0BDU904m?C`1?
Cdl0CTi>0P17AdL01010@400E5AD05ADE02?Shl20;:b/P040;Fe]@2l_;`0_;bl0<[:bP80`<3000@0
R8R8051@D01@D5007QhN0P0:2PX010092@T00P8200820P020P8200@410@00P820P071`L0000300L7
1`0820P020P800@01PH60P092@T010020P801PH600H61P0:2PX200`<300400<30`0410@010@400H6
1P800`<300@010@400T92@092@T010@40`051@D200L71`@01@D50P020P8010010@400`<300<30`09
2@T200D51@0400820P051@D01@D500<30`801`L700@010@400L71`071`L02@T90P030`<010051@D0
20P800P8200;2`/200X:2P0400D51@00000000000000008010@400<01@D500@4100410@010071`L2
00D51@0400@410071`L01`L700P820802`/;0`071`L0100410@01PH600H61P0820P200<30`<010@4
00@01@D500H61P061PH01PH60P030`<300@4100400410@030`<00`<300<30`801`L700@02`/;00L7
1`071`L07alO0P0Z:RX0100b<S80<c<c03<c<`0];Bd202h^;P0403Ti>@0h>3P0>3Ph01/K6`802`/;
00@03@d=00`<300<30`02`/;0P0E5AD0100C4a<01@D500D51@0N7Qh204M7A`0407EeM@2SXj<0Xj>S
0;2`/080YZJV00@0Y:BT0:FUY@2UYJD0[:b/0P2KVi/0101ZJVX0=cLg03Lg=`0G5aL2020P800401HF
5P000000000002@T9080?clo00@0?3`l059BDP1BDU80HF5Q0P1JFUX0101@D500AdM704M7A`0j>SX2
04M7A`0406=SH`1[Jf/0Jf][05eMG@80IFEU00@0JVYZ05]KF`1KFe/0E5AD0P11@D40101ZJVX0MWIf
07IfMP1YJFT20820P0<0KVi^00@0Hf=S05UIF@1IFET0RHV90`1iNGT208>3P`0406IVIP1jNWX0NWYj
08B4Q080QXJ600@0Kfm_07EeM@1eMGD0LW9b0P1GEeL0101EEED0?3`l03`l?01BDU8206IVIP0404i>
CP1JFUX0FUYJ06a/K080J6QX00@0LW9b06QXJ01XJ6P0Hf=S0P1iNGT0101_Kfl0HF5Q065QH@1DE5@2
055AD@0406MWI`1iNGT0NGUi06i^KP80MgMg00@0T92@08n?S`2?Shl0Ng]k0P1[Jf/01017AdL0<c<c
03<c<`1CDe<205EEE@0403Ti>@0Z:RX0:RXZ02LW9`D0?3`l00@0@d=305EEE@1EEED0De=C0P1[Jf/0
101RHV80DU9B059BDP1RHV820820P00406m_K`1?Cdl0Cdm?06=SH`80I6AT00@0:b/[02HV9P0V9RH0
A4A40P1<C4`00`10@400@T920492@P0304=3@`0404Y:BP14A4@0A4A404I6AP80CDe=00@0Bd];04m?
C`1?Cdl0De=C0P1>CTh0101?Cdl0EeMG05MGE`1JFUX205UIF@0405ADE01=CDd0CDe=04a<C080DE5A
00@0GEeM05EEE@1EEED0B4Q80P1ADE400`1MGEd0FUYJ05YJFP0304i>CP0404M7A`16ATH0ATI604Q8
B080@d=30`0l?3`01014A4@0ATI604I6AP10@40203/k>`040492@P1>CTh0CTi>04Q8B080AdM700@0
@41005ADE01DE5@0RHV90P2/[:`0102b/[80^[Zj0;Zj^P39bLT20;^k^`0407emO@12@T80@T9201<C
4`801@D500@01PH600X:2P0:2PX01`L70P092@T010020P801@D500D51@051@D200@4100000<01`L7
00P8200820P010061PH200T92@0400820P061PH01PH600X:2P8030`<00@00`<300@4100410@01PH6
0P030`<0100410@02@T900T92@0410@300D51@801`L710051@D200820P0400410@030`<00`<300T9
2@801@D500@00P8200D51@051@D00`<30P071`L0100410@01`L700L71`092@T200<30`0400D51@08
20P020P800/;2`802PX:00@01@D500000000000000000P0410@00`051@D010@400@4100400L71`80
1@D500@010@400L71`071`L020P80P0;2`/300L71`0400@410061PH01PH600P820800`<30`0410@0
10051@D01PH600H61P061PH200<30`<010@400@00@4100<30`030`<00`<30P071`L0100;2`/01`L7
00L71`0O7al202XZ:P04038b<P0c<c<0<c<c02d];@80;Rh^00@0>CTi03Ph>00h>3P06a/K0P0;2`/0
100=3@d030`<00`<300;2`/201DE5@0401<C4`051@D01@D501hN7P80AdM700@0MGEe0:>SX`2SXj<0
/;2`0P2VYZH0102TY:@0YJFU0:FUY@2/[:`209^KV`0406YZJP0g=cL0=cLg01LG5`80820P00@05QHF
00000000000092@T0P0o?cl0100l?3`0DU9B059BDP1QHF4205YJFP04051@D017AdL0AdM703Xj>P80
AdM700@0Hf=S06][J`1[Jf/0GEeM0P1UIFD0101ZJVX0Fe]K05]KF`1DE5@20451@@0406YZJP1fMWH0
MWIf06UYJ@80P8200`1^KVh0101SHf<0FEUI05UIF@29RHT307UiN@80Ph>300@0IVIV07YjNP1jNWX0
Q8B40P26QXH0101_Kfl0MGEe07EeM@1bLW8205MGE`0405EEE@0l?3`0?3`l059BDP80IVIV00@0CTi>
05YJFP1JFUX0K6a/0P1XJ6P0101bLW80J6QX06QXJ01SHf<207UiN@0406m_K`1QHF40HF5Q05ADE080
DE5A00@0IfMW07UiN@1iNGT0KVi^0P1gMgL0102@T900Shn?08n?S`1kNg/206][J`0404M7A`0c<c<0
<c<c05=CD`80EEEE00@0>CTi02XZ:P0Z:RX09bLW1@0l?3`01013@d<0EEEE05EEE@1CDe<206][J`04
069RHP1BDU80DU9B069RHP80P82000@0Kfm_04m?C`1?Cdl0Hf=S0P1TI6@0100[:b/09RHV02HV9P14
A4@204a<C0030410@012@T80@T9200<0@d=300@0BTY:04A4A014A4@0ATI60P1=CDd0101;Bd/0Cdm?
04m?C`1CDe<204i>CP0404m?C`1GEeL0EeMG05YJFP80FEUI00@0E5AD04e=C@1=CDd0C4a<0P1ADE40
101MGEd0EEEE05EEE@18B4P2055AD@0305eMG@1JFUX0FUYJ00<0CTi>00@0AdM704I6AP16ATH0B4Q8
0P13@d<303`l?00404A4A016ATH0ATI60410@080>c/k00@0@T9204i>CP1>CTh0B4Q80P17AdL01010
@400E5AD05ADE029RHT20:b/[0040;:b/P2j^[X0^[Zj0<W9b@80^k^k00@0OGem0492@P12@T804a<C
0P051@D010061PH02PX:00X:2P071`L200T92@0400820P051@D01@D500D51@8010@4000010061PH0
20P800P820051@D200820P0400T92@0;2`/02`/;00<30`<01PH60P092@T010061PH00@4100410@03
0`<200820P<01`L70`030`<0100410@02@T900T92@071`L200@4100400D51@061PH01PH600820P80
0`<300@030`<00P8200820P010@40P0820P010061PH03@d=00d=3@0:2PX300L71`800`<300@01PH6
00P8200820P01`L70P051@D300@4100400820P030`<00`<300<30`800P820`061PH300@4100400H6
1P0410@010@400820P801PH600@020P800D51@051@D00`<30P0410@400<30`800P8200@010@400L7
1`071`L00`<30P051@D010061PH00000000000010@4200<30`0400@410071`L01`L700@410803`l?
00@05QHF02`/;00/;2`0=3@d0P0V9RH0100_;bl0<30`030`<00f=SH202`/;00401<C4`0=3@d03@d=
00/;2`802@T900@04Q8B01PH600H61P030`<0P051@D0100_;bl0Fe]K05]KF`2ATI420:RXZ0040:FU
Y@2QXJ40XJ6Q0:2PX080ZJVY00@0/[:b09FEU@2EUID0HV9R0P0l?3`0100T92@0820P020P800I6AT2
00h>3P04034a<@1HF5P0F5QH04e=C@80@T9200<0EUIF06EUI@1UIFD00`1OGel0101XJ6P0NGUi07Ui
N@1dM7@2061PH004071`L021PH40PH61079bLP80I6AT00@0K6a/05EEE@1EEED0Jf][0P1OGel0100n
?Sh0Hf=S06=SH`1MGEd206IVIP0407EeM@1FEUH0EUIF07=cL`80NWYj00@0KVi^07QhN01hN7P0L71`
0P20P8001025QHD0QXJ608J6QP1VIVH208:2PP0408^;R`1fMWH0MWIf07QhN080LW9b0`20P800101_
Kfl0LG5a075aL@1fMWH206YZJP0406i^KP1JFUX0FUYJ0410@080Hf=S00@0Jf][06ATI01TI6@0JVYZ
0P1HF5P0101?Cdl0Hf=S06=SH`1EEED205IFEP0407AdM02?Shl0Shn?06a/K080De=C00@0Bd];03Ph
>00h>3P0FUYJ0P1BDU80100j>SX0;2`/02`/;00X:2P204U9B@0404E5A@10@400@41004M7A`80@D51
00@0DE5A05]KF`1KFe/0FUYJ0P1OGel0101WIfL0I6AT06ATI01TI6@206EUI@0406YZJP1UIFD0IFEU
03Xj>P80;bl_00@0BDU904e=C@1=CDd0A4A40P11@D40100o?cl0@T920492@P1>CTh204M7A`0404A4
A01>CTh0CTi>055AD@80EEEE00@0EUIF05ADE01DE5@0DU9B0P1DE5@0101EEED0De=C05=CD`1?Cdl2
05=CD`0405]KF`1LG5`0G5aL05mOG`80EeMG00@0D51@059BDP1BDU80EUIF0P1PH600101HF5P0D51@
051@D01;Bd/204U9B@0404I6AP0o?cl0?clo03/k>`80A4A400@0B4Q804A4A014A4@0ATI60P17AdL3
04Q8B00404E5A@17AdL0AdM704A4A080FUYJ00@0R8R80:VYZ@2YZJT0[jn_0P2h^;P01031`L40[jn_
0:n_[`1]KFd2030`<004014A4@0410@010@40000008020P800@02@T900P8200820P00`<30P0410@1
00D51@400`<30@030`<0000400@410051@D01@D500D51@800@4100<010@400H61P061PH00`030`<0
10020P800@4100410@051@D200@4100400H61P0;2`/02`/;00P8208010@400@00P8200<30`030`<0
1PH60P051@D0100820P00`<300<30`00000200P8200400/;2`051@D01@D500X:2P802`/;00@01PH6
00@4100410@01@D50`0820P200@4100400D51@092@T02@T900X:2P8010@40`020P8010010@400`<3
00<30`020P8200<30`<01PH600@010@400410@010@4010@40P0820P010020P800@4100410@051@D2
00H61P0400@410000000000000@410801@D500@00`<300@4100410@010@40P010@400`051@D00`<3
00<30`0300@4100300D51@030`<00`<300@010@40P030`<010061PH08b<S02<S8`0V9RH202/[:`04
03<c<`0U9BD09BDU02l_;`80?Cdm00@0=3@d01`L700L71`03Ph>0P0<30`0100820P02@T900T92@0M
7Ad201`L700401@D500C4a<04a<C02`/;080Hf=S00@0WIfM0:NWY`2WYjL0Xj>S0`2QXJ420:n_[`04
0;:b/P28R8P0R8R805QHF080?3`l00@0<30`02LW9`0W9bL09BDU0P0X:2P0100l?3`0D51@051@D01;
Bd/205eMG@0407UiN@1hN7P0N7Qh06e]K@80Kfm_00@0M7Ad07QhN01hN7P0JFUY0P1_Kfl0101iNGT0
I6AT06ATI01EEED205iNGP0406][J`1>CTh0CTi>04Q8B080GEeM00@0GemO07MgM`1gMgL0I6AT0P1K
Fe/0101bLW80E5AD05ADE01^KVh20820P00405ADE01OGel0GemO06YZJP80Kfm_0`1iNGT0101cLg<0
TI6A096AT@20P80207alO0040861P@1bLW80LW9b071`L080IFEU00@0Lg=c06a/K01/K6`0DE5A0P1N
GUh0101WIfL0D51@051@D01<C4`206QXJ00406UYJ@1RHV80HV9R071`L080HV9R00@0>SXj04I6AP16
ATH0FUYJ0P1VIVH305IFEP0404Y:BP11@D40@D5104i>CP80D51@00@0DE5A03De=@0e=CD0@T920P1J
FUX0101ADE40Bd];04];B`0o?cl204i>CP0405eMG@0m?Cd0?Cdm05MGE`80HF5Q00@0H61P05QHF01H
F5P0@d=30P1@D500101aLG40IFEU06EUI@1RHV8205eMG@0403Lg=`0c<c<0<c<c04e=C@80De=C00<0
EeMG04Y:BP1:BTX00`14A4@0101<C4`0A4A404A4A011@D4204Q8B00304U9B@1=CDd0CDe=00<0EUIF
00@0DU9B04i>CP1>CTh0Bd];0P1?Cdl0101>CTh0D51@051@D01FEUH205aLG00405mOG`1BDU80DU9B
05ADE080D51@00@0Bd];05MGE`1GEeL0D51@0P1:BTX304];B`0404Q8B019BDT0BDU904Q8B080C4a<
00@0Cdm?04Q8B018B4P0@4100P15ADD0101=CDd0BTY:04Y:BP18B4P204U9B@040451@@1IFET0FEUI
09JFUP80[:b/00@0ZJVY0;bl_02l_;`0`L710P2WYjL0101RHV80=3@d03@d=00K6a/200@4100400<3
0`020P800P8200D51@800P820`010@4100D51@402`/;0@0;2`/0000400@410051@D01@D500D51@80
0@4100<010@400H61P061PH00`030`<010020P800@4100410@051@D200@4100400H61P0;2`/02`/;
00P8208010@400@00P8200<30`030`<01PH60P051@D0100820P00`<300<30`00000200P8200400/;
2`051@D01@D500X:2P802`/;00@01PH600@4100410@01@D50`0820P200@4100400D51@092@T02@T9
00X:2P8010@40`020P8010010@400`<300<30`020P8200<30`<01PH600@010@400410@010@4010@4
0P0820P010020P800@4100410@051@D200H61P0400@410000000000000@410801@D500@00`<300@4
100410@010@40P010@400`051@D00`<300<30`0300@4100300D51@030`<00`<300@010@40P030`<0
10061PH08b<S02<S8`0V9RH202/[:`0403<c<`0U9BD09BDU02l_;`80?Cdm00@0=3@d01`L700L71`0
3Ph>0P0<30`0100820P02@T900T92@0M7Ad201`L700401@D500C4a<04a<C02`/;080Hf=S00@0WIfM
0:NWY`2WYjL0Xj>S0`2QXJ420:n_[`040;:b/P28R8P0R8R805QHF080?3`l00@0<30`02LW9`0W9bL0
9BDU0P0X:2P0100l?3`0D51@051@D01;Bd/205eMG@0407UiN@1hN7P0N7Qh06e]K@80Kfm_00@0M7Ad
07QhN01hN7P0JFUY0P1_Kfl0101iNGT0I6AT06ATI01EEED205iNGP0406][J`1>CTh0CTi>04Q8B080
GEeM00@0GemO07MgM`1gMgL0I6AT0P1KFe/0101bLW80E5AD05ADE01^KVh20820P00405ADE01OGel0
GemO06YZJP80Kfm_0`1iNGT0101cLg<0TI6A096AT@20P80207alO0040861P@1bLW80LW9b071`L080
IFEU00@0Lg=c06a/K01/K6`0DE5A0P1NGUh0101WIfL0D51@051@D01<C4`206QXJ00406UYJ@1RHV80
HV9R071`L080HV9R00@0>SXj04I6AP16ATH0FUYJ0P1VIVH305IFEP0404Y:BP11@D40@D5104i>CP80
D51@00@0DE5A03De=@0e=CD0@T920P1JFUX0101ADE40Bd];04];B`0o?cl204i>CP0405eMG@0m?Cd0
?Cdm05MGE`80HF5Q00@0H61P05QHF01HF5P0@d=30P1@D500101aLG40IFEU06EUI@1RHV8205eMG@04
03Lg=`0c<c<0<c<c04e=C@80De=C00<0EeMG04Y:BP1:BTX00`14A4@0101<C4`0A4A404A4A011@D42
04Q8B00304U9B@1=CDd0CDe=00<0EUIF00@0DU9B04i>CP1>CTh0Bd];0P1?Cdl0101>CTh0D51@051@
D01FEUH205aLG00405mOG`1BDU80DU9B05ADE080D51@00@0Bd];05MGE`1GEeL0D51@0P1:BTX304];
B`0404Q8B019BDT0BDU904Q8B080C4a<00@0Cdm?04Q8B018B4P0@4100P15ADD0101=CDd0BTY:04Y:
BP18B4P204U9B@040451@@1IFET0FEUI09JFUP80[:b/00@0ZJVY0;bl_02l_;`0`L710P2WYjL0101R
HV80=3@d03@d=00K6a/200@4100400<30`020P800P8200D51@800P820`010@4100D51@402`/;0@0;
2`/0000400D51@000000000000820P801`L700@02@T900/;2`0;2`/020P80P030`<0100410@00`<3
00<30`030`<200D51@0400T92@0;2`/02`/;00<30`801`L700@02`/;00P8200820P01`L70P030`<3
00D51@0400@410061PH01PH600D51@800`<300@030`<00T92@092@T00`<30P0820P010051@D00000
000000051@D200@4100400410@051@D01@D500P820801@D50`071`L0100410@00P8200820P030`<2
00P820<02@T900@02PX:00@4100410@00@410P051@D300820P0400X:2P0<30`030`<00D51@800@41
00@00P8200P8200820P01@D50P061PH010071`L010@400@410061PH200<30`0400T92@010@400@41
00<30`8020P800@00P8200D51@051@D01@D50P010@40100?3`l0;2`/02`/;00h>3P202XZ:P0403<c
<`0];Bd0;Bd]038b<P80?Shn00@0:b/[01DE5@0E5AD01@D50P0<30`0100=3@d02`/;00/;2`0G5aL2
010@400401PH600Q8B408B4Q03`l?080Ng]k00@0Y:BT0:VYZ@2YZJT0ZZZZ0P2YZJT0102WYjL0Zj^[
0:^[Z`2[Zj/207YjNP04059BDP1<C4`0C4a<04A4A080=CDe00@09RHV02DU9@0U9BD0<C4a0P0m?Cd0
101<C4`0Jf][06][J`1/K6`205]KF`0406ATI01WIfL0IfMW05QHF080FEUI00@0JFUY07emO@1mOGd0
MWIf0P1NGUh0101<C4`0De=C05=CD`1OGel204A4A00403/k>`1PH600H61P069RHP80IfMW00@0IFEU
05]KF`1KFe/0J6QX0P1HF5P0101/K6`0PX:208:2PP1OGel206i^KP0407EeM@1/K6`0K6a/06e]K@80
L71`00@0Ph>308R8R028R8P0HF5Q0P1OGel0101ADE40DU9B059BDP1YJFT2055AD@04061PH01/K6`0
K6a/04];B`80EeMG00@0KFe]06MWI`1WIfL0LG5a0P1cLg<306QXJ004079bLP1TI6@0I6AT03Lg=`80
D51@00@0KVi^06MWI`1WIfL0GemO0P1ZJVX0101?Cdl0B4Q804Q8B011@D4203Hf=P0403`l?00[:b/0
:b/[04e=C@80J6QX00@0IFEU04A4A014A4@0?3`l0P1>CTh0101BDU80@D510451@@1GEeL206UYJ@<0
@d=300@0>CTi04e=C@1=CDd0NWYj0P1fMWH0101`L700IfMW06MWI`0/;2`202XZ:P0404U9B@1ADE40
DE5A05eMG@80BTY:00@0AdM704];B`1;Bd/0BTY:0P14A4@01016ATH0@D510451@@0k>c/20410@004
059BDP1LG5`0G5aL05ADE080A4A400@0ADE505=CD`1CDe<0D51@0P1<C4`01017AdL0EUIF05IFEP1V
IVH205ADE004055AD@1DE5@0E5AD04i>CP80BTY:00@0B4Q804a<C01<C4`0De=C0P1BDU801018B4P0
BDU904U9B@1@D50204e=C@<0CTi>00@0ADE504A4A014A4@0B4Q80P19BDT01017AdL0@d=304=3@`0o
?cl205UIF@040:6QX@2h^;P0^;Rh0;Bd]080aLG500@0alO70:FUY@2UYJD0I6AT0P0i>CT0100F5QH0
0000000000061PH200L71`0400820P030`<00`<300H61P<02@T90P071`L0000400<30`051@D01@D5
00D51@801`L700@03@d=00X:2P0:2PX01@D50P092@T010071`L00P8200820P010@4200D51@0400H6
1P0820P020P800@410801@D500@02@T900D51@051@D00@410P0000000`030`<01@D500D51@0300L7
1`0300/;2`061PH01PH600<010@40`0820P010071`L02@T900T92@0;2`/200P8200400@410061PH0
1PH600D51@801PH600@01`L700D51@051@D01`L70P051@D010020P802PX:00X:2P0;2`/200P82004
00/;2`092@T02@T900<30`800@4100@010@400820P020P801PH60P092@T010030`<01@D500D51@03
0`<200D51@0400<30`051@D01@D500H61P800@4100@00`<300P8200820P00@410P00000010071`L0
1PH600H61P051@D200T92@0400@4100?3`l03`l?01dM7@80=3@d00@0<C4a02XZ:P0Z:RX0>CTi0P0a
<C40100e=CD0>CTi03Ti>@0P8202014A4@0400X:2P0?3`l03`l?00P820803`l?00@05QHF00P82008
20P0410@0P0I6AT0101:BTX0QhN708N7Q`2LW9`30:JVYP80YJFU00@0ZZZZ0:RXZ02XZ:P0V9RH0P1[
Jf/01018B4P0CTi>04i>CP1HF5P204i>CP0402PX:00H61P061PH02XZ:P80=SHf00@0Bd];05]KF`1K
Fe/0HV9R0P1XJ6P0101[Jf/0NGUi07UiN@1fMWH206UYJ@0406e]K@1^KVh0KVi^07MgM`80KVi^00@0
EUIF05mOG`1OGel0O7al0P1/K6`0101=CDd0BDU904U9B@1<C4`206i^KP0407UiN@1MGEd0GEeM06UY
J@80IVIV00@0I6AT075aL@1aLG40L71`0P1jNWX0101WIfL0CTi>04i>CP1QHF4206UYJ@0406][J`1M
GEd0GEeM051@D080IFEU00@0FEUI061PH01PH600SXj>0P20P800101bLW80O7al07alO01PH60204A4
A004051@D01NGUh0GUiN05iNGP80FUYJ00@0F5QH05]KF`1KFe/0HV9R0P1HF5P01013@d<0LW9b079b
LP1jNWX205ADE00406=SH`1eMGD0MGEe03/k>`80EUIF00@0Hf=S03Ph>00h>3P0?clo0P1;Bd/0101U
IFD0MGEe07EeM@1XJ6P203hn?P0404=3@`0];Bd0;Bd]03Ti>@80@41000@0@D5106MWI`1WIfL0@D51
0P1RHV80101/K6`0EUIF05IFEP1lO7`20820P00407AdM01PH600H61P02@T9080=CDe00@0FEUI04i>
CP1>CTh0D51@0P0o?cl01010@400DU9B059BDP1CDe<304a<C080A4A400@0@41004A4A014A4@0BDU9
0`1CDe<204A4A00404Q8B01LG5`0G5aL05]KF`80Cdm?00@0ADE505MGE`1GEeL0IFEU0P1=CDd01017
AdL0De=C05=CD`1@D50204e=C@03051@D01?Cdl0Cdm?00<0Cdm?00@0ATI60451@@11@D40BTY:0`1;
Bd/304Y:BP80D51@00@0B4Q804I6AP16ATH0A4A40P0k>c/0100o?cl0Hf=S06=SH`2UYJD20;fm_@04
0;Vi^@2o_kl0_kno0<W9b@80YZJV00@0IFEU02l_;`0_;bl03`l?0P010@4010030`<010@400@41001
0@4200<30`0400H61P092@T02@T900D51@800000000010030`<01@D500D51@051@D200L71`0400d=
3@0:2PX02PX:00D51@802@T900@01`L700820P020P800@410P051@D010061PH020P800P8200410@2
00D51@0400T92@051@D01@D500410@80000000<00`<300D51@051@D00`071`L00`0;2`/01PH600H6
1P0300@410<020P800@01`L700T92@092@T02`/;0P0820P0100410@01PH600H61P051@D200H61P04
00L71`051@D01@D500L71`801@D500@00P8200X:2P0:2PX02`/;0P0820P0100;2`/02@T900T92@03
0`<200410@0400@410020P800P8200H61P802@T900@00`<300D51@051@D00`<30P051@D010030`<0
1@D500D51@061PH200410@0400<30`0820P020P800410@80000000@01`L700H61P061PH01@D50P09
2@T0100410@03`l?00l?3`0M7Ad203@d=004034a<@0Z:RX0:RXZ03Ti>@80<C4a00@0=CDe03Ti>@0i
>CT0820P0P0A4A40100:2PX03`l?00l?3`0820P200l?3`0401HF5P0820P020P8010@40806ATI00@0
BTY:08N7Q`27QhL0W9bL0`2VYZH20:FUY@040:ZZZP2XZ:P0Z:RX09RHV080Jf][00@0B4Q804i>CP1>
CTh0F5QH0P1>CTh0100X:2P061PH01PH600Z:RX203Hf=P0404];B`1KFe/0Fe]K069RHP80J6QX00@0
Jf][07UiN@1iNGT0MWIf0P1YJFT0101]KFd0KVi^06i^KP1gMgL206i^KP0405IFEP1OGel0GemO07al
O080K6a/00@0CDe=04U9B@19BDT0C4a<0P1^KVh0101iNGT0GEeM05eMG@1YJFT206IVIP0406ATI01a
LG40LG5a071`L080NWYj00@0IfMW04i>CP1>CTh0HF5Q0P1YJFT0101[Jf/0GEeM05eMG@1@D50206EU
I@0405UIF@1PH600H61P08j>SP80P82000@0LW9b07alO01lO7`0H61P0P14A4@0101@D500GUiN05iN
GP1NGUh205YJFP0405QHF01KFe/0Fe]K069RHP80F5QH00@0@d=3079bLP1bLW80NWYj0P1DE5@0101S
Hf<0MGEe07EeM@0k>c/205IFEP0406=SH`0h>3P0>3Ph03lo?`80Bd];00@0IFEU07EeM@1eMGD0J6QX
0P0n?Sh01013@d<0;Bd]02d];@0i>CT20410@0040451@@1WIfL0IfMW0451@@80HV9R00@0K6a/05IF
EP1FEUH0O7al0P20P800101dM7@0H61P061PH00T92@203De=@0405UIF@1>CTh0CTi>051@D080?clo
00@0@410059BDP1BDU80De=C0`1<C4`204A4A0040410@014A4@0A4A404U9B@<0De=C0P14A4@01018
B4P0G5aL05aLG01KFe/204m?C`0404E5A@1GEeL0EeMG06EUI@80CDe=00@0AdM705=CD`1CDe<0D51@
0P1=CDd00`1@D500Cdm?04m?C`0304m?C`0404I6AP11@D40@D5104Y:BP<0Bd];0`1:BTX2051@D004
04Q8B016ATH0ATI604A4A080>c/k00@0?clo06=SH`1SHf<0YJFU0P2m_Kd0102i^KT0_kno0;no_`39
bLT20:JVYP0406EUI@0_;bl0;bl_00l?3`800@4100@00`<300@4100410@00@410P030`<010061PH0
2@T900T92@051@D2000000000`030`<0100820P01PH600H61P061PH200L71`0400410@061PH01PH6
00P820801PH600@01@D500L71`071`L00`<30P071`L0100;2`/01@D500D51@0410@200D51@040082
0P071`L01`L700T92@800`<300@01PH600T92@092@T02PX:0P061PH300<30`0400`<30092@T02@T9
00820P801`L700@01PH600<30`030`<01PH60P0;2`/00`061PH000000000000300L71`0400<30`09
2@T02@T900D51@801PH600@02@T900D51@051@D00`<30P061PH0100:2PX01@D500D51@0410@200D5
1@<010@400@00P8200H61P061PH00`<30P0410@0100820P00`<300<30`0410@200D51@0400<30`07
1`L01`L7000000802@T900@010@400X:2P0:2PX02PX:0P051@D0100000006QXJ01XJ6P0X:2P203Hf
=P<0;2`/00@0<c<c034a<@0a<C40<c<c0P0];Bd0100F5QH020P800P8200@4102018B4P0400<30`0B
4Q804Q8B01LG5`803`l?00@051@D02LW9`0W9bL0Fe]K0P2=SHd0102NWYh0YZJV0:JVYP2UYJD20:JV
YP040:^[Z`2TY:@0Y:BT08b<S080HV9R00@0<c<c028R8P0R8R80>c/k0P1<C4`0100X:2P0410@010@
400S8b<202TY:@0403/k>`1@D500D51@05=CD`80F5QH00@0GUiN06MWI`1WIfL0JVYZ0P1_Kfl0101S
Hf<0FUYJ05YJFP1MGEd205mOG`0405MGE`1FEUH0EUIF06MWI`80H61P00@0BTY:03Xj>P0j>SX0CTi>
0P1cLg<0101hN7P0@d=304=3@`1;Bd/205eMG@0405YJFP1RHV80HV9R07]kN`80QXJ600@0NWYj05EE
E@1EEED0I6AT0P1/K6`0101ZJVX0E5AD05ADE01FEUH207emO@0406i^KP1RHV80HV9R06m_K`80H61P
00@0Hf=S05UIF@1IFET0AdM70P0k>c/00`0a<C40ATI604I6AP0305ADE00404E5A@0f=SH0=SHf0410
@080>CTi00@0=cLg05QHF01HF5P0HF5Q0P1BDU8305eMG@0403Ph>01`L700L71`08n?S`80MWIf00@0
J6QX05MGE`1GEeL0HF5Q0P1jNWX0101YJFT0>SXj03Xj>P1=CDd202`/;00404E5A@1IFET0FEUI03/k
>`80JFUY00@0MgMg07UiN@1iNGT0R8R80P1YJFT01023Ph<0N7Qh07QhN01fMWH2055AD@0402@T9012
@T80@T9206QXJ080@d=300@0>SXj03lo?`0o?cl0@4100P1>CTh00`1HF5P0D51@051@D00304e=C@04
04I6AP19BDT0BDU904I6AP80BTY:00@0Cdm?04U9B@19BDT0DU9B0P1SHf<0101OGel0E5AD05ADE01>
CTh305iNGP80@D5100<0?clo04];B`1;Bd/00`1CDe<00`1=CDd0CTi>04i>CP0304Y:BP0404m?C`19
BDT0BDU904E5A@80C4a<00@0DE5A04Y:BP1:BTX0BTY:0P1>CTh01019BDT0Bd];04];B`16ATH203`l
?00404M7A`1/K6`0K6a/0:2PX080`/;20`33`l<0103De=@0[Zj^0:j^[P1OGel201lO7`0400d=3@07
1`L01`L700820P801@D500@01PH600820P020P801@D50P071`L100<30`4000000@000000000400D5
1@010@400@4100@410801PH600@020P800H61P061PH010@40`051@D200<30`0400D51@0:2PX02PX:
00D51@8010@400@02PX:00D51@051@D000000P071`L0100;2`/01`L700L71`051@D200<30`040082
0P051@D01@D500D51@8010@400@01`L700@4100410@01@D50P061PH010030`<02@T900T92@0:2PX2
00D51@0400L71`0?3`l03`l?00d=3@800`<30`020P8010030`<02PX:00X:2P051@D200820P0300@4
10061PH01PH600<01`L70`0820P0100410@00P8200820P0410@200410@@00`<30P0:2PX010051@D0
0@4100410@0410@200D51@0400H61P0820P020P800<30`801PH600@00`<300L71`071`L03@d=0P06
1PH0100<30`05aLG01LG5`0c<c<202l_;`04038b<P0];Bd0;Bd]02PX:080>CTi00@0>3Ph02TY:@0Y
:BT04Q8B0P0:2PX0100@41003@d=00d=3@0>3Ph201@D5004014A4@0D51@051@D02PX:080I6AT00@0
Shn?09^KV`2KVi/0VIVI0P2MWId0102TY:@0ZZZZ0:ZZZP2WYjL209VIV@0408j>SP1iNGT0NGUi04E5
A@806a/K00@06ATI030`<00`<300<c<c0P0P8200100`<300CTi>04i>CP16ATH203/k>`040410@00l
?3`0?3`l04E5A@80EEEE00@0IFEU06QXJ01XJ6P0DE5A0`1:BTX2055AD@0404e=C@1KFe/0Fe]K059B
DP80ATI600@0DU9B04e=C@1=CDd0DU9B0P11@D401018B4P0=CDe03De=@13@d<205EEE@04051@D01B
DU80DU9B06UYJ@80Kfm_00@0MGEe05QHF01HF5P0GEeM0P1bLW801020P800D51@051@D00h>3P205IF
EP0404Y:BP1?Cdl0Cdm?05]KF`80BTY:00@0Cdm?0410@010@400>3Ph0P1=CDd0101:BTX0C4a<04a<
C01JFUX205ADE00403lo?`13@d<0@d=305]KF`80?Cdm00@0:RXZ04Q8B018B4P0EEEE0P12@T80101@
D500GemO05mOG`1NGUh2061PH00405QHF01LG5`0G5aL06MWI`80JFUY00@0CDe=05=CD`1CDe<0Jf][
0P1<C4`0101RHV80Fe]K05]KF`1IFET208Z:RP0305IFEP1;Bd/0Bd];00<0NGUi00@0OGem06=SH`1S
Hf<0M7Ad0P1jNWX01020P800HF5Q065QH@0U9BD202l_;`0406ATI00h>3P0>3Ph01`L7080=3@d00@0
A4A404a<C01<C4`0D51@0P1:BTX0101@D500DE5A055AD@19BDT204Y:BP0404a<C01;Bd/0Bd];04U9
B@80@D5100@0D51@06=SH`1SHf<0Fe]K0P1?Cdl01018B4P0F5QH05QHF01BDU8203`l?0040410@012
@T80@T9204e=C@80Cdm?00@0BDU9051@D01@D500DU9B0P1@D500101BDU80Bd];04];B`13@d<204Y:
BP04055AD@1?Cdl0Cdm?04m?C`<0CDe=0P1GEeL0101>CTh0?clo03lo?`1;Bd/206QXJ00409JFUP3<
c<`0c<c<0=?Cd`<0bl_;0P2QXJ40101ADE405aLG01LG5`0<30`200D51@040000000410@010@400H6
1P<01@D50`061PH200820P0000@01@D500410@010@4010@40P061PH0100820P01PH600H61P0410@3
00D51@800`<300@01@D500X:2P0:2PX01@D50P0410@0100:2PX01@D500D51@00000200L71`0400/;
2`071`L01`L700D51@800`<300@00P8200D51@051@D01@D50P0410@010071`L010@400@410051@D2
00H61P0400<30`092@T02@T900X:2P801@D500@01`L700l?3`0?3`l03@d=0P030`<300820P0400<3
0`0:2PX02PX:00D51@800P8200<010@400H61P061PH00`071`L300P8200400@410020P800P8200@4
10800@4110030`<200X:2P0400D51@010@400@4100@410801@D500@01PH600P8200820P00`<30P06
1PH010030`<01`L700L71`0=3@d200H61P0400`<300G5aL05aLG03<c<`80;bl_00@0<S8b02d];@0]
;Bd0:2PX0P0i>CT0100h>3P0:BTY02TY:@0B4Q8200X:2P04010@400=3@d03@d=00h>3P8051@D00@0
4A4A01@D500D51@0:2PX0P1TI6@0102?Shl0Vi^K09^KV`2IVIT209fMW@040:BTY02ZZZX0ZZZZ0:NW
Y`80VIVI00@0SXj>07UiN@1iNGT0ADE50P0K6a/0100I6AT0<30`030`<00c<c<2020P8004030`<01>
CTh0CTi>04I6AP80>c/k00@0@41003`l?00l?3`0ADE50P1EEED0101UIFD0J6QX06QXJ01ADE4304Y:
BP80DE5A00@0CDe=05]KF`1KFe/0DU9B0P16ATH0101BDU80CDe=04e=C@1BDU820451@@0404Q8B00e
=CD0=CDe04=3@`80EEEE00@0D51@059BDP1BDU80JFUY0P1_Kfl0101eMGD0F5QH05QHF01MGEd2079b
LP040820P01@D500D51@03Ph>080EUIF00@0BTY:04m?C`1?Cdl0Fe]K0P1:BTX0101?Cdl0@4100410
@00h>3P204e=C@0404Y:BP1<C4`0C4a<05YJFP80E5AD00@0?clo04=3@`13@d<0Fe]K0P0m?Cd0100Z
:RX0B4Q804Q8B01EEED20492@P04051@D01OGel0GemO05iNGP80H61P00@0F5QH05aLG01LG5`0IfMW
0P1YJFT0101=CDd0De=C05=CD`1[Jf/204a<C004069RHP1KFe/0Fe]K05UIF@80RXZ:00<0EUIF04];
B`1;Bd/00`1iNGT0101mOGd0Hf=S06=SH`1dM7@207YjNP040820P01QHF40HF5Q02DU9@80;bl_00@0
I6AT03Ph>00h>3P071`L0P0d=3@01014A4@0C4a<04a<C01@D50204Y:BP04051@D01ADE40DE5A04U9
B@80BTY:00@0C4a<04];B`1;Bd/0BDU90P11@D40101@D500Hf=S06=SH`1KFe/204m?C`0404Q8B01H
F5P0F5QH059BDP80?3`l00@0@4100492@P12@T80CDe=0P1?Cdl01019BDT0D51@051@D01BDU82051@
D004059BDP1;Bd/0Bd];04=3@`80BTY:00@0DE5A04m?C`1?Cdl0Cdm?0`1=CDd205MGE`0404i>CP0o
?cl0?clo04];B`80J6QX00@0UYJF0<c<c03<c<`0dm?C0`3;bl/20:6QX@04055AD@0G5aL05aLG00`<
30801@D500@0000000@4100410@01PH60`051@D300H61P800P82000010030`<010@400@410051@D2
00410@0400L71`061PH01PH600H61P8020P800@010@400D51@051@D01`L70P092@T010061PH01@D5
00D51@061PH300@410<01@D50P061PH0100410@01@D500D51@0>3Ph200/;2`0400D51@030`<00`<3
00<30`801`L700@01PH60000000000000P820P071`L0100:2PX02@T900T92@0;2`/200X:2P0400/;
2`0:2PX02PX:000000800P8200@01PH600@4100410@000000P030`<300@4100400D51@061PH01PH6
00T92@801PH600@01@D500@4100410@02PX:0P0820P010020P800`<300<30`020P8200P820040000
00020P800P8200<30`8010@40`030`<010020P800`<300<30`061PH200820P0400@410071`L01`L7
01HF5P80;Bd]00@0<S8b02l_;`0_;bl0<C4a0P0S8b<0100V9RH0>SXj03Xj>P0`<30201<C4`0400/;
2`0A4A404A4A00/;2`802PX:00@06ATI01HF5P0F5QH07AdM0P0E5AD01014A4@0T92@092@T02[Zj/2
09NGU`0408V9R@2QXJ40XJ6Q0:ZZZP80XJ6Q00@0WYjN09bLW02LW9`0WIfM0P2HV9P0101^KVh0@410
0410@00R8R8201@D500402TY:@0O7al07alO024Q8@80FEUI00@0EUIF04e=C@1=CDd0LW9b0P1ZJVX0
101DE5@0JVYZ06YZJP1[Jf/205EEE@0404Y:BP1@D500D51@069RHP80GemO00@0Cdm?06UYJ@1YJFT0
JVYZ0P1RHV80101bLW80JFUY06UYJ@1JFUX204m?C`0404a<C00k>c/0>c/k05mOG`80GUiN00@0EeMG
03Ti>@0i>CT0@4100P1<C4`305]KF`0405YJFP1VIVH0IVIV07QhN080Hf=S00@0DU9B055AD@1ADE40
?Shn0P0b<S801011@D40DU9B059BDP1IFET205ADE00404e=C@14A4@0A4A404e=C@80FUYJ00<0DU9B
055AD@1ADE400`18B4P0101TI6@0EEEE05EEE@18B4P207MgM`0407AdM019BDT0BDU904a<C080GUiN
00@0NWYj04a<C01<C4`0@4100P1>CTh0101BDU80M7Ad07AdM01IFET204E5A@0406ATI00h>3P0>3Ph
05]KF`80Lg=c00@0G5aL09>CT`2CTi<0Ng]k0P1@D500101RHV80Ti>C09>CT`2@T90207alO004055A
D@1RHV80HV9R0820P080Lg=c00@0:BTY01/K6`0K6a/0G5aL0P0e=CD0100M7Ad0>3Ph03Ph>01CDe<2
059BDP<0Cdm?00@0D51@04Q8B018B4P0BTY:0P1;Bd/0101@D500CTi>04i>CP19BDT203lo?`0404=3
@`1SHf<0Hf=S06EUI@80CTi>00@0BDU905EEE@1EEED0@D510P0f=SH01018B4P0Bd];04];B`1;Bd/3
04i>CP<0C4a<0P1=CDd404Y:BP80BDU900@0B4Q804M7A`17AdL0B4Q80P1:BTX0101>CTh0EEEE05EE
E@1@D50204=3@`0404Q8B01RHV80HV9R09NGU`80b<S800@0bl_;0<W9b@39bLT0`<300P2ATI401012
@T806QXJ01XJ6P0?3`l200<30`0400@410061PH01PH600<30`801PH600@010@40000000000001@D5
0P0;2`/0000300L71`061PH01PH600<00P8200@01`L700D51@051@D01@D50P071`L010030`<01@D5
00D51@051@D200820P0300@410051@D01@D500<00`<300@01PH600@4100410@00P820`061PH200D5
1@0400P820051@D01@D500D51@800P8200@00@4100d=3@0=3@d02`/;0P051@D00`0820P01@D500D5
1@0300@4100400D51@0410@010@400D51@801`L70`061PH00`030`<000000000000400@410800@41
00<00`<300L71`071`L00`0;2`/010051@D00`<300<30`0410@200L71`0400<30`071`L01`L700D5
1@<010@40P051@D01000000010@400@4100:2PX200820P04000000061PH01PH600D51@802@T900@0
10@400h>3P0>3Ph07AdM0P0f=SH0100];Bd0=SHf03Hf=P0^;Rh2020P800403Hf=P0g=cL0=cLg02PX
:0802PX:00@030`<00d=3@0=3@d03@d=0P0E5AD0100H61P071`L01`L700K6a/201hN7P04071`L02X
Z:P0Z:RX0:j^[P80UYJF00@0S8b<0:VYZ@2YZJT0Xj>S0P2BTY80102HV9P0Z:RX0:RXZ02YZJT209fM
W@0408>3P`1LG5`0G5aL03`l?080:2PX00@0<30`02TY:@0Y:BT06QXJ0P0o?cl0101JFUX0HF5Q065Q
H@1XJ6P206=SH`0405ADE01LG5`0G5aL05=CD`80Bd];00@0FUYJ061PH01PH600GEeM0P1UIFD0101L
G5`0D51@051@D01VIVH206a/K004065QH@1<C4`0C4a<02h^;P80DE5A00@0F5QH03<c<`0c<c<0G5aL
0P1UIFD0101OGel0<C4a034a<@0_;bl205IFEP<0LW9b00@0FUYJ065QH@1QHF40LG5a0P1GEeL01015
ADD0CTi>04i>CP13@d<2034a<@04051@D01UIFD0IFEU065QH@80F5QH00@0Fe]K04a<C01<C4`0G5aL
0P1TI6@0101LG5`0P8200820P01iNGT205IFEP<0H61P00@0FEUI07moO`1oOgl0L71`0P14A4@0100k
>c/0:b/[02/[:`1GEeL204a<C00405EEE@1DE5@0E5AD038b<P80E5AD00@0FEUI0410@010@400G5aL
0P1FEUH0101OGel0Jf][06][J`1NGUh207UiN@0406QXJ01CDe<0De=C05mOG`80T92@0`22PX80101S
Hf<0JVYZ06YZJP2@T90206e]K@0402d];@0?3`l03`l?04Y:BP80:BTY00@092@T04A4A014A4@0D51@
0P19BDT0101:BTX0C4a<04a<C01;Bd/204A4A0<0AdM700@0B4Q804];B`1;Bd/0C4a<0P10@400100n
?Sh0EeMG05MGE`1QHF4305EEE@80De=C00@0?Cdm03Lg=`0g=cL0B4Q80`1BDU8204U9B@0404Q8B01=
CDd0CDe=055AD@80DU9B00@0C4a<04U9B@19BDT0B4Q80P1:BTX0101<C4`0BTY:04Y:BP17AdL204I6
AP0404e=C@1?Cdl0Cdm?04M7A`80@d=300@0BTY:06UYJ@1YJFT0[jn_0P38b<P0102n_[h0a/K60<K6
aP32`/8208f=S@0403Ti>@0G5aL05aLG00l?3`801PH600@020P800D51@051@D01PH60P0410@01001
0@401@D500D51@092@T200L71`0000<01`L700H61P061PH00`020P8010071`L01@D500D51@051@D2
00L71`0400<30`051@D01@D500D51@800P8200<010@400D51@051@D00`030`<010061PH010@400@4
10020P8300H61P801@D500@020P800D51@051@D01@D50P020P8010010@403@d=00d=3@0;2`/200D5
1@0300P820051@D01@D500<010@400@01@D500@4100410@01@D50P071`L300H61P0300<30`000000
000000@010@40P010@400`030`<01`L700L71`0300/;2`0400D51@030`<00`<300@410801`L700@0
0`<300L71`071`L01@D50`0410@200D51@040000000410@010@400X:2P800P8200@0000000H61P06
1PH01@D50P092@T0100410@03Ph>00h>3P0M7Ad203Hf=P0402d];@0f=SH0=SHf02h^;P80820P00@0
=SHf03Lg=`0g=cL0:2PX0P0:2PX0100<30`03@d=00d=3@0=3@d201DE5@0401PH600L71`071`L01/K
6`807QhN00@0L71`0:RXZ02XZ:P0[Zj^0P2FUYH0102<S8`0ZJVY0:VYZ@2SXj<209:BTP0409RHV02X
Z:P0Z:RX0:VYZ@80WIfM00@0Ph>305aLG01LG5`0?3`l0P0X:2P0100`<300:BTY02TY:@0J6QX203lo
?`0405YJFP1QHF40HF5Q06QXJ080Hf=S00@0E5AD05aLG01LG5`0De=C0P1;Bd/0101JFUX0H61P061P
H01MGEd206EUI@0405aLG01@D500D51@06IVIP80K6a/00@0HF5Q04a<C01<C4`0;Rh^0P1ADE40101H
F5P0<c<c03<c<`1LG5`206EUI@0405mOG`0a<C40<C4a02l_;`80EUIF0`1bLW80101JFUX0HF5Q065Q
H@1aLG4205MGE`0404E5A@1>CTh0CTi>04=3@`80<C4a00@0D51@06EUI@1UIFD0HF5Q0P1HF5P0101K
Fe/0C4a<04a<C01LG5`206ATI00405aLG020P800P82007UiN@80EUIF0`1PH600101IFET0Ogmo07mo
O`1`L70204A4A00403/k>`0[:b/0:b/[05MGE`80C4a<00@0EEEE05ADE01DE5@0<S8b0P1DE5@0101I
FET0@4100410@01LG5`205IFEP0405mOG`1[Jf/0Jf][05iNGP80NGUi00@0J6QX05=CD`1CDe<0GemO
0P2@T90308:2PP0406=SH`1ZJVX0JVYZ092@T080KFe]00@0;Bd]00l?3`0?3`l0BTY:0P0Y:BT0100T
92@0A4A404A4A01@D50204U9B@0404Y:BP1<C4`0C4a<04];B`80A4A40`17AdL01018B4P0Bd];04];
B`1<C4`20410@00403hn?P1GEeL0EeMG065QH@<0EEEE0P1CDe<0100m?Cd0=cLg03Lg=`18B4P3059B
DP80BDU900@0B4Q804e=C@1=CDd0DE5A0P1BDU80101<C4`0BDU904U9B@18B4P204Y:BP0404a<C01:
BTX0BTY:04M7A`80ATI600@0CDe=04m?C`1?Cdl0AdM70P13@d<0101:BTX0JFUY06UYJ@2_[jl20<S8
b0040;jn_P36a/H0a/K60<;2`P80SHf=00@0>CTi01LG5`0G5aL03`l?0P061PH0100820P01@D500D5
1@061PH200@4100400410@051@D01@D500T92@801`L7000010051@D00`<300<30`030`<300L71`80
20P800@00`<300H61P061PH02@T90P061PH00`0410@01@D500D51@0400@410800@4100@02@T900P8
200820P010@40P061PH010030`<00@4100410@00000200820P0400H61P030`<00`<300D51@802PX:
0`071`L0100820P010@400@410030`<200820P0400410@030`<00`<300<30`<01PH60P030`<01008
20P02@T900T92@0410@200D51@04000000030`<00`<300T92@8020P800@02`/;00T92@092@T00`<3
0P00000010010@400`<300<30`0:2PX300/;2`801PH600<00`<300@4100410@00`020P800`071`L0
00000000000300@4100400/;2`0410@010@400H61P8061PH00<0:RXZ02HV9P0V9RH00`0];Bd0100R
8R80;2`/02`/;00i>CT202`/;00401hN7P0:2PX02PX:00P820801PH600@05ADE01TI6@0I6AT061PH
0P0U9BD0100?3`l0?clo03lo?`2HV9P20;>c/`040;6a/@2LW9`0W9bL09BDU080XZ:R0`2JVYX0102S
Xj<0[Zj^0:j^[P2WYjL209RHV00408N7Q`1RHV80HV9R03hn?P80=CDe00@0@41003/k>`0k>c/06a/K
0P0M7Ad01013@d<0EEEE05EEE@1DE5@205MGE`0403lo?`0d=3@0=3@d04M7A`80E5AD00@0IFEU06UY
J@1YJFT0BDU90P1BDU80101TI6@0BTY:04Y:BP1MGEd205aLG00404];B`1ADE40DE5A05QHF080L71`
00@0H61P02`/;00/;2`0AdM70P1TI6@0101=CDd0A4A404A4A015ADD204U9B@04069RHP1fMWH0MWIf
05mOG`80Bd];00@0H61P05ADE01DE5@0CTi>0P1SHf<0101[Jf/0HV9R069RHP1[Jf/205iNGP0405YJ
FP18B4P0B4Q803Ti>@80CDe=00@0LG5a05YJFP1JFUX0D51@0P1mOGd0101cLg<0GemO05mOG`1XJ6P2
065QH@0405UIF@1/K6`0K6a/061PH080ADE500@0C4a<03@d=00d=3@0De=C0P1ZJVX0101iNGT0D51@
051@D00e=CD306ATI080ADE500@0De=C079bLP1bLW80BTY:0P17AdL0101;Bd/0AdM704M7A`1=CDd2
05]KF`0404e=C@1@D500D51@04Q8B080HV9R00@0P82006e]K@1]KFd0R8R80P1VIVH0100l?3`030`<
00`<3011@D4201lO7`0402@T9017AdL0AdM704Y:BP80AdM700@0C4a<04e=C@1=CDd0CDe=0P16ATH0
1018B4P0C4a<04a<C015ADD20410@0<0@d=300@0AdM7051@D01@D500CDe=0P1>CTh0101LG5`0GemO
05mOG`1ADE4204Q8B00404A4A018B4P0B4Q804];B`<0A4A40P1;Bd/3051@D00404m?C`1;Bd/0Bd];
04E5A@80C4a<00@0DU9B04];B`1;Bd/0CTi>0P1?Cdl304a<C00404=3@`0o?cl0?clo04A4A080L71`
00@0_;bl0<K6aP36a/H0^KVi0P31`L40102o_kl0R8R808R8R00^;Rh200h>3P0400`<300:2PX02PX:
00H61P<01@D50P071`L0100=3@d030`<00`<300820P200<30`0000@0000000<30`030`<020P80P04
10@010051@D01`L700L71`030`<200D51@0400T92@020P800P8200H61P8030`<00@01@D500@41004
10@00`<30P051@D300T92@0400D51@0410@010@400L71`8010@40`0820P0100410@00P8200820P06
1PH200L71`0300820P061PH01PH600<010@400<02@T900P8200820P00`0410@010030`<01@D500D5
1@0410@200820P0400H61P071`L01`L700@410801`L700@010@400P8200820P02@T90P0410@01006
1PH010@400@4100410@200H61P<02PX:00@03Ph>00P8200820P01@D50P0820P010071`L00`<300<3
0`0410@200820P0400D51@0410@010@400820P800@410`061PH0100;2`/06a/K01/K6`0/;2`202d]
;@04034a<@0Q8B408B4Q02HV9P80>CTi00@0?Cdm02PX:00X:2P02@T90P0820P0100410@02`/;00/;
2`0D51@201DE5@04028R8P0F5QH05QHF028R8P80M7Ad00@0[Jf]0;>c/`2c/k<0/;2`0P2OWil0102H
V9P0XZ:R0::RXP2RXZ820:RXZ0<0YZJV00@0V9RH09VIV@2IVIT0Shn?0P1]KFd0101HF5P0@D510451
@@0f=SH203@d=00401/K6`0M7Ad07AdM03Ti>@80<S8b00@0CDe=06IVIP1VIVH0EeMG0P10@400101<
C4`0GEeM05eMG@1;Bd/2051@D00404=3@`1GEeL0EeMG06][J`80CDe=00@0Cdm?059BDP1BDU80Bd];
0P1IFET0101^KVh0IfMW06MWI`19BDT203lo?`0405=CD`1DE5@0E5AD0492@P80L71`00@0P820069R
HP1RHV80HF5Q0P1gMgL0101NGUh0=SHf03Hf=P1KFe/205mOG`0405YJFP1GEeL0EeMG06EUI@80CDe=
00@0>c/k055AD@1ADE40J6QX0P1FEUH0100m?Cd0ATI604I6AP1NGUh204a<C00304M7A`1NGUh0GUiN
00<0EUIF00@0IFEU075aL@1aLG40K6a/0P1LG5`0101KFe/0IVIV06IVIP1aLG4204i>CP0405ADE01Q
HF40HF5Q0820P080H61P00@0@41005UIF@1IFET0H61P0P1VIVH0101GEeL0CTi>04i>CP0h>3P205=C
D`0404U9B@10@400@41006][J`80P82000@0DE5A03/k>`0k>c/0EeMG0P1fMWH0101bLW80HV9R069R
HP1UIFD204Y:BP040451@@0N7Qh07QhN04e=C@806QXJ00@092@T0410@010@400AdM70P1=CDd0101B
DU80EUIF05IFEP1<C4`20492@P0404Y:BP1=CDd0CDe=04];B`80ADE500@0?clo04E5A@15ADD0C4a<
0P19BDT01018B4P0BTY:04Y:BP1NGUh206EUI@0405YJFP1=CDd0CDe=04E5A@80BDU90`17AdL0101:
BTX0BDU904U9B@18B4P204];B`<0BDU900@0AdM704I6AP16ATH0C4a<0P17AdL0101:BTX0Bd];04];
B`13@d<204a<C00404i>CP10@400@41004A4A080NGUi00@0^KVi0<30`030`<00^KVi0P2e]KD0102T
Y:@0K6a/06a/K00P820200X:2P0300T92@0410@010@400<00P8200@01@D500L71`071`L01PH60P0:
2PX100P820401PH60@061PH00004000000030`<00`<300P8208010@400@01@D500L71`071`L00`<3
0P051@D010092@T00P8200820P061PH200`<300400D51@0410@010@400<30`801@D50`092@T01005
1@D010@400@410071`L200@410<020P800@010@400820P020P801PH60P071`L00`020P801PH600H6
1P0300@4100300T92@0820P020P800<010@400@00`<300D51@051@D010@40P020P8010061PH01`L7
00L71`0410@200L71`0400@4100820P020P800T92@8010@400@01PH600@4100410@010@40P061PH3
00X:2P0400h>3P0820P020P800D51@8020P800@01`L700<30`030`<010@40P020P8010051@D010@4
00@410020P8200410@<01PH600@02`/;01/K6`0K6a/0;2`/0P0];Bd0100a<C408B4Q024Q8@0V9RH2
03Ti>@0403dm?@0X:2P0:2PX00T92@8020P800@010@400/;2`0;2`/051@D0P0E5AD0100R8R805QHF
01HF5P0R8R8207AdM0040:f][@2c/k<0/k>c0;2`/080WinO00@0V9RH0::RXP2RXZ80XZ:R0P2XZ:P3
0:JVYP0409RHV02IVIT0VIVI08n?S`80KFe]00@0F5QH0451@@11@D40=SHf0P0d=3@0100K6a/07AdM
01dM7@0i>CT2038b<P0404e=C@1VIVH0IVIV05MGE`80@41000@0C4a<05eMG@1MGEd0Bd];0P1@D500
1013@d<0EeMG05MGE`1[Jf/204e=C@0404m?C`1BDU80DU9B04];B`80FEUI00@0KVi^06MWI`1WIfL0
BDU90P0o?cl0101CDe<0E5AD05ADE012@T82071`L0040820P01RHV80HV9R065QH@80MgMg00@0GUiN
03Hf=P0f=SH0Fe]K0P1OGel0101JFUX0EeMG05MGE`1UIFD204e=C@0403/k>`1ADE40DE5A06QXJ080
EUIF00@0?Cdm04I6AP16ATH0GUiN0P1<C4`00`17AdL0GUiN05iNGP0305IFEP0406EUI@1aLG40LG5a
06a/K080G5aL00@0Fe]K06IVIP1VIVH0LG5a0P1>CTh0101DE5@0HF5Q065QH@20P802061PH0040410
@01IFET0FEUI061PH080IVIV00@0EeMG04i>CP1>CTh0>3Ph0P1CDe<01019BDT0@4100410@01[Jf/2
0820P004055AD@0k>c/0>c/k05MGE`80MWIf00@0LW9b069RHP1RHV80IFEU0P1:BTX01011@D407QhN
01hN7P1=CDd201XJ6P0402@T9010@400@41004M7A`80CDe=00@0DU9B05IFEP1FEUH0C4a<0P12@T80
101:BTX0CDe=04e=C@1;Bd/204E5A@0403lo?`15ADD0ADE504a<C080BDU900@0B4Q804Y:BP1:BTX0
GUiN0P1UIFD0101JFUX0CDe=04e=C@15ADD204U9B@<0AdM700@0BTY:04U9B@19BDT0B4Q80P1;Bd/3
04U9B@0404M7A`16ATH0ATI604a<C080AdM700@0BTY:04];B`1;Bd/0@d=30P1<C4`0101>CTh0@410
0410@014A4@207UiN@040;Vi^@30`<00`<300;Vi^@80]KFe00@0Y:BT06a/K01/K6`0820P0P0:2PX0
0`092@T010@400@4100300820P0400D51@071`L01`L700H61P802PX:0@0820P100H61P401PH60000
10051@D01PH600H61P030`<200@4100400/;2`071`L01`L700L71`8020P800@01@D500L71`071`L0
1PH60P0820P010071`L01@D500D51@061PH300@410<01@D51@061PH300`<300300D51@030`<00`<3
00@010@40P051@D010010@401@D500D51@0B4Q8200h>3P0400H61P030`<00`<300820P801@D500@0
1PH600820P020P800@410P0410@300L71`0400<30`071`L01`L700H61P800`<300@01PH600L71`07
1`L01`L70P0:2PX300@4100400H61P0410@010@400820P8020P800@04Q8B00d=3@0=3@d01`L70P08
20P010061PH01@D500D51@00000200L71`0400@410030`<00`<3010@40809BDU00@0<c<c030`<00`
<300:RXZ0P0_;bl0100o?cl0=CDe03De=@0l?3`2020P800400L71`061PH01PH600L71`802`/;00@0
2PX:01TI6@0I6AT08R8R0P0:2PX0101<C4`0UiNG09NGU`2[Zj/30;>c/`80X:2P00@0TI6A09nOW`2O
Wil0YZJV0P2TY:@00`2OWil0ZZZZ0:ZZZP030:2PX00409fMW@1fMWH0MWIf05QHF080<S8b00@07alO
02l_;`0_;bl061PH0P0D51@0100[:b/0:BTY02TY:@1:BTX205YJFP0405eMG@1?Cdl0Cdm?04a<C080
F5QH00@0>CTi04Y:BP1:BTX0DU9B0P1RHV801019BDT08b<S02<S8`13@d<205YJFP0404M7A`0o?cl0
?clo061PH080EeMG00@0IfMW08>3P`23Ph<0HF5Q0P1GEeL0101OGel0DE5A055AD@1RHV8207AdM004
061PH01GEeL0EeMG02/[:`80ATI600@0TI6A07=cL`1cLg<0EUIF0P15ADD0101CDe<0CTi>04i>CP0f
=SH204I6AP0405EEE@18B4P0B4Q804I6AP80AdM700@0EEEE059BDP1BDU80BDU90`1?Cdl205QHF004
069RHP1]KFd0KFe]061PH080DU9B00@0Hf=S07MgM`1gMgL0MGEe0P16ATH0100o?cl0EeMG05MGE`1b
LW8205=CD`0403dm?@1@D500D51@05ADE080DE5A00@0Bd];04a<C01<C4`0CTi>0P1PH6001017AdL0
@d=304=3@`1GEeL205mOG`0406EUI@1PH600H61P05UIF@80J6QX0`1NGUh01012@T80?3`l03`l?00W
9bL20451@@04051@D00O7al07alO02DU9@80?3`l00@0ADE504M7A`17AdL0CDe=0P1HF5P0101BDU80
ADE504E5A@19BDT304E5A@80AdM700@0ADE504=3@`13@d<0@D510P0i>CT01016ATH0AdM704M7A`1D
E5@206QXJ00406=SH`1;Bd/0Bd];04A4A080C4a<0`17AdL304Y:BP0404i>CP1HF5P0F5QH04a<C080
@T9200@0BDU904I6AP16ATH0BDU90P1;Bd/01016ATH0B4Q804Q8B01=CDd205=CD`0404e=C@10@400
@41004i>CP80Ng]k00@0/;2`0;bl_02l_;`0^;Rh0P2k^k/0102PX:00FEUI05UIF@0Q8B42018B4P04
00P820010@400@4100L71`801PH60`00000010030`<01`L700L71`0410@200H61P0000@01@D500H6
1P061PH00P820`0820P200@4100300D51@061PH01PH600<01PH600@00P8200D51@051@D01`L70P03
0`<010061PH00`<300<30`020P8300H61P801@D500@01PH600@4100410@01PH60P0:2PX010092@T0
10@400@410010@4200D51@0400P8200410@010@400<30`<02@T90P061PH0100:2PX01PH600H61P03
0`<200L71`0400@410020P800P82000000800@4100@00`<300@4100410@010@40P020P8010061PH0
1@D500D51@061PH200T92@<01PH600@0000000P8200820P01@D50P00000300<30`0400T92@0:2PX0
2PX:00X:2P802@T900@01PH600<30`030`<020P80P071`L010010@4010@400@4100Q8B4202TY:@04
03Ph>00W9bL09bLW01hN7P80=cLg00@0ATI602l_;`0_;bl0=3@d0P0C4a<010051@D00@4100410@0>
3Ph2018B4P0401<C4`0P8200820P00l?3`8071`L00@0LG5a0:JVYP2VYZH0YZJV0P2d];@0102`/;00
W9bL09bLW02?Shl209nOW`040::RXP2FUYH0UYJF09VIV@80ZJVY00@0XZ:R09BDU02DU9@0WYjN0P2F
UYH0101WIfL0<30`030`<00c<c<20492@P0402@T900I6AT06ATI01XJ6P80<30`00@0ADE504U9B@19
BDT0ATI60P1GEeL0101TI6@0De=C05=CD`1>CTh206ATI00404E5A@10@400@41004a<C080?Shn00@0
Fe]K06YZJP1ZJVX0Fe]K0P1LG5`0101nOWh0EeMG05MGE`1_Kfl2092@T00405=CD`1VIVH0IVIV07Ui
N@80?Shn00@0F5QH07EeM@1eMGD0GemO0P1DE5@00`0Q8B40:b/[02/[:`03075aL@0407QhN01ZJVX0
JVYZ06QXJ080PH6100@0F5QH04I6AP16ATH0H61P0P19BDT01010@400Cdm?04m?C`1ADE42051@D004
05iNGP1LG5`0G5aL04U9B@80C4a<00@0GUiN06a/K01/K6`0EEEE0P1@D500101NGUh0J6QX06QXJ01^
KVh204m?C`0405QHF01_Kfl0Kfm_06IVIP80CTi>00@0CDe=05MGE`1GEeL0EEEE0P0e=CD01010@400
Fe]K05]KF`1>CTh204Y:BP04055AD@1;Bd/0Bd];05=CD`80>CTi00@0?Cdm03/k>`0k>c/0B4Q80P17
AdL0100g=cL0>CTi03Ti>@0P820202<S8`0403`l?01gMgL0MgMg04Q8B080;2`/00@0<c<c03Xj>P0j
>SX0@D510P16ATH0101<C4`0DU9B059BDP1KFe/2055AD@0404M7A`10@400@41004E5A@80BTY:00@0
D51@04e=C@1=CDd0?clo0P0b<S801015ADD0@d=304=3@`1;Bd/207AdM00406IVIP10@400@4100410
@080Bd];0`1<C4`01017AdL0ADE504E5A@1<C4`205ADE00404a<C018B4P0B4Q804U9B@80AdM700@0
BDU904a<C01<C4`0ATI60P1;Bd/0101DE5@0Cdm?04m?C`13@d<20410@00404m?C`20P800P8200;:b
/P80/k>c00@0];Bd0<?3``33`l<0[:b/0P1MGEd0100Q8B403`l?00l?3`061PH2000000H01`L700@0
0P8200H61P061PH020P80P0410@0000400D51@061PH01PH600820P<020P80P0410@00`051@D01PH6
00H61P0300H61P0400820P051@D01@D500L71`800`<300@01PH600<30`030`<00P820`061PH200D5
1@0400H61P0410@010@400H61P802PX:00@02@T900@4100410@00@410P051@D0100820P010@400@4
10030`<300T92@801PH600@02PX:00H61P061PH00`<30P071`L0100410@00P8200820P0000020041
0@0400<30`0410@010@400@410800P8200@01PH600D51@051@D01PH60P092@T300H61P0400000008
20P020P800D51@8000000`030`<010092@T02PX:00X:2P0:2PX200T92@0400H61P030`<00`<300P8
20801`L700@00@4100@4100410@08B4Q0P0Y:BT0100h>3P09bLW02LW9`0N7Qh203Lg=`0404I6AP0_
;bl0;bl_03@d=0804a<C00@01@D500410@010@403Ph>0P0B4Q80100C4a<0820P020P800?3`l201`L
7004075aL@2VYZH0YZJV0:JVYP80];Bd00@0/;2`09bLW02LW9`0Shn?0P2OWil0102RXZ80UYJF09JF
UP2IVIT20:VYZ@040::RXP2DU9@0U9BD09jNWP80UYJF00@0IfMW030`<00`<300<c<c0P12@T80100T
92@06ATI01TI6@0J6QX2030`<00404E5A@19BDT0BDU904I6AP80EeMG00@0I6AT05=CD`1CDe<0CTi>
0P1TI6@01015ADD0@4100410@01<C4`203hn?P0405]KF`1ZJVX0JVYZ05]KF`80G5aL00@0OWin05MG
E`1GEeL0Kfm_0P2@T900101CDe<0IVIV06IVIP1iNGT203hn?P0405QHF01eMGD0MGEe05mOG`80E5AD
00<08B4Q02/[:`0[:b/00`1aLG40101hN7P0JVYZ06YZJP1XJ6P20861P@0405QHF016ATH0ATI6061P
H080BDU900@0@41004m?C`1?Cdl0DE5A0P1@D500101NGUh0G5aL05aLG019BDT204a<C00405iNGP1/
K6`0K6a/05EEE@80D51@00@0GUiN06QXJ01XJ6P0KVi^0P1?Cdl0101HF5P0Kfm_06m_K`1VIVH204i>
CP0404e=C@1GEeL0EeMG05EEE@80=CDe00@0@41005]KF`1KFe/0CTi>0P1:BTX0101ADE40Bd];04];
B`1CDe<203Ti>@0403dm?@0k>c/0>c/k04Q8B080AdM700@0=cLg03Ti>@0i>CT0820P0P0S8b<0100l
?3`0MgMg07MgM`18B4P202`/;00403<c<`0j>SX0>SXj0451@@80ATI600@0C4a<059BDP1BDU80Fe]K
0P1ADE401017AdL0@4100410@015ADD204Y:BP04051@D01=CDd0CDe=03lo?`80<S8b00@0ADE504=3
@`13@d<0Bd];0P1dM7@0101VIVH0@4100410@010@40204];B`<0C4a<00@0AdM704E5A@15ADD0C4a<
0P1DE5@0101<C4`0B4Q804Q8B019BDT204M7A`0404U9B@1<C4`0C4a<04I6AP80Bd];00@0E5AD04m?
C`1?Cdl0@d=30P10@400101?Cdl0P8200820P02b/[820;>c/`040;Bd]033`l<0`l?30:b/[080GEeM
00@08B4Q00l?3`0?3`l01PH60P00000600L71`0400820P061PH01PH600P8208010@40000100410@0
1`L700L71`0820P200@4100300L71`061PH01PH600<00P8200<010@400820P020P800`020P801004
10@00`<300<30`010@4200<30`H01@D500@020P800<30`030`<000000P030`<010061PH00P820082
0P061PH200L71`0400P8200;2`/02`/;00T92@802PX:00@00`<300D51@051@D01`L70P061PH300<3
0`H00P8200<010@400H61P061PH00`030`<300410@0400H61P0=3@d03@d=00820P800@4100@010@4
00P8200820P01PH61@010@400`051@D00`<300<30`0300D51@0400820P030`<00`<300@410801`L7
00@00`<301TI6@0I6AT0?3`l0P0^;Rh0100W9bL07QhN01hN7P0Q8B4202d];@0403Ph>00a<C40<C4a
02HV9P802PX:00@010@400P8200820P03Ph>0P0?3`l0100F5QH05ADE01DE5@0@410203`l?00408V9
R@2WYjL0YjNW0:2PX080/[:b00@0Zj^[09RHV02HV9P0TI6A0P2MWId0102NWYh0UYJF09JFUP2JVYX2
09fMW@040:BTY02PX:00X:2P09:BTP80U9BD00@0O7al04Y:BP1:BTX0ATI60P14A4@0100X:2P092@T
02@T900S8b<2030`<00403lo?`17AdL0AdM704E5A@80GEeM00<0NWYj05eMG@1MGEd00`1PH600100W
9bL0@D510451@@1YJFT205]KF`0406m_K`1YJFT0JFUY06EUI@80O7al00@0M7Ad05]KF`1KFe/0K6a/
0P1ZJVX0101BDU80DE5A055AD@1VIVH203hn?P0405UIF@1RHV80HV9R061PH080Ng]k00@0AdM701TI
6@0I6AT0C4a<0P17AdL0101;Bd/0JFUY06UYJ@1RHV8205iNGP<0?clo00@0F5QH0492@P12@T80?Shn
0P1VIVH0101GEeL0EEEE05EEE@27QhL2075aL@0404=3@`1BDU80DU9B06IVIP80De=C00@0?Shn04a<
C01<C4`0CDe=0P1FEUH0101QHF40?clo03lo?`19BDT206ATI00405MGE`1CDe<0De=C04E5A@80BTY:
00@0HV9R03hn?P0n?Sh0>CTi0P1ADE401016ATH0>c/k03/k>`0n?Sh203Xj>P0404Q8B00k>c/0>c/k
02`/;0804a<C00@0;2`/020P800P8200<c<c0P0O7al0100V9RH0@d=304=3@`1fMWH208>3P`0403dm
?@0Z:RX0:RXZ02/[:`80=cLg00@0ATI604Y:BP1:BTX0D51@0P1?Cdl0101>CTh0CDe=04e=C@1ADE42
04Y:BP0404];B`1=CDd0CDe=051@D080De=C00@0@T9202`/;00/;2`0@4100P0o?cl0101=CDd0M7Ad
07AdM01KFe/203lo?`0404=3@`1?Cdl0Cdm?04m?C`80B4Q800@0ATI604U9B@19BDT0C4a<0`1>CTh2
04];B`0404Q8B017AdL0AdM704Q8B080BDU900@0@T9204Y:BP1:BTX0C4a<0P1:BTX0101<C4`0CDe=
04e=C@1;Bd/207emO@040;6a/@2c/k<0/k>c0;Zj^P80`/;200@0YjNW05iNGP1NGUh05QHF0P020P80
0`071`L00`<300<30`0300H61P0300L71`0;2`/02`/;00<00`<30@071`L100820P400P82000400@4
10801@D500@010@400H61P061PH00P820P0820P0100<30`01@D500D51@071`L200410@0300D51@04
10@010@400<010@400@01`L700D51@051@D00`<30P0410@010030`<010@400@410071`L200P82004
00D51@061PH01PH600820P8010@40`061PH010071`L020P800P8200410@200L71`04000000030`<0
0`<300L71`801PH600@00@4100D51@051@D01@D50P061PH010092@T01`L700L71`051@D200820P04
00P820051@D01@D500H61P801`L700@00@4100<30`030`<01PH60P092@T010030`<01`L700L71`00
000200410@@010@40P051@D010030`<00P8200820P030`<200D51@04010@400W9bL09bLW03@d=080
:RXZ00@09RHV03Lg=`0g=cL0=cLg0P0U9BD0100i>CT0>SXj03Xj>P0?3`l200d=3@0400l?3`0;2`/0
2`/;00h>3P803`l?00@04a<C014A4@0A4A40:BTY0P1LG5`0102GUiL0XJ6Q0:6QX@2TY:@20;>c/`04
0:VYZ@2BTY80TY:B08Z:RP80VYZJ00@0X:2P0:6QX@2QXJ40Z:RX0P2WYjL0102[Zj/0YJFU0:FUY@2;
Rh/208J6QP0408:2PP1]KFd0KFe]065QH@80A4A400@06QXJ01PH600H61P0:2PX0P0d=3@0100i>CT0
AdM704M7A`1EEED206EUI@0406e]K@17AdL0AdM704=3@`80FEUI00<08R8R03Lg=`0g=cL00`1OGel0
101gMgL0H61P061PH01OGel208N7Q`0407=cL`1dM7@0M7Ad07EeM@80I6AT00@0K6a/04a<C01<C4`0
EeMG0P0l?3`01019BDT0E5AD05ADE01<C4`2061PH00404m?C`0g=cL0=cLg05MGE`80HF5Q00@0E5AD
071`L01`L700Jf][0P1?Cdl0100n?Sh0>SXj03Xj>P0d=3@203De=@0403Ph>01KFe/0Fe]K05mOG`80
GUiN00@0PX:206][J`1[Jf/0>c/k0P1DE5@0101TI6@0?Cdm03dm?@0k>c/20492@P0403Ti>@1<C4`0
C4a<04Y:BP80>CTi00@0>3Ph04a<C01<C4`0BDU90P1<C4`01010@400;bl_02l_;`13@d<2038b<P04
02l_;`1:BTX0BTY:03Hf=P8071`L00@0;Bd]030`<00`<3008R8R0P0X:2P0100Z:RX04Q8B018B4P0J
6QX200D51@04010@400b<S80<S8b065QH@80JFUY00@0NWYj06IVIP1VIVH0=3@d0P0X:2P0100R8R80
=SHf03Hf=P1<C4`204I6AP04055AD@1@D500D51@04Q8B080BTY:00<0EeMG055AD@1ADE400`1<C4`3
04Q8B00404=3@`0m?Cd0?Cdm03`l?080=cLg00@0EUIF07UiN@1iNGT0G5aL0P15ADD01019BDT0De=C
05=CD`1ADE4204Q8B00404];B`1@D500D51@04i>CP80D51@00@0CDe=04A4A014A4@0AdM70P1=CDd0
1014A4@0?Shn03hn?P15ADD204m?C`0404];B`15ADD0ADE504=3@`80AdM700@0BTY:07=cL`1cLg<0
Xj>S0P2m_Kd01037alL0_kno0;no_`2HV9P204a<C00400h>3P0410@010@400P8208010@400@00P82
00T92@092@T00`<30P0:2PX010092@T01`L700L71`061PH200410@00100410@200D51@0400@41006
1PH01PH600820P8020P800@030`<00D51@051@D01`L70P010@400`051@D010@400@4100300@41004
00L71`051@D01@D500<30`8010@400@00`<300@4100410@01`L70P0820P010051@D01PH600H61P02
0P8200@410<01PH600@01`L700P8200820P010@40P071`L0100000000`<300<30`071`L200H61P04
00410@051@D01@D500D51@801PH600@02@T900L71`071`L01@D50P020P80100820P01@D500D51@06
1PH200L71`0400410@030`<00`<300H61P802@T900@00`<300L71`071`L000000P010@4400@41080
1@D500@00`<300820P020P800`<30P051@D0100@41009bLW02LW9`0d=3@202XZ:P0402HV9P0g=cL0
=cLg03Lg=`809BDU00@0>CTi03Xj>P0j>SX03`l?0P0=3@d0100?3`l02`/;00/;2`0>3Ph200l?3`04
01<C4`0A4A404A4A02TY:@80G5aL00@0UiNG0:6QX@2QXJ40Y:BT0P2c/k<0102YZJT0TY:B09:BTP2:
RXX209ZJVP040:2PX02QXJ40XJ6Q0:RXZ080YjNW00@0Zj^[0:FUY@2UYJD0Rh^;0P26QXH01022PX80
KFe]06e]K@1QHF4204A4A00401XJ6P0H61P061PH02PX:080=3@d00@0>CTi04M7A`17AdL0EEEE0P1U
IFD0101]KFd0AdM704M7A`13@d<205UIF@03028R8P0g=cL0=cLg00<0GemO00@0MgMg061PH01PH600
GemO0P27QhL0101cLg<0M7Ad07AdM01eMGD206ATI00406a/K01<C4`0C4a<05MGE`80?3`l00@0BDU9
05ADE01DE5@0C4a<0P1PH600101?Cdl0=cLg03Lg=`1GEeL2065QH@0405ADE01`L700L71`06][J`80
Cdm?00@0?Shn03Xj>P0j>SX0=3@d0P0e=CD0100h>3P0Fe]K05]KF`1OGel205iNGP0408:2PP1[Jf/0
Jf][03/k>`80E5AD00@0I6AT03dm?@0m?Cd0>c/k0P12@T80100i>CT0C4a<04a<C01:BTX203Ti>@04
03Ph>01<C4`0C4a<04U9B@80C4a<00@0@41002l_;`0_;bl0@d=30P0b<S80100_;bl0BTY:04Y:BP0f
=SH201`L700402d];@0`<300<30`028R8P80:2PX00@0:RXZ018B4P0B4Q806QXJ0P051@D0100@4100
<S8b038b<P1QHF4206UYJ@0407YjNP1VIVH0IVIV03@d=080:2PX00@08R8R03Hf=P0f=SH0C4a<0P16
ATH0101ADE40D51@051@D018B4P204Y:BP0305MGE`1ADE40DE5A00<0C4a<0`18B4P01013@d<0?Cdm
03dm?@0l?3`203Lg=`0405IFEP1iNGT0NGUi05aLG080ADE500@0BDU905=CD`1CDe<0DE5A0P18B4P0
101;Bd/0D51@051@D01>CTh2051@D00404e=C@14A4@0A4A404M7A`80CDe=00@0A4A403hn?P0n?Sh0
ADE50P1?Cdl0101;Bd/0ADE504E5A@13@d<204M7A`0404Y:BP1cLg<0Lg=c0:>SX`80_Kfm00@0alO7
0;no_`2o_kl0V9RH0P1<C4`0100>3Ph010@400@4100820P200@4100400820P092@T02@T900<30`80
2PX:00@02@T900L71`071`L01PH60P010@40000400P820071`L01`L700@410801@D500@010@400<3
0`030`<01@D50`0<30`300L71`803Ph>00@010@400820P020P802@T90P071`L300820P0400D51@03
0`<00`<300820P<02@T90P061PH010051@D020P800P8200:2PX200H61P0400D51@030`<00`<30082
0P800`<300@01@D500H61P061PH00P820P00000010030`<010@400@410020P8200<30`0400820P07
1`L01`L700L71`801@D500@020P800<30`030`<020P80P061PH400D51@80000000@00P8200H61P06
1PH00`<31@0820P00`020P800@4100410@0300410@0400L71`0;2`/02`/;00@41080000000@04Q8B
02d];@0];Bd0;bl_0P0g=cL0100c<c<0>3Ph03Ph>00b<S8202@T900403Hf=P0X:2P0:2PX00P82080
1`L700@03@d=00H61P061PH02PX:0`0>3Ph201dM7@040492@P1dM7@0M7Ad09bLW080X:2P00@0ZZZZ
0:b/[02/[:`0VYZJ0P2=SHd01029RHT0UIFE09FEU@2LW9`209jNWP040:FUY@2`/;00/;2`0:NWY`80
Ti>C00@0TY:B09NGU`2GUiL0SXj>0P1lO7`0101iNGT0IFEU06EUI@0`<30200X:2P0401HF5P0];Bd0
;Bd]02XZ:P80@T9200@0DU9B05eMG@1MGEd0A4A40P12@T801018B4P0ATI604I6AP0T92@203Ti>@04
051@D01XJ6P0J6QX09FEU@80QXJ600@0LW9b06e]K@1]KFd0Lg=c0P1YJFT0101WIfL0L71`071`L01_
Kfl2051@D00404i>CP1FEUH0EUIF06m_K`80L71`00@0DE5A038b<P0b<S80<S8b0P11@D401016ATH0
HF5Q065QH@1EEED204i>CP04059BDP1SHf<0Hf=S06UYJ@80EeMG00@0ATI604U9B@19BDT0>3Ph0P0n
?Sh0101;Bd/0CTi>04i>CP1GEeL2051@D00403Ti>@1:BTX0BTY:05QHF080>CTi00@0@41003@d=00d
=3@0=3@d0P1;Bd/0100_;bl0:BTY02TY:@0e=CD2030`<0<0;2`/00@0?Shn02HV9P0V9RH09RHV0`0a
<C4203Ph>00402/[:`0Q8B408B4Q03Hf=P80;Rh^00@061PH00/;2`0;2`/03@d=0P0<30`010010@40
5QHF01HF5P1?Cdl206e]K@04079bLP1[Jf/0Jf][06e]K@80G5aL00@0;bl_02<S8`0S8b<09RHV0P0k
>c/0101DE5@0CDe=04e=C@1CDe<204i>CP0404e=C@1>CTh0CTi>04a<C080A4A400@0Bd];04i>CP1>
CTh0ATI60P18B4P01017AdL0ATI604I6AP10@40203Ph>004059BDP1_Kfl0Kfm_055AD@80@41000@0
@d=304M7A`17AdL0ADE50P19BDT0101=CDd0Bd];04];B`1>CTh3059BDP80CDe=00@0A4A404Q8B018
B4P0B4Q80P0h>3P01010@400C4a<04a<C01@D50204M7A`0403dm?@0n?Sh0?Shn04a<C080NWYj00@0
WinO0;bl_02l_;`0a/K60P2_[jl01023Ph<0>SXj03Xj>P0D51@200T92@0300D51@0410@010@400<0
0`<300@00@4100<30`030`<02`/;0P092@T100L71`400P820@020P80000400D51@061PH01PH600<3
0`<01`L70P051@D0100;2`/030`<00`<300410@200D51@0400L71`0;2`/02`/;00H61P800@4100@0
0P8200<30`030`<010@40P051@D300@4100400D51@030`<00`<300<30`8010@400@02@T900P82008
20P010@40P0820P010092@T01PH600H61P0410@200P820<01@D500@01`L700H61P061PH01PH60P01
0@4010020P801@D500D51@051@D200@4100400410@020P800P8200@410801@D500@00P8200@41004
10@010@40P030`<010071`L020P800P820051@D200@4100400D51@092@T02@T900/;2`802PX:00@0
0P8200@4100410@00`<30P071`L400H61P801`L700@05QHF030`<00`<300:BTY0P0Z:RX0100g=cL0
>CTi03Ti>@0j>SX203/k>`0403Xj>P0K6a/06a/K00d=3@802@T900@0410@00<30`030`<01@D50P03
0`<0100=3@d0;2`/02`/;01LG5`20820P0<0Vi^K00@0XZ:R0:VYZ@2YZJT0U9BD0P23Ph<0101nOWh0
RXZ:08Z:RP2KVi/20::RXP040:FUY@2QXJ40XJ6Q08n?S`80TY:B00@0WinO0::RXP2RXZ80Y:BT0P2D
U9@0101jNWX0K6a/06a/K01QHF4203Lg=`0401HF5P0I6AT06ATI01lO7`80<S8b00@0CDe=055AD@1A
DE40>CTi0P10@400100/;2`0820P020P8010@402079bLP0407=cL`1aLG40LG5a08>3P`80PX:200@0
Ogmo05eMG@1MGEd0J6QX0P1JFUX0101SHf<0HV9R069RHP19BDT204];B`0405=CD`1<C4`0C4a<05QH
F080D51@00@0GEeM0451@@11@D40<30`0P0^;Rh0100l?3`0D51@051@D00m?Cd204a<C004059BDP1F
EUH0EUIF05UIF@80Bd];00@0ADE50410@010@400:b/[0P0n?Sh0101<C4`0BTY:04Y:BP12@T820410
@00403Ph>00a<C40<C4a03Hf=P80;Bd]00@0:BTY01@D500D51@04A4A0P0Z:RX0100M7Ad06ATI01TI
6@0S8b<200h>3P0401PH600A4A404A4A02LW9`80;2`/00@0;Rh^038b<P0b<S808R8R0P0F5QH0100@
410030`<00`<300A4A4201@D500401DE5@071`L01`L700L71`809BDU00@0>SXj05YJFP1JFUX0O7al
0P1`L700101YJFT0Lg=c07=cL`1dM7@206=SH`0403@d=00V9RH09RHV02`/;080AdM700@0E5AD04e=
C@1=CDd0D51@0P1:BTX0101;Bd/0CTi>04i>CP1<C4`204i>CP04055AD@1=CDd0CDe=04M7A`80CDe=
00@0B4Q80492@P12@T80?Cdm0P0];Bd0101>CTh0Hf=S06=SH`1ADE4204U9B@<0@d=300@0BDU904i>
CP1>CTh0ADE50P10@400101<C4`0EEEE05EEE@1HF5P2059BDP0404U9B@1;Bd/0Bd];04e=C@80@T92
00@0A4A404e=C@1=CDd0EEEE0P1@D5001010@400>c/k03/k>`1=CDd208B4Q0040:RXZ02g]kL0]kNg
0<30`080ZZZZ00@0QHF503Xj>P0j>SX04a<C0`092@T200@4100400H61P020P800P8200D51@801`L7
0`051@D100<30`400@410@010@40000400D51@061PH01PH600<30`<01`L70P051@D0100;2`/030`<
00`<300410@200D51@0400L71`0;2`/02`/;00H61P800@4100@00P8200<30`030`<010@40P051@D3
00@4100400D51@030`<00`<300<30`8010@400@02@T900P8200820P010@40P0820P010092@T01PH6
00H61P0410@200P820<01@D500@01`L700H61P061PH01PH60P010@4010020P801@D500D51@051@D2
00@4100400410@020P800P8200@410801@D500@00P8200@4100410@010@40P030`<010071`L020P8
00P820051@D200@4100400D51@092@T02@T900/;2`802PX:00@00P8200@4100410@00`<30P071`L4
00H61P801`L700@05QHF030`<00`<300:BTY0P0Z:RX0100g=cL0>CTi03Ti>@0j>SX203/k>`0403Xj
>P0K6a/06a/K00d=3@802@T900@0410@00<30`030`<01@D50P030`<0100=3@d0;2`/02`/;01LG5`2
0820P0<0Vi^K00@0XZ:R0:VYZ@2YZJT0U9BD0P23Ph<0101nOWh0RXZ:08Z:RP2KVi/20::RXP040:FU
Y@2QXJ40XJ6Q08n?S`80TY:B00@0WinO0::RXP2RXZ80Y:BT0P2DU9@0101jNWX0K6a/06a/K01QHF42
03Lg=`0401HF5P0I6AT06ATI01lO7`80<S8b00@0CDe=055AD@1ADE40>CTi0P10@400100/;2`0820P
020P8010@402079bLP0407=cL`1aLG40LG5a08>3P`80PX:200@0Ogmo05eMG@1MGEd0J6QX0P1JFUX0
101SHf<0HV9R069RHP19BDT204];B`0405=CD`1<C4`0C4a<05QHF080D51@00@0GEeM0451@@11@D40
<30`0P0^;Rh0100l?3`0D51@051@D00m?Cd204a<C004059BDP1FEUH0EUIF05UIF@80Bd];00@0ADE5
0410@010@400:b/[0P0n?Sh0101<C4`0BTY:04Y:BP12@T820410@00403Ph>00a<C40<C4a03Hf=P80
;Bd]00@0:BTY01@D500D51@04A4A0P0Z:RX0100M7Ad06ATI01TI6@0S8b<200h>3P0401PH600A4A40
4A4A02LW9`80;2`/00@0;Rh^038b<P0b<S808R8R0P0F5QH0100@410030`<00`<300A4A4201@D5004
01DE5@071`L01`L700L71`809BDU00@0>SXj05YJFP1JFUX0O7al0P1`L700101YJFT0Lg=c07=cL`1d
M7@206=SH`0403@d=00V9RH09RHV02`/;080AdM700@0E5AD04e=C@1=CDd0D51@0P1:BTX0101;Bd/0
CTi>04i>CP1<C4`204i>CP04055AD@1=CDd0CDe=04M7A`80CDe=00@0B4Q80492@P12@T80?Cdm0P0]
;Bd0101>CTh0Hf=S06=SH`1ADE4204U9B@<0@d=300@0BDU904i>CP1>CTh0ADE50P10@400101<C4`0
EEEE05EEE@1HF5P2059BDP0404U9B@1;Bd/0Bd];04e=C@80@T9200@0A4A404e=C@1=CDd0EEEE0P1@
D5001010@400>c/k03/k>`1=CDd208B4Q0040:RXZ02g]kL0]kNg0<30`080ZZZZ00@0QHF503Xj>P0j
>SX04a<C0`092@T200@4100400H61P020P800P8200D51@801`L70`051@D100<30`400@410@010@40
000400<30`0820P020P800H61P800`<300@010@400T92@092@T00P820P092@T010020P8010@400@4
10092@T200X:2P0400d=3@061PH01PH600H61P8020P800@01PH600L71`071`L00P820P030`<01002
0P800@4100410@0820P200T92@0400820P030`<00`<300D51@803Ph>00@02PX:00820P020P800000
0P030`<010061PH00`<300<30`030`<200D51@H01PH600<00`<300820P020P800`030`<010071`L0
0P8200820P020P8200<30`0400X:2P061PH01PH600H61P800`<300@02`/;00@4100410@00P820`03
0`<200D51@0400@410071`L01`L700820P801PH600@01@D500000000000010@40P0A4A40100H61P0
:2PX02PX:00[:b/201`L7004028R8P0n?Sh0?Shn04A4A080?Cdm00@0=3@d01LG5`0G5aL030`<0P09
2@T010051@D020P800P8200820P200l?3`04024Q8@0g=cL0=cLg07EeM@80RHV900@0UiNG0:BTY02T
Y:@0ZJVY0P2][Jd0102GUiL0P8200820P01YJFT207inOP0409bLW02NWYh0WYjN0:NWY`80WIfM00@0
T92@0::RXP2RXZ80Xj>S0P2NWYh0102XZ:P0Xj>S0:>SX`21PH4206EUI@0406e]K@1GEeL0EeMG02<S
8`802PX:00@02@T902HV9P0V9RH0=cLg0P0N7Qh0100Z:RX0<S8b038b<P0i>CT204=3@`04061PH01a
LG40LG5a08n?S`80QXJ600@0I6AT06i^KP1^KVh0MGEe0P12@T801019BDT0KFe]06e]K@1dM7@207Ee
M@0404M7A`0`<300<30`065QH@80FUYJ00@0@d=3030`<00`<300=SHf0P0h>3P0100k>c/0;Rh^02h^
;P0e=CD204I6AP030451@@1BDU80DU9B00<0G5aL00@0BDU90451@@11@D40=cLg0P0Z:RX0100^;Rh0
=cLg03Lg=`0i>CT20492@P04034a<@0W9bL09bLW03De=@8092@T00@05ADE01/K6`0K6a/06ATI0P0:
2PX0100820P05aLG01LG5`0W9bL201hN7P0400X:2P071`L01`L701LG5`802PX:00@030`<00l?3`0?
3`l05aLG0P0H61P00`0A4A402@T900T92@0300d=3@<020P800@02@T901PH600H61P0@4100P1TI6@0
101/K6`0L71`071`L01bLW8206][J`0406YZJP1[Jf/0Jf][06][J`80D51@00@0<C4a01dM7@0M7Ad0
=3@d0P1LG5`01019BDT0CDe=04e=C@1BDU8204I6AP0404A4A01=CDd0CDe=04];B`80C4a<00@0AdM7
04a<C01<C4`0CTi>0P1?Cdl0101:BTX0CTi>04i>CP0o?cl202/[:`0405UIF@1OGel0GemO04Y:BP80
B4Q800@0@D5104=3@`13@d<0AdM70P18B4P01013@d<0A4A404A4A019BDT205EEE@0405IFEP1<C4`0
C4a<04i>CP80CDe=00@0B4Q804U9B@19BDT0BDU90P1<C4`0101?Cdl0C4a<04a<C00k>c/203Hf=P04
051@D02:RXX0RXZ:0;6a/@80^k^k00@0_Kfm0:^[Z`2[Zj/0QHF50P0`<300100<30`02`/;00/;2`0;
2`/300H61P801@D500@02@T900D51@051@D00`<30P0:2PX100<30`401PH60@061PH0000400<30`07
1`L01`L700L71`800@4100@010@400D51@051@D010@40P061PH0100=3@d01PH600H61P061PH200P8
200300X:2P0410@010@400<01@D50`0410@010051@D010@400@410010@4200820P0400T92@0:2PX0
2PX:00@410800P8200@010@400T92@092@T020P80`0;2`/200T92@0300P820071`L01`L700H010@4
10051@D200410@0400<30`061PH01PH600L71`800`<300@01@D500820P020P8030`<0P0=3@d01007
1`L020P800P820020P8200D51@0400L71`092@T02@T900H61P800P8200<02@T900L71`071`L01004
10@20000000400<30`0H61P061PH02LW9`80:RXZ00@0=3@d02XZ:P0Z:RX03`l?0P0l?3`0101CDe<0
;bl_02l_;`0H61P200P8200400D51@010@400@4100H61P802PX:00@01PH601LG5`0G5aL09RHV0P1=
CDd0102<S8`0UIFE09FEU@2KVi/50:JVYP0409RHV02=SHd0SHf=06EUI@80MWIf00@0VIVI09fMW@2M
WId0ZZZZ0P2UYJD0102KVi/0Y:BT0:BTY02XZ:P20:VYZ@040:FUY@2SXj<0Xj>S09fMW@80Ph>300@0
LW9b05eMG@1MGEd0>CTi0P0I6AT0100000001@D500D51@0K6a/201<C4`0401hN7P0n?Sh0?Shn05iN
GP80G5aL00@0H61P03hn?P0n?Sh0BDU90P1HF5P01014A4@0AdM704M7A`10@40202@T900403<c<`1]
KFd0KFe]05UIF@80DU9B00@08R8R03<c<`0c<c<0GEeM0P1BDU801010@400:b/[02/[:`0L71`203Ti
>@0406MWI`1<C4`0C4a<03Ph>080?clo00<0G5aL05QHF01HF5P00`1>CTh0100c<c<0A4A404A4A00l
?3`202d];@0403hn?P10@400@4100410@080@d=300@0<S8b01lO7`0O7al09BDU0P0K6a/010051@D0
4Q8B018B4P0G5aL200L71`0400D51@092@T02@T901LG5`80410@00@00`<3014A4@0A4A403`l?0P0=
3@d010051@D01`L700L71`0A4A4201@D500400X:2P071`L01`L700`<30801PH600@02PX:010@400@
41009bLW0P11@D40101MGEd0KVi^06i^KP1ZJVX206][J`04061PH01UIFD0IFEU071`L080F5QH00@0
Cdm?0410@010@400<C4a0P0G5aL01016ATH0J6QX06QXJ015ADD204m?C`04051@D012@T80@T9203dm
?@80B4Q800@0DE5A04Y:BP1:BTX0@D510P1>CTh0101:BTX0B4Q804Q8B018B4P204i>CP04051@D00h
>3P0>3Ph061PH080IfMW00@0ADE50410@010@400AdM70P19BDT01010@400ADE504E5A@18B4P204U9
B@0404Y:BP1EEED0EEEE051@D080BDU90`1;Bd/01013@d<0?clo03lo?`10@40204U9B@04055AD@1>
CTh0CTi>03lo?`80?Shn00@0EeMG08V9R@29RHT0[Jf]0P2m_Kd0102k^k/0ZZZZ0:ZZZP1jNWX202LW
9`0300L71`0410@010@400<00`<300@010@400820P020P8010@40P010@4010030`<0410@010@4007
1`L200@4100000@00`<300L71`071`L01`L70P010@40100410@01@D500D51@0410@200H61P0400d=
3@061PH01PH600H61P8020P800<02PX:00@4100410@00`051@D300@4100400D51@0410@010@40041
0@800P8200@02@T900X:2P0:2PX010@40P020P80100410@02@T900T92@0820P300/;2`802@T900<0
20P800L71`071`L01P0410@400D51@800@4100@00`<300H61P061PH01`L70P030`<010051@D00P82
00820P0<30`200d=3@0400L71`0820P020P800820P801@D500@01`L700T92@092@T01PH60P020P80
0`092@T01`L700L71`0400@41080000000@00`<301PH600H61P09bLW0P0Z:RX0100d=3@0:RXZ02XZ
:P0?3`l203`l?00405=CD`0_;bl0;bl_01PH608020P800@01@D500410@010@401PH60P0:2PX01006
1PH05aLG01LG5`0V9RH204e=C@0408b<S02EUID0UIFE09^KV`D0YZJV00@0V9RH08f=S@2=SHd0IFEU
0P1fMWH0102IVIT0WIfM09fMW@2ZZZX20:FUY@0409^KV`2TY:@0Y:BT0:RXZ080ZJVY00@0YJFU0:>S
X`2SXj<0WIfM0P23Ph<0101bLW80GEeM05eMG@0i>CT201TI6@04000000051@D01@D501/K6`804a<C
00@07QhN03hn?P0n?Sh0GUiN0P1LG5`0101PH600?Shn03hn?P19BDT205QHF00404A4A017AdL0AdM7
0410@08092@T00@0<c<c06e]K@1]KFd0FEUI0P1BDU80100R8R80<c<c03<c<`1MGEd2059BDP040410
@00[:b/0:b/[01`L7080>CTi00@0IfMW04a<C01<C4`0>3Ph0P0o?cl00`1LG5`0F5QH05QHF00304i>
CP0403<c<`14A4@0A4A403`l?080;Bd]00@0?Shn0410@010@400@4100P13@d<0100b<S807alO01lO
7`0U9BD201/K6`0400D51@0B4Q804Q8B01LG5`801`L700@01@D500T92@092@T05aLG0P0@41001003
0`<04A4A014A4@0?3`l200d=3@0400D51@071`L01`L7014A4@8051@D00@02PX:00L71`071`L030`<
0P061PH0100:2PX0410@010@400W9bL20451@@0405eMG@1^KVh0KVi^06YZJP80Jf][00@0H61P06EU
I@1UIFD0L71`0P1HF5P0101?Cdl0@4100410@00a<C4201LG5`0404I6AP1XJ6P0J6QX04E5A@80Cdm?
00@0D51@0492@P12@T80?Cdm0P18B4P0101ADE40BTY:04Y:BP11@D4204i>CP0404Y:BP18B4P0B4Q8
04Q8B080CTi>00@0D51@03Ph>00h>3P0H61P0P1WIfL01015ADD0@4100410@017AdL204U9B@040410
@015ADD0ADE504Q8B080BDU900@0BTY:05EEE@1EEED0D51@0P19BDT304];B`0404=3@`0o?cl0?clo
0410@080BDU900@0DE5A04i>CP1>CTh0?clo0P0n?Sh0101GEeL0RHV908V9R@2][Jd20;fm_@040;^k
^`2ZZZX0ZZZZ07YjNP809bLW00<01`L700@4100410@00`030`<0100410@00P8200820P0410@20041
0@0400<30`0@4100410@00L71`8010@4000010020P802@T900T92@020P8200T92@0400P820000000
000000@410802PX:00@01`L700X:2P0:2PX03@d=0P061PH010051@D000000000000410@200/;2`04
00H61P071`L01`L700D51@801`L700@02@T900410@010@400`<30P061PH010051@D00P8200820P02
0P8200X:2P<01`L700@03@d=00P8200820P020P80P0<30`0100000000`<300<30`061PH200410@04
00<30`0820P020P800L71`801@D500@0000000820P020P8010@40`0820P200@410<02PX:00@00P82
00@4100410@02`/;0P0:2PX0100;2`/030`<00`<300;2`/200820P<01PH600@01@D500H61P061PH0
0`<30P071`L0100C4a<08R8R028R8P0[:b/2024Q8@0402XZ:P0m?Cd0?Cdm03Hf=P80B4Q800@0CTi>
02LW9`0W9bL04A4A0P00000010010@4010@400@4100>3Ph200d=3@0400h>3P0A4A404A4A02`/;080
L71`00@0W9bL0:>SX`2SXj<0YZJV0P2OWil0102QXJ40Y:BT0:BTY02EUID209>CT`0407QhN025QHD0
QHF50:>SX`80ZZZZ00@0Zj^[0:BTY02TY:@0X:2P0P2[Zj/0102i^KT0]kNg0;Ng]`2WYjL20:2PX003
0:6QX@2JVYX0VYZJ00<0T92@00@0RHV907MgM`1gMgL0D51@0P0L71`0100:2PX02@T900T92@0;2`/2
03Ph>00406QXJ01JFUX0FUYJ02d];@8061PH00@09RHV03Xj>P0j>SX0ATI60P1>CTh01013@d<08b<S
02<S8`0];Bd2059BDP0403De=@0W9bL09bLW020P8080;Bd]00@092@T03/k>`0k>c/0>SXj0P16ATH0
1011@D40?Shn03hn?P1[Jf/2069RHP<0@D5100@0FUYJ03@d=00d=3@0:b/[0P0f=SH0100R8R80;bl_
02l_;`0R8R8201hN7P0402XZ:P0];Bd0;Bd]03hn?P80>CTi00@09BDU02<S8`0S8b<0;Bd]0P0S8b<0
100:2PX030`<00`<300=3@d200/;2`0401<C4`071`L01`L700<30`8030`<00@05aLG01TI6@0I6AT0
2@T90P071`L0100;2`/05QHF01HF5P0:2PX200T92@0400P820061PH01PH600l?3`805QHF00@07alO
03De=@0e=CD0D51@0P1KFe/0101SHf<0Kfm_06m_K`1YJFT2065QH@0406UYJ@1cLg<0Lg=c06EUI@80
@D5100@0?Shn03De=@0e=CD09bLW0P0C4a<0101DE5@0I6AT06ATI016ATH204U9B@0404a<C015ADD0
ADE503lo?`80BDU900@0EUIF04i>CP1>CTh0ATI60`1<C4`204Q8B00404I6AP19BDT0BDU9069RHP80
B4Q800@0IVIV06][J`1[Jf/0ADE50P14A4@01011@D40@T920492@P12@T8204M7A`<0@d=300@0BTY:
05MGE`1GEeL0De=C0P1>CTh0101:BTX0Cdm?04m?C`19BDT203Xj>P040410@01=CDd0CDe=05MGE`80
DU9B00@0@d=30410@010@400EeMG0P2ATI40102[Zj/0];Bd0;Bd]02`/;020:FUY@0406EUI@0H61P0
61PH0000008010@400@01`L700410@010@400@410P00000010030`<01@D500D51@030`<200@41040
1`L70@010@4100410@0000@00`<300H61P061PH01@D50P0410@00`061PH00@4100410@0300<30`04
00D51@0820P020P800H61P801`L700@020P800820P020P800P821@0410@00`0820P01@D500D51@04
00<30`801@D500@02PX:00L71`071`L00`<30P0=3@d300L71`0400X:2P051@D01@D500/;2`8020P8
00@00P8200D51@051@D00P820`071`L200D51@<00P8200@00@4100H61P061PH00`<30P0820P01009
2@T010@400@410030`<200D51@0400410@020P800P8200l?3`8030`<00@020P800X:2P0:2PX051@D
0P092@T30000000400D51@0820P020P800H61P804Q8B00@0:2PX030`<00`<300<30`0P0/;2`0100i
>CT0CDe=04e=C@1LG5`204a<C00402HV9P0E5AD05ADE00d=3@802@T900@020P800<30`030`<02@T9
0P0<30`0100F5QH051@D01@D501<C4`208j>SP0409jNWP2OWil0WinO0:6QX@80UYJF00@0Vi^K09fM
W@2MWId0T92@0P26QXH0101gMgL0RXZ:08Z:RP2QXJ420:f][@040;:b/P2VYZH0YZJV09^KV`80XZ:R
00@0]kNg0<30`030`<00_kno0P2e]KD0102NWYh0Rh^;08^;R`27QhL209>CT`040:2PX02NWYh0WYjN
08^;R`80IFEU00@0?clo01PH600H61P02@T90P0:2PX0100X:2P0ATI604I6AP0];Bd201LG5`04030`
<00n?Sh0?Shn06EUI@80Kfm_00@0EEEE02XZ:P0Z:RX09BDU0P0k>c/0101SHf<0EeMG05MGE`1RHV82
05IFEP0402XZ:P14A4@0A4A404M7A`80DE5A00@0Bd];03Lg=`0g=cL0DU9B0P1KFe/01019BDT0CTi>
04i>CP1=CDd202HV9P0402XZ:P0W9bL09bLW02XZ:P80820P00@02PX:01LG5`0G5aL0;Rh^0P0c<c<0
100`<300820P020P800M7Ad202HV9P0402/[:`0Y:BT0:BTY01HF5P8030`<00@03@d=00@4100410@0
2PX:0P0B4Q8010092@T00000000000092@T200l?3`0400820P0:2PX02PX:01HF5P804a<C00@03`l?
01/K6`0K6a/06a/K0P0H61P0100O7al0=SHf03Hf=P0m?Cd204Q8B00405MGE`1TI6@0I6AT06IVIP80
IFEU00@0HF5Q06e]K@1]KFd0P8200P1_Kfl0101:BTX0;bl_02l_;`0g=cL202h^;P0402@T900J6QX0
6QXJ06i^KP80I6AT00@0ADE504Y:BP1:BTX0CTi>0P19BDT01017AdL0Cdm?04m?C`1ADE4204e=C@03
04a<C015ADD0ADE500<0ATI600@0ADE504I6AP16ATH0GemO0P1JFUX0101dM7@0IfMW06MWI`12@T82
04a<C00404=3@`19BDT0BDU904Y:BP<0@4100P18B4P304a<C0<0Cdm?00@0AdM70410@010@400@D51
0P0l?3`01019BDT0DE5A055AD@1:BTX204Q8B00404A4A00m?Cd0?Cdm05IFEP80UIFE00@0/;2`0;Rh
^02h^;P0]KFe0P2OWil0101HF5P06a/K01/K6`0;2`/200L71`0400P820020P800P8200410@800P82
0`010@4010071`L00P8200820P061PH200D51@0000@00`<300H61P061PH01@D50P0410@00`061PH0
0@4100410@0300<30`0400D51@0820P020P800H61P801`L700@020P800820P020P800P821@0410@0
0`0820P01@D500D51@0400<30`801@D500@02PX:00L71`071`L00`<30P0=3@d300L71`0400X:2P05
1@D01@D500/;2`8020P800@00P8200D51@051@D00P820`071`L200D51@<00P8200@00@4100H61P06
1PH00`<30P0820P010092@T010@400@410030`<200D51@0400410@020P800P8200l?3`8030`<00@0
20P800X:2P0:2PX051@D0P092@T30000000400D51@0820P020P800H61P804Q8B00@0:2PX030`<00`
<300<30`0P0/;2`0100i>CT0CDe=04e=C@1LG5`204a<C00402HV9P0E5AD05ADE00d=3@802@T900@0
20P800<30`030`<02@T90P0<30`0100F5QH051@D01@D501<C4`208j>SP0409jNWP2OWil0WinO0:6Q
X@80UYJF00@0Vi^K09fMW@2MWId0T92@0P26QXH0101gMgL0RXZ:08Z:RP2QXJ420:f][@040;:b/P2V
YZH0YZJV09^KV`80XZ:R00@0]kNg0<30`030`<00_kno0P2e]KD0102NWYh0Rh^;08^;R`27QhL209>C
T`040:2PX02NWYh0WYjN08^;R`80IFEU00@0?clo01PH600H61P02@T90P0:2PX0100X:2P0ATI604I6
AP0];Bd201LG5`04030`<00n?Sh0?Shn06EUI@80Kfm_00@0EEEE02XZ:P0Z:RX09BDU0P0k>c/0101S
Hf<0EeMG05MGE`1RHV8205IFEP0402XZ:P14A4@0A4A404M7A`80DE5A00@0Bd];03Lg=`0g=cL0DU9B
0P1KFe/01019BDT0CTi>04i>CP1=CDd202HV9P0402XZ:P0W9bL09bLW02XZ:P80820P00@02PX:01LG
5`0G5aL0;Rh^0P0c<c<0100`<300820P020P800M7Ad202HV9P0402/[:`0Y:BT0:BTY01HF5P8030`<
00@03@d=00@4100410@02PX:0P0B4Q8010092@T00000000000092@T200l?3`0400820P0:2PX02PX:
01HF5P804a<C00@03`l?01/K6`0K6a/06a/K0P0H61P0100O7al0=SHf03Hf=P0m?Cd204Q8B00405MG
E`1TI6@0I6AT06IVIP80IFEU00@0HF5Q06e]K@1]KFd0P8200P1_Kfl0101:BTX0;bl_02l_;`0g=cL2
02h^;P0402@T900J6QX06QXJ06i^KP80I6AT00@0ADE504Y:BP1:BTX0CTi>0P19BDT01017AdL0Cdm?
04m?C`1ADE4204e=C@0304a<C015ADD0ADE500<0ATI600@0ADE504I6AP16ATH0GemO0P1JFUX0101d
M7@0IfMW06MWI`12@T8204a<C00404=3@`19BDT0BDU904Y:BP<0@4100P18B4P304a<C0<0Cdm?00@0
AdM70410@010@400@D510P0l?3`01019BDT0DE5A055AD@1:BTX204Q8B00404A4A00m?Cd0?Cdm05IF
EP80UIFE00@0/;2`0;Rh^02h^;P0]KFe0P2OWil0101HF5P06a/K01/K6`0;2`/200L71`0400P82002
0P800P8200410@800P820`010@4010071`L00P8200820P061PH200D51@0000@00P8200L71`071`L0
2`/;0P061PH010030`<01`L700L71`0410@200<30`0400D51@030`<00`<300@410802@T900@020P8
00H61P061PH01PH60P051@D010071`L01PH600H61P092@T200P82004000000010@400@4100<30`80
000000@010@400H61P061PH01@D50P0<30`0100820P02@T900T92@061PH200X:2P0300/;2`071`L0
1`L700<01PH600@00P8200P8200820P01PH60P010@4010061PH02PX:00X:2P061PH200D51@<020P8
00@02PX:00D51@051@D000000P071`L010020P801@D500D51@061PH200P8200400/;2`0410@010@4
00h>3P801`L700@00`<300/;2`0;2`/01`L70P0=3@d010061PH05aLG01LG5`0a<C42030`<00403<c
<`0l?3`0?3`l05=CD`80GEeM00@0JFUY04a<C01<C4`07QhN0P061PH0100;2`/02PX:00X:2P0=3@d2
00l?3`<01PH600@020P802`/;00/;2`0P8200P2RXZ80102QXJ40WinO09nOW`2VYZH20:6QX@0409nO
W`2KVi/0Vi^K09FEU@80Ogmo00@0MgMg09BDU02DU9@0XZ:R0P2YZJT0102_[jl0XZ:R0::RXP2>SXh2
08^;R`040:>SX`2f][H0][Jf0;Rh^080[jn_00@0VYZJ096AT@2ATI40S8b<0P26QXH0102HV9P0YJFU
0:FUY@2QXJ4209JFUP0408J6QP1eMGD0MGEe06EUI@80@D5100@07AdM00X:2P0:2PX030`<0P0A4A40
100B4Q80;2`/02`/;01DE5@207QhN00407moO`1PH600H61P04i>CP809bLW00@0BTY:05EEE@1EEED0
Kfm_0P28R8P0101KFe/0Cdm?04m?C`1FEUH205YJFP04059BDP1<C4`0C4a<051@D080F5QH00@0@410
03Ti>@0i>CT0ADE50P17AdL0101GEeL0AdM704M7A`11@D42034a<@0402TY:@0b<S80<S8b034a<@80
;2`/00@0:BTY01dM7@0M7Ad08B4Q0P0R8R80100C4a<04Q8B018B4P092@T200L71`0400h>3P061PH0
1PH6014A4@806ATI00@03Ph>00P8200820P03Ph>0P0B4Q80100E5AD08b<S02<S8`0P820201dM7@03
02d];@0f=SH0=SHf00<0;Bd]00@0<C4a04E5A@15ADD0CDe=0P1FEUH0101JFUX0Jf][06][J`1ZJVX2
06QXJ00407=cL`28R8P0R8R808J6QP80O7al00@0EEEE03Lg=`0g=cL0>SXj0P0f=SH0100O7al06QXJ
01XJ6P26QXH205mOG`040451@@1:BTX0BTY:04a<C080@41000@0A4A404];B`1;Bd/0BTY:0`1>CTh2
04Y:BP0404Q8B017AdL0AdM704M7A`80BTY:00@0FEUI06ATI01TI6@0Ng]k0P1]KFd01012@T80AdM7
04M7A`18B4P204e=C@0404E5A@17AdL0AdM704Y:BP80CTi>00@0D51@04];B`1;Bd/0C4a<0P1@D500
101DE5@0ADE504E5A@10@40203hn?P0404A4A018B4P0B4Q804I6AP80C4a<00@0ATI60451@@11@D40
IFEU0P2IVIT0102/[:`0_[jn0;jn_P2j^[X209>CT`0405IFEP0R8R808R8R00d=3@801PH600@00P82
00L71`071`L00P820P061PH0100820P00P8200820P010@4200H61P400`<30@071`L100L71`0000@0
0@4100@4100410@010@40P061PH0100820P00`<300<30`020P8300<30`800P8200@020P800/;2`0;
2`/01PH60P020P8010092@T00`<300<30`0:2PX200D51@0400H61P092@T02@T900H61P8010@400@0
0`<300P8200820P01`L70P00000010020P8020P800P820051@D200@4100400410@0820P020P800@4
10800`<300@01@D500@4100410@00`<30P020P80100410@02PX:00X:2P030`<200@410<00@4100<0
0P8200/;2`0;2`/00`071`L0100>3Ph01`L700L71`020P8200X:2P0400T92@0:2PX02PX:00P82080
000000@02@T900H61P061PH01@D50P061PH0100:2PX01PH600H61P0=3@d202<S8`04038b<P0g=cL0
=cLg02/[:`80ADE500@0F5QH061PH01PH600IFEU0P0m?Cd0100O7al020P800P8200;2`/200L71`04
00T92@0<30`030`<00D51@800`<300@01`L704];B`1;Bd/0U9BD0P2NWYh0102UYJD0YjNW0:NWY`2[
Zj/20:ZZZP040:JVYP2JVYX0VYZJ09JFUP80Ng]k00@0P8200:ZZZP2ZZZX0/[:b0P2TY:@0102MWId0
UYJF09JFUP20P80208J6QP040;:b/P2l_;`0_;bl0:j^[P80YZJV00@0VIVI09ZJVP2JVYX0WIfM0P2D
U9@0102HV9P0XJ6Q0:6QX@2RXZ8209ZJVP0409:BTP2KVi/0Vi^K0:BTY080W9bL00@0KVi^02XZ:P0Z
:RX08b<S0P0Q8B40100000002@T900T92@0V9RH2055AD@0407IfMP1gMgL0MgMg07AdM080BTY:00@0
@41005QHF01HF5P0C4a<0P15ADD0100b<S80:RXZ02XZ:P0j>SX203`l?00402/[:`0K6a/06a/K030`
<080C4a<00@0@41002<S8`0S8b<0>SXj0P16ATH01012@T80ADE504E5A@0j>SX2034a<@04030`<00j
>SX0>SXj034a<@808R8R00@0:BTY030`<00`<30061PH0`0L71`200D51@0400l?3`0G5aL05aLG01HF
5P808B4Q00@0:RXZ02<S8`0S8b<08R8R0P0a<C40100[:b/0:RXZ02XZ:P0_;bl202XZ:P0402<S8`0^
;Rh0;Rh^03dm?@80?Shn00@0>3Ph03hn?P0n?Sh0BDU90P1CDe<0101TI6@0LW9b079bLP1TI6@305mO
G`80PH6100@0Vi^K08n?S`2?Shl0Q8B40P1gMgL0100l?3`0>3Ph03Ph>00f=SH203@d=00401LG5`0c
<c<0<c<c0:6QX@80Fe]K00@0@d=304M7A`17AdL0Bd];0P0e=CD00`0n?Sh0D51@051@D00304a<C004
05=CD`1HF5P0F5QH059BDP80CDe=00@0Bd];04U9B@19BDT0BDU90P1SHf<01028R8P0M7Ad07AdM014
A4@304M7A`80A4A400@0AdM704m?C`1?Cdl0Cdm?0P1;Bd/0101@D500DE5A055AD@1>CTh204Q8B004
04m?C`18B4P0B4Q80492@P80A4A400@0@d=304Q8B018B4P0CDe=0P15ADD0100m?Cd0@d=304=3@`1/
K6`209bLW0040:^[Z`31`L40`L710;Fe]@80RXZ:00@0FEUI02PX:00X:2P01PH60P0820P00`092@T0
10@400@4100300<30`0400D51@0:2PX02PX:00<30`801@D50@0410@100820P400P82000010010@40
10@400@4100410@200H61P0400P820030`<00`<300820P<00`<30P020P80100820P02`/;00/;2`06
1PH200820P0400T92@030`<00`<300X:2P801@D500@01PH600T92@092@T01PH60P0410@010030`<0
20P800P820071`L20000000400820P0820P020P800D51@8010@400@00@4100P8200820P010@40P03
0`<010051@D010@400@410030`<200820P0400@4100:2PX02PX:00<30`8010@40`010@400`020P80
2`/;00/;2`0300L71`0400h>3P071`L01`L700820P802PX:00@02@T900X:2P0:2PX020P80P000000
10092@T01PH600H61P051@D200H61P0400X:2P061PH01PH600d=3@808b<S00@0<S8b03Lg=`0g=cL0
:b/[0P15ADD0101HF5P0H61P061PH01UIFD203dm?@0401lO7`0820P020P800/;2`801`L700@02@T9
00`<300<30`01@D50P030`<010071`L0Bd];04];B`2DU9@209jNWP040:FUY@2WYjL0YjNW0:^[Z`80
ZZZZ00@0YZJV09ZJVP2JVYX0UYJF0P1kNg/01020P800ZZZZ0:ZZZP2b/[820:BTY00409fMW@2FUYH0
UYJF0820P080QXJ600@0/[:b0;bl_02l_;`0[Zj^0P2VYZH0102IVIT0VYZJ09ZJVP2MWId209BDU004
09RHV02QXJ40XJ6Q0::RXP80VYZJ00@0TY:B09^KV`2KVi/0Y:BT0P2LW9`0101^KVh0:RXZ02XZ:P0S
8b<2024Q8@04000000092@T02@T902HV9P80DE5A00@0MWIf07MgM`1gMgL0M7Ad0P1:BTX01010@400
F5QH05QHF01<C4`204E5A@04038b<P0Z:RX0:RXZ03Xj>P80?3`l00@0:b/[01/K6`0K6a/0<30`0P1<
C4`01010@4008b<S02<S8`0j>SX204I6AP040492@P15ADD0ADE503Xj>P80<C4a00@0<30`03Xj>P0j
>SX0<C4a0P0R8R80100Y:BT0<30`030`<00H61P301`L70801@D500@03`l?01LG5`0G5aL05QHF0P0Q
8B40100Z:RX08b<S02<S8`0R8R82034a<@0402/[:`0Z:RX0:RXZ02l_;`80:RXZ00@08b<S02h^;P0^
;Rh0?Cdm0P0n?Sh0100h>3P0?Shn03hn?P19BDT205=CD`0406ATI01bLW80LW9b06ATI0<0GemO0P21
PH40102KVi/0Shn?08n?S`24Q8@207MgM`0403`l?00h>3P0>3Ph03Hf=P80=3@d00@05aLG03<c<`0c
<c<0XJ6Q0P1KFe/01013@d<0AdM704M7A`1;Bd/203De=@0303hn?P1@D500D51@00<0C4a<00@0De=C
05QHF01HF5P0DU9B0P1=CDd0101;Bd/0BDU904U9B@19BDT206=SH`0408R8R01dM7@0M7Ad04A4A0<0
AdM70P14A4@01017AdL0Cdm?04m?C`1?Cdl204];B`04051@D01ADE40DE5A04i>CP80B4Q800@0Cdm?
04Q8B018B4P0@T920P14A4@01013@d<0B4Q804Q8B01=CDd204E5A@0403dm?@13@d<0@d=306a/K080
W9bL00@0Zj^[0<71`@31`L40]KFe0P2:RXX0101IFET0:2PX02PX:0061PH200P8200300T92@0410@0
10@400<00`<300@01@D500X:2P0:2PX00`<30P051@D100@410400P820@020P80000400L71`010@40
0@4100410@8010@400@020P800@4100410@00@410`061PH200410@0400H61P0410@010@400H61P80
0`<300@01@D500H61P061PH01`L70P0410@0100;2`/01PH600H61P061PH200820P0400410@030`<0
0`<300`<308020P800@00@4100@4100410@00@410P020P80100410@00P8200820P030`<200@41004
00<30`010@400@4100820P80000000@00P8200L71`071`L01PH60P030`<010020P8010@400@41002
0P8200T92@0300<30`071`L01`L700<02PX:00@020P800T92@092@T020P80P092@T300410@0400h>
3P092@T02@T900@410801`L700@02@T900L71`071`L06QXJ0P0Z:RX0100X:2P0=3@d03@d=00V9RH2
05YJFP0406EUI@1YJFT0JFUY065QH@80<30`00@07QhN00@4100410@01PH60P0410@300<30`040000
000F5QH05QHF0410@080O7al00@0UiNG09JFUP2FUYH0ZZZZ0P2b/[80102TY:@0Vi^K09^KV`2KVi/2
08Z:RP0408B4Q01mOGd0OGem08Z:RP80Z:RX00@0/;2`0:BTY02TY:@0UiNG0P2QXJ40102<S8`0N7Qh
07QhN02OWil20;^k^`040:^[Z`2BTY80TY:B09BDU080[Jf]00@0][Jf0:b/[02/[:`0XZ:R0`2IVIT2
09RHV00408j>SP2:RXX0RXZ:08b<S080SHf=00@0Ng]k04I6AP16ATH0;bl_0P0f=SH0100V9RH03`l?
00l?3`0<30`202l_;`040410@01ADE40DE5A05ADE080<C4a00@0;Rh^0492@P12@T80ADE50P1EEED3
04];B`0405mOG`1:BTX0BTY:04I6AP80De=C0`10@400100Z:RX071`L01`L700Z:RX203<c<`0403Ti
>@0e=CD0=CDe02PX:080:BTY00@0;bl_02`/;00/;2`0<30`0P0e=CD302`/;004028R8P0X:2P0:2PX
02TY:@805QHF00@09bLW03Hf=P0f=SH0=SHf0P10@4001019BDT0ATI604I6AP0n?Sh203Xj>P0403De
=@0d=3@0=3@d03Lg=`80<S8b00@0@41004U9B@19BDT0Bd];0P1CDe<0101>CTh0G5aL05aLG01]KFd2
06IVIP0406YZJP1fMWH0MWIf07AdM080Kfm_00@0Hf=S06][J`1[Jf/0Ti>C0P25QHD0101oOgl0F5QH
05QHF00^;Rh203/k>`0402PX:00f=SH0=SHf01`L7080EEEE00@0[Jf]059BDP1BDU80B4Q80P1?Cdl0
101@D500>CTi03Ti>@13@d<205IFEP0404Y:BP1<C4`0C4a<05=CD`80DU9B00@0Bd];04a<C01<C4`0
Bd];0P19BDT01016ATH0GemO05mOG`29RHT206i^KP0404i>CP18B4P0B4Q80410@080A4A400@0B4Q8
0410@010@400?clo0P18B4P0101@D500CDe=04e=C@1<C4`203lo?`040410@011@D40@D5103hn?P80
@41000@0BDU905ADE01DE5@0DU9B0P12@T801010@400@D510451@@1SHf<209fMW@040:RXZ02j^[X0
^[Zj0:n_[`80NGUi00@0ADE501hN7P0N7Qh020P80P020P8010061PH010@400@4100<30`200820P04
00410@061PH01PH600410@8020P80@051@D100410@400@41000010030`<00P8200820P0410@200<3
0`0400820P000000000000410@<00P820P061PH0100410@01@D500D51@051@D300T92@8030`<00@0
1PH600P8200820P01`L70P020P8010030`<00000000000020P8200/;2`0400D51@061PH01PH600P8
20800P8200@01`L70000000000001@D50`071`L200<30`<010@400@01@D500<30`030`<00P820P05
1@D010030`<00@4100410@0:2PX300L71`800`<300@01PH600P8200820P01`L70P051@D010071`L0
0@4100410@061PH200820P0400<30`071`L01`L700h>3P801@D500@0000000D51@051@D00`<30P0>
3Ph0100I6AT0;Bd]02d];@0];Bd202@T900402`/;01IFET0FEUI06QXJ080Jf][00@0Bd];01dM7@0M
7Ad0410@0`030`<200X:2P0400P820010@400@4100410@80@T9200@0K6a/08b<S02<S8`0XZ:R0P2O
Wil0102YZJT0[Jf]0:f][@2QXJ4209fMW@0409ZJVP29RHT0RHV907]kN`80Q8B400@0WinO0::RXP2R
XZ80Vi^K0P2GUiL0102:RXX0Rh^;08^;R`2BTY8208Z:RP0409JFUP2n_[h0_[jn0;>c/`80IVIV00@0
CTi>08:2PP22PX80WIfM0P2IVIT0102VYZH0XZ:R0::RXP26QXH207=cL`0307alO02?Shl0Shn?00<0
VIVI00@0IfMW01DE5@0E5AD05aLG0P11@D40101@D500;bl_02l_;`0H61P200h>3P0403hn?P11@D40
@D5102PX:080820P0`0V9RH0100^;Rh0=cLg03Lg=`0n?Sh204a<C004079bLP1ZJVX0JVYZ065QH@80
K6a/00@0G5aL05QHF01HF5P0BDU90P1EEED0101ADE40?clo03lo?`0l?3`202XZ:P04024Q8@0];Bd0
;Bd]03Lg=`80=CDe00@09bLW02HV9P0V9RH0:b/[0P0];Bd0100e=CD0>c/k03/k>`0e=CD203Lg=`04
0410@015ADD0ADE504Y:BP80CTi>00@0Cdm?05ADE01DE5@0AdM70P0j>SX0101;Bd/0ADE504E5A@0i
>CT20451@@0305MGE`1QHF40HF5Q00<0HF5Q00@0Hf=S06IVIP1VIVH0KVi^0P1aLG40101]KFd0LW9b
079bLP1mOGd20861P@04071`L014A4@0A4A405iNGP80HF5Q00@0E5AD03Lg=`0g=cL0=cLg0P0a<C40
100/;2`0DE5A055AD@0Z:RX2069RHP040:f][@1:BTX0BTY:04];B`80C4a<00@0B4Q80410@010@400
@d=30`1;Bd/204i>CP0404U9B@1:BTX0BTY:04M7A`<0BDU90P1>CTh0101FEUH0HF5Q065QH@1oOgl2
065QH@04059BDP13@d<0@d=303dm?@80Bd];00@0AdM70492@P12@T80@T920P1<C4`0101KFe/0CTi>
04i>CP18B4P204E5A@040492@P0o?cl0?clo04=3@`80A4A400@0B4Q8059BDP1BDU80CTi>0P11@D40
100o?cl0@T920492@P1_Kfl209jNWP0409>CT`2ZZZX0ZZZZ0:f][@80JVYZ00@0>3Ph018B4P0B4Q80
20P80`020P820000000400410@092@T02@T900/;2`8010@40`061PH100@410402PX:0@0:2PX00004
00<30`020P800P8200@410800`<300@00P820000000000000@410`020P8200H61P0400@410051@D0
1@D500D51@<02@T90P0<30`010061PH020P800P820071`L200820P0400<30`000000000000820P80
2`/;00@01@D500H61P061PH020P80P020P8010071`L00000000000051@D300L71`800`<30`0410@0
10051@D00`<300<30`020P8200D51@0400<30`010@400@4100X:2P<01`L70P030`<010061PH020P8
00P820071`L200D51@0400L71`010@400@4100H61P800P8200@00`<300L71`071`L03Ph>0P051@D0
100000001@D500D51@030`<200h>3P0401TI6@0];Bd0;Bd]02d];@8092@T00@0;2`/05UIF@1IFET0
J6QX0P1[Jf/0101;Bd/07AdM01dM7@0@410300<30`802PX:00@020P800410@010@400@410P12@T80
101/K6`0S8b<08b<S02RXZ8209nOW`040:VYZ@2][Jd0[Jf]0:6QX@80WIfM00@0VYZJ08V9R@29RHT0
Ng]k0P24Q8@0102OWil0XZ:R0::RXP2KVi/209NGU`0408Z:RP2;Rh/0Rh^;09:BTP80RXZ:00@0UYJF
0;jn_P2n_[h0/k>c0P1VIVH0101>CTh0PX:208:2PP2MWId209VIV@040:JVYP2RXZ80XZ:R08J6QP80
Lg=c00<0O7al08n?S`2?Shl00`2IVIT0101WIfL05ADE01DE5@0G5aL20451@@04051@D00_;bl0;bl_
01PH60803Ph>00@0?Shn0451@@11@D40:2PX0P0P820302HV9P0402h^;P0g=cL0=cLg03hn?P80C4a<
00@0LW9b06YZJP1ZJVX0HF5Q0P1/K6`0101LG5`0F5QH05QHF019BDT205EEE@04055AD@0o?cl0?clo
03`l?080:RXZ00@08B4Q02d];@0];Bd0=cLg0P0e=CD0100W9bL09RHV02HV9P0[:b/202d];@0403De
=@0k>c/0>c/k03De=@80=cLg00@0@41004E5A@15ADD0BTY:0P1>CTh0101?Cdl0E5AD05ADE017AdL2
03Xj>P0404];B`15ADD0ADE503Ti>@80@D5100<0EeMG065QH@1QHF400`1QHF40101SHf<0IVIV06IV
IP1^KVh2075aL@0406e]K@1bLW80LW9b07emO@80PH6100@0L71`04A4A014A4@0GUiN0P1QHF40101D
E5@0=cLg03Lg=`0g=cL2034a<@0402`/;01ADE40DE5A02XZ:P80HV9R00@0[Jf]04Y:BP1:BTX0Bd];
0P1<C4`01018B4P0@4100410@013@d<304];B`80CTi>00@0BDU904Y:BP1:BTX0AdM70`19BDT204i>
CP0405IFEP1QHF40HF5Q07moO`80HF5Q00@0DU9B04=3@`13@d<0?Cdm0P1;Bd/01017AdL0@T920492
@P12@T8204a<C00405]KF`1>CTh0CTi>04Q8B080ADE500@0@T9203lo?`0o?cl0@d=30P14A4@01018
B4P0DU9B059BDP1>CTh20451@@0403lo?`12@T80@T9206m_K`80WYjN00@0Ti>C0:ZZZP2ZZZX0[Jf]
0P1ZJVX0100h>3P04Q8B018B4P0820P300820P80000000@00@4100T92@092@T02`/;0P0410@300H6
1P4010@40@0:2PX100X:2P0000@00`<300410@010@400@410P020P801000000010@400@410092@T2
0000000400D51@0:2PX02PX:00H61P801@D500@01PH600/;2`0;2`/02@T90P061PH0100410@00P82
00820P092@T200L71`0400410@0410@010@400D51@802PX:00@01@D500H61P061PH00@410`061PH2
00`<300400L71`092@T02@T900/;2`<00@410P00000300<30`<01`L700@00`<300D51@051@D01@D5
0P030`<010051@D010@400@4100<30`300D51@800`<300@010@400L71`071`L02@T90P0000001009
2@T01@D500D51@092@T200X:2P0400T92@030`<00`<300820P805aLG00@09RHV02@T900T92@07alO
0P0R8R80100e=CD0Hf=S06=SH`1jNWX206IVIP04034a<@0>3Ph03Ph>00<30`802@T900@01@D500X:
2P0:2PX01@D50P000000100P8200KFe]06e]K@1nOWh2096AT@040:2PX02TY:@0Y:BT0:>SX`80W9bL
00@0X:2P0:b/[02/[:`0WinO0P2DU9@01027QhL0RXZ:08Z:RP2TY:@20:6QX@0409fMW@2IVIT0VIVI
08R8R080MWIf00@0P82009NGU`2GUiL0Vi^K0P2e]KD0102VYZH0BDU904U9B@0N7Qh205EEE@0409:B
TP2QXJ40XJ6Q0:RXZ080Ti>C00@0FUYJ03Hf=P0f=SH0>CTi0P1;Bd/0101>CTh0EEEE05EEE@0o?cl2
01<C4`04014A4@0];Bd0;Bd]02LW9`806a/K00@07QhN018B4P0B4Q80>c/k0P0b<S80100_;bl0A4A4
04A4A00`<30201`L700402XZ:P0T92@092@T01dM7@808R8R00@0BDU905eMG@1MGEd0GEeM0P1_Kfl0
101nOWh0OGem07emO@1`L70207AdM00406i^KP1HF5P0F5QH04U9B@80@d=300<0>c/k03Lg=`0g=cL0
0`0f=SH0100c<c<0>3Ph03Ph>00j>SX203De=@0403Ti>@0n?Sh0?Shn0410@080AdM700@0BTY:04i>
CP1>CTh0EUIF0P1=CDd01015ADD0DU9B059BDP1?Cdl20492@P0404e=C@19BDT0BDU90492@P80DE5A
00@0FUYJ06IVIP1VIVH0M7Ad0P1ZJVX0101`L700KFe]06e]K@1ZJVX206EUI@0404Y:BP17AdL0AdM7
05mOG`80Kfm_00<0JVYZ0410@010@4000`0m?Cd0100e=CD0>SXj03Xj>P0d=3@202/[:`0403Ti>@1;
Bd/0Bd];03`l?080MgMg00@0/[:b0492@P12@T80A4A40P1;Bd/30410@00404=3@`18B4P0B4Q804a<
C080Bd];00@0B4Q804];B`1;Bd/0CDe=0P1;Bd/304M7A`0405ADE01PH600H61P07UiN@80G5aL00@0
De=C04I6AP16ATH0?Cdm0P16ATH30492@P0403lo?`14A4@0A4A405MGE`80DU9B00@0A4A404U9B@19
BDT0B4Q80P12@T8404Y:BP80Cdm?00@0AdM70410@010@400@D510P19BDT0101WIfL0RHV908V9R@2J
VYX20;Jf]P040;6a/@1XJ6P0J6QX02h^;P803@d=0`061PH010030`<01PH600H61P0820P200L71`04
00D51@0410@010@400<30`801`L70@061PH100<30`400`<3000010061PH01@D500D51@030`<20082
0P0400L71`0410@010@400X:2P801@D500@010@400D51@051@D01PH60P030`<0100000001@D500D5
1@061PH200<30`<00P8200@01`L700D51@051@D01@D50P071`L010020P801@D500D51@061PH200T9
2@0400P8200=3@d03@d=00@410801`L700@01@D500H61P061PH030`<0P010@4300@4100400L71`05
1@D01@D500<30`800@4100@02@T900/;2`0;2`/00@410P071`L010030`<01`L700L71`061PH200D5
1@0400820P030`<00`<300@410803`l?00@03Ph>00T92@092@T03`l?0P0820P0100410@00`<300<3
0`0820P200<30`0400l?3`0J6QX06QXJ02/[:`807alO00@08B4Q03De=@0e=CD0Cdm?0P1nOWh01021
PH40D51@051@D00G5aL200<30`0400@4100:2PX02PX:00L71`801PH600@00@4100820P020P80E5AD
0P20P8001028R8P0ZJVY0:VYZ@2QXJ4209bLW00409NGU`2?Shl0Shn?0::RXP80ZZZZ0`2KVi/0102=
SHd0S8b<08b<S02SXj<20:^[Z`040;6a/@2RXZ80XZ:R08N7Q`80MgMg00@0Ph>309^KV`2KVi/0UYJF
0P2GUiL0101[Jf/06QXJ01XJ6P020P8203Ph>00409^KV`2j^[X0^[Zj0:f][@80Ng]k00@0?Cdm01TI
6@0I6AT03`l?0P0F5QH300410@0401dM7@0V9RH09RHV01/K6`80:BTY00@08B4Q00`<300<30`06QXJ
0P0g=cL0101@D500?Shn03hn?P0a<C4203<c<`0401DE5@092@T02@T901XJ6P<09RHV0P0R8R80100L
71`092@T02@T900^;Rh204I6AP0405mOG`1_Kfl0Kfm_07AdM080KFe]00@0LW9b07EeM@1eMGD0KVi^
0P1QHF40101EEED0DE5A055AD@1:BTX20451@@0404];B`1<C4`0C4a<03`l?080@41000@0C4a<04Y:
BP1:BTX0Cdm?0P1EEED0101GEeL0GEeM05eMG@1LG5`2055AD@04051@D01GEeL0EeMG04m?C`80AdM7
00@0C4a<055AD@1ADE40Bd];0P1GEeL306EUI@0407EeM@1gMgL0MgMg07MgM`80LW9b00<0Fe]K03hn
?P0n?Sh00`0W9bL0100c<c<0ATI604I6AP1CDe<20410@00403Xj>P0^;Rh0;Rh^03De=@80<C4a00@0
6a/K03`l?00l?3`0?Cdm0P0T92@0100c<c<0O7al07alO02i^KT204Y:BP040451@@1>CTh0CTi>03hn
?P80?Cdm00@0Bd];04Y:BP1:BTX0?Shn0P0o?cl01018B4P0CTi>04i>CP1>CTh204M7A`0404m?C`1B
DU80DU9B059BDP80IVIV00@0P820061PH01PH600DE5A0P1?Cdl0100n?Sh0?3`l03`l?010@40204E5
A@040410@016ATH0ATI6051@D080FEUI00@0C4a<04U9B@19BDT0@D510P12@T801016ATH0@T920492
@P19BDT204M7A`040451@@14A4@0A4A404I6AP80BDU900@0EeMG08f=S@2=SHd0^KVi0P2j^[X0102J
VYX0F5QH05QHF00U9BD2014A4@0400@410051@D01@D500D51@<010@40P030`<010020P800`<300<3
0`061PH200820P4010@40@010@4100410@0000@01PH600D51@051@D00`<30P020P8010071`L010@4
00@4100:2PX200D51@0400@410051@D01@D500H61P800`<300@0000000D51@051@D01PH60P030`<3
00820P0400L71`051@D01@D500D51@801`L700@00P8200D51@051@D01PH60P092@T0100820P03@d=
00d=3@0410@200L71`0400D51@061PH01PH600`<30800@410`0410@010071`L01@D500D51@030`<2
00410@0400T92@0;2`/02`/;00410@801`L700@00`<300L71`071`L01PH60P051@D010020P800`<3
00<30`0410@200l?3`0400h>3P092@T02@T900l?3`8020P800@010@400<30`030`<020P80P030`<0
100?3`l06QXJ01XJ6P0[:b/201lO7`04024Q8@0e=CD0=CDe04m?C`80OWin00@0PH61051@D01@D500
5aLG0P030`<0100410@02PX:00X:2P071`L200H61P0400410@020P800P8205ADE080P82000@0R8R8
0:VYZ@2YZJT0XJ6Q0P2LW9`0102GUiL0Shn?08n?S`2RXZ820:ZZZP<0Vi^K00@0SHf=08b<S02<S8`0
Xj>S0P2[Zj/0102a/K40XZ:R0::RXP27QhL207MgM`0408>3P`2KVi/0Vi^K09JFUP80UiNG00@0Jf][
01XJ6P0J6QX00P820P0h>3P0102KVi/0^[Zj0;Zj^P2][Jd207]kN`0403dm?@0I6AT06ATI00l?3`80
5QHF0`010@40100M7Ad09RHV02HV9P0K6a/202TY:@04024Q8@0<30`030`<01XJ6P80=cLg00@0D51@
03hn?P0n?Sh0<C4a0P0c<c<0100E5AD02@T900T92@0J6QX302HV9P808R8R00@071`L02@T900T92@0
;Rh^0P16ATH0101OGel0Kfm_06m_K`1dM7@206e]K@04079bLP1eMGD0MGEe06i^KP80HF5Q00@0EEEE
055AD@1ADE40BTY:0P11@D40101;Bd/0C4a<04a<C00l?3`20410@00404a<C01:BTX0BTY:04m?C`80
EEEE00@0EeMG05eMG@1MGEd0G5aL0P1ADE40101@D500EeMG05MGE`1?Cdl204M7A`0404a<C01ADE40
DE5A04];B`80EeMG0`1UIFD0101eMGD0MgMg07MgM`1gMgL2079bLP0305]KF`0n?Sh0?Shn00<09bLW
00@0<c<c04I6AP16ATH0De=C0P10@400100j>SX0;Rh^02h^;P0e=CD2034a<@0401/K6`0l?3`0?3`l
03dm?@8092@T00@0<c<c07alO01lO7`0^KVi0P1:BTX01011@D40CTi>04i>CP0n?Sh203dm?@0404];
B`1:BTX0BTY:03hn?P80?clo00@0B4Q804i>CP1>CTh0CTi>0P17AdL0101?Cdl0DU9B059BDP1BDU82
06IVIP040820P01PH600H61P055AD@80Cdm?00@0?Shn03`l?00l?3`0@4100P15ADD01010@400ATI6
04I6AP1@D50205UIF@0404a<C019BDT0BDU90451@@80@T9200@0ATI60492@P12@T80BDU90P17AdL0
1011@D40A4A404A4A016ATH204U9B@0405MGE`2=SHd0SHf=0;Vi^@80^[Zj00@0VYZJ05QHF01HF5P0
9BDU0P0A4A40100410@01@D500D51@051@D300@410800`<300@00P8200<30`030`<01PH60P020P81
00@410400@410@010@4000<00P8200@020P800L71`071`L01@D50P0410@300P8200300/;2`071`L0
1`L700<02@T900@010@400820P020P8010@40P030`<010092@T01`L700L71`092@T200@410<00`<3
00@01PH600@4100410@020P80`071`L200<30`0400D51@061PH01PH600D51@8010@400@00`<30041
0@010@400`<30P010@4010051@D01`L700L71`0820P200820P0400P820071`L01`L700<30`800P82
00@00`<300820P020P800`<30P092@T300P8200400T92@0410@010@400/;2`<02@T90P071`L0100:
2PX00@4100410@051@D200H61P0401PH600L71`071`L02LW9`808B4Q00@0>CTi059BDP1BDU80GemO
0P1gMgL0101]KFd0@4100410@00C4a<200@4100400D51@0410@010@400H61P8010@400@0000002<S
8`0S8b<0PX:20P27QhL0102>SXh0YjNW0:NWY`2TY:@20::RXP0409JFUP2CTi<0Ti>C09nOW`<0X:2P
0P2RXZ80102CTi<0VYZJ09ZJVP2/[:`20:2PX00409BDU02FUYH0UYJF0861P@80Lg=c00@0U9BD09fM
W@2MWId0OWin0P1aLG40101PH600C4a<04a<C01?Cdl206YZJP0409nOW`2_[jl0[jn_09JFUP80CTi>
00@03Ph>00P8200820P02PX:0P0/;2`0100l?3`0?Shn03hn?P0h>3P2028R8P0400/;2`0@4100410@
00X:2P802@T900@0410@02DU9@0U9BD0>c/k0P1JFUX0101aLG40GUiN05iNGP0d=3@201PH600401TI
6@0J6QX06QXJ01<C4`8051@D00@02`/;00X:2P0:2PX030`<0P0D51@0100K6a/0<C4a034a<@1BDU82
05mOG`0405iNGP1[Jf/0Jf][07IfMP80LW9b00@0LG5a06a/K01/K6`0H61P0P1GEeL0101UIFD0I6AT
06ATI01CDe<2059BDP0405IFEP1CDe<0De=C05UIF@80H61P00@0IFEU06=SH`1SHf<0F5QH0P1:BTX0
1018B4P0DE5A055AD@1<C4`204I6AP0404Y:BP19BDT0BDU9051@D080IfMW00<0LG5a06a/K01/K6`0
0`1^KVh0101TI6@0Fe]K05]KF`11@D4202/[:`0402LW9`0];Bd0;Bd]02HV9P80<30`00@0@T920410
@010@400?clo0P0g=cL0100b<S807alO01lO7`0W9bL203/k>`0402/[:`0a<C40<C4a03dm?@80P820
00@0_kno04m?C`1?Cdl0@T920P1=CDd0100k>c/0?3`l03`l?017AdL204U9B@0404M7A`12@T80@T92
059BDP80De=C00@0CTi>04Y:BP1:BTX0DU9B0P1DE5@01015ADD0HF5Q065QH@20P80205MGE`0304I6
AP1>CTh0CTi>00<0BTY:00@0AdM704Q8B018B4P0AdM70P1BDU80101FEUH0EEEE05EEE@1:BTX204U9
B@040410@015ADD0ADE504=3@`80?Shn00@0ADE504U9B@19BDT0CDe=0`16ATH204A4A004065QH@2K
Vi/0Vi^K0;Jf]P80^k^k00@0T92@04E5A@15ADD04Q8B0P0A4A4010061PH010@400@410061PH20041
0@0400L71`092@T02@T9000000801`L700@01@D500H61P061PH00`<30P0410@0000400/;2`061PH0
1PH600X:2P800P820`030`<0100<30`00000000000030`<200D51@0400H61P0820P020P800T92@80
0`<300@010@400P8200820P02`/;0P061PH010030`<01`L700L71`0410@200H61P0400<30`010@40
0@4100H61P801`L700@0000000D51@051@D03Ph>0P0=3@d0100<30`00P8200820P00000200820P04
00P820020P800P8200<30`<01PH60P030`<0100:2PX010@400@410051@D200410@0400<30`0=3@d0
3@d=00L71`801PH600@020P800<30`030`<01PH60P051@D300d=3@0300P820030`<00`<300<01PH6
0`071`L0100Y:BT08b<S02<S8`0^;Rh201/K6`040410@01QHF40HF5Q06ATI080Jf][00@0DE5A02LW
9`0W9bL030`<0P061PH00`071`L01@D500D51@0300820P04014A4@1HF5P0F5QH08f=S@80QHF500@0
Vi^K09nOW`2OWil0Y:BT0P2NWYh0102DU9@0YJFU0:FUY@2XZ:P20:VYZ@040:FUY@2HV9P0V9RH09^K
V`80YZJV00<0ZJVY09fMW@2MWId00`2BTY801022PX80QHF508F5Q@2EUID2079bLP0405=CD`1FEUH0
EUIF06][J`80TI6A00@0Z:RX0:BTY02TY:@0WIfM0P2:RXX0101HF5P06ATI01TI6@0820P2020P8004
04Y:BP1cLg<0Lg=c07]kN`80NGUi00@0JVYZ05aLG01LG5`0HF5Q0P1LG5`0100j>SX08R8R028R8P0E
5AD200L71`0400`<300T92@092@T04U9B@80FUYJ00@0Kfm_06i^KP1^KVh0IVIV0P1LG5`0101KFe/0
H61P061PH01MGEd205QHF0040451@@0^;Rh0;Rh^024Q8@806QXJ00@0<C4a05UIF@1IFET0IfMW0P1N
GUh0101BDU80F5QH05QHF01/K6`2071`L00406][J`1/K6`0K6a/075aL@80IfMW00@0GemO05IFEP1F
EUH0DE5A0P1CDe<0101BDU80De=C05=CD`1IFET205iNGP0405]KF`1:BTX0BTY:04I6AP80EUIF00@0
F5QH05EEE@1EEED0CDe=0P16ATH0101JFUX0J6QX06QXJ01TI6@306EUI@80I6AT00@0E5AD04I6AP16
ATH0>CTi0P0/;2`0100_;bl0A4A404A4A00k>c/2030`<00403/k>`15ADD0ADE504I6AP80=cLg00@0
71`L018B4P0B4Q809RHV0P0X:2P0101ADE40P8200820P01EEED207UiN@040<30`01IFET0FEUI04E5
A@80E5AD00@0ATI604A4A014A4@0Bd];0P18B4P0101EEED0CTi>04i>CP1BDU8204U9B@0404a<C01C
De<0De=C04i>CP80C4a<00@0>c/k05mOG`1OGel0S8b<0P1FEUH01011@D40ADE504E5A@18B4P204];
B`040492@P13@d<0@d=304I6AP80CTi>00@0D51@04Q8B018B4P0BTY:0P1;Bd/01016ATH0CTi>04i>
CP16ATH204A4A00404M7A`1:BTX0BTY:04A4A0<0@T920P0j>SX0101^KVh0WinO09nOW`2e]KD20<k>
cP0409bLW014A4@0A4A401<C4`804A4A00@02`/;00@4100410@00P820P0820P010051@D010@400@4
10051@D300@410801`L70@051@D100410@400@410000100;2`/01PH600H61P0:2PX200820P<00`<3
00@030`<0000000000000`<30P051@D010061PH020P800P820092@T200<30`0400@4100820P020P8
00/;2`801PH600@00`<300L71`071`L010@40P061PH010030`<00@4100410@061PH200L71`040000
00051@D01@D500h>3P803@d=00@030`<00820P020P8000000P020P80100820P00P8200820P030`<3
00H61P800`<300@02PX:00@4100410@01@D50P010@4010030`<03@d=00d=3@071`L200H61P0400P8
20030`<00`<300H61P801@D50`0=3@d00`0820P00`<300<30`0300H61P<01`L700@0:BTY02<S8`0S
8b<0;Rh^0P0K6a/01010@400HF5Q065QH@1TI6@206][J`04055AD@0W9bL09bLW00`<30801PH600<0
1`L700D51@051@D00`020P80100A4A40F5QH05QHF02=SHd208F5Q@0409^KV`2OWil0WinO0:BTY080
WYjN00@0U9BD0:FUY@2UYJD0Z:RX0P2YZJT0102UYJD0V9RH09RHV02KVi/20:JVYP030:VYZ@2MWId0
WIfM00<0TY:B00@0PX:208F5Q@25QHD0UIFE0P1bLW80101CDe<0EUIF05IFEP1[Jf/2096AT@040:RX
Z02TY:@0Y:BT09fMW@80RXZ:00@0F5QH01TI6@0I6AT020P80P0P8200101:BTX0Lg=c07=cL`1kNg/2
07UiN@0406YZJP1LG5`0G5aL065QH@80G5aL00@0>SXj028R8P0R8R805ADE0P071`L0100<30`092@T
02@T9019BDT205YJFP0406m_K`1^KVh0KVi^06IVIP80G5aL00@0Fe]K061PH01PH600GEeM0P1HF5P0
1011@D40;Rh^02h^;P0Q8B4201XJ6P04034a<@1IFET0FEUI06MWI`80GUiN00@0DU9B05QHF01HF5P0
K6a/0P1`L700101[Jf/0K6a/06a/K01aLG4206MWI`0405mOG`1FEUH0EUIF055AD@80De=C00@0DU9B
05=CD`1CDe<0FEUI0P1NGUh0101KFe/0BTY:04Y:BP16ATH205IFEP0405QHF01EEED0EEEE04e=C@80
ATI600@0FUYJ06QXJ01XJ6P0I6AT0`1UIFD206ATI00405ADE016ATH0ATI603Ti>@80;2`/00@0;bl_
04A4A014A4@0>c/k0P0`<300100k>c/0ADE504E5A@16ATH203Lg=`0401`L700B4Q804Q8B02HV9P80
:2PX00@0DE5A0820P020P800EEEE0P1iNGT01030`<00FEUI05UIF@15ADD205ADE00404I6AP14A4@0
A4A404];B`80B4Q800@0EEEE04i>CP1>CTh0DU9B0P19BDT0101<C4`0De=C05=CD`1>CTh204a<C004
03/k>`1OGel0GemO08b<S080EUIF00@0@D5104E5A@15ADD0B4Q80P1;Bd/01012@T80@d=304=3@`16
ATH204i>CP04051@D018B4P0B4Q804Y:BP80Bd];00@0ATI604i>CP1>CTh0ATI60P14A4@01017AdL0
BTY:04Y:BP14A4@30492@P80>SXj00@0KVi^09nOW`2OWil0]KFe0P3>c/h0102LW9`0A4A404A4A00C
4a<2014A4@0400/;2`0410@010@400820P8020P800@01@D500@4100410@01@D50`0410@200L71`40
1@D50@010@4100410@0000@02@T900@4100410@01PH60P092@T0100410@00000000000061PH200L7
1`0400P820010@400@4100D51@800`<300@010@400410@010@400P820P0820P010020P800`<300<3
0`071`L200X:2P0400D51@030`<00`<300H61P<01@D50`010@4200820P0400P820092@T02@T900@4
10800P8200@02@T900@4100410@01`L70P020P80100410@00000000000020P820000000400@41005
1@D01@D500<30`8010@400@020P800<30`030`<02`/;0P061PH010071`L01PH600H61P0410@20041
0@0400P8200<30`030`<00X:2P8010@400@01@D500X:2P0:2PX00`<30P0;2`/0100[:b/09bLW02LW
9`0f=SH2028R8P0403De=@1gMgL0MgMg07MgM`80IFEU00<0>3Ph00`<300<30`00`0820P010071`L0
20P800P820020P820000000402h^;P20P800P82008R8R080TY:B00@0YjNW0:BTY02TY:@0Z:RX0P2D
U9@0102ATI40[Zj^0:j^[P2b/[820;Bd]0040:RXZ02?Shl0Shn?09bLW080ZZZZ00@0ZJVY0:n_[`2_
[jl0[Zj^0P2CTi<01027QhL0WYjN09jNWP2HV9P207inOP0408J6QP2ATI40TI6A08n?S`80UYJF00@0
V9RH09:BTP2BTY80SHf=0P1hN7P0101@D500@T920492@P1FEUH206IVIP0407YjNP21PH40PH6107Mg
M`80Lg=c00@0L71`06a/K01/K6`0JVYZ0P1YJFT0101LG5`0DU9B059BDP0n?Sh201TI6@0401dM7@0Z
:RX0:RXZ03/k>`80D51@00@0O7al08n?S`2?Shl0UYJF0P2CTi<0102?Shl0QXJ608J6QP22PX8208^;
R`0408N7Q`20P800P820075aL@80HF5Q00@0GEeM06e]K@1]KFd0O7al0P1gMgL0101MGEd0BDU904U9
B@1BDU8205YJFP0406ATI01`L700L71`06MWI`80Fe]K00@0E5AD04m?C`1?Cdl0E5AD0P1GEeL3055A
D@0405UIF@1NGUh0GUiN05mOG`80G5aL00<0F5QH05UIF@1IFET00`1LG5`0101>CTh0CDe=04e=C@1K
Fe/305iNGP80EUIF00@0CTi>055AD@1ADE40C4a<0P17AdL0100k>c/0<S8b038b<P0b<S8204Q8B004
04I6AP0a<C40<C4a03Lg=`80Bd];00@0A4A402h^;P0^;Rh0:RXZ0P0g=cL0100c<c<0C4a<04a<C02;
Rh/20::RXP04065QH@1YJFT0JFUY0<71`@80LW9b00@0B4Q8059BDP1BDU80D51@0P17AdL01014A4@0
C4a<04a<C01XJ6P205=CD`0404e=C@1<C4`0C4a<04Y:BP80D51@00@0BTY:051@D01@D500@4100P1H
F5P0102=SHd0GEeM05eMG@11@D4204U9B@0304Q8B014A4@0A4A400<0BTY:00@0ATI6059BDP1BDU80
FEUI0P1<C4`0101=CDd0B4Q804Q8B017AdL204];B`0404A4A01:BTX0BTY:04E5A@80A4A40`10@400
100e=CD0?clo03lo?`1dM7@209NGU`040;Jf]P3<c<`0c<c<09VIV@80?3`l00@06ATI00@4100410@0
10@40`061PH200L71`0300<30`020P800P8200<01PH600@00`<300T92@092@T01`L70P051@D00004
00H61P020P800P8200L71`802@T900@02PX:00D51@051@D010@40P061PH010020P801@D500D51@03
0`<200820P0400/;2`051@D01@D500H61P802PX:00<020P800@4100410@00`051@D010071`L01@D5
00D51@071`L200T92@0400P820000000000000D51@800`<300@010@400T92@092@T01@D50P010@40
10061PH00`<300<30`030`<200L71`0400<30`020P800P8200T92@<00@410P061PH010092@T01PH6
00H61P061PH200820P0400<30`051@D01@D500<30`802PX:00<02`/;00410@010@400`0410@01001
0@402PX:00X:2P051@D200@4100400H61P0L71`071`L02h^;P809bLW00@0:2PX02/[:`0[:b/07QhN
0P1SHf<0101RHV80BDU904U9B@0J6QX200<30`0400820P0410@010@400h>3P802`/;00@00@4100l?
3`0?3`l0Fe]K0P25QHD0101mOGd0VIVI09VIV@2SXj<209jNWP040:JVYP2JVYX0VYZJ09bLW080ZJVY
00@0Z:RX0:BTY02TY:@0UiNG0P24Q8@0102BTY80YZJV0:JVYP2QXJ4209bLW00409>CT`24Q8@0Q8B4
08j>SP<0WinO0P2IVIT0102HV9P0XJ6Q0:6QX@2LW9`209ZJVP0409JFUP23Ph<0Ph>308J6QP80T92@
00@0X:2P0;:b/P2b/[80YZJV0P1oOgl0101[Jf/0IVIV06IVIP1GEeL2061PH00406i^KP1VIVH0IVIV
05mOG`80E5AD00@0ADE50492@P12@T80>3Ph0P0B4Q80100D51@0>CTi03Ti>@1RHV8208F5Q@04092@
T027QhL0QhN708R8R0<0RHV90P22PX80101lO7`0N7Qh07QhN01hN7P207YjNP0407UiN@1lO7`0O7al
07emO@<0MWIf0P1jNWX0101hN7P0KFe]06e]K@1YJFT205aLG00405EEE@1PH600H61P05eMG@80FUYJ
00@0G5aL05iNGP1NGUh0GUiN0P1TI6@0101YJFT0GUiN05iNGP1GEeL205YJFP0405MGE`1MGEd0GEeM
06=SH`80GUiN00@0F5QH059BDP1BDU80CDe=0P1CDe<0101FEUH0EeMG05MGE`1JFUX205IFEP0404a<
C012@T80@T9204A4A080@D5100@0?Cdm04M7A`17AdL0A4A40P15ADD01010@400<30`030`<00o?cl2
04E5A@0403Lg=`0f=SH0=SHf03Ph>080?clo00@0DU9B09FEU@2EUID0TI6A0P2JVYX0101iNGT0KFe]
06e]K@2l_;`20820P0<0BTY:00@0CTi>04Y:BP1:BTX0A4A40P1FEUH0101YJFT0B4Q804Q8B01<C4`2
055AD@0404U9B@1ADE40DE5A055AD@80F5QH00@0ADE505ADE01DE5@0QhN70P1JFUX01012@T80C4a<
04a<C019BDT20492@P0404m?C`17AdL0AdM704I6AP80DU9B00@0FUYJ051@D01@D500Cdm?0P1;Bd/0
1019BDT0ATI604I6AP13@d<204I6AP0403`l?010@400@41004M7A`80A4A400@0=cLg04M7A`17AdL0
J6QX0P2DU9@0102k^k/0aLG50<G5a@2CTi<2038b<P0401XJ6P061PH01PH600T92@801`L700@020P8
00D51@051@D01`L70P020P8010030`<01`L700L71`030`<200@410401@D50@092@T100T92@0000@0
1PH600820P020P801`L70P092@T0100:2PX01@D500D51@0410@200H61P0400820P051@D01@D500<3
0`800P8200@02`/;00D51@051@D01PH60P0:2PX00`0820P010@400@4100300D51@0400L71`051@D0
1@D500L71`802@T900@020P80000000000001@D50P030`<0100410@02@T900T92@051@D200410@04
00H61P030`<00`<300<30`801`L700@00`<300820P020P802@T90`010@4200H61P0400T92@061PH0
1PH600H61P800P8200@00`<300D51@051@D00`<30P0:2PX00`0;2`/00@4100410@0300@410040041
0@0:2PX02PX:00D51@8010@400@01PH601`L700L71`0;Rh^0P0W9bL0100X:2P0:b/[02/[:`0N7Qh2
06=SH`04069RHP19BDT0BDU901XJ6P800`<300@00P8200@4100410@03Ph>0P0;2`/010010@403`l?
00l?3`1KFe/208F5Q@0407emO@2IVIT0VIVI0:>SX`80WYjN00@0YZJV09ZJVP2JVYX0W9bL0P2YZJT0
102XZ:P0Y:BT0:BTY02GUiL208B4Q00409:BTP2VYZH0YZJV0:6QX@80W9bL00@0Ti>C08B4Q024Q8@0
SXj>0`2OWil209VIV@0409RHV02QXJ40XJ6Q09bLW080VYZJ00@0UYJF08>3P`23Ph<0QXJ60P2@T900
102PX:00/[:b0;:b/P2VYZH207moO`0406][J`1VIVH0IVIV05MGE`80H61P00@0KVi^06IVIP1VIVH0
GemO0P1DE5@01015ADD0@T920492@P0h>3P2018B4P0401@D500i>CT0>CTi069RHP80QHF500@0T92@
08N7Q`27QhL0R8R80`29RHT208:2PP0407alO01hN7P0N7Qh07QhN080NWYj00@0NGUi07alO01lO7`0
OGem0`1fMWH207YjNP0407QhN01]KFd0KFe]06UYJ@80G5aL00@0EEEE061PH01PH600GEeM0P1JFUX0
101LG5`0GUiN05iNGP1NGUh206ATI00406UYJ@1NGUh0GUiN05MGE`80FUYJ00@0EeMG05eMG@1MGEd0
Hf=S0P1NGUh0101HF5P0DU9B059BDP1=CDd205=CD`0405IFEP1GEeL0EeMG05YJFP80EUIF00@0C4a<
0492@P12@T80A4A40P11@D40100m?Cd0AdM704M7A`14A4@204E5A@040410@00`<300<30`03lo?`80
ADE500@0=cLg03Hf=P0f=SH0>3Ph0P0o?cl0101BDU80UIFE09FEU@2ATI4209ZJVP0407UiN@1]KFd0
KFe]0;bl_080P8200`1:BTX0101>CTh0BTY:04Y:BP14A4@205IFEP0406UYJ@18B4P0B4Q804a<C080
DE5A00@0BDU9055AD@1ADE40DE5A0P1HF5P01015ADD0E5AD05ADE027QhL205YJFP040492@P1<C4`0
C4a<04U9B@80@T9200@0Cdm?04M7A`17AdL0ATI60P1BDU80101JFUX0D51@051@D01?Cdl204];B`04
04U9B@16ATH0ATI604=3@`80ATI600@0?3`l0410@010@400AdM70P14A4@0100g=cL0AdM704M7A`1X
J6P209BDU0040;^k^`35aLD0aLG509>CT`80<S8b00@06QXJ00H61P061PH02@T90P071`L0100820P0
1@D500D51@071`L200820P0400<30`071`L01`L700<30`8010@40@051@D100T92@402@T900000`09
2@T00`<300<30`0300<30`0400820P0410@010@400L71`800@4100@010@400L71`071`L020P80`06
1PH200P8200400<30`051@D01@D500L71`800P8200@010@400820P020P800`<30P0410@010051@D0
1`L700L71`061PH300820P<00`<30P0820P300L71`04000000020P800P8200`<30800`<300@00P82
00<30`030`<030`<0P010@40100820P010@400@410061PH200D51@0400H61P092@T02@T900@41080
0`<300@01`L700<30`030`<00P820P061PH300P8200400D51@0;2`/02`/;00@4108020P800@03@d=
02h^;P0^;Rh0;bl_0P0V9RH0100Z:RX020P800P8200C4a<3059BDP80<c<c00@030`<00/;2`0;2`/0
2@T90P030`<0100:2PX03Ph>00h>3P00000203hn?P0408R8R023Ph<0Ph>308N7Q`80W9bL00@0X:2P
09fMW@2MWId0VYZJ0P2CTi<0102MWId0YjNW0:NWY`2WYjL208n?S`0407IfMP1lO7`0O7al08b<S080
WYjN00@0YjNW0:6QX@2QXJ40SHf=0P1mOGd0102<S8`0VIVI09VIV@2IVIT209ZJVP0409VIV@2CTi<0
Ti>C08N7Q`<0UIFE0P20P800102<S8`0XZ:R0::RXP2WYjL209^KV`0408N7Q`1VIVH0IVIV05=CD`80
CTi>00@0Bd];05IFEP1FEUH0GemO0P1LG5`0101MGEd0@d=304=3@`0d=3@203<c<`0400`<300M7Ad0
7AdM038b<P80E5AD00@0J6QX07]kN`1kNg/0OGem0`1iNGT206i^KP04079bLP1dM7@0M7Ad075aL@80
IVIV00@0J6QX06YZJP1ZJVX0J6QX0P1TI6@0101UIFD0Jf][06][J`1SHf<206IVIP0407=cL`1gMgL0
MgMg07YjNP80NGUi00@0KFe]06UYJ@1YJFT0JVYZ0P1VIVH0101RHV80JFUY06UYJ@1`L702079bLP04
07MgM`1[Jf/0Jf][06MWI`80MGEe00@0Lg=c06a/K01/K6`0JVYZ0P1VIVH0101ZJVX0K6a/06a/K01O
Gel305QHF080De=C00@0D51@055AD@1ADE40De=C0P1ADE40101?Cdl0BDU904U9B@0m?Cd303lo?`80
@41000@0>CTi03Xj>P0j>SX0Cdm?0P1:BTX0100m?Cd0?3`l03`l?00X:2P204m?C`0409>CT`2j^[X0
^[Zj09RHV080X:2P00@0Ng]k06a/K01/K6`0`L710P2CTi<304];B`0404Y:BP1<C4`0C4a<04e=C@80
D51@00@0DU9B0410@010@400Bd];0P1?Cdl0101=CDd0DE5A055AD@1BDU8205QHF00404M7A`1EEED0
EEEE08R8R080EEEE00@0ATI604i>CP1>CTh0ADE50P10@400101DE5@0ADE504E5A@14A4@204i>CP04
04m?C`1;Bd/0Bd];051@D080CDe=00<0B4Q80410@010@4000`0o?cl0100n?Sh0@T920492@P18B4P2
0410@00403hn?P14A4@0A4A4079bLP80WYjN00@0]KFe0<K6aP36a/H0Q8B40P0/;2`0100K6a/01PH6
00H61P051@D200820P0400H61P051@D01@D500L71`800P8200@0000000T92@092@T010@40P020P81
00P820403`l?0@0?3`l0000400820P061PH01PH600410@8000000`0410@010092@T020P800P82004
10@200820P0400D51@0820P020P800<30`801`L700@00P8200P8200820P00@410P0:2PX0100820P0
1PH600H61P0820P200d=3@0400P820071`L01`L700T92@<00`<30P0410@0100;2`/01PH600H61P03
0`<200H61P0400<30`020P800P8200P820801`L700@00@4100<30`030`<010@40P0820P0100410@0
0@4100410@061PH200P8200400H61P071`L01`L700<30`801@D500@02PX:00T92@092@T000000P09
2@T0100?3`l02`/;00/;2`0;2`/200T92@0400H61P020P800P8201XJ6P80=CDe00@0:b/[02DU9@0U
9BD0@4100P0P8200100<30`0@4100410@00o?cl201lO7`0400D51@061PH01PH600/;2`801PH600@0
0`<300P8200820P01@D50P1QHF401027QhL0Ogmo07moO`2?Shl209VIV@<0WinO00@0VIVI09NGU`2G
UiL0Y:BT0P2XZ:P0102WYjL0WIfM09fMW@2ATI4209ZJVP0409VIV@2LW9`0W9bL0:n_[`80WYjN00@0
N7Qh071`L01`L700Rh^;0P2RXZ80102QXJ40Vi^K09^KV`2PX:0208^;R`0406a/K01fMWH0MWIf07Ui
N@80LG5a00@0P82009ZJVP2JVYX0W9bL0P2<S8`0101dM7@0ADE504E5A@17AdL205mOG`0406MWI`1^
KVh0KVi^061PH080ADE500@0<c<c02TY:@0Y:BT08B4Q0P0V9RH0100P8200?Shn03hn?P16ATH206MW
I`0407AdM01_Kfl0Kfm_06ATI080Fe]K00@0GemO05aLG01LG5`0FEUI0P1GEeL0101>CTh0@d=304=3
@`1@D50205YJFP0405UIF@1ADE40DE5A04m?C`80Fe]K00@0FEUI05eMG@1MGEd0K6a/0P1dM7@0101k
Ng/0Ogmo07moO`1lO7`207AdM00306e]K@1^KVh0KVi^00<0K6a/00@0M7Ad079bLP1bLW80Lg=c0P1j
NWX00`1hN7P0MWIf07IfMP0307AdM00407EeM@1]KFd0KFe]07IfMP80PH6100@0L71`06a/K01/K6`0
KVi^0P1PH600101EEED0C4a<04a<C01EEED205eMG@04051@D01?Cdl0Cdm?04M7A`80?Cdm00@0<S8b
03Hf=P0f=SH0<C4a0P14A4@0101LG5`0B4Q804Q8B00U9BD201TI6@0405=CD`2HV9P0V9RH0:FUY@80
ZZZZ00@0X:2P0:>SX`2SXj<0L71`0P1DE5@0102^[Zh0YZJV0:JVYP1BDU8204Y:BP0404U9B@16ATH0
ATI6059BDP80EUIF00<0EeMG055AD@1ADE400`1=CDd0101?Cdl0ATI604I6AP18B4P205EEE@0404Y:
BP1;Bd/0Bd];08J6QP80G5aL00@0BTY:05=CD`1CDe<0CTi>0P1@D500101LG5`0BTY:04Y:BP15ADD2
04a<C00404i>CP1ADE40DE5A055AD@80B4Q800@0BTY:0492@P12@T80AdM70P13@d<0101<C4`0B4Q8
04Q8B016ATH203hn?P040492@P16ATH0ATI60861P@80ZJVY00@0/K6a0;no_`2o_kl0OGem0P0f=SH0
100L71`01`L700L71`0820P200D51@0400L71`0820P020P800L71`801@D500@030`<00L71`071`L0
1@D50P020P8100H61P4020P80@0820P0000400820P061PH01PH600410@8000000`0410@010092@T0
20P800P8200410@200820P0400D51@0820P020P800<30`801`L700@00P8200P8200820P00@410P0:
2PX0100820P01PH600H61P0820P200d=3@0400P820071`L01`L700T92@<00`<30P0410@0100;2`/0
1PH600H61P030`<200H61P0400<30`020P800P8200P820801`L700@00@4100<30`030`<010@40P08
20P0100410@00@4100410@061PH200P8200400H61P071`L01`L700<30`801@D500@02PX:00T92@09
2@T000000P092@T0100?3`l02`/;00/;2`0;2`/200T92@0400H61P020P800P8201XJ6P80=CDe00@0
:b/[02DU9@0U9BD0@4100P0P8200100<30`0@4100410@00o?cl201lO7`0400D51@061PH01PH600/;
2`801PH600@00`<300P8200820P01@D50P1QHF401027QhL0Ogmo07moO`2?Shl209VIV@<0WinO00@0
VIVI09NGU`2GUiL0Y:BT0P2XZ:P0102WYjL0WIfM09fMW@2ATI4209ZJVP0409VIV@2LW9`0W9bL0:n_
[`80WYjN00@0N7Qh071`L01`L700Rh^;0P2RXZ80102QXJ40Vi^K09^KV`2PX:0208^;R`0406a/K01f
MWH0MWIf07UiN@80LG5a00@0P82009ZJVP2JVYX0W9bL0P2<S8`0101dM7@0ADE504E5A@17AdL205mO
G`0406MWI`1^KVh0KVi^061PH080ADE500@0<c<c02TY:@0Y:BT08B4Q0P0V9RH0100P8200?Shn03hn
?P16ATH206MWI`0407AdM01_Kfl0Kfm_06ATI080Fe]K00@0GemO05aLG01LG5`0FEUI0P1GEeL0101>
CTh0@d=304=3@`1@D50205YJFP0405UIF@1ADE40DE5A04m?C`80Fe]K00@0FEUI05eMG@1MGEd0K6a/
0P1dM7@0101kNg/0Ogmo07moO`1lO7`207AdM00306e]K@1^KVh0KVi^00<0K6a/00@0M7Ad079bLP1b
LW80Lg=c0P1jNWX00`1hN7P0MWIf07IfMP0307AdM00407EeM@1]KFd0KFe]07IfMP80PH6100@0L71`
06a/K01/K6`0KVi^0P1PH600101EEED0C4a<04a<C01EEED205eMG@04051@D01?Cdl0Cdm?04M7A`80
?Cdm00@0<S8b03Hf=P0f=SH0<C4a0P14A4@0101LG5`0B4Q804Q8B00U9BD201TI6@0405=CD`2HV9P0
V9RH0:FUY@80ZZZZ00@0X:2P0:>SX`2SXj<0L71`0P1DE5@0102^[Zh0YZJV0:JVYP1BDU8204Y:BP04
04U9B@16ATH0ATI6059BDP80EUIF00<0EeMG055AD@1ADE400`1=CDd0101?Cdl0ATI604I6AP18B4P2
05EEE@0404Y:BP1;Bd/0Bd];08J6QP80G5aL00@0BTY:05=CD`1CDe<0CTi>0P1@D500101LG5`0BTY:
04Y:BP15ADD204a<C00404i>CP1ADE40DE5A055AD@80B4Q800@0BTY:0492@P12@T80AdM70P13@d<0
101<C4`0B4Q804Q8B016ATH203hn?P040492@P16ATH0ATI60861P@80ZJVY00@0/K6a0;no_`2o_kl0
OGem0P0f=SH0100L71`01`L700L71`0820P200D51@0400L71`0820P020P800L71`801@D500@030`<
00L71`071`L01@D50P020P8100H61P4020P80@0820P0000400820P051@D01@D500X:2P801`L700@0
0@4100820P020P800P820P092@T010051@D00P8200820P010@4200T92@0400D51@0820P020P800H6
1P8020P800@00`<300H61P061PH030`<0P071`L010061PH020P800P820092@T200D51@0300T92@07
1`L01`L700<00@4100@010@40000000000000@410P0410@0100:2PX00@4100410@030`<200/;2`04
00L71`0820P020P800<30`8020P800@010@400D51@051@D020P80P071`L00`0820P01`L700L71`03
00H61P0400P8200@4100410@00d=3@8030`<00@03@d=00P8200820P0410@0P0410@010092@T0410@
010@400W9bL203De=@0402HV9P0K6a/06a/K04M7A`80De=C00@0;bl_03@d=00d=3@0<C4a0P0820P0
10092@T02PX:00X:2P061PH200@410<0000000@0;Bd]08^;R`2;Rh/0R8R80P2=SHd0102EUID0RXZ:
08Z:RP2EUID209^KV`04092@T02EUID0UIFE09jNWP80WIfM00@0Z:RX0;Jf]P2f][H0[Jf]0P2VYZH0
102RXZ80XJ6Q0:6QX@2EUID207AdM00406QXJ01oOgl0Ogmo09fMW@80/[:b00@0Zj^[09NGU`2GUiL0
WinO0P2=SHd0101JFUX0AdM704M7A`19BDT2075aL@0409>CT`2TY:@0Y:BT0:6QX@80T92@00@0LW9b
04m?C`1?Cdl0CDe=0P1;Bd/01012@T80@D510451@@0k>c/203De=@040410@011@D40@D5103Xj>P80
=3@d00@0<C4a04A4A014A4@0BTY:0P1ADE40101<C4`0?clo03lo?`0l?3`203Xj>P0403/k>`12@T80
@T9203`l?080<c<c00@0<30`02PX:00X:2P0:2PX0P0P8200100T92@0;Bd]02d];@0_;bl203De=@<0
ADE500@0CTi>05YJFP1JFUX0I6AT0P1RHV80101SHf<0IFEU06EUI@1NGUh305YJFP80EUIF00@0G5aL
05]KF`1KFe/0EeMG0P1NGUh0101OGel0G5aL05aLG01TI6@206YZJP04075aL@1eMGD0MGEe06m_K`80
KFe]00@0LG5a07alO01lO7`0Ogmo0P1`L700101SHf<0FUYJ05YJFP1MGEd205aLG00404i>CP1EEED0
EEEE05EEE@80ADE500@0;2`/02h^;P0^;Rh0:RXZ0P10@400101BDU80@T920492@P0b<S8204=3@`04
09BDU02YZJT0ZJVY09RHV080WIfM00@0WYjN0:j^[P2^[Zh0JVYZ0P1BDU80102GUiL0Xj>S0:>SX`1K
Fe/204Y:BP0404e=C@17AdL0AdM704i>CP80CDe=00@0Cdm?05YJFP1JFUX0Cdm?0P1@D500101DE5@0
B4Q804Q8B01=CDd205IFEP0404U9B@1:BTX0BTY:07emO@80EeMG00@0Cdm?05EEE@1EEED0B4Q80P1>
CTh0101@D500ADE504E5A@18B4P3051@D080AdM700@0C4a<04U9B@19BDT0B4Q80`12@T8203Xj>P04
04a<C018B4P0B4Q804e=C@80ADE500@0?Cdm04Q8B018B4P0S8b<0P2c/k<0102e]KD0Z:RX0:RXZ01T
I6@202LW9`0401LG5`0>3Ph03Ph>00<30`800P8200@010@400X:2P0:2PX00P820P030`<010051@D0
3`l?00l?3`051@D200410@400`<30@0820P100P820000`061PH010092@T01`L700L71`061PH300<3
0`801PH600@01@D500L71`071`L00`<30P0820P300@4100400H61P0820P020P800@410800P8200@0
20P800820P020P800P820`030`<200@4100400820P0;2`/02`/;00T92@8010@400@00@4100T92@09
2@T02`/;0P0:2PX010051@D00000000000030`<200D51@0400820P092@T02@T900<30`802@T900@0
1`L700/;2`0;2`/03Ph>0P010@4010020P800`<300<30`0410@200<30`040000000;2`/02`/;00d=
3@800P8200@01PH600@4100410@03Ph>0P051@D010020P8071`L01`L700^;Rh203<c<`04028R8P0W
9bL09bLW0492@P80E5AD00@092@T01DE5@0E5AD0820P0P0B4Q8010071`L00P8200820P071`L20082
0P0400@4100000000000055AD@80TI6A00@0PX:209^KV`2KVi/0WinO0P2>SXh0102KVi/0UiNG09NG
U`2>SXh2092@T00409:BTP2OWil0WinO0;Fe]@80_;bl00<0YjNW09RHV02HV9P00`2FUYH01026QXH0
Ph>308>3P`2CTi<209JFUP040:2PX02XZ:P0Z:RX09VIV@80UIFE00@0Zj^[08^;R`2;Rh/0>3Ph0P0O
7al0100_;bl0F5QH05QHF01bLW8207IfMP0406MWI`1EEED0EEEE04Y:BP80ATI600@0;Bd]01lO7`0O
7al09bLW0P0];Bd01012@T80CTi>04i>CP1BDU8204i>CP0304U9B@11@D40@D5100<0=CDe00@0<c<c
02PX:00X:2P0820P0P0C4a<0100J6QX07QhN01hN7P0D51@201dM7@0401PH600F5QH05QHF00h>3P80
2@T900@01@D500L71`071`L01PH60P0820P0100=3@d05QHF01HF5P0Y:BT201lO7`0401`L700W9bL0
9bLW03Ph>080>c/k00@0>CTi03dm?@0m?Cd0?Cdm0`0h>3P203Xj>P0303De=@0c<c<0<c<c00<0<30`
00@0@41004Y:BP1:BTX0@d=30P15ADD0101CDe<0GEeM05eMG@1HF5P205aLG00406i^KP1bLW80LW9b
07=cL`80M7Ad0`1fMWH0101`L700JVYZ06YZJP1RHV8205QHF00404Q8B017AdL0AdM703`l?080<C4a
00@09BDU03Xj>P0j>SX0@d=30P0`<300100j>SX0PH610861P@2=SHd208B4Q0040:>SX`27QhL0QhN7
08N7Q`80Zj^[00@0Fe]K05MGE`1GEeL0NGUi0P2:RXX0101LG5`0@4100410@017AdL204U9B@04055A
D@1=CDd0CDe=04i>CP80BDU900@0ATI604];B`1;Bd/0CDe=0P16ATH00`1<C4`0E5AD05ADE00304Q8
B00407UiN@1EEED0EEEE03hn?P80AdM700@0@D5104I6AP16ATH0Cdm?0P1BDU801018B4P0EEEE05EE
E@1LG5`204Q8B004055AD@1<C4`0C4a<04U9B@80A4A400@0>SXj03dm?@0m?Cd0C4a<0P12@T801019
BDT0@D510451@@0g=cL205EEE@0409>CT`2b/[80/[:b0;Zj^P80UIFE00@0EUIF02XZ:P0Z:RX06ATI
0P061PH010092@T01PH600H61P00000200D51@0400410@092@T02@T900@4108030`<00@00P820041
0@010@401@D50P0=3@d000<01PH600@02@T900L71`071`L01PH60`030`<200H61P0400D51@071`L0
1`L700<30`8020P80`0410@010061PH020P800P8200410@200820P0400P820020P800P8200820P<0
0`<30P0410@010020P802`/;00/;2`092@T200@4100400410@092@T02@T900/;2`802PX:00@01@D5
0000000000000`<30P051@D010020P802@T900T92@030`<200T92@0400L71`0;2`/02`/;00h>3P80
0@4100@00P8200<30`030`<010@40P030`<0100000002`/;00/;2`0=3@d200820P0400H61P0410@0
10@400h>3P801@D500@00P8201`L700L71`0;Rh^0P0c<c<0100R8R809bLW02LW9`12@T8205ADE004
02@T900E5AD05ADE020P80804Q8B00@01`L700820P020P801`L70P020P80100410@000000000001A
DE42096AT@0408:2PP2KVi/0Vi^K09nOW`80SXj>00@0Vi^K09NGU`2GUiL0SXj>0P2@T900102BTY80
WinO09nOW`2e]KD20;bl_0030:NWY`2HV9P0V9RH00<0UYJF00@0QXJ608>3P`23Ph<0Ti>C0P2FUYH0
102PX:00Z:RX0:RXZ02IVIT209FEU@040:^[Z`2;Rh/0Rh^;03Ph>0807alO00@0;bl_05QHF01HF5P0
LW9b0P1fMWH0101WIfL0EEEE05EEE@1:BTX204I6AP0402d];@0O7al07alO02LW9`80;Bd]00@0@T92
04i>CP1>CTh0DU9B0P1>CTh00`19BDT0@D510451@@0303De=@0403<c<`0X:2P0:2PX020P80804a<C
00@06QXJ01hN7P0N7Qh051@D0P0M7Ad0100H61P05QHF01HF5P0>3Ph200T92@0400D51@071`L01`L7
00H61P8020P800@03@d=01HF5P0F5QH0:BTY0P0O7al0100L71`09bLW02LW9`0h>3P203/k>`0403Ti
>@0m?Cd0?Cdm03dm?@<0>3Ph0P0j>SX00`0e=CD0<c<c03<c<`03030`<0040410@01:BTX0BTY:04=3
@`80ADE500@0De=C05eMG@1MGEd0F5QH0P1LG5`0101^KVh0LW9b079bLP1cLg<207AdM0<0MWIf00@0
L71`06YZJP1ZJVX0HV9R0P1HF5P01018B4P0AdM704M7A`0l?3`2034a<@0402DU9@0j>SX0>SXj04=3
@`80<30`00@0>SXj0861P@21PH40SHf=0P24Q8@0102SXj<0QhN708N7Q`27QhL20:^[Z`0405]KF`1G
EeL0EeMG07UiN@80RXZ:00@0G5aL0410@010@400AdM70P19BDT0101ADE40CDe=04e=C@1>CTh204U9
B@0404I6AP1;Bd/0Bd];04e=C@80ATI600<0C4a<05ADE01DE5@00`18B4P0101iNGT0EEEE05EEE@0n
?Sh204M7A`040451@@16ATH0ATI604m?C`80DU9B00@0B4Q805EEE@1EEED0G5aL0P18B4P0101ADE40
C4a<04a<C019BDT204A4A00403Xj>P0m?Cd0?Cdm04a<C080@T9200@0BDU90451@@11@D40=cLg0P1E
EED0102CTi<0/[:b0;:b/P2j^[X209FEU@0405IFEP0Z:RX0:RXZ01TI6@801PH600@02@T900H61P06
1PH000000P051@D010010@402@T900T92@0410@200`<300400820P010@400@4100D51@803@d=0000
10020P802`/;00/;2`020P8200410@0400D51@030`<00`<300P820801PH600@00`<300@4100410@0
0`<30P071`L0100410@00`<300<30`051@D200P8200400820P0820P020P800P820802@T900@00`<3
00P8200820P00P820P030`<010092@T01@D500D51@071`L200@4100400P820030`<00`<300@41080
3`l?00@020P800<30`030`<000000P0410@010051@D03Ph>00h>3P010@4300H61P8020P800@010@4
00D51@051@D000000P071`L300@4100400P820000000000000410@8010@400<0410@00P8200820P0
0`061PH0100000007AdM01dM7@0e=CD202HV9P0402TY:@1;Bd/0Bd];03/k>`80@41000@0>SXj02d]
;@0];Bd06QXJ0P061PH010010@400P8200820P061PH200P820040000000J6QX06QXJ07=cL`80Ogmo
00@0PH6109jNWP2NWYh0Vi^K0P2DU9@0102NWYh0Ti>C09>CT`2>SXh30820P080UiNG00@0YJFU0:VY
Z@2YZJT0XZ:R0P2MWId0102CTi<0RHV908V9R@2HV9P20:NWY`040:BTY02JVYX0VYZJ09BDU080UIFE
00@0UiNG09BDU02DU9@0Shn?0P1WIfL0100M7Ad05ADE01DE5@0W9bL202HV9P0403@d=00f=SH0=SHf
02`/;0809BDU00@0:BTY030`<00`<300=cLg0P0f=SH0100j>SX0?clo03lo?`10@40204I6AP0403dm
?@0h>3P0>3Ph03`l?080=SHf00@08b<S020P800P82007AdM0P0820P010061PH02PX:00X:2P051@D2
00h>3P0401<C4`0>3Ph03Ph>00<30`801`L700@0410@00P8200820P020P80P0410@010061PH01@D5
00D51@030`<200H61P0400@410030`<00`<300X:2P803@d=00@03`l?014A4@0A4A405QHF0P0R8R80
100P82005aLG01LG5`0K6a/202LW9`0402DU9@0Q8B408B4Q02@T90807QhN00@09BDU03De=@0e=CD0
<S8b0P0`<300100h>3P0?3`l03`l?010@40204U9B@04051@D01HF5P0F5QH06=SH`80Jf][00@0MgMg
0820P020P800P8200P1lO7`0101cLg<0HV9R069RHP1BDU8205MGE`0404];B`10@400@41003Ph>080
?clo00@0@41002h^;P0^;Rh0AdM70P2FUYH0101]KFd0FUYJ05YJFP25QHD206a/K00407UiN@2FUYH0
UYJF05IFEP80C4a<00@0F5QH07]kN`1kNg/0Fe]K0P14A4@0101EEED0C4a<04a<C01ADE4205=CD`04
05QHF018B4P0B4Q804M7A`80@D510`12@T801016ATH0DE5A055AD@19BDT203Xj>P04071`L01KFe/0
Fe]K03`l?0<0BDU90P13@d<0101=CDd0DE5A055AD@11@D4204Q8B00404a<C01:BTX0BTY:05]KF`80
CTi>00@0ATI604A4A014A4@0@D510P18B4P0101:BTX0@d=304=3@`12@T8203dm?@0403lo?`1OGel0
GemO09^KV`80`/;200@0_kno092@T02@T900Fe]K0P0V9RH300@4100400T92@0?3`l03`l?00000080
0`<300@00P8200T92@092@T00P821@030`<100D51@4020P80@0820P0000400/;2`051@D01@D500D5
1@802`/;00@01PH600D51@051@D00@410P020P80100820P01PH600H61P071`L200X:2P0400D51@07
1`L01`L700820P8020P800@01PH600D51@051@D01@D50P0=3@d0100410@00`<300<30`00000200H6
1P0400T92@071`L01`L700@410800`<300@030`<00000000000020P80P092@T010061PH02@T900T9
2@0:2PX200D51@0300<30`0410@010@400<00P8200@01PH600@4100410@000000P030`<010010@40
1PH600H61P071`L200820P04010@400<30`030`<00X:2P802`/;00@01`L700P8200820P020P80P0>
3Ph0100:2PX0:RXZ02XZ:P0g=cL202TY:@0403Lg=`1UIFD0IFEU04Q8B08092@T00@07alO01LG5`0G
5aL04a<C0P0?3`l0100820P00`<300<30`00000200L71`040000000l?3`0?3`l08J6QP80MgMg00@0
QhN709RHV02HV9P0UIFE0P2;Rh/0102@T900Rh^;08^;R`1aLG4205eMG@0406QXJ020P800P8200:6Q
X@80]KFe00@0YZJV08f=S@2=SHd0Ogmo0P2>SXh0102[Zj/0[:b/0:b/[02ATI4207inOP0408b<S02Q
XJ40XJ6Q09^KV`80PH6100@0K6a/04A4A014A4@05aLG0P0E5AD0100A4A405ADE01DE5@0H61P200H6
1P0401TI6@0l?3`0?3`l0410@080BTY:00@0D51@03lo?`0o?cl0=cLg0P0`<300100T92@0:BTY02TY
:@0/;2`202DU9@0401`L700G5aL05aLG010@40804a<C00@02PX:01@D500D51@051@D0P0O7al0100I
6AT07AdM01dM7@0S8b<2038b<P03030`<00K6a/06a/K00<07QhN00@09bLW01LG5`0G5aL03Ph>0P0K
6a/0100F5QH01`L700L71`0@410200X:2P0400/;2`0@4100410@00d=3@802PX:00@03@d=00/;2`0;
2`/01`L70P0820P0100F5QH04Q8B018B4P092@T200/;2`0401`L700O7al07alO014A4@805QHF00@0
820P01dM7@0M7Ad061PH0P0K6a/0100Z:RX0<C4a034a<@0e=CD203dm?@0404M7A`1IFET0FEUI06AT
I080LG5a00@0PH610820P020P800Ng]k0P1`L700101VIVH0G5aL05aLG01;Bd/304E5A@80A4A400@0
=CDe03<c<`0c<c<0?Shn0P1ZJVX0101GEeL0@d=304=3@`1[Jf/206m_K`0407emO@23Ph<0Ph>3061P
H080BDU900@0GemO07moO`1oOgl0Fe]K0P0k>c/0101@D500@D510451@@1GEeL205ADE00405=CD`18
B4P0B4Q804a<C080AdM70`18B4P0101<C4`0De=C05=CD`1CDe<20410@00306e]K@1JFUX0FUYJ00<0
A4A400@0?Cdm03Ti>@0i>CT0Cdm?0P1CDe<01017AdL0Bd];04];B`18B4P204m?C`0405IFEP1;Bd/0
Bd];0492@P80@D5100@0A4A40410@010@400@T920P16ATH01015ADD0@T920492@P12@T82069RHP04
0::RXP2i^KT0^KVi0:6QX@80QXJ600@0C4a<02@T900T92@010@40P020P80100;2`/010@400@41005
1@D200<30`0300D51@0410@010@400<01@D500@02`/;00410@010@401@D50P0;2`/0000400/;2`05
1@D01@D500D51@802`/;00@01PH600D51@051@D00@410P020P80100820P01PH600H61P071`L200X:
2P0400D51@071`L01`L700820P8020P800@01PH600D51@051@D01@D50P0=3@d0100410@00`<300<3
0`00000200H61P0400T92@071`L01`L700@410800`<300@030`<00000000000020P80P092@T01006
1PH02@T900T92@0:2PX200D51@0300<30`0410@010@400<00P8200@01PH600@4100410@000000P03
0`<010010@401PH600H61P071`L200820P04010@400<30`030`<00X:2P802`/;00@01`L700P82008
20P020P80P0>3Ph0100:2PX0:RXZ02XZ:P0g=cL202TY:@0403Lg=`1UIFD0IFEU04Q8B08092@T00@0
7alO01LG5`0G5aL04a<C0P0?3`l0100820P00`<300<30`00000200L71`040000000l?3`0?3`l08J6
QP80MgMg00@0QhN709RHV02HV9P0UIFE0P2;Rh/0102@T900Rh^;08^;R`1aLG4205eMG@0406QXJ020
P800P8200:6QX@80]KFe00@0YZJV08f=S@2=SHd0Ogmo0P2>SXh0102[Zj/0[:b/0:b/[02ATI4207in
OP0408b<S02QXJ40XJ6Q09^KV`80PH6100@0K6a/04A4A014A4@05aLG0P0E5AD0100A4A405ADE01DE
5@0H61P200H61P0401TI6@0l?3`0?3`l0410@080BTY:00@0D51@03lo?`0o?cl0=cLg0P0`<300100T
92@0:BTY02TY:@0/;2`202DU9@0401`L700G5aL05aLG010@40804a<C00@02PX:01@D500D51@051@D
0P0O7al0100I6AT07AdM01dM7@0S8b<2038b<P03030`<00K6a/06a/K00<07QhN00@09bLW01LG5`0G
5aL03Ph>0P0K6a/0100F5QH01`L700L71`0@410200X:2P0400/;2`0@4100410@00d=3@802PX:00@0
3@d=00/;2`0;2`/01`L70P0820P0100F5QH04Q8B018B4P092@T200/;2`0401`L700O7al07alO014A
4@805QHF00@0820P01dM7@0M7Ad061PH0P0K6a/0100Z:RX0<C4a034a<@0e=CD203dm?@0404M7A`1I
FET0FEUI06ATI080LG5a00@0PH610820P020P800Ng]k0P1`L700101VIVH0G5aL05aLG01;Bd/304E5
A@80A4A400@0=CDe03<c<`0c<c<0?Shn0P1ZJVX0101GEeL0@d=304=3@`1[Jf/206m_K`0407emO@23
Ph<0Ph>3061PH080BDU900@0GemO07moO`1oOgl0Fe]K0P0k>c/0101@D500@D510451@@1GEeL205AD
E00405=CD`18B4P0B4Q804a<C080AdM70`18B4P0101<C4`0De=C05=CD`1CDe<20410@00306e]K@1J
FUX0FUYJ00<0A4A400@0?Cdm03Ti>@0i>CT0Cdm?0P1CDe<01017AdL0Bd];04];B`18B4P204m?C`04
05IFEP1;Bd/0Bd];0492@P80@D5100@0A4A40410@010@400@T920P16ATH01015ADD0@T920492@P12
@T82069RHP040::RXP2i^KT0^KVi0:6QX@80QXJ600@0C4a<02@T900T92@010@40P020P80100;2`/0
10@400@410051@D200<30`0300D51@0410@010@400<01@D500@02`/;00410@010@401@D50P0;2`/0
000400@410000000000000@410801PH600<00`<300L71`071`L010030`<200D51@0400`<30071`L0
1`L7000000<00`<30P092@T0100410@00`<300<30`020P8200D51@0400P820030`<00`<300D51@80
2@T90`051@D010030`<02`/;00/;2`061PH200@4100400H61P030`<00`<300P820800P8200<02`/;
00H61P061PH00`071`L0100410@00@4100410@071`L200T92@0400H61P0410@010@400`<30802@T9
00@02PX:00H61P061PH010@40P051@D0100410@02`/;00/;2`051@D200<30`0400@4100A4A404A4A
01PH6080<S8b00@0<C4a03Xj>P0j>SX0CDe=0P1QHF40101LG5`0?3`l03`l?00J6QX200L71`0400/;
2`0B4Q804Q8B00X:2P8020P800@010@4000000000000410@0P1[Jf/01023Ph<0MWIf07IfMP2CTi<2
09nOW`0408j>SP1eMGD0MGEe08J6QP80Ng]k00@0Bd];03`l?00l?3`0GEeM0P25QHD0102[Zj/0]kNg
0;Ng]`2SXj<207inOP0406][J`2?Shl0Shn?0:FUY@80W9bL00@0TY:B08b<S02<S8`0Xj>S0P2^[Zh0
1021PH40FEUI05UIF@1;Bd/202l_;`0400`<30010@400@4101TI6@80=CDe00@0=3@d02h^;P0^;Rh0
A4A40`1@D50204e=C@0403Ti>@0_;bl0;bl_02h^;P809RHV00@04a<C00H61P061PH051@D0P0C4a<0
100M7Ad08B4Q024Q8@0W9bL202<S8`0402XZ:P13@d<0@d=302/[:`80;Bd]00@0>c/k0410@010@400
;bl_0P0f=SH01011@D408B4Q024Q8@0];Bd203Hf=P0403De=@0j>SX0>SXj03<c<`80=SHf00@0<S8b
020P800P8200:RXZ0P0J6QX0100?3`l0820P020P800P820202@T900402HV9P0K6a/06a/K01hN7P80
9RHV00<0;2`/02@T900T92@00`0G5aL0100U9BD0:RXZ02XZ:P0I6AT201PH6004024Q8@0P8200820P
028R8P807AdM00@05ADE01@D500D51@071`L0P0S8b<0100/;2`0?Shn03hn?P15ADD205=CD`0406i^
KP1aLG40LG5a07AdM080NWYj00@0OGem06i^KP1^KVh0GemO0P1@D500101:BTX0C4a<04a<C00l?3`2
0410@0040451@@1BDU80DU9B03Lg=`80>CTi00@0N7Qh07inOP1nOWh0P8200P1iNGT0101LG5`0Bd];
04];B`1KFe/206a/K00406ATI00d=3@0=3@d04M7A`80@d=300@0GEeM05MGE`1GEeL0EUIF0P18B4P0
1017AdL0CDe=04e=C@1<C4`204Q8B004051@D01=CDd0CDe=04m?C`80ADE500@0K6a/05mOG`1OGel0
BDU90P10@4001014A4@0?3`l03`l?01KFe/205EEE@0404A4A01<C4`0C4a<04I6AP80DU9B00@0D51@
04E5A@15ADD0ADE50P16ATH01013@d<0AdM704M7A`13@d<20492@P0404Y:BP10@400@41003lo?`80
IVIV00@0ZJVY0:BTY02TY:@0S8b<0P2>SXh01010@4003Ph>00h>3P071`L200H61P0400P8200410@0
10@400P820800`<300@00@4100<30`030`<01PH60P071`L0100410@00P8200820P061PH200d=3@00
00@01PH600X:2P0:2PX010@40P010@40100000001PH600H61P020P8200D51@0400T92@0000000000
00D51@8030`<00@01@D500<30`030`<01PH60P051@D0100410@01PH600H61P00000200X:2P0400/;
2`020P800P8200P820802@T900@01@D500410@010@401@D50P0;2`/010030`<00P8200820P051@D2
00L71`0300H61P0<30`030`<00<010@400@01`L700H61P061PH04A4A0P030`<010020P800`<300<3
0`051@D200`<300400d=3@020P800P8200410@800P8200@01@D500H61P061PH01PH60P030`<0100:
2PX020P800P820092@T200D51@0401/K6`0`<300<30`030`<080C4a<00@0EeMG06ATI01TI6@0Kfm_
0P1DE5@0100`<3003@d=00d=3@092@T200l?3`0400@410020P800P8200@410800`<300@0;Rh^07Yj
NP1jNWX0LG5a0P1]KFd01026QXH0WIfM09fMW@29RHT206IVIP04075aL@1OGel0GemO02d];@80<C4a
00@0LW9b0:6QX@2QXJ40ZJVY0P2UYJD0102DU9@0Lg=c07=cL`1[Jf/209FEU@030:JVYP2PX:00X:2P
00<0ZZZZ00@0YJFU09VIV@2IVIT0MWIf0P1HF5P01014A4@0:b/[02/[:`0O7al201LG5`04030`<01:
BTX0BTY:05=CD`80BDU90`1:BTX01013@d<0;Rh^02h^;P0F5QH201/K6`0301LG5`0@4100410@00<0
20P800@06ATI01DE5@0E5AD07AdM0P0L71`0100Q8B40=3@d03@d=010@40204i>CP040451@@1>CTh0
CTi>04Q8B080?3`l00@0;Bd]02l_;`0_;bl0>CTi0P0O7al0100/;2`0=SHf03Hf=P0S8b<202TY:@04
03<c<`0X:2P0:2PX02<S8`80<30`00@0:b/[01hN7P0N7Qh06QXJ0P0I6AT0100P8200=CDe03De=@0b
<S8202PX:00402`/;00e=CD0=CDe03Xj>P80<c<c00@0;Bd]030`<00`<3008R8R0P0S8b<0100X:2P0
820P020P800S8b<202PX:004028R8P0J6QX06QXJ01DE5@803`l?00@04A4A01DE5@0E5AD061PH0P0W
9bL0100f=SH0BDU904U9B@1LG5`205MGE`04069RHP1iNGT0NGUi08>3P`80PH6100@0NGUi06a/K01/
K6`0G5aL0P1DE5@0101@D500De=C05=CD`1=CDd206YZJP0403<c<`0l?3`0?3`l07alO080R8R800@0
Ph>3079bLP1bLW80FEUI0P1HF5P0101KFe/0EEEE05EEE@1aLG420410@00404=3@`1@D500D51@05IF
EP80CDe=00@0De=C059BDP1BDU80Bd];0P14A4@01015ADD0BDU904U9B@1BDU8205EEE@0405=CD`19
BDT0BDU9069RHP80F5QH00@0BDU904Y:BP1:BTX0D51@0P12@T80101aLG40CTi>04i>CP10@40204i>
CP0403dm?@16ATH0ATI604];B`<0B4Q80P19BDT01010@400B4Q804Q8B014A4@20451@@0404a<C013
@d<0@d=30410@080KVi^00@0ZJVY092@T02@T900VIVI0P2BTY80100f=SH04Q8B018B4P0:2PX200<3
0`0400H61P051@D01@D500P820800`<300@010@400<30`030`<010@40`071`L300H61P8010@40000
10061PH02PX:00X:2P0410@200410@04000000061PH01PH600820P801@D500@02@T9000000000000
1@D50P0<30`010051@D00`<300<30`061PH200D51@0400@410061PH01PH6000000802PX:00@02`/;
00820P020P8020P80P092@T010051@D00@4100410@051@D200/;2`0400<30`020P800P8200D51@80
1`L700<01PH600`<300<30`00`0410@010071`L01PH600H61P0A4A4200<30`0400820P030`<00`<3
00D51@8030`<00@03@d=00820P020P800@410P020P8010051@D01PH600H61P061PH200<30`0400X:
2P0820P020P800T92@801@D500@06a/K030`<00`<300<30`0P1<C4`0101GEeL0I6AT06ATI01_Kfl2
05ADE004030`<00=3@d03@d=00T92@803`l?00@010@400820P020P8010@40P030`<0100^;Rh0NWYj
07YjNP1aLG4206e]K@0408J6QP2MWId0WIfM08V9R@80IVIV00@0LG5a05mOG`1OGel0;Bd]0P0a<C40
101bLW80XJ6Q0:6QX@2YZJT20:FUY@0409BDU01cLg<0Lg=c06][J`80UIFE00<0YZJV0:2PX02PX:00
0`2ZZZX0102UYJD0VIVI09VIV@1fMWH205QHF00404A4A00[:b/0:b/[01lO7`805aLG00@0<30`04Y:
BP1:BTX0De=C0P19BDT304Y:BP0404=3@`0^;Rh0;Rh^01HF5P806a/K00<05aLG010@400@41000`08
20P0100I6AT05ADE01DE5@0M7Ad201`L7004024Q8@0d=3@0=3@d0410@080CTi>00@0@D5104i>CP1>
CTh0B4Q80P0l?3`0100];Bd0;bl_02l_;`0i>CT201lO7`0402`/;00f=SH0=SHf02<S8`80:BTY00@0
<c<c02PX:00X:2P08b<S0P0`<300100[:b/07QhN01hN7P0J6QX201TI6@04020P800e=CD0=CDe038b
<P80:2PX00@0;2`/03De=@0e=CD0>SXj0P0c<c<0100];Bd0<30`030`<00R8R8202<S8`0402PX:00P
8200820P02<S8`80:2PX00@08R8R01XJ6P0J6QX05ADE0P0?3`l0100A4A405ADE01DE5@0H61P202LW
9`0403Hf=P19BDT0BDU905aLG080EeMG00@0HV9R07UiN@1iNGT0Ph>30P21PH40101iNGT0K6a/06a/
K01LG5`205ADE004051@D01CDe<0De=C04e=C@80JVYZ00@0<c<c03`l?00l?3`0O7al0P28R8P01023
Ph<0LW9b079bLP1IFET205QHF00405]KF`1EEED0EEEE075aL@80@41000@0@d=3051@D01@D500EUIF
0P1=CDd0101CDe<0DU9B059BDP1;Bd/204A4A00404E5A@19BDT0BDU9059BDP80EEEE00@0De=C04U9
B@19BDT0HV9R0P1HF5P01019BDT0BTY:04Y:BP1@D5020492@P04075aL@1>CTh0CTi>0410@080CTi>
00@0?Cdm04I6AP16ATH0Bd];0`18B4P204U9B@040410@018B4P0B4Q804A4A080@D5100@0C4a<04=3
@`13@d<0@4100P1^KVh0102YZJT0T92@092@T02IVIT209:BTP0403Hf=P0B4Q804Q8B00X:2P800`<3
00@01PH600D51@051@D020P80P030`<0100410@00`<300<30`0410@300L71`<01PH60P0410@00004
00H61P020P800P8200L71`801@D500@02@T900@4100410@000000P030`<0100410@01`L700L71`02
0P8200D51@0400H61P0:2PX02PX:00410@800P8200<01`L700P8200820P00`051@D010010@400`<3
00<30`020P8200<30`<010@400@01PH600D51@051@D01@D50P010@40100:2PX02@T900T92@071`L2
00T92@0300H61P020P800P8200<00P8200@010@400D51@051@D00@410P030`<0100410@00`<300<3
0`020P8200D51@0300L71`051@D01@D500<01`L700@00P8200<30`030`<00P820P092@T010071`L0
3`l?00l?3`0h>3P202d];@0402HV9P1:BTX0BTY:055AD@80JFUY00@0IVIV04I6AP16ATH09RHV0P03
0`<010051@D03Ph>00h>3P071`L200P8200400D51@0F5QH05QHF05EEE@80LW9b00@0JFUY07UiN@1i
NGT0QhN70P2:RXX0101]KFd0EUIF05IFEP1OGel20451@@0402HV9P1BDU80DU9B08f=S@80XJ6Q00@0
YJFU09VIV@2IVIT0LG5a0P1_Kfl01028R8P0TY:B09:BTP2JVYX20:6QX@0409FEU@28R8P0R8R808f=
S@80T92@00@0Lg=c03De=@0e=CD03`l?0P0E5AD0100];Bd0@4100410@018B4P2059BDP0404U9B@11
@D40@D5103De=@809RHV00@07AdM01DE5@0E5AD0410@0P0>3Ph010071`L010@400@4100I6AT502HV
9P0402TY:@0P8200820P02/[:`80@T9200@0=SHf03Xj>P0j>SX0@D510P0l?3`0100N7Qh092@T02@T
900o?cl204Q8B00404M7A`0[:b/0:b/[020P8080>SXj00@0<S8b02LW9`0W9bL0:2PX0P0/;2`0100c
<c<0=CDe03De=@0M7Ad202h^;P04030`<00Q8B408B4Q02@T9080?clo00@0?3`l03Ti>@0i>CT0<30`
0P0Y:BT0100_;bl0=3@d03@d=00g=cL204A4A00403Ph>00W9bL09bLW02d];@80;2`/00@0;Bd]038b
<P0b<S809BDU0P0R8R80100X:2P06QXJ01XJ6P0F5QH2010@400400d=3@0F5QH05QHF01DE5@80:2PX
00@0@T9203lo?`0o?cl0ADE50P1PH600101WIfL0Kfm_06m_K`1jNWX20861P@04075aL@1UIFD0IFEU
05]KF`80FEUI00@0D51@05IFEP1FEUH0<C4a0P11@D40101dM7@0PX:208:2PP1/K6`205aLG004055A
D@1;Bd/0Bd];065QH@80Bd];00@0Kfm_05UIF@1IFET0@T920P1?Cdl305ADE0<0EEEE00@0D51@04I6
AP16ATH0B4Q80P1<C4`0101FEUH0FEUI05UIF@1DE5@204i>CP04069RHP1KFe/0Fe]K04Q8B080DE5A
00@0BDU903`l?00l?3`0IVIV0`15ADD204i>CP0404=3@`18B4P0B4Q804i>CP80C4a<00@0A4A404U9
B@19BDT0@4100P0o?cl30410@00404Y:BP13@d<0@d=303Xj>P80Ph>300@0UiNG06a/K01/K6`0Y:BT
0P23Ph<0100U9BD03@d=00d=3@010@4200<30`0400@410071`L01`L700D51@802PX:00@01@D500X:
2P0:2PX02PX:0P030`<010051@D01`L700L71`0;2`/200D51@0000@01@D500L71`071`L00@410`03
0`<200@410@01PH60P010@40100:2PX01PH600H61P030`<200L71`0300P820010@400@4100<00P82
00@010@400P8200820P010@40P051@D0100410@02`/;00/;2`00000200<30`0400H61P0410@010@4
00@410801PH600@02@T900<30`030`<02@T90P051@D010061PH00@4100410@092@T200`<300400H6
1P010@400@4100D51@800P8200@01PH600P8200820P00P820`071`L200D51@0400@410010@400@41
00H61P80000000@00`<300T92@092@T00`<30P0K6a/0100f=SH0;Rh^02h^;P0[:b/204Y:BP0405AD
E01UIFD0IFEU051@D080<30`00@051@D00X:2P0:2PX00`<30P051@D010092@T01PH600H61P000002
02h^;P04065QH@1EEED0EEEE06EUI@80Rh^;00@0TI6A08B4Q024Q8@0MGEe0P1^KVh01013@d<08R8R
028R8P1<C4`208:2PP0409ZJVP2PX:00X:2P09FEU@80MgMg00@0KVi^092@T02@T900SHf=0P1dM7@0
1020P800PX:208:2PP1SHf<205MGE`0406i^KP1bLW80LW9b04=3@`80820P00@0;bl_04U9B@19BDT0
G5aL0P1OGel0101BDU80B4Q804Q8B00];Bd2020P800401LG5`0I6AT06ATI01PH60803`l?00@03Ph>
01XJ6P0J6QX04Q8B0P0H61P0100R8R8061PH01PH600U9BD203dm?@0403Xj>P0Q8B408B4Q01LG5`80
7AdM00@09bLW03Lg=`0g=cL0>CTi0P0c<c<0100W9bL0;bl_02l_;`0_;bl203De=@0403Ti>@0c<c<0
<c<c02/[:`80;bl_00@0;Bd]02h^;P0^;Rh09RHV0P0e=CD01016ATH0@4100410@00X:2P202h^;P04
03<c<`0[:b/0:b/[02HV9P<09bLW0P0`<300100a<C40;Rh^02h^;P0i>CT203Ph>00403/k>`1EEED0
EEEE051@D080=SHf00@0A4A404I6AP16ATH0:BTY0P0J6QX0100Q8B40>3Ph03Ph>00d=3@202HV9P04
02l_;`0T92@092@T01TI6@806a/K00@03`l?01LG5`0G5aL0:BTY0P0V9RH0100/;2`0AdM704M7A`1B
DU8205iNGP0406m_K`20P800P82007alO080N7Qh00@0Lg=c06IVIP1VIVH0DU9B0P16ATH0100W9bL0
@D510451@@1TI6@207AdM00405eMG@14A4@0A4A404Y:BP80@D5100@0E5AD04A4A014A4@0MWIf0P1g
MgL0100o?cl0Bd];04];B`1HF5P205]KF`0404];B`1<C4`0C4a<04Y:BP80A4A400@0DE5A04i>CP1>
CTh0DE5A0P1DE5@0101>CTh0C4a<04a<C01MGEd205YJFP0404E5A@1CDe<0De=C0492@P80@D5100<0
Hf=S04Q8B018B4P00`1>CTh0101=CDd0C4a<04a<C01>CTh304];B`<0B4Q80P14A4@01010@400ATI6
04I6AP1>CTh20451@@0403/k>`22PX80PX:207]kN`80LG5a00@0YJFU06YZJP1ZJVX06QXJ0`092@T2
00D51@<01PH600@010@400D51@051@D01`L70P0;2`/0100:2PX01`L700L71`061PH200410@401@D5
0@030`<100<30`0000@01@D500L71`071`L00@410`030`<200@410@01PH60P010@40100:2PX01PH6
00H61P030`<200L71`0300P820010@400@4100<00P8200@010@400P8200820P010@40P051@D01004
10@02`/;00/;2`00000200<30`0400H61P0410@010@400@410801PH600@02@T900<30`030`<02@T9
0P051@D010061PH00@4100410@092@T200`<300400H61P010@400@4100D51@800P8200@01PH600P8
200820P00P820`071`L200D51@0400@410010@400@4100H61P80000000@00`<300T92@092@T00`<3
0P0K6a/0100f=SH0;Rh^02h^;P0[:b/204Y:BP0405ADE01UIFD0IFEU051@D080<30`00@051@D00X:
2P0:2PX00`<30P051@D010092@T01PH600H61P00000202h^;P04065QH@1EEED0EEEE06EUI@80Rh^;
00@0TI6A08B4Q024Q8@0MGEe0P1^KVh01013@d<08R8R028R8P1<C4`208:2PP0409ZJVP2PX:00X:2P
09FEU@80MgMg00@0KVi^092@T02@T900SHf=0P1dM7@01020P800PX:208:2PP1SHf<205MGE`0406i^
KP1bLW80LW9b04=3@`80820P00@0;bl_04U9B@19BDT0G5aL0P1OGel0101BDU80B4Q804Q8B00];Bd2
020P800401LG5`0I6AT06ATI01PH60803`l?00@03Ph>01XJ6P0J6QX04Q8B0P0H61P0100R8R8061PH
01PH600U9BD203dm?@0403Xj>P0Q8B408B4Q01LG5`807AdM00@09bLW03Lg=`0g=cL0>CTi0P0c<c<0
100W9bL0;bl_02l_;`0_;bl203De=@0403Ti>@0c<c<0<c<c02/[:`80;bl_00@0;Bd]02h^;P0^;Rh0
9RHV0P0e=CD01016ATH0@4100410@00X:2P202h^;P0403<c<`0[:b/0:b/[02HV9P<09bLW0P0`<300
100a<C40;Rh^02h^;P0i>CT203Ph>00403/k>`1EEED0EEEE051@D080=SHf00@0A4A404I6AP16ATH0
:BTY0P0J6QX0100Q8B40>3Ph03Ph>00d=3@202HV9P0402l_;`0T92@092@T01TI6@806a/K00@03`l?
01LG5`0G5aL0:BTY0P0V9RH0100/;2`0AdM704M7A`1BDU8205iNGP0406m_K`20P800P82007alO080
N7Qh00@0Lg=c06IVIP1VIVH0DU9B0P16ATH0100W9bL0@D510451@@1TI6@207AdM00405eMG@14A4@0
A4A404Y:BP80@D5100@0E5AD04A4A014A4@0MWIf0P1gMgL0100o?cl0Bd];04];B`1HF5P205]KF`04
04];B`1<C4`0C4a<04Y:BP80A4A400@0DE5A04i>CP1>CTh0DE5A0P1DE5@0101>CTh0C4a<04a<C01M
GEd205YJFP0404E5A@1CDe<0De=C0492@P80@D5100<0Hf=S04Q8B018B4P00`1>CTh0101=CDd0C4a<
04a<C01>CTh304];B`<0B4Q80P14A4@01010@400ATI604I6AP1>CTh20451@@0403/k>`22PX80PX:2
07]kN`80LG5a00@0YJFU06YZJP1ZJVX06QXJ0`092@T200D51@<01PH600@010@400D51@051@D01`L7
0P0;2`/0100:2PX01`L700L71`061PH200410@401@D50@030`<100<30`0000@01PH600410@010@40
0@410`0410@200H61P0400820P061PH01PH600@41080000000@00`<300D51@051@D01PH60P092@T0
100=3@d02`/;00/;2`0410@200820P0400L71`051@D01@D500l?3`802@T900@02PX:018B4P0B4Q80
30`<0P020P800`071`L010@400@4100300L71`0400H61P0410@010@400<30`800P8200@0000000<3
0`030`<01PH60P0820P0100410@01PH600H61P071`L200820P0400<30`051@D01@D500L71`8010@4
00@02@T900L71`071`L00@410P020P8010030`<010@400@410092@T200H61P0301@D500Z:RX0:RXZ
00<0:b/[00@0;2`/04=3@`13@d<0FUYJ0P1ADE40100j>SX06a/K01/K6`0410@200X:2P0400D51@08
20P020P800H61P800@4100@01`L704i>CP1>CTh0G5aL0P1RHV801026QXH0Vi^K09^KV`2?Shl20861
P@0407moO`1[Jf/0Jf][04A4A080D51@00@0Q8B409fMW@2MWId0WinO0P2=SHd0101eMGD0LW9b079b
LP1oOgl208F5Q@0406][J`1VIVH0IVIV0820P080NGUi00@0HV9R05eMG@1MGEd0I6AT0P1ADE40100e
=CD0@D510451@@1HF5P205mOG`0406][J`1NGUh0GUiN03Xj>P8092@T00@06ATI01<C4`0C4a<02@T9
0P0;2`/0100?3`l03Ph>00h>3P0C4a<201XJ6P0400/;2`0D51@051@D02DU9@808R8R00@08B4Q030`
<00`<300@4100P0f=SH0100e=CD0<c<c03<c<`0I6AT302/[:`80410@00@05QHF02<S8`0S8b<08R8R
0P0a<C40100O7al061PH01PH600V9RH203De=@040451@@0m?Cd0?Cdm02LW9`809BDU00@0<c<c03hn
?P0n?Sh0;Rh^0P0d=3@01012@T80>SXj03Xj>P10@40203Xj>P0402h^;P0d=3@0=3@d01lO7`809RHV
00@0C4a<04=3@`13@d<0>c/k0P18B4P01010@400>3Ph03Ph>01>CTh204I6AP0402h^;P0W9bL09bLW
02l_;`80=SHf00@0:b/[02HV9P0V9RH09bLW0P0S8b<401dM7@8061PH00@051@D01LG5`0G5aL07alO
0P0[:b/0100c<c<0?clo03lo?`1=CDd206MWI`0407EeM@1kNg/0Ng]k0820P080Kfm_00@0FUYJ04Q8
B018B4P0?Shn0P1<C4`0101KFe/0NWYj07YjNP1RHV8204A4A00405mOG`1IFET0FEUI04Y:BP80>c/k
00@0K6a/07inOP1nOWh0@d=30P1>CTh0101CDe<0Cdm?04m?C`10@4020451@@0404I6AP13@d<0@d=3
04M7A`80Cdm?0`1CDe<0101ADE40CTi>04i>CP1GEeL2059BDP040451@@1<C4`0C4a<0410@080CDe=
00@0Fe]K04=3@`13@d<0CDe=0P19BDT01018B4P0AdM704M7A`1:BTX204M7A`0404];B`16ATH0ATI6
04U9B@80DE5A00@0ADE504U9B@19BDT0CDe=0P13@d<0100j>SX0CTi>04i>CP1RHV8209ZJVP040;>c
/`1[Jf/0Jf][01DE5@<02@T90P00000010061PH01`L700L71`00000200410@0400<30`010@400@41
00T92@801@D500@02PX:00820P020P801`L70P0410@0000400D51@030`<00`<300@410800P8200@0
1@D500X:2P0:2PX010@40P051@D010020P801@D500D51@0410@200D51@0400H61P051@D01@D500h>
3P803@d=00@020P80000000000001@D50P061PH00`0410@02`/;00/;2`0300T92@0400@4100?3`l0
3`l?00820P801@D500@00`<300@4100410@03`l?0P030`<010061PH000000000000820P200<30`04
00410@0:2PX02PX:00L71`800`<300@00P8200H61P061PH01PH60P020P8010051@D00`<300<30`02
0P8200L71`030000000410@010@400<00@4100@01@D500@4100410@09RHV0P0_;bl0100R8R80:RXZ
02XZ:P0/;2`20492@P0405=CD`0e=CD0=CDe024Q8@801`L700@01@D500@4100410@01PH60P0?3`l0
100=3@d000000000000[:b/207=cL`0407MgM`25QHD0QHF509bLW080WIfM00@0TY:B08R8R028R8P0
Kfm_0P1?Cdl0101FEUH0QHF508F5Q@2NWYh209VIV@0408b<S01hN7P0N7Qh06i^KP80NWYj00@0MGEe
05iNGP1NGUh0F5QH0P1iNGT0102BTY80OWin07inOP1VIVH205iNGP0404Q8B00k>c/0>c/k04i>CP80
IfMW00@0KVi^05iNGP1NGUh0EEEE0P14A4@0100U9BD0410@010@40092@T2010@400400l?3`0=3@d0
3@d=014A4@80:2PX00@07AdM024Q8@0Q8B407AdM0P0X:2P0100a<C40<30`030`<00V9RH202DU9@04
03Lg=`0f=SH0=SHf03Xj>P80?clo00@051@D010@400@41004A4A0P0@4100100W9bL0:RXZ02XZ:P0g
=cL203Xj>P0403dm?@0];Bd0;Bd]02`/;080?clo00@0AdM701`L700L71`071`L0P0?3`l0100`<300
>CTi03Ti>@0_;bl203/k>`0404E5A@10@400@41004A4A080>c/k00@0<c<c04Q8B018B4P09RHV0P0I
6AT0100/;2`0<30`030`<00g=cL2038b<P0402h^;P0m?Cd0?Cdm04A4A080:b/[00@08b<S03De=@0e
=CD0=SHf0P0e=CD0100b<S808B4Q024Q8@0P820202TY:@<08B4Q00@08b<S01HF5P0F5QH04a<C0P0G
5aL0100B4Q803Ph>00h>3P0J6QX202l_;`040410@01;Bd/0Bd];05MGE`80KVi^00@0O7al07AdM01d
M7@0Jf][0`1<C4`205MGE`0405IFEP1iNGT0NGUi06IVIP80EeMG00@0K6a/05=CD`1CDe<0?clo0P0f
=SH0101UIFD0OWin07inOP1=CDd205QHF00405=CD`1=CDd0CDe=04];B`80?Cdm00@0@d=30451@@11
@D40?Cdm0P19BDT3051@D00405EEE@1<C4`0C4a<055AD@80CDe=00@0AdM704m?C`1?Cdl0ADE50P1H
F5P0101@D500?clo03lo?`18B4P204=3@`0404];B`1=CDd0CDe=04Y:BP80AdM700@0BDU904A4A014
A4@0?3`l0P1:BTX01015ADD0@4100410@01<C4`204Q8B00403lo?`0l?3`0?3`l07]kN`80][Jf00@0
VIVI05IFEP1FEUH04a<C0P0820P010051@D01PH600H61P0410@200820P0400H61P010@400@4100H6
1P800`<300@02@T900820P020P801@D50P0410@100<30`401PH60@061PH0000400D51@030`<00`<3
00@410800P8200@01@D500X:2P0:2PX010@40P051@D010020P801@D500D51@0410@200D51@0400H6
1P051@D01@D500h>3P803@d=00@020P80000000000001@D50P061PH00`0410@02`/;00/;2`0300T9
2@0400@4100?3`l03`l?00820P801@D500@00`<300@4100410@03`l?0P030`<010061PH000000000
000820P200<30`0400410@0:2PX02PX:00L71`800`<300@00P8200H61P061PH01PH60P020P801005
1@D00`<300<30`020P8200L71`030000000410@010@400<00@4100@01@D500@4100410@09RHV0P0_
;bl0100R8R80:RXZ02XZ:P0/;2`20492@P0405=CD`0e=CD0=CDe024Q8@801`L700@01@D500@41004
10@01PH60P0?3`l0100=3@d000000000000[:b/207=cL`0407MgM`25QHD0QHF509bLW080WIfM00@0
TY:B08R8R028R8P0Kfm_0P1?Cdl0101FEUH0QHF508F5Q@2NWYh209VIV@0408b<S01hN7P0N7Qh06i^
KP80NWYj00@0MGEe05iNGP1NGUh0F5QH0P1iNGT0102BTY80OWin07inOP1VIVH205iNGP0404Q8B00k
>c/0>c/k04i>CP80IfMW00@0KVi^05iNGP1NGUh0EEEE0P14A4@0100U9BD0410@010@40092@T2010@
400400l?3`0=3@d03@d=014A4@80:2PX00@07AdM024Q8@0Q8B407AdM0P0X:2P0100a<C40<30`030`
<00V9RH202DU9@0403Lg=`0f=SH0=SHf03Xj>P80?clo00@051@D010@400@41004A4A0P0@4100100W
9bL0:RXZ02XZ:P0g=cL203Xj>P0403dm?@0];Bd0;Bd]02`/;080?clo00@0AdM701`L700L71`071`L
0P0?3`l0100`<300>CTi03Ti>@0_;bl203/k>`0404E5A@10@400@41004A4A080>c/k00@0<c<c04Q8
B018B4P09RHV0P0I6AT0100/;2`0<30`030`<00g=cL2038b<P0402h^;P0m?Cd0?Cdm04A4A080:b/[
00@08b<S03De=@0e=CD0=SHf0P0e=CD0100b<S808B4Q024Q8@0P820202TY:@<08B4Q00@08b<S01HF
5P0F5QH04a<C0P0G5aL0100B4Q803Ph>00h>3P0J6QX202l_;`040410@01;Bd/0Bd];05MGE`80KVi^
00@0O7al07AdM01dM7@0Jf][0`1<C4`205MGE`0405IFEP1iNGT0NGUi06IVIP80EeMG00@0K6a/05=C
D`1CDe<0?clo0P0f=SH0101UIFD0OWin07inOP1=CDd205QHF00405=CD`1=CDd0CDe=04];B`80?Cdm
00@0@d=30451@@11@D40?Cdm0P19BDT3051@D00405EEE@1<C4`0C4a<055AD@80CDe=00@0AdM704m?
C`1?Cdl0ADE50P1HF5P0101@D500?clo03lo?`18B4P204=3@`0404];B`1=CDd0CDe=04Y:BP80AdM7
00@0BDU904A4A014A4@0?3`l0P1:BTX01015ADD0@4100410@01<C4`204Q8B00403lo?`0l?3`0?3`l
07]kN`80][Jf00@0VIVI05IFEP1FEUH04a<C0P0820P010051@D01PH600H61P0410@200820P0400H6
1P010@400@4100H61P800`<300@02@T900820P020P801@D50P0410@100<30`401PH60@061PH00004
00D51@071`L01`L700@410<00P820P071`L010092@T00P8200820P0410@200L71`0400T92@0820P0
20P800@4108020P800@010@400<30`030`<01`L70P0E5AD0100C4a<01@D500D51@030`<200P82004
00<30`0:2PX02PX:00820P8010@400@01`L700X:2P0:2PX010@40`0:2PX200410@0400820P061PH0
1PH600D51@8010@400@0000000<30`030`<010@40P030`<0100:2PX01@D500D51@061PH200820P04
00<30`000000000000D51@800@4100@010@400820P020P800@410P000000100410@020P800P8200P
820202LW9`0402XZ:P0X:2P0:2PX020P8080ADE500@0DU9B030`<00`<30051@D0P030`<300D51@04
00P8200B4Q804Q8B00D51@80410@00@0G5aL08j>SP2>SXh0TY:B0P2GUiL0102JVYX0TI6A096AT@2B
TY82096AT@0406QXJ01CDe<0De=C07=cL`80WinO00@0ZZZZ09RHV02HV9P0MgMg0P1XJ6P0101bLW80
PX:208:2PP1hN7P206=SH`0406EUI@1lO7`0O7al08>3P`80IVIV00@0BTY:04];B`1;Bd/0DU9B0P1S
Hf<0101dM7@0KVi^06i^KP1OGel204U9B@04034a<@0G5aL05aLG00H61P802`/;0`051@D0100D51@0
6ATI01TI6@0E5AD202XZ:P0402`/;00R8R808R8R01XJ6P80?3`l00@0=cLg03De=@0e=CD0?3`l0P0Z
:RX0100f=SH0A4A404A4A00e=CD205MGE`0403<c<`0I6AT06ATI00/;2`805ADE00@0<S8b02@T900T
92@09RHV0P0S8b<0100g=cL0=SHf03Hf=P0H61P201@D500403hn?P0T92@092@T020P808061PH0`0T
92@0100e=CD0@d=304=3@`0Y:BT202LW9`040410@016ATH0ATI604M7A`80E5AD00@0<C4a03De=@0e
=CD0=CDe0P0c<c<0100k>c/0;2`/02`/;00/;2`203<c<`0403De=@0c<c<0<c<c038b<P80>CTi00@0
=SHf03Ph>00h>3P0AdM70P10@400100g=cL0=CDe03De=@0/;2`203`l?00403dm?@0S8b<08b<S01<C
4`803Ph>00@07AdM01LG5`0G5aL01@D50P0N7Qh0100_;bl0<30`030`<00i>CT2051@D00406QXJ01a
LG40LG5a07AdM080GUiN00@0HV9R061PH01PH600De=C0P1`L700101_Kfl0L71`071`L01lO7`204e=
C@04038b<P10@400@41007IfMP80PH6100@0CDe=05]KF`1KFe/0De=C0P16ATH01019BDT0@T920492
@P1:BTX20451@@0404E5A@1:BTX0BTY:04];B`80C4a<00@0EeMG055AD@1ADE40DU9B0P1>CTh0101=
CDd0BTY:04Y:BP13@d<205eMG@04059BDP10@400@41004E5A@80?Shn00@0A4A404Q8B018B4P0@d=3
0`17AdL204=3@`0403`l?015ADD0ADE50492@P80>c/k00@0Cdm?04I6AP16ATH0@T920P1GEeL01025
QHD0/;2`0;2`/020P8020492@P0401@D500820P020P800`<30801PH60`051@D010061PH010@400@4
100410@300H61P800`<300@0000000P8200820P04Q8B0P092@T000<00P8200@00@4100<30`030`<0
1PH60P071`L010051@D00P8200820P092@T200X:2P0300@410092@T02@T900<00`<300@01PH600D5
1@051@D00`<30P0D51@0100;2`/01`L700L71`051@D200H61P0400<30`051@D01@D500820P<01PH6
0P020P80100820P02@T900T92@010@4300T92@8030`<00@0000000L71`071`L000000P030`<0100;
2`/00@4100410@010@4200D51@0400H61P071`L01`L700<30`<01PH60P020P80100410@01@D500D5
1@0410@200T92@0400<30`0O7al07alO02HV9P809bLW00@0?Shn03Xj>P0j>SX0<C4a0P17AdL01010
@400:RXZ02XZ:P0?3`l200`<300400820P071`L01`L700/;2`803Ph>00@0000003<c<`0c<c<0Ng]k
0P2BTY80102DU9@0Rh^;08^;R`2=SHd209>CT`0409BDU020P800P82006EUI@80MgMg00@0Vi^K0:j^
[P2^[Zh0XZ:R0P1iNGT0101KFe/0Kfm_06m_K`26QXH207IfMP04071`L01iNGT0NGUi05]KF`80De=C
00@0GEeM0492@P12@T80?Cdm0P1@D500101TI6@0LG5a075aL@1XJ6P204m?C`0403@d=00P8200820P
014A4@801`L700@02`/;014A4@0A4A404a<C0P0A4A40100F5QH09BDU02DU9@0S8b<201/K6`04020P
800N7Qh07QhN01/K6`<0;2`/0P0D51@0100L71`09RHV02HV9P0c<c<20410@00402h^;P13@d<0@d=3
03dm?@809bLW0`0E5AD0100P8200:BTY02TY:@0N7Qh201HF5P0402HV9P0I6AT06ATI01HF5P8071`L
00@0=CDe01HF5P0F5QH0410@0P0J6QX0100U9BD08b<S02<S8`0_;bl202HV9P0401<C4`0^;Rh0;Rh^
04i>CP80<S8b00@0@41004E5A@15ADD09bLW0P0j>SX0100l?3`0:2PX02PX:00d=3@203Ph>0040410
@017AdL0AdM704I6AP80ADE500@0@41003`l?00l?3`0<S8b0P0d=3@01015ADD0@d=304=3@`0b<S82
02XZ:P0402TY:@0];Bd0;Bd]02XZ:P8092@T00@08B4Q01DE5@0E5AD0820P0P0U9BD0100:2PX010@4
00@4100E5AD202TY:@04028R8P0Y:BT0:BTY04];B`80Kfm_00@0N7Qh06i^KP1^KVh0LW9b0P1WIfL0
101NGUh0KFe]06e]K@1aLG4207QhN00408B4Q01UIFD0IFEU03Ph>080BDU900@0Ph>30861P@21PH40
Cdm?0P1DE5@0101EEED0BTY:04Y:BP18B4P204A4A00404Y:BP14A4@0A4A404e=C@<0ATI60P1;Bd/0
101=CDd0AdM704M7A`18B4P3051@D080DE5A00@0EUIF065QH@1QHF40C4a<0P14A4@0101<C4`0A4A4
04A4A017AdL204m?C`0404];B`17AdL0AdM70451@@80?clo00@0@d=304Q8B018B4P0?Shn0P0k>c/0
101FEUH0@T920492@P0n?Sh207IfMP0409BDU02/[:`0[:b/08:2PP80@D5100@04a<C00`<300<30`0
1PH60P071`L010061PH00`<300<30`0410@200/;2`<01@D500@0000000D51@051@D010@40P061PH1
00l?3`4020P80@0820P000<00P8200@00@4100<30`030`<01PH60P071`L010051@D00P8200820P09
2@T200X:2P0300@410092@T02@T900<00`<300@01PH600D51@051@D00`<30P0D51@0100;2`/01`L7
00L71`051@D200H61P0400<30`051@D01@D500820P<01PH60P020P80100820P02@T900T92@010@43
00T92@8030`<00@0000000L71`071`L000000P030`<0100;2`/00@4100410@010@4200D51@0400H6
1P071`L01`L700<30`<01PH60P020P80100410@01@D500D51@0410@200T92@0400<30`0O7al07alO
02HV9P809bLW00@0?Shn03Xj>P0j>SX0<C4a0P17AdL01010@400:RXZ02XZ:P0?3`l200`<30040082
0P071`L01`L700/;2`803Ph>00@0000003<c<`0c<c<0Ng]k0P2BTY80102DU9@0Rh^;08^;R`2=SHd2
09>CT`0409BDU020P800P82006EUI@80MgMg00@0Vi^K0:j^[P2^[Zh0XZ:R0P1iNGT0101KFe/0Kfm_
06m_K`26QXH207IfMP04071`L01iNGT0NGUi05]KF`80De=C00@0GEeM0492@P12@T80?Cdm0P1@D500
101TI6@0LG5a075aL@1XJ6P204m?C`0403@d=00P8200820P014A4@801`L700@02`/;014A4@0A4A40
4a<C0P0A4A40100F5QH09BDU02DU9@0S8b<201/K6`04020P800N7Qh07QhN01/K6`<0;2`/0P0D51@0
100L71`09RHV02HV9P0c<c<20410@00402h^;P13@d<0@d=303dm?@809bLW0`0E5AD0100P8200:BTY
02TY:@0N7Qh201HF5P0402HV9P0I6AT06ATI01HF5P8071`L00@0=CDe01HF5P0F5QH0410@0P0J6QX0
100U9BD08b<S02<S8`0_;bl202HV9P0401<C4`0^;Rh0;Rh^04i>CP80<S8b00@0@41004E5A@15ADD0
9bLW0P0j>SX0100l?3`0:2PX02PX:00d=3@203Ph>0040410@017AdL0AdM704I6AP80ADE500@0@410
03`l?00l?3`0<S8b0P0d=3@01015ADD0@d=304=3@`0b<S8202XZ:P0402TY:@0];Bd0;Bd]02XZ:P80
92@T00@08B4Q01DE5@0E5AD0820P0P0U9BD0100:2PX010@400@4100E5AD202TY:@04028R8P0Y:BT0
:BTY04];B`80Kfm_00@0N7Qh06i^KP1^KVh0LW9b0P1WIfL0101NGUh0KFe]06e]K@1aLG4207QhN004
08B4Q01UIFD0IFEU03Ph>080BDU900@0Ph>30861P@21PH40Cdm?0P1DE5@0101EEED0BTY:04Y:BP18
B4P204A4A00404Y:BP14A4@0A4A404e=C@<0ATI60P1;Bd/0101=CDd0AdM704M7A`18B4P3051@D080
DE5A00@0EUIF065QH@1QHF40C4a<0P14A4@0101<C4`0A4A404A4A017AdL204m?C`0404];B`17AdL0
AdM70451@@80?clo00@0@d=304Q8B018B4P0?Shn0P0k>c/0101FEUH0@T920492@P0n?Sh207IfMP04
09BDU02/[:`0[:b/08:2PP80@D5100@04a<C00`<300<30`01PH60P071`L010061PH00`<300<30`04
10@200/;2`<01@D500@0000000D51@051@D010@40P061PH100l?3`4020P80@0820P0000300X:2P05
1@D01@D500<010@400@00`<300D51@051@D01`L70P020P80100:2PX01@D500D51@030`<200L71`04
00d=3@000000000000L71`802`/;00@02PX:00D51@051@D00`<30P0410@010071`L03@d=00d=3@08
20P300T92@80000000@03@d=00<30`030`<01PH60P071`L010061PH03@d=00d=3@0820P300<30`80
1@D500<010@400X:2P0:2PX00`030`<010020P801@D500D51@051@D300P820801`L700<00P8200@4
100410@00`000000100410@00P8200820P0?3`l202TY:@0401lO7`0_;bl0;bl_0451@@80>c/k00@0
A4A404];B`1;Bd/0?Cdm0P0Q8B4300D51@0400@410030`<00`<300X:2P800@4100@02@T9051@D01@
D500Shn?0P2KVi/0102@T900RHV908V9R@2CTi<209^KV`0409FEU@1hN7P0N7Qh07EeM@80VIVI00@0
Y:BT09jNWP2NWYh0TY:B0P1dM7@0101_Kfl0Ph>308>3P`23Ph<207UiN@<0Rh^;00@0HF5Q05=CD`1C
De<0CDe=0P11@D40101BDU80IfMW06MWI`1_Kfl206QXJ00405ADE00a<C40<C4a01HF5P803@d=00@0
10@400<30`030`<020P80P0:2PX0100=3@d04Q8B018B4P0I6AT202HV9P0401`L700N7Qh07QhN02PX
:0805ADE00@061PH02<S8`0S8b<0;2`/0P0Z:RX0100/;2`09RHV02HV9P0d=3@203<c<`0402TY:@0Z
:RX0:RXZ030`<080410@00@0:2PX01@D500D51@0:RXZ0P0m?Cd302XZ:P0402TY:@0>3Ph03Ph>00D5
1@805ADE00@0<30`014A4@0A4A406a/K0P0A4A40100U9BD0<30`030`<00c<c<202@T900402HV9P0h
>3P0>3Ph0410@080<S8b00@0@d=30492@P12@T80=cLg0P0h>3P0100d=3@0>SXj03Xj>P0l?3`203<c
<`040451@@15ADD0ADE503`l?080ADE500@0Bd];03`l?00l?3`0>SXj0P15ADD01012@T80@D510451
@@0k>c/202d];@0403<c<`0j>SX0>SXj03Xj>P80>c/k00@0>CTi030`<00`<300:BTY0P0Q8B40100N
7Qh03@d=00d=3@0<30`201`L700400d=3@0H61P061PH03`l?080EUIF00@0IFEU06a/K01/K6`0OWin
0P1eMGD0101RHV80K6a/06a/K01jNWX207IfMP0407QhN01/K6`0K6a/030`<080@41000@0Shn?0820
P020P800DU9B0P18B4P0101@D500Bd];04];B`18B4P20451@@0404E5A@10@400@41004M7A`80BDU9
00@0C4a<04Q8B018B4P0B4Q80P16ATH0101>CTh0DU9B059BDP17AdL204a<C00405UIF@1RHV80HV9R
04E5A@80@41000@0ADE504=3@`13@d<0Bd];0P17AdL30410@0040492@P17AdL0AdM704U9B@80@410
00@0?Shn03lo?`0o?cl0BTY:0P0m?Cd01010@400OWin07inOP2HV9P20:BTY0040820P00g=cL0=cLg
00X:2P8010@400@03@d=00<30`030`<00`<30P071`L010051@D02`/;00/;2`061PH200410@0400<3
0`061PH01PH600D51@8010@40@0=3@d100/;2`402`/;000300H61P<01`L700@01@D500L71`071`L0
1PH60P000000100;2`/010@400@410020P8200@4100400h>3P0?3`l03`l?00T92@801`L700@02@T9
00410@010@401@D50P030`<0100410@02@T900T92@051@D200T92@0400<30`020P800P8200P82080
2@T900@010@400`<300<30`01@D50P0820P300D51@0400<30`0410@010@400D51@802`/;0`0410@0
100<30`010@400@410010@4200<30`0400T92@0<30`030`<00T92@801`L700@01@D500P8200820P0
1PH60P0410@0100P8200<c<c03<c<`0U9BD203lo?`0403dm?@0e=CD0=CDe04a<C080AdM700@0>3Ph
01@D500D51@01@D50P000000100<30`01`L700L71`0;2`/200L71`04038b<P1gMgL0MgMg09bLW080
XJ6Q00@0TI6A09VIV@2IVIT0WIfM0P2NWYh0102IVIT0QHF508F5Q@2:RXX20:n_[`040;:b/P2?Shl0
Shn?07UiN@80LG5a00@0KFe]06][J`1[Jf/0N7Qh0P28R8P01026QXH0MgMg07MgM`1LG5`204e=C@04
04M7A`1=CDd0CDe=06QXJ080N7Qh00@0JVYZ04U9B@19BDT0:2PX0P0<30`010092@T01`L700L71`00
000200h>3P0301HF5P0E5AD05ADE00<05QHF00@07AdM02HV9P0V9RH0820P0P0V9RH0100_;bl04A4A
014A4@0>3Ph2010@400402XZ:P18B4P0B4Q8038b<P802PX:00@06a/K02h^;P0^;Rh0>3Ph0P13@d<0
100i>CT04a<C01<C4`0_;bl2024Q8@0403Ti>@0n?Sh0?Shn03/k>`80@T9200@071`L01DE5@0E5AD0
8B4Q0P0D51@0100R8R803`l?00l?3`0D51@201TI6@0403Hf=P0d=3@0=3@d01PH60804a<C00@0=cLg
03Hf=P0f=SH0;bl_0P0h>3P01012@T80>CTi03Ti>@0l?3`203Ti>@0402XZ:P0l?3`0?3`l02h^;P80
71`L00@0;Rh^030`<00`<300=CDe0P10@4001013@d<0;2`/02`/;00S8b<203Xj>P0402d];@0_;bl0
;bl_03Xj>P80;Bd]00@0<C4a02XZ:P0Z:RX0=SHf0P14A4@0100g=cL0<c<c03<c<`0_;bl201DE5@04
02<S8`0Y:BT0:BTY02HV9P808b<S00@03Ph>01XJ6P0J6QX0;Rh^0P0e=CD01013@d<0FUYJ05YJFP1k
Ng/207emO@0406IVIP1SHf<0Hf=S07alO080MgMg00@0Lg=c06YZJP1ZJVX0>3Ph0P1:BTX00`2LW9`0
OGem07emO@0304U9B@0405QHF01@D500D51@04A4A080?Shn00@0BDU904=3@`13@d<0B4Q80P1BDU80
101HF5P0A4A404A4A01DE5@304m?C`80DU9B00@0BDU904A4A014A4@0F5QH0P1XJ6P01015ADD0BDU9
04U9B@1>CTh204=3@`<0A4A400@0BTY:04Q8B018B4P0B4Q80P1:BTX01015ADD0?3`l03`l?011@D42
04U9B@0404a<C00n?Sh0?Shn04A4A080P82000@0VYZJ09jNWP2NWYh0Ng]k0P0Z:RX0100;2`/01`L7
00L71`071`L200410@0400@410092@T02@T900L71`800P8200@02`/;00D51@051@D01@D50P0820P0
10010@4010@400@410010@4200<30`000`061PH300L71`0400D51@071`L01`L700H61P80000000@0
2`/;00@4100410@00P820P0410@0100>3Ph03`l?00l?3`092@T200L71`0400T92@010@400@4100D5
1@800`<300@010@400T92@092@T01@D50P092@T010030`<00P8200820P0820P200T92@0400@4100<
30`030`<00D51@8020P80`051@D010030`<010@400@410051@D200/;2`<010@400@030`<00@41004
10@00@410P030`<010092@T030`<00`<30092@T200L71`0400D51@0820P020P800H61P8010@400@0
820P03<c<`0c<c<09BDU0P0o?cl0100m?Cd0=CDe03De=@1<C4`204M7A`0403Ph>00D51@051@D00D5
1@80000000@030`<00L71`071`L02`/;0P071`L0100b<S80MgMg07MgM`2LW9`20:6QX@04096AT@2I
VIT0VIVI09fMW@80WYjN00@0VIVI08F5Q@25QHD0RXZ:0P2_[jl0102b/[80Shn?08n?S`1iNGT2075a
L@0406e]K@1[Jf/0Jf][07QhN080R8R800@0QXJ607MgM`1gMgL0G5aL0P1=CDd01017AdL0CDe=04e=
C@1XJ6P207QhN00406YZJP19BDT0BDU902PX:08030`<00@02@T900L71`071`L000000P0>3Ph00`0F
5QH05ADE01DE5@0301HF5P0401dM7@0V9RH09RHV020P80809RHV00@0;bl_014A4@0A4A403Ph>0P0@
4100100Z:RX0B4Q804Q8B00b<S8200X:2P0401/K6`0^;Rh0;Rh^03Ph>080@d=300@0>CTi01<C4`0C
4a<0;bl_0P0Q8B40100i>CT0?Shn03hn?P0k>c/20492@P0401`L700E5AD05ADE024Q8@8051@D00@0
8R8R00l?3`0?3`l051@D0P0I6AT0100f=SH0=3@d03@d=00H61P201<C4`0403Lg=`0f=SH0=SHf02l_
;`80>3Ph00@0@T9203Ti>@0i>CT0?3`l0P0i>CT0100Z:RX0?3`l03`l?00^;Rh201`L700402h^;P0`
<300<30`03De=@80@41000@0@d=302`/;00/;2`08b<S0P0j>SX0100];Bd0;bl_02l_;`0j>SX202d]
;@04034a<@0Z:RX0:RXZ03Hf=P80A4A400@0=cLg03<c<`0c<c<0;bl_0P0E5AD0100S8b<0:BTY02TY
:@0V9RH202<S8`0400h>3P0J6QX06QXJ02h^;P80=CDe00@0@d=305YJFP1JFUX0Ng]k0P1mOGd0101V
IVH0Hf=S06=SH`1lO7`207MgM`0407=cL`1ZJVX0JVYZ03Ph>080BTY:00<0W9bL07emO@1mOGd00`19
BDT0101HF5P0D51@051@D014A4@203hn?P0404U9B@13@d<0@d=304Q8B080DU9B00@0F5QH04A4A014
A4@0E5AD0`1?Cdl2059BDP0404U9B@14A4@0A4A405QHF080J6QX00@0ADE504U9B@19BDT0CTi>0P13
@d<304A4A00404Y:BP18B4P0B4Q804Q8B080BTY:00@0ADE503`l?00l?3`0@D510P19BDT0101<C4`0
?Shn03hn?P14A4@20820P00409ZJVP2NWYh0WYjN07]kN`80:RXZ00@02`/;00L71`071`L01`L70P01
0@40100410@02@T900T92@071`L200820P0400/;2`051@D01@D500D51@8020P800@00@4100@41004
10@00@410P030`<0000400@410051@D01@D500820P8010@400<01@D500L71`071`L00`020P80100@
410010@400@410071`L200D51@0400L71`0D51@051@D00D51@801PH600@010@400H61P061PH00`<3
0`071`L200<30`0400/;2`0<30`030`<00L71`800@4100@00P8200H61P061PH01@D50P0:2PX300@4
100300D51@030`<00`<300<01PH600@00@4100D51@051@D02`/;0`030`<500@4100400P820071`L0
1`L700X:2P8010@400@00`<300H61P061PH010@40P0@4100100Z:RX0<S8b038b<P0i>CT204=3@`04
03@d=00i>CT0>CTi04];B`80@T9200@09BDU018B4P0B4Q804A4A0P071`L0100<30`00`<300<30`03
0`<201dM7@0405iNGP2@T900T92@09^KV`80WIfM0`2JVYX0102DU9@0V9RH09RHV028R8P208B4Q004
09ZJVP2YZJT0ZJVY09nOW`80QHF500@0Ogmo07inOP1nOWh0JFUY0P1SHf<0101hN7P0NWYj07YjNP1a
LG4206m_K`04059BDP15ADD0ADE505UIF@80KVi^00@0Ng]k06IVIP1VIVH0@T920P0Y:BT0100F5QH0
1`L700L71`0;2`/201@D5004010@400E5AD05ADE01lO7`8071`L00@0410@014A4@0A4A40820P0P0L
71`0100C4a<06QXJ01XJ6P0G5aL201HF5P0401/K6`0R8R808R8R034a<@80>3Ph00@0@T92020P800P
82009BDU0P0c<c<0100];Bd0AdM704M7A`0V9RH202h^;P0404M7A`0_;bl0;bl_020P80807alO00@0
=3@d04Y:BP1:BTX08B4Q0P0=3@d0100c<c<07alO01lO7`0A4A4300820P8061PH00@0820P01LG5`0G
5aL02`/;0P0D51@0100N7Qh03@d=00d=3@0F5QH201TI6@0401/K6`0c<c<0<c<c030`<0809RHV00@0
7QhN02LW9`0W9bL07alO0P0W9bL304Q8B004059BDP1;Bd/0Bd];03Ph>080;2`/00@0<C4a0492@P12
@T80<C4a0P0V9RH0100Z:RX0<S8b038b<P0d=3@201`L700402XZ:P12@T80@T9203Xj>P80<C4a00@0
<30`02TY:@0Y:BT0;bl_0P0e=CD0100c<c<08B4Q024Q8@0;2`/301DE5@8030`<00@08B4Q0492@P12
@T80GUiN0P1ZJVX0101cLg<0NGUi07UiN@1gMgL207inOP0407]kN`19BDT0BDU903De=@80DU9B00@0
UYJF0820P020P800E5AD0P1JFUX0101FEUH0C4a<04a<C018B4P204=3@`0404];B`18B4P0B4Q8059B
DP80DE5A00@0De=C04Y:BP1:BTX0F5QH0P1<C4`01019BDT0ADE504E5A@16ATH204E5A@0406e]K@1Z
JVX0JVYZ03`l?080BDU900@0BTY:04M7A`17AdL0BDU90P1<C4`0101>CTh0@d=304=3@`1>CTh204E5
A@0403hn?P14A4@0A4A404=3@`80Bd];00@0De=C03hn?P0n?Sh0ATI60P22PX80102[Zj/0Y:BT0:BT
Y01^KVh202XZ:P0300X:2P061PH01PH600<02PX:00@02@T900D51@051@D00`<30P071`L010051@D0
1PH600H61P092@T200P8200400X:2P061PH01PH600<30`800P820000100?3`l030`<00`<30000002
00X:2P0400H61P010@400@4100H61P800`<300@010@400L71`071`L03@d=0`0410@200d=3@0400@4
10000000000000@410800P8200@010@400P8200820P01`L70P0>3Ph300@4100400H61P0000000000
00@410800`<300@01@D500410@010@402`/;0P030`<010051@D01`L700L71`0:2PX200P8200400D5
1@0:2PX02PX:00820P800`<30`051@D0100:2PX01`L700L71`0820P200820P0400D51@071`L01`L7
00<30`801@D500@02@T901HF5P0F5QH0:b/[0P0W9bL0100f=SH0=CDe03De=@0^;Rh303Ph>080<S8b
00@04a<C00/;2`0;2`/03`l?0P0=3@d0100000002@T900T92@0?3`l203De=@0407EeM@2:RXX0RXZ:
08Z:RP80U9BD00@0W9bL09JFUP2FUYH0TY:B0P2ATI401026QXH0SXj>08j>SP2LW9`209jNWP0408j>
SP26QXH0QXJ60861P@80M7Ad00@0D51@04I6AP16ATH0HF5Q0P1bLW80101fMWH0LG5a075aL@1JFUX2
05mOG`0407MgM`1nOWh0OWin071`L080AdM700@07AdM00X:2P0:2PX030`<0P0>3Ph0100C4a<05QHF
01HF5P0>3Ph200`<300401HF5P0K6a/06a/K00l?3`803@d=00@09RHV02`/;00/;2`09BDU0P0];Bd0
100T92@07QhN01hN7P0W9bL202<S8`04034a<@0N7Qh07QhN034a<@80;Rh^00@0:b/[028R8P0R8R80
7AdM0P1DE5@0100I6AT0820P020P800f=SH202@T900401XJ6P0Q8B408B4Q02@T90808b<S00@07QhN
00T92@092@T092@T0P0A4A40100=3@d04a<C01<C4`0L71`201TI6@0400h>3P0B4Q804Q8B02PX:080
<S8b00@09BDU01@D500D51@06ATI0P071`L0100>3Ph0>SXj03Xj>P0/;2`201hN7P0402`/;010@400
@41003Hf=P80;bl_00@0@T9204I6AP16ATH0?3`l0P0b<S80100j>SX0?3`l03`l?00n?Sh203/k>`04
034a<@0f=SH0=SHf03Lg=`80?clo00@0>3Ph03De=@0e=CD0A4A40P12@T80100i>CT09BDU02DU9@0I
6AT202`/;0<0<30`00@09BDU01hN7P0N7Qh0:b/[0P0/;2`0100H61P020P800P8200=3@d202/[:`04
04i>CP1KFe/0Fe]K06QXJ080Ogmo00@0NGUi07YjNP1jNWX0O7al0P1?Cdl0100o?cl0FEUI05UIF@2<
S8`2075aL@0404e=C@1EEED0EEEE04Y:BP<0AdM70`13@d<204I6AP0405QHF01ADE40DE5A04i>CP80
Cdm?00@0BDU904I6AP16ATH0D51@0P16ATH0101@D500?Cdm03dm?@1bLW8206ATI00403Xj>P1:BTX0
BTY:0410@080ATI600@0BDU9055AD@1ADE40B4Q80P10@400101CDe<0B4Q804Q8B014A4@204a<C004
04];B`1@D500D51@04a<C080>CTi00@0FUYJ08^;R`2;Rh/0[Jf]0P2TY:@0101NGUh05ADE01DE5@0=
3@d200`<300400T92@0820P020P8000000801`L700@00`<300L71`071`L00`<30P061PH00`051@D0
10@400@4100300D51@4020P80@030`<100<30`0000@03`l?00`<300<30`000000P0:2PX010061PH0
0@4100410@061PH200<30`0400@410071`L01`L700d=3@<010@40P0=3@d0100410@0000000000004
10@200820P0400@4100820P020P800L71`803Ph>0`0410@010061PH000000000000410@200<30`04
00D51@010@400@4100/;2`800`<300@01@D500L71`071`L02PX:0P0820P010051@D02PX:00X:2P02
0P8200<30`<01@D500@02PX:00L71`071`L020P80P020P8010051@D01`L700L71`030`<200D51@04
00T92@0F5QH05QHF02/[:`809bLW00@0=SHf03De=@0e=CD0;Rh^0`0h>3P2038b<P0401<C4`0;2`/0
2`/;00l?3`803@d=00@0000000T92@092@T03`l?0P0e=CD0101eMGD0RXZ:08Z:RP2:RXX209BDU004
09bLW02FUYH0UYJF09:BTP80TI6A00@0QXJ608j>SP2>SXh0W9bL0P2NWYh0102>SXh0QXJ608J6QP21
PH4207AdM004051@D016ATH0ATI6065QH@80LW9b00@0MWIf075aL@1aLG40FUYJ0P1OGel0101gMgL0
OWin07inOP1`L70204M7A`0401dM7@0:2PX02PX:00`<30803Ph>00@04a<C01HF5P0F5QH03Ph>0P0<
30`0100F5QH06a/K01/K6`0?3`l200d=3@0402HV9P0/;2`0;2`/02DU9@80;Bd]00@092@T01hN7P0N
7Qh09bLW0P0S8b<0100a<C407QhN01hN7P0a<C4202h^;P0402/[:`0R8R808R8R01dM7@80E5AD00@0
6ATI020P800P8200=SHf0P0T92@0100J6QX08B4Q024Q8@0T92@202<S8`0401hN7P092@T02@T902@T
90804A4A00@03@d=01<C4`0C4a<071`L0P0I6AT0100>3Ph04Q8B018B4P0X:2P2038b<P0402DU9@0D
51@051@D01TI6@801`L700@03Ph>03Xj>P0j>SX0;2`/0P0N7Qh0100/;2`0@4100410@00f=SH202l_
;`040492@P16ATH0ATI603`l?080<S8b00@0>SXj03`l?00l?3`0?Shn0P0k>c/0100a<C40=SHf03Hf
=P0g=cL203lo?`0403Ph>00e=CD0=CDe04A4A080@T9200@0>CTi02DU9@0U9BD06ATI0P0/;2`3030`
<00402DU9@0N7Qh07QhN02/[:`80;2`/00@061PH00P8200820P03@d=0P0[:b/0101>CTh0Fe]K05]K
F`1XJ6P207moO`0407UiN@1jNWX0NWYj07alO080Cdm?00@0?clo05UIF@1IFET0S8b<0P1aLG40101=
CDd0EEEE05EEE@1:BTX304M7A`<0@d=30P16ATH0101HF5P0DE5A055AD@1>CTh204m?C`0404U9B@16
ATH0ATI6051@D080ATI600@0D51@03dm?@0m?Cd0LW9b0P1TI6@0100j>SX0BTY:04Y:BP10@40204I6
AP0404U9B@1ADE40DE5A04Q8B080@41000@0De=C04Q8B018B4P0A4A40P1<C4`0101;Bd/0D51@051@
D01<C4`203Ti>@0405YJFP2;Rh/0Rh^;0:f][@80Y:BT00@0GUiN01DE5@0E5AD03@d=0P0<30`01009
2@T020P800P82000000200L71`0400<30`071`L01`L700<30`801PH600<01@D500@4100410@00`05
1@D100P820400`<30@030`<0000400P820071`L01`L700410@803`l?00@03@d=00D51@051@D00`<3
0P092@T010061PH00`<300<30`0A4A4200@4100400H61P0@4100410@00<30`8020P800@01PH600T9
2@092@T01`L70P0<30`0100410@04A4A014A4@0<30`200L71`0400820P092@T02@T900@410801@D5
00@020P800820P020P800`<30P0:2PX0100820P01PH600H61P051@D200<30`0400@410061PH01PH6
00L71`801PH600<02@T900@4100410@01P030`<300820P0400H61P020P800P8200h>3P808B4Q00@0
<C4a03<c<`0c<c<0:RXZ0P0S8b<0100Y:BT0;Rh^02h^;P0b<S8202@T900400d=3@030`<00`<300H6
1P802@T900@02`/;00X:2P0:2PX06a/K0P1MGEd01028R8P0Q8B408B4Q02=SHd209nOW`0409JFUP29
RHT0RHV908^;R`80SXj>00@0Ti>C092@T02@T900R8R80P2FUYH0102IVIT0RXZ:08Z:RP1fMWH206MW
I`0404M7A`0o?cl0?clo05QHF080H61P00@0HV9R06MWI`1WIfL0HV9R0P1]KFd0101nOWh0IVIV06IV
IP0o?cl201XJ6P<03@d=00@00@4100T92@092@T03Ph>0P0=3@d0100;2`/03@d=00d=3@0K6a/201hN
7P04018B4P0C4a<04a<C018B4P805ADE00@05aLG01`L700L71`051@D0P0>3Ph0100^;Rh0<30`030`
<00k>c/203Xj>P0403<c<`0S8b<08b<S024Q8@<0=3@d0P1TI6@0100V9RH02@T900T92@0/;2`204i>
CP<08R8R00@07AdM01XJ6P0J6QX06ATI0P0<30`0100P82006QXJ01XJ6P0I6AT201HF5P0401hN7P0A
4A404A4A018B4P80:b/[100a<C4202PX:004020P800M7Ad07AdM02@T9080<S8b00@0<30`0410@010
@400>3Ph0P0T92@0100S8b<09BDU02DU9@0Y:BT203Hf=P0403Lg=`0c<c<0<c<c02TY:@807alO00@0
:b/[02XZ:P0Z:RX09BDU0P0/;2`0100`<300<c<c03<c<`0/;2`202h^;P04038b<P0_;bl0;bl_0410
@080>c/k00@0:b/[0410@010@400>CTi0P0Z:RX0100H61P07QhN01hN7P0e=CD202PX:004010@4009
2@T02@T900/;2`809RHV00@0>SXj04I6AP16ATH0F5QH0P1aLG401020P800NWYj07YjNP1bLW8205eM
G@0404E5A@1FEUH0EUIF07alO080GUiN00@0ADE505ADE01DE5@0BTY:0P12@T80100o?cl0@4100410
@019BDT204Q8B003059BDP1HF5P0F5QH00<0CDe=00@0Cdm?05EEE@1EEED0D51@0P19BDT0101CDe<0
>c/k03/k>`1eMGD205=CD`0403hn?P1?Cdl0Cdm?04A4A080BDU900@0@d=304a<C01<C4`0AdM70P0o
?cl0101<C4`0B4Q804Q8B016ATH204E5A@0404Q8B01;Bd/0Bd];04I6AP80?3`l00@0IfMW08^;R`2;
Rh/0YjNW0P2EUID01018B4P020P800P8200<30`200820P0300H61P020P800P8200<01@D500@020P8
00T92@092@T0410@0P0820P010061PH00@4100410@051@D300820P800@410000100410@01@D500D5
1@030`<200410@0400<30`020P800P8200@410801PH600@03@d=00820P020P802`/;0P0?3`l01007
1`L00`<300<30`010@4200P820@010@40P0>3Ph0100A4A404Q8B018B4P0410@200<30`0400@41002
0P800P8200D51@801`L700@01PH600d=3@0=3@d010@40P071`L010010@400P8200820P030`<200H6
1P<00@4100@020P800@4100410@01PH60P020P80100410@01`L700L71`010@4200820P0400H61P05
1@D01@D500@410800P8200@04A4A024Q8@0Q8B40:b/[0P0`<300100[:b/0;bl_02l_;`0`<30202d]
;@0402@T900G5aL05aLG00d=3@<01`L70P020P8300l?3`0402XZ:P1[Jf/0Jf][08^;R`80S8b<00@0
UIFE0:2PX02PX:00Ti>C0P2=SHd0102;Rh/0Q8B408B4Q02IVIT2092@T00407alO02<S8`0S8b<09bL
W080Ti>C0`29RHT0101^KVh0GUiN05iNGP1ZJVX206IVIP0405]KF`1QHF40HF5Q07QhN080PX:200@0
Lg=c04Q8B018B4P06a/K0P0:2PX0100=3@d03`l?00l?3`0410@20000000400l?3`0E5AD05ADE00/;
2`803`l?00@051@D01DE5@0E5AD05QHF0P0K6a/0100>3Ph04a<C01<C4`0H61P201dM7@0402l_;`0J
6QX06QXJ01hN7P80<C4a00@0410@02PX:00X:2P0De=C0P0V9RH0100F5QH0@D510451@@1:BTX205mO
G`0404Q8B01:BTX0BTY:03/k>`80GemO00@0?Shn028R8P0R8R809RHV0P0O7al0100^;Rh09BDU02DU
9@0Q8B4201/K6`0301PH600J6QX06QXJ00<07AdM00@06ATI01@D500D51@03Ph>0P0J6QX0100Z:RX0
9RHV02HV9P0O7al201HF5P0402XZ:P0W9bL09bLW01LG5`808R8R00@05aLG01`L700L71`06a/K0P0[
:b/0101;Bd/0@T920492@P0n?Sh203Ph>00402XZ:P0l?3`0?3`l03hn?P80<c<c00@0>3Ph038b<P0b
<S80<30`0P0m?Cd0100k>c/0ATI604I6AP1ADE4203dm?@0403hn?P0m?Cd0?Cdm02LW9`80=cLg0`10
@400100i>CT0?Cdm03dm?@18B4P203Ph>00402<S8`0Q8B408B4Q01PH60803Ph>00@061PH02d];@0]
;Bd0C4a<0P1YJFT01020P800MGEe07EeM@1PH60205eMG@0404e=C@1DE5@0E5AD06EUI@80E5AD00@0
C4a<05=CD`1CDe<0B4Q80P0g=cL0100m?Cd0@4100410@01?Cdl205ADE004059BDP1CDe<0De=C04=3
@`80B4Q800@0CDe=05]KF`1KFe/0D51@0P1>CTh304M7A`030820P015ADD0ADE500<0ADE500@0@D51
04];B`1;Bd/0@d=30P1:BTX01015ADD0ATI604I6AP1<C4`204=3@`040410@00n?Sh0?Shn04Q8B080
Bd];00@0Cdm?03Ti>@0i>CT0IFEU0P2@T900102g]kL0QXJ608J6QP0`<30201HF5P0400T92@071`L0
1`L700L71`802PX:00@020P800820P020P800P820P051@D010061PH020P800P820071`L300D51@80
2PX:0@092@T100X:2P402PX:0000100410@01@D500D51@030`<200410@0400<30`020P800P8200@4
10801PH600@03@d=00820P020P802`/;0P0?3`l010071`L00`<300<30`010@4200P820@010@40P0>
3Ph0100A4A404Q8B018B4P0410@200<30`0400@410020P800P8200D51@801`L700@01PH600d=3@0=
3@d010@40P071`L010010@400P8200820P030`<200H61P<00@4100@020P800@4100410@01PH60P02
0P80100410@01`L700L71`010@4200820P0400H61P051@D01@D500@410800P8200@04A4A024Q8@0Q
8B40:b/[0P0`<300100[:b/0;bl_02l_;`0`<30202d];@0402@T900G5aL05aLG00d=3@<01`L70P02
0P8300l?3`0402XZ:P1[Jf/0Jf][08^;R`80S8b<00@0UIFE0:2PX02PX:00Ti>C0P2=SHd0102;Rh/0
Q8B408B4Q02IVIT2092@T00407alO02<S8`0S8b<09bLW080Ti>C0`29RHT0101^KVh0GUiN05iNGP1Z
JVX206IVIP0405]KF`1QHF40HF5Q07QhN080PX:200@0Lg=c04Q8B018B4P06a/K0P0:2PX0100=3@d0
3`l?00l?3`0410@20000000400l?3`0E5AD05ADE00/;2`803`l?00@051@D01DE5@0E5AD05QHF0P0K
6a/0100>3Ph04a<C01<C4`0H61P201dM7@0402l_;`0J6QX06QXJ01hN7P80<C4a00@0410@02PX:00X
:2P0De=C0P0V9RH0100F5QH0@D510451@@1:BTX205mOG`0404Q8B01:BTX0BTY:03/k>`80GemO00@0
?Shn028R8P0R8R809RHV0P0O7al0100^;Rh09BDU02DU9@0Q8B4201/K6`0301PH600J6QX06QXJ00<0
7AdM00@06ATI01@D500D51@03Ph>0P0J6QX0100Z:RX09RHV02HV9P0O7al201HF5P0402XZ:P0W9bL0
9bLW01LG5`808R8R00@05aLG01`L700L71`06a/K0P0[:b/0101;Bd/0@T920492@P0n?Sh203Ph>004
02XZ:P0l?3`0?3`l03hn?P80<c<c00@0>3Ph038b<P0b<S80<30`0P0m?Cd0100k>c/0ATI604I6AP1A
DE4203dm?@0403hn?P0m?Cd0?Cdm02LW9`80=cLg0`10@400100i>CT0?Cdm03dm?@18B4P203Ph>004
02<S8`0Q8B408B4Q01PH60803Ph>00@061PH02d];@0];Bd0C4a<0P1YJFT01020P800MGEe07EeM@1P
H60205eMG@0404e=C@1DE5@0E5AD06EUI@80E5AD00@0C4a<05=CD`1CDe<0B4Q80P0g=cL0100m?Cd0
@4100410@01?Cdl205ADE004059BDP1CDe<0De=C04=3@`80B4Q800@0CDe=05]KF`1KFe/0D51@0P1>
CTh304M7A`030820P015ADD0ADE500<0ADE500@0@D5104];B`1;Bd/0@d=30P1:BTX01015ADD0ATI6
04I6AP1<C4`204=3@`040410@00n?Sh0?Shn04Q8B080Bd];00@0Cdm?03Ti>@0i>CT0IFEU0P2@T900
102g]kL0QXJ608J6QP0`<30201HF5P0400T92@071`L01`L700L71`802PX:00@020P800820P020P80
0P820P051@D010061PH020P800P820071`L300D51@802PX:0@092@T100X:2P402PX:000010051@D0
1PH600H61P071`L200820P040000000410@010@400<30`801`L700@01PH600l?3`0?3`l0410@0P0:
2PX010071`L00P8200820P061PH200<30`0400820P0820P020P800820P802PX:00@01@D500<30`03
0`<02@T90P010@4010092@T01@D500D51@071`L200T92@0400820P061PH01PH600@410801@D500<0
0`<300820P020P800`051@D0100820P01`L700L71`051@D200X:2P0400D51@0410@010@400<30`80
0@4100@010@400H61P061PH030`<0P061PH010030`<030`<00`<300C4a<203De=@04038b<P0X:2P0
:2PX03Ti>@80<c<c00@0<30`038b<P0b<S8061PH0P0<30`300D51@0400H61P010@400@4101XJ6P80
8R8R00@0CTi>08>3P`23Ph<0Shn?0P2>SXh0102GUiL0U9BD09BDU02;Rh/208n?S`04092@T029RHT0
RHV90:2PX080NWYj00@0Fe]K0861P@21PH40W9bL0P2<S8`308:2PP0406][J`1OGel0GemO065QH@80
IFEU00@0J6QX07=cL`1cLg<0QXJ60P1nOWh0101DE5@0:RXZ02XZ:P0?3`l200T92@0400`<300@4100
410@00`<30803Ph>00@0820P024Q8@0Q8B403Ph>0P0;2`/0100D51@04A4A014A4@0@410200h>3P04
01DE5@0F5QH05QHF01TI6@80:BTY00@09BDU01TI6@0I6AT0<c<c0P0/;2`0100>3Ph0<C4a034a<@15
ADD201HF5P0403Hf=P19BDT0BDU902PX:080<c<c0`0j>SX0100/;2`0>3Ph03Ph>01>CTh204m?C`04
03hn?P0F5QH05QHF00L71`806QXJ00@092@T03Xj>P0j>SX08R8R0P0M7Ad0100H61P05ADE01DE5@0?
3`l200820P04018B4P0?3`l03`l?00T92@80;2`/00@09BDU00<30`030`<0:2PX0P0g=cL0100S8b<0
7AdM01dM7@071`L2028R8P0402h^;P0c<c<0<c<c04Q8B080<C4a00@0;2`/02LW9`0W9bL0820P0P0b
<S80100T92@0;2`/02`/;012@T8203Lg=`0403Ph>012@T80@T920451@@80@41000@0@T9204M7A`17
AdL0B4Q80P0j>SX0100d=3@0@T920492@P17AdL20410@00402l_;`0d=3@0=3@d03hn?P80:BTY00@0
<30`04E5A@15ADD0;2`/0P0=3@d0100F5QH07alO01lO7`0g=cL205aLG00407inOP1hN7P0N7Qh06YZ
JP80HV9R00@0De=C051@D01@D500GUiN0P1CDe<01018B4P0@D510451@@13@d<20492@P0404=3@`11
@D40@D5103lo?`80B4Q800@0CTi>04a<C01<C4`0@d=30P1@D500101;Bd/0De=C05=CD`1ADE4204a<
C00403hn?P1YJFT0JFUY08>3P`80@41000@0BDU904E5A@15ADD0?clo0P15ADD0101?Cdl0DE5A055A
D@17AdL204I6AP040492@P0o?cl0?clo03dm?@80>c/k00@0C4a<051@D01@D500Bd];0P12@T801024
Q8@0XJ6Q0:6QX@2i^KT208F5Q@0403Lg=`0H61P061PH00P820803@d=00@00`<300/;2`0;2`/01PH6
0P030`<00`020P800`<300<30`0300<30`0400@410030`<00`<300P820802@T90@020P8100410@40
0@41000300410@0400/;2`051@D01@D500@410800`<300@01@D500<30`030`<010@40P071`L0100=
3@d00@4100410@020P8200L71`0400H61P0410@010@400D51@8010@400@020P800T92@092@T01`L7
0P030`<0100410@00`<300<30`0820P200H61P0400D51@0>3Ph03Ph>00<30`8010@400@01`L700h>
3P0>3Ph01@D50P071`L010020P802@T900T92@051@D200410@0400820P030`<00`<300H61P802`/;
00@02@T900410@010@401`L70P0820P0100:2PX01`L700L71`030`<2018B4P0401dM7@0o?cl0?clo
030`<0807QhN0`0o?cl0100i>CT0<C4a034a<@0G5aL200L71`0400410@071`L01`L7000000803Ph>
00@07alO038b<P0b<S80J6QX0P26QXH00`28R8P0SHf=08f=S@0409RHV080Ogmo00@0P82009ZJVP2J
VYX0Y:BT0P1?Cdl0100o?cl0P8200820P02FUYH208b<S00407UiN@1[Jf/0Jf][071`L080IFEU00@0
FUYJ06QXJ01XJ6P0MgMg0P20P800101mOGd0GemO05mOG`0e=CD2010@400400820P051@D01@D5014A
4@805ADE00@0410@01PH600H61P071`L0P0B4Q80100820P010@400@4100F5QH202HV9P0401LG5`0=
3@d03@d=01XJ6P803@d=00@061PH02`/;00/;2`08b<S0P0U9BD0100a<C40820P020P800S8b<203Ti
>@0402TY:@0410@010@403/k>`80Hf=S00@09RHV01@D500D51@00`<30P0Z:RX0100a<C407alO01lO
7`19BDT203dm?@0403Ti>@0L71`071`L01XJ6P804a<C00@06a/K02LW9`0W9bL06a/K0P0[:b/0100B
4Q80410@010@400T92@2010@400400l?3`0I6AT06ATI014A4@807alO00@0=SHf02<S8`0S8b<0:BTY
0P0F5QH0100K6a/0?clo03lo?`0W9bL201DE5@0401dM7@0h>3P0>3Ph03@d=08071`L00@0<30`038b
<P0b<S807QhN0P0F5QH0100R8R80@T920492@P14A4@203@d=00404=3@`1@D500D51@04];B`80BDU9
00@0C4a<05EEE@1EEED0C4a<0P1:BTX3055AD@04051@D010@400@41003`l?080@d=300@0=3@d02HV
9P0V9RH0?clo0P11@D40100S8b<04a<C01<C4`0C4a<200P8200402LW9`19BDT0BDU906i^KP80Kfm_
00@0KVi^065QH@1QHF40GEeM0P1DE5@306IVIP0405=CD`13@d<0@d=304I6AP80EeMG00@0A4A40410
@010@400?Shn0P11@D40101=CDd0FUYJ05YJFP1?Cdl205MGE`0404];B`1@D500D51@05ADE080CDe=
00@0?clo05UIF@1IFET0Jf][0`10@40204M7A`0404Y:BP18B4P0B4Q805EEE@80Bd];00@0@T920451
@@11@D40?clo0P10@400100l?3`0?Shn03hn?P19BDT204a<C00403dm?@13@d<0@d=308>3P`80WIfM
00@0/[:b08B4Q024Q8@0@4100P0;2`/0100=3@d00P8200820P051@D200L71`0400P820061PH01PH6
00X:2P802`/;00@020P800L71`071`L01`L70P061PH0100?3`l01@D500D51@030`<2000000000`01
0@40100;2`/01@D500D51@0410@200<30`0400D51@030`<00`<300@410801`L700@03@d=00410@01
0@400P820P071`L010061PH010@400@410051@D200@4100400P820092@T02@T900L71`800`<300@0
10@400<30`030`<020P80P061PH010051@D03Ph>00h>3P030`<200@4100400L71`0>3Ph03Ph>00D5
1@801`L700@00P8200T92@092@T01@D50P010@4010020P800`<300<30`061PH200/;2`0400T92@01
0@400@4100L71`8020P800@02PX:00L71`071`L00`<30P0B4Q80100M7Ad0?clo03lo?`0`<30201hN
7P<0?clo00@0>CTi034a<@0a<C405aLG0P071`L010010@401`L700L71`00000200h>3P0401lO7`0b
<S80<S8b06QXJ080QXJ600<0R8R808f=S@2=SHd0102HV9P207moO`040820P02JVYX0VYZJ0:BTY080
Cdm?00@0?clo0820P020P800UYJF0P2<S8`0101iNGT0Jf][06][J`1`L70206EUI@0405YJFP1XJ6P0
J6QX07MgM`80P82000@0OGem05mOG`1OGel0=CDe0P0@410010020P801@D500D51@0A4A4201DE5@04
010@400H61P061PH01`L70804Q8B00@020P800@4100410@05QHF0P0V9RH0100G5aL03@d=00d=3@0J
6QX200d=3@0401PH600/;2`0;2`/02<S8`809BDU00@0<C4a020P800P82008b<S0P0i>CT0100Y:BT0
10@400@4100k>c/206=SH`0402HV9P0D51@051@D00<30`80:RXZ00@0<C4a01lO7`0O7al0BDU90P0m
?Cd0100i>CT071`L01`L700J6QX201<C4`0401/K6`0W9bL09bLW01/K6`80:b/[00@04Q8B010@400@
410092@T0P0@4100100?3`l06ATI01TI6@0A4A4201lO7`0403Hf=P0S8b<08b<S02TY:@805QHF00@0
6a/K03lo?`0o?cl09bLW0P0E5AD0100M7Ad0>3Ph03Ph>00d=3@201`L7004030`<00b<S80<S8b01hN
7P805QHF00@08R8R0492@P12@T80A4A40P0d=3@01013@d<0D51@051@D01;Bd/204U9B@0404a<C01E
EED0EEEE04a<C080BTY:0`1ADE40101@D500@4100410@00l?3`204=3@`0403@d=00V9RH09RHV03lo
?`80@D5100@08b<S01<C4`0C4a<04a<C0P0820P0100W9bL0BDU904U9B@1^KVh206m_K`0406i^KP1Q
HF40HF5Q05eMG@80E5AD0`1VIVH0101CDe<0@d=304=3@`16ATH205MGE`0404A4A010@400@41003hn
?P80@D5100@0CDe=05YJFP1JFUX0Cdm?0P1GEeL0101;Bd/0D51@051@D01DE5@204e=C@0403lo?`1I
FET0FEUI06][J`<0@4100P17AdL0101:BTX0B4Q804Q8B01EEED204];B`040492@P11@D40@D5103lo
?`80@41000@0?3`l03hn?P0n?Sh0BDU90P1<C4`0100m?Cd0@d=304=3@`23Ph<209fMW@040;:b/P24
Q8@0Q8B40410@0802`/;00@03@d=00820P020P801@D50P071`L0100820P01PH600H61P0:2PX200/;
2`0400P820071`L01`L700L71`801PH600@03`l?00D51@051@D00`<30P000000000400@410071`L0
1`L700@410<02@T90P0820P010030`<02@T900T92@092@T200D51@0400X:2P051@D01@D500820P80
10@400@01@D500820P020P8010@40P0820P010092@T03Ph>00h>3P092@T200820P0400P8200410@0
10@400@410800`<300@00P8200L71`071`L010@40P0>3Ph300D51@0300d=3@0820P020P800<00P82
10010@4200<30`0400820P061PH01PH600L71`8010@400@00P8200@4100410@01`L70P020P801006
1PH08b<S02<S8`0V9RH202l_;`0402`/;00_;bl0;bl_0410@080@T9200@0@41002d];@0];Bd0410@
0P071`L010030`<010@400@410010@4201/K6`0402XZ:P11@D40@D5106e]K@80O7al00@0QXJ609RH
V02HV9P0UiNG0`2IVIT207EeM@0408^;R`2/[:`0[:b/08n?S`80?clo00@0ADE507inOP1nOWh0SHf=
0P22PX80101SHf<0KVi^06i^KP20P80206e]K@04061PH01[Jf/0Jf][07alO080Ng]k00@0HF5Q03/k
>`0k>c/08R8R0P0:2PX010030`<04A4A014A4@0G5aL201lO7`0401/K6`0D51@051@D00l?3`804A4A
00@06a/K01HF5P0F5QH071`L0P0W9bL0100L71`030`<00`<300B4Q8200X:2P0400d=3@0L71`071`L
03@d=0<0@4100P0^;Rh0100e=CD0820P020P800[:b/2034a<@0402LW9`1LG5`0G5aL061PH080EUIF
00@08R8R02TY:@0Y:BT0<c<c0P0l?3`0101;Bd/0<c<c03<c<`0/;2`2018B4P0400@4100D51@051@D
03Ti>@8092@T00@02`/;03@d=00d=3@09RHV0P0K6a/0100[:b/04A4A014A4@00000200/;2`0401TI
6@061PH01PH6018B4P807QhN00@09bLW01LG5`0G5aL08B4Q0P0^;Rh0100X:2P07AdM01dM7@0L71`2
01lO7`0402/[:`0b<S80<S8b02d];@80<30`00@0;Rh^01dM7@0M7Ad05QHF0P0Z:RX0100i>CT07AdM
01dM7@0J6QX203<c<`04030`<00f=SH0=SHf03dm?@80@T9200@0ATI6051@D01@D500GEeM0P1=CDd0
100b<S807alO01lO7`0[:b/203Ph>00403De=@10@400@41003Hf=P808B4Q00@07alO01TI6@0I6AT0
3`l?0P0>3Ph0100M7Ad0>c/k03/k>`1OGel3075aL@80GUiN00@0FUYJ051@D01@D500HF5Q0P1JFUX0
1017AdL0Bd];04];B`1JFUX205mOG`<0?3`l00@0CDe=04Y:BP1:BTX0Cdm?0P1HF5P0101?Cdl0EUIF
05IFEP17AdL2055AD@0404i>CP16ATH0ATI604A4A080D51@00@0DE5A03dm?@0m?Cd0A4A40P1?Cdl0
101EEED0ATI604I6AP1:BTX20492@P<0ADE500@0?clo04A4A014A4@0ATI60P14A4@01012@T80C4a<
04a<C010@40204i>CP0407IfMP2EUID0UIFE09bLW080Kfm_00@0@41000/;2`0;2`/03@d=0P0820P0
10092@T01PH600H61P0;2`/200D51@0400<30`092@T02@T900d=3@802`/;00@01PH600820P020P80
2PX:0P0820P100d=3@401PH60@061PH0000400<30`0410@010@400<30`8030`<00@01`L700@41004
10@01PH60P0=3@d300<30`0400/;2`0820P020P800L71`<0410@0P061PH0100820P02@T900T92@07
1`L200X:2P0400h>3P0820P020P800T92@800`<300@03Ph>00L71`071`L010@40P092@T0100;2`/0
1PH600H61P0820P200H61P0400`<30061PH01PH600L71`8020P80`0410@010020P8020P800P82008
20P200@4100400410@020P800P8200D51@800@4100@020P800820P020P8020P80P0a<C40100b<S80
9RHV02HV9P0_;bl203hn?P0403<c<`0e=CD0=CDe03dm?@80:b/[00@04Q8B00H61P061PH01@D50P09
2@T0100;2`/0:BTY02TY:@0j>SX205QHF00407inOP28R8P0R8R809FEU@80YZJV00@0YJFU0:JVYP2V
YZH0SHf=0P1dM7@0102MWId0Y:BT0:BTY01UIFD204Q8B00405eMG@1bLW80LW9b08b<S080NWYj00@0
IVIV0820P020P800P8200P1[Jf/0101VIVH0MgMg07MgM`21PH4206e]K@0404A4A00K6a/06a/K00L7
1`801@D500@0410@01dM7@0M7Ad04A4A0P0<30`0100J6QX0:2PX02PX:00W9bL201/K6`0400`<300>
3Ph03Ph>020P80807alO00<06ATI01HF5P0F5QH00`0J6QX0100;2`/05ADE01DE5@0I6AT201hN7P04
01`L700M7Ad07AdM0410@080820P00@09RHV05=CD`1CDe<0C4a<0P0k>c/0100`<300F5QH05QHF01[
Jf/206IVIP0405EEE@0m?Cd0?Cdm05=CD`80BDU900<03@d=00`<300<30`00`0g=cL0100b<S8071`L
01`L70071`L202HV9P0403Lg=`0U9BD09BDU01`L70804a<C00@06a/K01XJ6P0J6QX01@D50P0;2`/0
100C4a<092@T02@T900?3`l201`L700403`l?00o?cl0?clo028R8P80820P00@0;bl_01XJ6P0J6QX0
:RXZ0P0g=cL0100N7Qh09bLW02LW9`0b<S82034a<@0402`/;00P8200820P03Hf=P80ADE500@0;bl_
02h^;P0^;Rh0@4100P0l?3`0100^;Rh0?Shn03hn?P16ATH20492@P0404Y:BP0n?Sh0?Shn03<c<`80
>3Ph0`11@D40100c<c<0;bl_02l_;`0`<3020410@004038b<P0F5QH05QHF00P8208051@D00@0410@
02l_;`0_;bl0ATI60P1TI6@0101bLW80HV9R069RHP1DE5@2059BDP04065QH@1EEED0EEEE03`l?080
@41000@0H61P05]KF`1KFe/0ATI60P15ADD0101IFET0Cdm?04m?C`1:BTX2059BDP0404a<C01CDe<0
De=C055AD@80EeMG00@0B4Q80410@010@400BTY:0P19BDT01017AdL0@D510451@@15ADD204I6AP04
04E5A@12@T80@T9204I6AP80BDU900@0AdM703hn?P0n?Sh0>c/k0P11@D401018B4P0A4A404A4A018
B4P204a<C00403Ti>@1RHV80HV9R08R8R080YjNW00@0UiNG061PH01PH600>3Ph0P0@4100100>3Ph0
2PX:00X:2P051@D200h>3P0400D51@0410@010@400@410800`<300@03`l?00T92@092@T01PH60P03
0`<300T92@404Q8B0@0:2PX100X:2P0000@00`<300@4100410@00`<30P0<30`010071`L010@400@4
10061PH200d=3@<00`<300@02`/;00P8200820P01`L70`0@410200H61P0400P820092@T02@T900L7
1`802PX:00@03Ph>00P8200820P02@T90P030`<0100>3Ph01`L700L71`0410@200T92@0400/;2`06
1PH01PH600P820801PH600@030`<00H61P061PH01`L70P0820P300@4100400820P0820P020P800P8
208010@400@00@4100820P020P801@D50P010@40100820P00P8200820P0820P2034a<@04038b<P0V
9RH09RHV02l_;`80?Shn00@0<c<c03De=@0e=CD0?Cdm0P0[:b/0100B4Q801PH600H61P051@D200T9
2@0400/;2`0Y:BT0:BTY03Xj>P80F5QH00@0OWin08R8R028R8P0UIFE0P2VYZH0102UYJD0YZJV0:JV
YP2=SHd207AdM00409fMW@2TY:@0Y:BT06EUI@80B4Q800@0GEeM079bLP1bLW80S8b<0P1jNWX0101V
IVH0P8200820P020P80206][J`0406IVIP1gMgL0MgMg0861P@80KFe]00@0A4A401/K6`0K6a/01`L7
0P051@D0100@41007AdM01dM7@0A4A4200`<300401XJ6P0X:2P0:2PX02LW9`806a/K00@030`<00h>
3P0>3Ph0820P0P0O7al00`0I6AT05QHF01HF5P0301XJ6P0400/;2`0E5AD05ADE01TI6@807QhN00@0
71`L01dM7@0M7Ad0@4100P0P8200100V9RH0De=C05=CD`1<C4`203/k>`04030`<01HF5P0F5QH06][
J`80IVIV00@0EEEE03dm?@0m?Cd0De=C0P19BDT00`0=3@d030`<00`<300303Lg=`04038b<P0L71`0
71`L00L71`809RHV00@0=cLg02DU9@0U9BD071`L0P0C4a<0100K6a/06QXJ01XJ6P051@D200/;2`04
01<C4`0T92@092@T00l?3`8071`L00@0?3`l03lo?`0o?cl08R8R0P0P8200100_;bl06QXJ01XJ6P0Z
:RX203Lg=`0401hN7P0W9bL09bLW038b<P80<C4a00@0;2`/020P800P8200=SHf0P15ADD0100_;bl0
;Rh^02h^;P10@40203`l?00402h^;P0n?Sh0?Shn04I6AP80@T9200@0BTY:03hn?P0n?Sh0<c<c0P0h
>3P30451@@0403<c<`0_;bl0;bl_030`<080@41000@0<S8b01HF5P0F5QH020P80P0D51@0100@4100
;bl_02l_;`16ATH206ATI004079bLP1RHV80HV9R05ADE080DU9B00@0HF5Q05EEE@1EEED0?3`l0P10
@400101PH600Fe]K05]KF`16ATH204E5A@0405UIF@1?Cdl0Cdm?04Y:BP80DU9B00@0C4a<05=CD`1C
De<0DE5A0P1GEeL01018B4P0@4100410@01:BTX204U9B@0404M7A`11@D40@D5104E5A@80ATI600@0
ADE50492@P12@T80ATI60P19BDT01017AdL0?Shn03hn?P0k>c/20451@@0404Q8B014A4@0A4A404Q8
B080C4a<00@0>CTi069RHP1RHV80R8R80P2WYjL0102GUiL0H61P061PH00h>3P2010@400400h>3P0:
2PX02PX:00D51@803Ph>00@01@D500@4100410@010@40P030`<0100?3`l02@T900T92@061PH200<3
0`<02@T90@0B4Q8100X:2P402PX:000010030`<00@4100410@092@T200410@0400H61P0820P020P8
00D51@<010@40P0820P010092@T010@400@410061PH200/;2`0400P8200;2`/02`/;00L71`801PH6
00@00`<300H61P061PH02`/;0P0<30`010061PH020P800P8200=3@d200T92@0400@410051@D01@D5
00@410801`L700@00@4100H61P061PH02@T90P051@D010092@T030`<00`<300410@200D51@<020P8
00@01PH600L71`071`L01`L70P051@D010010@4020P800P8200;2`/200@4100400`<300];Bd0;Bd]
03De=@80:BTY00@0<C4a04M7A`17AdL0@d=30P0i>CT0100f=SH09bLW02LW9`0J6QX200T92@0400P8
20071`L01`L700`<3080:RXZ00@0@41006m_K`1_Kfl0S8b<0P2ATI40102?Shl0UIFE09FEU@2UYJD2
0:RXZ00307IfMP1VIVH0IVIV00<0SHf=00@0IVIV06YZJP1ZJVX0IVIV0P1TI6@0101mOGd0IfMW06MW
I`1ZJVX207inOP0407IfMP1aLG40LG5a07YjNP80Ogmo00@0MgMg05UIF@1IFET0<C4a0P0;2`/01001
0@400P8200820P0@410201hN7P04010@400?3`l03`l?01hN7P<0<C4a0P0F5QH010010@4030`<00`<
300T92@201`L700401XJ6P0W9bL09bLW02TY:@80:2PX00@071`L01DE5@0E5AD05aLG0P0O7al0100K
6a/061PH01PH600e=CD202@T900402d];@0n?Sh0?Shn03lo?`80EUIF00@0BTY:03hn?P0n?Sh0>CTi
0P0`<300100b<S80BDU904U9B@1`L70204A4A004010@400410@010@401@D50808R8R00<03`l?01TI
6@0I6AT00`0;2`/00`0X:2P0<c<c03<c<`03024Q8@0401dM7@0H61P061PH00l?3`803@d=00@08B4Q
028R8P0R8R807alO0P0;2`/0100C4a<09BDU02DU9@0T92@202LW9`04030`<00@4100410@02HV9P80
=cLg00@051@D018B4P0B4Q808B4Q0P0Y:BT0100Z:RX06QXJ01XJ6P0L71`2038b<P0402d];@0f=SH0
=SHf05=CD`80A4A400@0=3@d03`l?00l?3`0<C4a0P0[:b/0100g=cL0<c<c03<c<`18B4P205EEE@04
04=3@`17AdL0AdM70492@P80;bl_00@0@41005UIF@1IFET0?Cdm0P0P8200100D51@06a/K01/K6`0F
5QH201hN7P040410@01EEED0EEEE06QXJ080IfMW00@0FEUI059BDP1BDU80HV9R0P1NGUh01019BDT0
B4Q804Q8B01UIFD205UIF@04051@D01;Bd/0Bd];05]KF`80FUYJ00@0C4a<059BDP1BDU80B4Q80P1;
Bd/0101ADE40D51@051@D00o?cl204A4A00405eMG@1>CTh0CTi>04M7A`80A4A400@0ADE504];B`1;
Bd/0CTi>0P1=CDd01016ATH0D51@051@D016ATH203`l?00404E5A@17AdL0AdM704Y:BP80Bd];00@0
Cdm?04];B`1;Bd/0>3Ph0P1/K6`0102ATI40/[:b0;:b/P2JVYX205]KF`0402/[:`0>3Ph03Ph>00D5
1@800P8200@00@4100T92@092@T000000P092@T010020P8010@400@4100;2`/200H61P0400X:2P04
10@010@400H61P8030`<0@0=3@d100@4104010@4000010051@D02@T900T92@092@T200X:2P0400L7
1`0=3@d03@d=00`<308020P800<01@D500`<300<30`00`020P80100<30`02PX:00X:2P0410@200H6
1P0400L71`0820P020P800T92@<020P80P0<30`010071`L01@D500D51@051@D200@4100400D51@03
0`<00`<300P820802`/;00@0000000P8200820P010@40`071`L200H61P<00@4100@01PH600P82008
20P01`L70P0410@0100<30`02@T900T92@0:2PX2018B4P0400`<30000000000001dM7@80<30`00@0
=SHf03<c<`0c<c<0=cLg0P18B4P0101>CTh0>CTi03Ti>@0S8b<201HF5P0401<C4`0=3@d03@d=014A
4@803Ph>00@061PH02PX:00X:2P0BDU90P1hN7P01020P800R8R808R8R02>SXh209FEU@030::RXP2S
Xj<0Xj>S00<0N7Qh00@0U9BD0861P@21PH40P8200P2@T900101QHF40Cdm?04m?C`1PH602065QH@04
06MWI`1/K6`0K6a/071`L080NGUi00@0QXJ607moO`1oOgl0H61P0P0m?Cd0100H61P01@D500D51@0A
4A4201lO7`0401LG5`0<30`030`<01XJ6P80;Bd]00@0820P01<C4`0C4a<061PH0P0R8R80100T92@0
9BDU02DU9@0L71`200l?3`0401hN7P0`<300<30`01lO7`804A4A00@0<C4a04I6AP16ATH0?Cdm0P0j
>SX0100b<S805QHF01HF5P0@4102020P800402LW9`0^;Rh0;Rh^024Q8@80=SHf00@0Hf=S04A4A014
A4@09RHV0P0/;2`0100h>3P0ADE504E5A@1@D50201TI6@0403Ph>01NGUh0GUiN02TY:@80410@00@0
1@D503Hf=P0f=SH02PX:0P0820P01015ADD0;Rh^02h^;P0N7Qh200T92@0400820P092@T02@T901lO
7`805QHF00@04Q8B01DE5@0E5AD061PH0P0E5AD010051@D02`/;00/;2`0T92@202DU9@0402`/;00K
6a/06a/K02h^;P80BDU900@0=CDe01lO7`0O7al0:BTY0P0S8b<010010@403`l?00l?3`0_;bl2030`
<00402<S8`0a<C40<C4a04U9B@80=cLg00@0:2PX02l_;`0_;bl08b<S0P0^;Rh01011@D40>CTi03Ti
>@15ADD20410@00402XZ:P0e=CD0=CDe05EEE@80BTY:00@0A4A403/k>`0k>c/08R8R0P0N7Qh0100M
7Ad05QHF01HF5P0>3Ph201dM7@0404I6AP1>CTh0CTi>05iNGP80Hf=S00@0FEUI04];B`1;Bd/0FEUI
0P1>CTh01012@T80De=C05=CD`1dM7@2061PH004055AD@1<C4`0C4a<05ADE080EUIF00@0BDU904a<
C01<C4`0ATI60P1=CDd0101;Bd/0Cdm?04m?C`1:BTX204i>CP04059BDP16ATH0ATI60492@P80@410
00<0@T9204M7A`17AdL00`1;Bd/01017AdL0C4a<04a<C014A4@204=3@`0404U9B@18B4P0B4Q804Q8
B080BDU900@0C4a<0492@P12@T80Bd];0P28R8P0102GUiL0YjNW0:NWY`2BTY82055AD@04024Q8@09
2@T02@T900L71`800@410`061PH010071`L01PH600H61P0410@200X:2P0400T92@020P800P820041
0@802`/;00@030`<00P8200820P02@T90P061PH0000400D51@092@T02@T900T92@802PX:00@01`L7
00d=3@0=3@d030`<0P0820P00`051@D030`<00`<300300820P0400`<300:2PX02PX:00@410801PH6
00@01`L700P8200820P02@T90`0820P200`<300400L71`051@D01@D500D51@8010@400@01@D500<3
0`030`<020P80P0;2`/01000000020P800P8200410@300L71`801PH60`010@4010061PH020P800P8
20071`L200@4100400`<30092@T02@T900X:2P804Q8B00@030`<0000000000007AdM0P0`<300100f
=SH0<c<c03<c<`0g=cL204Q8B00404i>CP0i>CT0>CTi02<S8`805QHF00@04a<C00d=3@0=3@d04A4A
0P0>3Ph0100H61P0:2PX02PX:019BDT207QhN0040820P028R8P0R8R808j>SP80UIFE00<0XZ:R0:>S
X`2SXj<00`1hN7P0102DU9@0PH610861P@20P802092@T004065QH@1?Cdl0Cdm?061PH080HF5Q00@0
IfMW06a/K01/K6`0L71`0P1iNGT01026QXH0Ogmo07moO`1PH60203dm?@0401PH60051@D01@D5014A
4@807alO00@05aLG00`<300<30`06QXJ0P0];Bd0100P82004a<C01<C4`0H61P2028R8P0402@T900U
9BD09BDU01`L70803`l?00@07QhN030`<00`<3007alO0P0A4A40100a<C40ATI604I6AP0m?Cd203Xj
>P04038b<P0F5QH05QHF010@4080820P00@09bLW02h^;P0^;Rh08B4Q0P0f=SH0101SHf<0A4A404A4
A00V9RH202`/;00403Ph>015ADD0ADE5051@D0806ATI00@0>3Ph05iNGP1NGUh0:BTY0P0@41001005
1@D0=SHf03Hf=P0:2PX200P8200404E5A@0^;Rh0;Rh^01hN7P802@T900@00P8200T92@092@T07alO
0P0F5QH0100B4Q805ADE01DE5@0H61P201DE5@0400D51@0;2`/02`/;02@T90809BDU00@0;2`/01/K
6`0K6a/0;Rh^0P19BDT0100e=CD07alO01lO7`0Y:BT202<S8`0400410@0?3`l03`l?02l_;`80<30`
00@08b<S034a<@0a<C40BDU90P0g=cL0100X:2P0;bl_02l_;`0S8b<202h^;P040451@@0i>CT0>CTi
04E5A@80@41000@0:RXZ03De=@0e=CD0EEEE0P1:BTX01014A4@0>c/k03/k>`0R8R8201hN7P0401dM
7@0F5QH05QHF00h>3P807AdM00@0ATI604i>CP1>CTh0GUiN0P1SHf<0101IFET0Bd];04];B`1IFET2
04i>CP040492@P1CDe<0De=C07AdM080H61P00@0DE5A04a<C01<C4`0E5AD0P1FEUH01019BDT0C4a<
04a<C016ATH204e=C@0404];B`1?Cdl0Cdm?04Y:BP80CTi>00@0DU9B04I6AP16ATH0@T920P10@400
0`12@T80AdM704M7A`0304];B`0404M7A`1<C4`0C4a<04A4A080@d=300@0BDU904Q8B018B4P0B4Q8
0P19BDT0101<C4`0@T920492@P1;Bd/208R8R00409NGU`2WYjL0YjNW09:BTP80DE5A00@08B4Q00T9
2@092@T01`L70P010@4300H61P0400L71`061PH01PH600@410802PX:00@02@T900820P020P800@41
0P0;2`/0100<30`020P800P820092@T200H61P0000@00`<300P8200820P01@D50P0820P010071`L0
0P8200820P051@D200820P0400L71`0?3`l03`l?00<30`80410@00@03Ph>00H61P061PH00@410P00
000300L71`0400D51@010@400@4100820P802PX:00@01PH600D51@051@D01PH60P071`L010000000
0P8200820P0<30`200P8200400<30`020P800P8200<30`8030`<00@01`L700410@010@4000000P0<
30`010051@D010@400@410071`L200<30`0400P8200410@010@400<30`802`/;00@01@D500410@01
0@409bLW0P0d=3@0100c<c<0<30`030`<011@D4204M7A`040410@00f=SH0=SHf028R8P802`/;00@0
1`L700/;2`0;2`/03Ph>0P0I6AT0100V9RH0<c<c03<c<`1cLg<2096AT@040820P029RHT0RHV909VI
V@80WYjN00@0Ti>C08n?S`2?Shl0PX:20P29RHT0102NWYh0TI6A096AT@2CTi<2092@T00405IFEP1=
CDd0CDe=061PH080L71`00@0NGUi07QhN01hN7P0LG5a0P1cLg<0101nOWh0LG5a075aL@1?Cdl202TY
:@0400d=3@0:2PX02PX:010@40805aLG0`0L71`0100O7al08B4Q024Q8@0Q8B4201dM7@0401TI6@0E
5AD05ADE010@40806ATI00@07QhN01/K6`0K6a/0<30`0P0g=cL0100U9BD0410@010@400O7al203@d
=00305=CD`0m?Cd0?Cdm00<04A4A00@05QHF02<S8`0S8b<0:RXZ0P0I6AT0100=3@d05QHF01HF5P0<
30`202TY:@0404e=C@14A4@0A4A4024Q8@803Ph>00@0:RXZ020P800P8200<S8b0P1[Jf/0100o?cl0
>3Ph03Ph>00[:b/201TI6@0401lO7`00000000000492@P80FEUI00@0<S8b03De=@0e=CD03Ph>0P0H
61P0100D51@04Q8B018B4P0O7al201`L700401/K6`0:2PX02PX:00X:2P80:RXZ00@07alO01DE5@0E
5AD04Q8B0P0<30`0100R8R80:RXZ02XZ:P0O7al203De=@0403hn?P0U9BD09BDU020P8080;2`/00@0
8B4Q01`L700L71`07QhN0P0J6QX0100Y:BT0;2`/02`/;00/;2`20410@00404Q8B011@D40@D5103/k
>`80?clo00@0DE5A04e=C@1=CDd0BDU90P1>CTh01014A4@0<S8b038b<P0m?Cd203Ph>00401hN7P0O
7al07alO02d];@806a/K00@02@T901hN7P0N7Qh0@4100P1?Cdl306ATI00405]KF`19BDT0BDU9051@
D080C4a<00@0BTY:051@D01@D500L71`0P1WIfL304U9B@0404a<C01FEUH0EUIF051@D080DE5A0`1>
CTh01017AdL0ADE504E5A@1CDe<205iNGP0405EEE@19BDT0BDU904A4A080B4Q800@0BDU904E5A@15
ADD0A4A40P18B4P304e=C@0404A4A016ATH0ATI604=3@`80ADE500@0@d=30410@010@400C4a<0P0k
>c/0101?Cdl0UiNG09NGU`2JVYX20:RXZ00409VIV@1;Bd/0Bd];018B4P801@D500@03@d=00D51@05
1@D01@D50P0:2PX0100<30`01PH600H61P092@T200H61P0400/;2`010@400@4100@410802PX:00@0
1`L700D51@051@D010@40P0;2`/0000400@410061PH01PH600<30`801`L700@01@D500820P020P80
2PX:0P020P8010061PH010@400@410071`L200/;2`0400820P010@400@4100410@80000000<00@41
00H61P061PH00`051@D300P8200400@4100820P020P800<30`80000000@00`<300P8200820P061PH
0P0?3`l600@4100400X:2P000000000000D51@D010@400@00P8200@4100410@00`<30P0<30`01006
1PH020P800P820071`L200h>3P04038b<P0g=cL0=cLg03dm?@80>3Ph00@0B4Q803`l?00l?3`0;Rh^
0P0g=cL0100/;2`05QHF01HF5P0=3@d200l?3`04010@400Q8B408B4Q020P8080?clo00@0QHF508n?
S`2?Shl0P8200P21PH40102BTY80WYjN09jNWP2BTY8208N7Q`040861P@29RHT0RHV90:>SX`80YJFU
00@0W9bL07moO`1oOgl0C4a<0P1ADE40101QHF40LG5a075aL@20P80207IfMP0406m_K`1jNWX0NWYj
07UiN@80FEUI00@0=CDe01LG5`0G5aL051@D0P0M7Ad0100E5AD051@D01@D500J6QX2020P80<0:2PX
00@092@T02HV9P0V9RH08R8R0`0G5aL201/K6`0401hN7P0P8200820P01dM7@804A4A00@08B4Q01TI
6@0I6AT05ADE0P0V9RH01016ATH0B4Q804Q8B00V9RH2028R8P0401DE5@0X:2P0:2PX03Ph>0<0De=C
0P0i>CT01017AdL0Hf=S06=SH`1KFe/2055AD@0403hn?P0F5QH05QHF03hn?P80@T920`0R8R80100:
2PX0=3@d03@d=017AdL202<S8`0401hN7P0@4100410@04I6AP80DU9B00@0>CTi04Q8B018B4P09RHV
0P0J6QX0100P82004Q8B018B4P0=3@d200l?3`04028R8P0W9bL09bLW01LG5`80;Bd]00@0:RXZ01hN
7P0N7Qh07AdM0P0?3`l0100`<300>CTi03Ti>@0V9RH202`/;00401TI6@051@D01@D502<S8`80;Rh^
00@06ATI02PX:00X:2P0?Cdm0P0X:2P0100K6a/09RHV02HV9P0X:2P2038b<P<0=SHf00@0>CTi0451
@@11@D40AdM70P0b<S80100h>3P0Cdm?04m?C`1?Cdl204E5A@0403`l?00h>3P0>3Ph0492@P80;Rh^
00@0:RXZ01TI6@0I6AT02PX:0P0E5AD0100c<c<0AdM704M7A`1QHF42069RHP0405IFEP1?Cdl0Cdm?
04Y:BP80@41000@0ATI604A4A014A4@0BTY:0P1ADE401015ADD0A4A404A4A019BDT206QXJ00405aL
G01DE5@0E5AD05eMG@80C4a<00@0ADE504A4A014A4@0FEUI0P1MGEd0101<C4`0ADE504E5A@0n?Sh2
0410@0030492@P15ADD0ADE500<0@T9200@0AdM705EEE@1EEED0CTi>0P16ATH00`12@T80@D510451
@@0304I6AP0404a<C00n?Sh0?Shn05]KF`80UYJF00@0XJ6Q0:ZZZP2ZZZX0SXj>0P10@400100K6a/0
1`L700L71`0@410200@4100400L71`061PH01PH600<30`801`L700@02PX:00`<300<30`03@d=0P06
1PH010030`<00@4100410@0410@200L71`<00P820000100410@01PH600H61P030`<200L71`0400D5
1@020P800P8200X:2P800P8200@01PH600@4100410@01`L70P0;2`/010020P800@4100410@010@42
0000000300410@061PH01PH600<01@D50`0820P0100410@020P800P820030`<20000000400<30`08
20P020P801PH60803`l?1P0410@0100:2PX00000000000051@D500@4100400820P0410@010@400<3
0`8030`<00@01PH600P8200820P01`L70P0>3Ph0100b<S80=cLg03Lg=`0m?Cd203Ph>00404Q8B00l
?3`0?3`l02h^;P80=cLg00@0;2`/01HF5P0F5QH03@d=0P0?3`l0100@41008B4Q024Q8@0P820203lo
?`0408F5Q@2?Shl0Shn?0820P080PH6100@0TY:B09jNWP2NWYh0TY:B0P27QhL01021PH40RHV908V9
R@2SXj<20:FUY@0409bLW01oOgl0Ogmo04a<C080DE5A00@0HF5Q075aL@1aLG40P8200P1fMWH0101_
Kfl0NWYj07YjNP1iNGT205UIF@0403De=@0G5aL05aLG01@D50807AdM00@05ADE01@D500D51@06QXJ
0P0P820302PX:00402@T900V9RH09RHV028R8P<05aLG0P0K6a/0100N7Qh0820P020P800M7Ad2014A
4@04024Q8@0I6AT06ATI01DE5@809RHV00@0ATI604Q8B018B4P09RHV0P0R8R80100E5AD0:2PX02PX
:00h>3P305=CD`80>CTi00@0AdM706=SH`1SHf<0Fe]K0P1ADE40100n?Sh05QHF01HF5P0n?Sh20492
@P<08R8R00@02PX:03@d=00d=3@0AdM70P0S8b<0100N7Qh0410@010@4016ATH2059BDP0403Ti>@18
B4P0B4Q802HV9P806QXJ00@0820P018B4P0B4Q803@d=0P0?3`l0100R8R809bLW02LW9`0G5aL202d]
;@0402XZ:P0N7Qh07QhN01dM7@803`l?00@0<30`03Ti>@0i>CT09RHV0P0/;2`0100I6AT01@D500D5
1@0S8b<202h^;P0401TI6@0X:2P0:2PX03dm?@80:2PX00@06a/K02HV9P0V9RH0:2PX0P0b<S8303Hf
=P0403Ti>@11@D40@D5104M7A`80<S8b00@0>3Ph04m?C`1?Cdl0Cdm?0P15ADD0100l?3`0>3Ph03Ph
>012@T8202h^;P0402XZ:P0I6AT06ATI00X:2P805ADE00@0<c<c04M7A`17AdL0HF5Q0P1RHV80101F
EUH0Cdm?04m?C`1:BTX20410@00404I6AP14A4@0A4A404Y:BP80DE5A00@0ADE504A4A014A4@0BDU9
0P1XJ6P0101LG5`0E5AD05ADE01MGEd204a<C00404E5A@14A4@0A4A405UIF@80GEeM00@0C4a<04E5
A@15ADD0?Shn0P10@4000`12@T80ADE504E5A@030492@P0404M7A`1EEED0EEEE04i>CP80ATI600<0
@T920451@@11@D400`16ATH0101<C4`0?Shn03hn?P1KFe/209JFUP040:6QX@2ZZZX0ZZZZ08j>SP80
@41000@06a/K00L71`071`L0410@0P0410@010071`L01PH600H61P030`<200L71`0400X:2P0<30`0
30`<00d=3@801PH600@00`<300410@010@4010@40P071`L300820P0000@00`<300D51@051@D01@D5
0P0:2PX010092@T010@400@4100;2`/200X:2P04010@40010@400@4100H61P8010@400@020P800X:
2P0:2PX02@T90P051@D010010@400P8200820P0410@200P8200400L71`0<30`030`<00H61P801`L7
00@010@400T92@092@T01PH60P092@T0100=3@d03Ph>00h>3P0=3@d200820P0400<30`061PH01PH6
00d=3@80000000@00`<300H61P061PH01@D50P071`L010051@D02PX:00X:2P0:2PX200D51@0400L7
1`030`<00`<300`<30803Ph>00@0<C4a03<c<`0c<c<0>3Ph0P10@4001019BDT0<30`030`<00a<C42
04E5A@0402PX:00=3@d03@d=00d=3@<04A4A0P0R8R80100U9BD0EUIF05IFEP21PH4208B4Q00408N7
Q`2;Rh/0Rh^;09VIV@80Vi^K00@0Q8B407inOP1nOWh0QXJ60P2>SXh0102CTi<0UiNG09NGU`2HV9P2
07=cL`0404m?C`1OGel0GemO069RHP80KFe]00@0Ng]k07IfMP1fMWH0Ng]k0P1oOgl0101_Kfl0@T92
0492@P0D51@20000000400l?3`0Q8B408B4Q02PX:080;Rh^00@08R8R01`L700L71`08R8R0P0U9BD0
100/;2`0<C4a034a<@0U9BD201LG5`0401TI6@0K6a/06a/K01<C4`807AdM00@0<S8b034a<@0a<C40
6ATI0P0E5AD0100H61P09bLW02LW9`0^;Rh204E5A@040410@00a<C40<C4a02@T908061PH00@06QXJ
03@d=00d=3@0:b/[0P0];Bd0101PH600IFEU06EUI@12@T8204a<C00406ATI01iNGT0NGUi0451@@80
F5QH00@0KVi^06m_K`1_Kfl0@D510P0M7Ad302d];@0403@d=00m?Cd0?Cdm04a<C080;2`/00@01`L7
014A4@0A4A4092@T0P0@4100100=3@d05ADE01DE5@0I6AT2018B4P0400l?3`0@4100410@01/K6`80
;Rh^00@06QXJ01HF5P0F5QH07QhN0P0T92@0100_;bl0;Bd]02d];@0Y:BT203De=@0402HV9P0B4Q80
4Q8B024Q8@809RHV00@04a<C02<S8`0S8b<0=cLg0P0R8R80100K6a/09BDU02DU9@0U9BD201lO7`04
02@T900j>SX0>SXj04=3@`80>SXj00@0=cLg04m?C`1?Cdl0E5AD0P0l?3`0101DE5@0Bd];04];B`0X
:2P203@d=00403lo?`0c<c<0<c<c0492@P80=SHf00@08B4Q014A4@0A4A40:BTY0P15ADD0101PH600
GUiN05iNGP1DE5@2059BDP040451@@0o?cl0?clo04a<C080BTY:00@0Bd];04a<C01<C4`0BDU90P1<
C4`01012@T80J6QX06QXJ01MGEd204I6AP0405eMG@1ADE40DE5A059BDP80C4a<00@0HF5Q05]KF`1K
Fe/0Bd];0P17AdL0100i>CT0?3`l03`l?018B4P204Y:BP0404=3@`17AdL0AdM704];B`80CDe=00@0
@d=304A4A014A4@0ADE50P11@D40101;Bd/0DE5A055AD@1:BTX204A4A00307IfMP2@T900T92@00<0
YZJV00@0Q8B403`l?00l?3`071`L0P092@T0100:2PX00P8200820P051@D200L71`0400D51@0A4A40
4A4A00@410801@D500@02PX:00L71`071`L010@40P00000010010@402`/;00/;2`0?3`l200820P00
00@01PH600410@010@4010@40P0:2PX010092@T02`/;00/;2`092@T200H61P0400d=3@092@T02@T9
00X:2P800`<300@01@D500@4100410@01PH60P030`<0100;2`/01`L700L71`020P8200T92@0400P8
20071`L01`L700D51@801`L700@01@D500P8200820P02@T90P0820P010071`L010@400@4100820P2
00T92@0400D51@030`<00`<300@410803@d=00@010@400H61P061PH01@D50P0820P0100;2`/01PH6
00H61P030`<200H61P0400L71`061PH01PH600/;2`805ADE00@0=SHf03<c<`0c<c<0<C4a0P18B4P0
1015ADD0>c/k03/k>`15ADD203Ph>00401LG5`0<30`030`<00l?3`805QHF00@05ADE01lO7`0O7al0
<S8b0P1/K6`01024Q8@0R8R808R8R02BTY8208V9R@0409BDU02GUiL0UiNG07YjNP80O7al00@0T92@
09BDU02DU9@0TI6A0P2QXJ40102UYJD0K6a/06a/K01DE5@206EUI@04069RHP1cLg<0Lg=c07IfMP80
Lg=c00@0Ng]k07=cL`1cLg<0DU9B0P0Q8B40100<30`04a<C01<C4`0N7Qh2024Q8@0401TI6@0G5aL0
5aLG01hN7P809BDU0`0P8200100X:2P0=3@d03@d=00^;Rh201TI6@03020P800S8b<08b<S00<092@T
00@0<30`02d];@0];Bd05aLG0P0M7Ad0100g=cL0;bl_02l_;`0J6QX201PH60<02`/;00@06ATI02HV
9P0V9RH0?clo0P0g=cL0100f=SH0>CTi03Ti>@0i>CT203hn?P0404I6AP0a<C40<C4a02DU9@80@410
00@0=cLg05aLG01LG5`0FUYJ0P1RHV80101DE5@0?clo03lo?`14A4@2028R8P0404A4A010@400@410
034a<@<08R8R0P0F5QH0100Z:RX0;bl_02l_;`0n?Sh202/[:`0401DE5@0[:b/0:b/[02l_;`806ATI
00@020P801PH600H61P0<C4a0P0[:b/0100O7al0=3@d03@d=011@D4201TI6@0400l?3`0Y:BT0:BTY
01`L7080410@00@07alO02XZ:P0Z:RX0<30`0P0j>SX3030`<0040410@01<C4`0C4a<04Q8B080:BTY
00@0:RXZ02`/;00/;2`06a/K0P0[:b/0100i>CT0CTi>04i>CP1PH60203Ph>00403dm?@1;Bd/0Bd];
05IFEP80G5aL00@0?clo03`l?00l?3`0Bd];0P0j>SX0100J6QX020P800P8200M7Ad20410@00405]K
F`1NGUh0GUiN05aLG080De=C00@0@410055AD@1ADE40G5aL0P1=CDd0101GEeL0BDU904U9B@13@d<2
04m?C`0403dm?@1WIfL0IfMW06ATI080AdM700@0CTi>04Y:BP1:BTX0G5aL0P1:BTX0101IFET0EEEE
05EEE@1;Bd/204Q8B00403dm?@0k>c/0>c/k0410@080ADE500@0@T9204U9B@19BDT0C4a<0P19BDT0
100o?cl0A4A404A4A011@D4203hn?P<0C4a<00@0@d=304Y:BP1:BTX0Rh^;0P2EUID0102k^k/0Vi^K
09^KV`1/K6`203De=@0401/K6`0:2PX02PX:00@410800P8200@020P800D51@051@D00@410P0410@3
00L71`0400H61P071`L01`L700H61P801`L700@00@4100H61P061PH03@d=0P051@D0000400H61P01
0@400@4100@410802PX:00@02@T900/;2`0;2`/02@T90P061PH0100=3@d02@T900T92@0:2PX200<3
0`0400D51@0410@010@400H61P800`<300@02`/;00L71`071`L00P820P092@T0100820P01`L700L7
1`051@D200L71`0400D51@0820P020P800T92@8020P800@01`L700@4100410@020P80P092@T01005
1@D00`<300<30`0410@200d=3@0400@410061PH01PH600D51@8020P800@02`/;00H61P061PH00`<3
0P061PH010071`L01PH600H61P0;2`/201DE5@0403Hf=P0c<c<0<c<c034a<@80B4Q800@0ADE503/k
>`0k>c/0ADE50P0h>3P0100G5aL030`<00`<300?3`l201HF5P0401DE5@0O7al07alO038b<P80K6a/
00@0Q8B408R8R028R8P0TY:B0P29RHT0102DU9@0UiNG09NGU`1jNWX207alO004092@T02DU9@0U9BD
096AT@80XJ6Q00@0YJFU06a/K01/K6`0E5AD0P1UIFD0101RHV80Lg=c07=cL`1fMWH207=cL`0407]k
N`1cLg<0Lg=c059BDP808B4Q00@030`<01<C4`0C4a<07QhN0P0Q8B40100I6AT05aLG01LG5`0N7Qh2
02DU9@<0820P00@0:2PX03@d=00d=3@0;Rh^0P0I6AT00`0P82008b<S02<S8`0302@T9004030`<00]
;Bd0;Bd]01LG5`807AdM00@0=cLg02l_;`0_;bl06QXJ0P0H61P300/;2`0401TI6@0V9RH09RHV03lo
?`80=cLg00@0=SHf03Ti>@0i>CT0>CTi0P0n?Sh01016ATH0<C4a034a<@0U9BD20410@00403Lg=`1L
G5`0G5aL05YJFP80HV9R00@0E5AD03lo?`0o?cl0A4A40P0R8R801014A4@0@4100410@00a<C43028R
8P805QHF00@0:RXZ02l_;`0_;bl0?Shn0P0[:b/0100E5AD0:b/[02/[:`0_;bl201TI6@0400P8200H
61P061PH034a<@80:b/[00@07alO03@d=00d=3@0@D510P0I6AT0100?3`l0:BTY02TY:@0L71`2010@
400401lO7`0Z:RX0:RXZ030`<080>SXj0`0`<3001010@400C4a<04a<C018B4P202TY:@0402XZ:P0/
;2`0;2`/01/K6`80:b/[00@0>CTi04i>CP1>CTh0H61P0P0h>3P0100m?Cd0Bd];04];B`1FEUH205aL
G00403lo?`0l?3`0?3`l04];B`80>SXj00@06QXJ00P8200820P07AdM0P10@400101KFe/0GUiN05iN
GP1LG5`205=CD`040410@01ADE40DE5A05aLG080CDe=00@0EeMG04U9B@19BDT0@d=30P1?Cdl0100m
?Cd0IfMW06MWI`1TI6@204M7A`0404i>CP1:BTX0BTY:05aLG080BTY:00@0FEUI05EEE@1EEED0Bd];
0P18B4P0100m?Cd0>c/k03/k>`10@40204E5A@040492@P19BDT0BDU904a<C080BDU900@0?clo04A4
A014A4@0@D510P0n?Sh304a<C00404=3@`1:BTX0BTY:08^;R`80UIFE00@0^k^k09^KV`2KVi/0K6a/
0P0e=CD0100K6a/02PX:00X:2P0410@200820P0400P820051@D01@D500410@8010@40`071`L01006
1PH01`L700L71`061PH200L71`0400410@061PH01PH600d=3@801@D5000300820P0400P820030`<0
0`<300T92@8020P800@01PH600<30`030`<02PX:0`051@D200820P0400@410020P800P8200410@80
10@400@00@4100000000000000000P030`<010010@402@T900T92@010@420000000400<30`051@D0
1@D500D51@801`L700@02@T900L71`071`L010@40P051@D010020P801PH600H61P051@D200<30`04
000000071`L01`L700X:2P802`/;0`030`<010051@D01PH600H61P0;2`/200T92@04014A4@0/;2`0
;2`/0410@080<C4a00@0<30`03`l?00l?3`0>c/k0P11@D40101?Cdl0:BTY02TY:@0D51@201<C4`04
00l?3`0@4100410@01TI6@809bLW00@0ATI607QhN01hN7P0T92@0P2<S8`00`2DU9@0Rh^;08^;R`03
09BDU00407]kN`24Q8@0Q8B4096AT@80TY:B00@0UIFE0:VYZ@2YZJT0UIFE0P1KFe/0101IFET0Hf=S
06=SH`1XJ6P207YjNP0407EeM@1hN7P0N7Qh07YjNP80KFe]00@0A4A401@D500D51@020P80P0F5QH0
0`0R8R808b<S02<S8`0301dM7@04028R8P0F5QH05QHF00/;2`808R8R00@0;2`/01lO7`0O7al08B4Q
0P0J6QX0100@41004Q8B018B4P0N7Qh202@T900401lO7`0N7Qh07QhN024Q8@80=SHf00@092@T03lo
?`0o?cl0;bl_0P0>3Ph0100Q8B40<30`030`<00Y:BT201`L70<07AdM00@0;2`/05IFEP1FEUH0BDU9
0P0^;Rh01016ATH0Hf=S06=SH`16ATH203Ti>@040410@00P8200820P01hN7P80?Shn00@0AdM704=3
@`13@d<0<S8b0P0Q8B40100m?Cd0BTY:04Y:BP0h>3P204Q8B004061PH01?Cdl0Cdm?05IFEP8051@D
00@09BDU051@D01@D50092@T0P0C4a<0100F5QH06QXJ01XJ6P0>3Ph201HF5P0404M7A`19BDT0BDU9
024Q8@808R8R00@0@T9203@d=00d=3@03Ph>0P071`L00`0=3@d061PH01PH600302/[:`0403Lg=`1=
CDd0CDe=04Q8B080?Cdm00@0:2PX03<c<`0c<c<0>CTi0P0C4a<0100Y:BT0<c<c03<c<`0?3`l202l_
;`0404];B`10@400@410051@D080E5AD00@0DU9B04M7A`17AdL0A4A40P13@d<0100k>c/0?Shn03hn
?P0k>c/204=3@`04024Q8@071`L01`L701HF5P80>c/k00@0FEUI06ATI01TI6@0GUiN0P1FEUH01014
A4@0CDe=04e=C@1RHV8205aLG00405YJFP10@400@41003Ph>080ATI600@0@d=306m_K`1_Kfl0FUYJ
0P18B4P0101ADE40Cdm?04m?C`1IFET204I6AP0405iNGP1GEeL0EeMG03hn?P80?Cdm00@0@D510492
@P12@T80?Cdm0P0n?Sh0100k>c/0A4A404A4A017AdL20492@P<0@41000@0?Shn0410@010@400?Shn
0P1CDe<01011@D40GemO05mOG`2?Shl209NGU`040<G5a@2?Shl0Shn?05YJFP80;2`/00<04Q8B0082
0P020P800`010@4010061PH01@D500D51@0410@200D51@0400/;2`0:2PX02PX:00820P802@T900<0
3@d=00X:2P0:2PX00`092@T100D51@400`<30@030`<0000400820P010@400@4100@410800P8200@0
2PX:00410@010@401PH60`051@D200T92@0400D51@061PH01PH600L71`8010@400@01PH600L71`07
1`L00P820P071`L010030`<030`<00`<300;2`/200410@04000000030`<00`<300D51@802PX:00@0
2@T900/;2`0;2`/020P80P071`L010092@T01PH600H61P00000200<30`0400P820051@D01@D50082
0P800`<300@02`/;00@4100410@000000P071`L010051@D01PH600H61P0410@200410@0401@D500]
;Bd0;Bd]030`<0809RHV00@0@41003Xj>P0j>SX0<C4a0P10@400101=CDd092@T02@T900=3@d200T9
2@0401DE5@0D51@051@D01dM7@80<C4a00@0GEeM07moO`1oOgl0RHV90P2CTi<0102PX:00O7al07al
O01jNWX208F5Q@0407YjNP1oOgl0Ogmo08>3P`80RXZ:00@0Rh^;09jNWP2NWYh0P8200P1@D500101I
FET0Kfm_06m_K`1kNg/20820P00407moO`20P800P820075aL@80EeMG00@09bLW00L71`071`L03@d=
0P0H61P0100J6QX07QhN01hN7P0Y:BT202LW9`0402<S8`0R8R808R8R01XJ6P8092@T00@0<c<c01LG
5`0G5aL02@T90P0S8b<0100/;2`092@T02@T900P820202XZ:P0402`/;00U9BD09BDU02/[:`80:RXZ
00@0@D5104e=C@1=CDd0=cLg0P0f=SH0100l?3`0:RXZ02XZ:P0^;Rh202`/;00401XJ6P0X:2P0:2PX
04Y:BP80I6AT00@0D51@01XJ6P0J6QX09RHV0P15ADD0101IFET0EEEE05EEE@0k>c/201hN7P0401lO
7`0d=3@0=3@d051@D080AdM700@04A4A00@4100410@04Q8B0P0a<C40100_;bl0BTY:04Y:BP14A4@2
03hn?P04061PH00_;bl0;bl_010@4080@41000@0>SXj01dM7@0M7Ad0410@0P0];Bd01016ATH0?Shn
03hn?P0H61P2030`<00403De=@0O7al07alO03De=@8071`L00@00P8201@D500D51@030`<0P0820P0
100L71`0;Bd]02d];@0h>3P2034a<@<06a/K00@0820P02TY:@0Y:BT08B4Q0P051@D0100S8b<08B4Q
024Q8@020P82024Q8@0404A4A011@D40@D5105EEE@80HF5Q00@0CDe=0410@010@400Bd];0P18B4P0
1013@d<0>c/k03/k>`0h>3P20492@P0402PX:0020P800P8201<C4`80=3@d00@0DE5A06UYJ@1YJFT0
Hf=S0P1GEeL0101>CTh0EEEE05EEE@1DE5@204U9B@0404a<C011@D40@D510492@P80CTi>00@0DE5A
07QhN01hN7P0FEUI0P18B4P0101@D500CTi>04i>CP1=CDd203hn?P04065QH@1IFET0FEUI03`l?080
?Shn00@0A4A404M7A`17AdL0@4100P0o?cl0100k>c/0CDe=04e=C@17AdL20492@P0404=3@`17AdL0
AdM704M7A`80@d=300@0?clo055AD@1ADE40=CDe0P1cLg<0101lO7`0Ti>C09>CT`30`<02092@T004
05MGE`0U9BD09BDU00l?3`801`L700@01@D500X:2P0:2PX02PX:0P071`L0100820P01PH600H61P01
0@4200D51@0400820P051@D01@D500L71`80000000@02PX:00T92@092@T00`<30P051@D000040082
0P010@400@4100@410800P8200@02PX:00410@010@401PH60`051@D200T92@0400D51@061PH01PH6
00L71`8010@400@01PH600L71`071`L00P820P071`L010030`<030`<00`<300;2`/200410@040000
00030`<00`<300D51@802PX:00@02@T900/;2`0;2`/020P80P071`L010092@T01PH600H61P000002
00<30`0400P820051@D01@D500820P800`<300@02`/;00@4100410@000000P071`L010051@D01PH6
00H61P0410@200410@0401@D500];Bd0;Bd]030`<0809RHV00@0@41003Xj>P0j>SX0<C4a0P10@400
101=CDd092@T02@T900=3@d200T92@0401DE5@0D51@051@D01dM7@80<C4a00@0GEeM07moO`1oOgl0
RHV90P2CTi<0102PX:00O7al07alO01jNWX208F5Q@0407YjNP1oOgl0Ogmo08>3P`80RXZ:00@0Rh^;
09jNWP2NWYh0P8200P1@D500101IFET0Kfm_06m_K`1kNg/20820P00407moO`20P800P820075aL@80
EeMG00@09bLW00L71`071`L03@d=0P0H61P0100J6QX07QhN01hN7P0Y:BT202LW9`0402<S8`0R8R80
8R8R01XJ6P8092@T00@0<c<c01LG5`0G5aL02@T90P0S8b<0100/;2`092@T02@T900P820202XZ:P04
02`/;00U9BD09BDU02/[:`80:RXZ00@0@D5104e=C@1=CDd0=cLg0P0f=SH0100l?3`0:RXZ02XZ:P0^
;Rh202`/;00401XJ6P0X:2P0:2PX04Y:BP80I6AT00@0D51@01XJ6P0J6QX09RHV0P15ADD0101IFET0
EEEE05EEE@0k>c/201hN7P0401lO7`0d=3@0=3@d051@D080AdM700@04A4A00@4100410@04Q8B0P0a
<C40100_;bl0BTY:04Y:BP14A4@203hn?P04061PH00_;bl0;bl_010@4080@41000@0>SXj01dM7@0M
7Ad0410@0P0];Bd01016ATH0?Shn03hn?P0H61P2030`<00403De=@0O7al07alO03De=@8071`L00@0
0P8201@D500D51@030`<0P0820P0100L71`0;Bd]02d];@0h>3P2034a<@<06a/K00@0820P02TY:@0Y
:BT08B4Q0P051@D0100S8b<08B4Q024Q8@020P82024Q8@0404A4A011@D40@D5105EEE@80HF5Q00@0
CDe=0410@010@400Bd];0P18B4P01013@d<0>c/k03/k>`0h>3P20492@P0402PX:0020P800P8201<C
4`80=3@d00@0DE5A06UYJ@1YJFT0Hf=S0P1GEeL0101>CTh0EEEE05EEE@1DE5@204U9B@0404a<C011
@D40@D510492@P80CTi>00@0DE5A07QhN01hN7P0FEUI0P18B4P0101@D500CTi>04i>CP1=CDd203hn
?P04065QH@1IFET0FEUI03`l?080?Shn00@0A4A404M7A`17AdL0@4100P0o?cl0100k>c/0CDe=04e=
C@17AdL20492@P0404=3@`17AdL0AdM704M7A`80@d=300@0?clo055AD@1ADE40=CDe0P1cLg<0101l
O7`0Ti>C09>CT`30`<02092@T00405MGE`0U9BD09BDU00l?3`801`L700@01@D500X:2P0:2PX02PX:
0P071`L0100820P01PH600H61P010@4200D51@0400820P051@D01@D500L71`80000000@02PX:00T9
2@092@T00`<30P051@D000<010@400@02@T900P8200820P00`<30P071`L0100=3@d01`L700L71`06
1PH200<30`0400H61P0<30`030`<00L71`800`<300@010@400H61P061PH00P820P061PH0100410@0
2@T900T92@051@D200@4100400P820030`<00`<300820P80000000@01`L700X:2P0:2PX01@D50P03
0`<0100410@01@D500D51@010@4200820P0400@410051@D01@D500H61P802`/;00<02@T900P82008
20P00`0410@010010@401PH600H61P0=3@d2014A4@04024Q8@0_;bl0;bl_02/[:`80;Bd]00@0De=C
04I6AP16ATH0;bl_0P1;Bd/01014A4@03`l?00l?3`0@4102014A4@0401XJ6P0C4a<04a<C02XZ:P80
CDe=00@0M7Ad08F5Q@25QHD0QhN70P2TY:@0102VYZH0H61P061PH01JFUX207EeM@04075aL@1iNGT0
NGUi07emO@80MWIf00@0N7Qh08R8R028R8P0Kfm_0P1FEUH00`1PH600L71`071`L00307IfMP040820
P01nOWh0OWin06IVIP80BTY:00<06QXJ00X:2P0:2PX00`0L71`0100J6QX06a/K01/K6`0R8R8202LW
9`0401lO7`0H61P061PH01LG5`806QXJ00@08R8R02XZ:P0Z:RX07alO0P0N7Qh0100b<S808b<S02<S
8`0J6QX203Hf=P0404A4A00T92@092@T01`L7080;Rh^00@0@41003Ph>00h>3P071`L0P0A4A40100O
7al0:2PX02PX:00X:2P2065QH@0404E5A@0b<S80<S8b04Q8B080?clo00@0<C4a024Q8@0Q8B40<S8b
0P1<C4`0101BDU80;2`/02`/;00j>SX205=CD`0402h^;P0n?Sh0?Shn04U9B@80Lg=c00@0CTi>04Q8
B018B4P0;bl_0P17AdL01018B4P0:2PX02PX:00c<c<202d];@0403Xj>P0U9BD09BDU00L71`80>CTi
00@0:2PX02<S8`0S8b<0<c<c0P0`<300100[:b/0?3`l03`l?00L71`2028R8P0402l_;`0Y:BT0:BTY
03dm?@80=3@d00@07alO01LG5`0G5aL05QHF0P0U9BD0100^;Rh0<C4a034a<@0m?Cd2034a<@0402TY
:@0n?Sh0?Shn04M7A`80=3@d00@08R8R03<c<`0c<c<0@D510P0j>SX0100U9BD0:BTY02TY:@0`<302
04A4A00404e=C@16ATH0ATI60451@@80@T9200@0Fe]K05=CD`1CDe<0?3`l0P0a<C40100j>SX0;Rh^
02h^;P0K6a/200X:2P0400D51@0];Bd0;Bd]051@D080HV9R00@0I6AT05EEE@1EEED0DU9B0P1JFUX0
101=CDd0B4Q804Q8B016ATH20492@P0404Q8B016ATH0ATI604A4A080JVYZ00@0E5AD04U9B@19BDT0
BTY:0P18B4P0101=CDd0A4A404A4A01QHF4205EEE@<0AdM700@0@d=304A4A014A4@0@d=30P11@D40
1010@400Bd];04];B`10@40204];B`@0A4A40P0h>3P0101:BTX0Cdm?04m?C`0h>3P208>3P`04079b
LP2XZ:P0Z:RX0;^k^`80U9BD00@0Fe]K02TY:@0Y:BT04Q8B0P030`<010010@4020P800P8200<30`2
00d=3@0400410@051@D01@D500H61P801`L700@02PX:00<30`030`<00`<30`051@D200<30`402@T9
0@0410@100@4100000<01`L700820P020P80100;2`/200h>3P0400L71`010@400@4100L71`800`<3
00@02`/;00l?3`0?3`l020P80P010@40100000001@D500D51@092@T200P8200400/;2`0820P020P8
00P820801`L700<010@400H61P061PH00`051@D0100@41001PH600H61P051@D200820P0400T92@03
0`<00`<300D51@802@T900@00`<300L71`071`L010@40P0<30`00`0820P010@400@4100300D51@04
00410@030`<00`<300@410808R8R00@0<c<c02l_;`0_;bl0<30`0P0k>c/01019BDT0?clo03lo?`0a
<C4205ADE00403Ph>00?3`l03`l?00P820806ATI00@07AdM01`L700L71`0=cLg0P1JFUX0101fMWH0
NWYj07YjNP1lO7`209VIV@0409bLW01KFe/0Fe]K05ADE080MWIf00@0Lg=c06UYJ@1YJFT0I6AT0P1G
EeL0101TI6@0Lg=c07=cL`1NGUh205QHF00405mOG`1ZJVX0JVYZ07IfMP80NGUi00@0Ph>307emO@1m
OGd0EeMG0P0c<c<0100=3@d051@D01@D500S8b<2020P80<07alO00@05aLG01lO7`0O7al0?3`l0P0/
;2`0100H61P071`L01`L700?3`l201PH600402d];@0/;2`0;2`/02h^;P8071`L00@092@T03hn?P0n
?Sh0;2`/0P0G5aL0100R8R8061PH01PH600N7Qh20410@00403@d=00Z:RX0:RXZ03@d=080<30`00@0
;Rh^03lo?`0o?cl09BDU0P0A4A40100W9bL0:BTY02TY:@19BDT204I6AP0403`l?01ADE40DE5A075a
L@80DU9B00@0@410055AD@1ADE40ATI60P1NGUh0101<C4`0IfMW06MWI`14A4@204U9B@040492@P0n
?Sh0?Shn04m?C`80@d=300@0ATI603Xj>P0j>SX0:RXZ0P0U9BD0100g=cL0<C4a034a<@0_;bl202LW
9`04028R8P0J6QX06QXJ010@40808R8R00@0:2PX01dM7@0M7Ad06a/K0P0Z:RX0100j>SX07AdM01dM
7@0D51@202DU9@0401dM7@0^;Rh0;Rh^04I6AP80;Rh^00@0;Bd]03Ti>@0i>CT0@T920P1YJFT0101C
De<061PH01PH600V9RH204Q8B00403dm?@0j>SX0>SXj03@d=08092@T00@09BDU04Y:BP1:BTX0@d=3
0P0l?3`0101EEED0@4100410@019BDT205EEE@0404i>CP1?Cdl0Cdm?0410@08061PH00@07QhN01dM
7@0M7Ad07alO0P0Z:RX01015ADD0F5QH05QHF01OGel205EEE@0405MGE`1HF5P0F5QH04A4A080BDU9
00@0@d=304E5A@15ADD0BTY:0P18B4P0101<C4`0IVIV06IVIP1=CDd204m?C`<0C4a<00@0F5QH04a<
C01<C4`0GEeM0P1<C4`01018B4P0?clo03lo?`10@40204E5A@0404I6AP0l?3`0?3`l04E5A@80AdM7
00@0>3Ph04A4A014A4@0@d=30P15ADD01010@400=CDe03De=@1@D5020410@00404i>CP2DU9@0U9BD
07moO`80ZZZZ00@0W9bL09JFUP2FUYH0I6AT0P0X:2P0100:2PX010@400@410092@T200H61P03010@
400<30`030`<00<00P8200@02PX:00/;2`0;2`/030`<0P030`<00`061PH02@T900T92@0300@41040
1PH60@0<30`100`<300000<01`L700820P020P80100;2`/200h>3P0400L71`010@400@4100L71`80
0`<300@02`/;00l?3`0?3`l020P80P010@40100000001@D500D51@092@T200P8200400/;2`0820P0
20P800P820801`L700<010@400H61P061PH00`051@D0100@41001PH600H61P051@D200820P0400T9
2@030`<00`<300D51@802@T900@00`<300L71`071`L010@40P0<30`00`0820P010@400@4100300D5
1@0400410@030`<00`<300@410808R8R00@0<c<c02l_;`0_;bl0<30`0P0k>c/01019BDT0?clo03lo
?`0a<C4205ADE00403Ph>00?3`l03`l?00P820806ATI00@07AdM01`L700L71`0=cLg0P1JFUX0101f
MWH0NWYj07YjNP1lO7`209VIV@0409bLW01KFe/0Fe]K05ADE080MWIf00@0Lg=c06UYJ@1YJFT0I6AT
0P1GEeL0101TI6@0Lg=c07=cL`1NGUh205QHF00405mOG`1ZJVX0JVYZ07IfMP80NGUi00@0Ph>307em
O@1mOGd0EeMG0P0c<c<0100=3@d051@D01@D500S8b<2020P80<07alO00@05aLG01lO7`0O7al0?3`l
0P0/;2`0100H61P071`L01`L700?3`l201PH600402d];@0/;2`0;2`/02h^;P8071`L00@092@T03hn
?P0n?Sh0;2`/0P0G5aL0100R8R8061PH01PH600N7Qh20410@00403@d=00Z:RX0:RXZ03@d=080<30`
00@0;Rh^03lo?`0o?cl09BDU0P0A4A40100W9bL0:BTY02TY:@19BDT204I6AP0403`l?01ADE40DE5A
075aL@80DU9B00@0@410055AD@1ADE40ATI60P1NGUh0101<C4`0IfMW06MWI`14A4@204U9B@040492
@P0n?Sh0?Shn04m?C`80@d=300@0ATI603Xj>P0j>SX0:RXZ0P0U9BD0100g=cL0<C4a034a<@0_;bl2
02LW9`04028R8P0J6QX06QXJ010@40808R8R00@0:2PX01dM7@0M7Ad06a/K0P0Z:RX0100j>SX07AdM
01dM7@0D51@202DU9@0401dM7@0^;Rh0;Rh^04I6AP80;Rh^00@0;Bd]03Ti>@0i>CT0@T920P1YJFT0
101CDe<061PH01PH600V9RH204Q8B00403dm?@0j>SX0>SXj03@d=08092@T00@09BDU04Y:BP1:BTX0
@d=30P0l?3`0101EEED0@4100410@019BDT205EEE@0404i>CP1?Cdl0Cdm?0410@08061PH00@07QhN
01dM7@0M7Ad07alO0P0Z:RX01015ADD0F5QH05QHF01OGel205EEE@0405MGE`1HF5P0F5QH04A4A080
BDU900@0@d=304E5A@15ADD0BTY:0P18B4P0101<C4`0IVIV06IVIP1=CDd204m?C`<0C4a<00@0F5QH
04a<C01<C4`0GEeM0P1<C4`01018B4P0?clo03lo?`10@40204E5A@0404I6AP0l?3`0?3`l04E5A@80
AdM700@0>3Ph04A4A014A4@0@d=30P15ADD01010@400=CDe03De=@1@D5020410@00404i>CP2DU9@0
U9BD07moO`80ZZZZ00@0W9bL09JFUP2FUYH0I6AT0P0X:2P0100:2PX010@400@410092@T200H61P03
010@400<30`030`<00<00P8200@02PX:00/;2`0;2`/030`<0P030`<00`061PH02@T900T92@0300@4
10401PH60@0<30`100`<300010061PH200P8200400X:2P071`L01`L700L71`8010@400@01PH600<3
0`030`<01PH60P0000000`092@T01`L700L71`0300<30`0400`<300>3Ph03Ph>00410@801@D500@0
1PH600D51@051@D020P80P030`<010010@4010@400@4100:2PX200L71`0400P820020P800P8200X:
2P803@d=00@01`L700P8200820P010@40P020P80100410@00`<300<30`0820P200H61P0400820P04
10@010@400@4108020P800@03`l?02d];@0];Bd0;2`/0P0S8b<0100Z:RX0@d=304=3@`17AdL203@d
=00403`l?01>CTh0CTi>02TY:@802@T900@030`<01/K6`0K6a/071`L0P0[:b/01011@D40IfMW06MW
I`1kNg/20861P@0408F5Q@22PX80PX:207MgM`<0>CTi0P1PH600101VIVH0Fe]K05]KF`1IFET204a<
C00405eMG@1bLW80LW9b05aLG080HF5Q00@0L71`07QhN01hN7P0OWin0P1oOgl01021PH40MWIf07If
MP1>CTh201hN7P0400D51@0I6AT06ATI02HV9P807AdM00@07alO02`/;00/;2`08B4Q0P0H61P0100d
=3@0;Rh^02h^;P0@410202<S8`0402d];@0B4Q804Q8B01LG5`80;bl_00@0>CTi030`<00`<300;Bd]
0P0Q8B40100U9BD08b<S02<S8`071`L201PH600404I6AP1_Kfl0Kfm_04I6AP80?3`l00@0F5QH03Ph
>00h>3P0AdM70P1HF5P0100S8b<02`/;00/;2`0Y:BT202l_;`0404i>CP1ADE40DE5A02d];@80>3Ph
00@0Bd];04M7A`17AdL0F5QH0P20P800100n?Sh0ADE504E5A@17AdL206ATI004038b<P0/;2`0;2`/
00`<30803@d=00@0>SXj02l_;`0_;bl0<C4a0P0j>SX0100[:b/0410@010@400I6AT201LG5`040410
@00i>CT0>CTi00/;2`80?Shn00@0<c<c00l?3`0?3`l071`L0P0X:2P0100_;bl0<30`030`<00/;2`2
010@400401`L700c<c<0<c<c01/K6`80:BTY00@0@d=301lO7`0O7al09BDU0P19BDT0100f=SH0>CTi
03Ti>@17AdL203Lg=`040410@01JFUX0FUYJ05IFEP80@T9200@0=cLg03Hf=P0f=SH0;Bd]0P0n?Sh0
1010@400C4a<04a<C01TI6@204Y:BP0404m?C`1FEUH0EUIF05aLG080IVIV00@0C4a<038b<P0b<S80
:b/[0P0D51@0100Q8B40:BTY02TY:@0g=cL205IFEP0305MGE`1BDU80DU9B00<0E5AD00<0?clo04A4
A014A4@00`1<C4`0101;Bd/0CTi>04i>CP1DE5@206=SH`0404i>CP1=CDd0CDe=04U9B@80CTi>0`1;
Bd/0101[Jf/0ADE504E5A@0n?Sh20451@@0404];B`1>CTh0CTi>04E5A@80?Cdm00@0EEEE04];B`1;
Bd/0@4100`13@d<20492@P0403/k>`12@T80@T9205EEE@80;2`/00@0KVi^096AT@2ATI40SXj>0P2R
XZ80102EUID0UYJF09JFUP1HF5P202XZ:P0400L71`000000000000L71`801@D500@01PH600D51@05
1@D01PH60P051@D010071`L02@T900T92@0:2PX200D51@<00@4100<010@400410@010@400`051@D0
000400D51@0820P020P800H61P8020P80`020P80100000003@d=00d=3@0<30`200H61P<00P8200@0
20P800<30`030`<010@40P092@T0100410@00@4100410@071`L300820P800`<30`051@D0100410@0
1@D500D51@00000200L71`<00`<300@00P8200H61P061PH010@40P0820P00`0?3`l01`L700L71`03
0000000400D51@010@400@4100/;2`800P8200@01@D500l?3`0?3`l07alO0`0a<C4202/[:`04034a
<@1>CTh0CTi>04i>CP80<30`0`10@400100J6QX01PH600H61P0G5aL2028R8P0401`L700e=CD0=CDe
04E5A@80KVi^00@0Ng]k07YjNP1jNWX0MWIf0P1mOGd0101_Kfl0FEUI05UIF@1^KVh207IfMP0305iN
GP1@D500D51@00<0FEUI00@0EeMG06][J`1[Jf/0HF5Q0P1XJ6P0101hN7P0NGUi07UiN@1kNg/207in
OP0407YjNP1QHF40HF5Q03`l?0804a<C00@01PH601XJ6P0J6QX08B4Q0P0L71`0100M7Ad09RHV02HV
9P0c<c<2030`<00402/[:`0T92@092@T018B4P808R8R00@09RHV00/;2`0;2`/09RHV0P10@400100i
>CT0<S8b038b<P10@40203De=@04034a<@0V9RH09RHV01@D5080>SXj00@0?Cdm03<c<`0c<c<0<S8b
0P0e=CD0101DE5@09bLW02LW9`0_;bl206e]K@0305=CD`16ATH0ATI600<0?3`l00@0;Rh^02PX:00X
:2P0<30`0P17AdL0101^KVh0Jf][06][J`10@402059BDP0401PH600Z:RX0:RXZ03lo?`80Cdm?00@0
;2`/061PH01PH600De=C0P0j>SX0101ZJVX0I6AT06ATI00h>3P202@T9004018B4P0R8R808R8R05IF
EP<0?Shn0P0a<C40100G5aL0?clo03lo?`0o?cl201dM7@0400T92@0N7Qh07QhN02XZ:P804Q8B0`0>
3Ph0100820P03Ph>00h>3P0c<c<203lo?`0402h^;P0/;2`0;2`/04Q8B080H61P00@0:RXZ01LG5`0G
5aL0ADE50P18B4P0100i>CT0:BTY02TY:@0X:2P202l_;`0403Xj>P0_;bl0;bl_00<30`80:b/[00@0
FUYJ05IFEP1FEUH0@T920P0^;Rh0100b<S80Bd];04];B`1:BTX203Hf=P0402/[:`0^;Rh0;Rh^020P
80803`l?00@06QXJ02l_;`0_;bl0@d=30P1QHF40101PH600IFEU06EUI@1EEED205YJFP0404U9B@11
@D40@D5104e=C@<0ATI60P1>CTh0101;Bd/0EUIF05IFEP1@D50205EEE@0404e=C@1@D500D51@0492
@P80CTi>00@0Lg=c04=3@`13@d<0AdM70P18B4P01016ATH0CDe=04e=C@0h>3P20492@P0405EEE@15
ADD0ADE504Q8B080Bd];00@0A4A404=3@`13@d<0>SXj0P1:BTX01014A4@092@T02@T902?Shl20820
P00408n?S`2/[:`0[:b/0:j^[P80S8b<00@0@D5102LW9`0W9bL04Q8B0P061PH0100820P00`<300<3
0`020P8200X:2P0400L71`061PH01PH600X:2P8030`<00@02@T900@4100410@01@D50`020P8200H6
1P4020P80@0410@100@4100000@01@D500P8200820P01PH60P0820P300820P040000000=3@d03@d=
00`<30801PH60`020P80100820P00`<300<30`0410@200T92@0400@410010@400@4100L71`<00P82
0P030`<300D51@0400@410051@D01@D5000000801`L70`030`<010020P801PH600H61P0410@200P8
200300l?3`071`L01`L700<0000000@01@D500410@010@402`/;0P020P8010051@D03`l?00l?3`0O
7al3034a<@80:b/[00@0<C4a04i>CP1>CTh0CTi>0P0`<3030410@00401XJ6P061PH01PH601LG5`80
8R8R00@071`L03De=@0e=CD0ADE50P1^KVh0101kNg/0NWYj07YjNP1fMWH207emO@0406m_K`1IFET0
FEUI06i^KP80MWIf00<0GUiN051@D01@D5000`1IFET0101GEeL0Jf][06][J`1QHF4206QXJ00407Qh
N01iNGT0NGUi07]kN`80OWin00@0NWYj065QH@1QHF40?3`l0P0C4a<010061PH06QXJ01XJ6P0Q8B42
01`L700401dM7@0V9RH09RHV03<c<`80<30`00@0:b/[02@T900T92@04Q8B0P0R8R80100V9RH02`/;
00/;2`0V9RH20410@00403Ti>@0b<S80<S8b0410@080=CDe00@0<C4a02HV9P0V9RH051@D0P0j>SX0
100m?Cd0<c<c03<c<`0b<S8203De=@0405ADE00W9bL09bLW02l_;`80KFe]00<0De=C04I6AP16ATH0
0`0l?3`0100^;Rh0:2PX02PX:00`<30204M7A`0406i^KP1[Jf/0Jf][0410@080DU9B00@061PH02XZ
:P0Z:RX0?clo0P1?Cdl0100/;2`0H61P061PH01CDe<203Xj>P0406YZJP1TI6@0I6AT03Ph>08092@T
00@04Q8B028R8P0R8R80EUIF0`0n?Sh2034a<@0401LG5`0o?cl0?clo03lo?`807AdM00@02@T901hN
7P0N7Qh0:RXZ0P0B4Q8300h>3P0400P8200>3Ph03Ph>03<c<`80?clo00@0;Rh^02`/;00/;2`0B4Q8
0P1PH600100Z:RX05aLG01LG5`15ADD204Q8B00403Ti>@0Y:BT0:BTY02PX:080;bl_00@0>SXj02l_
;`0_;bl00`<30P0[:b/0101JFUX0EUIF05IFEP12@T8202h^;P04038b<P1;Bd/0Bd];04Y:BP80=SHf
00@0:b/[02h^;P0^;Rh0820P0P0?3`l0100J6QX0;bl_02l_;`13@d<2065QH@04061PH01UIFD0IFEU
05EEE@80FUYJ00@0BDU90451@@11@D40CDe=0`16ATH204i>CP0404];B`1FEUH0EUIF051@D080EEEE
00@0CDe=051@D01@D500@T920P1>CTh0101cLg<0@d=304=3@`17AdL204Q8B00404I6AP1=CDd0CDe=
03Ph>080@T9200@0EEEE04E5A@15ADD0B4Q80P1;Bd/01014A4@0@d=304=3@`0j>SX204Y:BP0404A4
A00T92@092@T08n?S`80P82000@0Shn?0:b/[02/[:`0[Zj^0P2<S8`01011@D409bLW02LW9`0B4Q82
00H61P0400P820030`<00`<300820P802PX:00@01`L700H61P061PH02PX:0P0<30`010092@T010@4
00@410051@D300820P801PH60@0820P100@4104010@4000010010@400`<300<30`0=3@d200P82004
00<30`061PH01PH600H61P803Ph>00@00`<300820P020P8020P80P0410@010071`L010@400@41007
1`L2000000<02PX:00@020P80000000000002PX:0P051@D0100=3@d03Ph>00h>3P0820P200L71`03
00410@051@D01@D500<00`<300@01PH600`<300<30`00`<30P061PH0100>3Ph02@T900T92@0;2`/2
00T92@0400@4100=3@d03@d=00/;2`800P8200@02`/;010@400@41005QHF0P0W9bL0100c<c<0;bl_
02l_;`0h>3P204Q8B0040410@00_;bl0;bl_04E5A@80=cLg00@04A4A00X:2P0:2PX07AdM0P0L71`0
100W9bL0Bd];04];B`1HF5P207MgM`0408N7Q`1mOGd0OGem06YZJP80MgMg00@0MGEe065QH@1QHF40
IFEU0P1eMGD0101MGEd0ADE504E5A@1IFET207MgM`0407IfMP1^KVh0KVi^05mOG`80IfMW0`1[Jf/0
101iNGT0O7al07alO01cLg<205EEE@0402/[:`0?3`l03`l?00H61P803Ph>00@04A4A01TI6@0I6AT0
8B4Q0P0C4a<0100M7Ad0?3`l03`l?00d=3@202<S8`04020P800M7Ad07AdM00l?3`80410@00@0=3@d
0492@P12@T80=CDe0P0S8b<0100/;2`0@D510451@@0c<c<2028R8P04024Q8@0`<300<30`03@d=080
:BTY00@0=CDe03/k>`0k>c/0<c<c0P10@400101BDU80H61P061PH01HF5P204i>CP0403Ph>00`<300
<30`034a<@80C4a<00@0HF5Q04I6AP16ATH07alO0P1:BTX0100n?Sh09RHV02HV9P0N7Qh30410@080
HV9R00@0L71`06MWI`1WIfL0:b/[0P0^;Rh0101YJFT0A4A404A4A00T92@202PX:00400@4100U9BD0
9BDU05UIF@80ATI600@0;2`/01TI6@0I6AT0>3Ph0P0N7Qh0100@410061PH01PH600K6a/204Y:BP04
0451@@0L71`071`L024Q8@80820P00@05ADE01hN7P0N7Qh0>3Ph0P0^;Rh0100G5aL0;Rh^02h^;P1F
EUH206a/K00404a<C00^;Rh0;Rh^0492@P80A4A400@0;Rh^030`<00`<300:BTY0P0V9RH01010@400
>CTi03Ti>@0N7Qh303Lg=`80;Rh^00@0=CDe03<c<`0c<c<0<S8b0`17AdL2038b<P0402HV9P0`<300
<30`01hN7P803Ph>00@06a/K030`<00`<300ATI60`1/K6`206IVIP0405EEE@1QHF40HF5Q04i>CP80
>3Ph00@0CTi>04=3@`13@d<0?clo0P1EEED0101GEeL0E5AD05ADE01;Bd/204e=C@0404M7A`1@D500
D51@0451@@80EeMG00@0MgMg04A4A014A4@0DE5A0P1>CTh0101:BTX0A4A404A4A00/;2`205MGE`04
04i>CP17AdL0AdM704U9B@80ATI600@0@T9204A4A014A4@0BDU90P1DE5@0100Q8B40CTi>04i>CP2S
Xj<206e]K@0408N7Q`2PX:00X:2P0:BTY080Q8B400@0@D5101<C4`0C4a<01PH60P071`L300@41004
00820P0;2`/02`/;00@410803@d=00<02@T900X:2P0:2PX00`071`L0100410@01PH600H61P030`<2
00P820401`L70@051@D100D51@0000@020P800<30`030`<010@40P020P80100410@01@D500D51@0:
2PX200`<300400820P030`<00`<30000008010@400@02@T900L71`071`L00`<30P020P80100410@0
0P8200820P020P8200@4100300`<30051@D01@D500<02PX:00@010@400D51@051@D01PH60P0820P0
10030`<01`L700L71`030`<200L71`0400820P0820P020P800T92@800@4100@030`<00@4100410@0
1PH60P0;2`/010030`<00@4100410@061PH200`<300402<S8`0T92@092@T02/[:`80:RXZ00@0>SXj
04e=C@1=CDd0@D510P0i>CT00`17AdL0:b/[02/[:`0300`<300401lO7`0K6a/06a/K01lO7`80DE5A
00@0OGem08n?S`2?Shl0TY:B0P21PH40101oOgl0NWYj07YjNP1]KFd206UYJ@0404];B`1EEED0EEEE
05QHF080EUIF00@0H61P06a/K01/K6`0NGUi0P1^KVh0101TI6@0K6a/06a/K01TI6@206a/K00407al
O01iNGT0NGUi06i^KP80E5AD00@0;2`/00D51@051@D0410@0P0U9BD3024Q8@04038b<P0d=3@0=3@d
030`<080?3`l00@0:b/[01dM7@0M7Ad07alO0P0C4a<0100F5QH07alO01lO7`0d=3@2038b<P0401DE
5@0R8R808R8R02PX:080@41000@0D51@055AD@1ADE40<c<c0P0R8R80100e=CD0<30`030`<010@402
055AD@0404m?C`10@400@41003dm?@80@41000@0?3`l04=3@`13@d<0@D510P1;Bd/0101EEED0LW9b
079bLP2;Rh/208V9R@0403hn?P1?Cdl0Cdm?069RHP80Fe]K00@0@D510410@010@4009bLW0P0e=CD0
101JFUX0EEEE05EEE@0N7Qh201TI6@0405EEE@0o?cl0?clo01lO7`80=CDe00@0Bd];038b<P0b<S80
6ATI0P0Q8B40100^;Rh0:2PX02PX:00l?3`201hN7P04014A4@0C4a<04a<C00000080820P00@0AdM7
03`l?00l?3`092@T0P0Y:BT0100S8b<07AdM01dM7@0M7Ad2038b<P04034a<@0R8R808R8R03Xj>P80
@T9200<0<c<c030`<00`<3000`14A4@0100e=CD0AdM704M7A`1@D50204U9B@0405eMG@1?Cdl0Cdm?
03Lg=`80<30`00@08R8R02l_;`0_;bl0?Shn0P10@400100[:b/0=SHf03Hf=P1:BTX204U9B@04034a
<@0W9bL09bLW01/K6`800P8200@07alO03Ti>@0i>CT0CTi>0P1]KFd0101TI6@0FUYJ05YJFP1GEeL2
05YJFP0405UIF@0l?3`0?3`l0492@P<0ADE50P1DE5@0101CDe<0D51@051@D01=CDd2055AD@04059B
DP1DE5@0E5AD03dm?@80F5QH00@0KVi^03hn?P0n?Sh0@T920P17AdL0101FEUH0>CTi03Ti>@0o?cl2
06YZJP040410@014A4@0A4A404U9B@80@d=300@0A4A40451@@11@D40ADE50P0o?cl0100S8b<0T92@
092@T02ZZZX208J6QP040:VYZ@2i^KT0^KVi0;2`/080SXj>00@0DE5A01@D500D51@000000P051@D0
10061PH00`<300<30`0410@2014A4@0400`<300?3`l03`l?00l?3`<01@D50`0410@200P8200400<3
0`092@T02@T900L71`800`<30000100820P00`<300<30`0410@200820P0400@410051@D01@D500X:
2P8030`<00@00P8200<30`030`<000000P0410@010092@T01`L700L71`030`<200820P0400@41002
0P800P8200820P8010@400<030`<00D51@051@D00`0:2PX0100410@01@D500D51@061PH200P82004
00<30`071`L01`L700<30`801`L700@00P8200P8200820P02@T90P010@40100<30`010@400@41006
1PH200/;2`0400<30`010@400@4100H61P8030`<00@08b<S02@T900T92@0:b/[0P0Z:RX0100j>SX0
CDe=04e=C@11@D4203Ti>@0304M7A`0[:b/0:b/[00<030`<00@07alO01/K6`0K6a/07alO0P1ADE40
101mOGd0Shn?08n?S`2BTY820861P@0407moO`1jNWX0NWYj06e]K@80JFUY00@0Bd];05EEE@1EEED0
F5QH0P1FEUH0101PH600K6a/06a/K01iNGT206i^KP0406ATI01/K6`0K6a/06ATI080K6a/00@0O7al
07UiN@1iNGT0KVi^0P1DE5@0100/;2`01@D500D51@0@410202DU9@<08B4Q00@0<S8b03@d=00d=3@0
<30`0P0l?3`0100[:b/07AdM01dM7@0O7al201<C4`0401HF5P0O7al07alO03@d=080<S8b00@05ADE
028R8P0R8R80:2PX0P10@400101@D500DE5A055AD@0c<c<2028R8P0403De=@0`<300<30`0410@080
DE5A00@0Cdm?0410@010@400?Cdm0P10@400100l?3`0@d=304=3@`11@D4204];B`0405EEE@1bLW80
LW9b08^;R`80RHV900@0?Shn04m?C`1?Cdl0HV9R0P1KFe/01011@D40@4100410@00W9bL203De=@04
05YJFP1EEED0EEEE01hN7P806ATI00@0EEEE03lo?`0o?cl07alO0P0e=CD0101;Bd/0<S8b038b<P0I
6AT2024Q8@0402h^;P0X:2P0:2PX03`l?0807QhN00@04A4A01<C4`0C4a<000000P0P82001017AdL0
?3`l03`l?00T92@202TY:@0402<S8`0M7Ad07AdM01dM7@80<S8b00@0<C4a028R8P0R8R80>SXj0P12
@T800`0c<c<0<30`030`<00304A4A00403De=@17AdL0AdM7051@D080BDU900@0GEeM04m?C`1?Cdl0
=cLg0P0`<300100R8R80;bl_02l_;`0n?Sh20410@00402/[:`0f=SH0=SHf04Y:BP80BDU900@0<C4a
02LW9`0W9bL06a/K0P020P80100O7al0>CTi03Ti>@1>CTh206e]K@0406ATI01JFUX0FUYJ05MGE`80
FUYJ00@0FEUI03`l?00l?3`0@T920`15ADD205ADE00405=CD`1@D500D51@04e=C@80DE5A00@0DU9B
05ADE01DE5@0?Cdm0P1HF5P0101^KVh0?Shn03hn?P12@T8204M7A`0405IFEP0i>CT0>CTi03lo?`80
JVYZ00@0@41004A4A014A4@0BDU90P13@d<01014A4@0@D510451@@15ADD203lo?`0402<S8`2@T900
T92@0:ZZZP80QXJ600@0ZJVY0;Vi^@2i^KT0/;2`0P2>SXh0101ADE4051@D01@D5000000200D51@04
00H61P030`<00`<300@410804A4A00@030`<00l?3`0?3`l03`l?0`051@D300@4108020P800@00`<3
00T92@092@T01`L70P030`<0000400h>3P0;2`/02`/;00820P801`L700@01PH600<30`030`<00P82
0P051@D010010@401`L700L71`0:2PX200P8200400L71`092@T02@T900d=3@800P8200@00`<300H6
1P061PH010@40P071`L010030`<01PH600H61P010@4200@4100400H61P030`<00`<300H61P800000
00@01`L700820P020P8010@40P00000010010@400`<300<30`0:2PX200@4100300820P061PH01PH6
00<00P8200@02@T900/;2`0;2`/01@D50P0G5aL0100a<C40:2PX02PX:00];Bd203Ti>@0404E5A@1K
Fe/0Fe]K03Xj>P80<C4a00@0<c<c01DE5@0E5AD03@d=0P0G5aL0100V9RH05QHF01HF5P0Q8B4205QH
F0040820P023Ph<0Ph>30861P@80OGem00@0S8b<08:2PP22PX80Ogmo0P1fMWH0100l?3`0BTY:04Y:
BP1XJ6P206e]K@04069RHP1QHF40HF5Q0861P@80PX:200@0LG5a06QXJ01XJ6P0GEeM0P1]KFd0101g
MgL0N7Qh07QhN01ZJVX20451@@0401/K6`051@D01@D500l?3`<09BDU0P0K6a/0100Q8B40<S8b038b
<P0i>CT203<c<`0402d];@0f=SH0=SHf03Xj>P80;bl_00@0=CDe034a<@0a<C40=SHf0P15ADD0100Z
:RX08b<S02<S8`0Z:RX201hN7P0401lO7`0R8R808R8R01<C4`80:2PX00@0<30`01dM7@0M7Ad0>SXj
0P19BDT01010@400;Rh^02h^;P14A4@204M7A`040451@@18B4P0B4Q8055AD@80E5AD00@0?Cdm0410
@010@400D51@0P1]KFd0101dM7@0GEeM05eMG@10@40204m?C`0405MGE`0b<S80<S8b01hN7P80@410
00@0EeMG02d];@0];Bd0:2PX0P0d=3@0100@410061PH01PH600<30`202`/;003038b<P0@4100410@
00<03@d=00@051@D01/K6`0K6a/02PX:0P092@T303<c<`03018B4P0b<S80<S8b00<0ATI600@0:RXZ
01@D500D51@04A4A0P0I6AT0100V9RH0=CDe03De=@0/;2`201dM7@0404U9B@1GEeL0EeMG03Ti>@80
?Cdm00@0B4Q804];B`1;Bd/0BDU90P17AdL0100j>SX0?3`l03`l?01=CDd2038b<P0402DU9@0Y:BT0
:BTY03Ph>080;Bd]00@0;2`/03dm?@0m?Cd0BTY:0P1<C4`0100o?cl0=cLg03Lg=`0i>CT202<S8`04
01TI6@0@4100410@01dM7@80=3@d00@0CDe=06UYJ@1YJFT0JFUY0P1EEED0101FEUH0G5aL05aLG01i
NGT204m?C`0403Ph>01=CDd0CDe=04a<C080CDe=00@0Cdm?059BDP1BDU80CTi>0`1CDe<2059BDP04
03lo?`1KFe/0Fe]K06YZJP<0ADE50P12@T800`19BDT092@T02@T900306=SH`0403`l?01:BTX0BTY:
04m?C`80@d=300@0@T9204=3@`13@d<0?Shn0P0K6a/0101RHV80]KFe0;Fe]@2WYjL20:>SX`040;Rh
^02i^KT0^KVi0:b/[080RXZ:00@0G5aL024Q8@0Q8B400@410P051@D010020P801`L700L71`0>3Ph2
014A4@<02`/;00@05QHF00T92@092@T00`<30P092@T010020P8020P800P820061PH200<30`4020P8
0@0000010000000000@00P8200h>3P0>3Ph010@40P030`<010051@D02@T900T92@071`L200P82003
00L71`051@D01@D500<01@D500@02PX:00H61P061PH01@D50P010@40100:2PX01@D500D51@0:2PX2
00H61P0400410@0:2PX02PX:00H61P801`L700@01PH600820P020P8020P80P020P8010061PH00`<3
00<30`0410@200D51@0300H61P051@D01@D500<01`L700@01PH600D51@051@D03@d=0P0410@01005
1@D010@400@410061PH201LG5`04030`<00c<c<0<c<c03Ti>@80=cLg00@0A4A405YJFP1JFUX0<c<c
0P0h>3P0100c<c<04Q8B018B4P0;2`/202<S8`0402XZ:P0J6QX06QXJ03Xj>P80K6a/00<0QXJ608:2
PP22PX800`1nOWh0101kNg/0MGEe07EeM@21PH4206EUI@0403Ti>@1BDU80DU9B06i^KP80Jf][00<0
GUiN065QH@1QHF400`1nOWh0101`L700IVIV06IVIP1LG5`206][J`<0MgMg00@0HF5Q03Lg=`0g=cL0
5QHF0P092@T0100:2PX06ATI01TI6@0U9BD502@T900402HV9P0T92@092@T02@T9080<C4a00@0=3@d
02h^;P0^;Rh0>3Ph0P10@400100j>SX0<S8b038b<P0_;bl204A4A004051@D00d=3@0=3@d020P8080
3`l?00@05QHF03hn?P0n?Sh0@d=30P15ADD00`13@d<0<C4a034a<@0302`/;004069RHP1bLW80LW9b
05aLG080CDe=00@0GEeM06IVIP1VIVH0Bd];0P1GEeL0101>CTh0>SXj03Xj>P1:BTX205ADE004051@
D01PH600H61P04];B`809bLW00@08b<S04Y:BP1:BTX0FUYJ0P13@d<0101BDU80F5QH05QHF00l?3`2
05eMG@0402`/;00n?Sh0?Shn069RHP80B4Q800@07alO010@400@4100<c<c0P13@d<0100T92@07AdM
01dM7@0_;bl202PX:00401<C4`14A4@0A4A40410@080<C4a00@0;bl_01XJ6P0J6QX071`L0P0Z:RX0
100];Bd09BDU02DU9@0b<S8204a<C00405iNGP1;Bd/0Bd];02/[:`80?clo00<0ATI602/[:`0[:b/0
0`0R8R80100];Bd0EEEE05EEE@1PH60203@d=0<0<c<c00@0>SXj02TY:@0Y:BT0<30`0P0n?Sh0100o
?cl0@D510451@@0^;Rh2024Q8@0402XZ:P0R8R808R8R01lO7`807AdM00@0<C4a03Ti>@0i>CT0Cdm?
0P1SHf<0101`L700FEUI05UIF@1@D50204Q8B00406][J`1DE5@0E5AD03lo?`80Bd];00@0@D5104i>
CP1>CTh0C4a<0P1@D500101;Bd/0E5AD05ADE01?Cdl204I6AP0403Hf=P1GEeL0EeMG06MWI`80@T92
00@0Bd];04U9B@19BDT0?Shn0P0P8200101PH600DE5A055AD@17AdL204];B`0404A4A012@T80@T92
0410@080ATI600@0<C4a03hn?P0n?Sh0Y:BT0P2k^k/0102SXj<0YjNW0:NWY`2/[:`20:^[Z`040;:b
/P2;Rh/0Rh^;04];B`805ADE00@0000000P8200820P00`<30P061PH010092@T030`<00`<300;2`/2
00P8200400/;2`061PH01PH600L71`802@T900@00`<300`<300<30`000000P010@4100<30`401PH6
0@061PH0000400820P0>3Ph03Ph>00@410800`<300@01@D500T92@092@T01`L70P0820P00`071`L0
1@D500D51@0300D51@0400X:2P061PH01PH600D51@800@4100@02PX:00D51@051@D02PX:0P061PH0
10010@402PX:00X:2P061PH200L71`0400H61P020P800P8200P820800P8200@01PH600<30`030`<0
10@40P051@D00`061PH01@D500D51@0300L71`0400H61P051@D01@D500d=3@8010@400@01@D500@4
100410@01PH60P0G5aL0100`<300<c<c03<c<`0i>CT203Lg=`0404A4A01JFUX0FUYJ03<c<`80>3Ph
00@0<c<c018B4P0B4Q802`/;0P0S8b<0100Z:RX06QXJ01XJ6P0j>SX206a/K00308J6QP22PX80PX:2
00<0OWin00@0Ng]k07EeM@1eMGD0PH610P1UIFD0100i>CT0DU9B059BDP1^KVh206][J`0305iNGP1Q
HF40HF5Q00<0OWin00@0L71`06IVIP1VIVH0G5aL0P1[Jf/307MgM`04065QH@0g=cL0=cLg01HF5P80
2@T900@02PX:01TI6@0I6AT09BDU1@0T92@0100V9RH092@T02@T900T92@2034a<@0403@d=00^;Rh0
;Rh^03Ph>080@41000@0>SXj038b<P0b<S80;bl_0P14A4@0101@D500=3@d03@d=00P820200l?3`04
01HF5P0n?Sh0?Shn04=3@`80ADE500<0@d=3034a<@0a<C400`0/;2`0101RHV80LW9b079bLP1LG5`2
04e=C@0405eMG@1VIVH0IVIV04];B`80EeMG00@0CTi>03Xj>P0j>SX0BTY:0P1DE5@0101@D500H61P
061PH01;Bd/202LW9`0402<S8`1:BTX0BTY:05YJFP80@d=300@0DU9B05QHF01HF5P0?3`l0P1MGEd0
100/;2`0?Shn03hn?P1RHV8204Q8B00401lO7`0@4100410@03<c<`80@d=300@092@T01dM7@0M7Ad0
;bl_0P0X:2P0100C4a<0A4A404A4A010@402034a<@0402l_;`0J6QX06QXJ01`L7080:RXZ00@0;Bd]
02DU9@0U9BD0<S8b0P1<C4`0101NGUh0Bd];04];B`0[:b/203lo?`0304I6AP0[:b/0:b/[00<08R8R
00@0;Bd]05EEE@1EEED0H61P0P0d=3@303<c<`0403Xj>P0Y:BT0:BTY030`<080?Shn00@0?clo0451
@@11@D40;Rh^0P0Q8B40100Z:RX08R8R028R8P0O7al201dM7@04034a<@0i>CT0>CTi04m?C`80Hf=S
00@0L71`05UIF@1IFET0D51@0P18B4P0101[Jf/0E5AD05ADE00o?cl204];B`040451@@1>CTh0CTi>
04a<C080D51@00@0Bd];05ADE01DE5@0Cdm?0P16ATH0100f=SH0EeMG05MGE`1WIfL20492@P0404];
B`19BDT0BDU903hn?P80820P00@0H61P055AD@1ADE40AdM70P1;Bd/01014A4@0@T920492@P10@402
04I6AP04034a<@0n?Sh0?Shn0:BTY080^k^k00@0Xj>S0:NWY`2WYjL0[:b/0P2[Zj/0102b/[80Rh^;
08^;R`1;Bd/201DE5@040000000820P020P800<30`801PH600@02@T900`<300<30`02`/;0P0820P0
100;2`/01PH600H61P071`L200T92@0400<30`0<30`030`<000000800@410@030`<100H61P401PH6
000010061PH020P800P820030`<200410@0400H61P0820P020P800H61P801@D500@00@4100H61P06
1PH01`L70P030`<010020P800`<300<30`0:2PX200D51@0400@4100820P020P800L71`800@410`04
10@0100820P02@T900T92@071`L200410@0400D51@020P800P8200P8208030`<00@00@4100@41004
10@02PX:0P030`<0100820P01@D500D51@00000200L71`0300P820020P800P8200<010@400@06ATI
02<S8`0S8b<0=3@d0P0`<300100c<c<0<C4a034a<@1:BTX204i>CP0402h^;P0n?Sh0?Shn030`<080
4A4A00@03`l?01lO7`0O7al09BDU0P0C4a<0100n?Sh0OGem07emO@2>SXh208J6QP0407emO@1iNGT0
NGUi07EeM@80NGUi00@0QXJ6092@T02@T900UIFE0P24Q8@0101iNGT0Ng]k07]kN`1^KVh2069RHP04
07AdM01`L700L71`06=SH`80HV9R00@0I6AT07EeM@1eMGD0NGUi0P1/K6`0101JFUX0>CTi03Ti>@0C
4a<200/;2`0401XJ6P0W9bL09bLW02`/;080<30`00@0:b/[024Q8@0Q8B4092@T0P0N7Qh00`0L71`0
92@T02@T9003020P800402`/;016ATH0ATI6059BDP80:b/[00@04a<C03/k>`0k>c/0DU9B0P12@T80
1010@400=SHf03Hf=P12@T8203Hf=P0402d];@19BDT0BDU904U9B@80Cdm?00@0GUiN05ADE01DE5@0
ATI60P1?Cdl0101[Jf/0KFe]06e]K@1WIfL2061PH00406UYJ@1eMGD0MGEe06IVIP80HV9R0`1]KFd0
101RHV80GEeM05eMG@0k>c/203lo?`04030`<013@d<0@d=306i^KP80IVIV00@0De=C04M7A`17AdL0
:BTY0P0h>3P0101DE5@0B4Q804Q8B01UIFD203`l?00402@T900U9BD09BDU02h^;P80C4a<00@0EeMG
02XZ:P0Z:RX0=3@d0P0M7Ad010030`<0?clo03lo?`18B4P202d];@04038b<P0];Bd0;Bd]02TY:@80
@D5100@0?Cdm01/K6`0K6a/07QhN0P0W9bL0100U9BD0=3@d03@d=00m?Cd204Q8B00406=SH`1PH600
H61P03Hf=P809bLW00@0D51@06EUI@1UIFD0CDe=0P0a<C40100g=cL0A4A404A4A019BDT2034a<@<0
=SHf00@0;Rh^034a<@0a<C40:RXZ0P0Q8B40100K6a/07QhN01hN7P0G5aL202d];@0404A4A00i>CT0
>CTi059BDP80GEeM00@0GemO05YJFP1JFUX0FUYJ0P1DE5@0101WIfL0E5AD05ADE00n?Sh204Q8B004
04I6AP1FEUH0EUIF04=3@`80C4a<00@0Cdm?05=CD`1CDe<0Cdm?0P18B4P0100h>3P0GEeM05eMG@1S
Hf<20410@00404Y:BP16ATH0ATI602/[:`80;Rh^00@0E5AD04Y:BP1:BTX0Cdm?0P15ADD01010@400
?Shn03hn?P14A4@204a<C00402DU9@1bLW80LW9b0;Jf]P80[:b/00@0WYjN0:f][@2][Jd0]KFe0P2d
];@0102m_Kd0S8b<08b<S00g=cL200`<3004000000030`<00`<300410@801@D500@01PH600D51@05
1@D02PX:0`061PH200P8200400D51@010@400@4100@410801`L700@00`<300820P020P8010@40P01
0@4000<02@T900@00`<30000000000001`L70`0820P200<30`0400@410051@D01@D500/;2`803@d=
00@00`<300D51@051@D02@T90P061PH010010@401PH600H61P061PH200D51@0400L71`051@D01@D5
00H61P<01@D50P0:2PX010061PH020P800P820061PH200P8200400<30`071`L01`L700L71`801PH6
00@03Ph>00D51@051@D00@410P020P80100:2PX02`/;00/;2`030`<200L71`0401DE5@0X:2P0:2PX
03<c<`80:2PX00@0<c<c03@d=00d=3@0CTi>0P1;Bd/0100c<c<0?clo03lo?`0Z:RX2010@400401LG
5`0[:b/0:b/[02l_;`8030`<00@0=cLg08F5Q@25QHD0RXZ:0P2;Rh/0101kNg/0IVIV06IVIP1nOWh2
08j>SP0408f=S@2XZ:P0Z:RX0:VYZ@80SXj>00@0L71`075aL@1aLG40O7al0`1`L70206e]K@04065Q
H@1SHf<0Hf=S06ATI080MGEe00@0OGem07AdM01dM7@0GEeM0P0d=3@0100?3`l02@T900T92@0R8R82
02d];@0401TI6@0P8200820P030`<080:2PX00@092@T01dM7@0M7Ad09RHV0P0h>3P0100b<S80:2PX
02PX:00E5AD2020P800404E5A@0j>SX0>SXj02DU9@80@D5100@0C4a<04E5A@15ADD0C4a<0P0g=cL0
1010@400?Cdm03dm?@0i>CT204i>CP0404E5A@1DE5@0E5AD05]KF`80ATI600@0;Bd]02/[:`0[:b/0
>c/k0P0n?Sh0101>CTh0BTY:04Y:BP1=CDd206ATI00406m_K`1YJFT0JFUY07EeM@80CDe=00@08b<S
05YJFP1JFUX0Bd];0P1:BTX0100a<C40B4Q804Q8B01_Kfl20820P00401DE5@0C4a<04a<C02DU9@80
<S8b00@0:2PX00`<300<30`08b<S0P0H61P0100a<C40>3Ph03Ph>00G5aL202/[:`0402DU9@0/;2`0
;2`/01XJ6P807AdM00@09BDU065QH@1QHF40DE5A0P0D51@0100O7al09RHV02HV9P0G5aL202XZ:P04
030`<00B4Q804Q8B02`/;080ADE500@0;Bd]04I6AP16ATH0KVi^0P1>CTh0100c<c<0@T920492@P19
BDT204e=C@0404I6AP0`<300<30`02@T9080;Rh^00@0>3Ph03@d=00d=3@0=cLg0P0Z:RX0100l?3`0
?Cdm03dm?@0m?Cd204A4A00403De=@0b<S80<S8b02l_;`807QhN00@05QHF02<S8`0S8b<0>3Ph0P0m
?Cd0101KFe/0Hf=S06=SH`1OGel3059BDP80Hf=S00@0KVi^05YJFP1JFUX0?Shn0P1:BTX01016ATH0
C4a<04a<C011@D4204i>CP<0Cdm?00@0Bd];04Q8B018B4P0=SHf0P1RHV80101GEeL0?Cdm03dm?@1B
DU8204=3@`0402DU9@0m?Cd0?Cdm04m?C`80ATI600@0CTi>0410@010@400B4Q80P0g=cL01018B4P0
A4A404A4A00o?cl209^KV`040;2`/02TY:@0Y:BT08j>SP80/;2`00@0`<300;>c/`2c/k<0]kNg0P2E
UID01015ADD04Q8B018B4P030`<200`<300400T92@010@400@4100H61P8010@400@00`<300X:2P0:
2PX030`<0P0410@0100<30`00P8200820P051@D200P8200400<30`020P800P82000000800`<30003
00T92@0400<30`000000000000L71`<020P80P030`<0100410@01@D500D51@0;2`/200d=3@0400<3
0`051@D01@D500T92@801PH600@00@4100H61P061PH01PH60P051@D010071`L01@D500D51@061PH3
00D51@802PX:00@01PH600P8200820P01PH60P0820P010030`<01`L700L71`071`L200H61P0400h>
3P051@D01@D500410@800P8200@02PX:00/;2`0;2`/00`<30P071`L0100E5AD0:2PX02PX:00c<c<2
02PX:00403<c<`0d=3@0=3@d04i>CP80Bd];00@0<c<c03lo?`0o?cl0:RXZ0P0@4100100G5aL0:b/[
02/[:`0_;bl200`<300403Lg=`25QHD0QHF508Z:RP80Rh^;00@0Ng]k06IVIP1VIVH0OWin0P2>SXh0
102=SHd0Z:RX0:RXZ02YZJT208j>SP04071`L01aLG40LG5a07alO0<0L71`0P1]KFd0101QHF40Hf=S
06=SH`1TI6@207EeM@0407emO@1dM7@0M7Ad05eMG@80=3@d00@03`l?00T92@092@T08R8R0P0];Bd0
100I6AT0820P020P800`<30202PX:00402@T900M7Ad07AdM02HV9P80>3Ph00@0<S8b02PX:00X:2P0
5ADE0P0P82001015ADD0>SXj03Xj>P0U9BD20451@@0404a<C015ADD0ADE504a<C080=cLg00@0@410
03dm?@0m?Cd0>CTi0P1>CTh01015ADD0E5AD05ADE01KFe/204I6AP0402d];@0[:b/0:b/[03/k>`80
?Shn00@0CTi>04Y:BP1:BTX0CDe=0P1TI6@0101_Kfl0JFUY06UYJ@1eMGD204e=C@0402<S8`1JFUX0
FUYJ04];B`80BTY:00@0<C4a04Q8B018B4P0Kfm_0P20P800100E5AD04a<C01<C4`0U9BD2038b<P04
02PX:00<30`030`<02<S8`8061PH00@0<C4a03Ph>00h>3P05aLG0P0[:b/0100U9BD0;2`/02`/;00J
6QX201dM7@0402DU9@1QHF40HF5Q055AD@8051@D00@07alO02HV9P0V9RH05aLG0P0Z:RX0100`<300
4Q8B018B4P0/;2`204E5A@0402d];@16ATH0ATI606i^KP80CTi>00@0<c<c0492@P12@T80BDU90P1=
CDd01016ATH0<30`030`<00T92@202h^;P0403Ph>00d=3@0=3@d03Lg=`80:RXZ00@0?3`l03dm?@0m
?Cd0?Cdm0P14A4@0100e=CD0<S8b038b<P0_;bl201hN7P0401HF5P0S8b<08b<S03Ph>080?Cdm00@0
Fe]K06=SH`1SHf<0GemO0`1BDU8206=SH`0406i^KP1JFUX0FUYJ03hn?P80BTY:00@0ATI604a<C01<
C4`0@D510P1>CTh304m?C`0404];B`18B4P0B4Q803Hf=P80HV9R00@0EeMG03dm?@0m?Cd0DU9B0P13
@d<0100U9BD0?Cdm03dm?@1?Cdl204I6AP0404i>CP10@400@41004Q8B080=cLg00@0B4Q804A4A014
A4@0?clo0P2KVi/0102`/;00Y:BT0:BTY02>SXh20;2`/0040<30`02c/k<0/k>c0;Ng]`80UIFE00@0
ADE5018B4P0B4Q800`<30P0<30`010092@T00@4100410@061PH200@4100400<30`0:2PX02PX:00`<
308010@400@030`<00820P020P801@D50P0820P010030`<00P8200820P00000200<30`0000@020P8
00L71`071`L01@D50P030`<0100820P01PH600H61P071`L300D51@8030`<00@01`L700<30`030`<0
1@D50P010@4010020P8010@400@4100410@200<30`0400D51@092@T02@T900820P800@4100@01@D5
00<30`030`<00P820P0820P010061PH02`/;00/;2`061PH200/;2`0400<30`051@D01@D500<30`80
0P8200@01`L700H61P061PH01@D50P071`L010051@D02PX:00X:2P030`<200d=3@0400P8200N7Qh0
7QhN03De=@80=SHf00@0?clo034a<@0a<C40ADE50P1=CDd0100e=CD0=SHf03Hf=P0[:b/201TI6@04
01dM7@0X:2P0:2PX02l_;`806ATI00@0>c/k08Z:RP2:RXX0Q8B40P1eMGD0101bLW80LG5a075aL@2;
Rh/208f=S@0408J6QP2HV9P0V9RH09:BTP80RHV900@0KVi^06YZJP1ZJVX0OWin0P1jNWX0101dM7@0
KVi^06i^KP1KFe/2061PH00406YZJP1_Kfl0Kfm_07YjNP80N7Qh00@0EeMG038b<P0b<S802@T90P0?
3`l0100Q8B40;Rh^02h^;P0X:2P202XZ:P0403/k>`0m?Cd0?Cdm030`<0806QXJ00@0>3Ph051@D01@
D500>c/k0P0/;2`0100P8200;Rh^02h^;P0h>3P202PX:00402LW9`0c<c<0<c<c04M7A`80GemO00@0
EUIF03Ph>00h>3P0@d=30P1:BTX0100l?3`0>c/k03/k>`0U9BD202h^;P0403/k>`16ATH0ATI605]K
F`80JVYZ00@0@d=304a<C01<C4`0EUIF0P1JFUX305ADE00406=SH`1`L700L71`08V9R@80GUiN00@0
@41005eMG@1MGEd0G5aL0P17AdL0100T92@0?clo03lo?`0g=cL2069RHP0402DU9@0E5AD05ADE020P
8080=SHf00@0;bl_01TI6@0I6AT04A4A0P0;2`/0100M7Ad0;2`/02`/;017AdL20410@00401HF5P0M
7Ad07AdM01LG5`8071`L00@092@T02<S8`0S8b<0=3@d0P12@T80101:BTX0=3@d03@d=00I6AT201dM
7@0402`/;00H61P061PH02TY:@80CDe=00@0>3Ph04];B`1;Bd/0N7Qh0P1MGEd0100j>SX0?3`l03`l
?016ATH204a<C0040451@@0j>SX0>SXj02l_;`808b<S00@0A4A404E5A@15ADD0<S8b0P0o?cl0101=
CDd0@T920492@P1:BTX205=CD`<071`L00@0<C4a01LG5`0G5aL02`/;0P0M7Ad0100h>3P0C4a<04a<
C01RHV83065QH@80C4a<00@0CTi>06UYJ@1YJFT0MGEe0P1JFUX01010@400ATI604I6AP18B4P204U9
B@0404M7A`19BDT0BDU904M7A`80EUIF00@0Cdm?0492@P12@T80=3@d0P1XJ6P0101DE5@0@4100410
@01FEUH203hn?P0403`l?016ATH0ATI604m?C`80@D5100@0Bd];0492@P12@T80BDU90P0l?3`0101?
Cdl0<30`030`<01[Jf/20;>c/`0409ZJVP2TY:@0Y:BT09FEU@80/K6a00@0_Kfm0;Fe]@2e]KD0][Jf
0P24Q8@0100`<300410@010@400410@200H61P0400T92@030`<00`<300d=3@801@D500@01PH600d=
3@0=3@d02@T90P051@D300@4100400D51@0>3Ph03Ph>00820P801`L70@010@410000004000000000
100820P01PH600H61P051@D200L71`0400X:2P071`L01`L700`<30801PH600@020P800T92@092@T0
1PH60P010@40100;2`/01@D500D51@030`<300820P801@D500@02`/;00d=3@0=3@d00@410P0410@0
100<30`020P800P820061PH200@4100400/;2`071`L01`L700`<30801PH600@020P800L71`071`L0
10@40P071`L010051@D00`<300<30`00000200H61P0400D51@030`<00`<300X:2P8030`<00@01`L7
00X:2P0:2PX0:BTY0P0Z:RX303`l?0040451@@1@D500D51@03Hf=P<0<S8b0P0H61P0100D51@07AdM
01dM7@0X:2P201`L700402l_;`1MGEd0GEeM06ATI080BTY:00@0G5aL07moO`1oOgl0SHf=0P2:RXX0
102?Shl0U9BD09BDU028R8P208Z:RP<0OGem00@0Rh^;08Z:RP2:RXX0OWin0P1WIfL0101>CTh0Cdm?
04m?C`1SHf<206a/K00407QhN01bLW80LW9b05ADE080=3@d00@02@T9014A4@0A4A408R8R0P0T92@3
02HV9P0402/[:`0j>SX0>SXj03@d=08092@T00@0>CTi03<c<`0c<c<06ATI0P0N7Qh0100X:2P0?3`l
03`l?00a<C4202TY:@0403Ph>00i>CT0>CTi0410@080B4Q800@0=SHf03De=@0e=CD0@d=30P0i>CT0
100c<c<0GEeM05eMG@1WIfL204];B`0405mOG`1JFUX0FUYJ05=CD`80A4A400@0820P05IFEP1FEUH0
Ng]k0P2CTi<0101nOWh0KVi^06i^KP1cLg<2069RHP0406ATI01?Cdl0Cdm?04e=C@80ATI600@0BDU9
06ATI01TI6@0JFUY0P1VIVH0101PH600HV9R069RHP1QHF4203`l?00400h>3P0<30`030`<00H61P80
51@D00@02@T902@T900T92@0ADE50P0C4a<0100M7Ad0?clo03lo?`0k>c/201DE5@0401lO7`0Z:RX0
:RXZ018B4P8030`<00@0;Bd]04M7A`17AdL0>c/k0P0A4A40100000007AdM01dM7@0X:2P201@D5004
01/K6`0W9bL09bLW04M7A`80F5QH00@0>CTi03Xj>P0j>SX0B4Q80P1@D500101DE5@0EeMG05MGE`1G
EeL203lo?`04038b<P0U9BD09BDU03lo?`80BDU900@0>CTi03Ph>00h>3P0@4100P12@T80101>CTh0
Hf=S06=SH`0f=SH202@T900402<S8`0<30`030`<00820P809BDU00@0BDU905eMG@1MGEd0HF5Q0P1T
I6@0101LG5`0CTi>04i>CP1BDU8206YZJP0408>3P`1FEUH0EUIF03hn?P80C4a<00@0CDe=04=3@`13
@d<0@T920P1:BTX0101?Cdl0EeMG05MGE`1:BTX204I6AP0403Xj>P1VIVH0IVIV04Y:BP80ATI600@0
DE5A04M7A`17AdL0E5AD0P1;Bd/0101?Cdl0@4100410@018B4P20492@P0403hn?P12@T80@T9204Q8
B080:BTY00@0U9BD0:b/[02/[:`0UIFE0P2/[:`0102^[Zh0b<S80<S8b032`/820;Zj^P040;Vi^@1k
Ng/0Ng]k02@T90801@D500@030`<00@4100410@00P820P010@4010030`<02`/;00/;2`0A4A4200P8
200400410@061PH01PH600<30`800@4100@01`L700`<300<30`010@40P051@D100L71`4010@40@04
10@0000400P820061PH01PH600D51@801`L700@02PX:00L71`071`L030`<0P061PH0100820P02@T9
00T92@061PH200410@0400/;2`051@D01@D500<30`<00P820P051@D0100;2`/03@d=00d=3@010@42
00@4100400`<300820P020P800H61P8010@400@02`/;00L71`071`L030`<0P061PH0100820P01`L7
00L71`0410@200L71`0400D51@030`<00`<3000000801PH600@01@D500<30`030`<02PX:0P0<30`0
10071`L02PX:00X:2P0Y:BT202XZ:P<0?3`l00@0@D51051@D01@D500=SHf0`0b<S8201PH600401@D
500M7Ad07AdM02PX:08071`L00@0;bl_05eMG@1MGEd0I6AT0P1:BTX0101LG5`0Ogmo07moO`2=SHd2
08Z:RP0408n?S`2DU9@0U9BD08R8R080RXZ:0`1mOGd0102;Rh/0RXZ:08Z:RP1nOWh206MWI`0404i>
CP1?Cdl0Cdm?06=SH`80K6a/00@0N7Qh079bLP1bLW80E5AD0P0d=3@010092@T04A4A014A4@0R8R82
02@T90<09RHV00@0:b/[03Xj>P0j>SX0=3@d0P0T92@0100i>CT0<c<c03<c<`0I6AT201hN7P0402PX
:00l?3`0?3`l034a<@80:BTY00@0>3Ph03Ti>@0i>CT0@4100P18B4P0100f=SH0=CDe03De=@13@d<2
03Ti>@0403<c<`1MGEd0GEeM06MWI`80Bd];00@0GemO05YJFP1JFUX0De=C0P14A4@0100P8200EUIF
05IFEP1kNg/209>CT`0407inOP1^KVh0KVi^07=cL`80HV9R00@0I6AT04m?C`1?Cdl0CDe=0P16ATH0
1019BDT0I6AT06ATI01YJFT206IVIP04061PH01RHV80HV9R065QH@80?3`l00@03Ph>00`<300<30`0
1PH60P0D51@010092@T092@T02@T9015ADD201<C4`0401dM7@0o?cl0?clo03/k>`805ADE00@07alO
02XZ:P0Z:RX04Q8B0P0<30`0100];Bd0AdM704M7A`0k>c/2014A4@040000000M7Ad07AdM02PX:080
51@D00@06a/K02LW9`0W9bL0AdM70P1HF5P0100i>CT0>SXj03Xj>P18B4P2051@D00405ADE01GEeL0
EeMG05MGE`80?clo00@0<S8b02DU9@0U9BD0?clo0P19BDT0100i>CT0>3Ph03Ph>010@4020492@P04
04i>CP1SHf<0Hf=S03Hf=P8092@T00@08b<S00`<300<30`00P820P0U9BD01019BDT0GEeM05eMG@1Q
HF4206ATI00405aLG01>CTh0CTi>059BDP80JVYZ00@0Ph>305IFEP1FEUH0?Shn0P1<C4`0101=CDd0
@d=304=3@`12@T8204Y:BP0404m?C`1GEeL0EeMG04Y:BP80ATI600@0>SXj06IVIP1VIVH0BTY:0P16
ATH0101ADE40AdM704M7A`1DE5@204];B`0404m?C`10@400@41004Q8B080@T9200@0?Shn0492@P12
@T80B4Q80P0Y:BT0102DU9@0[:b/0:b/[02EUID20:b/[0040:j^[P38b<P0b<S80<;2`P80^[Zj00@0
^KVi07]kN`1kNg/092@T0P051@D0100<30`010@400@410020P8200410@0400<30`0;2`/02`/;014A
4@8020P800@00@4100H61P061PH00`<30P010@4010071`L030`<00`<300410@200D51@401`L70@04
10@100@4100000@00@4100<30`030`<01`L70P020P8010010@402PX:00X:2P0<30`200D51@0400@4
100;2`/02`/;00L71`80000000@02PX:00@4100410@01@D50P061PH0100820P01@D500D51@0=3@d2
00l?3`0400T92@0410@010@400P820800P8200@00`<300P8200820P01`L70P051@D0100410@01@D5
00D51@0:2PX200@4100400820P0410@010@400X:2P<00`<30P020P8010061PH00P8200820P020P82
018B4P0400h>3P092@T02@T902`/;0807QhN00@0;Bd]03/k>`0k>c/0@4100P1;Bd/0100_;bl0=SHf
03Hf=P0i>CT201hN7P0401DE5@0G5aL05aLG02@T90806a/K00@09bLW03hn?P0n?Sh0Cdm?0P0l?3`0
101:BTX0M7Ad07AdM020P80207UiN@040820P029RHT0RHV90820P0<0QhN70`20P80208:2PP0407Ui
N@1PH600H61P04E5A@80E5AD00@0IVIV06MWI`1WIfL0MGEe0P1bLW80101FEUH09RHV02HV9P0410@2
00X:2P04024Q8@0b<S80<S8b034a<@80:RXZ00@0;bl_03/k>`0k>c/0=3@d0P0f=SH01014A4@0;Bd]
02d];@0K6a/2024Q8@0403@d=01>CTh0CTi>03dm?@807alO00@0:2PX04=3@`13@d<0C4a<0P13@d<0
100e=CD0?Shn03hn?P1KFe/205=CD`0403hn?P1FEUH0EUIF05aLG080>CTi00@0C4a<04];B`1;Bd/0
@4100P0g=cL0100Z:RX0DE5A055AD@1MGEd204U9B@0403Lg=`1GEeL0EeMG07YjNP80QhN700@0QHF5
061PH01PH600CTi>0P1;Bd/0101>CTh0GEeM05eMG@17AdL201LG5`0404A4A00S8b<08b<S01/K6`80
71`L00@03Ph>02TY:@0Y:BT0;Bd]0P0i>CT01010@400;Bd]02d];@1ADE4203<c<`0402LW9`1FEUH0
EUIF05YJFP80;bl_00@051@D03Xj>P0j>SX0>c/k0P0A4A40100F5QH0:2PX02PX:00`<30202<S8`04
02@T900^;Rh0;Rh^02XZ:P809RHV00@0<c<c03Hf=P0f=SH0=3@d0P0/;2`0100[:b/0ATI604I6AP0o
?cl203De=@040492@P1MGEd0GEeM06IVIP80<30`00@09RHV03`l?00l?3`0A4A40P17AdL01011@D40
<30`030`<010@402051@D0040451@@0h>3P0>3Ph030`<080;bl_00@05aLG00L71`071`L02`/;0P0Q
8B401014A4@0GUiN05iNGP1RHV8206IVIP0405UIF@1BDU80DU9B05IFEP80EeMG00@0OGem06m_K`1_
Kfl0ADE50P1>CTh0101:BTX0@T920492@P15ADD204=3@`0404U9B@17AdL0AdM703lo?`80@41000@0
>3Ph069RHP1RHV80?Shn0P17AdL0101ADE40FEUI05UIF@1JFUX204e=C@0404];B`0l?3`0?3`l04A4
A080@41000@0>SXj04a<C01<C4`0=3@d0P1GEeL0102n_[h0TY:B09:BTP2IVIT20:^[Z`040:NWY`2n
_[h0_[jn0;Jf]P80/[:b00@0X:2P06QXJ01XJ6P0;bl_0P0:2PX0100410@02`/;00/;2`0;2`/500H6
1P0400X:2P092@T02@T900820P8030`<00@010@40000000000002@T90P0:2PX0100410@020P800P8
20030`<200L71`0000@01`L700D51@051@D000000P061PH010030`<01PH600H61P0;2`/200@41003
00P820071`L01`L700<01PH600@01@D500H61P061PH000000P0<30`0100820P00@4100410@0410@2
00<30`0400820P071`L01`L700`<30801PH600@01@D500h>3P0>3Ph02`/;0P020P8010092@T020P8
00P8200?3`l200X:2P0400<30`051@D01@D500D51@802@T900@00P8200P8200820P00P820P092@T0
10020P801`L700L71`0:2PX201DE5@04038b<P0W9bL09bLW030`<080>CTi00@0?Cdm0410@010@400
;bl_0P0n?Sh0100e=CD07QhN01hN7P0E5AD2018B4P0401/K6`0D51@051@D01TI6@80:b/[00@0<S8b
024Q8@0Q8B40>CTi0P1UIFD0101dM7@0KFe]06e]K@1_Kfl207MgM`040820P02:RXX0RXZ:08>3P`80
MgMg00@0M7Ad07YjNP1jNWX0Kfm_0P1WIfL01019BDT0C4a<04a<C01UIFD206YZJP0407IfMP1eMGD0
MGEe065QH@80;2`/00@010@401@D500D51@08b<S0P0U9BD0100P82008R8R028R8P0/;2`202HV9P04
01/K6`0/;2`0;2`/03Ti>@80=3@d00<0@41003hn?P0n?Sh00`0d=3@0100c<c<0@4100410@01:BTX2
051@D00404m?C`19BDT0BDU904=3@`80BDU900@0Fe]K05YJFP1JFUX0BTY:0P1;Bd/0101CDe<0C4a<
04a<C01>CTh204I6AP0404U9B@1BDU80DU9B075aL@80RHV900@0N7Qh0492@P12@T80@D510P1EEED0
100i>CT0FUYJ05YJFP1iNGT205YJFP0403`l?016ATH0ATI604i>CP80A4A400@0@41002XZ:P0Z:RX0
?Shn0P0F5QH0100e=CD0:RXZ02XZ:P0W9bL203`l?0040451@@0i>CT0>CTi020P80807alO00@0<C4a
02XZ:P0Z:RX06QXJ0P0f=SH01019BDT0E5AD05ADE01HF5P2034a<@0402TY:@1:BTX0BTY:04M7A`80
=CDe00@04Q8B00d=3@0=3@d0A4A40P1:BTX0100K6a/000000000000Q8B4203De=@0400/;2`0N7Qh0
7QhN0410@080<c<c00@0@d=304e=C@1=CDd0?3`l0P15ADD0101:BTX0;2`/02`/;00Z:RX204A4A004
04e=C@11@D40@D5103Ti>@80@T9200@0@d=303Ph>00h>3P0?Cdm0P0V9RH0100I6AT09RHV02HV9P0@
410200L71`0400/;2`0/;2`0;2`/04m?C`D0HV9R00@0FUYJ04m?C`1?Cdl0GEeM0P1CDe<0101XJ6P0
O7al07alO01<C4`204I6AP0404=3@`11@D40@D5104M7A`80@T9200@0BTY:0410@010@400@4100P0l
?3`01017AdL0KFe]06e]K@12@T8204Q8B00404i>CP1GEeL0EeMG055AD@80C4a<00@0Bd];0410@010
@400A4A40P0d=3@0100h>3P0ADE504E5A@0Q8B4208b<S0040;bl_025QHD0QHF50:>SX`80Zj^[00@0
ZZZZ0;bl_02l_;`0[Zj^0P2ZZZX0102GUiL0KFe]06e]K@10@40500H61P0400D51@061PH01PH600D5
1@801PH600@020P800l?3`0?3`l02`/;0P0>3Ph010030`<00P8200820P0410@200H61P0400P82006
1PH01PH600H61P800@41000010071`L01@D500D51@00000200H61P0400<30`061PH01PH600/;2`80
10@400<020P800L71`071`L00`061PH010051@D01PH600H61P00000200`<300400P820010@400@41
00@410800`<300@00P8200L71`071`L030`<0P061PH010051@D03Ph>00h>3P0;2`/200820P0400T9
2@0820P020P800l?3`802PX:00@00`<300D51@051@D01@D50P092@T010020P8020P800P820020P82
00T92@0400820P071`L01`L700X:2P805ADE00@0<S8b02LW9`0W9bL0<30`0P0i>CT0100m?Cd0@410
0410@00_;bl203hn?P0403De=@0N7Qh07QhN01DE5@804Q8B00@06a/K01@D500D51@06ATI0P0[:b/0
100b<S808B4Q024Q8@0i>CT206EUI@0407AdM01]KFd0KFe]06m_K`80MgMg00@0P82008Z:RP2:RXX0
Ph>30P1gMgL0101dM7@0NWYj07YjNP1_Kfl206MWI`0404U9B@1<C4`0C4a<06EUI@80JVYZ00@0MWIf
07EeM@1eMGD0HF5Q0P0/;2`0100410@051@D01@D500S8b<202DU9@04020P800R8R808R8R02`/;080
9RHV00@06a/K02`/;00/;2`0>CTi0P0d=3@00`10@400?Shn03hn?P0303@d=00403<c<`10@400@410
04Y:BP80D51@00@0Cdm?04U9B@19BDT0@d=30P19BDT0101KFe/0FUYJ05YJFP1:BTX204];B`0405=C
D`1<C4`0C4a<04i>CP80ATI600@0BDU9059BDP1BDU80LG5a0P29RHT0101hN7P0@T920492@P11@D42
05EEE@0403Ti>@1JFUX0FUYJ07UiN@80FUYJ00@0?3`l04I6AP16ATH0CTi>0P14A4@01010@400:RXZ
02XZ:P0n?Sh201HF5P0403De=@0Z:RX0:RXZ02LW9`80?3`l00@0@D5103Ti>@0i>CT0820P0P0O7al0
100a<C40:RXZ02XZ:P0J6QX203Hf=P0404U9B@1DE5@0E5AD05QHF080<C4a00@0:BTY04Y:BP1:BTX0
AdM70P0e=CD0100B4Q803@d=00d=3@14A4@204Y:BP0401/K6`0000000000024Q8@80=CDe00@02`/;
01hN7P0N7Qh0@4100P0c<c<01013@d<0CDe=04e=C@0l?3`204E5A@0404Y:BP0/;2`0;2`/02XZ:P80
A4A400@0CDe=0451@@11@D40>CTi0P12@T801013@d<0>3Ph03Ph>00m?Cd202HV9P0401TI6@0V9RH0
9RHV010@40801`L700@02`/;02`/;00/;2`0Cdm?1@1RHV80101JFUX0Cdm?04m?C`1MGEd205=CD`04
06QXJ01lO7`0O7al04a<C080ATI600@0@d=30451@@11@D40AdM70P12@T80101:BTX0@4100410@010
@40203`l?00404M7A`1]KFd0KFe]0492@P80B4Q800@0CTi>05MGE`1GEeL0DE5A0P1<C4`0101;Bd/0
@4100410@014A4@203@d=00403Ph>015ADD0ADE5024Q8@80S8b<00@0_;bl08F5Q@25QHD0Xj>S0P2[
Zj/0102ZZZX0_;bl0;bl_02^[Zh20:ZZZP0409NGU`1]KFd0KFe]0410@0D01PH600@01@D500H61P06
1PH01@D50P061PH0100820P03`l?00l?3`0;2`/200h>3P0400<30`020P800P8200@410801PH600@0
20P800H61P061PH01PH60P010@40000400<30`051@D01@D500<30`8020P80`030`<0100000000`<3
00<30`0<30`200@410@00P820P010@400`051@D00@4100410@0300D51@0400`<300;2`/02`/;00<3
0`801PH600@01`L700P8200820P00`<30P061PH010051@D020P800P8200820P200D51@0400/;2`05
1@D01@D500L71`800P8200<01@D500L71`071`L010051@D200410@0400/;2`0410@010@400l?3`80
410@00@0:BTY02`/;00/;2`0<S8b0P0i>CT0100g=cL0=3@d03@d=00d=3@203Xj>P0402`/;00I6AT0
6ATI010@40803@d=00@03Ph>00`<300<30`04a<C0P0W9bL0100G5aL061PH01PH600n?Sh20451@@04
04m?C`1LG5`0G5aL065QH@80Fe]K00<0L71`0820P020P8000`1eMGD0101gMgL0N7Qh07QhN01YJFT2
06ATI00404m?C`0n?Sh0?Shn05ADE080J6QX00@0K6a/06][J`1[Jf/0FUYJ0P0d=3@0100410@061PH
01PH600J6QX201@D5004020P800V9RH09RHV034a<@80=3@d00@0<C4a03De=@0e=CD09bLW0P0I6AT0
100T92@0;2`/02`/;00e=CD203Hf=P0404I6AP1UIFD0IFEU04m?C`80?3`l00@0?Cdm0410@010@400
A4A40P10@400100g=cL0>SXj03Xj>P10@40204i>CP0404e=C@10@400@4100492@P80@41000@0DE5A
05QHF01HF5P0FEUI0P1RHV80101KFe/0@T920492@P1PH60208F5Q@0405IFEP1BDU80DU9B07=cL`80
F5QH00@0;Rh^04m?C`1?Cdl0AdM70P18B4P0101OGel0KVi^06i^KP1_Kfl206][J`0406QXJ00Z:RX0
:RXZ00d=3@809RHV00@01PH6014A4@0A4A408R8R0P0H61P00`0];Bd0:RXZ02XZ:P0301DE5@0400l?
3`0E5AD05ADE034a<@80820P00@0;bl_05YJFP1JFUX0@D510P0k>c/0100N7Qh03Ph>00h>3P0K6a/2
00`<300401LG5`0@4100410@01HF5P80E5AD00@0BDU903Ph>00h>3P0G5aL0P1CDe<01012@T80BDU9
04U9B@1GEeL205iNGP0405MGE`1<C4`0C4a<04U9B@<0C4a<0P15ADD0100V9RH0=SHf03Hf=P10@402
01<C4`04010@400Z:RX0:RXZ02l_;`806QXJ00@01PH60000000000002`/;0P0_;bl0101JFUX0J6QX
06QXJ01YJFT206a/K00405YJFP13@d<0@d=305MGE`80Fe]K00@0HV9R07MgM`1gMgL0De=C0P18B4P0
1010@400AdM704M7A`1:BTX20492@P0404];B`12@T80@T9204=3@`80:b/[00@0G5aL06IVIP1VIVH0
@4100P1ADE40101<C4`0?Shn03hn?P0k>c/20410@0040451@@12@T80@T9203lo?`80:BTY00@0@d=3
03Ph>00h>3P0E5AD0P2m_Kd0102QXJ40UIFE09FEU@2_[jl20:NWY`0409fMW@2][Jd0[Jf]0:RXZ080
X:2P00@0[:b/07MgM`1gMgL0;bl_0P0820P0100:2PX01@D500D51@030`<200D51@0400H61P0<30`0
30`<00@410801@D500@00@4100@4100410@020P80P051@D0100000000P8200820P030`<200D51@40
30`<0@092@T100T92@0000@00`<300T92@092@T01PH60`092@T200H61P0400T92@071`L01`L700X:
2P801@D500@01`L700D51@051@D010@40P0820P010092@T030`<00`<300:2PX200T92@0400<30`05
1@D01@D500@410802PX:00@010@400L71`071`L00P820P0820P0100000002@T900T92@010@4200/;
2`@02PX:0P061PH010030`<00P8200820P071`L200H61P0400<30`061PH01PH600H61P801@D500@0
6QXJ01TI6@0I6AT0;Bd]0P0/;2`0100[:b/0?3`l03`l?00h>3P202/[:`04030`<00f=SH0=SHf024Q
8@804A4A00@0410@00/;2`0;2`/02@T90P071`L0100<30`04a<C01<C4`0A4A4202@T900403Ti>@0^
;Rh0;Rh^03`l?080ATI600@0DU9B04a<C01<C4`0D51@0P1UIFD0101SHf<0Lg=c07=cL`1cLg<206QX
J00405iNGP1JFUX0FUYJ05IFEP80CDe=00@0GUiN079bLP1bLW80MWIf0P1cLg<0101IFET0;Rh^02h^
;P0<30`2018B4P0401XJ6P0N7Qh07QhN02DU9@808b<S00<09BDU03Xj>P0j>SX00`1;Bd/0100m?Cd0
9RHV02HV9P0^;Rh203lo?`040410@01HF5P0F5QH075aL@80I6AT00@0De=C04];B`1;Bd/0@T920`1A
DE4204I6AP0404a<C010@400@4100410@080CDe=00@0?Cdm03`l?00l?3`0Cdm?0P19BDT0100f=SH0
EeMG05MGE`1OGel204a<C0<0G5aL00@0CDe=079bLP1bLW80P8200P1eMGD0101oOgl0EeMG05MGE`0b
<S8205ADE00405EEE@1]KFd0KFe]079bLP80HF5Q00@0FEUI06YZJP1ZJVX0=cLg0P0^;Rh01010@400
FEUI05UIF@0j>SX205YJFP04051@D00d=3@0=3@d03lo?`80@41000@0@T920451@@11@D40FUYJ0P0j
>SX0100T92@08b<S02<S8`0e=CD20410@00401PH600Z:RX0:RXZ03Lg=`80@41000@0:2PX00T92@09
2@T08b<S0P0N7Qh0100L71`0D51@051@D01GEeL202HV9P0402h^;P10@400@41003lo?`<0EUIF0P1=
CDd0101BDU80Cdm?04m?C`0l?3`204E5A@0404A4A00m?Cd0?Cdm02@T90808B4Q00@0@41003<c<`0c
<c<04A4A0P0G5aL0100S8b<03Ph>00h>3P071`L200`<3004024Q8@0m?Cd0?Cdm06ATI080K6a/00@0
J6QX06YZJP1ZJVX0EUIF0P1@D500101MGEd0Fe]K05]KF`1WIfL2075aL@0404];B`17AdL0AdM70410
@080De=C00@0EUIF04M7A`17AdL0@T920P14A4@01011@D40=CDe03De=@1`L70204m?C`0303Lg=`1=
CDd0CDe=00<0@d=300@0C4a<04I6AP16ATH0@T920P19BDT0100k>c/0<c<c03<c<`18B4P201hN7P04
08V9R@2n_[h0_[jn08^;R`80WinO00@0XZ:R09>CT`2CTi<0W9bL0P2SXj<0102IVIT0WIfM09fMW@2i
^KT206i^KP04028R8P0820P020P800D51@801PH600@00P8200D51@051@D030`<0P0?3`l010092@T0
1`L700L71`0820P200/;2`0400<30`071`L01`L700D51@802@T90`0410@100<30`401@D50@051@D0
000400<30`092@T02@T900H61P<02@T90P061PH010092@T01`L700L71`0:2PX200D51@0400L71`05
1@D01@D500@4108020P800@02@T900`<300<30`02PX:0P092@T010030`<01@D500D51@0410@200X:
2P0400@410071`L01`L700820P8020P800@0000000T92@092@T00@410P0;2`/400X:2P801PH600@0
0`<300820P020P801`L70P061PH010030`<01PH600H61P061PH200D51@0401XJ6P0I6AT06ATI02d]
;@80;2`/00@0:b/[03`l?00l?3`0>3Ph0P0[:b/0100`<300=SHf03Hf=P0Q8B42014A4@04010@400;
2`/02`/;00T92@801`L700@030`<01<C4`0C4a<04A4A0P0T92@0100i>CT0;Rh^02h^;P0l?3`204I6
AP04059BDP1<C4`0C4a<051@D080IFEU00@0Hf=S07=cL`1cLg<0Lg=c0P1XJ6P0101NGUh0FUYJ05YJ
FP1FEUH204e=C@0405iNGP1bLW80LW9b07IfMP80Lg=c00@0FEUI02h^;P0^;Rh030`<0P0B4Q80100J
6QX07QhN01hN7P0U9BD202<S8`0302DU9@0j>SX0>SXj00<0Bd];00@0?Cdm02HV9P0V9RH0;Rh^0P0o
?cl01010@400F5QH05QHF01aLG4206ATI00405=CD`1;Bd/0Bd];0492@P<0DE5A0P16ATH0101<C4`0
@4100410@010@40204e=C@0403dm?@0l?3`0?3`l04m?C`80BDU900@0=SHf05MGE`1GEeL0GemO0P1<
C4`305aLG00404e=C@1bLW80LW9b0820P080MGEe00@0Ogmo05MGE`1GEeL0<S8b0P1DE5@0101EEED0
KFe]06e]K@1bLW82065QH@0405UIF@1ZJVX0JVYZ03Lg=`80;Rh^00@0@41005UIF@1IFET0>SXj0P1J
FUX0101@D500=3@d03@d=00o?cl20410@0040492@P11@D40@D5105YJFP80>SXj00@092@T02<S8`0S
8b<0=CDe0P10@400100H61P0:RXZ02XZ:P0g=cL20410@00402PX:0092@T02@T902<S8`807QhN00@0
71`L051@D01@D500EeMG0P0V9RH0100^;Rh0@4100410@00o?cl305IFEP80CDe=00@0DU9B04m?C`1?
Cdl0?3`l0P15ADD01014A4@0?Cdm03dm?@0T92@2024Q8@040410@00c<c<0<c<c014A4@805aLG00@0
8b<S00h>3P0>3Ph01`L70P0<30`0100Q8B40?Cdm03dm?@1TI6@206a/K00406QXJ01ZJVX0JVYZ05IF
EP80D51@00@0GEeM05]KF`1KFe/0IfMW0P1aLG40101;Bd/0AdM704M7A`10@40205=CD`0405IFEP17
AdL0AdM70492@P80A4A400@0@D5103De=@0e=CD0L71`0P1?Cdl00`0g=cL0CDe=04e=C@0304=3@`04
04a<C016ATH0ATI60492@P80BDU900@0>c/k03<c<`0c<c<0B4Q80P0N7Qh01029RHT0_[jn0;jn_P2;
Rh/209nOW`040::RXP2CTi<0Ti>C09bLW080Xj>S00@0VIVI09fMW@2MWId0^KVi0P1^KVh0100R8R80
20P800P820051@D200H61P0400820P051@D01@D500`<30803`l?00@02@T900L71`071`L020P80P0;
2`/010030`<01`L700L71`051@D200T92@<010@40@030`<100D51@401@D50000100820P010@400@4
100410@2000000<00@4100@01PH600`<300<30`00P820P0820P010051@D00`<300<30`0410@200H6
1P0400410@0:2PX02PX:00T92@803@d=00<01`L700<30`030`<00`092@T0100?3`l02@T900T92@03
0`<200P8200400D51@0410@010@400410@801@D500@03Ph>00@4100410@00`<30P0410@010010@40
1PH600H61P092@T200h>3P0400X:2P030`<00`<300T92@800@4100@092@T02TY:@0Y:BT0;2`/0`0`
<3020451@@040410@00j>SX0>SXj02`/;080=cLg00@06ATI00`<300<30`05ADE0P0:2PX0100820P0
0P8200820P0>3Ph200410@0400X:2P0R8R808R8R02l_;`80:2PX00@0<c<c04M7A`17AdL0DE5A0P1<
C4`0100j>SX0>CTi03Ti>@0j>SX2059BDP0405MGE`1>CTh0CTi>05UIF@80HV9R00@0HF5Q05iNGP1N
GUh0H61P0P1_Kfl0101cLg<0KVi^06i^KP1GEeL202/[:`0400P8200:2PX02PX:02/[:`80?3`l00@0
>CTi03Xj>P0j>SX0=3@d0P14A4@01016ATH0?3`l03`l?01:BTX2038b<P0401PH600a<C40<C4a03hn
?P80A4A400@0@d=303Ti>@0i>CT0C4a<0P1:BTX01011@D40Hf=S06=SH`1JFUX204A4A00404i>CP17
AdL0AdM705eMG@80IFEU00@0F5QH05eMG@1MGEd0Hf=S0P1LG5`01010@400F5QH05QHF01ZJVX204i>
CP0406YZJP1cLg<0Lg=c05=CD`80IFEU00@0P820061PH01PH600DE5A0P1JFUX0101=CDd0@4100410
@01OGel209:BTP0407YjNP1XJ6P0J6QX07alO080Jf][00@0F5QH04I6AP16ATH0>CTi0P1DE5@0101@
D500EUIF05IFEP15ADD202d];@0404Q8B01;Bd/0Bd];03/k>`80@T9200<0IVIV06UYJ@1YJFT00`1Q
HF40101LG5`0D51@051@D010@40203lo?`0403De=@0b<S80<S8b01DE5@8051@D00@09bLW01hN7P0N
7Qh09BDU0P0X:2P0100/;2`0=CDe03De=@12@T8204E5A@0404Y:BP1WIfL0IfMW05YJFP80>3Ph00@0
:BTY02PX:00X:2P0<C4a0P0h>3P0100Z:RX08B4Q024Q8@0/;2`203De=@0403Lg=`0_;bl0;bl_014A
4@806ATI00@09BDU00h>3P0>3Ph02PX:0P0H61P0100/;2`0CDe=04e=C@1]KFd206][J`04069RHP1V
IVH0IVIV05]KF`80GUiN00@0GemO05EEE@1EEED0I6AT0P1SHf<0100m?Cd0@4100410@011@D4204];
B`@0AdM70P1<C4`01010@400De=C05=CD`1]KFd204I6AP0404Q8B01:BTX0BTY:0410@080CDe=00@0
DE5A04M7A`17AdL0?clo0P17AdL0100d=3@0?clo03lo?`0e=CD203Lg=`040:n_[`2UYJD0YJFU09FE
U@80[Jf]00@0Zj^[0:BTY02TY:@0Y:BT0P2;Rh/0102<S8`0YjNW0:NWY`2d];@206UYJ@0401`L700<
30`030`<00T92@800P8200@020P800X:2P0:2PX02@T90P0?3`l0100<30`00P8200820P0820P2010@
400400P820020P800P8200X:2P802@T900@01PH600@4100410@01`L70P020P80000400/;2`020P80
0P8200D51@800P8200@01PH600/;2`0;2`/020P80P092@T0100820P01`L700L71`0410@200410@04
00D51@0=3@d03@d=00X:2P801@D500@02`/;00P8200820P01@D50P030`<010061PH000000000000:
2PX200@41004000000020P800P8200@410801@D500@00@4100<30`030`<01@D50P030`<010000000
1@D500D51@00000200X:2P0400@4100:2PX02PX:00T92@800`<300@00@41014A4@0A4A40:BTY0P0[
:b/0100_;bl0;Rh^02h^;P0X:2P203/k>`<0@D5100@0:b/[02h^;P0^;Rh04A4A0P092@T0100>3Ph0
0@4100410@00000300L71`801@D500@0410@01hN7P0N7Qh09BDU0P0P8200100g=cL0@d=304=3@`15
ADD204i>CP0402l_;`0T92@092@T028R8P80<c<c0`10@40304U9B@0404=3@`1?Cdl0Cdm?04a<C080
EeMG00@0I6AT06m_K`1_Kfl0HV9R0P0f=SH010061PH02@T900T92@0Y:BT203/k>`04034a<@0U9BD0
9BDU02PX:080@41000@0A4A403/k>`0k>c/0A4A40P0e=CD0100H61P08b<S02<S8`0f=SH204M7A`04
05QHF01PH600H61P06MWI`80EeMG00@0GEeM061PH01PH600AdM70P1@D5000`1EEED0@d=304=3@`03
04];B`04059BDP1HF5P0F5QH04U9B@80CTi>00@0JVYZ07]kN`1kNg/0NWYj0P1OGel0101GEeL0Cdm?
04m?C`1HF5P2061PH00406m_K`1cLg<0Lg=c06YZJP80GemO00@0FUYJ06][J`1[Jf/0OGem0P22PX80
1015ADD0?3`l03`l?01dM7@206MWI`0405IFEP1RHV80HV9R055AD@80A4A400@0B4Q804M7A`17AdL0
ADE50P10@400100V9RH06ATI01TI6@0l?3`2030`<00401@D500X:2P0:2PX03De=@80>3Ph00@0@410
03Ti>@0i>CT0@T920P1DE5@0100m?Cd0EeMG05MGE`1CDe<2014A4@0401`L7015ADD0ADE503dm?@80
8R8R00@04a<C01HF5P0F5QH0A4A40P1NGUh0100e=CD0=cLg03Lg=`16ATH203hn?P040451@@0`<300
<30`03/k>`80=3@d00@0;bl_02`/;00/;2`09RHV0P0];Bd0100j>SX09bLW02LW9`071`L201PH6004
018B4P0?3`l03`l?01/K6`8071`L00@0;bl_05ADE01DE5@0M7Ad0P1]KFd0101MGEd0HF5Q065QH@1>
CTh205EEE@0406ATI01DE5@0E5AD05]KF`80EeMG00@0@d=304A4A014A4@0AdM70P1?Cdl01019BDT0
BTY:04Y:BP13@d<204A4A00403Hf=P1WIfL0IfMW06=SH`80BTY:00<0D51@04m?C`1?Cdl00`18B4P0
101;Bd/0CDe=04e=C@1;Bd/20451@@0403`l?017AdL0AdM7014A4@80Lg=c00@0^KVi09BDU02DU9@0
[:b/0P2d];@0102YZJT0TI6A096AT@21PH4209FEU@040;Ng]`2m_Kd0_Kfm0:f][@80IfMW00@0:b/[
00820P020P801PH60P051@D010071`L01@D500D51@051@D2010@400400H61P0410@010@400D51@80
2@T900@030`<00L71`071`L00@410P061PH010010@401@D500D51@030`<200T92@0000@02`/;0082
0P020P801@D50P020P8010061PH02`/;00/;2`0820P200T92@0400P820071`L01`L700@410800@41
00@01@D500d=3@0=3@d02PX:0P051@D0100;2`/020P800P820051@D200<30`0400H61P0000000000
00X:2P8010@400@0000000820P020P8010@40P051@D010010@400`<300<30`051@D200<30`040000
00051@D01@D5000000802PX:00@010@400X:2P0:2PX02@T90P030`<010010@404A4A014A4@0Y:BT2
02/[:`0402l_;`0^;Rh0;Rh^02PX:080>c/k0`11@D40100[:b/0;Rh^02h^;P0A4A4200T92@0400h>
3P010@400@41000000<01`L70P051@D0100@41007QhN01hN7P0U9BD2020P800403Lg=`13@d<0@d=3
04E5A@80CTi>00@0;bl_02@T900T92@08R8R0P0c<c<30410@0<0BDU900@0@d=304m?C`1?Cdl0C4a<
0P1GEeL0101TI6@0Kfm_06m_K`1RHV8203Hf=P0400H61P092@T02@T902TY:@80>c/k00@0<C4a02DU
9@0U9BD0:2PX0P10@4001014A4@0>c/k03/k>`14A4@203De=@0401PH600S8b<08b<S03Hf=P80AdM7
00@0F5QH061PH01PH600IfMW0P1GEeL0101MGEd0H61P061PH017AdL2051@D00305EEE@13@d<0@d=3
00<0Bd];00@0DU9B05QHF01HF5P0BDU90P1>CTh0101ZJVX0Ng]k07]kN`1jNWX205mOG`0405MGE`1?
Cdl0Cdm?05QHF080H61P00@0Kfm_07=cL`1cLg<0JVYZ0P1OGel0101JFUX0Jf][06][J`1mOGd208:2
PP0404E5A@0l?3`0?3`l07AdM080IfMW00@0EUIF069RHP1RHV80DE5A0P14A4@01018B4P0AdM704M7
A`15ADD20410@00402HV9P0I6AT06ATI03`l?080<30`00@051@D02PX:00X:2P0=CDe0P0h>3P01010
@400>CTi03Ti>@12@T8205ADE00403dm?@1GEeL0EeMG05=CD`804A4A00@071`L04E5A@15ADD0?Cdm
0P0R8R80100C4a<05QHF01HF5P14A4@205iNGP0403De=@0g=cL0=cLg04I6AP80?Shn00@0@D51030`
<00`<300>c/k0P0d=3@0100_;bl0;2`/02`/;00V9RH202d];@0403Xj>P0W9bL09bLW00L71`8061PH
00@04Q8B00l?3`0?3`l06a/K0P0L71`0100_;bl0E5AD05ADE01dM7@206e]K@0405eMG@1QHF40HF5Q
04i>CP80EEEE00@0I6AT05ADE01DE5@0Fe]K0P1GEeL01013@d<0A4A404A4A017AdL204m?C`0404U9
B@1:BTX0BTY:04=3@`80A4A400@0=SHf06MWI`1WIfL0Hf=S0P1:BTX00`1@D500Cdm?04m?C`0304Q8
B00404];B`1=CDd0CDe=04];B`80@D5100@0?3`l04M7A`17AdL04A4A0P1cLg<0102i^KT0U9BD09BD
U02/[:`20;Bd]0040:VYZ@2ATI40TI6A0861P@80UIFE00@0]kNg0;fm_@2m_Kd0[Jf]0P1WIfL0100[
:b/00P8200820P061PH200D51@0400L71`051@D01@D500D51@80410@00@01PH600@4100410@01@D5
0P092@T0100<30`01`L700L71`010@4200H61P0400410@051@D01@D500<30`802@T9000010071`L0
10@400@4100410@300L71`8010@400@02@T900@4100410@01PH60P0:2PX300820P0400L71`061PH0
1PH600X:2P801@D500@02@T900`<300<30`02PX:0P092@T010010@402@T900T92@051@D200X:2P04
00H61P0410@010@400410@801PH60`051@D010030`<00@4100410@020P8200P820040000000820P0
20P800T92@8010@400@0000000@4100410@01@D50P0?3`l0100_;bl0;Rh^02h^;P0f=SH2034a<@04
038b<P0k>c/0>c/k03De=@80<S8b00@0;2`/02PX:00X:2P020P80P061PH010071`L01PH600H61P04
10@200<30`0400X:2P000000000001DE5@808B4Q00<0;bl_02<S8`0S8b<00`0];Bd0100T92@09bLW
02LW9`0<30`201LG5`0402`/;00O7al07alO02PX:080<30`00@09RHV02/[:`0[:b/0@T920P1DE5@3
05=CD`0406QXJ01mOGd0OGem06m_K`80@41000@030`<00@4100410@09RHV0P0j>SX0100a<C406QXJ
01XJ6P0U9BD204A4A0030492@P0g=cL0=cLg00<0<C4a00@0<S8b03Hf=P0f=SH0?clo0P0j>SX01019
BDT0GemO05mOG`1IFET2059BDP0405UIF@1:BTX0BTY:0410@080BDU900@0>SXj02d];@0];Bd0>SXj
0P12@T80101@D500GEeM05eMG@1CDe<2051@D004069RHP1GEeL0EeMG05=CD`80CDe=00@0KFe]075a
L@1aLG40KFe]0P16ATH0101=CDd0HV9R069RHP1WIfL2065QH@0405MGE`1^KVh0KVi^07AdM080F5QH
00@0<S8b06QXJ01XJ6P0P8200P1SHf<0101<C4`0CTi>04i>CP1QHF4204a<C00403dm?@0g=cL0=cLg
02/[:`808b<S00@09RHV02/[:`0[:b/0<S8b0P0X:2P00`0T92@0@D510451@@0304I6AP0405iNGP1Q
HF40HF5Q0451@@80@41000@0<C4a03Lg=`0g=cL0FUYJ0P10@400100d=3@0=CDe03De=@0=3@d201lO
7`040410@00Q8B408B4Q01hN7P80@T9200@0HV9R06][J`1[Jf/0EEEE0P11@D40100l?3`0>3Ph03Ph
>00g=cL202@T900402XZ:P0j>SX0>SXj02`/;0807AdM00@07QhN02PX:00X:2P061PH0P0820P0100>
3Ph03`l?00l?3`0E5AD2028R8P0404a<C01SHf<0Hf=S06m_K`80K6a/00@0EeMG05IFEP1FEUH0CDe=
0P1HF5P0101/K6`0CTi>04i>CP1<C4`204i>CP0404e=C@1?Cdl0Cdm?059BDP80C4a<00@0CDe=04I6
AP16ATH0>CTi0P0c<c<0100l?3`0IfMW06MWI`1?Cdl204Y:BP04051@D01>CTh0CTi>04a<C080EEEE
00@0FEUI04i>CP1>CTh0Cdm?0P15ADD01018B4P0:BTY02TY:@0N7Qh20:NWY`040;Jf]P2PX:00X:2P
0:n_[`80/K6a00@0YjNW08Z:RP2:RXX0ZZZZ0P3:b/X01037alL0^[Zj0;Zj^P2a/K4206a/K00402TY
:@0;2`/02`/;00P820801`L700@01PH600820P020P802PX:0P0820P010030`<01PH600H61P0;2`/2
00`<300400P8200:2PX02PX:00H61P800`<300@00@4100<30`030`<00P820P061PH0000400H61P04
10@010@400L71`801PH600@010@400D51@051@D02PX:0P0820P010030`<010@400@4100410@200D5
1@0400410@0410@010@400L71`8010@400<0000000D51@051@D00`092@T010020P801PH600H61P02
0P8200410@0400P8200410@010@400T92@802PX:00@020P800<30`030`<01`L70P030`<0100410@0
0`<300<30`071`L200P8200400H61P020P800P8200820P8020P800@01PH6018B4P0B4Q80<c<c0P0d
=3@0100];Bd0:b/[02/[:`0l?3`203Ti>@0402`/;00^;Rh0;Rh^038b<P806ATI00@01PH600`<300<
30`010@40`071`L200X:2P<0410@00@0820P01PH600H61P0<c<c0P0a<C40100];Bd0@4100410@016
ATH202l_;`0401@D500@4100410@024Q8@808b<S00@05aLG00@4100410@09RHV0P10@400101MGEd0
HF5Q065QH@1GEeL204m?C`0405eMG@1aLG40LG5a06UYJ@80@T9200@06QXJ00h>3P0>3Ph0<C4a0P0l
?3`0100[:b/05aLG01LG5`0K6a/202`/;00403<c<`15ADD0ADE504e=C@80AdM700@0@d=304];B`1;
Bd/0CTi>0P0m?Cd303hn?P0403/k>`1;Bd/0Bd];04];B`80>SXj00@0D51@05eMG@1MGEd0@4100P0b
<S80100g=cL0@4100410@01<C4`504M7A`0303lo?`14A4@0A4A400<0Bd];00@0Jf][06YZJP1ZJVX0
H61P0P1IFET305aLG004069RHP1WIfL0IfMW065QH@80Hf=S00@0LW9b07=cL`1cLg<0JVYZ0P2>SXh0
101lO7`0FUYJ05YJFP1CDe<204a<C0040451@@0e=CD0=CDe02/[:`80;Bd]00@0>c/k04];B`1;Bd/0
CTi>0P0o?cl01013@d<0B4Q804Q8B016ATH205eMG@04065QH@1ADE40DE5A05ADE080NGUi0`1_Kfl0
101`L700<C4a034a<@0Q8B4203@d=00403dm?@1CDe<0De=C0410@0805aLG00@08R8R02LW9`0W9bL0
5QHF0P0b<S80101/K6`0P8200820P01;Bd/202l_;`04030`<010@400@41004=3@`807AdM00@0;Bd]
04m?C`1?Cdl0=cLg0P0_;bl0100M7Ad04A4A014A4@0=3@d201<C4`0400l?3`0=3@d03@d=01dM7@80
>c/k00@0J6QX07=cL`1cLg<0IfMW0P1JFUX01018B4P0AdM704M7A`1CDe<205mOG`0406QXJ01>CTh0
CTi>04E5A@80BDU900@0D51@04Q8B018B4P0Bd];0P17AdL01015ADD0ATI604I6AP14A4@203Hf=P04
04e=C@1MGEd0GEeM04Q8B080BTY:00@0EeMG04e=C@1=CDd0@T920P1HF5P0101PH600F5QH05QHF01:
BTX205ADE0040451@@051@D01@D50861P@80`/;20`2RXZ80102a/K40[Jf]0:f][@2EUID208V9R@<0
_;bl00@0^[Zj0:n_[`2_[jl0/K6a0P1YJFT0100K6a/01`L700L71`0<30`200H61P0400D51@0:2PX0
2PX:00H61P8010@400@01`L700<30`030`<010@40P051@D010071`L01PH600H61P0:2PX200@41004
00<30`0410@010@400X:2P803@d=000010061PH010@400@410071`L200H61P0400@410051@D01@D5
00X:2P8020P800@00`<300@4100410@010@40P051@D010010@4010@400@410071`L200@410030000
00051@D01@D500<02@T900@00P8200H61P061PH00P820P010@40100820P010@400@410092@T200X:
2P0400P820030`<00`<300L71`800`<300@010@400<30`030`<01`L70P0820P010061PH00P820082
0P020P8200P8200400H61P0B4Q804Q8B03<c<`80=3@d00@0;Bd]02/[:`0[:b/0?3`l0P0i>CT0100/
;2`0;Rh^02h^;P0b<S8201TI6@0400H61P0<30`030`<00@410<01`L70P0:2PX3010@4004020P800H
61P061PH03<c<`80<C4a00@0;Bd]0410@010@400ATI60P0_;bl0100D51@0410@010@400Q8B4202<S
8`0401LG5`0410@010@402HV9P80@41000@0GEeM065QH@1QHF40EeMG0P1?Cdl0101MGEd0LG5a075a
L@1YJFT20492@P0401XJ6P0>3Ph03Ph>034a<@80?3`l00@0:b/[01LG5`0G5aL06a/K0P0/;2`0100c
<c<0ADE504E5A@1=CDd204M7A`0404=3@`1;Bd/0Bd];04i>CP80?Cdm0`0n?Sh0100k>c/0Bd];04];
B`1;Bd/203Xj>P04051@D01MGEd0GEeM0410@080<S8b00@0=cLg0410@010@400C4a<1@17AdL00`0o
?cl0A4A404A4A00304];B`0406][J`1ZJVX0JVYZ061PH080FEUI0`1LG5`0101RHV80IfMW06MWI`1Q
HF4206=SH`04079bLP1cLg<0Lg=c06YZJP80SXj>00@0O7al05YJFP1JFUX0De=C0P1<C4`01011@D40
=CDe03De=@0[:b/202d];@0403/k>`1;Bd/0Bd];04i>CP80?clo00@0@d=304Q8B018B4P0ATI60P1M
GEd0101QHF40DE5A055AD@1DE5@207UiN@<0Kfm_00@0L71`034a<@0a<C408B4Q0P0d=3@0100m?Cd0
De=C05=CD`10@40201LG5`04028R8P0W9bL09bLW01HF5P80<S8b00@0K6a/0820P020P800Bd];0P0_
;bl0100`<300@4100410@013@d<201dM7@0402d];@1?Cdl0Cdm?03Lg=`80;bl_00@07AdM014A4@0A
4A403@d=0P0C4a<0100?3`l03@d=00d=3@0M7Ad203/k>`0406QXJ01cLg<0Lg=c06MWI`80FUYJ00@0
B4Q804M7A`17AdL0De=C0P1OGel0101XJ6P0CTi>04i>CP15ADD204U9B@04051@D018B4P0B4Q804];
B`80AdM700@0ADE504I6AP16ATH0A4A40P0f=SH0101=CDd0GEeM05eMG@18B4P204Y:BP0405MGE`1=
CDd0CDe=0492@P80F5QH00@0H61P05QHF01HF5P0BTY:0P1DE5@01011@D401@D500D51@21PH420<;2
`P<0XZ:R00@0/K6a0:f][@2][Jd0UIFE0P29RHT30;bl_0040;Zj^P2_[jl0[jn_0;6a/@80JFUY00@0
6a/K00L71`071`L030`<0P061PH010051@D02PX:00X:2P061PH200@4100400L71`030`<00`<300@4
10801@D500@01`L700H61P061PH02PX:0P0410@010030`<010@400@4100:2PX200d=3@0000@02@T9
00820P020P8000000P0820P0100410@00000000000051@D200410@0300H61P010@400@4100<00`<3
00<010@400820P020P800`092@T010051@D00P8200820P051@D200820P0300T92@0<30`030`<00<0
1@D500@00`<300820P020P800P820P030`<010092@T03@d=00d=3@0<30`20000000400<30`000000
000000410@801`L700@02@T900D51@051@D02PX:0P061PH010092@T04Q8B018B4P0];Bd2038b<P04
02XZ:P0/;2`0;2`/03Ti>@80?Cdm0`0a<C40100d=3@030`<00`<300410@200H61P0400820P092@T0
2@T900<30`801PH600@00`<301hN7P0N7Qh0;2`/0P0G5aL0100/;2`0<30`030`<00[:b/202@T9004
01/K6`0P8200820P028R8P8051@D00@05QHF01TI6@0I6AT02`/;0P0O7al0100o?cl0De=C05=CD`1^
KVh206ATI00405IFEP1CDe<0De=C05QHF080J6QX00@0L71`04m?C`1?Cdl06a/K0P0D51@0100X:2P0
;Rh^02h^;P0`<30202`/;00401`L700C4a<04a<C02LW9`80>CTi00@0?3`l04U9B@19BDT0?3`l0P0g
=cL0101:BTX0De=C05=CD`1PH602069RHP0405iNGP1?Cdl0Cdm?03lo?`80=3@d00@0<30`03`l?00l
?3`0BTY:0P10@400100g=cL0@D510451@@1CDe<205IFEP0405iNGP1FEUH0EUIF04e=C@80JVYZ00@0
KFe]05MGE`1GEeL0Cdm?0P17AdL0101IFET0MGEe07EeM@1WIfL2059BDP0405ADE013@d<0@d=304e=
C@80F5QH00@0HV9R07moO`1oOgl0L71`0P1mOGd0101`L700>CTi03Ti>@0];Bd204=3@`0404i>CP1<
C4`0C4a<055AD@80CDe=00@0AdM705aLG01LG5`0Cdm?0P10@400100o?cl0@D510451@@1KFe/206e]
K@0406MWI`1GEeL0EeMG04e=C@80KVi^00@0J6QX05]KF`1KFe/0HF5Q0P1EEED0101CDe<0AdM704M7
A`0O7al202@T900404e=C@11@D40@D5102DU9@D092@T00@0?Cdm05iNGP1NGUh0C4a<0P0l?3`01011
@D40?3`l03`l?01<C4`204=3@`0404M7A`1CDe<0De=C03Ph>080;Bd]00@0;Rh^01lO7`0O7al05ADE
0P0M7Ad0100A4A407QhN01hN7P0g=cL204Q8B00406a/K01gMgL0MgMg06QXJ080De=C00@0DE5A04U9
B@19BDT0CDe=0P1TI6@0101PH600Cdm?04m?C`19BDT204a<C00405UIF@1:BTX0BTY:04m?C`80EUIF
00@0C4a<04Y:BP1:BTX0@4100P0b<S80101TI6@0FEUI05UIF@16ATH204a<C00404i>CP11@D40@D51
04U9B@80HV9R00@0GUiN05]KF`1KFe/0Bd];0P1?Cdl0100O7al0Bd];04];B`31`L420;>c/`0408n?
S`2XZ:P0Z:RX0;no_`80Y:BT00@0T92@0:^[Z`2[Zj/0a/K60P2g]kL0102c/k<0U9BD09BDU02LW9`2
05QHF00401TI6@0A4A404A4A00L71`802`/;00<020P800T92@092@T00`0<30`010061PH010@400@4
100820P200410@0400<30`020P800P8200820P8020P800@00P8200D51@051@D00@410P071`L00004
0000000410@010@400820P<010@40`010@4200H61P0400820P051@D01@D500h>3P802@T900@00`<3
00l?3`0?3`l020P80`061PH200<30`0400T92@051@D01@D500820P800@4100@01@D500820P020P80
2@T90P010@4010030`<01@D500D51@0:2PX200/;2`0400H61P030`<00`<300L71`<00@410P020P80
100410@00`<300<30`061PH200@4100400l?3`0=3@d03@d=02TY:@80:b/[00@0820P02TY:@0Y:BT0
>CTi0P12@T80100e=CD0>c/k03/k>`0`<30200X:2P0400P820051@D01@D500D51@801PH60`0?3`l0
100J6QX0>c/k03/k>`0Y:BT201<C4`0404U9B@0l?3`0?3`l01HF5P802`/;00@01@D502l_;`0_;bl0
9bLW0P0K6a/0100M7Ad06ATI01TI6@0?3`l201XJ6P0404U9B@1TI6@0I6AT07=cL`80L71`00@0HV9R
04a<C01<C4`0DE5A0P1]KFd0101oOgl0Hf=S06=SH`0[:b/2014A4@0400l?3`0H61P061PH030`<080
?Cdm00@07QhN01TI6@0I6AT0>3Ph0P0X:2P0100I6AT0;Rh^02h^;P0j>SX20410@00404M7A`0j>SX0
>SXj02PX:080ATI600@0H61P03dm?@0m?Cd0=cLg0P1KFe/01014A4@0:b/[02/[:`0e=CD202`/;004
03<c<`0n?Sh0?Shn04m?C`80GemO0`1QHF40101MGEd0I6AT06ATI01VIVH207MgM`0406YZJP1MGEd0
GEeM065QH@80K6a/00@0MWIf06=SH`1SHf<0HF5Q0P1MGEd0101EEED0B4Q804Q8B015ADD204Y:BP04
04e=C@1JFUX0FUYJ04U9B@80BTY:00@0B4Q804Y:BP1:BTX0CDe=0P1HF5P0101[Jf/0Fe]K05]KF`0l
?3`205iNGP0406m_K`1UIFD0IFEU051@D080ATI600@0Jf][07moO`1oOgl0KVi^0P1WIfL0101NGUh0
JVYZ06YZJP1VIVH305IFEP80J6QX00@0KVi^05eMG@1MGEd0A4A40P0/;2`0100I6AT07alO01lO7`0n
?Sh204a<C00404I6AP0b<S80<S8b01dM7@808b<S00@092@T01<C4`0C4a<0410@0P0X:2P0101:BTX0
BDU904U9B@0i>CT204A4A00404U9B@0i>CT0>CTi03dm?@80<S8b00@05ADE01`L700L71`04A4A0P0h
>3P01017AdL0GUiN05iNGP1hN7P206m_K`04065QH@1;Bd/0Bd];04I6AP80ADE500@0C4a<05mOG`1O
Gel0EUIF0P19BDT0101;Bd/0Cdm?04m?C`1CDe<304Q8B080ADE500@0@41003lo?`0o?cl0=3@d0P0a
<C40101TI6@0GUiN05iNGP10@40204U9B@040492@P0j>SX0>SXj05EEE@80GUiN00@0De=C05ADE01D
E5@0B4Q80P0Y:BT0100O7al0WIfM09fMW@2g]kL209>CT`0409FEU@2k^k/0^k^k0;Rh^080XZ:R00@0
ZJVY0<30`030`<00`<300P2c/k<0102b/[80Rh^;08^;R`2:RXX205IFEP0401lO7`0A4A404A4A0082
0P8020P800@02PX:00/;2`0;2`/04A4A0P0820P010030`<01`L700L71`061PH20000000400/;2`09
2@T02@T900T92@8010@400@00`<300410@010@4010@40P00000000040000000410@010@400820P<0
10@40`010@4200H61P0400820P051@D01@D500h>3P802@T900@00`<300l?3`0?3`l020P80`061PH2
00<30`0400T92@051@D01@D500820P800@4100@01@D500820P020P802@T90P010@4010030`<01@D5
00D51@0:2PX200/;2`0400H61P030`<00`<300L71`<00@410P020P80100410@00`<300<30`061PH2
00@4100400l?3`0=3@d03@d=02TY:@80:b/[00@0820P02TY:@0Y:BT0>CTi0P12@T80100e=CD0>c/k
03/k>`0`<30200X:2P0400P820051@D01@D500D51@801PH60`0?3`l0100J6QX0>c/k03/k>`0Y:BT2
01<C4`0404U9B@0l?3`0?3`l01HF5P802`/;00@01@D502l_;`0_;bl09bLW0P0K6a/0100M7Ad06ATI
01TI6@0?3`l201XJ6P0404U9B@1TI6@0I6AT07=cL`80L71`00@0HV9R04a<C01<C4`0DE5A0P1]KFd0
101oOgl0Hf=S06=SH`0[:b/2014A4@0400l?3`0H61P061PH030`<080?Cdm00@07QhN01TI6@0I6AT0
>3Ph0P0X:2P0100I6AT0;Rh^02h^;P0j>SX20410@00404M7A`0j>SX0>SXj02PX:080ATI600@0H61P
03dm?@0m?Cd0=cLg0P1KFe/01014A4@0:b/[02/[:`0e=CD202`/;00403<c<`0n?Sh0?Shn04m?C`80
GemO0`1QHF40101MGEd0I6AT06ATI01VIVH207MgM`0406YZJP1MGEd0GEeM065QH@80K6a/00@0MWIf
06=SH`1SHf<0HF5Q0P1MGEd0101EEED0B4Q804Q8B015ADD204Y:BP0404e=C@1JFUX0FUYJ04U9B@80
BTY:00@0B4Q804Y:BP1:BTX0CDe=0P1HF5P0101[Jf/0Fe]K05]KF`0l?3`205iNGP0406m_K`1UIFD0
IFEU051@D080ATI600@0Jf][07moO`1oOgl0KVi^0P1WIfL0101NGUh0JVYZ06YZJP1VIVH305IFEP80
J6QX00@0KVi^05eMG@1MGEd0A4A40P0/;2`0100I6AT07alO01lO7`0n?Sh204a<C00404I6AP0b<S80
<S8b01dM7@808b<S00@092@T01<C4`0C4a<0410@0P0X:2P0101:BTX0BDU904U9B@0i>CT204A4A004
04U9B@0i>CT0>CTi03dm?@80<S8b00@05ADE01`L700L71`04A4A0P0h>3P01017AdL0GUiN05iNGP1h
N7P206m_K`04065QH@1;Bd/0Bd];04I6AP80ADE500@0C4a<05mOG`1OGel0EUIF0P19BDT0101;Bd/0
Cdm?04m?C`1CDe<304Q8B080ADE500@0@41003lo?`0o?cl0=3@d0P0a<C40101TI6@0GUiN05iNGP10
@40204U9B@040492@P0j>SX0>SXj05EEE@80GUiN00@0De=C05ADE01DE5@0B4Q80P0Y:BT0100O7al0
WIfM09fMW@2g]kL209>CT`0409FEU@2k^k/0^k^k0;Rh^080XZ:R00@0ZJVY0<30`030`<00`<300P2c
/k<0102b/[80Rh^;08^;R`2:RXX205IFEP0401lO7`0A4A404A4A00820P8020P800@02PX:00/;2`0;
2`/04A4A0P0820P010030`<01`L700L71`061PH20000000400/;2`092@T02@T900T92@8010@400@0
0`<300410@010@4010@40P000000000400410@020P800P8200@410801`L70`051@D0100410@02PX:
00X:2P0:2PX200T92@0400@410071`L01`L700@410803@d=00@02`/;00X:2P0:2PX00P820P092@T0
0`0<30`010@400@4100300@410<00P8200@01`L700X:2P0:2PX01@D50P092@T0100820P00`<300<3
0`061PH200<30`0400@410030`<00`<300410@802@T900@01PH600D51@051@D010@40P0>3Ph0100B
4Q808b<S02<S8`0Z:RX202/[:`0402XZ:P0/;2`0;2`/02h^;P80@41000@0=CDe04=3@`13@d<0:b/[
0P0A4A40100=3@d01PH600H61P071`L200P820<03@d=00@071`L01lO7`0O7al0:RXZ0P0Q8B400`0j
>SX0<30`030`<00301LG5`04014A4@0S8b<08b<S010@40807QhN00@0:RXZ030`<00`<300820P0P0E
5AD01014A4@0GEeM05eMG@1[Jf/207IfMP0406IVIP1=CDd0CDe=05=CD`80HV9R00@0IFEU061PH01P
H600?3`l0P0S8b<0100[:b/0:2PX02PX:00M7Ad202LW9`0402HV9P0L71`071`L02HV9P809bLW00@0
;2`/038b<P0b<S80?Shn0P18B4P00`11@D40?3`l03`l?00302d];@0402XZ:P0P8200820P0410@080
DE5A00@0>CTi03De=@0e=CD0=cLg0P0e=CD01010@400A4A404A4A016ATH206IVIP0407EeM@1ZJVX0
JVYZ06UYJ@80FEUI00@0Cdm?06m_K`1_Kfl0KVi^0P1jNWX0101lO7`0OWin07inOP29RHT206m_K`04
07alO02>SXh0SXj>07UiN@80G5aL00@0Bd];034a<@0a<C40B4Q80P1EEED00`0l?3`0AdM704M7A`03
05ADE00404e=C@1:BTX0BTY:05eMG@80KFe]00@0Hf=S065QH@1QHF40EEEE0P18B4P0101BDU80D51@
051@D01NGUh206ATI00404U9B@1BDU80DU9B06MWI`80KVi^0`1kNg/0101UIFD0NWYj07YjNP2;Rh/2
071`L004055AD@10@400@41003<c<`80:2PX00@0;2`/02d];@0];Bd0;Rh^0P0c<c<0100^;Rh04Q8B
018B4P030`<2010@400401LG5`0O7al07alO02PX:080820P00@06a/K02HV9P0V9RH0;2`/0P0I6AT0
100g=cL0:b/[02/[:`0G5aL201dM7@0401`L7011@D40@D5105IFEP80Lg=c00@0LW9b05mOG`1OGel0
E5AD0P14A4@00`12@T80C4a<04a<C00305IFEP04061PH01CDe<0De=C04Q8B080BTY:0`1<C4`01019
BDT0?Shn03hn?P0n?Sh203Lg=`04034a<@0j>SX0>SXj061PH080GUiN00@0?Shn03lo?`0o?cl0?3`l
0P0j>SX01018B4P0C4a<04a<C01?Cdl203Xj>P0401XJ6P0Z:RX0:RXZ0820P080];Bd00@0VYZJ08b<
S02<S8`0ZJVY0P2l_;`0102][Jd0YJFU0:FUY@2VYZH20;Vi^@040;fm_@2d];@0];Bd0;Rh^080Ti>C
00@0RHV906ATI01TI6@09RHV0P051@D010092@T02`/;00/;2`092@T200d=3@0400T92@020P800P82
00H61P8030`<00@00P8200410@010@401`L70P061PH0100:2PX01@D500D51@030`<200410@400`<3
0@051@D100D51@0000@01@D500<30`030`<010@40P0:2PX010020P801`L700L71`0820P200410@04
00P820071`L01`L700<30`801`L700@00`<300820P020P801PH60P071`L300P8200400T92@061PH0
1PH600<30`801@D500@01PH600L71`071`L010@40P051@D010020P801PH600H61P010@4200<30`<0
10@400@0000000<30`030`<00@410P071`L0100:2PX01PH600H61P0410@200410@0400D51@0N7Qh0
7QhN02l_;`80:2PX00@0>c/k03`l?00l?3`0;bl_0P10@40303Ti>@0400/;2`051@D01@D500L71`80
1@D500@01`L700X:2P0:2PX02PX:0P0>3Ph0100L71`02`/;00/;2`0Y:BT202/[:`0402DU9@0m?Cd0
?Cdm03hn?P808R8R00@03Ph>02LW9`0W9bL07AdM0P0S8b<0100G5aL06a/K01/K6`0C4a<200h>3P04
03lo?`1RHV80HV9R07AdM080P82000@0LG5a05QHF01HF5P0DE5A0P1MGEd0101/K6`0KVi^06i^KP1;
Bd/202HV9P0402DU9@0W9bL09bLW02`/;0808b<S00@06a/K02XZ:P0Z:RX0=3@d0P0V9RH0100Y:BT0
@4100410@016ATH204M7A`040492@P0o?cl0?clo0492@P80AdM700@0B4Q803Lg=`0g=cL0>SXj0P10
@400100m?Cd0A4A404A4A017AdL204Y:BP04051@D01YJFT0JFUY06e]K@80O7al00@0PX:206e]K@1]
KFd0PH610P1kNg/0101eMGD0NWYj07YjNP1hN7P208^;R`0408Z:RP1iNGT0NGUi0820P080Ogmo00@0
Ph>308F5Q@25QHD0QHF50P1fMWH0101]KFd0L71`071`L01`L70205]KF`0406EUI@1PH600H61P06AT
I0<0GemO0P1SHf<0101UIFD0L71`071`L01KFe/204i>CP0405ADE01HF5P0F5QH065QH@80De=C00@0
?clo05YJFP1JFUX0Hf=S0P1@D5001010@400AdM704M7A`1QHF4206IVIP0404M7A`1NGUh0GUiN07]k
N`80GemO00@0BTY:06MWI`1WIfL0OWin0P1SHf<0101>CTh0@d=304=3@`0b<S8203hn?P0404I6AP0Q
8B408B4Q02<S8`80<S8b00@05QHF03@d=00d=3@0=CDe0P0Y:BT0100e=CD0;Rh^02h^;P0_;bl2028R
8P0402<S8`0?3`l03`l?00L71`803`l?00@0>3Ph04i>CP1>CTh0K6a/0P1hN7P0101WIfL0GemO05mO
G`1;Bd/203lo?`0404Y:BP1DE5@0E5AD05mOG`80DE5A00@0De=C04E5A@15ADD0?Shn0P13@d<01014
A4@0DU9B059BDP1@D5030492@P80<c<c00@0<30`04A4A014A4@0IVIV0P1<C4`0100b<S809bLW02LW
9`0S8b<202DU9@0403<c<`0h>3P0>3Ph02XZ:P8051@D00@0?Shn08R8R028R8P0^;Rh0P2ZZZX0102J
VYX0V9RH09RHV02e]KD20;Zj^P040;Vi^@2JVYX0VYZJ0:6QX@80`l?300@0a<C40;Jf]P2f][H0[Zj^
0P2DU9@0102<S8`0HV9R069RHP0U9BD200L71`04014A4@0820P020P800820P<01PH60P020P801004
10@020P800P820071`L200H61P04018B4P0820P020P800410@8020P800@010@400P8200820P00P82
0P0<30`0000400D51@030`<00`<300@410802PX:00@00P8200L71`071`L020P80P010@40100820P0
1`L700L71`030`<200L71`0400<30`020P800P8200H61P801`L70`0820P010092@T01PH600H61P03
0`<200D51@0400H61P071`L01`L700@410801@D500@00P8200H61P061PH00@410P030`<300@41004
000000030`<00`<300410@801`L700@02PX:00H61P061PH010@40P010@4010051@D07QhN01hN7P0_
;bl202PX:00403/k>`0l?3`0?3`l02l_;`80@4100`0i>CT0100;2`/01@D500D51@071`L200D51@04
00L71`0:2PX02PX:00X:2P803Ph>00@071`L00/;2`0;2`/0:BTY0P0[:b/0100U9BD0?Cdm03dm?@0n
?Sh2028R8P0400h>3P0W9bL09bLW01dM7@808b<S00@05aLG01/K6`0K6a/04a<C0P0>3Ph0100o?cl0
HV9R069RHP1dM7@20820P004075aL@1HF5P0F5QH055AD@80GEeM00@0K6a/06i^KP1^KVh0Bd];0P0V
9RH0100U9BD09bLW02LW9`0/;2`202<S8`0401/K6`0Z:RX0:RXZ03@d=0809RHV00@0:BTY0410@010
@400ATI60P17AdL01012@T80?clo03lo?`12@T8204M7A`0404Q8B00g=cL0=cLg03Xj>P80@41000@0
?Cdm04A4A014A4@0AdM70P1:BTX0101@D500JFUY06UYJ@1]KFd207alO00408:2PP1]KFd0KFe]0861
P@80Ng]k00@0MGEe07YjNP1jNWX0N7Qh0P2;Rh/0102:RXX0NGUi07UiN@20P80207moO`0408>3P`25
QHD0QHF508F5Q@80MWIf00@0KFe]071`L01`L700L71`0P1KFe/0101UIFD0H61P061PH01TI6@305mO
G`80Hf=S00@0IFEU071`L01`L700Fe]K0P1>CTh0101DE5@0F5QH05QHF01QHF4205=CD`0403lo?`1J
FUX0FUYJ06=SH`80D51@00@0@41004M7A`17AdL0HF5Q0P1VIVH01017AdL0GUiN05iNGP1kNg/205mO
G`0404Y:BP1WIfL0IfMW07inOP80Hf=S00@0CTi>04=3@`13@d<0<S8b0P0n?Sh01016ATH08B4Q024Q
8@0S8b<2038b<P0401HF5P0d=3@0=3@d03De=@80:BTY00@0=CDe02h^;P0^;Rh0;bl_0P0R8R80100S
8b<03`l?00l?3`071`L200l?3`0403Ph>01>CTh0CTi>06a/K080N7Qh00@0IfMW05mOG`1OGel0Bd];
0P0o?cl0101:BTX0E5AD05ADE01OGel2055AD@0405=CD`15ADD0ADE503hn?P80@d=300@0A4A4059B
DP1BDU80D51@0`12@T8203<c<`04030`<014A4@0A4A406IVIP80C4a<00@0<S8b02LW9`0W9bL08b<S
0P0U9BD0100c<c<0>3Ph03Ph>00Z:RX201@D500403hn?P28R8P0R8R80;Rh^080ZZZZ00@0VYZJ09RH
V02HV9P0]KFe0P2j^[X0102i^KT0VYZJ09ZJVP2QXJ420<?3``040<C4a02f][H0][Jf0:j^[P80U9BD
00@0S8b<069RHP1RHV809BDU0P071`L0100A4A4020P800P820020P8300H61P800P8200@010@400P8
200820P01`L70P061PH0100B4Q8020P800P820010@4200P8200400@4100820P020P800820P8030`<
00000`0000002@T900T92@0300H61P0400820P071`L01`L700X:2P<01PH60`020P8200L71`0400P8
200:2PX02PX:00/;2`8010@40`071`L010092@T01PH600H61P092@T200H61P0400820P030`<00`<3
00820P801@D500@00P8200L71`071`L01PH60P0820P0100000000`<300<30`051@D200<30`0400@4
10061PH01PH600<30`800@4100@00`<300820P020P802`/;0P0Q8B40100V9RH07alO01lO7`0b<S82
02TY:@04034a<@0i>CT0>CTi03Lg=`80;Bd]00@01PH600@4100410@000000P030`<0100410@00P82
00820P0@410201HF5P04024Q8@0W9bL09bLW03Xj>P80>3Ph00@08B4Q0451@@11@D40DU9B0P0a<C40
100J6QX0=3@d03@d=00Q8B4202DU9@04018B4P071`L01`L700410@802`/;00@0:b/[05=CD`1CDe<0
K6a/0`1dM7@206IVIP0305ADE01GEeL0EeMG00<0L71`00@0CTi>02HV9P0V9RH051@D0P0K6a/01013
@d<0A4A404A4A00_;bl202HV9P0401/K6`0X:2P0:2PX04a<C080EEEE00@0?clo03<c<`0c<c<0=3@d
0P0k>c/0100h>3P0=3@d03@d=016ATH20410@004034a<@0l?3`0?3`l04=3@`80@T9200@0?Cdm03/k
>`0k>c/0D51@0P1VIVH0101ZJVX0Lg=c07=cL`1]KFd205iNGP04071`L01^KVh0KVi^07EeM@80O7al
00@0MgMg08F5Q@25QHD0Rh^;0P1aLG40101XJ6P0FEUI05UIF@1WIfL207]kN`0407QhN01[Jf/0Jf][
07UiN@80Ph>300@0GEeM04Y:BP1:BTX0IFEU0P1IFET0101bLW80IFEU06EUI@1DE5@206a/K00406YZ
JP1DE5@0E5AD0492@P80Cdm?00<0DU9B04Y:BP1:BTX00`1GEeL0101EEED0Ng]k07]kN`1ZJVX204A4
A00404M7A`1BDU80DU9B05aLG080H61P00@0EEEE06IVIP1VIVH0IfMW0P1:BTX0100i>CT0C4a<04a<
C01aLG4207MgM`0406UYJ@1IFET0FEUI04i>CP80?clo00@0>CTi01hN7P0N7Qh09RHV0P12@T80100`
<300@T920492@P1ADE4204A4A00404U9B@0b<S80<S8b030`<080:2PX00@05aLG01PH600H61P04A4A
0P0b<S80101FEUH0KVi^06i^KP20P802075aL@0405UIF@1=CDd0CDe=0492@P80@d=300@0DU9B05QH
F01HF5P0GemO0P1EEED0101:BTX0?Cdm03dm?@15ADD2055AD@0404];B`1CDe<0De=C04e=C@80>3Ph
00@0<C4a02d];@0];Bd0ADE50P1HF5P0101YJFT0>CTi03Ti>@0I6AT200/;2`0400d=3@0D51@051@D
01DE5@803`l?00@02`/;0410@010@400T92@0P32`/80102a/K40WYjN09jNWP2>SXh20::RXP040;Rh
^02_[jl0[jn_0:VYZ@80PX:200@0YZJV0<W9b@39bLT0]kNg0P2c/k<0102^[Zh0PH610861P@20P802
05eMG@04028R8P061PH01PH600D51@800P8200@01`L700D51@051@D01`L70P0820P010092@T010@4
00@4100410@200D51@0401<C4`0:2PX02PX:00@410801PH600@02PX:00@4100410@020P80P092@T0
000400820P0:2PX02PX:00H61P800@4100@010@400410@010@4000000P030`<0100820P01PH600H6
1P061PH200P820<03@d=00@010@400L71`071`L01@D50P020P8010030`<020P800P8200;2`/200X:
2P0400820P051@D01@D500H61P800@4100@010@400D51@051@D020P80P061PH010051@D020P800P8
20020P8200D51@<00@4100@01@D500H61P061PH02`/;0P061PH0100Q8B408b<S02<S8`0N7Qh202<S
8`0402l_;`0];Bd0;Bd]03lo?`80<S8b00@0<c<c01lO7`0O7al01`L70P0>3Ph010071`L02@T900T9
2@0820P200L71`04014A4@0<30`030`<02<S8`80?clo0`0c<c<0100Y:BT09BDU02DU9@10@40203Ti
>@0402h^;P0Q8B408B4Q00@410807alO00<06a/K00H61P061PH00`030`<0100T92@0EEEE05EEE@1b
LW82071`L00406m_K`1aLG40LG5a05mOG`80Bd];00@0FUYJ06UYJ@1YJFT0EUIF0P0Y:BT0100S8b<0
9bLW02LW9`0b<S8202`/;00402LW9`0O7al07alO01dM7@80>3Ph00@0ATI603<c<`0c<c<0<C4a0P0h
>3P0100a<C40@T920492@P10@40203@d=00404A4A018B4P0B4Q804I6AP80@d=300@0=CDe034a<@0a
<C40@T920P14A4@0101DE5@0GUiN05iNGP1PH602071`L00407alO01QHF40HF5Q05MGE`80I6AT00@0
NGUi08>3P`23Ph<0LW9b0P1YJFT0101gMgL0Lg=c07=cL`1oOgl205]KF`04075aL@26QXH0QXJ608R8
R080NGUi00@0N7Qh08N7Q`27QhL0LW9b0P1eMGD0101^KVh0GEeM05eMG@1iNGT205mOG`0404I6AP1E
EED0EEEE05eMG@80De=C00@0EeMG06MWI`1WIfL0Bd];0P10@400101MGEd0CTi>04i>CP10@40205AD
E00404e=C@1FEUH0EUIF06MWI`80IVIV00@0MgMg06m_K`1_Kfl0Hf=S0P1hN7P0101WIfL0>CTi03Ti
>@10@40206IVIP0406i^KP1cLg<0Lg=c069RHP80De=C00@0JVYZ04U9B@19BDT0<C4a0P16ATH0101>
CTh0BTY:04Y:BP10@40204I6AP0404Y:BP0`<300<30`02d];@807AdM00@06ATI00`<300<30`010@4
0P0?3`l0100O7al0@T920492@P1OGel2075aL@04079bLP1UIFD0IFEU05QHF080BDU900@0@4100492
@P12@T80Hf=S0P1RHV80101KFe/0EUIF05IFEP1@D50204Y:BP040492@P10@400@41004];B`80Cdm?
00@0ADE503De=@0e=CD0;Bd]0P0e=CD0101ZJVX0P8200820P021PH4205=CD`04034a<@0o?cl0?clo
03Ti>@8071`L00@04A4A02DU9@0U9BD0GemO0P2PX:001030`<00][Jf0;Jf]P2RXZ8209JFUP0408N7
Q`2[Zj/0Zj^[0;:b/P80YjNW00@0X:2P08J6QP26QXH0/k>c0P32`/80102`/;00]kNg0;Ng]`2WYjL2
0820P00408n?S`1WIfL0IfMW02`/;0803`l?00@02@T900d=3@0=3@d02@T90P0820P0100:2PX02@T9
00T92@0=3@d200P82003000000071`L01`L700<01@D500@01PH600D51@051@D02PX:0P071`L100P8
20400@410@010@40000400820P0:2PX02PX:00H61P800@4100@010@400410@010@4000000P030`<0
100820P01PH600H61P061PH200P820<03@d=00@010@400L71`071`L01@D50P020P8010030`<020P8
00P8200;2`/200X:2P0400820P051@D01@D500H61P800@4100@010@400D51@051@D020P80P061PH0
10051@D020P800P820020P8200D51@<00@4100@01@D500H61P061PH02`/;0P061PH0100Q8B408b<S
02<S8`0N7Qh202<S8`0402l_;`0];Bd0;Bd]03lo?`80<S8b00@0<c<c01lO7`0O7al01`L70P0>3Ph0
10071`L02@T900T92@0820P200L71`04014A4@0<30`030`<02<S8`80?clo0`0c<c<0100Y:BT09BDU
02DU9@10@40203Ti>@0402h^;P0Q8B408B4Q00@410807alO00<06a/K00H61P061PH00`030`<0100T
92@0EEEE05EEE@1bLW82071`L00406m_K`1aLG40LG5a05mOG`80Bd];00@0FUYJ06UYJ@1YJFT0EUIF
0P0Y:BT0100S8b<09bLW02LW9`0b<S8202`/;00402LW9`0O7al07alO01dM7@80>3Ph00@0ATI603<c
<`0c<c<0<C4a0P0h>3P0100a<C40@T920492@P10@40203@d=00404A4A018B4P0B4Q804I6AP80@d=3
00@0=CDe034a<@0a<C40@T920P14A4@0101DE5@0GUiN05iNGP1PH602071`L00407alO01QHF40HF5Q
05MGE`80I6AT00@0NGUi08>3P`23Ph<0LW9b0P1YJFT0101gMgL0Lg=c07=cL`1oOgl205]KF`04075a
L@26QXH0QXJ608R8R080NGUi00@0N7Qh08N7Q`27QhL0LW9b0P1eMGD0101^KVh0GEeM05eMG@1iNGT2
05mOG`0404I6AP1EEED0EEEE05eMG@80De=C00@0EeMG06MWI`1WIfL0Bd];0P10@400101MGEd0CTi>
04i>CP10@40205ADE00404e=C@1FEUH0EUIF06MWI`80IVIV00@0MgMg06m_K`1_Kfl0Hf=S0P1hN7P0
101WIfL0>CTi03Ti>@10@40206IVIP0406i^KP1cLg<0Lg=c069RHP80De=C00@0JVYZ04U9B@19BDT0
<C4a0P16ATH0101>CTh0BTY:04Y:BP10@40204I6AP0404Y:BP0`<300<30`02d];@807AdM00@06ATI
00`<300<30`010@40P0?3`l0100O7al0@T920492@P1OGel2075aL@04079bLP1UIFD0IFEU05QHF080
BDU900@0@4100492@P12@T80Hf=S0P1RHV80101KFe/0EUIF05IFEP1@D50204Y:BP040492@P10@400
@41004];B`80Cdm?00@0ADE503De=@0e=CD0;Bd]0P0e=CD0101ZJVX0P8200820P021PH4205=CD`04
034a<@0o?cl0?clo03Ti>@8071`L00@04A4A02DU9@0U9BD0GemO0P2PX:001030`<00][Jf0;Jf]P2R
XZ8209JFUP0408N7Q`2[Zj/0Zj^[0;:b/P80YjNW00@0X:2P08J6QP26QXH0/k>c0P32`/80102`/;00
]kNg0;Ng]`2WYjL20820P00408n?S`1WIfL0IfMW02`/;0803`l?00@02@T900d=3@0=3@d02@T90P08
20P0100:2PX02@T900T92@0=3@d200P82003000000071`L01`L700<01@D500@01PH600D51@051@D0
2PX:0P071`L100P820400@410@010@40000400X:2P092@T02@T900<30`800P8200@02@T900820P02
0P8020P80P071`L300D51@0400410@071`L01`L700820P801PH600<020P800d=3@0=3@d00`030`<0
10071`L01PH600H61P0410@500H61P0400D51@071`L01`L700T92@800`<300@00P8200@4100410@0
2@T90P071`L010010@401@D500D51@020P8200X:2P0400D51@030`<00`<30000008030`<00@06a/K
030`<00`<30092@T0P0U9BD0100a<C40<c<c03<c<`0a<C4202XZ:P04034a<@0D51@051@D00<30`80
1@D500<01`L700P8200820P00`0820P010010@401@D500D51@0a<C420410@00402<S8`0k>c/0>c/k
03De=@8092@T00@0BTY:0410@010@400:b/[0P0Q8B40100F5QH08R8R028R8P0H61P200T92@0400D5
1@000000000001/K6`80ADE500<0I6AT071`L01`L7000`1^KVh0101WIfL0EEEE05EEE@1IFET2061P
H00305QHF00b<S80<S8b00<09RHV00@0;bl_02h^;P0^;Rh08b<S0P0L71`0100X:2P0=CDe03De=@0e
=CD202HV9P0402h^;P0d=3@0=3@d02HV9P80<S8b00@0=SHf02PX:00X:2P0:BTY0P0n?Sh0101<C4`0
CTi>04i>CP1:BTX20410@00404I6AP14A4@0A4A404I6AP80CDe=00@0F5QH06MWI`1WIfL0NGUi0P1a
LG40101YJFT0Lg=c07=cL`1dM7@208N7Q`040861P@1cLg<0Lg=c079bLP80IfMW00@0Ogmo07AdM01d
M7@0PX:20P1eMGD00`24Q8@0U9BD09BDU00307=cL`0306UYJ@1[Jf/0Jf][00<0Jf][00@0M7Ad055A
D@1ADE40CDe=0P1LG5`0101iNGT0MGEe07EeM@1?Cdl2059BDP0404Y:BP19BDT0BDU9071`L080Fe]K
00@0>3Ph03Xj>P0j>SX0@4100P1ADE40101TI6@0H61P061PH01RHV8206QXJ00405]KF`1aLG40LG5a
07alO080BTY:00@0?Cdm04a<C01<C4`0IVIV0P1jNWX0101ADE40?clo03lo?`1ADE4204=3@`0403`l
?00k>c/0>c/k03Xj>P80EUIF00@0ATI603lo?`0o?cl0BTY:0P0n?Sh0100c<c<08b<S02<S8`0N7Qh2
01`L700401<C4`0<30`030`<04M7A`80Cdm?00@0JFUY06YZJP1ZJVX0IVIV0P1OGel0101>CTh0AdM7
04M7A`10@40204Y:BP0406UYJ@1PH600H61P051@D080ADE500@0@T9204A4A014A4@0>SXj0P0m?Cd0
101CDe<0A4A404A4A00l?3`203Ti>@0403`l?01@D500D51@0820P080Shn?00@0SHf=07EeM@1eMGD0
Lg=c0P1eMGD0101IFET0ADE504E5A@1CDe<206QXJ00409^KV`36a/H0a/K60;Jf]P80X:2P00@0XJ6Q
09NGU`2GUiL0Zj^[0P2l_;`0102_[jl0Z:RX0:RXZ02QXJ4209BDU0040;Vi^@2j^[X0^[Zj0;no_`80
]kNg00@0Y:BT09NGU`2GUiL0Y:BT0P1OGel0100E5AD00000000000092@T200l?3`0400X:2P051@D0
1@D500T92@801@D500@04a<C00h>3P0>3Ph020P80P0<30`0100410@00`<300<30`061PH200820P04
00H61P0410@010@400<30`800@410000100=3@d01`L700L71`030`<300@410801PH600@02@T900L7
1`071`L00P820P051@D0100410@02@T900T92@030`<200L71`<02`/;0`092@T0100;2`/01@D500D5
1@030`<200P8200400T92@051@D01@D500H61P800P8200@020P800<30`030`<00`<30`020P8200<3
0`0400D51@0820P020P800H61P800P8200<02@T900<30`030`<00`0820P010071`L06QXJ01XJ6P0U
9BD202LW9`04030`<00g=cL0=cLg0451@@80>c/k00<09RHV010@400@410010051@D200L71`0400`<
300?3`l03`l?00d=3@804Q8B00@0<30`03Lg=`0g=cL0<S8b0P12@T80100k>c/0=3@d03@d=00k>c/2
03Hf=P04030`<00e=CD0=CDe02HV9P8092@T00@04Q8B01LG5`0G5aL02@T90P051@D0100E5AD0?clo
03lo?`1QHF4206e]K@0406m_K`1]KFd0KFe]06EUI@80E5AD00@0EEEE05]KF`1KFe/0CTi>0P0/;2`0
100a<C40=cLg03Lg=`0Z:RX202@T900402PX:00^;Rh0;Rh^02d];@80:BTY0`0c<c<0100d=3@0>SXj
03Xj>P0f=SH203<c<`0403Xj>P0m?Cd0?Cdm03Lg=`80@d=300@0Bd];05EEE@1EEED0GUiN0P1BDU80
1017AdL0@T920492@P1LG5`205eMG@0405ADE01HF5P0F5QH06=SH`80J6QX00@0I6AT07emO@1mOGd0
KFe]0P1nOWh0102ATI40P8200820P01UIFD206MWI`0407AdM01/K6`0K6a/0820P080Ng]k00@0QhN7
08^;R`2;Rh/0EeMG0P1IFET0101YJFT0H61P061PH01IFET2051@D00406=SH`1QHF40HF5Q079bLP80
J6QX00@0I6AT05IFEP1FEUH0@4100P1FEUH0101JFUX0Bd];04];B`1LG5`205QHF00405YJFP1OGel0
GemO065QH@80Hf=S00@0H61P05=CD`1CDe<0B4Q80P1ADE40101?Cdl0IfMW06MWI`1/K6`205IFEP04
06QXJ015ADD0ADE503hn?P80J6QX00@0De=C055AD@1ADE40ATI60P0i>CT01015ADD0@4100410@018
B4P206ATI00405aLG00`<300<30`03dm?@80B4Q800@0<30`02HV9P0V9RH0:RXZ0P0R8R80100K6a/0
51@D01@D501ADE4205iNGP0407EeM@1`L700L71`069RHP80CTi>00@0=3@d038b<P0b<S80@T920P1W
IfL0101VIVH0DE5A055AD@1@D50204i>CP040492@P0a<C40<C4a03De=@80@d=300<0C4a<030`<00`
<3000`0Y:BT0101<C4`0OGem07emO@2GUiL209^KV`0409fMW@2IVIT0VIVI09FEU@80PX:200@0MgMg
07IfMP1fMWH0Q8B40P2DU9@0102/[:`0][Jf0;Jf]P2^[Zh20;6a/@040:JVYP2RXZ80XZ:R0<K6aP80
/k>c00@0YjNW0;:b/P2b/[80V9RH0P2KVi/0102n_[h0]KFe0;Fe]@33`l<20;>c/`040:b/[02UYJD0
YJFU09jNWP80BDU900@02PX:00H61P061PH01`L70P0>3Ph0100?3`l030`<00`<300>3Ph200D51@04
00d=3@051@D01@D500`<30802@T900@020P800D51@051@D01PH60P0820P300D51@400P820@030`<1
00<30`0000@03@d=00L71`071`L00`<30`0410@200H61P0400T92@071`L01`L700820P801@D500@0
10@400T92@092@T00`<30P071`L300/;2`<02@T900@02`/;00D51@051@D00`<30P0820P010092@T0
1@D500D51@061PH200820P0400P820030`<00`<300<30`<00P820P030`<010051@D020P800P82006
1PH200820P0300T92@030`<00`<300<020P800@01`L701XJ6P0J6QX09BDU0P0W9bL0100`<300=cLg
03Lg=`11@D4203/k>`0302HV9P0@4100410@00@01@D50P071`L0100<30`03`l?00l?3`0=3@d2018B
4P04030`<00g=cL0=cLg038b<P80@T9200@0>c/k03@d=00d=3@0>c/k0P0f=SH0100`<300=CDe03De
=@0V9RH202@T9004018B4P0G5aL05aLG00T92@801@D500@05ADE03lo?`0o?cl0HF5Q0P1]KFd0101_
Kfl0KFe]06e]K@1UIFD205ADE00405EEE@1KFe/0Fe]K04i>CP80;2`/00@0<C4a03Lg=`0g=cL0:RXZ
0P0T92@0100X:2P0;Rh^02h^;P0];Bd202TY:@<0<c<c00@0=3@d03Xj>P0j>SX0=SHf0P0c<c<0100j
>SX0?Cdm03dm?@0g=cL204=3@`0404];B`1EEED0EEEE05iNGP80DU9B00@0AdM70492@P12@T80G5aL
0P1MGEd0101DE5@0F5QH05QHF01SHf<206QXJ00406ATI01mOGd0OGem06e]K@80OWin00@0TI6A0820
P020P800IFEU0P1WIfL0101dM7@0K6a/06a/K020P80207]kN`0408N7Q`2;Rh/0Rh^;05MGE`80FEUI
00@0JFUY061PH01PH600FEUI0P1@D500101SHf<0HF5Q065QH@1bLW8206QXJ00406ATI01FEUH0EUIF
0410@080EUIF00@0FUYJ04];B`1;Bd/0G5aL0P1HF5P0101JFUX0GemO05mOG`1QHF4206=SH`04061P
H01CDe<0De=C04Q8B080DE5A00@0Cdm?06MWI`1WIfL0K6a/0P1FEUH0101XJ6P0ADE504E5A@0n?Sh2
06QXJ00405=CD`1ADE40DE5A04I6AP80>CTi00@0ADE50410@010@400B4Q80P1TI6@0101LG5`0<30`
030`<00m?Cd204Q8B004030`<00V9RH09RHV02XZ:P808R8R00@06a/K01@D500D51@0DE5A0P1NGUh0
101eMGD0L71`071`L01RHV8204i>CP0403@d=00b<S80<S8b0492@P80IfMW00@0IVIV055AD@1ADE40
D51@0P1>CTh01012@T80<C4a034a<@0e=CD204=3@`0304a<C00`<300<30`00<0:BTY00@0C4a<07em
O@1mOGd0UiNG0P2KVi/0102MWId0VIVI09VIV@2EUID208:2PP0407MgM`1fMWH0MWIf08B4Q080U9BD
00@0[:b/0;Jf]P2f][H0[Zj^0P2a/K40102VYZH0XZ:R0::RXP36a/H20;>c/`040:NWY`2b/[80/[:b
09RHV080Vi^K00@0_[jn0;Fe]@2e]KD0`l?30P2c/k<0102/[:`0YJFU0:FUY@2NWYh204U9B@0400X:
2P061PH01PH600L71`803Ph>00@03`l?00`<300<30`03Ph>0P051@D0100=3@d01@D500D51@0<30`2
00T92@0400P820051@D01@D500H61P8020P80`051@D100820P400`<30@030`<0000400X:2P0410@0
10@400<30`800P8200@01`L700D51@051@D01@D50`020P8200<30`0300820P0=3@d03@d=00<01PH6
00@01`L700h>3P0>3Ph01`L70P030`<0100:2PX01@D500D51@051@D300<30`800@4100@02`/;00P8
200820P03`l?0P071`L010061PH020P800P820061PH200T92@04018B4P092@T02@T900H61P800P82
00@01`L700/;2`0;2`/01@D50P0=3@d0100M7Ad0:RXZ02XZ:P0V9RH202/[:`0403Hf=P0^;Rh0;Rh^
03Hf=P80?Cdm00<092@T00`<300<30`00`0;2`/0100410@01`L700L71`092@T200d=3@04014A4@0X
:2P0:2PX03`l?080>CTi00@0?3`l03dm?@0m?Cd0@T920P1GEeL01010@400;Rh^02h^;P10@40203Ti
>@0402LW9`0h>3P0>3Ph01`L70805aLG00@04a<C0000000000003@d=0P0l?3`0101IFET0Hf=S06=S
H`1_Kfl207QhN00407MgM`1PH600H61P05ADE080Hf=S00@0De=C01hN7P0N7Qh0:BTY0P0n?Sh0100`
<3006ATI01TI6@0B4Q8201lO7`04034a<@0e=CD0=CDe03/k>`80@d=300@0DE5A05iNGP1NGUh0GEeM
0P1ADE40101FEUH0I6AT06ATI01EEED204a<C00404e=C@1<C4`0C4a<04M7A`80C4a<00@0A4A404E5
A@15ADD0HV9R0P1PH600101HF5P0IVIV06IVIP1cLg<206YZJP0405mOG`1kNg/0Ng]k07IfMP80KFe]
00<0NWYj0820P020P8000`1aLG40101fMWH0Jf][06][J`1bLW8207emO@0409VIV@2FUYH0UYJF05]K
F`80FEUI00@0K6a/04E5A@15ADD0DU9B0P1VIVH0101]KFd0EEEE05EEE@1MGEd206i^KP0406][J`1=
CDd0CDe=03lo?`80DE5A00@0BDU903Hf=P0f=SH0<C4a0P16ATH0101RHV80EEEE05EEE@1EEED205QH
F00404a<C01FEUH0EUIF061PH080BDU900@0Bd];06e]K@1]KFd0CDe=0P0e=CD0101/K6`0JFUY06UY
J@1GEeL206=SH`0404];B`1UIFD0IFEU06IVIP80>c/k00@0<30`03Hf=P0f=SH0@D510P15ADD0101G
EeL0BDU904U9B@0j>SX204];B`0403/k>`0Z:RX0:RXZ0410@0809RHV00@02PX:038b<P0b<S80H61P
0P1/K6`0101]KFd0FEUI05UIF@1ADE420410@00402l_;`0g=cL0=cLg05EEE@80Ng]k00@0F5QH0451
@@11@D40BTY:0P12@T801016ATH0?3`l03`l?00j>SX20410@00403hn?P0];Bd0;Bd]02/[:`80>3Ph
00@0Kfm_0:6QX@2QXJ40XJ6Q0P2TY:@0102a/K40[:b/0:b/[02EUID20861P@0408n?S`2FUYH0UYJF
08n?S`80VYZJ00@0Zj^[0:BTY02TY:@0Zj^[0P2e]KD0102NWYh0Zj^[0:^[Z`2^[Zh207inOP0408j>
SP2c/k<0/k>c08j>SP80Z:RX00@0a/K60;Bd]02d];@0^[Zj0P2][Jd0102VYZH0Vi^K09^KV`2IVIT2
04Y:BP0401HF5P051@D01@D500h>3P8030`<00@00P8200h>3P0>3Ph03Ph>0P092@T00`0:2PX01@D5
00D51@0300H61P<01@D500<01`L700H61P061PH00`0:2PX100D51@4000000@000000000300X:2P04
10@010@400<01@D500@020P800D51@051@D010@40P0820P0100410@00@4100410@010@4200P82004
00@410061PH01PH600H61P802@T900@01PH600P8200820P01PH60P0410@010071`L00P8200820P09
2@T200H61P0400d=3@0410@010@400T92@800P8200@01@D500X:2P0:2PX000000P0820P010020P80
10@400@410010@4300@410800P8200@010@401XJ6P0J6QX092@T0P0V9RH0100O7al06a/K01/K6`0`
<30202LW9`0402TY:@0k>c/0>c/k02/[:`803@d=00@02PX:00/;2`0;2`/01PH60P0:2PX010071`L0
3@d=00d=3@0D51@203De=@0404Q8B00V9RH09RHV03Ti>@80Cdm?00@0A4A4055AD@1ADE40De=C0P0m
?Cd0101CDe<0@D510451@@0N7Qh202DU9@0401HF5P061PH01PH600P820801PH600@06ATI03hn?P0n
?Sh0B4Q80P1FEUH0101VIVH0IfMW06MWI`1_Kfl206UYJ@0405ADE01BDU80DU9B04i>CP<05aLG0P0b
<S80100k>c/0<S8b038b<P0T92@202LW9`04038b<P10@400@41004];B`80BDU900@0DU9B05=CD`1C
De<0B4Q80P1?Cdl0101PH600HV9R069RHP1LG5`205QHF00405=CD`1@D500D51@04E5A@80ATI600@0
?clo04Q8B018B4P0BTY:0P0l?3`00`1FEUH0KFe]06e]K@0306e]K@0406a/K01bLW80LW9b07MgM`80
P8200`1aLG40101bLW80JVYZ06YZJP1bLW8207YjNP0407EeM@1SHf<0Hf=S06=SH`80NGUi00@0IVIV
06m_K`1_Kfl0OGem0P1PH600101ZJVX0I6AT06ATI01VIVH205]KF`0404e=C@1DE5@0E5AD06UYJ@80
IfMW00@0GemO05iNGP1NGUh0CTi>0P11@D401010@400E5AD05ADE016ATH202HV9P0404Q8B01MGEd0
GEeM061PH080MgMg00@0L71`05EEE@1EEED0IfMW0P1lO7`0101GEeL0G5aL05aLG01oOgl205eMG@04
04i>CP1NGUh0GUiN055AD@80Cdm?00@0CTi>03Ti>@0i>CT0=SHf0P0`<300100b<S80?Cdm03dm?@1L
G5`206MWI`0405ADE01[Jf/0Jf][04i>CP80<C4a00@0?3`l01/K6`0K6a/06QXJ0P1:BTX0101ZJVX0
LW9b079bLP1SHf<204];B`0404I6AP0g=cL0=cLg03Ph>080EUIF00@0LW9b06m_K`1_Kfl0AdM70P18
B4P01013@d<0<c<c03<c<`14A4@204=3@`040410@013@d<0@d=303Ph>080AdM700@0D51@06=SH`1S
Hf<0U9BD0P2^[Zh0102NWYh0Xj>S0:>SX`2XZ:P30:2PX080XJ6Q00@0VYZJ08f=S@2=SHd0TI6A0P2N
WYh0102_[jl0];Bd0;Bd]02j^[X209NGU`0408f=S@2`/;00/;2`09FEU@80MGEe00@0VIVI0:VYZ@2Y
ZJT0RXZ:0P2c/k<0102i^KT0/K6a0;6a/@2a/K420::RXP040:BTY02CTi<0Ti>C08j>SP80CTi>00@0
51@D00L71`071`L01`L70P092@T010030`<03Ph>00h>3P0;2`/200L71`0400`<300:2PX02PX:0082
0P800`<300@00@4100H61P061PH02`/;0P0=3@d0100820P01PH600H61P030`<200820P0000<02PX:
00@4100410@00`051@D0100820P01@D500D51@0410@200P8200400@410010@400@4100410@8020P8
00@010@400H61P061PH01PH60P092@T010061PH020P800P820061PH200@4100400L71`020P800P82
00T92@801PH600@03@d=00@4100410@02@T90P020P8010051@D02PX:00X:2P00000200P820040082
0P0410@010@400410@<010@40P020P80100410@06QXJ01XJ6P0T92@202HV9P0401lO7`0K6a/06a/K
030`<0809bLW00@0:BTY03/k>`0k>c/0:b/[0P0=3@d0100:2PX02`/;00/;2`061PH200X:2P0400L7
1`0=3@d03@d=01@D5080=CDe00@0B4Q802HV9P0V9RH0>CTi0P1?Cdl01014A4@0DE5A055AD@1CDe<2
03dm?@0405=CD`11@D40@D5101hN7P809BDU00@05QHF00H61P061PH020P80P061PH0100I6AT0?Shn
03hn?P18B4P205IFEP0406IVIP1WIfL0IfMW06m_K`80JFUY00@0E5AD059BDP1BDU80CTi>0`0G5aL2
038b<P0403/k>`0b<S80<S8b02@T90809bLW00@0<S8b0410@010@400Bd];0P19BDT0101BDU80De=C
05=CD`18B4P204m?C`04061PH01RHV80HV9R05aLG080F5QH00@0De=C051@D01@D500ADE50P16ATH0
100o?cl0B4Q804Q8B01:BTX203`l?00305IFEP1]KFd0KFe]00<0KFe]00@0K6a/079bLP1bLW80MgMg
0P20P803075aL@04079bLP1ZJVX0JVYZ079bLP80NWYj00@0MGEe06=SH`1SHf<0Hf=S0P1iNGT0101V
IVH0Kfm_06m_K`1mOGd2061PH00406YZJP1TI6@0I6AT06IVIP80Fe]K00@0CDe=05ADE01DE5@0JFUY
0P1WIfL0101OGel0GUiN05iNGP1>CTh20451@@040410@01DE5@0E5AD04I6AP809RHV00@0B4Q805eM
G@1MGEd0H61P0P1gMgL0101`L700EEEE05EEE@1WIfL207alO00405MGE`1LG5`0G5aL07moO`80GEeM
00@0CTi>05iNGP1NGUh0DE5A0P1?Cdl0101>CTh0>CTi03Ti>@0f=SH2030`<004038b<P0m?Cd0?Cdm
05aLG080IfMW00@0E5AD06][J`1[Jf/0CTi>0P0a<C40100l?3`06a/K01/K6`0J6QX204Y:BP0406YZ
JP1bLW80LW9b06=SH`80Bd];00@0ATI603Lg=`0g=cL0>3Ph0P1FEUH0101bLW80Kfm_06m_K`17AdL2
04Q8B00404=3@`0c<c<0<c<c04A4A080@d=300@0@41004=3@`13@d<0>3Ph0P17AdL0101@D500Hf=S
06=SH`2DU9@20:j^[P0409jNWP2SXj<0Xj>S0:RXZ0<0X:2P0P2QXJ40102JVYX0SHf=08f=S@2ATI42
09jNWP040:n_[`2d];@0];Bd0;Zj^P80UiNG00@0SHf=0;2`/02`/;00UIFE0P1eMGD0102IVIT0ZJVY
0:VYZ@2:RXX20;>c/`040;Vi^@2a/K40/K6a0;6a/@80XZ:R00@0Y:BT09>CT`2CTi<0SXj>0P1>CTh0
100D51@01`L700L71`071`L200T92@0400<30`0>3Ph03Ph>00/;2`801`L700@030`<00X:2P0:2PX0
0P820P030`<010010@401PH600H61P0;2`/200d=3@0400P820061PH01PH600<30`800P8200001009
2@T01PH600H61P0<30`200@4100400P8200<30`030`<00<30`801@D500@02`/;00D51@051@D00`<3
0P071`L0100820P02PX:00X:2P0B4Q8200d=3@0400X:2P061PH01PH600P820803`l?00@020P800<3
0`030`<020P80`00000200@4100400P8200410@010@4000000800@4100@01@D50000000000000@41
0`051@D300@4108020P800@010@401DE5@0E5AD0:BTY0P0S8b<0100K6a/07AdM01dM7@0`<303034a
<@80;Bd]00@08B4Q018B4P0B4Q803`l?0P0;2`/0100820P00@4100410@071`L200h>3P04018B4P10
@400@41004Q8B0808b<S00@0@41004A4A014A4@0>SXj0P0m?Cd0100f=SH0?clo03lo?`10@402028R
8P0401/K6`0D51@051@D01PH60804A4A00@03@d=00T92@092@T05ADE0P0g=cL0101=CDd0HF5Q065Q
H@1ZJVX2065QH@0406IVIP1_Kfl0Kfm_069RHP80F5QH00@0C4a<020P800P82008B4Q0P0_;bl0100V
9RH0<S8b038b<P0U9BD201hN7P0403@d=01@D500D51@04m?C`80@41000@0C4a<05MGE`1GEeL0De=C
0P1BDU80101EEED0EUIF05IFEP1MGEd2069RHP0405UIF@1KFe/0Fe]K05ADE080CDe=00@0BTY:04m?
C`1?Cdl0D51@0P1GEeL0101bLW80MGEe07EeM@1QHF4206e]K@0407YjNP1gMgL0MgMg07=cL`80OWin
00@0LG5a07QhN01hN7P0M7Ad0P1HF5P0101eMGD0QhN708N7Q`1aLG4207QhN0040820P025QHD0QHF5
07EeM@80NGUi00@0P82006UYJ@1YJFT0IFEU0P1ADE40101FEUH0H61P061PH01JFUX205EEE@0406UY
J@1]KFd0KFe]06UYJ@80GEeM00@0DE5A04i>CP1>CTh0EEEE0P1VIVH0101GEeL0E5AD05ADE01/K6`2
069RHP0406IVIP1gMgL0MgMg06=SH`80B4Q800@0CTi>07EeM@1eMGD0LW9b0P1TI6@0101aLG40DE5A
055AD@0a<C4205IFEP0407=cL`1FEUH0EUIF04U9B@80CDe=00@0>3Ph02d];@0];Bd0?Shn0P1?Cdl0
101GEeL0GUiN05iNGP1[Jf/206UYJ@0402XZ:P0a<C40<C4a03Hf=P802PX:00@0<C4a061PH01PH600
Kfm_0P1QHF40101DE5@0DE5A055AD@10@40203Ph>00404M7A`1]KFd0KFe]07inOP80FEUI00@0A4A4
04];B`1;Bd/0@D510`0k>c/303Lg=`80?Shn00@0@T9205YJFP1JFUX0K6a/0P2JVYX0102h^;P0/[:b
0;:b/P2WYjL20:FUY@0409ZJVP2>SXh0SXj>09:BTP80TI6A00@0R8R807EeM@1eMGD0NWYj0P2?Shl0
102RXZ80_;bl0;bl_030`<0207moO`0408n?S`2][Jd0[Jf]08J6QP80RHV900@0^;Rh09jNWP2NWYh0
RHV90P2b/[80102XZ:P0];Bd0;Bd]02^[Zh20:6QX@040;2`/02:RXX0RXZ:07EeM@80DE5A00@051@D
00L71`071`L00`<30P051@D00`061PH02PX:00X:2P0300L71`0400D51@0820P020P800L71`8010@4
0`051@D400<30`<01`L70P051@D0000400D51@061PH01PH600d=3@8010@400@01`L700h>3P0>3Ph0
1`L70`051@D200820P0400<30`092@T02@T900/;2`801`L700@01PH600D51@051@D02`/;0P051@D0
10030`<01PH600H61P071`L200@4100400D51@0410@010@400<30`<010@40P071`L0100410@020P8
00P8200=3@d200<30`0400H61P0820P020P800<30`8010@400@00`<300P8200820P00P820P0D51@0
100b<S809BDU02DU9@0C4a<202d];@0403hn?P13@d<0@d=303@d=080<C4a00<09RHV00h>3P0>3Ph0
0`0=3@d0100820P00`<300<30`0;2`/200`<300401lO7`1;Bd/0Bd];05ADE080A4A400@0ADE503Ti
>@0i>CT0=3@d0P0g=cL0100c<c<0A4A404A4A013@d<202XZ:P04030`<00K6a/06a/K01PH60803Ph>
00@02@T900P8200820P04A4A0P0e=CD0101@D500EUIF05IFEP1IFET205YJFP04061PH01TI6@0I6AT
06MWI`80JVYZ00@0HV9R03/k>`0k>c/07alO0P0P8200100W9bL0@4100410@012@T8202h^;P0402@T
900g=cL0=cLg04A4A080AdM700@0EEEE05=CD`1CDe<0FEUI0P1GEeL01016ATH0Cdm?04m?C`1KFe/2
05QHF0<0CTi>00@0F5QH05aLG01LG5`0FUYJ0P1HF5P0101ADE40D51@051@D01JFUX2075aL@0406YZ
JP1UIFD0IFEU06a/K080OGem00@0Lg=c069RHP1RHV80H61P0P23Ph<0102BTY80Lg=c07=cL`1kNg/2
08N7Q`04065QH@1eMGD0MGEe08^;R`80LW9b0`1_Kfl0101IFET0@D510451@@1YJFT2075aL@04061P
H01KFe/0Fe]K06i^KP80FUYJ00@0EEEE06QXJ01XJ6P0I6AT0P0l?3`0100k>c/0E5AD05ADE01RHV82
055AD@0403Ph>01>CTh0CTi>05YJFP80E5AD00@0JFUY06IVIP1VIVH0EeMG0P1<C4`0101CDe<0L71`
071`L01PH602055AD@04069RHP1>CTh0CTi>03Ph>080EEEE00@0Kfm_055AD@1ADE40ADE50P1NGUh0
101ADE40?Shn03hn?P0`<30203/k>`0405IFEP1@D500D51@05aLG080IFEU00@0ADE504Q8B018B4P0
8b<S0P092@T01015ADD0K6a/06a/K01ZJVX205MGE`0404M7A`14A4@0A4A403Hf=P80@T9200@0D51@
07AdM01dM7@0K6a/0P1=CDd0101<C4`0@T920492@P0n?Sh20492@P04038b<P0a<C40<C4a03Lg=`80
@T9200@0G5aL06][J`1[Jf/0P8200P2[Zj/0102m_Kd0/[:b0;:b/P2VYZH209FEU@0408R8R020P800
P82007IfMP80L71`00@0LW9b055AD@1ADE40EUIF0P2;Rh/0102FUYH0YZJV0:JVYP2EUID206e]K@04
08^;R`2@T900T92@08Z:RP80Xj>S00@0_Kfm096AT@2ATI40SXj>0P2_[jl0102TY:@0/[:b0;:b/P2U
YJD20:ZZZP040;6a/@2@T900T92@07IfMP80EEEE00<071`L00X:2P0:2PX00`061PH010051@D00P82
00820P0<30`300d=3@801@D500@010@400820P020P800@410P051@D0100820P00`<300<30`000002
00@4104030`<0@0:2PX100X:2P0000@01@D500H61P061PH03@d=0P0410@010071`L03Ph>00h>3P07
1`L300D51@800P8200@00`<300T92@092@T02`/;0P071`L010061PH01@D500D51@0;2`/200D51@04
00<30`061PH01PH600L71`8010@400@01@D500@4100410@00`<30`0410@200L71`0400@4100820P0
20P800d=3@800`<300@01PH600P8200820P00`<30P0410@010030`<020P800P820020P8201@D5004
038b<P0U9BD09BDU01<C4`80;Bd]00@0?Shn04=3@`13@d<0=3@d0P0a<C400`0V9RH03Ph>00h>3P03
00d=3@0400P820030`<00`<300/;2`8030`<00@07alO04];B`1;Bd/0E5AD0P14A4@01015ADD0>CTi
03Ti>@0d=3@203Lg=`0403<c<`14A4@0A4A404=3@`80:RXZ00@0<30`01/K6`0K6a/061PH0P0>3Ph0
10092@T020P800P8200A4A4203De=@04051@D01FEUH0EUIF05UIF@80FUYJ00@0H61P06ATI01TI6@0
IfMW0P1ZJVX0101RHV80>c/k03/k>`0O7al2020P800402LW9`10@400@4100492@P80;Rh^00@092@T
03Lg=`0g=cL0A4A40P17AdL0101EEED0De=C05=CD`1IFET205MGE`0404I6AP1?Cdl0Cdm?05]KF`80
F5QH0`1>CTh0101HF5P0G5aL05aLG01JFUX205QHF004055AD@1@D500D51@05YJFP80LG5a00@0JVYZ
06EUI@1UIFD0K6a/0P1mOGd0101cLg<0HV9R069RHP1PH60208>3P`0409:BTP1cLg<0Lg=c07]kN`80
QhN700@0HF5Q07EeM@1eMGD0Rh^;0P1bLW8306m_K`0405UIF@11@D40@D5106UYJ@80LG5a00@0H61P
05]KF`1KFe/0KVi^0P1JFUX0101EEED0J6QX06QXJ01TI6@203`l?00403/k>`1DE5@0E5AD069RHP80
DE5A00@0>3Ph04i>CP1>CTh0FUYJ0P1DE5@0101YJFT0IVIV06IVIP1GEeL204a<C00405=CD`1`L700
L71`061PH080DE5A00@0HV9R04i>CP1>CTh0>3Ph0P1EEED0101_Kfl0DE5A055AD@15ADD205iNGP04
055AD@0n?Sh0?Shn030`<080>c/k00@0EUIF051@D01@D500G5aL0P1UIFD01015ADD0B4Q804Q8B00S
8b<200T92@0404E5A@1/K6`0K6a/06YZJP80EeMG00@0AdM704A4A014A4@0=SHf0P12@T80101@D500
M7Ad07AdM01/K6`204e=C@0404a<C012@T80@T9203hn?P80@T9200@0<S8b034a<@0a<C40=cLg0P12
@T80101LG5`0Jf][06][J`20P8020:^[Z`040;fm_@2b/[80/[:b0:JVYP80UIFE00@0R8R80820P020
P800MWIf0P1`L700101bLW80DE5A055AD@1FEUH208^;R`0409JFUP2VYZH0YZJV09FEU@80KFe]00@0
Rh^;092@T02@T900RXZ:0P2SXj<0102m_Kd0TI6A096AT@2>SXh20:n_[`040:BTY02b/[80/[:b0:FU
Y@80ZZZZ00@0/K6a092@T02@T900MWIf0P1EEED00`0L71`02PX:00X:2P0300H61P0400D51@020P80
0P8200`<30<03@d=0P051@D0100410@00P8200820P010@4200D51@0400P820030`<00`<300000080
10@40@0<30`100X:2P402PX:000300H61P0400L71`010@400@4100410@8020P800@02@T900/;2`0;
2`/000000P030`<010020P8020P800P8200>3Ph200X:2P0400L71`0>3Ph03Ph>00X:2P801PH600@0
2PX:0000000000000P820P010@40100410@00P8200820P071`L200D51@0300L71`0820P020P800<0
1PH600@020P80000000000000@410P030`<010010@4020P800P820030`<200D51@0400L71`0C4a<0
4a<C02XZ:P80:2PX00@07QhN03Hf=P0f=SH0>c/k0P0o?cl0100`<300=3@d03@d=00U9BD200/;2`04
00`<300@4100410@00/;2`802@T900@02PX:00`<300<30`0<30`0P0o?cl0100m?Cd0=3@d03@d=013
@d<20492@P04038b<P0d=3@0=3@d04Y:BP80A4A400@0Bd];04E5A@15ADD0<30`0P0K6a/0100A4A40
2`/;00/;2`061PH200@4100401LG5`0i>CT0>CTi05IFEP80EEEE0`1FEUH0101EEED0FUYJ05YJFP1W
IfL306QXJ080JVYZ00@0>c/k01PH600H61P09bLW0P0l?3`0100k>c/0;Rh^02h^;P0U9BD203dm?@04
05ADE01?Cdl0Cdm?04U9B@80@41000@0D51@065QH@1QHF40Cdm?0P1:BTX00`1?Cdl0Bd];04];B`03
04];B`0404Y:BP1EEED0EEEE05aLG080Fe]K0`1LG5`0101GEeL0G5aL05aLG01VIVH207AdM003075a
L@1mOGd0OGem00<0OWin00@0P82007emO@1mOGd0RHV90P26QXH0101nOWh0P8200820P01eMGD208Z:
RP0408R8R01SHf<0Hf=S0861P@80MgMg00@0GEeM06=SH`1SHf<0KFe]0P1`L700101kNg/0L71`071`
L01ZJVX205IFEP0406QXJ022PX80PX:205]KF`80B4Q800@0Hf=S06UYJ@1YJFT0C4a<0P0n?Sh0101>
CTh0I6AT06ATI01OGel206][J`040820P01HF5P0F5QH04e=C@80KFe]00@0K6a/059BDP1BDU80=cLg
0P10@400101;Bd/0@4100410@01>CTh2079bLP040820P01UIFD0IFEU05=CD`80F5QH00@0De=C04m?
C`1?Cdl0BTY:0P0];Bd0100c<c<0=SHf03Hf=P17AdL205aLG004059BDP0g=cL0=cLg010@4080=3@d
00@0FEUI06ATI01TI6@0D51@0P19BDT0100k>c/0<30`030`<015ADD205]KF`04065QH@1oOgl0Ogmo
061PH080ATI600@0Bd];0410@010@400?Shn0P0g=cL0100Z:RX0>3Ph03Ph>013@d<2059BDP0406AT
I01`L700L71`09RHV080Xj>S00@0YJFU0:ZZZP2ZZZX0X:2P0P2FUYH0101hN7P0GEeM05eMG@14A4@2
03De=@04034a<@0G5aL05aLG03Hf=P80MgMg00@0VYZJ09jNWP2NWYh0RXZ:0P2=SHd0102CTi<0R8R8
08R8R02JVYX20;>c/`040:n_[`29RHT0RHV909fMW@80/k>c00@0ZZZZ0:JVYP2VYZH0X:2P0P2e]KD0
102JVYX0UIFE09FEU@24Q8@204a<C00401HF5P0;2`/02`/;00D51@802@T900@02PX:00T92@092@T0
3@d=0P010@40100<30`01`L700L71`0:2PX200h>3P0400@4100820P020P800d=3@802`/;00@01PH6
00@4100410@01`L70P030`<000<00P8200<03Ph>00/;2`0;2`/010051@D200<30`0400410@020P80
0P8200410@800`<300@020P800T92@092@T01@D50P0A4A4010051@D01PH600H61P0:2PX200410@04
00@410030`<00`<300D51@801PH600<010@400T92@092@T00`0410@0100820P00000000000020P82
00410@0400820P051@D01@D500<30`801@D500@01`L700@4100410@01PH60P0H61P0100W9bL092@T
02@T900_;bl203Lg=`0403Hf=P0k>c/0>c/k03@d=080;2`/00@04a<C00`<300<30`03@d=0P020P80
100000001PH600H61P00000200<30`0402XZ:P13@d<0@d=303De=@80=SHf00@0@D5104A4A014A4@0
ADE50P0i>CT01015ADD0>c/k03/k>`0h>3P202LW9`04018B4P0E5AD05ADE00L71`801PH600@01@D5
00X:2P0:2PX061PH0P0i>CT0101EEED0F5QH05QHF01GEeL206=SH`0405mOG`1FEUH0EUIF061PH080
J6QX00@0Jf][07AdM01dM7@0GUiN0P0[:b/0100X:2P0=CDe03De=@0X:2P202TY:@0403De=@14A4@0
A4A404i>CP80BTY:00@0B4Q804M7A`17AdL0DE5A0P1MGEd0101?Cdl0ADE504E5A@1ADE42051@D004
04E5A@16ATH0ATI604i>CP80F5QH00@0DU9B04U9B@19BDT0FEUI0P1LG5`0101EEED0GemO05mOG`1Q
HF42079bLP0407MgM`1iNGT0NGUi07emO@80P82000@0PX:207UiN@1iNGT0PH610P24Q8@01021PH40
Rh^;08^;R`1jNWX20820P00407=cL`1KFe/0Fe]K079bLP80EEEE00@0E5AD06YZJP1ZJVX0KFe]0P1Y
JFT0101ZJVX0G5aL05aLG01=CDd205aLG00406ATI01OGel0GemO04];B`80JVYZ00@0NGUi061PH01P
H600@d=30P1=CDd0101HF5P0DE5A055AD@1EEED205eMG@0406UYJ@1=CDd0CDe=04m?C`80JFUY00@0
KFe]07AdM01dM7@0Fe]K0P0g=cL0100k>c/0GEeM05eMG@1[Jf/206i^KP0407=cL`1[Jf/0Jf][06m_
K`80Jf][00@0F5QH04Q8B018B4P0B4Q80P0Q8B4010061PH05QHF01HF5P0P820201/K6`0402l_;`0K
6a/06a/K01TI6@80B4Q800@0EEEE055AD@1ADE40A4A40`0i>CT203dm?@04065QH@1RHV80HV9R075a
L@80LW9b00@0Bd];03/k>`0k>c/0>c/k0P0n?Sh0100f=SH09RHV02HV9P0/;2`203lo?`0404i>CP1V
IVH0IVIV07]kN`80QhN700@0Z:RX0::RXP2RXZ80YZJV0P2YZJT0102<S8`0TY:B09:BTP20P802059B
DP0402@T900>3Ph03Ph>01HF5P80410@00@09RHV07alO01lO7`0Xj>S0P1oOgl0102:RXX0Y:BT0:BT
Y02XZ:P20:j^[P<0/;2`00@0Y:BT08n?S`2?Shl0Y:BT0P2`/;00102WYjL0VIVI09VIV@2][Jd20;jn
_P0408Z:RP2>SXh0SXj>08F5Q@80@41000@03Ph>00<30`030`<000000P0<30`010071`L02PX:00X:
2P061PH200@4100400h>3P051@D01@D500D51@802@T900@01`L700D51@051@D02`/;0P0=3@d01005
1@D020P800P8200410@200T92@000`020P800`0>3Ph02`/;00/;2`0400D51@800`<300@00@410082
0P020P800@410P030`<0100820P02@T900T92@051@D2014A4@0400D51@061PH01PH600X:2P800@41
00@010@400<30`030`<01@D50P061PH00`0410@02@T900T92@0300@4100400P82000000000000082
0P800@4100@00P8200D51@051@D00`<30P051@D010071`L010@400@410061PH201PH600402LW9`0T
92@092@T02l_;`80=cLg00@0=SHf03/k>`0k>c/0=3@d0P0/;2`0100C4a<030`<00`<300=3@d20082
0P04000000061PH01PH6000000800`<300@0:RXZ04=3@`13@d<0=CDe0P0f=SH01011@D40A4A404A4
A015ADD203Ti>@0404E5A@0k>c/0>c/k03Ph>0809bLW00@04Q8B01DE5@0E5AD01`L70P061PH01005
1@D02PX:00X:2P0H61P203Ti>@0405EEE@1HF5P0F5QH05MGE`80Hf=S00@0GemO05IFEP1FEUH0H61P
0P1XJ6P0101[Jf/0M7Ad07AdM01NGUh202/[:`0402PX:00e=CD0=CDe02PX:080:BTY00@0=CDe04A4
A014A4@0CTi>0P1:BTX01018B4P0AdM704M7A`1ADE4205eMG@0404m?C`15ADD0ADE5055AD@80D51@
00@0ADE504I6AP16ATH0CTi>0P1HF5P0101BDU80BDU904U9B@1IFET205aLG00405EEE@1OGel0GemO
065QH@80LW9b00@0MgMg07UiN@1iNGT0OGem0P20P8001022PX80NGUi07UiN@21PH4208B4Q0040861
P@2;Rh/0Rh^;07YjNP80P82000@0Lg=c05]KF`1KFe/0LW9b0P1EEED0101DE5@0JVYZ06YZJP1]KFd2
06UYJ@0406YZJP1LG5`0G5aL04e=C@80G5aL00@0I6AT05mOG`1OGel0Bd];0P1ZJVX0101iNGT0H61P
061PH013@d<204e=C@0405QHF01ADE40DE5A05EEE@80GEeM00@0JFUY04e=C@1=CDd0Cdm?0P1YJFT0
101]KFd0M7Ad07AdM01KFe/203Lg=`0403/k>`1MGEd0GEeM06][J`80KVi^00@0Lg=c06][J`1[Jf/0
Kfm_0P1[Jf/0101HF5P0B4Q804Q8B018B4P2024Q8@0400H61P0F5QH05QHF020P80806a/K00@0;bl_
01/K6`0K6a/06ATI0P18B4P0101EEED0DE5A055AD@14A4@303Ti>@80?Cdm00@0HF5Q069RHP1RHV80
LG5a0P1bLW80101;Bd/0>c/k03/k>`0k>c/203hn?P0403Hf=P0V9RH09RHV02`/;080?clo00@0CTi>
06IVIP1VIVH0Ng]k0P27QhL0102XZ:P0XZ:R0::RXP2VYZH20:VYZ@0408b<S02BTY80TY:B0820P080
DU9B00@092@T00h>3P0>3Ph05QHF0P0@4100100V9RH0O7al07alO02SXj<207moO`0408Z:RP2TY:@0
Y:BT0:RXZ080[Zj^0`2`/;00102TY:@0Shn?08n?S`2TY:@20;2`/0040:NWY`2IVIT0VIVI0:f][@80
_[jn00@0RXZ:08j>SP2>SXh0QHF50P10@400100>3Ph00`<300<30`00000200`<300400L71`0:2PX0
2PX:00H61P8010@400@03Ph>00D51@051@D01@D50P092@T010071`L01@D500D51@0;2`/200d=3@04
00D51@0820P020P800@410802@T900000`061PH02PX:00X:2P0300@41004000000030`<00`<300L7
1`8010@400@01@D50000000000001`L70P0:2PX300P8200300L71`092@T02@T900<01`L700@00P82
00@4100410@00P820P0410@010051@D010@400@4100820P200h>3P0400P820092@T02@T900X:2P80
1PH600@00P8200L71`071`L010@40P00000010030`<01`L700L71`030`<200@4100400T92@0@4100
410@020P80807QhN00@0:2PX02`/;00/;2`0=cLg0P0a<C40100^;Rh0:RXZ02XZ:P0A4A4300@41080
1@D500@0000000<30`030`<00P820P071`L0100/;2`0BDU904U9B@0d=3@203dm?@0403Xj>P0e=CD0
=CDe03dm?@80;Rh^00@09bLW03Hf=P0f=SH0>3Ph0P0Y:BT300d=3@0300L71`061PH01PH600<01@D5
00@06a/K04M7A`17AdL0G5aL0P1EEED0101ADE40IVIV06IVIP1TI6@2059BDP0405ADE01PH600H61P
06m_K`80NWYj00@0IFEU03@d=00d=3@0:BTY0P0n?Sh0100a<C40<c<c03<c<`0l?3`203/k>`0403hn
?P16ATH0ATI605EEE@80DU9B00@0DE5A05YJFP1JFUX0DU9B0P17AdL0101:BTX0DE5A055AD@1=CDd2
055AD@0406=SH`1LG5`0G5aL04U9B@80C4a<00@0F5QH06MWI`1WIfL0JVYZ0P1YJFT0101NGUh0JVYZ
06YZJP1gMgL2079bLP0406a/K01TI6@0I6AT06][J`80N7Qh00@0O7al06UYJ@1YJFT0O7al0P2LW9`0
101ZJVX0MWIf07IfMP1NGUh204U9B@04079bLP19BDT0BDU904E5A@80EUIF00@0I6AT065QH@1QHF40
Fe]K0P1XJ6P0101TI6@0Hf=S06=SH`1>CTh204a<C0040492@P1>CTh0CTi>05ADE080Cdm?00@0GEeM
06UYJ@1YJFT0CTi>0P0g=cL0101DE5@0IVIV06IVIP1OGel20451@@0404Y:BP1IFET0FEUI05eMG@80
OGem00@0Jf][03Xj>P0j>SX0@D510P1UIFD0101DE5@0Bd];04];B`1ZJVX206MWI`0405UIF@18B4P0
B4Q803Ph>080<c<c00@0;Bd]024Q8@0Q8B407AdM0P0=3@d0100J6QX0:RXZ02XZ:P1BDU8204Y:BP04
03Xj>P1BDU80DU9B04e=C@80?clo00@0=3@d030`<00`<300?Shn0P1CDe<0101UIFD0FEUI05UIF@1g
MgL205iNGP040410@015ADD0ADE50451@@80?3`l00@0:RXZ02/[:`0[:b/0@D510P19BDT0101TI6@0
NWYj07YjNP2CTi<20:RXZ0040;6a/@2WYjL0YjNW0;Jf]P80[jn_00@0Ph>307MgM`1gMgL0LW9b0P1/
K6`01010@400;2`/02`/;00/;2`203De=@0405EEE@2FUYH0UYJF09RHV080KVi^00@0T92@0:b/[02/
[:`0[jn_0P2ZZZX0102c/k<0/K6a0;6a/@2OWil208Z:RP0409VIV@2VYZH0YZJV0:6QX@80WinO00@0
/k>c0:ZZZP2ZZZX0OGem0P28R8P0101hN7P0=cLg03Lg=`0E5AD200H61P0400<30`0:2PX02PX:00P8
20803`l?00@03@d=00T92@092@T01PH60P071`L0100410@00000000000030`<300X:2P8010@40`08
20P100`<30402@T90@092@T0000400X:2P0820P020P800820P801`L700@01@D500@4100410@01@D5
0P0410@010010@4020P800P8200?3`l200P82004000000030`<00`<300<30`800@4100@02@T900@4
100410@00`<30P061PH0100820P02PX:00X:2P051@D20000000400410@092@T02@T900X:2P<00P82
0P051@D010092@T030`<00`<30030`<200820P0400@4100:2PX02PX:00820P802@T900@03@d=02<S
8`0S8b<0:RXZ0P0W9bL0100Z:RX0;Rh^02h^;P0j>SX2038b<P0402HV9P0I6AT06ATI00/;2`800P82
00@01`L700/;2`0;2`/01@D50P0410@010061PH06QXJ01XJ6P0[:b/20410@00403`l?018B4P0B4Q8
0410@080=3@d00@0;Bd]02h^;P0^;Rh0:RXZ0P0`<300100P82009bLW02LW9`0H61P200/;2`0400H6
1P092@T02@T900P8208010@400@07AdM04I6AP16ATH0G5aL0P1HF5P0101FEUH0I6AT06ATI01WIfL2
05aLG00405UIF@1UIFD0IFEU07QhN080M7Ad00@0GEeM04U9B@19BDT0=CDe0`0g=cL203`l?00403Xj
>P0m?Cd0?Cdm04=3@`80Bd];00@0EUIF0451@@11@D40@4100P1EEED0101=CDd0@D510451@@12@T82
04Q8B00404e=C@1BDU80DU9B05eMG@80De=C00@0CDe=05ADE01DE5@0CDe=0P1QHF40101_Kfl0JVYZ
06YZJP1/K6`207YjNP04075aL@1UIFD0IFEU06=SH`80Kfm_00@0MWIf07inOP1nOWh0Ng]k0P1YJFT0
101]KFd0Rh^;08^;R`1hN7P208:2PP0406][J`1FEUH0EUIF08f=S@80Ng]k00@0HF5Q05mOG`1OGel0
Kfm_0P1cLg<0101iNGT0RHV908V9R@1fMWH205EEE@0404Y:BP1VIVH0IVIV05IFEP80F5QH00@0EEEE
04A4A014A4@0Fe]K0P1EEED01011@D40@4100410@01HF5P206=SH`0406a/K01RHV80HV9R06=SH`80
FUYJ00@0AdM705YJFP1JFUX0Cdm?0P0c<c<01010@400G5aL05aLG01JFUX204a<C00405MGE`1RHV80
HV9R05MGE`80?3`l00@09BDU028R8P0R8R80=CDe0P10@400100i>CT0@D510451@@1[Jf/2069RHP04
061PH01GEeL0EeMG04I6AP80D51@00@0@d=303Ph>00h>3P0=CDe0P14A4@0101@D500J6QX06QXJ01Q
HF4206=SH`04071`L01=CDd0CDe=04A4A0<0@4100P0j>SX0100[:b/0>SXj03Xj>P1HF5P205]KF`04
07UiN@2DU9@0U9BD0:NWY`80/K6a00@0ZJVY09ZJVP2JVYX0[Jf]0P2EUID0101bLW80Hf=S06=SH`11
@D4204i>CP04065QH@1iNGT0NGUi08j>SP80YZJV00@0Y:BT0:RXZ02XZ:P0U9BD0P2GUiL0102ZZZX0
[Jf]0:f][@2_[jl20:RXZ0040;6a/@2g]kL0]kNg09fMW@80O7al00@0UIFE09ZJVP2JVYX0V9RH0P2[
Zj/00`2^[Zh0YZJV0:JVYP0309RHV00406=SH`0Q8B408B4Q00/;2`803`l?00@01`L700410@010@40
1`L70P0F5QH0100G5aL03@d=00d=3@0410@200h>3P0400T92@030`<00`<3000000<020P80P0410@0
100820P01`L700L71`0410@200P8200000@02PX:00P8200820P00P820P071`L010051@D010@400@4
10051@D200@4100400410@0820P020P800l?3`8020P800@0000000<30`030`<00`<30P010@401009
2@T010@400@410030`<200H61P0400P8200:2PX02PX:00D51@80000000@00@4100T92@092@T02PX:
0`020P8200D51@0400T92@0<30`030`<00<30`800P8200@010@400X:2P0:2PX00P820P092@T0100=
3@d08b<S02<S8`0Z:RX202LW9`0402XZ:P0^;Rh0;Rh^03Xj>P80<S8b00@09RHV01TI6@0I6AT02`/;
0P020P8010071`L02`/;00/;2`051@D200@4100400H61P0J6QX06QXJ02/[:`80@41000@0?3`l04Q8
B018B4P0@4100P0d=3@0100];Bd0;Rh^02h^;P0Z:RX2030`<004020P800W9bL09bLW01PH60802`/;
00@01PH600T92@092@T020P80P0410@0100M7Ad0ATI604I6AP1LG5`205QHF00405IFEP1TI6@0I6AT
06MWI`80G5aL00@0FEUI06EUI@1UIFD0N7Qh0P1dM7@0101MGEd0BDU904U9B@0e=CD303Lg=`80?3`l
00@0>SXj03dm?@0m?Cd0@d=30P1;Bd/0101FEUH0@D510451@@10@40205EEE@0404e=C@11@D40@D51
0492@P80B4Q800@0CDe=059BDP1BDU80GEeM0P1CDe<0101=CDd0E5AD05ADE01=CDd2065QH@0406m_
K`1ZJVX0JVYZ06a/K080NWYj00@0LG5a06EUI@1UIFD0Hf=S0P1_Kfl0101fMWH0OWin07inOP1kNg/2
06UYJ@0406e]K@2;Rh/0Rh^;07QhN080PX:200@0Jf][05IFEP1FEUH0SHf=0P1kNg/0101QHF40GemO
05mOG`1_Kfl207=cL`0407UiN@29RHT0RHV907IfMP80EEEE00@0BTY:06IVIP1VIVH0EUIF0P1HF5P0
101EEED0A4A404A4A01KFe/205EEE@040451@@10@400@41005QHF080Hf=S00@0K6a/069RHP1RHV80
Hf=S0P1JFUX01017AdL0FUYJ05YJFP1?Cdl203<c<`040410@01LG5`0G5aL05YJFP80C4a<00@0EeMG
069RHP1RHV80EeMG0P0l?3`0100U9BD08R8R028R8P0e=CD20410@00403Ti>@11@D40@D5106][J`80
HV9R00@0H61P05MGE`1GEeL0ATI60P1@D5001013@d<0>3Ph03Ph>00e=CD204A4A004051@D01XJ6P0
J6QX065QH@80Hf=S00@0L71`04e=C@1=CDd0A4A40`10@40203Xj>P0402/[:`0j>SX0>SXj05QHF080
Fe]K00@0NGUi09BDU02DU9@0YjNW0P2a/K40102YZJT0VYZJ09ZJVP2][Jd209FEU@04079bLP1SHf<0
Hf=S0451@@80CTi>00@0HF5Q07UiN@1iNGT0SXj>0P2VYZH0102TY:@0Z:RX0:RXZ02DU9@209NGU`04
0:ZZZP2][Jd0[Jf]0:n_[`80Z:RX00@0/K6a0;Ng]`2g]kL0WIfM0P1lO7`0102EUID0VYZJ09ZJVP2H
V9P20:^[Z`030:j^[P2VYZH0YZJV00<0V9RH00@0Hf=S024Q8@0Q8B402`/;0P0?3`l010071`L00@41
00410@071`L201HF5P0401LG5`0=3@d03@d=00@410803Ph>00@02@T900<30`030`<000000`0820P2
00@4100400P820071`L01`L700@4108020P80000100820P01@D500D51@051@D200H61P0400@41003
0`<00`<300<30`801PH600@010@400P8200820P00`<30P000000100410@03@d=00d=3@0;2`/200<3
0`<01@D500@01PH600/;2`0;2`/030`<0P071`L300820P0400X:2P092@T02@T900410@801@D50`04
10@010092@T01@D500D51@010@4200`<300400@410092@T02@T900@410802PX:00@030`<02/[:`0[
:b/0:BTY0P0N7Qh0100R8R80=3@d03@d=00d=3@202`/;004020P80061PH01PH60000008020P800@0
1@D500@4100410@01PH60P0;2`/00`051@D08b<S02<S8`0302h^;P0403Ti>@0o?cl0?clo0492@P80
>3Ph00@071`L02LW9`0W9bL0=3@d0P0^;Rh0100E5AD03`l?00l?3`0;2`/200X:2P0400D51@010@40
0@4100410@802`/;00@08B4Q0410@010@400EeMG0P1JFUX0101HF5P0IfMW06MWI`1ZJVX205eMG@04
05YJFP1TI6@0I6AT0820P080O7al00@0IVIV05EEE@1EEED0ADE50P0Z:RX0100_;bl0?Cdm03dm?@0k
>c/20492@P0404I6AP14A4@0A4A404Q8B080@41000@0@d=304m?C`1?Cdl0A4A40P15ADD0101:BTX0
>c/k03/k>`11@D4205eMG@0406UYJ@1PH600H61P05QHF080CTi>00@0BTY:055AD@1ADE40G5aL0P1]
KFd0101jNWX0O7al07alO01VIVH207UiN@0408F5Q@2;Rh/0Rh^;08V9R@80MGEe00@0KFe]08F5Q@25
QHD0NWYj0P1fMWH01020P800MWIf07IfMP1aLG4205iNGP0406][J`1;Bd/0Bd];03<c<`80FEUI0`1n
OWh0101^KVh0M7Ad07AdM01KFe/205MGE`0406EUI@1^KVh0KVi^05YJFP80H61P00@0CDe=03Ph>00h
>3P0EUIF0P1;Bd/0100n?Sh0BDU904U9B@1LG5`2055AD@0406=SH`1cLg<0Lg=c05mOG`80HF5Q00@0
M7Ad06UYJ@1YJFT0ADE50P0_;bl0100o?cl0IFEU06EUI@1hN7P206a/K004059BDP1=CDd0CDe=03`l
?08092@T00@08b<S02HV9P0V9RH0DE5A0P1HF5P0101IFET0FUYJ05YJFP1VIVH206MWI`0405iNGP1=
CDd0CDe=0410@080?3`l00@0:b/[03De=@0e=CD0De=C0P1RHV80101`L700Ogmo07moO`1]KFd207mo
O`0406=SH`0k>c/0>c/k04U9B@80@4100`0n?Sh01011@D40BTY:04Y:BP1RHV8207UiN@0409FEU@2[
Zj/0Zj^[0:RXZ080Y:BT00@0XJ6Q09bLW02LW9`0/;2`0P2?Shl0101eMGD0J6QX06QXJ00S8b<201XJ
6P0404=3@`1oOgl0Ogmo09NGU`80Shn?00@0Xj>S0:FUY@2UYJD0TI6A0P2[Zj/0102f][H0[Jf]0:f]
[@2VYZH20:f][@040;6a/@2d];@0];Bd08j>SP80MgMg00@0XZ:R0:FUY@2UYJD0XJ6Q0P2`/;00102S
Xj<0XZ:R0::RXP2XZ:P209fMW@04059BDP0D51@051@D00L71`802`/;00@01PH600D51@051@D030`<
1@0?3`l0100820P0410@010@400;2`/200@4100400L71`051@D01@D500P820802PX:00@00@410082
0P020P800P820P092@T0000300820P061PH01PH600<02@T900@01@D500<30`030`<02@T90P030`<0
100410@02@T900T92@051@D200L71`0400T92@0?3`l03`l?00X:2P802@T900@02PX:000000000000
00000P051@D0100820P01@D500D51@051@D200@4100400`<300;2`/02`/;00<30`801@D500@02`/;
00P8200820P000000`051@D200H61P0300D51@071`L01`L700<01PH600@03Ph>02TY:@0Y:BT08b<S
0P0>3Ph0100U9BD0?3`l03`l?00a<C4202HV9P04020P80071`L01`L700<30`800P8200@010@40041
0@010@401@D50P0>3Ph00`0820P09bLW02LW9`0303Lg=`0404Y:BP11@D40@D510410@080A4A400@0
9RHV028R8P0R8R809bLW0P0H61P300l?3`0400d=3@051@D01@D500@410801PH600@01`L700l?3`0?
3`l0:RXZ0P17AdL0101CDe<0EUIF05IFEP1GEeL206][J`0406UYJ@1NGUh0GUiN05UIF@80H61P00@0
N7Qh07YjNP1jNWX0L71`0P1NGUh01015ADD06QXJ01XJ6P0V9RH20451@@0403hn?P0m?Cd0?Cdm03/k
>`80@41000@0DU9B05EEE@1EEED0EEEE0P1IFET0101CDe<0EEEE05EEE@1CDe<20492@P0404I6AP1I
FET0FEUI05mOG`80Fe]K00<0E5AD04m?C`1?Cdl00`1GEeL0101UIFD0NWYj07YjNP1fMWH207inOP04
06MWI`1`L700L71`07inOP80NWYj00@0QHF506e]K@1]KFd0KFe]0P29RHT00`2;Rh/0LW9b079bLP03
06UYJ@0407]kN`1iNGT0NGUi069RHP<0AdM70P1[Jf/01020P800IFEU06EUI@1BDU8206ATI00405iN
GP1OGel0GemO06ATI080HV9R00@0A4A404U9B@19BDT0DU9B0P0k>c/01018B4P0CTi>04i>CP1DE5@2
05UIF@0407QhN025QHD0QHF5071`L080GemO00@0C4a<055AD@1ADE40D51@0P0f=SH0100i>CT0<c<c
03<c<`0[:b/204Q8B00406=SH`1WIfL0IfMW04A4A080;Bd]00@06QXJ00D51@051@D09RHV0P1=CDd0
101PH600IFEU06EUI@1aLG4205iNGP@0Bd];0P0j>SX0100[:b/0820P020P800S8b<204E5A@04075a
L@1fMWH0MWIf08N7Q`80PH6100@0MWIf08>3P`23Ph<0GEeM0P10@400101=CDd0BDU904U9B@1;Bd/2
05YJFP<0Hf=S00@0MgMg09RHV02HV9P0YJFU0P2/[:`30::RXP040:6QX@2FUYH0UYJF09fMW@80TY:B
00@0Xj>S09^KV`2KVi/0FEUI0P1HF5P0101SHf<0NWYj07YjNP20P80207MgM`0409VIV@2GUiL0UiNG
0:6QX@<0[Jf]0P2[Zj/0102/[:`0_Kfm0;fm_@2k^k/20:^[Z`0408J6QP2:RXX0RXZ:0:b/[0<0Y:BT
0P2XZ:P0102MWId0WinO09nOW`2IVIT208F5Q@0404e=C@0M7Ad07AdM00L71`D02PX:0`0;2`/01006
1PH01@D500D51@071`L300T92@800`<300@030`<00D51@051@D01`L70P051@D010020P801PH600H6
1P092@T200@4100000<00P8200H61P061PH00`092@T010051@D00`<300<30`092@T200<30`0400@4
10092@T02@T900D51@801`L700@02@T900l?3`0?3`l02PX:0P092@T0100:2PX00000000000000002
00D51@0400P820051@D01@D500D51@8010@400@030`<00/;2`0;2`/00`<30P051@D0100;2`/020P8
00P82000000300D51@801PH600<01@D500L71`071`L00`061PH0100>3Ph0:BTY02TY:@0S8b<200h>
3P0402DU9@0l?3`0?3`l034a<@809RHV00@0820P00L71`071`L00`<30P020P80100410@00@410041
0@051@D200h>3P0300P8200W9bL09bLW00<0=cLg00@0BTY:0451@@11@D40@4100P14A4@0100V9RH0
8R8R028R8P0W9bL201PH60<03`l?00@03@d=00D51@051@D010@40P061PH010071`L03`l?00l?3`0Z
:RX204M7A`0405=CD`1FEUH0EUIF05MGE`80Jf][00@0JFUY05iNGP1NGUh0FEUI0P1PH600101hN7P0
NWYj07YjNP1`L70205iNGP0404E5A@0J6QX06QXJ02HV9P80@D5100@0?Shn03dm?@0m?Cd0>c/k0P10
@400101BDU80EEEE05EEE@1EEED205UIF@0405=CD`1EEED0EEEE05=CD`80@T9200@0ATI605UIF@1I
FET0GemO0P1KFe/00`1DE5@0Cdm?04m?C`0305MGE`0406EUI@1jNWX0NWYj07IfMP80OWin00@0IfMW
071`L01`L700OWin0P1jNWX01025QHD0KFe]06e]K@1]KFd208V9R@0308^;R`1bLW80LW9b00<0JFUY
00@0Ng]k07UiN@1iNGT0HV9R0`17AdL206][J`040820P01UIFD0IFEU059BDP80I6AT00@0GUiN05mO
G`1OGel0I6AT0P1RHV801014A4@0BDU904U9B@1BDU8203/k>`0404Q8B01>CTh0CTi>05ADE080FEUI
00@0N7Qh08F5Q@25QHD0L71`0P1OGel0101<C4`0DE5A055AD@1@D50203Hf=P0403Ti>@0c<c<0<c<c
02/[:`80B4Q800@0Hf=S06MWI`1WIfL0A4A40P0];Bd0100J6QX01@D500D51@0V9RH204e=C@04061P
H01UIFD0IFEU075aL@80GUiN101;Bd/203Xj>P0402/[:`0P8200820P02<S8`80ADE500@0LG5a07If
MP1fMWH0QhN70P21PH40101fMWH0Ph>308>3P`1MGEd20410@00404e=C@19BDT0BDU904];B`80FUYJ
0`1SHf<0101gMgL0V9RH09RHV02UYJD20:b/[0<0XZ:R00@0XJ6Q09JFUP2FUYH0WIfM0P2BTY80102S
Xj<0Vi^K09^KV`1IFET205QHF00406=SH`1jNWX0NWYj0820P080MgMg00@0VIVI09NGU`2GUiL0XJ6Q
0`2][Jd20:^[Z`040:b/[02m_Kd0_Kfm0;^k^`80Zj^[00@0QXJ608Z:RP2:RXX0[:b/0`2TY:@20:RX
Z00409fMW@2OWil0WinO09VIV@80QHF500@0CDe=01dM7@0M7Ad01`L71@0:2PX300/;2`0400H61P05
1@D01@D500L71`<02@T90P030`<0100<30`01@D500D51@071`L200D51@0400820P061PH01PH600T9
2@8010@40000100820P03@d=00d=3@010@4200820P<01PH600@010@400D51@051@D030`<0P061PH0
10010@401@D500D51@092@T200D51@04000000051@D01@D500P820801PH600@00@4100L71`071`L0
4A4A0P051@D0100410@01`L700L71`0410@200H61P0400@410051@D01@D500@410800`<300@00@41
00@4100410@02`/;0P0410@010071`L010@400@410061PH200L71`04014A4@0X:2P0:2PX028R8P80
61PH00@0=3@d03Ph>00h>3P0>c/k0P0d=3@0100Y:BT02@T900T92@071`L200D51@0400820P061PH0
1PH600D51@802PX:00@04A4A028R8P0R8R80=cLg0P0V9RH0100o?cl0CTi>04i>CP15ADD20410@004
02XZ:P0Y:BT0:BTY02PX:08061PH00@02`/;00h>3P0>3Ph04Q8B0P061PH0100410@0410@010@4007
1`L200d=3@0402PX:018B4P0B4Q805=CD`80GEeM00@0FUYJ06ATI01TI6@0J6QX0P1TI6@0101DE5@0
JVYZ06YZJP1fMWH206i^KP0407IfMP1ZJVX0JVYZ04U9B@806ATI00@092@T04E5A@15ADD0B4Q80P10
@400100n?Sh0A4A404A4A01@D50204Y:BP0404I6AP1;Bd/0Bd];04a<C080EEEE00@0FUYJ05UIF@1I
FET0HV9R0P1NGUh0101@D500C4a<04a<C01;Bd/205QHF00407=cL`1SHf<0Hf=S05YJFP80LG5a00@0
J6QX06m_K`1_Kfl0FEUI0P1LG5`0101mOGd0KFe]06e]K@1_Kfl207emO@0408N7Q`1jNWX0NWYj0861
P@80SXj>00@0LG5a06e]K@1]KFd0IFEU0P1WIfL0101aLG40FUYJ05YJFP1IFET204U9B@0405UIF@1K
Fe/0Fe]K06][J`80NWYj00@0Jf][061PH01PH600DU9B0P1IFET0101CDe<0@T920492@P12@T8203Xj
>P0404A4A01=CDd0CDe=05MGE`80BDU900@0G5aL07AdM01dM7@0H61P0P1CDe<0101PH600JVYZ06YZ
JP1ADE420492@P0404i>CP19BDT0BDU903lo?`80?Cdm00@0BDU904=3@`13@d<07AdM0P0G5aL0100V
9RH0?clo03lo?`1HF5P205mOG`0405eMG@1QHF40HF5Q05eMG@80EEEE00@0@d=302d];@0];Bd06QXJ
0P0A4A40100P8200>SXj03Xj>P1KFe/2079bLP0407YjNP25QHD0QHF509FEU@80MGEe00@0M7Ad08F5
Q@25QHD0HV9R0P1:BTX01016ATH0ADE504E5A@1>CTh2061PH00406][J`1bLW80LW9b08F5Q@80ZJVY
00@0/;2`09nOW`2OWil0Vi^K0P2UYJD0102JVYX0VIVI09VIV@2TY:@20::RXP040;:b/P2`/;00/;2`
09>CT`80Shn?00@0N7Qh07EeM@1eMGD0WYjN0P31`L40102TY:@0UiNG09NGU`2YZJT20:JVYP040:RX
Z02ZZZX0ZZZZ0;Fe]@80`<3000@0_;bl0:BTY02TY:@0SXj>0P2BTY80102IVIT0TI6A096AT@2MWId2
09jNWP040:JVYP2YZJT0ZJVY09NGU`80N7Qh00@0Cdm?02@T900T92@01@D50P071`L010061PH010@4
00@410061PH300X:2P8010@40`071`L010030`<01@D500D51@092@T200/;2`0400X:2P061PH01PH6
00T92@801@D50@0820P100D51@401@D50000100=3@d030`<00`<30010@4200<30`0400D51@0410@0
10@400L71`802@T900@03Ph>00D51@051@D010@40P020P8010051@D01`L700L71`00000200H61P04
00D51@071`L01`L700<30`800P8200@02PX:00H61P061PH01`L70P0;2`/010051@D0000000000004
10@200P8200400<30`010@400@4100820P8010@400@01PH600L71`071`L02@T90`061PH200`<3004
00h>3P0X:2P0:2PX020P80806ATI00@0<30`02l_;`0_;bl0:b/[0`0^;Rh200h>3P0400H61P071`L0
1`L700D51@<02@T90P0<30`0100410@05ADE01DE5@0X:2P202<S8`0303Ph>00j>SX0>SXj00<0@d=3
00@0:b/[03Lg=`0g=cL0=3@d0P0Q8B40100P8200410@010@400<30`200T92@0400L71`061PH01PH6
00<30`802PX:00@08R8R04A4A014A4@0FEUI0P1PH600101LG5`0HV9R069RHP1WIfL205iNGP0404I6
AP1LG5`0G5aL06YZJP80IFEU00@0JFUY06EUI@1UIFD0EEEE0P0U9BD0100P8200=3@d03@d=00n?Sh2
03Lg=`0404A4A01=CDd0CDe=04a<C080Cdm?00@0G5aL06ATI01TI6@0Fe]K0P1MGEd0101QHF40DE5A
055AD@18B4P204m?C`04059BDP1DE5@0E5AD04];B`80CDe=0`1VIVH0101KFe/0IVIV06IVIP1bLW82
0820P00406][J`1HF5P0F5QH061PH0<0Ng]k0P1eMGD0101UIFD0MgMg07MgM`20P80208J6QP040820
P01mOGd0OGem071`L080JFUY00@0PX:206UYJ@1YJFT0?clo0P0/;2`0101CDe<0Kfm_06m_K`20P802
0861P@<0F5QH00@0GUiN05eMG@1MGEd0EUIF0P15ADD0101@D500CTi>04i>CP1:BTX204a<C00405]K
F`19BDT0BDU904U9B@80FUYJ00@0DE5A04E5A@15ADD0GEeM0P1aLG40101VIVH0GUiN05iNGP0o?cl2
03Hf=P0404e=C@0_;bl0;bl_01dM7@808B4Q00@05ADE01hN7P0N7Qh0@4100P1DE5@0101QHF40K6a/
06a/K01FEUH204];B`040410@00o?cl0?clo02l_;`804A4A00@06ATI038b<P0b<S80@D510P1/K6`0
1027QhL0Rh^;08^;R`23Ph<2096AT@0409>CT`1]KFd0KFe]0820P080PX:200@0J6QX05iNGP1NGUh0
EUIF0P1VIVH0101ZJVX0HF5Q065QH@1OGel207AdM00408J6QP2OWil0WinO0::RXP80Shn?00@0X:2P
0;6a/@2a/K40/K6a0P2l_;`01030`<00^KVi0;Vi^@2_[jl209bLW00409^KV`2;Rh/0Rh^;08R8R080
YjNW00@0b/[:0;jn_P2n_[h0VIVI0`2XZ:P20:f][@040;2`/02^[Zh0[Zj^0;Ng]`80^[Zj00@0[jn_
09^KV`2KVi/0SXj>0P2?Shl0102BTY80U9BD09BDU02KVi/20:2PX0040:JVYP2LW9`0W9bL09FEU@80
OWin00@0D51@01lO7`0O7al010@40P071`L010092@T02`/;00/;2`0<30`200X:2P0400h>3P051@D0
1@D5000000801PH600@01`L700H61P061PH00P820P0820P00`051@D00`<300<30`0300@410401`L7
0@0410@100@4100000@03@d=00`<300<30`00@410P030`<010051@D010@400@410071`L200T92@04
00h>3P051@D01@D500@410800P8200@01@D500L71`071`L000000P061PH010051@D01`L700L71`03
0`<200820P0400X:2P061PH01PH600L71`802`/;00@01@D500000000000010@40P0820P010030`<0
0@4100410@020P8200@4100400H61P071`L01`L700T92@<01PH60P0<30`0100>3Ph0:2PX02PX:00P
820201TI6@04030`<00_;bl0;bl_02/[:`<0;Rh^0P0>3Ph010061PH01`L700L71`051@D300T92@80
30`<00@010@401DE5@0E5AD0:2PX0P0S8b<00`0h>3P0>SXj03Xj>P0304=3@`0402/[:`0g=cL0=cLg
03@d=0808B4Q00@0820P010@400@410030`<0P092@T010071`L01PH600H61P030`<200X:2P04028R
8P14A4@0A4A405UIF@80H61P00@0G5aL069RHP1RHV80IfMW0P1NGUh01016ATH0G5aL05aLG01ZJVX2
06EUI@0406UYJ@1UIFD0IFEU05EEE@809BDU00@0820P03@d=00d=3@0?Shn0P0g=cL01014A4@0CDe=
04e=C@1<C4`204m?C`0405aLG01TI6@0I6AT05]KF`80GEeM00@0HF5Q055AD@1ADE40B4Q80P1?Cdl0
101BDU80E5AD05ADE01;Bd/204e=C@<0IVIV00@0Fe]K06IVIP1VIVH0LW9b0P20P800101[Jf/0F5QH
05QHF01PH60307]kN`80MGEe00@0IFEU07MgM`1gMgL0P8200P26QXH01020P800OGem07emO@1`L702
06UYJ@0408:2PP1YJFT0JFUY03lo?`80;2`/00@0De=C06m_K`1_Kfl0P8200P21PH4305QHF00405iN
GP1MGEd0GEeM05IFEP80ADE500@0D51@04i>CP1>CTh0BTY:0P1<C4`0101KFe/0BDU904U9B@19BDT2
05YJFP04055AD@15ADD0ADE505eMG@80LG5a00@0IVIV05iNGP1NGUh0?clo0P0f=SH0101=CDd0;bl_
02l_;`0M7Ad2024Q8@0401DE5@0N7Qh07QhN0410@080E5AD00@0HF5Q06a/K01/K6`0EUIF0P1;Bd/0
1010@400?clo03lo?`0_;bl2014A4@0401TI6@0b<S80<S8b0451@@80K6a/00@0QhN708^;R`2;Rh/0
Ph>30P2ATI40102CTi<0KFe]06e]K@20P80208:2PP0406QXJ01NGUh0GUiN05IFEP80IVIV00@0JVYZ
065QH@1QHF40GemO0P1dM7@01026QXH0WinO09nOW`2RXZ8208n?S`040:2PX02a/K40/K6a0;6a/@80
_;bl00@0`<300;Vi^@2i^KT0[jn_0P2LW9`0102KVi/0Rh^;08^;R`28R8P20:NWY`040<[:bP2n_[h0
_[jn09VIV@<0Z:RX0P2][Jd0102`/;00[Zj^0:j^[P2g]kL20;Zj^P040:n_[`2KVi/0Vi^K08j>SP80
Shn?00@0TY:B09BDU02DU9@0Vi^K0P2PX:00102VYZH0W9bL09bLW02EUID207inOP04051@D00O7al0
7alO00@410801`L700@02@T900/;2`0;2`/030`<0P0:2PX0100>3Ph01@D500D51@00000200H61P04
00L71`061PH01PH600820P8020P800<01@D500<30`030`<00`0410@100L71`4010@40@0410@00004
00D51@092@T02@T900H61P<00`<30P051@D010071`L00@4100410@020P8200@4100400h>3P092@T0
2@T900H61P800`<300@010@400<30`030`<00`<30`0410@200820P0400<30`0410@010@400L71`80
20P80`000000100410@020P800P820020P8200D51@0400L71`020P800P8200820P801`L700@02`/;
00@4100410@02@T90P0C4a<0100H61P08B4Q024Q8@0Q8B42020P800303@d=011@D40@D5100<0:b/[
00@09BDU00X:2P0:2PX00`<30P020P8010092@T02PX:00X:2P0;2`/300X:2P80<C4a00@0;bl_034a
<@0a<C40>c/k0P14A4@0101FEUH0?Cdm03dm?@0[:b/203`l?00403<c<`0/;2`0;2`/02@T908020P8
00@01@D500@4100410@02PX:0P061PH010051@D03@d=00d=3@0X:2P204Y:BP0405YJFP1EEED0EEEE
05MGE`80FUYJ00@0I6AT061PH01PH600B4Q80P10@400101BDU80F5QH05QHF01=CDd205]KF`0405iN
GP0X:2P0:2PX01XJ6P809BDU00@0?3`l03Ti>@0i>CT0AdM70P1?Cdl0101FEUH0De=C05=CD`1;Bd/2
061PH00405eMG@1=CDd0CDe=059BDP80CTi>00@0BTY:05MGE`1GEeL0G5aL0P1DE5@00`1JFUX0IfMW
06MWI`0305eMG@0406IVIP1NGUh0GUiN06m_K`80PH6100@0MWIf061PH01PH600Cdm?0P1nOWh01027
QhL0MWIf07IfMP1RHV8207IfMP0407AdM01RHV80HV9R06IVIP80IfMW00@0Hf=S05MGE`1GEeL0J6QX
0P1_Kfl0101ADE40CDe=04e=C@1XJ6P2071`L00406QXJ01LG5`0G5aL04i>CP80FUYJ00@0Kfm_06IV
IP1VIVH0A4A40P19BDT0101FEUH0@D510451@@10@40203hn?P0404m?C`1GEeL0EeMG051@D080CDe=
00@0D51@055AD@1ADE40E5AD0P17AdL0100n?Sh0F5QH05QHF01<C4`203hn?P0404A4A00J6QX06QXJ
00820P803Ph>00@09BDU0410@010@400Cdm?0P18B4P0101YJFT0LG5a075aL@1:BTX203Xj>P0403De
=@0];Bd0;Bd]01HF5P806ATI00@0@41005aLG01LG5`0MWIf0P2DU9@0102CTi<0QXJ608J6QP23Ph<2
09JFUP0408f=S@1ZJVX0JVYZ08R8R080NWYj00@0MWIf07MgM`1gMgL0K6a/0P29RHT0102HV9P0SXj>
08j>SP1gMgL2079bLP0407=cL`1nOWh0OWin07moO`80RHV900@0YjNW0:RXZ02XZ:P0/k>c0P2l_;`0
102g]kL0[jn_0:n_[`2RXZ8209BDU0040::RXP2FUYH0UYJF09JFUP80^;Rh00@0_Kfm096AT@2ATI40
VYZJ0P2QXJ40102OWil0X:2P0:2PX02=SHd20:BTY0040;Ng]`2a/K40/K6a09nOW`80TY:B00@0SHf=
09BDU02DU9@0WinO0P2JVYX0102GUiL0X:2P0:2PX02UYJD209nOW`0408j>SP1fMWH0MWIf04Q8B080
4Q8B00@01`L700X:2P0:2PX02PX:0P0C4a<0100A4A401`L700L71`051@D200L71`0400<30`051@D0
1@D500/;2`8020P800@01PH600h>3P0>3Ph00`<30P0:2PX300D51@4030`<0@0410@100@4100000<0
2@T900L71`071`L00`051@D010020P801@D500D51@061PH200820P0300@410061PH01PH600@01`L7
0P020P80100410@00000000000030`<300H61P801`L70`030`<0100410@00P8200820P051@D200<3
0`<00@4100<01@D500P8200820P00`0410@010092@T030`<00`<30061PH200L71`0400P820092@T0
2@T901LG5`806QXJ00@07AdM01`L700L71`0=CDe0P18B4P0100i>CT0;2`/02`/;00A4A4200<30`04
00`<300410@010@400@410800`<300@01`L700D51@051@D061PH0P1BDU80101;Bd/0?3`l03`l?00a
<C4203dm?@0404m?C`0a<C40<C4a03Lg=`80?clo00@0<S8b02d];@0];Bd05ADE0P0410@010092@T0
0P8200820P0820P201@D500400/;2`0G5aL05aLG03De=@80BTY:00<0De=C04m?C`1?Cdl00`1ADE40
101NGUh0I6AT06ATI01VIVH204Y:BP040410@01>CTh0CTi>04Y:BP80EeMG00@0F5QH03Lg=`0g=cL0
5QHF0P0K6a/0100l?3`0@4100410@01>CTh204e=C@0405=CD`1:BTX0BTY:02l_;`80Cdm?00@0Hf=S
04M7A`17AdL0@T920P1=CDd0101QHF40KFe]06e]K@1EEED203dm?@0404];B`1RHV80HV9R051@D080
DE5A00@0J6QX05]KF`1KFe/0F5QH0P1SHf<0101/K6`0L71`071`L01SHf<206m_K`0407=cL`23Ph<0
Ph>307moO`80NGUi00@0KVi^07YjNP1jNWX0MgMg0P1bLW80101^KVh0Jf][06][J`1EEED204m?C`04
059BDP1XJ6P0J6QX07=cL`80K6a/00@0GUiN05ADE01DE5@0GEeM0P1HF5P0101@D500De=C05=CD`1A
DE4205ADE00404a<C019BDT0BDU9069RHP80GemO00@0GUiN05aLG01LG5`0C4a<0P0b<S80100i>CT0
B4Q804Q8B00n?Sh202d];@0402/[:`1:BTX0BTY:05aLG080C4a<00@0>3Ph01LG5`0G5aL01`L70P0N
7Qh0100k>c/0CDe=04e=C@1@D50204M7A`0405QHF01NGUh0GUiN04E5A@80<c<c00@0<30`02<S8`0S
8b<0:BTY0P1ADE40101VIVH0OWin07inOP2>SXh20::RXP040:JVYP2FUYH0UYJF08n?S`80VIVI00@0
PH6107MgM`1gMgL0T92@0P1oOgl01028R8P0P8200820P01mOGd209ZJVP0409VIV@2HV9P0V9RH09RH
V080RHV900@0LW9b06a/K01/K6`0Kfm_0P29RHT0102KVi/0T92@092@T02GUiL20:2PX0040:FUY@2M
WId0WIfM09ZJVP80YjNW00@0Zj^[09ZJVP2JVYX0XZ:R0P39bLT0102m_Kd0UiNG09NGU`2ZZZX209^K
V`040;Fe]@2ATI40TI6A06EUI@80V9RH00@0ZZZZ0::RXP2RXZ80T92@0P2:RXX0102DU9@0XJ6Q0:6Q
X@2RXZ8209NGU`0409>CT`2SXj<0Xj>S0:JVYP80UiNG00@0Q8B4075aL@1aLG40@D510P0820P01003
0`<02PX:00X:2P0:2PX200/;2`0400P8200410@010@400410@801`L700@020P800820P020P800`<3
0P0410@010020P801`L700L71`051@D500T92@402`/;0@071`L100L71`0000<02@T900L71`071`L0
0`051@D010020P801@D500D51@061PH200820P0300@410061PH01PH600@01`L70P020P80100410@0
0000000000030`<300H61P801`L70`030`<0100410@00P8200820P051@D200<30`<00@4100<01@D5
00P8200820P00`0410@010092@T030`<00`<30061PH200L71`0400P820092@T02@T901LG5`806QXJ
00@07AdM01`L700L71`0=CDe0P18B4P0100i>CT0;2`/02`/;00A4A4200<30`0400`<300410@010@4
00@410800`<300@01`L700D51@051@D061PH0P1BDU80101;Bd/0?3`l03`l?00a<C4203dm?@0404m?
C`0a<C40<C4a03Lg=`80?clo00@0<S8b02d];@0];Bd05ADE0P0410@010092@T00P8200820P0820P2
01@D500400/;2`0G5aL05aLG03De=@80BTY:00<0De=C04m?C`1?Cdl00`1ADE40101NGUh0I6AT06AT
I01VIVH204Y:BP040410@01>CTh0CTi>04Y:BP80EeMG00@0F5QH03Lg=`0g=cL05QHF0P0K6a/0100l
?3`0@4100410@01>CTh204e=C@0405=CD`1:BTX0BTY:02l_;`80Cdm?00@0Hf=S04M7A`17AdL0@T92
0P1=CDd0101QHF40KFe]06e]K@1EEED203dm?@0404];B`1RHV80HV9R051@D080DE5A00@0J6QX05]K
F`1KFe/0F5QH0P1SHf<0101/K6`0L71`071`L01SHf<206m_K`0407=cL`23Ph<0Ph>307moO`80NGUi
00@0KVi^07YjNP1jNWX0MgMg0P1bLW80101^KVh0Jf][06][J`1EEED204m?C`04059BDP1XJ6P0J6QX
07=cL`80K6a/00@0GUiN05ADE01DE5@0GEeM0P1HF5P0101@D500De=C05=CD`1ADE4205ADE00404a<
C019BDT0BDU9069RHP80GemO00@0GUiN05aLG01LG5`0C4a<0P0b<S80100i>CT0B4Q804Q8B00n?Sh2
02d];@0402/[:`1:BTX0BTY:05aLG080C4a<00@0>3Ph01LG5`0G5aL01`L70P0N7Qh0100k>c/0CDe=
04e=C@1@D50204M7A`0405QHF01NGUh0GUiN04E5A@80<c<c00@0<30`02<S8`0S8b<0:BTY0P1ADE40
101VIVH0OWin07inOP2>SXh20::RXP040:JVYP2FUYH0UYJF08n?S`80VIVI00@0PH6107MgM`1gMgL0
T92@0P1oOgl01028R8P0P8200820P01mOGd209ZJVP0409VIV@2HV9P0V9RH09RHV080RHV900@0LW9b
06a/K01/K6`0Kfm_0P29RHT0102KVi/0T92@092@T02GUiL20:2PX0040:FUY@2MWId0WIfM09ZJVP80
YjNW00@0Zj^[09ZJVP2JVYX0XZ:R0P39bLT0102m_Kd0UiNG09NGU`2ZZZX209^KV`040;Fe]@2ATI40
TI6A06EUI@80V9RH00@0ZZZZ0::RXP2RXZ80T92@0P2:RXX0102DU9@0XJ6Q0:6QX@2RXZ8209NGU`04
09>CT`2SXj<0Xj>S0:JVYP80UiNG00@0Q8B4075aL@1aLG40@D510P0820P010030`<02PX:00X:2P0:
2PX200/;2`0400P8200410@010@400410@801`L700@020P800820P020P800`<30P0410@010020P80
1`L700L71`051@D500T92@402`/;0@071`L100L71`0000@020P80000000000001@D50P071`L01002
0P801PH600H61P071`L200`<300400T92@051@D01@D500L71`802@T900@01`L700H61P061PH00000
0P030`<010051@D01PH600H61P020P8200@4100400H61P0:2PX02PX:00@410800`<300@01`L700H6
1P061PH020P80P030`<010092@T02PX:00X:2P010@4200D51@0400T92@051@D01@D500@410800`<3
00@0000000h>3P0>3Ph08b<S0P0U9BD0100M7Ad071`L01`L700h>3P203De=@0403@d=00[:b/0:b/[
018B4P801@D500@01`L700<30`030`<020P80`061PH200820P0401@D5018B4P0B4Q804I6AP80<c<c
00@0=cLg03hn?P0n?Sh0C4a<0P0e=CD302XZ:P0401lO7`0@4100410@00P820803`l?00@02@T900H6
1P061PH020P80P0@410301@D500403lo?`1;Bd/0Bd];04Q8B0<0D51@0P1=CDd0101@D500Cdm?04m?
C`1ZJVX206EUI@0403lo?`17AdL0AdM705aLG080H61P00@0FUYJ04I6AP16ATH07QhN0P0Q8B40100j
>SX0@d=304=3@`1:BTX203hn?P0404=3@`1;Bd/0Bd];04Q8B080EEEE00@0FUYJ05eMG@1MGEd0EUIF
0P10@400101<C4`0HF5Q065QH@1ADE4203lo?`040492@P1FEUH0EUIF065QH@80GUiN00@0HF5Q05IF
EP1FEUH0H61P0P1`L700101NGUh0KVi^06i^KP1iNGT207MgM`04071`L01hN7P0N7Qh07moO`80RHV9
00@0LG5a0820P020P800OWin0P20P800101cLg<0L71`071`L01[Jf/206=SH`0406MWI`1XJ6P0J6QX
06i^KP80LW9b00@0OGem07IfMP1fMWH0EeMG0P14A4@01012@T80EeMG05MGE`1SHf<205]KF`0406e]
K@1^KVh0KVi^06m_K`80FUYJ00@0DE5A04E5A@15ADD0;bl_0P0[:b/0101;Bd/0CTi>04i>CP10@402
04A4A00404I6AP1>CTh0CTi>04A4A080;Bd]00@07AdM014A4@0A4A4051@D0P0Y:BT01011@D40C4a<
04a<C01=CDd2055AD@0403lo?`0a<C40<C4a02d];@80:BTY00@08R8R02TY:@0Y:BT0JVYZ0P1kNg/0
1021PH40TY:B09:BTP2HV9P209bLW0040:>SX`2QXJ40XJ6Q09jNWP80UIFE00@0NGUi08J6QP26QXH0
WIfM0P2DU9@0102HV9P0RXZ:08Z:RP2DU9@20:n_[`040::RXP2JVYX0VYZJ09^KV`80UYJF00@0QhN7
07emO@1mOGd0Ogmo0P2=SHd0102JVYX0YjNW0:NWY`2RXZ8209JFUP0409jNWP2[Zj/0Zj^[0;no_`80
`<3000@0YJFU09^KV`2KVi/0[jn_0P3;bl/0102][Jd0VIVI09VIV@2a/K420:NWY`040;Ng]`1LG5`0
G5aL02/[:`80MGEe00@0VYZJ0:BTY02TY:@0VYZJ0P2:RXX0102ATI40Y:BT0:BTY02XZ:P209jNWP04
092@T02MWId0WIfM09RHV080O7al00@0QhN707]kN`1kNg/0>3Ph0P071`L010010@4030`<00`<300<
30`200820P0400@410020P800P8200410@800P8200@0000000@4100410@00P820`030`<200P820<0
10@400@020P800D51@051@D00`<30P071`L0000400P820061PH01PH600D51@8010@400@00P8200@4
100410@00`<30P051@D0100;2`/02PX:00X:2P071`L200D51@0400@4100:2PX02PX:00L71`800`<3
00@00P8200@4100410@01PH60P071`L0100820P01`L700L71`010@4200<30`0400H61P071`L01`L7
00L71`801@D500@00`<300L71`071`L00P820P051@D0100;2`/01PH600H61P0410@200820P0400<3
0`0B4Q804Q8B030`<0809BDU00@071`L034a<@0a<C40ATI60`0Y:BT202`/;00401XJ6P0820P020P8
00820P801@D500@02PX:00d=3@0=3@d03@d=0P071`L010061PH09BDU02DU9@0h>3P202d];@04034a
<@0b<S80<S8b0451@@80BDU900@0>c/k02<S8`0S8b<04A4A0P010@400`0820P06QXJ01XJ6P0300d=
3@0400<30`0410@010@400h>3P803@d=00@0>c/k051@D01@D500DU9B0P1EEED0101CDe<0EUIF05IF
EP1GEeL204U9B@0405aLG01eMGD0MGEe05IFEP80CTi>00@0J6QX06UYJ@1YJFT0HV9R0P13@d<0100L
71`092@T02@T9011@D4205MGE`0404I6AP0d=3@0=3@d03Xj>P80CDe=00@0EEEE04a<C01<C4`0AdM7
0P1DE5@0101HF5P0A4A404A4A013@d<205=CD`0305MGE`1@D500D51@00<0@41000@0EUIF061PH01P
H600H61P0P1OGel0101QHF40MgMg07MgM`1XJ6P207AdM00407YjNP1gMgL0MgMg0861P@80IfMW00@0
GEeM0820P020P800Ng]k0P1jNWX0101VIVH0GUiN05iNGP1VIVH205IFEP0405UIF@1ADE40DE5A061P
H080FUYJ00@0E5AD06YZJP1ZJVX0Ph>30P1[Jf/0101CDe<0F5QH05QHF01TI6@205MGE`0304Q8B015
ADD0ADE500<0IVIV00@0CDe=0492@P12@T80De=C0P18B4P0100j>SX0DE5A055AD@1WIfL204U9B@04
04M7A`1KFe/0Fe]K04M7A`80@T9200@0?Cdm020P800P82002@T90P051@D0100F5QH0;bl_02l_;`15
ADD204];B`0403`l?00c<c<0<c<c01HF5P802@T900@04a<C02TY:@0Y:BT0=SHf0P1HF5P0102<S8`0
RXZ:08Z:RP2CTi<20:FUY@0409nOW`2WYjL0YjNW0:BTY080UYJF00@0SHf=08B4Q024Q8@0Q8B40P2G
UiL0102RXZ80X:2P0:2PX02SXj<209BDU0040:6QX@2a/K40/K6a0:j^[P80Zj^[00@0TY:B092@T02@
T900Ti>C0P29RHT0102EUID0V9RH09RHV02LW9`20;>c/`040:^[Z`2RXZ80XZ:R0:f][@80`<3000@0
c/k>0<;2`P32`/80YjNW0P2/[:`0102l_;`0`L710<71`@2HV9P209^KV`040;2`/02ZZZX0ZZZZ0:2P
X080EEEE00@0?clo07=cL`1cLg<0Shn?0P2KVi/0102JVYX0TY:B09:BTP2DU9@20:FUY@040:j^[P2R
XZ80XZ:R08f=S@80Ti>C00@0V9RH08Z:RP2:RXX0S8b<0P1^KVh0100Y:BT01`L700L71`030`<200P8
200300T92@020P800P8200<010@400@00P8200410@010@400P820P071`L300T92@0400H61P092@T0
2@T900H61P800@4100@02@T900L71`071`L00`<30P020P80000400P820061PH01PH600D51@8010@4
00@00P8200@4100410@00`<30P051@D0100;2`/02PX:00X:2P071`L200D51@0400@4100:2PX02PX:
00L71`800`<300@00P8200@4100410@01PH60P071`L0100820P01`L700L71`010@4200<30`0400H6
1P071`L01`L700L71`801@D500@00`<300L71`071`L00P820P051@D0100;2`/01PH600H61P0410@2
00820P0400<30`0B4Q804Q8B030`<0809BDU00@071`L034a<@0a<C40ATI60`0Y:BT202`/;00401XJ
6P0820P020P800820P801@D500@02PX:00d=3@0=3@d03@d=0P071`L010061PH09BDU02DU9@0h>3P2
02d];@04034a<@0b<S80<S8b0451@@80BDU900@0>c/k02<S8`0S8b<04A4A0P010@400`0820P06QXJ
01XJ6P0300d=3@0400<30`0410@010@400h>3P803@d=00@0>c/k051@D01@D500DU9B0P1EEED0101C
De<0EUIF05IFEP1GEeL204U9B@0405aLG01eMGD0MGEe05IFEP80CTi>00@0J6QX06UYJ@1YJFT0HV9R
0P13@d<0100L71`092@T02@T9011@D4205MGE`0404I6AP0d=3@0=3@d03Xj>P80CDe=00@0EEEE04a<
C01<C4`0AdM70P1DE5@0101HF5P0A4A404A4A013@d<205=CD`0305MGE`1@D500D51@00<0@41000@0
EUIF061PH01PH600H61P0P1OGel0101QHF40MgMg07MgM`1XJ6P207AdM00407YjNP1gMgL0MgMg0861
P@80IfMW00@0GEeM0820P020P800Ng]k0P1jNWX0101VIVH0GUiN05iNGP1VIVH205IFEP0405UIF@1A
DE40DE5A061PH080FUYJ00@0E5AD06YZJP1ZJVX0Ph>30P1[Jf/0101CDe<0F5QH05QHF01TI6@205MG
E`0304Q8B015ADD0ADE500<0IVIV00@0CDe=0492@P12@T80De=C0P18B4P0100j>SX0DE5A055AD@1W
IfL204U9B@0404M7A`1KFe/0Fe]K04M7A`80@T9200@0?Cdm020P800P82002@T90P051@D0100F5QH0
;bl_02l_;`15ADD204];B`0403`l?00c<c<0<c<c01HF5P802@T900@04a<C02TY:@0Y:BT0=SHf0P1H
F5P0102<S8`0RXZ:08Z:RP2CTi<20:FUY@0409nOW`2WYjL0YjNW0:BTY080UYJF00@0SHf=08B4Q024
Q8@0Q8B40P2GUiL0102RXZ80X:2P0:2PX02SXj<209BDU0040:6QX@2a/K40/K6a0:j^[P80Zj^[00@0
TY:B092@T02@T900Ti>C0P29RHT0102EUID0V9RH09RHV02LW9`20;>c/`040:^[Z`2RXZ80XZ:R0:f]
[@80`<3000@0c/k>0<;2`P32`/80YjNW0P2/[:`0102l_;`0`L710<71`@2HV9P209^KV`040;2`/02Z
ZZX0ZZZZ0:2PX080EEEE00@0?clo07=cL`1cLg<0Shn?0P2KVi/0102JVYX0TY:B09:BTP2DU9@20:FU
Y@040:j^[P2RXZ80XZ:R08f=S@80Ti>C00@0V9RH08Z:RP2:RXX0S8b<0P1^KVh0100Y:BT01`L700L7
1`030`<200P8200300T92@020P800P8200<010@400@00P8200410@010@400P820P071`L300T92@04
00H61P092@T02@T900H61P800@4100@02@T900L71`071`L00`<30P020P80000400T92@020P800P82
00<30`8010@40`061PH010030`<01`L700L71`0>3Ph200`<300400820P010@400@41000000802`/;
00@03Ph>00H61P061PH01PH60P000000100410@020P800P8200820P200L71`0400H61P071`L01`L7
00D51@801PH600@00P8200@4100410@01PH60P00000010010@400`<300<30`051@D200L71`<00`<3
00@01`L701@D500D51@0:BTY0P0P8200100I6AT0;2`/02`/;011@D42030`<004038b<P0S8b<08b<S
00L71`<02PX:0P071`L010051@D00P8200820P0410@200P8200401<C4`0c<c<0<c<c04I6AP80?3`l
00@0<S8b02LW9`0W9bL0:2PX0`18B4P201/K6`0401DE5@0<30`030`<00l?3`805aLG00@01@D5010@
400@41001@D50P020P8010071`L04A4A014A4@0c<c<204E5A@<0De=C00@0EUIF065QH@1QHF40GUiN
0P1ADE40101HF5P0LW9b079bLP1WIfL205YJFP0406YZJP1SHf<0Hf=S05mOG`80@D5100@07AdM01LG
5`0G5aL0>SXj0P1IFET01013@d<0@T920492@P13@d<203dm?@0403/k>`18B4P0B4Q805EEE@80Cdm?
00@0CDe=04m?C`1?Cdl0DU9B0P1=CDd0101CDe<0F5QH05QHF00k>c/203Xj>P0405]KF`1VIVH0IVIV
06=SH`80LW9b00@0IVIV079bLP1bLW80MGEe0P1`L700101[Jf/0JVYZ06YZJP24Q8@207alO00406EU
I@1KFe/0Fe]K06ATI080OGem00@0M7Ad05=CD`1CDe<0AdM70P1HF5P0101^KVh0Cdm?04m?C`1@D502
06m_K`0405iNGP1GEeL0EeMG06=SH`80AdM700@0JVYZ06ATI01TI6@0CTi>0P0m?Cd01014A4@0GUiN
05iNGP1QHF42061PH00406IVIP1IFET0FEUI05]KF`<0JFUY0`1KFe/204Q8B00403Hf=P0o?cl0?clo
03De=@80;2`/00@0<C4a024Q8@0Q8B404Q8B0P0L71`0100W9bL0=SHf03Hf=P12@T8204U9B@0402TY
:@0C4a<04a<C01LG5`809RHV00@0<30`03lo?`0o?cl0FEUI0P24Q8@0102MWId0QhN708N7Q`2?Shl2
0:6QX@0409VIV@2UYJD0YJFU09fMW@80TI6A00@0QhN708R8R028R8P0W9bL0P2WYjL0102XZ:P0YJFU
0:FUY@2PX:0209RHV0040:f][@2_[jl0[jn_0:j^[P80Y:BT00@0PH6108j>SP2>SXh0YZJV0P2HV9P0
102TY:@0Zj^[0:^[Z`2UYJD20;Bd]0<0/[:b00@0^KVi0<K6aP36a/H0bl_;0P2n_[h0102b/[80_;bl
0;bl_036a/H20;>c/`04092@T02WYjL0YjNW0:>SX`80WinO00@0[jn_0::RXP2RXZ80Shn?0P2@T900
102ATI40SXj>08j>SP2DU9@209:BTP0409ZJVP2][Jd0[Jf]0:ZZZP80UYJF00<0T92@09FEU@2EUID0
0`2GUiL0102?Shl0IVIV06IVIP0U9BD200@4100400H61P051@D01@D500D51@802`/;00@020P800H6
1P061PH01PH60P030`<0100820P01PH600H61P051@D2014A4@0400L71`0410@010@400P820<01PH6
0`030`<200L71`0000<020P800<30`030`<01P0410@010051@D02PX:00X:2P0D51@200`<30040000
00061PH01PH600<30`801`L700<020P800820P020P800`0410@010030`<01@D500D51@0820P600<3
0`801`L70`061PH010092@T010@400@410020P8200@410<01@D50`030`<010061PH07QhN01hN7P0V
9RH201XJ6P04028R8P0`<300<30`03lo?`80<30`00@0;Rh^028R8P0R8R8010@40P0;2`/010092@T0
1PH600H61P0820P200@410040000000>3Ph03Ph>038b<P80Cdm?00<0ATI602l_;`0_;bl00`0P8200
100=3@d07alO01lO7`16ATH201lO7`0401HF5P0D51@051@D00L71`8010@400@01`L700`<300<30`0
0`<30P0410@010092@T061PH01PH600j>SX204Y:BP04059BDP1@D500D51@05IFEP80FUYJ00@0EUIF
05eMG@1MGEd0GEeM0P1XJ6P0101WIfL0DE5A055AD@1JFUX204m?C`0405EEE@1<C4`0C4a<02/[:`80
4Q8B00@0;Bd]04a<C01<C4`0@d=30P18B4P01013@d<0?3`l03`l?01;Bd/205eMG@0405aLG01MGEd0
GEeM059BDP80B4Q800@0GemO05EEE@1EEED0CDe=0P1GEeL01010@400ADE504E5A@1ADE4205]KF`04
06MWI`1PH600H61P05aLG080O7al00@0M7Ad06][J`1[Jf/0L71`0P1SHf<0101VIVH0R8R808R8R01h
N7P204m?C`0406a/K028R8P0R8R808n?S`80S8b<0`1`L700102>SXh0Kfm_06m_K`1NGUh2065QH@04
05QHF01MGEd0GEeM05]KF`80?clo00@0E5AD04e=C@1=CDd0@T920P1>CTh0101PH600FUYJ05YJFP1:
BTX206=SH`0407moO`1TI6@0I6AT04Y:BP80Cdm?00@0BDU90410@010@400HV9R0P1]KFd0101FEUH0
@4100410@00];Bd202h^;P0402d];@0L71`071`L00X:2P807AdM00@0<C4a04E5A@15ADD0BTY:0P10
@400100W9bL0=cLg03Lg=`1<C4`204];B`04051@D01JFUX0FUYJ07emO@80VYZJ00@0W9bL08^;R`2;
Rh/0X:2P0P2YZJT0102QXJ40XZ:R0::RXP2CTi<2096AT@0408N7Q`2BTY80TY:B0:ZZZP80/K6a00@0
/[:b0:BTY02TY:@0UiNG0P2OWil0102_[jl0YJFU0:FUY@2TY:@209BDU00408B4Q02DU9@0U9BD0:JV
YP80XZ:R00@0YjNW0;>c/`2c/k<0]KFe0P2f][H0102d];@0][Jf0;Jf]P2i^KT20;fm_@040;no_`2b
/[80/[:b0;Bd]080a<C400@0`l?309bLW02LW9`0UYJF0P2h^;P0102MWId0UYJF09JFUP2`/;020:j^
[P040::RXP2PX:00X:2P09JFUP80SXj>00@0U9BD08J6QP26QXH0UIFE0P2a/K40102WYjL0U9BD09BD
U02GUiL209JFUP0408V9R@2:RXX0RXZ:08V9R@80GemO00@061PH0000000000001@D50P061PH01003
0`<020P800P8200820P300L71`802@T900@03@d=00P8200820P02@T90P0=3@d00`061PH00`<300<3
0`0300H61P0400L71`010@400@4100T92@803@d=00000`0820P00`<300<30`0600@4100400D51@0:
2PX02PX:01@D508030`<00@0000000H61P061PH00`<30P071`L00`0820P00P8200820P0300@41004
00<30`051@D01@D500P820H00`<30P071`L300H61P0400T92@0410@010@400820P8010@40`051@D3
00<30`0400H61P0N7Qh07QhN02HV9P806QXJ00@08R8R030`<00`<300?clo0P0`<300100^;Rh08R8R
028R8P0410@200/;2`0400T92@061PH01PH600P8208010@400@0000000h>3P0>3Ph0<S8b0P1?Cdl0
0`16ATH0;bl_02l_;`03020P800400d=3@0O7al07alO04I6AP807alO00@05QHF01@D500D51@01`L7
0P0410@010071`L030`<00`<30030`<200@4100400T92@0H61P061PH03Xj>P80BTY:00@0DU9B051@
D01@D500EUIF0P1JFUX0101FEUH0GEeM05eMG@1MGEd206QXJ00406MWI`1ADE40DE5A05YJFP80Cdm?
00@0EEEE04a<C01<C4`0:b/[0P0B4Q80100];Bd0C4a<04a<C013@d<204Q8B00404=3@`0l?3`0?3`l
04];B`80GEeM00@0G5aL05eMG@1MGEd0DU9B0P18B4P0101OGel0EEEE05EEE@1=CDd205MGE`040410
@015ADD0ADE5055AD@80Fe]K00@0IfMW061PH01PH600G5aL0P1lO7`0101dM7@0Jf][06][J`1`L702
06=SH`0406IVIP28R8P0R8R807QhN080Cdm?00@0K6a/08R8R028R8P0Shn?0P2<S8`3071`L00408j>
SP1_Kfl0Kfm_05iNGP80HF5Q00@0F5QH05eMG@1MGEd0Fe]K0P0o?cl0101DE5@0CDe=04e=C@12@T82
04i>CP04061PH01JFUX0FUYJ04Y:BP80Hf=S00@0Ogmo06ATI01TI6@0BTY:0P1?Cdl01019BDT0@410
0410@01RHV8206e]K@0405IFEP10@400@41002d];@80;Rh^00@0;Bd]01`L700L71`02PX:0P0M7Ad0
100a<C40ADE504E5A@1:BTX20410@00402LW9`0g=cL0=cLg04a<C080Bd];00@0D51@05YJFP1JFUX0
OGem0P2JVYX0102LW9`0Rh^;08^;R`2PX:020:VYZ@040:6QX@2RXZ80XZ:R09>CT`80TI6A00@0QhN7
09:BTP2BTY80ZZZZ0P2a/K40102b/[80Y:BT0:BTY02GUiL209nOW`040:n_[`2UYJD0YJFU0:BTY080
U9BD00@0Q8B409BDU02DU9@0YZJV0P2RXZ80102WYjL0/k>c0;>c/`2e]KD20;Jf]P040;Bd]02f][H0
][Jf0;Vi^@80_Kfm00@0_kno0;:b/P2b/[80];Bd0P34a<@01033`l<0W9bL09bLW02FUYH20;Rh^004
09fMW@2FUYH0UYJF0;2`/080[Zj^00@0XZ:R0:2PX02PX:00UYJF0P2>SXh0102DU9@0QXJ608J6QP2E
UID20;6a/@040:NWY`2DU9@0U9BD09NGU`80UYJF00@0RHV908Z:RP2:RXX0RHV90P1OGel0100H61P0
0000000000051@D200H61P0400<30`0820P020P800P820<01`L70P092@T0100=3@d020P800P82009
2@T200d=3@0300H61P030`<00`<300<01PH600@01`L700410@010@402@T90P0=3@d0000400D51@03
0`<00`<300410@80000000@00@4100H61P061PH010@40P010@40100>3Ph02PX:00X:2P020P8300T9
2@<00`<30P020P800`061PH02`/;00/;2`0400L71`800`<300@00P8200<30`030`<01`L70P0820P0
100:2PX030`<00`<30071`L300P820801PH60`071`L010051@D00`<300<30`020P8201LG5`0402XZ
:P0H61P061PH01DE5@80;2`/00@0AdM7038b<P0b<S8092@T0P0M7Ad010071`L01@D500D51@051@D2
00L71`<020P800@01`L700d=3@0=3@d0:BTY0P0n?Sh0100i>CT0>c/k03/k>`0];Bd2028R8P0401XJ
6P0D51@051@D030`<0803Ph>00@030`<01HF5P0F5QH020P80P061PH00`0:2PX020P800P8200400@4
108071`L00@0>SXj04];B`1;Bd/0EUIF0P1GEeL0101EEED0DU9B059BDP1GEeL205iNGP0405QHF01_
Kfl0Kfm_07AdM080>c/k00@0<30`02h^;P0^;Rh0@D510P1;Bd/0100[:b/061PH01PH600Z:RX204Y:
BP0404M7A`16ATH0ATI604M7A`80A4A400@0EEEE061PH01PH600De=C0P1ADE401017AdL0@4100410
@01MGEd2065QH@04059BDP1;Bd/0Bd];04I6AP80BTY:00@0?Shn04m?C`1?Cdl0I6AT0P1GEeL0101O
Gel0Ng]k07]kN`1ZJVX207IfMP040861P@1fMWH0MWIf079bLP80Ogmo00@0LG5a06i^KP1^KVh0O7al
0P22PX801023Ph<0SXj>08j>SP2CTi<2071`L00406MWI`1UIFD0IFEU05UIF@80DE5A00@0J6QX07=c
L`1cLg<0EEEE0P19BDT0101MGEd0GemO05mOG`1PH60204m?C`0404=3@`10@400@4100410@080I6AT
00@0N7Qh071`L01`L700G5aL0P11@D401010@400F5QH05QHF01ZJVX206=SH`0405mOG`16ATH0ATI6
02TY:@80=cLg00@0<30`018B4P0B4Q803@d=0P0R8R80100i>CT0F5QH05QHF01<C4`203<c<`040410
@01MGEd0GEeM06EUI@80JFUY00@0J6QX08J6QP26QXH0ZJVY0P2][Jd0102RXZ80WYjN09jNWP2f][H2
0:f][@040::RXP2MWId0WIfM08j>SP80Rh^;00@0PX:209:BTP2BTY80ZJVY0P2a/K40102h^;P0YJFU
0:FUY@2OWil20:RXZ00409jNWP2QXJ40XJ6Q0:6QX@80U9BD00@0WinO0:BTY02TY:@0Xj>S0P2ZZZX0
102`/;00/k>c0;>c/`2i^KT20;Fe]@040:j^[P2a/K40/K6a0;Vi^@80];Bd00@0[jn_0;Vi^@2i^KT0
`<300P31`L40102`/;00UIFE09FEU@2][Jd20;no_`<0XJ6Q00@0YjNW09jNWP2NWYh0V9RH0P2EUID3
08V9R@0408n?S`21PH40PH6108f=S@80YjNW00@0Y:BT08j>SP2>SXh0Ti>C0P2HV9P0102=SHd0T92@
092@T020P80204e=C@04010@40020P800P8200D51@802@T900@02PX:00D51@051@D01@D50P0820P3
00d=3@0400`<300820P020P800L71`801@D500@01`L700P8200820P00`<30`061PH200<30`402PX:
0@0820P100P8200000@01@D500P8200820P020P80P020P8010051@D03@d=00d=3@0>3Ph200D51@04
00L71`092@T02@T900D51@802PX:00@01`L700410@010@401@D50P030`<00`071`L02`/;00/;2`03
00P8200400H61P0410@010@400D51@<01`L70P051@D0100820P02@T900T92@030`<200H61P0400X:
2P0410@010@400D51@801PH600@010@400820P020P8020P80P0L71`0100Z:RX07AdM01dM7@0J6QX2
030`<00404A4A00d=3@0=3@d02HV9P808B4Q00@020P800<30`030`<010@40P061PH010051@D020P8
00P8200@410200X:2P0401lO7`14A4@0A4A404I6AP80De=C00@0?Shn038b<P0b<S80@4100P0/;2`0
100W9bL010@400@4100B4Q8201TI6@0400L71`0=3@d03@d=00d=3@801`L700@02@T900P8200820P0
2@T90P0T92@0100h>3P0C4a<04a<C01EEED205iNGP<0I6AT00@0Hf=S05UIF@1IFET0FEUI0P1nOWh0
101[Jf/0:RXZ02XZ:P0Q8B4202/[:`0403Ph>019BDT0BDU902h^;P804Q8B00@09bLW04E5A@15ADD0
ATI60P1<C4`0101=CDd0BDU904U9B@1ADE4205IFEP0404e=C@10@400@4100492@P80FUYJ00@0K6a/
06MWI`1WIfL0EeMG0P17AdL01015ADD0CDe=04e=C@1CDe<205iNGP0405YJFP1BDU80DU9B06IVIP80
Ng]k00@0Jf][07EeM@1eMGD0M7Ad0P1bLW801024Q8@0QXJ608J6QP1`L70207IfMP04069RHP20P800
P82009BDU080Kfm_00@0SXj>07IfMP1fMWH0GemO0P1jNWX0101EEED0De=C05=CD`1`L70207IfMP04
05iNGP1VIVH0IVIV07]kN`80GemO00@0ATI603dm?@0m?Cd0@d=30P1ADE400`1IFET0Jf][06][J`03
075aL@0405mOG`1ADE40DE5A06IVIP80K6a/00@0CDe=03@d=00d=3@0?3`l0P0a<C40100N7Qh0:b/[
02/[:`0L71`200X:2P0401HF5P0Z:RX0:RXZ03hn?P80FEUI00@0D51@0410@010@400FUYJ0P1QHF40
101`L700PX:208:2PP29RHT20:j^[P040;^k^`2/[:`0[:b/0:n_[`80Z:RX00@0[jn_0;6a/@2a/K40
YZJV0P2GUiL01029RHT0U9BD09BDU01kNg/208b<S0040:ZZZP2][Jd0[Jf]0;Bd]080Xj>S00@0[Jf]
0;:b/P2b/[80UYJF0P2KVi/0102IVIT0V9RH09RHV02SXj<20:^[Z`040:b/[02a/K40/K6a0;Ng]`80
/[:b00@0];Bd0;Vi^@2i^KT0^KVi0P2g]kL0102j^[X0]KFe0;Fe]@2a/K420<71`@040<S8b02f][H0
][Jf09NGU`80WIfM00@0`l?30;Rh^02h^;P0XZ:R0P2XZ:P0102NWYh0UYJF09JFUP2LW9`209ZJVP04
08R8R027QhL0QhN708n?S`80TY:B00@0V9RH09jNWP2NWYh0UYJF0P27QhL309>CT`0409NGU`2QXJ40
XJ6Q07MgM`80=CDe00@02PX:00820P020P800@410P092@T0100?3`l02`/;00/;2`0>3Ph200/;2`04
00D51@061PH01PH600`<30802`/;00@00@4100D51@051@D01`L70P020P8300@410<00P820@051@D1
00H61P401PH6000010051@D020P800P8200820P200820P0400D51@0=3@d03@d=00h>3P801@D500@0
1`L700T92@092@T01@D50P0:2PX010071`L00@4100410@051@D200<30`0300L71`0;2`/02`/;00<0
20P800@01PH600@4100410@01@D50`071`L200D51@0400P820092@T02@T900<30`801PH600@02PX:
00@4100410@01@D50P061PH0100410@00P8200820P0820P201`L700402XZ:P0M7Ad07AdM01XJ6P80
<30`00@0A4A403@d=00d=3@09RHV0P0Q8B40100820P00`<300<30`0410@200H61P0400D51@0820P0
20P8010@40802PX:00@07alO04A4A014A4@0ATI60P1CDe<0100n?Sh0<S8b038b<P10@40202`/;004
02LW9`0410@010@4018B4P806ATI00@01`L700d=3@0=3@d03@d=0P071`L010092@T020P800P82009
2@T202@T900403Ph>01<C4`0C4a<05EEE@80GUiN0`1TI6@0101SHf<0FEUI05UIF@1IFET207inOP04
06][J`0Z:RX0:RXZ024Q8@80:b/[00@0>3Ph04U9B@19BDT0;Rh^0P0B4Q80100W9bL0ADE504E5A@16
ATH204a<C00404e=C@19BDT0BDU9055AD@80EUIF00@0CDe=0410@010@400@T920P1JFUX0101/K6`0
IfMW06MWI`1GEeL204M7A`0404E5A@1=CDd0CDe=05=CD`80GUiN00@0FUYJ059BDP1BDU80IVIV0P1k
Ng/0101[Jf/0MGEe07EeM@1dM7@2079bLP0408B4Q026QXH0QXJ6071`L080MWIf00@0HV9R0820P020
P800U9BD0P1_Kfl0102>SXh0MWIf07IfMP1OGel207YjNP0405EEE@1CDe<0De=C071`L080MWIf00@0
GUiN06IVIP1VIVH0Ng]k0P1OGel01016ATH0?Cdm03dm?@13@d<2055AD@0305UIF@1[Jf/0Jf][00<0
LG5a00@0GemO055AD@1ADE40IVIV0P1/K6`0101=CDd0=3@d03@d=00l?3`2034a<@0401hN7P0[:b/0
:b/[01`L70802PX:00@05QHF02XZ:P0Z:RX0?Shn0P1IFET0101@D500@4100410@01JFUX2065QH@04
071`L022PX80PX:208V9R@80[Zj^00@0^k^k0:b/[02/[:`0[jn_0P2XZ:P0102_[jl0/K6a0;6a/@2V
YZH209NGU`0408V9R@2DU9@0U9BD07]kN`80S8b<00@0ZZZZ0:f][@2][Jd0];Bd0P2SXj<0102][Jd0
/[:b0;:b/P2FUYH209^KV`0409VIV@2HV9P0V9RH0:>SX`80Zj^[00@0[:b/0;6a/@2a/K40]kNg0P2b
/[80102d];@0^KVi0;Vi^@2i^KT20;Ng]`040;Zj^P2e]KD0]KFe0;6a/@80`L7100@0b<S80;Jf]P2f
][H0UiNG0P2MWId01033`l<0^;Rh0;Rh^02RXZ820:RXZ00409jNWP2FUYH0UYJF09bLW080VYZJ00@0
R8R808N7Q`27QhL0Shn?0P2BTY80102HV9P0WYjN09jNWP2FUYH208N7Q`<0Ti>C00@0UiNG0:6QX@2Q
XJ40MgMg0P0e=CD0100:2PX00P8200820P010@4200T92@0400l?3`0;2`/02`/;00h>3P802`/;00@0
1@D500H61P061PH030`<0P0;2`/010010@401@D500D51@071`L200820P<010@40`020P8100D51@40
1PH60@061PH0000300820P0410@010@400<01`L700@02@T900`<300<30`0410@0P0>3Ph300/;2`04
00d=3@0?3`l03`l?00T92@801PH600@010@400410@010@401PH60P051@D0100820P02@T900T92@03
0`<200L71`0400P8200410@010@400@410801@D500@020P800H61P061PH000000P010@4010020P80
1PH600H61P0410@200<30`0400L71`000000000000P820809BDU00@0:2PX01lO7`0O7al0;Rh^0P10
@400100o?cl0<C4a034a<@0_;bl201/K6`0400T92@0=3@d03@d=00P820802PX:00@01`L700D51@05
1@D02@T90P0;2`/0100N7Qh0>3Ph03Ph>00i>CT203dm?@0402XZ:P0g=cL0=cLg04M7A`80?clo00@0
=SHf01HF5P0F5QH09bLW0P0M7Ad0100=3@d01`L700L71`092@T200<30`0400@410071`L01`L7010@
40808b<S00@0>c/k05ADE01DE5@0E5AD0P1GEeL0101TI6@0HV9R069RHP1RHV8205UIF@04065QH@1n
OWh0OWin04m?C`80?clo00@0B4Q8051@D01@D500?clo0P14A4@0100m?Cd05QHF01HF5P0];Bd203lo
?`0403hn?P1@D500D51@04m?C`80AdM700@0C4a<05=CD`1CDe<0GEeM0P1=CDd0100k>c/0De=C05=C
D`1fMWH206m_K`0405mOG`1HF5P0F5QH0410@080?clo00@0D51@05UIF@1IFET0GemO0P1KFe/0101F
EUH0Kfm_06m_K`1mOGd20820P00406QXJ01TI6@0I6AT07AdM080R8R800@0Jf][05YJFP1JFUX0G5aL
0P1bLW80102<S8`0MgMg07MgM`2FUYH208>3P`0406QXJ01/K6`0K6a/04a<C080CTi>00@0GUiN07Ad
M01dM7@0Kfm_0P1bLW80101cLg<0FEUI05UIF@1EEED207EeM@0406m_K`1HF5P0F5QH05YJFP80Fe]K
00@0GEeM06UYJ@1YJFT0IVIV0P1EEED0101KFe/0J6QX06QXJ01LG5`203hn?P0402PX:00R8R808R8R
02@T9080820P0`0@4100100N7Qh0=CDe03De=@18B4P204];B`0404=3@`15ADD0ADE5061PH080Kfm_
00@0P820092@T02@T900ZJVY0P2i^KT0102e]KD0YjNW0:NWY`2o_kl20;Vi^@040;2`/02_[jl0[jn_
09fMW@80QXJ600@0Ph>30:6QX@2QXJ40JFUY0P24Q8@0102^[Zh0YZJV0:JVYP2_[jl20:6QX@040:NW
Y`2XZ:P0Z:RX09VIV@80TY:B00@0VYZJ0:BTY02TY:@0WinO0P2RXZ80102`/;00/k>c0;>c/`2c/k<2
0;2`/0040;>c/`2l_;`0_;bl0;Rh^080[jn_00@0];Bd0;no_`2o_kl0`/;20P30`<001031`L40Zj^[
0:^[Z`2GUiL20;2`/0040;Zj^P2RXZ80XZ:R0:6QX@80YJFU00@0VYZJ0:6QX@2QXJ40Z:RX0P2UYJD0
102FUYH0S8b<08b<S02DU9@209ZJVP040:6QX@2TY:@0Y:BT09fMW@<0YZJV0P24Q8@0102>SXh0VYZJ
09ZJVP1XJ6P202@T900400410@051@D01@D500L71`801PH600@02@T900P8200820P02@T90P0820P0
100410@00`<300<30`061PH200X:2P0400D51@000000000000820P800`<300@0000000410@010@40
0`<31@0410@000<01@D500@00`<300H61P061PH01PH60P030`<010051@D03@d=00d=3@0B4Q8200l?
3`04018B4P0;2`/02`/;00820P8010@400@00`<300D51@051@D00P820P00000010061PH01`L700L7
1`092@T200L71`0400<30`0410@010@400@41080000000@01@D500T92@092@T01@D50P010@401004
10@02`/;00/;2`051@D20000000400820P030`<00`<300L71`807QhN00@0:BTY02DU9@0U9BD0;2`/
0P0i>CT0100j>SX0<S8b038b<P0g=cL201`L700400d=3@0E5AD05ADE00`<308020P800@02@T900P8
200820P00P820P0>3Ph0100N7Qh0:2PX02PX:00g=cL204U9B@040410@01?Cdl0Cdm?04a<C080@410
00@0<30`018B4P0B4Q806ATI0P0=3@d00`0D51@020P800P8200400P820801PH600@02`/;02HV9P0V
9RH0?Cdm0P1CDe<0101EEED0FEUI05UIF@1QHF4205EEE@04069RHP1KFe/0Fe]K06ATI080Kfm_00@0
A4A405]KF`1KFe/0GemO0P1/K6`01019BDT0>SXj03Xj>P0i>CT201PH600402DU9@0i>CT0>CTi03`l
?080BTY:00@0CTi>04U9B@19BDT0E5AD0P1OGel0101WIfL0Fe]K05]KF`11@D4204E5A@<0K6a/00@0
DU9B04=3@`13@d<0>c/k0P14A4@0100n?Sh0@D510451@@1KFe/306e]K@80LW9b00@0O7al08^;R`2;
Rh/0KFe]0P1RHV80101`L700QXJ608J6QP1YJFT205UIF@0407EeM@1/K6`0K6a/07EeM@80L71`00@0
NWYj07]kN`1kNg/0I6AT0P1KFe/0101@D500GUiN05iNGP1WIfL2065QH@0405QHF01@D500D51@04i>
CP80G5aL00@0GEeM075aL@1aLG40LG5a0P1HF5P0101CDe<0FEUI05UIF@1XJ6P206m_K`0404m?C`14
A4@0A4A405eMG@80JFUY00@0HF5Q04m?C`1?Cdl0@4100P0k>c/0100Z:RX02`/;00/;2`010@4200T9
2@0402LW9`1:BTX0BTY:05IFEP80@d=300@0>3Ph04Y:BP1:BTX0Jf][0P28R8P0102;Rh/0T92@092@
T02g]kL20;>c/`040;Ng]`2d];@0];Bd0;jn_P80^KVi00@0[:b/0:JVYP2VYZH0Shn?0P1kNg/0102<
S8`0Xj>S0:>SX`1RHV8207inOP040:RXZ02QXJ40XJ6Q0:VYZ@80X:2P00@0Vi^K09fMW@2MWId0WIfM
0P2>SXh0102EUID0UiNG09NGU`2IVIT209ZJVP040:n_[`2m_Kd0_Kfm0;Fe]@<0]kNg0P2b/[80102Z
ZZX0ZJVY0:VYZ@2h^;P20;no_`040<?3``31`L40`L710;bl_080VIVI00@0VYZJ0;^k^`2k^k/0[:b/
0P2RXZ80102_[jl0ZJVY0:VYZ@2QXJ420:BTY0<0V9RH00@0WIfM09NGU`2GUiL0XZ:R0P2SXj<0102O
Wil0ZJVY0:VYZ@2][Jd20:^[Z`0409JFUP20P800P82008J6QP80PX:200@0GemO02`/;00/;2`020P8
0P0<30`00`0B4Q802@T900T92@0300<30`0400410@030`<00`<300P820802`/;00@01`L700410@01
0@4010@40P061PH010051@D01PH600H61P020P8200410@0300H61P092@T02@T900<01PH6000300D5
1@0400<30`061PH01PH600H61P800`<300@01@D500d=3@0=3@d04Q8B0P0?3`l0100B4Q802`/;00/;
2`020P8200@4100400<30`051@D01@D500820P80000000@01PH600L71`071`L02@T90P071`L01003
0`<010@400@4100410@20000000400D51@092@T02@T900D51@800@4100@010@400/;2`0;2`/01@D5
0P00000010020P800`<300<30`071`L201hN7P0402TY:@0U9BD09BDU02`/;080>CTi00@0>SXj038b
<P0b<S80=cLg0P0L71`0100=3@d05ADE01DE5@0<30`200P8200400T92@0820P020P800820P803Ph>
00@07QhN02PX:00X:2P0=cLg0P19BDT01010@400Cdm?04m?C`1<C4`20410@004030`<00B4Q804Q8B
01TI6@803@d=00<051@D00P8200820P0100820P200H61P0400/;2`0V9RH09RHV03dm?@80De=C00@0
EEEE05UIF@1IFET0HF5Q0P1EEED0101RHV80Fe]K05]KF`1TI6@206m_K`0404A4A01KFe/0Fe]K05mO
G`80K6a/00@0BDU903Xj>P0j>SX0>CTi0P0H61P0100U9BD0>CTi03Ti>@0l?3`204Y:BP0404i>CP19
BDT0BDU905ADE080GemO00@0IfMW05]KF`1KFe/0@D510P15ADD306a/K004059BDP13@d<0@d=303/k
>`80A4A400@0?Shn0451@@11@D40Fe]K0`1]KFd2079bLP0407alO02;Rh/0Rh^;06e]K@80HV9R00@0
L71`08J6QP26QXH0JFUY0P1IFET0101eMGD0K6a/06a/K01eMGD2071`L00407YjNP1kNg/0Ng]k06AT
I080Fe]K00@0D51@05iNGP1NGUh0IfMW0P1QHF40101HF5P0D51@051@D01>CTh205aLG00405eMG@1a
LG40LG5a075aL@80F5QH00@0De=C05UIF@1IFET0J6QX0P1_Kfl0101?Cdl0A4A404A4A01MGEd206UY
J@04065QH@1?Cdl0Cdm?0410@080>c/k00@0:RXZ00/;2`0;2`/00@410P092@T0100W9bL0BTY:04Y:
BP1FEUH204=3@`0403Ph>01:BTX0BTY:06][J`80R8R800@0Rh^;092@T02@T900]kNg0P2c/k<0102g
]kL0];Bd0;Bd]02n_[h20;Vi^@040:b/[02VYZH0YZJV08n?S`80Ng]k00@0S8b<0:>SX`2SXj<0HV9R
0P1nOWh0102XZ:P0XJ6Q0:6QX@2YZJT20:2PX00409^KV`2MWId0WIfM09fMW@80SXj>00@0UIFE09NG
U`2GUiL0VIVI0P2JVYX0102_[jl0_Kfm0;fm_@2e]KD30;Ng]`80/[:b00@0ZZZZ0:VYZ@2YZJT0^;Rh
0P2o_kl01033`l<0`L710<71`@2l_;`209VIV@0409ZJVP2k^k/0^k^k0:b/[080XZ:R00@0[jn_0:VY
Z@2YZJT0XJ6Q0P2TY:@309RHV00409fMW@2GUiL0UiNG0::RXP80Xj>S00@0WinO0:VYZ@2YZJT0[Jf]
0P2[Zj/0102FUYH0P8200820P026QXH208:2PP0405mOG`0/;2`0;2`/00P8208030`<00<04Q8B00T9
2@092@T00`030`<010010@400`<300<30`0820P200/;2`0400L71`010@400@4100@410801PH600@0
1@D500H61P061PH00P820P010@400`061PH02@T900T92@0300H61P0000@02@T900D51@051@D00@41
0P0410@010061PH01`L700L71`071`L200`<3004018B4P0:2PX02PX:00T92@801`L700@010@400<3
0`030`<00P820P061PH300@4100400D51@030`<00`<3010@40802@T900@0000000<30`030`<01@D5
0P020P8010051@D01PH600H61P051@D200@4100400L71`092@T02@T900@410800P8200@00`<300D5
1@051@D00`<30P0@4100100W9bL0:2PX02PX:00L71`202/[:`0403@d=00/;2`0;2`/038b<P8071`L
00@03Ph>01HF5P0F5QH0410@0P0>3Ph0100820P00`<300<30`020P8200h>3P0402PX:00h>3P0>3Ph
04U9B@80EEEE00@0?3`l0410@010@400>c/k0P0^;Rh0100B4Q800P8200820P0@410200T92@0400X:
2P092@T02@T9018B4P801`L700@06ATI00/;2`0;2`/03@d=0P0V9RH0100k>c/0Cdm?04m?C`1EEED2
05IFEP0405aLG01KFe/0Fe]K06QXJ080De=C00@0KFe]06QXJ01XJ6P0BDU90P1VIVH0101QHF40MgMg
07MgM`1LG5`204A4A00403Lg=`0J6QX06QXJ01TI6@80<S8b00@0?Cdm04Y:BP1:BTX0ATI60P0o?cl0
101FEUH0FUYJ05YJFP18B4P204U9B@0405eMG@1KFe/0Fe]K05iNGP80I6AT00@0F5QH04e=C@1=CDd0
B4Q80P1=CDd01017AdL0A4A404A4A01:BTX205aLG004069RHP1dM7@0M7Ad07YjNP80M7Ad00@0H61P
06YZJP1ZJVX0Ogmo0P23Ph<0101^KVh0L71`071`L01hN7P206i^KP0407=cL`1QHF40HF5Q075aL@80
MGEe00@0G5aL06EUI@1UIFD0EUIF0P1^KVh0101fMWH0Bd];04];B`1JFUX2055AD@0404I6AP1VIVH0
IVIV05aLG080EeMG00@0KFe]06YZJP1ZJVX0D51@0P1>CTh0101PH600EUIF05IFEP0l?3`205QHF004
06UYJ@19BDT0BDU905EEE@80HF5Q00@0@T9202l_;`0_;bl061PH0P020P8010071`L05ADE01DE5@0d
=3@205eMG@0405YJFP0f=SH0=SHf03Ph>080GemO00@0MgMg08R8R028R8P0UYJF0P2LW9`0102WYjL0
W9bL09bLW02][Jd20;Ng]`040;Rh^02_[jl0[jn_09jNWP80W9bL00@0R8R80820P020P800X:2P0P2J
VYX0101]KFd0L71`071`L02DU9@209jNWP040:2PX02SXj<0Xj>S09nOW`80X:2P00@0Rh^;07MgM`1g
MgL0PX:20P26QXH308f=S@040:^[Z`2n_[h0_[jn0;Ng]`80/[:b00@0Z:RX0:FUY@2UYJD0ZJVY0P2e
]KD0102k^k/0/K6a0;6a/@2f][H20<;2`P040;6a/@20P800P820096AT@80];Bd00@0Zj^[0:ZZZP2Z
ZZX0YjNW0`2RXZ8209jNWP0409fMW@2JVYX0VYZJ09bLW080WinO00@0Xj>S09^KV`2KVi/0TY:B0P2Q
XJ40102/[:`0VYZJ09ZJVP20P80307alO080MWIf00@0F5QH02@T900T92@01`L70P0820P0100>3Ph0
1`L700L71`010@4200P8200400D51@020P800P8200P820D01`L700@010@400H61P061PH010@40P02
0P8010010@401@D500D51@0820P200@410401`L70@0?3`l100l?3`0000@02PX:00H61P061PH00000
0P030`<0100;2`/03Ph>00h>3P0;2`/200h>3P04018B4P071`L01`L700X:2P804A4A00@02PX:00H6
1P061PH01PH60P071`L400H61P802PX:00@030`<00@4100410@00@410P030`<010071`L01PH600H6
1P051@D200820P0300D51@092@T02@T900<010@400<01@D500820P020P800`061PH0100000003@d=
00d=3@0Z:RX202HV9P0401TI6@0^;Rh0;Rh^03<c<`808b<S00@09bLW01PH600H61P02`/;0P0F5QH0
100=3@d04a<C01<C4`0;2`/200820P040000000820P020P802h^;P80@41000@0>3Ph034a<@0a<C40
8b<S0P0_;bl0100e=CD07QhN01hN7P0@4102014A4@0401/K6`0>3Ph03Ph>01DE5@805aLG00@03@d=
018B4P0B4Q804Q8B0P0<30`0100;2`/09RHV02HV9P13@d<204];B`04069RHP1TI6@0I6AT05iNGP80
IVIV00@0J6QX051@D01@D500Ogmo0P1SHf<0101JFUX0MgMg07MgM`1RHV82071`L00405iNGP13@d<0
@d=303Hf=P806ATI00@05QHF038b<P0b<S80>3Ph0P17AdL01015ADD0<c<c03<c<`16ATH205=CD`03
04];B`17AdL0AdM700<0EEEE00@0EeMG06QXJ01XJ6P0G5aL0P1FEUH01014A4@0>3Ph03Ph>01LG5`2
05IFEP0404Y:BP1NGUh0GUiN04A4A080IVIV00@0Shn?07inOP1nOWh0I6AT0P1aLG40101mOGd0PX:2
08:2PP1gMgL207UiN@<0LW9b00@0Lg=c065QH@1QHF40MGEe0P1fMWH0101KFe/0BTY:04Y:BP0`<302
04a<C00405mOG`1GEeL0EeMG07MgM`80J6QX00@0AdM705YJFP1JFUX0GEeM0P1QHF40101bLW80K6a/
06a/K019BDT204m?C`04061PH01IFET0FEUI05EEE@80EUIF00@0@41002h^;P0^;Rh0DU9B0P1JFUX0
0`0g=cL071`L01`L700300/;2`0401DE5@0/;2`0;2`/0410@080G5aL00@0DE5A03<c<`0c<c<0BDU9
0P1aLG401029RHT0U9BD09BDU02_[jl20;>c/`0409^KV`2HV9P0V9RH0:NWY`80[Zj^00@0/;2`0:f]
[@2][Jd0VYZJ0P2@T900101hN7P0Q8B408B4Q02PX:0208B4Q00407]kN`1cLg<0Lg=c0820P080VIVI
00@0WIfM0:2PX02PX:00WIfM0P2EUID0101XJ6P0EUIF05IFEP24Q8@2092@T00408V9R@2?Shl0Shn?
0:JVYP80YjNW00@0Z:RX0:6QX@2QXJ40UYJF0P2RXZ80102^[Zh0/[:b0;:b/P2a/K420:n_[`040;Jf
]P2k^k/0^k^k09nOW`80Ph>300@0X:2P0;6a/@2a/K40];Bd0P2f][H0102WYjL0YJFU0:FUY@2RXZ82
09^KV`0409bLW02<S8`0S8b<092@T080XZ:R00@0Vi^K09BDU02DU9@0W9bL0P2_[jl0102/[:`0TY:B
09:BTP1iNGT207IfMP0408b<S02;Rh/0Rh^;05=CD`805aLG00<0000000410@010@400`030`<00`04
10@01PH600H61P0300H61P0400X:2P051@D01@D500820P802@T900@020P800X:2P0:2PX01PH60P03
0`<0100410@01@D500D51@0;2`/200L71`401@D50@0=3@d100d=3@0000@02PX:00H61P061PH00000
0P030`<0100;2`/03Ph>00h>3P0;2`/200h>3P04018B4P071`L01`L700X:2P804A4A00@02PX:00H6
1P061PH01PH60P071`L400H61P802PX:00@030`<00@4100410@00@410P030`<010071`L01PH600H6
1P051@D200820P0300D51@092@T02@T900<010@400<01@D500820P020P800`061PH0100000003@d=
00d=3@0Z:RX202HV9P0401TI6@0^;Rh0;Rh^03<c<`808b<S00@09bLW01PH600H61P02`/;0P0F5QH0
100=3@d04a<C01<C4`0;2`/200820P040000000820P020P802h^;P80@41000@0>3Ph034a<@0a<C40
8b<S0P0_;bl0100e=CD07QhN01hN7P0@4102014A4@0401/K6`0>3Ph03Ph>01DE5@805aLG00@03@d=
018B4P0B4Q804Q8B0P0<30`0100;2`/09RHV02HV9P13@d<204];B`04069RHP1TI6@0I6AT05iNGP80
IVIV00@0J6QX051@D01@D500Ogmo0P1SHf<0101JFUX0MgMg07MgM`1RHV82071`L00405iNGP13@d<0
@d=303Hf=P806ATI00@05QHF038b<P0b<S80>3Ph0P17AdL01015ADD0<c<c03<c<`16ATH205=CD`03
04];B`17AdL0AdM700<0EEEE00@0EeMG06QXJ01XJ6P0G5aL0P1FEUH01014A4@0>3Ph03Ph>01LG5`2
05IFEP0404Y:BP1NGUh0GUiN04A4A080IVIV00@0Shn?07inOP1nOWh0I6AT0P1aLG40101mOGd0PX:2
08:2PP1gMgL207UiN@<0LW9b00@0Lg=c065QH@1QHF40MGEe0P1fMWH0101KFe/0BTY:04Y:BP0`<302
04a<C00405mOG`1GEeL0EeMG07MgM`80J6QX00@0AdM705YJFP1JFUX0GEeM0P1QHF40101bLW80K6a/
06a/K019BDT204m?C`04061PH01IFET0FEUI05EEE@80EUIF00@0@41002h^;P0^;Rh0DU9B0P1JFUX0
0`0g=cL071`L01`L700300/;2`0401DE5@0/;2`0;2`/0410@080G5aL00@0DE5A03<c<`0c<c<0BDU9
0P1aLG401029RHT0U9BD09BDU02_[jl20;>c/`0409^KV`2HV9P0V9RH0:NWY`80[Zj^00@0/;2`0:f]
[@2][Jd0VYZJ0P2@T900101hN7P0Q8B408B4Q02PX:0208B4Q00407]kN`1cLg<0Lg=c0820P080VIVI
00@0WIfM0:2PX02PX:00WIfM0P2EUID0101XJ6P0EUIF05IFEP24Q8@2092@T00408V9R@2?Shl0Shn?
0:JVYP80YjNW00@0Z:RX0:6QX@2QXJ40UYJF0P2RXZ80102^[Zh0/[:b0;:b/P2a/K420:n_[`040;Jf
]P2k^k/0^k^k09nOW`80Ph>300@0X:2P0;6a/@2a/K40];Bd0P2f][H0102WYjL0YJFU0:FUY@2RXZ82
09^KV`0409bLW02<S8`0S8b<092@T080XZ:R00@0Vi^K09BDU02DU9@0W9bL0P2_[jl0102/[:`0TY:B
09:BTP1iNGT207IfMP0408b<S02;Rh/0Rh^;05=CD`805aLG00<0000000410@010@400`030`<00`04
10@01PH600H61P0300H61P0400X:2P051@D01@D500820P802@T900@020P800X:2P0:2PX01PH60P03
0`<0100410@01@D500D51@0;2`/200L71`401@D50@0=3@d100d=3@0000@01PH600X:2P0:2PX01PH6
0P020P8010092@T020P800P8200820P200`<300400T92@0410@010@400X:2P8030`<00@010@400L7
1`071`L010@40P010@4300H61P0400<30`0820P020P800P820801@D500@020P800L71`071`L01PH6
0P051@D0100820P01`L700L71`051@D200<30`0400D51@0820P020P800<30`80000000@01PH600L7
1`071`L00P820P0K6a/0100_;bl092@T02@T900Y:BT30410@0<0:BTY0P0L71`0100<30`05ADE01DE
5@0<30`200h>3P0400/;2`051@D01@D500<30`801PH600@061PH02d];@0];Bd0;Rh^0P0g=cL0100X
:2P0:BTY02TY:@0W9bL2014A4@0401/K6`0B4Q804Q8B00@410801@D50`0F5QH0100410@030`<00`<
300>3Ph2014A4@0400X:2P0O7al07alO03lo?`80@41000@0GemO06YZJP1ZJVX0GEeM0P1YJFT0101T
I6@0EEEE05EEE@1nOWh205eMG@04079bLP26QXH0QXJ606QXJ080LG5a00@0HV9R03Lg=`0g=cL0<30`
0P0Q8B40100>3Ph08b<S02<S8`0f=SH204E5A@0404a<C010@400@41004=3@`<0C4a<0P13@d<01019
BDT0DE5A055AD@1OGel2071`L00405EEE@1<C4`0C4a<04E5A@80=3@d00@0FEUI04m?C`1?Cdl0De=C
0P1QHF40100k>c/0JFUY06UYJ@2ATI4208Z:RP0406UYJ@1TI6@0I6AT07MgM`80QhN700@0PH6107]k
N`1kNg/0M7Ad0`20P80207]kN`0406m_K`1cLg<0Lg=c06a/K080F5QH00@0B4Q805ADE01DE5@0JFUY
0P1_Kfl0101[Jf/0KVi^06i^KP1OGel205eMG@0406ATI01^KVh0KVi^071`L080EUIF00@0=3@d04U9
B@19BDT0Hf=S0P1OGel0101EEED0D51@051@D013@d<204A4A00405UIF@1BDU80DU9B04a<C080?Shn
00@03@d=00820P020P8071`L0P0g=cL0100o?cl0CTi>04i>CP17AdL20451@@0406=SH`1_Kfl0Kfm_
08j>SP80Z:RX00@0[jn_0:FUY@2UYJD0UYJF0P2LW9`0102TY:@0[:b/0:b/[02YZJT20:BTY00409RH
V029RHT0RHV906i^KP80SHf=00@0UiNG0820P020P800Rh^;0P26QXH00`1hN7P0RXZ:08Z:RP0309ZJ
VP0409FEU@22PX80PX:204I6AP80A4A400@0Shn?09NGU`2GUiL0Shn?0P2JVYX0102/[:`0YZJV0:JV
YP2UYJD20::RXP0409fMW@2QXJ40XJ6Q0:^[Z`80YZJV00@0Xj>S0:j^[P2^[Zh0]kNg0P2XZ:P0102?
Shl0UYJF09JFUP2UYJD20:f][@040;Rh^02a/K40/K6a0:6QX@80XZ:R00@0Xj>S0::RXP2RXZ80WinO
0P28R8P0102BTY80[Jf]0:f][@2OWil209FEU@040:FUY@2c/k<0/k>c0:2PX080QHF50`1dM7@0102F
UYH0SHf=08f=S@17AdL201PH600300P8200410@010@400<010@400@01@D500T92@092@T02PX:0P09
2@T0100:2PX02`/;00/;2`061PH20000000400@4100;2`/02`/;00H61P8010@400@01@D500820P02
0P8010@40P0820P100D51@402`/;0@0;2`/000040000000?3`l03`l?00h>3P80000000@01PH600L7
1`071`L02PX:0P0@4100100820P01@D500D51@092@T200820P0400@410061PH01PH600D51@800P82
00@02@T900D51@051@D01`L70`0;2`/300T92@8010@400@0000000820P020P801PH60`071`L200H6
1P<00P8200@01`L700H61P061PH01PH60P051@D0100;2`/07alO01lO7`0U9BD201/K6`0402<S8`0n
?Sh0?Shn04Q8B080>3Ph00@0;Rh^01XJ6P0J6QX04A4A0P0H61P0100:2PX020P800P820071`L200P8
200400L71`092@T02@T901`L7080?clo00@0@T9204A4A014A4@0;bl_0P0^;Rh0100c<c<030`<00`<
300F5QH2018B4P0400X:2P0?3`l03`l?018B4P8030`<00@02PX:00410@010@402`/;0P0A4A40100?
3`l06QXJ01XJ6P0e=CD204M7A`0405=CD`1QHF40HF5Q061PH080IfMW00@0HF5Q06ATI01TI6@0KFe]
0P1FEUH0101jNWX0Ng]k07]kN`1VIVH206EUI@0405aLG00b<S80<S8b03@d=0809bLW00@0000001PH
600H61P0@4100P14A4@0101ADE40Cdm?04m?C`15ADD203hn?P040492@P1>CTh0CTi>05ADE080FUYJ
00@0IFEU06IVIP1VIVH0CDe=0P14A4@0101DE5@0KFe]06e]K@1^KVh203<c<`0404A4A01QHF40HF5Q
04i>CP<0KFe]0P1gMgL0101WIfL0JVYZ06YZJP1gMgL207moO`0407alO02;Rh/0Rh^;06e]K@80H61P
00@0Lg=c07alO01lO7`0Lg=c0P1`L700101QHF40IFEU06EUI@1aLG4206UYJ@0407IfMP1JFUX0FUYJ
04];B`80Hf=S00@0GemO06IVIP1VIVH0P8200P1cLg<0101SHf<0GemO05mOG`1IFET2069RHP0406IV
IP1CDe<0De=C04e=C@80EeMG00@0D51@05IFEP1FEUH0K6a/0P1NGUh0101>CTh0>CTi03Ti>@0;2`/2
014A4@0403<c<`13@d<0@d=304a<C080GemO00@0B4Q80451@@11@D40H61P0P1dM7@0102;Rh/0WIfM
09fMW@2JVYX209NGU`0409ZJVP2NWYh0WYjN09bLW080XZ:R00@0WinO09JFUP2FUYH0RXZ:0P27QhL0
0`25QHD0VIVI09VIV@0309:BTP<0VIVI00@0SHf=08:2PP22PX80Ph>30P2:RXX0102ATI40MgMg07Mg
M`0h>3P20410@00408F5Q@2PX:00X:2P0:VYZ@80ZZZZ00@0/K6a0:f][@2][Jd0YjNW0`2PX:0209^K
V`0409RHV02MWId0WIfM0::RXP80U9BD00@0WYjN09FEU@2EUID0RHV90P2EUID0102ATI40Xj>S0:>S
X`2ZZZX309JFUP80YJFU00@0Zj^[0:b/[02/[:`0YjNW0P29RHT0102@T900[Zj^0:j^[P2HV9P208B4
Q00409FEU@2IVIT0VIVI08j>SP80TY:B00@0VIVI08^;R`2;Rh/0QhN70P1cLg<0100c<c<030`<00`<
30051@D300P8208010@400@02PX:00l?3`0?3`l01`L70P061PH0100820P02@T900T92@0410@20082
0P0400P820051@D01@D500<30`8010@400@02PX:00T92@092@T010@40P092@T100H61P4010@40@04
10@000040000000?3`l03`l?00h>3P80000000@01PH600L71`071`L02PX:0P0@4100100820P01@D5
00D51@092@T200820P0400@410061PH01PH600D51@800P8200@02@T900D51@051@D01`L70`0;2`/3
00T92@8010@400@0000000820P020P801PH60`071`L200H61P<00P8200@01`L700H61P061PH01PH6
0P051@D0100;2`/07alO01lO7`0U9BD201/K6`0402<S8`0n?Sh0?Shn04Q8B080>3Ph00@0;Rh^01XJ
6P0J6QX04A4A0P0H61P0100:2PX020P800P820071`L200P8200400L71`092@T02@T901`L7080?clo
00@0@T9204A4A014A4@0;bl_0P0^;Rh0100c<c<030`<00`<300F5QH2018B4P0400X:2P0?3`l03`l?
018B4P8030`<00@02PX:00410@010@402`/;0P0A4A40100?3`l06QXJ01XJ6P0e=CD204M7A`0405=C
D`1QHF40HF5Q061PH080IfMW00@0HF5Q06ATI01TI6@0KFe]0P1FEUH0101jNWX0Ng]k07]kN`1VIVH2
06EUI@0405aLG00b<S80<S8b03@d=0809bLW00@0000001PH600H61P0@4100P14A4@0101ADE40Cdm?
04m?C`15ADD203hn?P040492@P1>CTh0CTi>05ADE080FUYJ00@0IFEU06IVIP1VIVH0CDe=0P14A4@0
101DE5@0KFe]06e]K@1^KVh203<c<`0404A4A01QHF40HF5Q04i>CP<0KFe]0P1gMgL0101WIfL0JVYZ
06YZJP1gMgL207moO`0407alO02;Rh/0Rh^;06e]K@80H61P00@0Lg=c07alO01lO7`0Lg=c0P1`L700
101QHF40IFEU06EUI@1aLG4206UYJ@0407IfMP1JFUX0FUYJ04];B`80Hf=S00@0GemO06IVIP1VIVH0
P8200P1cLg<0101SHf<0GemO05mOG`1IFET2069RHP0406IVIP1CDe<0De=C04e=C@80EeMG00@0D51@
05IFEP1FEUH0K6a/0P1NGUh0101>CTh0>CTi03Ti>@0;2`/2014A4@0403<c<`13@d<0@d=304a<C080
GemO00@0B4Q80451@@11@D40H61P0P1dM7@0102;Rh/0WIfM09fMW@2JVYX209NGU`0409ZJVP2NWYh0
WYjN09bLW080XZ:R00@0WinO09JFUP2FUYH0RXZ:0P27QhL00`25QHD0VIVI09VIV@0309:BTP<0VIVI
00@0SHf=08:2PP22PX80Ph>30P2:RXX0102ATI40MgMg07MgM`0h>3P20410@00408F5Q@2PX:00X:2P
0:VYZ@80ZZZZ00@0/K6a0:f][@2][Jd0YjNW0`2PX:0209^KV`0409RHV02MWId0WIfM0::RXP80U9BD
00@0WYjN09FEU@2EUID0RHV90P2EUID0102ATI40Xj>S0:>SX`2ZZZX309JFUP80YJFU00@0Zj^[0:b/
[02/[:`0YjNW0P29RHT0102@T900[Zj^0:j^[P2HV9P208B4Q00409FEU@2IVIT0VIVI08j>SP80TY:B
00@0VIVI08^;R`2;Rh/0QhN70P1cLg<0100c<c<030`<00`<30051@D300P8208010@400@02PX:00l?
3`0?3`l01`L70P061PH0100820P02@T900T92@0410@200820P0400P820051@D01@D500<30`8010@4
00@02PX:00T92@092@T010@40P092@T100H61P4010@40@0410@0000400T92@0?3`l03`l?010@4080
2@T900@01PH600P8200820P03@d=0P0E5AD0100;2`/01`L700L71`061PH200@4100400L71`030`<0
0`<300H61P802PX:00@01PH600@4100410@020P80P0:2PX010061PH00P8200820P0410@200820P04
00@410010@400@4100<30`800P8200@01`L700`<300<30`01`L70P061PH010092@T02PX:00X:2P09
2@T200@4100400/;2`0Q8B408B4Q02h^;P809BDU00@07QhN038b<P0b<S80@4100P0e=CD0100/;2`0
4A4A014A4@0?3`l201hN7P04014A4@0<30`030`<00X:2P802@T900@00@4100H61P061PH09bLW0P12
@T8303De=@0401dM7@0P8200820P03<c<`8061PH00@07QhN00P8200820P03@d=0`0H61P200/;2`04
010@40030`<00`<300`<308020P800@03`l?01/K6`0K6a/0=CDe0P1EEED0101FEUH0H61P061PH01T
I6@206IVIP0405YJFP1/K6`0K6a/06=SH`80D51@00@0KVi^069RHP1RHV80I6AT0P1SHf<0101;Bd/0
<S8b038b<P0n?Sh202`/;00400410@0P8200820P04I6AP80BTY:00@0Bd];0410@010@400@D510P14
A4@0101CDe<0HF5Q065QH@1@D502055AD@0406][J`1]KFd0KFe]06IVIP80FUYJ00@0Bd];06EUI@1U
IFD0K6a/0P16ATH0101ADE40GemO05mOG`1HF5P205eMG@0405YJFP1`L700L71`06e]K@80Jf][00@0
KFe]07]kN`1kNg/0MgMg0P1oOgl0101ZJVX0IFEU06EUI@1eMGD2069RHP0406ATI01kNg/0Ng]k06YZ
JP80GUiN00@0Kfm_07AdM01dM7@0L71`0P1QHF40101kNg/0MWIf07IfMP1HF5P206=SH`0407emO@1`
L700L71`06=SH`80GUiN00@0GEeM05]KF`1KFe/0HF5Q0P1PH600101HF5P0C4a<04a<C00k>c/204U9
B@0406UYJ@1GEeL0EeMG038b<P806a/K00@02@T901PH600H61P0=CDe0P0o?cl01014A4@0DU9B059B
DP13@d<204Y:BP0405mOG`20P800P82008B4Q080R8R800@0S8b<09>CT`2CTi<0UiNG0P2LW9`309BD
U00409^KV`2:RXX0RXZ:07inOP80RXZ:00@0VYZJ09RHV02HV9P0UYJF0P2LW9`0102MWId0YZJV0:JV
YP2YZJT208j>SP040861P@29RHT0RHV908>3P`80JVYZ00@0ATI605MGE`1GEeL0Ph>30P2VYZH0102d
];@0][Jf0;Jf]P2e]KD20:VYZ@040::RXP2HV9P0V9RH08b<S080P82000@0QhN709ZJVP2JVYX0SHf=
0P1_Kfl0102<S8`0RHV908V9R@1fMWH208Z:RP0408f=S@2OWil0WinO09bLW080Rh^;00@0WinO0;Fe
]@2e]KD0^KVi0P2_[jl0102OWil0Rh^;08^;R`2DU9@20:VYZ@0409JFUP22PX80PX:208V9R@80QhN7
00@0SHf=0::RXP2RXZ80]kNg0P2a/K40102<S8`0J6QX06QXJ00e=CD2018B4P0300T92@071`L01`L7
00<00P8200@030`<00/;2`0;2`/00`<30`061PH200@4100300820P0410@010@400<03Ph>0`0820P3
00d=3@0400`<300;2`/02`/;00410@800P820000100=3@d01PH600H61P092@T300d=3@803Ph>00<0
2@T900L71`071`L00`0820P010061PH02@T900T92@071`L200@4100400<30`0;2`/02`/;00L71`80
10@400@00P8200<30`030`<01@D50P092@T010030`<00@4100410@051@D200L71`0400H61P051@D0
1@D5000000801PH600@030`<00/;2`0;2`/010@40P010@4010051@D00`<300<30`020P8201DE5@<0
:BTY00@0820P03Xj>P0j>SX0ADE50P0d=3@0100_;bl051@D01@D500410@300h>3P802@T90`051@D3
00L71`0400`<300@4100410@00410@802`/;00@03@d=00h>3P0>3Ph07QhN0P0E5AD0100B4Q8010@4
00@4100?3`l201<C4`0400l?3`0820P020P800l?3`8010@400@03`l?00/;2`0;2`/04Q8B0P0P8200
100c<c<0CTi>04i>CP1QHF4206EUI@<0IfMW00@0EEEE06QXJ01XJ6P0HV9R0P1KFe/00`1ZJVX0C4a<
04a<C00305aLG00403`l?011@D40@D5103lo?`808B4Q00@02PX:02TY:@0Y:BT0>c/k0P16ATH0101=
CDd0>SXj03Xj>P0n?Sh3059BDP80D51@00@0De=C065QH@1QHF40M7Ad0P1kNg/0101cLg<0GemO05mO
G`1@D50204=3@`040492@P1VIVH0IVIV07=cL`80EUIF00@0CDe=04Q8B018B4P0F5QH0P1dM7@0101b
LW80M7Ad07AdM01eMGD207=cL`0407EeM@1RHV80HV9R07]kN`80Q8B400@0MGEe061PH01PH600GEeM
0P1oOgl01023Ph<0MWIf07IfMP1^KVh207UiN@0407IfMP1SHf<0Hf=S07EeM@80LW9b00@0Lg=c075a
L@1aLG40HV9R0P1/K6`0101nOWh0I6AT06ATI01CDe<205UIF@0406=SH`1RHV80HV9R05YJFP80EUIF
00@0EeMG055AD@1ADE40D51@0P0m?Cd0100H61P0410@010@400820P200`<300402<S8`0c<c<0<c<c
0410@080BDU900@0DU9B06IVIP1VIVH0OGem0P29RHT0102=SHd0Rh^;08^;R`23Ph<308b<S080UYJF
00@0T92@08Z:RP2:RXX0TI6A0P1oOgl0102:RXX0WIfM09fMW@2UYJD209jNWP040::RXP2QXJ40XJ6Q
0:BTY080Z:RX00<0[:b/09BDU02DU9@00`2IVIT0101bLW80HF5Q065QH@1UIFD207MgM`0407inOP2@
T900T92@0:6QX@80YjNW00@0Y:BT09jNWP2NWYh0UIFE0P25QHD0101cLg<0IfMW06MWI`1eMGD207Mg
M`0406e]K@1cLg<0Lg=c09RHV080P82000@0F5QH0820P020P800UIFE0P2JVYX0102MWId0UYJF09JF
UP2OWil20:VYZ@040;>c/`2/[:`0[:b/0:BTY080WYjN00@0Vi^K09fMW@2MWId0Rh^;0P1dM7@0101m
OGd0UYJF09JFUP2OWil209jNWP040:NWY`2XZ:P0Z:RX08N7Q`80IFEU00<0>3Ph00T92@092@T00`05
1@D010061PH01@D500D51@010@4200@410<01`L700@00P8200H61P061PH02PX:0P092@T0100<30`0
2@T900T92@051@D200820P0400D51@0;2`/02`/;00`<30801PH60@0410@100P8204020P80000100=
3@d01PH600H61P092@T300d=3@803Ph>00<02@T900L71`071`L00`0820P010061PH02@T900T92@07
1`L200@4100400<30`0;2`/02`/;00L71`8010@400@00P8200<30`030`<01@D50P092@T010030`<0
0@4100410@051@D200L71`0400H61P051@D01@D5000000801PH600@030`<00/;2`0;2`/010@40P01
0@4010051@D00`<300<30`020P8201DE5@<0:BTY00@0820P03Xj>P0j>SX0ADE50P0d=3@0100_;bl0
51@D01@D500410@300h>3P802@T90`051@D300L71`0400`<300@4100410@00410@802`/;00@03@d=
00h>3P0>3Ph07QhN0P0E5AD0100B4Q8010@400@4100?3`l201<C4`0400l?3`0820P020P800l?3`80
10@400@03`l?00/;2`0;2`/04Q8B0P0P8200100c<c<0CTi>04i>CP1QHF4206EUI@<0IfMW00@0EEEE
06QXJ01XJ6P0HV9R0P1KFe/00`1ZJVX0C4a<04a<C00305aLG00403`l?011@D40@D5103lo?`808B4Q
00@02PX:02TY:@0Y:BT0>c/k0P16ATH0101=CDd0>SXj03Xj>P0n?Sh3059BDP80D51@00@0De=C065Q
H@1QHF40M7Ad0P1kNg/0101cLg<0GemO05mOG`1@D50204=3@`040492@P1VIVH0IVIV07=cL`80EUIF
00@0CDe=04Q8B018B4P0F5QH0P1dM7@0101bLW80M7Ad07AdM01eMGD207=cL`0407EeM@1RHV80HV9R
07]kN`80Q8B400@0MGEe061PH01PH600GEeM0P1oOgl01023Ph<0MWIf07IfMP1^KVh207UiN@0407If
MP1SHf<0Hf=S07EeM@80LW9b00@0Lg=c075aL@1aLG40HV9R0P1/K6`0101nOWh0I6AT06ATI01CDe<2
05UIF@0406=SH`1RHV80HV9R05YJFP80EUIF00@0EeMG055AD@1ADE40D51@0P0m?Cd0100H61P0410@
010@400820P200`<300402<S8`0c<c<0<c<c0410@080BDU900@0DU9B06IVIP1VIVH0OGem0P29RHT0
102=SHd0Rh^;08^;R`23Ph<308b<S080UYJF00@0T92@08Z:RP2:RXX0TI6A0P1oOgl0102:RXX0WIfM
09fMW@2UYJD209jNWP040::RXP2QXJ40XJ6Q0:BTY080Z:RX00<0[:b/09BDU02DU9@00`2IVIT0101b
LW80HF5Q065QH@1UIFD207MgM`0407inOP2@T900T92@0:6QX@80YjNW00@0Y:BT09jNWP2NWYh0UIFE
0P25QHD0101cLg<0IfMW06MWI`1eMGD207MgM`0406e]K@1cLg<0Lg=c09RHV080P82000@0F5QH0820
P020P800UIFE0P2JVYX0102MWId0UYJF09JFUP2OWil20:VYZ@040;>c/`2/[:`0[:b/0:BTY080WYjN
00@0Vi^K09fMW@2MWId0Rh^;0P1dM7@0101mOGd0UYJF09JFUP2OWil209jNWP040:NWY`2XZ:P0Z:RX
08N7Q`80IFEU00<0>3Ph00T92@092@T00`051@D010061PH01@D500D51@010@4200@410<01`L700@0
0P8200H61P061PH02PX:0P092@T0100<30`02@T900T92@051@D200820P0400D51@0;2`/02`/;00`<
30801PH60@0410@100P8204020P80000100;2`/010@400@410061PH200P820<03@d=00@01PH60041
0@010@402PX:0P071`L0100820P00@4100410@00000200P8200400820P0;2`/02`/;00`<308010@4
00@01PH600P8200820P01`L70P061PH010071`L010@400@41000000200L71`0400X:2P020P800P82
000000800`<300@010@400H61P061PH03@d=0P061PH300<30`0400@4100H61P061PH024Q8@80820P
00@06QXJ03hn?P0n?Sh0DE5A0P0m?Cd0100e=CD08R8R028R8P0=3@d200H61P0300D51@092@T02@T9
00<01PH600@03@d=00`<300<30`02PX:0P0H61P0100G5aL04a<C01<C4`0P820201`L700401XJ6P0@
4100410@00`<3080410@00@04A4A01<C4`0C4a<03@d=0P020P80100:2PX030`<00`<300B4Q8201@D
500401PH600S8b<08b<S030`<080AdM700@0Hf=S06YZJP1ZJVX0Kfm_0P1VIVH0101GEeL0IfMW06MW
I`1OGel206EUI@0405mOG`14A4@0A4A406EUI@80D51@00@0?Shn05iNGP1NGUh0BDU90P0E5AD0100;
2`/0;bl_02l_;`0i>CT20451@@04051@D014A4@0A4A40410@080B4Q800@0BDU9055AD@1ADE40F5QH
0P1UIFD0101`L700Kfm_06m_K`1JFUX204=3@`0405ADE01HF5P0F5QH04A4A080EeMG00@0G5aL05EE
E@1EEED0EEEE0P12@T80101DE5@0P8200820P01iNGT2075aL@0408F5Q@1cLg<0Lg=c07inOP80MWIf
00@0S8b<07YjNP1jNWX0Lg=c0P1jNWX0101OGel0GEeM05eMG@1VIVH206][J`04069RHP1VIVH0IVIV
07EeM@80HF5Q00@0FEUI065QH@1QHF40HV9R0P1YJFT0101PH600JFUY06UYJ@25QHD206i^KP0406MW
I`1eMGD0MGEe06e]K@80Fe]K00@0EUIF06=SH`1SHf<0IVIV0P1FEUH0101GEeL0C4a<04a<C00P8202
00`<300400/;2`0G5aL05aLG02PX:080=SHf00@0DE5A05UIF@1IFET0GEeM0P1cLg<01027QhL0LW9b
079bLP1cLg<307]kN`<0QHF50`2?Shl208>3P`040861P@1iNGT0NGUi09JFUP80WIfM00@0XJ6Q09jN
WP2NWYh0WYjN0P2RXZ80102ZZZX0Xj>S0:>SX`2OWil209JFUP040:NWY`2<S8`0S8b<06EUI@80DU9B
00@0IFEU096AT@2ATI40P8200P1cLg<0102?Shl0Ti>C09>CT`28R8P20861P@0407MgM`1cLg<0Lg=c
065QH@80Bd];00@0G5aL07]kN`1kNg/0S8b<0P29RHT0102?Shl0PH610861P@1^KVh20861P@04096A
T@2FUYH0UYJF09RHV080Ti>C00@0VYZJ0:FUY@2UYJD0Y:BT0P2OWil00`2YZJT0Xj>S0:>SX`0309VI
V@0408Z:RP1oOgl0Ogmo092@T080[:b/00@0YjNW09nOW`2OWil0Xj>S0P2JVYX0101jNWX0HF5Q065Q
H@0g=cL20000000400<30`0:2PX02PX:00l?3`80410@00@01`L700<30`030`<010@40P071`L00`05
1@D02`/;00/;2`0300h>3P0400`<30030`<00`<300H61P801`L70`051@D010071`L010@400@41008
20P2010@400000@03`l?00H61P061PH010@40P0;2`/0100?3`l03@d=00d=3@0<30`200X:2P0400P8
20010@400@4100/;2`8010@400@0000000h>3P0>3Ph01`L70P0:2PX010071`L00P8200820P0820P2
00D51@0400`<30061PH01PH600`<30801`L700@00P8200<30`030`<00`<30P010@40100410@01`L7
00L71`0:2PX200<30`0300X:2P092@T02@T900<01@D500<01`L701TI6@0I6AT00`0V9RH0100M7Ad0
?clo03lo?`1EEED203`l?004034a<@0Y:BT0:BTY01@D50802@T900@01PH600/;2`0;2`/03`l?0P07
1`L010020P801PH600H61P0B4Q8201dM7@0401`L700H61P061PH01TI6@80:BTY00@0=cLg01lO7`0O
7al06ATI0P0P8200100<30`03`l?00l?3`0R8R8200h>3P0400d=3@0A4A404A4A00L71`803Ph>00@0
51@D01hN7P0N7Qh0=SHf0P1=CDd0101IFET0HV9R069RHP1WIfL205aLG00405QHF01YJFT0JFUY065Q
H@80K6a/00@0HV9R05YJFP1JFUX0LW9b0P1=CDd0101?Cdl0GemO05mOG`15ADD201PH600400T92@0M
7Ad07AdM03Lg=`80Cdm?00@0ATI603lo?`0o?cl0A4A40P0l?3`01015ADD0G5aL05aLG01BDU8205]K
F`0406i^KP1UIFD0IFEU05MGE`80CTi>00@0EeMG05EEE@1EEED0EeMG0P1ZJVX0101QHF40FUYJ05YJ
FP1FEUH205=CD`0405IFEP1kNg/0Ng]k07UiN@80IfMW00@0RXZ:08N7Q`27QhL0L71`0P1_Kfl0102;
Rh/0OWin07inOP23Ph<209bLW00407emO@1RHV80HV9R04a<C080EeMG00<0Kfm_05QHF01HF5P00`1O
Gel0101HF5P0LG5a075aL@1NGUh205mOG`0405MGE`16ATH0ATI606EUI@80HF5Q00@0IFEU06MWI`1W
IfL0FUYJ0P1LG5`0101ADE40@D510451@@14A4@204M7A`0404e=C@14A4@0A4A401XJ6P801PH600@0
3`l?01TI6@0I6AT0:b/[0P0m?Cd0101DE5@0G5aL05aLG01RHV8207alO00408R8R01XJ6P0J6QX059B
DP80F5QH00@0J6QX071`L01`L700Ng]k0P28R8P0102?Shl0RHV908V9R@1`L70207MgM`0409^KV`2H
V9P0V9RH09fMW@80UIFE00@0UiNG09jNWP2NWYh0YJFU0P2VYZH0102GUiL0RXZ:08Z:RP2=SHd207in
OP0407EeM@1JFUX0FUYJ06ATI080QXJ600@0MWIf05YJFP1JFUX0M7Ad0P1nOWh0101`L700GemO05mO
G`1>CTh2059BDP0405IFEP1?Cdl0Cdm?07=cL`80YJFU00@0WinO08:2PP22PX80Ng]k0P26QXH0102G
UiL0TI6A096AT@2FUYH20:ZZZP040:>SX`2CTi<0Ti>C09RHV080ZZZZ00@0Y:BT09fMW@2MWId0ZJVY
0P2RXZ80102KVi/0YZJV0:JVYP2YZJT20:6QX@0409nOW`2UYJD0YJFU0:BTY080XJ6Q00@0YJFU09JF
UP2FUYH0Ng]k0P1UIFD0100b<S800P8200820P071`L300d=3@80410@00@02PX:00D51@051@D01@D5
0P0:2PX300L71`0400X:2P071`L01`L700H61P8010@400@02`/;00`<300<30`02PX:0P051@D01007
1`L01PH600H61P071`L200P8200000@03`l?00H61P061PH010@40P0;2`/0100?3`l03@d=00d=3@0<
30`200X:2P0400P820010@400@4100/;2`8010@400@0000000h>3P0>3Ph01`L70P0:2PX010071`L0
0P8200820P0820P200D51@0400`<30061PH01PH600`<30801`L700@00P8200<30`030`<00`<30P01
0@40100410@01`L700L71`0:2PX200<30`0300X:2P092@T02@T900<01@D500<01`L701TI6@0I6AT0
0`0V9RH0100M7Ad0?clo03lo?`1EEED203`l?004034a<@0Y:BT0:BTY01@D50802@T900@01PH600/;
2`0;2`/03`l?0P071`L010020P801PH600H61P0B4Q8201dM7@0401`L700H61P061PH01TI6@80:BTY
00@0=cLg01lO7`0O7al06ATI0P0P8200100<30`03`l?00l?3`0R8R8200h>3P0400d=3@0A4A404A4A
00L71`803Ph>00@051@D01hN7P0N7Qh0=SHf0P1=CDd0101IFET0HV9R069RHP1WIfL205aLG00405QH
F01YJFT0JFUY065QH@80K6a/00@0HV9R05YJFP1JFUX0LW9b0P1=CDd0101?Cdl0GemO05mOG`15ADD2
01PH600400T92@0M7Ad07AdM03Lg=`80Cdm?00@0ATI603lo?`0o?cl0A4A40P0l?3`01015ADD0G5aL
05aLG01BDU8205]KF`0406i^KP1UIFD0IFEU05MGE`80CTi>00@0EeMG05EEE@1EEED0EeMG0P1ZJVX0
101QHF40FUYJ05YJFP1FEUH205=CD`0405IFEP1kNg/0Ng]k07UiN@80IfMW00@0RXZ:08N7Q`27QhL0
L71`0P1_Kfl0102;Rh/0OWin07inOP23Ph<209bLW00407emO@1RHV80HV9R04a<C080EeMG00<0Kfm_
05QHF01HF5P00`1OGel0101HF5P0LG5a075aL@1NGUh205mOG`0405MGE`16ATH0ATI606EUI@80HF5Q
00@0IFEU06MWI`1WIfL0FUYJ0P1LG5`0101ADE40@D510451@@14A4@204M7A`0404e=C@14A4@0A4A4
01XJ6P801PH600@03`l?01TI6@0I6AT0:b/[0P0m?Cd0101DE5@0G5aL05aLG01RHV8207alO00408R8
R01XJ6P0J6QX059BDP80F5QH00@0J6QX071`L01`L700Ng]k0P28R8P0102?Shl0RHV908V9R@1`L702
07MgM`0409^KV`2HV9P0V9RH09fMW@80UIFE00@0UiNG09jNWP2NWYh0YJFU0P2VYZH0102GUiL0RXZ:
08Z:RP2=SHd207inOP0407EeM@1JFUX0FUYJ06ATI080QXJ600@0MWIf05YJFP1JFUX0M7Ad0P1nOWh0
101`L700GemO05mOG`1>CTh2059BDP0405IFEP1?Cdl0Cdm?07=cL`80YJFU00@0WinO08:2PP22PX80
Ng]k0P26QXH0102GUiL0TI6A096AT@2FUYH20:ZZZP040:>SX`2CTi<0Ti>C09RHV080ZZZZ00@0Y:BT
09fMW@2MWId0ZJVY0P2RXZ80102KVi/0YZJV0:JVYP2YZJT20:6QX@0409nOW`2UYJD0YJFU0:BTY080
XJ6Q00@0YJFU09JFUP2FUYH0Ng]k0P1UIFD0100b<S800P8200820P071`L300d=3@80410@00@02PX:
00D51@051@D01@D50P0:2PX300L71`0400X:2P071`L01`L700H61P8010@400@02`/;00`<300<30`0
2PX:0P051@D010071`L01PH600H61P071`L200P8200000@02PX:00D51@051@D020P80P0?3`l0100A
4A404Q8B018B4P092@T200@4100400410@051@D01@D500L71`801@D500@00`<300X:2P0:2PX010@4
0P020P80100000001`L700L71`071`L200<30`0400/;2`020P800P8200H61P8020P800@010@400T9
2@092@T020P80P051@D00`0410@01@D500D51@0300X:2P<01PH610030`<200/;2`0401hN7P0Q8B40
8B4Q01@D5080=3@d00@0Cdm?03Xj>P0j>SX0<C4a0P0_;bl0100C4a<00000000000010@4200D51@04
00h>3P0:2PX02PX:00410@80000000@01PH601DE5@0E5AD07QhN0P0I6AT0100E5AD0=3@d03@d=01;
Bd/203De=@0403@d=00V9RH09RHV00`<30807AdM00@09bLW00`<300<30`04Q8B0P0=3@d010051@D0
2PX:00X:2P061PH201XJ6P0403@d=01=CDd0CDe=05MGE`80HF5Q00@0GEeM059BDP1BDU80FEUI0P1X
J6P0101OGel0MGEe07EeM@1_Kfl206=SH`0405YJFP1:BTX0BTY:05YJFP80De=C00@0>SXj01`L700L
71`05ADE0P0C4a<0100d=3@0DE5A055AD@11@D4204Y:BP0405EEE@1=CDd0CDe=059BDP80Fe]K00@0
G5aL06EUI@1UIFD0HV9R0P1SHf<0101EEED0BDU904U9B@1NGUh204M7A`040451@@1YJFT0JFUY06YZ
JP80G5aL00@0EUIF06m_K`1_Kfl0MWIf0P1iNGT0101eMGD0LW9b079bLP1lO7`208J6QP0407MgM`1^
KVh0KVi^0820P080H61P00@0HF5Q08^;R`2;Rh/0OGem0P1bLW80101VIVH0GUiN05iNGP1dM7@2069R
HP04051@D01BDU80DU9B04];B`80JVYZ00@0KVi^05]KF`1KFe/0EeMG0P1DE5@0101KFe/0GemO05mO
G`1LG5`204e=C@0405UIF@1gMgL0MgMg061PH0<0>CTi0P13@d<01014A4@0=cLg03Lg=`0@41020000
0004018B4P0M7Ad07AdM02PX:080<c<c00@0BDU9051@D01@D500JFUY0P24Q8@01020P800K6a/06a/
K01=CDd20451@@0405YJFP1ZJVX0JVYZ07moO`80SHf=00@0U9BD08j>SP2>SXh0Hf=S0P22PX80102N
WYh0VIVI09VIV@2OWil209NGU`0409^KV`2MWId0WIfM09nOW`80Zj^[00@0/;2`08n?S`2?Shl0IfMW
0P24Q8@0102BTY80RXZ:08Z:RP24Q8@207]kN`0408^;R`23Ph<0Ph>306][J`80KFe]00@0I6AT05aL
G01LG5`0EEEE0P1HF5P0101bLW80P8200820P02HV9P20:b/[00408j>SP1dM7@0M7Ad07=cL`80O7al
00@0SXj>09:BTP2BTY80WIfM0P2^[Zh0102TY:@0VIVI09VIV@2LW9`20;2`/0040;Ng]`2e]KD0]KFe
0;Rh^080/K6a00@0[Jf]0;>c/`2c/k<0/k>c0P2RXZ80102JVYX0WYjN09jNWP2PX:020::RXP040:ZZ
ZP2DU9@0U9BD07UiN@80H61P00@0820P0000000000000`<30P0410@010010@401@D500D51@051@D2
00P8200400L71`0:2PX02PX:00T92@801PH600@01`L700@4100410@010@40P061PH0100820P01@D5
00D51@0;2`/300P820801PH60@0:2PX100<30`400`<30000100;2`/02PX:00X:2P0=3@d200`<3004
00T92@0>3Ph03Ph>00H61P801@D500@00P8200P8200820P01PH60P0820P010061PH00P8200820P03
0`<200410@04000000071`L01`L700H61P800P8200@010@400820P020P800@410P0410@010092@T0
2`/;00/;2`0820P200<30`0400H61P0410@010@400@410802@T900@02PX:00L71`071`L01PH60P02
0P80100000002PX:00X:2P0A4A4201/K6`0400h>3P0S8b<08b<S051@D080A4A400@0;Bd]038b<P0b
<S807alO0P051@D0100410@01`L700L71`071`L200D51@0400410@000000000000P820806a/K00@0
9RHV020P800P82003`l?0P0V9RH0100i>CT09RHV02HV9P0X:2P201`L700401LG5`0I6AT06ATI01hN
7P8020P800@03Ph>00X:2P0:2PX01`L70P0410@0100:2PX08B4Q024Q8@0^;Rh204I6AP0405IFEP1S
Hf<0Hf=S061PH080Bd];00@0F5QH065QH@1QHF40F5QH0P1jNWX0101fMWH0IfMW06MWI`1FEUH205EE
E@0405iNGP1LG5`0G5aL04=3@`809RHV00@061PH00P8200820P0=CDe0P1=CDd00`13@d<0DE5A055A
D@0305mOG`0405EEE@1>CTh0CTi>05]KF`80KFe]0`1PH6001019BDT0?Shn03hn?P1LG5`204];B`04
0410@01;Bd/0Bd];04E5A@80DE5A00@0G5aL061PH01PH600Kfm_0P1eMGD0101YJFT0O7al07alO01f
MWH207UiN@0408J6QP1YJFT0JFUY071`L080HF5Q00@0IfMW08n?S`2?Shl0Jf][0P1FEUH0101cLg<0
J6QX06QXJ01IFET2071`L00406][J`1VIVH0IVIV069RHP80Kfm_00@0LG5a051@D01@D500Cdm?0P1X
J6P0101NGUh0Cdm?04m?C`1CDe<2055AD@0406a/K01lO7`0O7al069RHPD0E5AD00@0DE5A03Ph>00h
>3P04Q8B0P0410@0100B4Q80<S8b038b<P0m?Cd202`/;0040410@015ADD0ADE506m_K`80OGem00@0
E5AD034a<@0a<C407QhN0P0P8200100l?3`0IFEU06EUI@1nOWh208n?S`0409^KV`2@T900T92@06YZ
JP80Shn?00@0YZJV09fMW@2MWId0Vi^K0P2TY:@0102WYjL0XJ6Q0:6QX@2RXZ820:j^[P040;bl_02@
T900T92@06EUI@80OGem00@0NGUi09BDU02DU9@0TY:B0P29RHT0102a/K40][Jf0;Jf]P28R8P2092@
T00409BDU02<S8`0S8b<08J6QP80O7al00@0OWin08j>SP2>SXh0Y:BT0P2SXj<01023Ph<0JVYZ06YZ
JP1ZJVX2079bLP040820P028R8P0R8R8096AT@80YjNW00@0[:b/09nOW`2OWil0Ti>C0P2SXj<0102a
/K40^KVi0;Vi^@30`<020:>SX`0409nOW`2`/;00/;2`0:ZZZP80WinO00@0X:2P0:NWY`2WYjL0Y:BT
0P2VYZH0102^[Zh0SHf=08f=S@1/K6`2055AD@0301@D50000000000000<00`<300@00P8200D51@05
1@D01`L70P061PH010010@401`L700L71`0<30`200X:2P0400H61P071`L01`L700@410<00`<30P06
1PH300h>3P0400820P030`<00`<300`<30802@T90000100;2`/02PX:00X:2P0=3@d200`<300400T9
2@0>3Ph03Ph>00H61P801@D500@00P8200P8200820P01PH60P0820P010061PH00P8200820P030`<2
00410@04000000071`L01`L700H61P800P8200@010@400820P020P800@410P0410@010092@T02`/;
00/;2`0820P200<30`0400H61P0410@010@400@410802@T900@02PX:00L71`071`L01PH60P020P80
100000002PX:00X:2P0A4A4201/K6`0400h>3P0S8b<08b<S051@D080A4A400@0;Bd]038b<P0b<S80
7alO0P051@D0100410@01`L700L71`071`L200D51@0400410@000000000000P820806a/K00@09RHV
020P800P82003`l?0P0V9RH0100i>CT09RHV02HV9P0X:2P201`L700401LG5`0I6AT06ATI01hN7P80
20P800@03Ph>00X:2P0:2PX01`L70P0410@0100:2PX08B4Q024Q8@0^;Rh204I6AP0405IFEP1SHf<0
Hf=S061PH080Bd];00@0F5QH065QH@1QHF40F5QH0P1jNWX0101fMWH0IfMW06MWI`1FEUH205EEE@04
05iNGP1LG5`0G5aL04=3@`809RHV00@061PH00P8200820P0=CDe0P1=CDd00`13@d<0DE5A055AD@03
05mOG`0405EEE@1>CTh0CTi>05]KF`80KFe]0`1PH6001019BDT0?Shn03hn?P1LG5`204];B`040410
@01;Bd/0Bd];04E5A@80DE5A00@0G5aL061PH01PH600Kfm_0P1eMGD0101YJFT0O7al07alO01fMWH2
07UiN@0408J6QP1YJFT0JFUY071`L080HF5Q00@0IfMW08n?S`2?Shl0Jf][0P1FEUH0101cLg<0J6QX
06QXJ01IFET2071`L00406][J`1VIVH0IVIV069RHP80Kfm_00@0LG5a051@D01@D500Cdm?0P1XJ6P0
101NGUh0Cdm?04m?C`1CDe<2055AD@0406a/K01lO7`0O7al069RHPD0E5AD00@0DE5A03Ph>00h>3P0
4Q8B0P0410@0100B4Q80<S8b038b<P0m?Cd202`/;0040410@015ADD0ADE506m_K`80OGem00@0E5AD
034a<@0a<C407QhN0P0P8200100l?3`0IFEU06EUI@1nOWh208n?S`0409^KV`2@T900T92@06YZJP80
Shn?00@0YZJV09fMW@2MWId0Vi^K0P2TY:@0102WYjL0XJ6Q0:6QX@2RXZ820:j^[P040;bl_02@T900
T92@06EUI@80OGem00@0NGUi09BDU02DU9@0TY:B0P29RHT0102a/K40][Jf0;Jf]P28R8P2092@T004
09BDU02<S8`0S8b<08J6QP80O7al00@0OWin08j>SP2>SXh0Y:BT0P2SXj<01023Ph<0JVYZ06YZJP1Z
JVX2079bLP040820P028R8P0R8R8096AT@80YjNW00@0[:b/09nOW`2OWil0Ti>C0P2SXj<0102a/K40
^KVi0;Vi^@30`<020:>SX`0409nOW`2`/;00/;2`0:ZZZP80WinO00@0X:2P0:NWY`2WYjL0Y:BT0P2V
YZH0102^[Zh0SHf=08f=S@1/K6`2055AD@0301@D50000000000000<00`<300@00P8200D51@051@D0
1`L70P061PH010010@401`L700L71`0<30`200X:2P0400H61P071`L01`L700@410<00`<30P061PH3
00h>3P0400820P030`<00`<300`<30802@T90000100@41001PH600H61P0:2PX200`<3004018B4P0:
2PX02PX:00820P801PH600@00`<300H61P061PH00`<30P051@D0100000002PX:00X:2P071`L20082
0P040000000410@010@400D51@8010@400@01PH600<30`030`<00`<30P0410@0100820P02PX:00X:
2P020P8300@410800`<300<010@400<30`030`<00`061PH010092@T010@400@41000000200/;2`04
00X:2P0O7al07alO01lO7`8071`L00@0@d=304];B`1;Bd/0<c<c0P0Z:RX0100_;bl061PH01PH6004
10@200X:2P0400T92@0820P020P800H61P800@4100@01PH600L71`071`L03`l?0P0B4Q8010010@40
6a/K01/K6`0Y:BT2010@400401dM7@0R8R808R8R01dM7@80410@00@06ATI018B4P0B4Q801PH60P0>
3Ph010051@D00@4100410@0;2`/201lO7`0403Ti>@1=CDd0CDe=05QHF080HV9R00<0GUiN0410@010
@4000`1EEED0101FEUH0Ng]k07]kN`1eMGD2071`L00406=SH`1CDe<0De=C051@D080EUIF00@0ADE5
02h^;P0^;Rh04A4A0P000000100c<c<0F5QH05QHF017AdL203`l?00404];B`1ADE40DE5A04Y:BP80
FUYJ00@0GemO06=SH`1SHf<0JFUY0P1MGEd01016ATH0C4a<04a<C01DE5@20410@0040451@@18B4P0
B4Q8055AD@80G5aL00@0FUYJ055AD@1ADE40FUYJ0P1gMgL0101[Jf/0Lg=c07=cL`1kNg/206i^KP04
0820P01^KVh0KVi^06m_K`80QhN700@0MGEe08>3P`23Ph<0K6a/0P1>CTh0101XJ6P0KVi^06i^KP1@
D502061PH00406a/K01VIVH0IVIV06UYJ@<0M7Ad0P1CDe<0100k>c/0EeMG05MGE`1UIFD205MGE`04
05UIF@1RHV80HV9R06m_K`80HF5Q00@0DE5A05mOG`1OGel0FEUI0P17AdL0100o?cl08R8R028R8P0<
30`200P8200401PH601DE5@0E5AD06=SH`80<S8b00@0:b/[0410@010@400IFEU0P1OGel0100b<S80
4A4A014A4@092@T201<C4`0401TI6@1@D500D51@07UiN@80TI6A00@0Vi^K08F5Q@25QHD0M7Ad0P2F
UYH0102^[Zh0XZ:R0::RXP2HV9P20:6QX@040:j^[P2c/k<0/k>c0;2`/080]kNg00@0XZ:R071`L01`
L700R8R80P2ATI40101jNWX0U9BD09BDU026QXH208j>SP040;6a/@2MWId0WIfM08J6QP80XZ:R00@0
Z:RX09>CT`2CTi<0PX:20P1jNWX0101hN7P0QXJ608J6QP2KVi/2096AT@04079bLP1YJFT0JFUY07Qh
N080PH6100@0SXj>09:BTP2BTY80UYJF0P2][Jd00`2k^k/0];Bd0;Bd]0030:6QX@040:^[Z`2c/k<0
/k>c0<30`080WYjN00@0V9RH0:BTY02TY:@0Vi^K0P2OWil0102NWYh0Y:BT0:BTY02WYjL20:RXZ004
09nOW`1iNGT0NGUi05mOG`80CDe=00@051@D0000000000001PH60P020P8010030`<01`L700L71`09
2@T20000000400<30`0820P020P800X:2P8020P800@02@T900h>3P0>3Ph020P80P010@4010092@T0
30`<00`<300;2`/2014A4@0400D51@0820P020P800X:2P801`L70000100?3`l00000000000092@T2
014A4@04010@400410@010@400<30`8010@400@00`<300D51@051@D020P80P061PH010010@403@d=
00d=3@0820P200@4100400<30`061PH01PH600<30`801PH600@02@T900410@010@400`<30P071`L0
10030`<020P800P820071`L200T92@0400820P030`<00`<3000000801@D500@020P800<30`030`<0
20P80`061PH200@4100400X:2P0O7al07alO024Q8@8061PH00@09bLW0410@010@400@D510P0W9bL0
100`<3009BDU02DU9@071`L200T92@0400h>3P0;2`/02`/;00H61P800`<300@020P800L71`071`L0
5ADE0P0H61P0100000004A4A014A4@0I6AT200<30`0401TI6@0[:b/0:b/[01hN7P8071`L00@051@D
00T92@092@T03@d=0P0;2`/010010@4010@400@4100820P201TI6@0403`l?01BDU80DU9B05eMG@80
Hf=S00@0DU9B0451@@11@D40GemO0P1GEeL0101NGUh0PH610861P@1XJ6P2065QH@0406UYJ@1ADE40
DE5A04Q8B080Fe]K00@0FUYJ03Xj>P0j>SX03Ph>0P000000100Q8B40CDe=04e=C@1;Bd/203lo?`04
0410@01<C4`0C4a<04e=C@80HV9R00@0GUiN05UIF@1IFET0Jf][0P1^KVh00`1BDU80>SXj03Xj>P03
03dm?@040451@@1GEeL0EeMG05iNGP80CDe=00@0Fe]K079bLP1bLW80J6QX0P1oOgl01020P800M7Ad
07AdM01YJFT2065QH@040820P02EUID0UIFE0861P@80Ti>C00@0LW9b05iNGP1NGUh0KVi^0P1IFET0
101HF5P0Jf][06][J`1<C4`205MGE`0406][J`1LG5`0G5aL05IFEP80HF5Q00@0LG5a061PH01PH600
@d=30P1LG5`0101oOgl0Ng]k07]kN`1LG5`205]KF`04071`L01WIfL0IfMW05EEE@80CTi>00@0@d=3
03lo?`0o?cl0=CDe0P0K6a/0100?3`l03Ph>00h>3P0S8b<205mOG`0407QhN01>CTh0CTi>02l_;`80
@41000@0EeMG04a<C01<C4`0<S8b0`0l?3`203Ti>@0402XZ:P1;Bd/0Bd];07emO@80VYZJ00@0UYJF
07UiN@1iNGT0QXJ60P2][Jd0102[Zj/0VYZJ09ZJVP2CTi<209bLW0040:VYZ@2m_Kd0_Kfm0;Jf]P80
[:b/00@0TI6A075aL@1aLG40VYZJ0P2TY:@0102XZ:P0[jn_0:n_[`1hN7P207emO@040:JVYP2:RXX0
RXZ:08N7Q`80Y:BT00@0UiNG0820P020P800LG5a0P1eMGD0101nOWh0PH610861P@2=SHd20820P004
05iNGP1^KVh0KVi^09JFUP80XZ:R00@0ZZZZ0:^[Z`2[Zj/0Zj^[0P2a/K40102_[jl0/[:b0;:b/P2[
Zj/20:RXZ0040:j^[P2][Jd0[Jf]0:b/[080WYjN00@0Y:BT09nOW`2OWil0U9BD0`2SXj<20:NWY`04
0:>SX`2RXZ80XZ:R096AT@80K6a/00@0GUiN04Q8B018B4P04a<C0P030`<0100:2PX01@D500D51@00
000300H61P800`<300@020P800H61P061PH010@40P071`L010092@T03`l?00l?3`0;2`/200D51@04
00X:2P0@4100410@00d=3@80410@00@02PX:00P8200820P01PH60P0:2PX0000400l?3`0000000000
00T92@804A4A00@0410@00@4100410@00`<30P0410@010030`<01@D500D51@0820P200H61P040041
0@0=3@d03@d=00P8208010@400@00`<300H61P061PH00`<30P061PH010092@T00@4100410@030`<2
00L71`0400<30`0820P020P800L71`802@T900@00P8200<30`030`<000000P051@D0100820P00`<3
00<30`0820P300H61P8010@400@02PX:01lO7`0O7al08B4Q0P0H61P0100W9bL0@4100410@011@D42
02LW9`04030`<00U9BD09BDU00L71`802@T900@03Ph>00/;2`0;2`/01PH60P030`<0100820P01`L7
00L71`0E5AD201PH60040000000A4A404A4A01TI6@800`<300@06ATI02/[:`0[:b/07QhN0P0L71`0
100D51@02@T900T92@0=3@d200/;2`0400410@0410@010@400P820806ATI00@0?3`l059BDP1BDU80
GEeM0P1SHf<0101BDU80@D510451@@1OGel205MGE`0405iNGP21PH40PH6106QXJ080HF5Q00@0JFUY
055AD@1ADE40B4Q80P1KFe/0101JFUX0>SXj03Xj>P0>3Ph200000004024Q8@1=CDd0CDe=04];B`80
?clo00@0@41004a<C01<C4`0CDe=0P1RHV80101NGUh0FEUI05UIF@1[Jf/206i^KP03059BDP0j>SX0
>SXj00<0?Cdm00@0@D5105MGE`1GEeL0GUiN0P1=CDd0101KFe/0LW9b079bLP1XJ6P207moO`040820
P01dM7@0M7Ad06UYJ@80HF5Q00@0P82009FEU@2EUID0PH610P2CTi<0101bLW80GUiN05iNGP1^KVh2
05UIF@0405QHF01[Jf/0Jf][04a<C080EeMG00@0Jf][05aLG01LG5`0EUIF0P1QHF40101aLG40H61P
061PH013@d<205aLG00407moO`1kNg/0Ng]k05aLG080Fe]K00@0L71`06MWI`1WIfL0EEEE0P1>CTh0
1013@d<0?clo03lo?`0e=CD201/K6`0400l?3`0>3Ph03Ph>02<S8`80GemO00@0N7Qh04i>CP1>CTh0
;bl_0P10@400101GEeL0C4a<04a<C00b<S8303`l?080>CTi00@0:RXZ04];B`1;Bd/0OGem0P2JVYX0
102FUYH0NGUi07UiN@26QXH20:f][@040:^[Z`2JVYX0VYZJ09>CT`80W9bL00@0ZJVY0;fm_@2m_Kd0
][Jf0P2/[:`0102ATI40LG5a075aL@2JVYX20:BTY0040:RXZ02_[jl0[jn_07QhN080OGem00@0YZJV
08Z:RP2:RXX0QhN70P2TY:@0102GUiL0P8200820P01aLG4207EeM@0407inOP21PH40PH6108f=S@80
P82000@0GUiN06i^KP1^KVh0UYJF0P2RXZ80102ZZZX0Zj^[0:^[Z`2[Zj/20;6a/@040:n_[`2b/[80
/[:b0:^[Z`80Z:RX00@0[Zj^0:f][@2][Jd0[:b/0P2NWYh0102TY:@0WinO09nOW`2DU9@30:>SX`80
YjNW00@0Xj>S0::RXP2RXZ80TI6A0P1/K6`0101NGUh0B4Q804Q8B00C4a<200<30`0400X:2P051@D0
1@D5000000<01PH60P030`<0100820P01PH600H61P0410@200L71`0400T92@0?3`l03`l?00/;2`80
1@D500@02PX:010@400@41003@d=0P0@4100100:2PX020P800P820061PH200X:2P0000@04a<C00D5
1@051@D00`<30P061PH010010@4010@400@4100820P200D51@0400<30`0410@010@400d=3@8020P8
00@00P8200L71`071`L02PX:0P071`L00`0820P030`<00`<300300L71`0400@410010@400@410082
0P801`L700@01PH60000000000001@D50P071`L010051@D00@4100410@051@D200X:2P0400D51@03
0`<00`<300L71`803Ph>00@03@d=00H61P061PH03Ph>0P0O7al0100L71`08R8R028R8P0g=cL20410
@0040451@@0b<S80<S8b038b<P80:b/[00@03`l?00L71`071`L03@d=0P0;2`/010061PH020P800P8
200820P200D51@0402@T900^;Rh0;Rh^00l?3`80820P00@0:2PX00L71`071`L020P80P0N7Qh0100G
5aL03`l?00l?3`0A4A4200L71`0300X:2P0F5QH05QHF00<04Q8B00@04a<C018B4P0B4Q80=SHf0P1F
EUH0101ZJVX0K6a/06a/K01<C4`204E5A@0405iNGP1OGel0GemO05mOG`80N7Qh00@0Hf=S05aLG01L
G5`0H61P0P1:BTX01018B4P0Jf][06][J`1KFe/2030`<00401<C4`0820P020P801PH6080@41000@0
D51@04];B`1;Bd/0BTY:0P1RHV80101UIFD0EeMG05MGE`1BDU8205iNGP0406=SH`1YJFT0JFUY05iN
GP80@41000@0AdM704];B`1;Bd/0BTY:0P1WIfL0101HF5P0?clo03lo?`1MGEd207MgM`0406m_K`1n
OWh0OWin07moO`80OGem00@0J6QX06i^KP1^KVh0Q8B40P27QhL0101oOgl0RXZ:08Z:RP1iNGT206=S
H`0407MgM`1`L700L71`05aLG080LW9b00@0BTY:05QHF01HF5P0M7Ad0P1ZJVX0101DE5@0FUYJ05YJ
FP1eMGD2079bLP0405eMG@1IFET0FEUI075aL@80MgMg00@0IVIV05mOG`1OGel0Jf][0P1NGUh01014
A4@0AdM704M7A`11@D4203Ti>@0403@d=00L71`071`L00X:2P803@d=00@0;Rh^05]KF`1KFe/0MWIf
0P1UIFD01015ADD0?clo03lo?`1JFUX205EEE@0403lo?`1@D500D51@04Y:BP80E5AD00@0BTY:04i>
CP1>CTh0NGUi0P2IVIT0102DU9@0OGem07emO@2DU9@20:f][@0409fMW@2EUID0UIFE08^;R`80VIVI
00@0YZJV0;:b/P2b/[80/;2`0P2SXj<0102=SHd0P8200820P02IVIT209nOW`040;>c/`2_[jl0[jn_
07=cL`80NWYj00@0UIFE0820P020P800Rh^;0P2JVYX01028R8P0O7al07alO01bLW82075aL@0407Mg
M`1mOGd0OGem08^;R`80MGEe00@0F5QH07emO@1mOGd0VYZJ0P2KVi/0102TY:@0YZJV0:JVYP2_[jl2
0:VYZ@0409jNWP2XZ:P0Z:RX0:j^[P80Xj>S00@0UIFE09fMW@2MWId0Zj^[0P2PX:00102WYjL0Xj>S
0:>SX`2MWId209nOW`0409^KV`2b/[80/[:b0:^[Z`80WIfM00@0Ti>C075aL@1aLG40H61P0P0n?Sh0
100>3Ph04A4A014A4@0:2PX200`<3004000000030`<00`<300T92@801PH600@00P8200D51@051@D0
2`/;0P051@D010092@T00`<300<30`071`L200H61P0400@4100<30`030`<00h>3P803@d=00@02`/;
00d=3@0=3@d020P80P061PH000<03Ph>00@01`L700<30`030`<00P820P030`<010061PH00`<300<3
0`00000200D51@0400P820061PH01PH6000000801PH600@02`/;00L71`071`L02@T90P061PH300P8
20@01PH60P0;2`/0100=3@d00`<300<30`020P8300<30`800@4100<010@400T92@092@T00`0410@0
100820P02`/;00/;2`061PH300X:2P808b<S00@0820P02@T900T92@0@d=30P16ATH01010@400?clo
03lo?`0b<S8203Ti>@0401/K6`0410@010@400l?3`804a<C0`0E5AD010061PH000000000000H61P2
02`/;00401/K6`0M7Ad07AdM03Ph>080:RXZ00@061PH02@T900T92@0820P0P0?3`l0100@41004a<C
01<C4`0A4A42028R8P0401LG5`0F5QH05QHF00d=3@803Ph>00@0=3@d05QHF01HF5P0K6a/0P1YJFT0
1013@d<0@D510451@@1ADE4206IVIP0406QXJ01OGel0GemO05]KF`80EEEE00@0DE5A04Y:BP1:BTX0
CTi>0P1ZJVX01012@T80:BTY02TY:@0G5aL200D51@04020P8019BDT0BDU904];B`80?Cdm00@0ADE5
06=SH`1SHf<0K6a/0P1QHF40101MGEd0KFe]06e]K@1XJ6P205IFEP0405ADE01EEED0EEEE065QH@80
FUYJ00@0BTY:05YJFP1JFUX0EeMG0P16ATH0101GEeL0LG5a075aL@1aLG42071`L00405aLG01aLG40
LG5a07inOP80MWIf00@0MgMg06][J`1[Jf/0LG5a0P1_Kfl0101RHV80LW9b079bLP1aLG4207EeM@04
065QH@1YJFT0JFUY055AD@80AdM700@0MGEe06a/K01/K6`0BDU90P1MGEd0101eMGD0HF5Q065QH@1@
D50205EEE@04075aL@1XJ6P0J6QX05MGE`80HF5Q00@0Lg=c061PH01PH600@4100P18B4P0100j>SX0
:2PX02PX:00^;Rh201<C4`0400410@0:2PX02PX:03@d=080GemO00@0NGUi06QXJ01XJ6P0CDe=0P10
@400101OGel0H61P061PH019BDT204A4A00404E5A@1IFET0FEUI05IFEP80G5aL00@0K6a/08^;R`2;
Rh/0SXj>0P21PH40102?Shl0X:2P0:2PX02NWYh20:2PX00409RHV02SXj<0Xj>S0:VYZ@80[Zj^00@0
ZZZZ09bLW02LW9`0Ng]k0P1oOgl0102MWId0X:2P0:2PX02c/k<20:ZZZP0407AdM01lO7`0O7al08F5
Q@80KVi^00@0N7Qh08N7Q`27QhL0PX:20P1hN7P0101[Jf/0IfMW06MWI`1[Jf/207QhN0040861P@1Q
HF40HF5Q05]KF`80U9BD00@0YJFU0:RXZ02XZ:P0[Zj^0P2TY:@0102c/k<0];Bd0;Bd]02/[:`20:j^
[P040;6a/@2YZJT0ZJVY09FEU@80YZJV00@0a/K60;Vi^@2i^KT0[jn_0P2SXj<0102QXJ40VYZJ09ZJ
VP2LW9`20:n_[`040:FUY@2IVIT0VIVI09ZJVP80PH6100@0GEeM03`l?00l?3`04Q8B0P092@T0100;
2`/01`L700L71`010@4200@4100400d=3@0<30`030`<00H61P801@D500@03Ph>00L71`071`L03@d=
0P0410@300<30`0400P820020P800P8200H61P803@d=0`0;2`/100T92@400`<30@030`<000<03Ph>
00@01`L700<30`030`<00P820P030`<010061PH00`<300<30`00000200D51@0400P820061PH01PH6
000000801PH600@02`/;00L71`071`L02@T90P061PH300P820@01PH60P0;2`/0100=3@d00`<300<3
0`020P8300<30`800@4100<010@400T92@092@T00`0410@0100820P02`/;00/;2`061PH300X:2P80
8b<S00@0820P02@T900T92@0@d=30P16ATH01010@400?clo03lo?`0b<S8203Ti>@0401/K6`0410@0
10@400l?3`804a<C0`0E5AD010061PH000000000000H61P202`/;00401/K6`0M7Ad07AdM03Ph>080
:RXZ00@061PH02@T900T92@0820P0P0?3`l0100@41004a<C01<C4`0A4A42028R8P0401LG5`0F5QH0
5QHF00d=3@803Ph>00@0=3@d05QHF01HF5P0K6a/0P1YJFT01013@d<0@D510451@@1ADE4206IVIP04
06QXJ01OGel0GemO05]KF`80EEEE00@0DE5A04Y:BP1:BTX0CTi>0P1ZJVX01012@T80:BTY02TY:@0G
5aL200D51@04020P8019BDT0BDU904];B`80?Cdm00@0ADE506=SH`1SHf<0K6a/0P1QHF40101MGEd0
KFe]06e]K@1XJ6P205IFEP0405ADE01EEED0EEEE065QH@80FUYJ00@0BTY:05YJFP1JFUX0EeMG0P16
ATH0101GEeL0LG5a075aL@1aLG42071`L00405aLG01aLG40LG5a07inOP80MWIf00@0MgMg06][J`1[
Jf/0LG5a0P1_Kfl0101RHV80LW9b079bLP1aLG4207EeM@04065QH@1YJFT0JFUY055AD@80AdM700@0
MGEe06a/K01/K6`0BDU90P1MGEd0101eMGD0HF5Q065QH@1@D50205EEE@04075aL@1XJ6P0J6QX05MG
E`80HF5Q00@0Lg=c061PH01PH600@4100P18B4P0100j>SX0:2PX02PX:00^;Rh201<C4`0400410@0:
2PX02PX:03@d=080GemO00@0NGUi06QXJ01XJ6P0CDe=0P10@400101OGel0H61P061PH019BDT204A4
A00404E5A@1IFET0FEUI05IFEP80G5aL00@0K6a/08^;R`2;Rh/0SXj>0P21PH40102?Shl0X:2P0:2P
X02NWYh20:2PX00409RHV02SXj<0Xj>S0:VYZ@80[Zj^00@0ZZZZ09bLW02LW9`0Ng]k0P1oOgl0102M
WId0X:2P0:2PX02c/k<20:ZZZP0407AdM01lO7`0O7al08F5Q@80KVi^00@0N7Qh08N7Q`27QhL0PX:2
0P1hN7P0101[Jf/0IfMW06MWI`1[Jf/207QhN0040861P@1QHF40HF5Q05]KF`80U9BD00@0YJFU0:RX
Z02XZ:P0[Zj^0P2TY:@0102c/k<0];Bd0;Bd]02/[:`20:j^[P040;6a/@2YZJT0ZJVY09FEU@80YZJV
00@0a/K60;Vi^@2i^KT0[jn_0P2SXj<0102QXJ40VYZJ09ZJVP2LW9`20:n_[`040:FUY@2IVIT0VIVI
09ZJVP80PH6100@0GEeM03`l?00l?3`04Q8B0P092@T0100;2`/01`L700L71`010@4200@4100400d=
3@0<30`030`<00H61P801@D500@03Ph>00L71`071`L03@d=0P0410@300<30`0400P820020P800P82
00H61P803@d=0`0;2`/100T92@400`<30@030`<0000400@4100>3Ph03Ph>010@408030`<0`061PH0
10092@T010@400@41000000300D51@800P8200@01@D500X:2P0:2PX020P80`0;2`/200@4100400P8
200410@010@400X:2P8020P80`0<30`010071`L010@400@4100410@200D51@0400410@020P800P82
00H61P802@T900@01`L700820P020P801`L70P030`<01000000010@400@410051@D201hN7P0402LW
9`0S8b<08b<S02XZ:P80@D5100@0ATI603`l?00l?3`09RHV0P0n?Sh0100_;bl02@T900T92@071`L2
01PH600401hN7P0C4a<04a<C00T92@<00P820P0D51@0100A4A4010@400@4100L71`202/[:`03028R
8P0M7Ad07AdM00@04a<C0P0>3Ph0100H61P07AdM01dM7@010@4200`<300400l?3`0>3Ph03Ph>03<c
<`80C4a<00@0EEEE05MGE`1GEeL0@T920P16ATH0101IFET0L71`071`L01^KVh305UIF@<0CDe=0P1<
C4`01015ADD0EEEE05EEE@14A4@203/k>`0401PH60051@D01@D501LG5`80?Shn00@0@d=30492@P12
@T80C4a<0P1IFET0101QHF40HV9R069RHP1GEeL206EUI@0407MgM`1MGEd0GEeM04Y:BP80DU9B00@0
Fe]K065QH@1QHF40F5QH0P1<C4`0101;Bd/0BDU904U9B@1ADE4206YZJP0406UYJ@1ZJVX0JVYZ06QX
J080MgMg00@0S8b<07alO01lO7`0Lg=c0P1aLG40101kNg/0MWIf07IfMP1NGUh206a/K00406IVIP1b
LW80LW9b08>3P`80Kfm_00@0EeMG05=CD`1CDe<0Ogmo0P1`L700101:BTX0GEeM05eMG@1SHf<205=C
D`0405ADE01NGUh0GUiN07MgM`80JVYZ00@0DU9B065QH@1QHF40MWIf0P1XJ6P01015ADD0=SHf03Hf
=P0b<S820451@@0403@d=0051@D01@D500D51@803`l?00@0>c/k06][J`1[Jf/0Q8B40P1`L700101M
GEd0CTi>04i>CP1GEeL205aLG00404];B`12@T80@T9204Q8B080Bd];00@0Fe]K06UYJ@1YJFT0EEEE
0P28R8P0102BTY80R8R808R8R025QHD20:2PX0040:6QX@2HV9P0V9RH09RHV080Xj>S00@0YjNW0:n_
[`2_[jl0Y:BT0P2FUYH01027QhL0VIVI09VIV@2TY:@209bLW0040:j^[P2WYjL0YjNW07IfMP80JVYZ
00@0Lg=c06=SH`1SHf<0Hf=S0P22PX801028R8P0LG5a075aL@1TI6@305eMG@80MWIf00@0Ng]k05AD
E01DE5@0IVIV0P2^[Zh0102l_;`0`<300<30`02j^[X20:NWY`040;Bd]02g]kL0]kNg0:j^[P80Z:RX
00@0[jn_0;6a/@2a/K40[jn_0P2e]KD0102k^k/0/K6a0;6a/@2c/k<20:>SX`040:6QX@2OWil0WinO
0:b/[080Zj^[00@0Y:BT09nOW`2OWil0WIfM0P2@T900101OGel0?Shn03hn?P0D51@200<30`0400D5
1@030`<00`<300H61P801@D500@00`<300P8200820P02PX:0P00000010071`L010@400@410092@T3
00@410801PH600@03`l?00P8200820P010@40P0;2`/00`0410@01@D500D51@0300T92@0000@00`<3
010@400@41002`/;0P0<30`00`051@D02PX:00X:2P0300H61P0300820P0410@010@400<010@40`0>
3Ph00`051@D01`L700L71`0300P8200400H61P000000000000@410801PH600@020P800@4100410@0
1`L70P061PH00`051@D01PH600H61P0300D51@0400T92@071`L01`L700@410800@4100@01PH600@4
100410@01PH60P030`<010071`L0410@010@400N7Qh202/[:`0401`L700h>3P0>3Ph04E5A@80?clo
00@0:b/[02d];@0];Bd0>3Ph0P0D51@0100000004Q8B018B4P0F5QH200h>3P04010@40092@T02@T9
000000802PX:00@09bLW02d];@0];Bd05ADE0P0?3`l0100P82006a/K01/K6`051@D200`<300401TI
6@0B4Q804Q8B01LG5`8061PH00@010@401LG5`0G5aL0820P0P0;2`/0100c<c<0DE5A055AD@1FEUH2
04m?C`0404Y:BP1>CTh0CTi>05MGE`80Lg=c00@0LG5a06UYJ@1YJFT0Hf=S0P1BDU801019BDT0?Cdm
03dm?@0k>c/204Q8B004055AD@15ADD0ADE501`L70801`L700@06a/K038b<P0b<S80=cLg0P1;Bd/0
101FEUH0BTY:04Y:BP1?Cdl205ADE00404m?C`1]KFd0KFe]07moO`80Fe]K00@0AdM704a<C01<C4`0
B4Q80P1CDe<0101NGUh0DE5A055AD@1>CTh205UIF@0405aLG01PH600H61P069RHP80N7Qh00@0Ph>3
071`L01`L700Ogmo0P20P800101jNWX0OWin07inOP1jNWX207=cL`04071`L01UIFD0IFEU05]KF`80
MgMg00@0UiNG0820P020P800DU9B0P1dM7@0101bLW80Jf][06][J`1SHf<206IVIP0405YJFP1BDU80
DU9B051@D080Cdm?00@0D51@05EEE@1EEED0K6a/0P1bLW80101XJ6P0EEEE05EEE@0j>SX203@d=004
03<c<`0j>SX0>SXj02h^;P8020P800@02`/;01DE5@0E5AD0@T920P1_Kfl0101mOGd0IFEU06EUI@1T
I6@205iNGP04059BDP1PH600H61P05]KF`80C4a<00@0Cdm?04a<C01<C4`0HF5Q0P1EEED0100o?cl0
SXj>08j>SP2LW9`208n?S`040820P02GUiL0UiNG09:BTP80T92@00@0UIFE09JFUP2FUYH0WIfM0P2[
Zj/0102SXj<0UiNG09NGU`2RXZ820;:b/P040:FUY@2VYZH0YZJV0:b/[080VYZJ00@0PX:206EUI@1U
IFD0GUiN0P1QHF40101EEED0KVi^06i^KP20P80206a/K004061PH01BDU80DU9B05]KF`80P82000@0
MWIf04m?C`1?Cdl0N7Qh0P2h^;P0102l_;`0^k^k0;^k^`2a/K420:FUY@040:j^[P2_[jl0[jn_0:NW
Y`80[:b/00<0_;bl0;Fe]@2e]KD00`2_[jl0102WYjL0Z:RX0:RXZ02i^KT20:RXZ0040::RXP2QXJ40
XJ6Q0:FUY@80ZJVY00@0[Jf]0:BTY02TY:@0WinO0P28R8P0101NGUh0@4100410@00>3Ph2010@4004
00410@0820P020P800@410800`<300@01`L700410@010@402PX:0P030`<010092@T0000000000009
2@T200@4100400410@000000000000T92@801PH600@00`<300P8200820P01`L70P0B4Q8100T92@40
1`L70@071`L0000400<30`0@4100410@00/;2`8030`<00<01@D500X:2P0:2PX00`061PH00`020P80
10@400@4100300@410<03Ph>00<01@D500L71`071`L00`0820P010061PH000000000000410@200H6
1P0400P8200410@010@400L71`801PH600<01@D500H61P061PH00`051@D010092@T01`L700L71`04
10@200410@0400H61P0410@010@400H61P800`<300@01`L7010@400@41007QhN0P0[:b/0100L71`0
>3Ph03Ph>015ADD203lo?`0402/[:`0];Bd0;Bd]03Ph>08051@D00@00000018B4P0B4Q805QHF0P0>
3Ph0100@41002@T900T92@00000200X:2P0402LW9`0];Bd0;Bd]01DE5@803`l?00@0820P01/K6`0K
6a/01@D50P0<30`0100I6AT04Q8B018B4P0G5aL201PH600400@4100G5aL05aLG020P80802`/;00@0
<c<c055AD@1ADE40EUIF0P1?Cdl0101:BTX0CTi>04i>CP1GEeL207=cL`04075aL@1YJFT0JFUY06=S
H`80DU9B00@0BDU903dm?@0m?Cd0>c/k0P18B4P0101ADE40ADE504E5A@0L71`200L71`0401/K6`0b
<S80<S8b03Lg=`80Bd];00@0EUIF04Y:BP1:BTX0Cdm?0P1DE5@0101?Cdl0KFe]06e]K@1oOgl205]K
F`0404M7A`1<C4`0C4a<04Q8B080De=C00@0GUiN055AD@1ADE40CTi>0P1IFET0101LG5`0H61P061P
H01RHV8207QhN00408>3P`1`L700L71`07moO`80P82000@0NWYj07inOP1nOWh0NWYj0P1cLg<0101`
L700IFEU06EUI@1KFe/207MgM`0409NGU`20P800P820059BDP80M7Ad00@0LW9b06][J`1[Jf/0Hf=S
0P1VIVH0101JFUX0DU9B059BDP1@D50204m?C`04051@D01EEED0EEEE06a/K080LW9b00@0J6QX05EE
E@1EEED0>SXj0P0d=3@0100c<c<0>SXj03Xj>P0^;Rh200P8200400/;2`0E5AD05ADE0492@P80Kfm_
00@0OGem06EUI@1UIFD0I6AT0P1NGUh0101BDU80H61P061PH01KFe/204a<C00404m?C`1<C4`0C4a<
065QH@80EEEE00@0?clo08j>SP2>SXh0W9bL0P2?Shl01020P800UiNG09NGU`2BTY82092@T00409FE
U@2FUYH0UYJF09fMW@80Zj^[00@0Xj>S09NGU`2GUiL0XZ:R0P2b/[80102UYJD0YZJV0:JVYP2/[:`2
09ZJVP0408:2PP1UIFD0IFEU05iNGP80HF5Q00@0EEEE06i^KP1^KVh0P8200P1/K6`0101PH600DU9B
059BDP1KFe/20820P00407IfMP1?Cdl0Cdm?07QhN080^;Rh00@0_;bl0;^k^`2k^k/0/K6a0P2UYJD0
102^[Zh0[jn_0:n_[`2WYjL20:b/[0030;bl_02e]KD0]KFe00<0[jn_00@0YjNW0:RXZ02XZ:P0^KVi
0P2XZ:P0102RXZ80XJ6Q0:6QX@2UYJD20:VYZ@040:f][@2TY:@0Y:BT09nOW`80R8R800@0GUiN0410
@010@4003Ph>0P0@410010010@4020P800P8200410@200<30`0400L71`010@400@4100X:2P800`<3
00@02@T90000000000002@T90P0410@010010@400000000000092@T200H61P0400<30`0820P020P8
00L71`804Q8B0@092@T100L71`401`L70000100410@04Q8B018B4P0410@200D51@0400<30`0410@0
10@400820P800@4100@00P8200D51@051@D01PH60P0;2`/0100@41002PX:00X:2P0820P200L71`04
000000051@D01@D500L71`800@4100@0000000X:2P0:2PX01PH60P0410@0100:2PX02@T900T92@07
1`L200820P0400H61P071`L01`L700820P<00`<30P020P80100820P01@D500D51@051@D200P82004
00X:2P0>3Ph03Ph>01/K6`80:RXZ00@07alO03Lg=`0g=cL0BTY:0P1>CTh01013@d<08B4Q024Q8@0i
>CT202HV9P0400D51@092@T02@T900`<30802@T900@02`/;00P8200820P00P820P092@T0100f=SH0
?Cdm03dm?@0<30`200@41004020P800R8R808R8R00h>3P804a<C00@05QHF01<C4`0C4a<05ADE0P0>
3Ph0100?3`l03Ph>00h>3P0B4Q8200P8200402l_;`1CDe<0De=C061PH080C4a<00@0@d=304m?C`1?
Cdl0CDe=0P1aLG430861P@0406QXJ01LG5`0G5aL051@D080@41000@0BDU904M7A`17AdL0D51@0P1:
BTX0100O7al02@T900T92@0C4a<20492@P0403lo?`1;Bd/0Bd];05mOG`80AdM700@0CDe=05ADE01D
E5@0F5QH0P1_Kfl0101bLW80Fe]K05]KF`1;Bd/2055AD@0405=CD`17AdL0AdM703hn?P80@D5100@0
DE5A05aLG01LG5`0I6AT0P1VIVH0101XJ6P0MWIf07IfMP1cLg<206QXJ00407QhN01gMgL0MgMg079b
LP80P82000@0QXJ607MgM`1gMgL0O7al0P1_Kfl0101NGUh0LG5a075aL@1dM7@207MgM`0405]KF`1o
Ogl0Ogmo06][J`80DU9B00@0EUIF06UYJ@1YJFT0J6QX0P1QHF40101CDe<0Hf=S06=SH`1[Jf/206YZ
JP0407EeM@1gMgL0MgMg07EeM@80GEeM00@0A4A405=CD`1CDe<0@T920P0V9RH0100W9bL02`/;00/;
2`0<30`2038b<P04055AD@1ZJVX0JVYZ07IfMP80IVIV00@0G5aL06EUI@1UIFD0De=C0P1<C4`0101F
EUH0EEEE05EEE@1JFUX205eMG@0405UIF@0Y:BT0:BTY055AD@80Shn?00@0TI6A08Z:RP2:RXX0NGUi
0P1oOgl01023Ph<0UiNG09NGU`2IVIT209^KV`040:FUY@2/[:`0[:b/0:ZZZP80WYjN00@0Y:BT0:6Q
X@2QXJ40UiNG0P2/[:`0102PX:00Rh^;08^;R`2?Shl207EeM@0406=SH`1eMGD0MGEe06EUI@80GUiN
00@0JVYZ065QH@1QHF40EUIF0P1ADE40101XJ6P0OGem07emO@1LG5`204];B`0408J6QP2g]kL0]kNg
0;Bd]080/[:b00@0/K6a0:ZZZP2ZZZX0ZZZZ0P2g]kL0102`/;00^;Rh0;Rh^031`L420:n_[`<0YjNW
00@0Z:RX0:j^[P2^[Zh0[jn_0P2XZ:P0102OWil0X:2P0:2PX02MWId20:ZZZP040;6a/@2TY:@0Y:BT
0:RXZ080Ogmo00@0BDU903`l?00l?3`03Ph>0P0<30`0100;2`/00P8200820P071`L200H61P0400X:
2P020P800P8200T92@<020P80P030`<00`0;2`/00P8200820P0300L71`0400X:2P000000000000<3
0`801`L700@02PX:00d=3@0=3@d010@40P0=3@d0000300T92@0>3Ph03Ph>00<010@40`020P801007
1`L00@4100410@030`<200@4100400T92@0?3`l03`l?00P820801`L700@030`<00/;2`0;2`/010@4
0P061PH010051@D00`<300<30`020P8200P8200400L71`051@D01@D500T92@801`L710020P8200D5
1@0400<30`051@D01@D500@410802@T900@01`L700@4100410@00P820P030`<010061PH030`<00`<
300L71`2024Q8@04020P800j>SX0>SXj04U9B@80B4Q800@0Bd];02LW9`0W9bL0<c<c0P0h>3P0100?
3`l00@4100410@092@T200/;2`0400X:2P061PH01PH600H61P80000000@08B4Q02d];@0];Bd03`l?
0P0410@0100E5AD08R8R028R8P0E5AD201/K6`0401lO7`0B4Q804Q8B00h>3P804a<C00@06ATI00h>
3P0>3Ph06QXJ0P0<30`0100Q8B40E5AD05ADE01LG5`204U9B@0403hn?P1:BTX0BTY:05IFEP80MWIf
00@0PH6108N7Q`27QhL0M7Ad0P1XJ6P0101CDe<0DE5A055AD@1JFUX203hn?P040451@@17AdL0AdM7
01PH60<02`/;0P1BDU80101@D500G5aL05aLG01WIfL304];B`80BDU900@0FUYJ05aLG01LG5`0GemO
0P1QHF401017AdL0DU9B059BDP1ZJVX205MGE`0403Ph>00d=3@0=3@d04I6AP80D51@00<0HV9R07=c
L`1cLg<00`1iNGT0101XJ6P0JFUY06UYJ@20P80208J6QP04075aL@1^KVh0KVi^08B4Q080SXj>00@0
Ph>307emO@1mOGd0LG5a0P1lO7`0101VIVH0KVi^06i^KP1UIFD206m_K`040820P01LG5`0G5aL04E5
A@80JFUY00@0LG5a06][J`1[Jf/0Jf][0P1/K6`01020P800PX:208:2PP1VIVH206UYJ@0407IfMP1F
EUH0EUIF04U9B@80FEUI00@0C4a<0451@@11@D40:RXZ0P000000100>3Ph0@d=304=3@`1VIVH207Qh
N00408F5Q@1jNWX0NWYj04e=C@80FEUI00@0F5QH038b<P0b<S80@D510P1GEeL0101FEUH0DU9B059B
DP0`<302028R8P0407QhN02CTi<0Ti>C08j>SP80LW9b00@0F5QH06a/K01/K6`0PH610P2HV9P0102A
TI40W9bL09bLW02c/k<20:b/[0040:f][@2SXj<0Xj>S09VIV@80S8b<00@0TY:B0:>SX`2SXj<0SXj>
0P2;Rh/0102BTY80O7al07alO01hN7P208f=S@0408:2PP1XJ6P0J6QX065QH@80FUYJ00<0De=C05EE
E@1EEED00`1ZJVX01016ATH0EUIF05IFEP2KVi/20;^k^`040;Ng]`2b/[80/[:b0;Jf]P80]KFe00@0
XJ6Q0:VYZ@2YZJT0X:2P0P2c/k<01033`l<0[Zj^0:j^[P2SXj<20:VYZ@040:FUY@2VYZH0YZJV0:b/
[080]KFe0`2QXJ40102TY:@0[:b/0:b/[02d];@20:JVYP040:j^[P2=SHd0SHf=04A4A080;bl_00@0
6ATI00L71`071`L020P80P0410@300P8200400820P030`<00`<300H61P802PX:00@01PH600P82008
20P02@T90P030`<300X:2P0400T92@0410@010@400410@801`L700@03`l?00`<300<30`020P80P09
2@T0000300T92@0>3Ph03Ph>00<010@40`020P8010071`L00@4100410@030`<200@4100400T92@0?
3`l03`l?00P820801`L700@030`<00/;2`0;2`/010@40P061PH010051@D00`<300<30`020P8200P8
200400L71`051@D01@D500T92@801`L710020P8200D51@0400<30`051@D01@D500@410802@T900@0
1`L700@4100410@00P820P030`<010061PH030`<00`<300L71`2024Q8@04020P800j>SX0>SXj04U9
B@80B4Q800@0Bd];02LW9`0W9bL0<c<c0P0h>3P0100?3`l00@4100410@092@T200/;2`0400X:2P06
1PH01PH600H61P80000000@08B4Q02d];@0];Bd03`l?0P0410@0100E5AD08R8R028R8P0E5AD201/K
6`0401lO7`0B4Q804Q8B00h>3P804a<C00@06ATI00h>3P0>3Ph06QXJ0P0<30`0100Q8B40E5AD05AD
E01LG5`204U9B@0403hn?P1:BTX0BTY:05IFEP80MWIf00@0PH6108N7Q`27QhL0M7Ad0P1XJ6P0101C
De<0DE5A055AD@1JFUX203hn?P040451@@17AdL0AdM701PH60<02`/;0P1BDU80101@D500G5aL05aL
G01WIfL304];B`80BDU900@0FUYJ05aLG01LG5`0GemO0P1QHF401017AdL0DU9B059BDP1ZJVX205MG
E`0403Ph>00d=3@0=3@d04I6AP80D51@00<0HV9R07=cL`1cLg<00`1iNGT0101XJ6P0JFUY06UYJ@20
P80208J6QP04075aL@1^KVh0KVi^08B4Q080SXj>00@0Ph>307emO@1mOGd0LG5a0P1lO7`0101VIVH0
KVi^06i^KP1UIFD206m_K`040820P01LG5`0G5aL04E5A@80JFUY00@0LG5a06][J`1[Jf/0Jf][0P1/
K6`01020P800PX:208:2PP1VIVH206UYJ@0407IfMP1FEUH0EUIF04U9B@80FEUI00@0C4a<0451@@11
@D40:RXZ0P000000100>3Ph0@d=304=3@`1VIVH207QhN00408F5Q@1jNWX0NWYj04e=C@80FEUI00@0
F5QH038b<P0b<S80@D510P1GEeL0101FEUH0DU9B059BDP0`<302028R8P0407QhN02CTi<0Ti>C08j>
SP80LW9b00@0F5QH06a/K01/K6`0PH610P2HV9P0102ATI40W9bL09bLW02c/k<20:b/[0040:f][@2S
Xj<0Xj>S09VIV@80S8b<00@0TY:B0:>SX`2SXj<0SXj>0P2;Rh/0102BTY80O7al07alO01hN7P208f=
S@0408:2PP1XJ6P0J6QX065QH@80FUYJ00<0De=C05EEE@1EEED00`1ZJVX01016ATH0EUIF05IFEP2K
Vi/20;^k^`040;Ng]`2b/[80/[:b0;Jf]P80]KFe00@0XJ6Q0:VYZ@2YZJT0X:2P0P2c/k<01033`l<0
[Zj^0:j^[P2SXj<20:VYZ@040:FUY@2VYZH0YZJV0:b/[080]KFe0`2QXJ40102TY:@0[:b/0:b/[02d
];@20:JVYP040:j^[P2=SHd0SHf=04A4A080;bl_00@06ATI00L71`071`L020P80P0410@300P82004
00820P030`<00`<300H61P802PX:00@01PH600P8200820P02@T90P030`<300X:2P0400T92@0410@0
10@400410@801`L700@03`l?00`<300<30`020P80P092@T0000400`<300>3Ph03Ph>00P820802PX:
00@0000000L71`071`L010@40P010@4010020P8000000000000410@200/;2`0400<30`0;2`/02`/;
00d=3@8010@400@01`L700X:2P0:2PX00P820`051@D200@410<01@D500@02`/;00@4100410@00P82
0P051@D00`030`<010@400@4100300P8200300D51@0<30`030`<00<01@D500@02PX:00410@010@40
20P80P051@D0100F5QH0:BTY02TY:@0T92@203<c<`0403Lg=`0d=3@0=3@d04A4A080AdM700@0<S8b
03<c<`0c<c<08B4Q0`051@D200h>3P0400l?3`0=3@d03@d=00X:2P800P8200@0410@02DU9@0U9BD0
820P0P0820P0100>3Ph061PH01PH600F5QH202DU9@0402d];@0R8R808R8R01@D50805aLG00@04a<C
01HF5P0F5QH08b<S0P0>3Ph0100B4Q80E5AD05ADE01IFET204];B`0403hn?P11@D40@D5106=SH`80
Q8B400@0QhN708n?S`2?Shl0QhN70P1hN7P0101HF5P0FEUI05UIF@1BDU8203Ph>0040410@00n?Sh0
?Shn014A4@800@4100@0410@04M7A`17AdL0@d=30P1IFET0101LG5`0Bd];04];B`1:BTX204U9B@04
071`L01]KFd0KFe]05]KF`80FEUI00@0A4A404Y:BP1:BTX0GEeM0P1IFET0101DE5@0BDU904U9B@12
@T82055AD@0406ATI01[Jf/0Jf][07UiN@80OWin00@0L71`06m_K`1_Kfl0O7al0P2DU9@0101gMgL0
KFe]06e]K@1gMgL207]kN`0406m_K`1jNWX0NWYj07=cL`80NGUi00@0LW9b06ATI01TI6@0GEeM0P1V
IVH01023Ph<0MgMg07MgM`1OGel207IfMP0406ATI018B4P0B4Q805iNGP80G5aL00@0K6a/079bLP1b
LW80E5AD0P1IFET0101LG5`0@T920492@P1HF5P205iNGP0403`l?010@400@41002<S8`80000000@0
5QHF0451@@11@D40OGem0P2>SXh00`1hN7P0I6AT06ATI00305aLG004059BDP0a<C40<C4a0410@080
ATI600@0@41002d];@0];Bd071`L0P1ADE401025QHD0S8b<08b<S02:RXX206UYJ@0405YJFP1gMgL0
MgMg08J6QP80VYZJ00@0U9BD09RHV02HV9P0Zj^[0P2RXZ80102LW9`0VIVI09VIV@2>SXh208:2PP04
092@T02DU9@0U9BD08R8R080SXj>00@0RHV907EeM@1eMGD0Ng]k0P2FUYH0102CTi<0NGUi07UiN@1Q
HF4205EEE@<0DU9B00@0IfMW06=SH`1SHf<0@D510P1MGEd00`2VYZH0^KVi0;Vi^@030;Fe]@040;>c
/`2^[Zh0[Zj^09JFUP80VIVI00@0TI6A0:>SX`2SXj<0]KFe0P2RXZ80102FUYH0Z:RX0:RXZ02LW9`2
09JFUP040:JVYP2ZZZX0ZZZZ09JFUP80TY:B00@0VYZJ0:>SX`2SXj<0[:b/0P2SXj<0102TY:@0T92@
092@T01HF5P202HV9P0400h>3P051@D01@D500410@800`<300@00@4100<30`030`<01@D50P000000
100<30`03`l?00l?3`051@D200T92@0300P820061PH01PH600<00P8200@01PH600l?3`0?3`l02`/;
0P051@D0100;2`/03Ph>00h>3P0?3`l200410@0000@030`<00T92@092@T01PH60P071`L0100410@0
1@D500D51@010@4200H61P0400820P051@D01@D500<30`8020P800@01PH600`<300<30`02`/;0P01
0@4010061PH020P800P8200820P200820P0400D51@020P800P8200<30`8010@400@02`/;00X:2P0:
2PX020P80`020P8200<30`0300D51@0820P020P800<01PH600@020P800<30`030`<01@D50P071`L0
10030`<00@4100410@0=3@d202/[:`0401`L700U9BD09BDU03De=@80<S8b00@0?3`l04m?C`1?Cdl0
>CTi0P0/;2`0100_;bl04A4A014A4@0410@200/;2`03010@400H61P061PH00<03`l?0`0@4100100I
6AT03@d=00d=3@0E5AD2020P800402<S8`0/;2`0;2`/02/[:`80:BTY00@092@T01hN7P0N7Qh04A4A
0P0>3Ph0100:2PX000000000000F5QH20410@00404e=C@1<C4`0C4a<03Ph>080@41000@0I6AT08:2
PP22PX80TI6A0P2DU9@0101kNg/0NGUi07UiN@1TI6@205aLG0040410@00i>CT0>CTi061PH080EEEE
00@05QHF00410@010@4030`<0P10@4001017AdL0E5AD05ADE01RHV8205ADE00404Q8B01ADE40DE5A
071`L080OGem00@0IfMW05QHF01HF5P0C4a<0P0k>c/01010@400Cdm?04m?C`1JFUX205MGE`0404a<
C01IFET0FEUI065QH@80FEUI00@0IFEU06YZJP1ZJVX0J6QX0P1`L700101bLW80QhN708N7Q`1mOGd2
07MgM`0407]kN`1aLG40LG5a06e]K@80P82000@0LW9b065QH@1QHF40MWIf0P1eMGD0101RHV80I6AT
06ATI01hN7P208B4Q00407EeM@1/K6`0K6a/06=SH`80G5aL00@0GEeM05MGE`1GEeL0IFEU0P1^KVh0
101LG5`0C4a<04a<C019BDT204Y:BP0406=SH`1KFe/0Fe]K02/[:`80820P00@05ADE00H61P061PH0
7QhN0P1;Bd/01024Q8@0U9BD09BDU01YJFT205IFEP0407]kN`1HF5P0F5QH03/k>`80?Cdm00@0ADE5
034a<@0a<C40>3Ph0P0P8200101>CTh0Ph>308>3P`24Q8@20861P@0407UiN@1oOgl0Ogmo08N7Q`80
SHf=00@0Ti>C09fMW@2MWId0Vi^K0P2NWYh0102RXZ80WIfM09fMW@2CTi<209NGU`0409FEU@21PH40
PH6108R8R080SXj>00@0PH6107AdM01dM7@0MGEe0`1gMgL208n?S`0409:BTP1]KFd0KFe]04i>CP80
Bd];00@0D51@059BDP1BDU80Jf][0P1VIVH01015ADD0IfMW06MWI`2[Zj/20;6a/@040:ZZZP2e]KD0
]KFe0;6a/@80Y:BT00<0XZ:R0:b/[02/[:`00`2OWil0102PX:00UYJF09JFUP2FUYH20:JVYP040::R
XP2UYJD0YJFU0:JVYP80WIfM00@0U9BD08f=S@2=SHd0UiNG0P2OWil0102SXj<0XZ:R0::RXP2NWYh2
0820P00406EUI@0W9bL09bLW00P820802`/;00@02PX:00820P020P800P820P010@40100=3@d01@D5
00D51@0:2PX200P8200400<30`061PH01PH600D51@8020P800@01`L700X:2P0:2PX03@d=0P0:2PX0
100@41002@T900T92@020P8200@410403`l?0@0410@100@4100000@030`<00T92@092@T01PH60P07
1`L0100410@01@D500D51@010@4200H61P0400820P051@D01@D500<30`8020P800@01PH600`<300<
30`02`/;0P010@4010061PH020P800P8200820P200820P0400D51@020P800P8200<30`8010@400@0
2`/;00X:2P0:2PX020P80`020P8200<30`0300D51@0820P020P800<01PH600@020P800<30`030`<0
1@D50P071`L010030`<00@4100410@0=3@d202/[:`0401`L700U9BD09BDU03De=@80<S8b00@0?3`l
04m?C`1?Cdl0>CTi0P0/;2`0100_;bl04A4A014A4@0410@200/;2`03010@400H61P061PH00<03`l?
0`0@4100100I6AT03@d=00d=3@0E5AD2020P800402<S8`0/;2`0;2`/02/[:`80:BTY00@092@T01hN
7P0N7Qh04A4A0P0>3Ph0100:2PX000000000000F5QH20410@00404e=C@1<C4`0C4a<03Ph>080@410
00@0I6AT08:2PP22PX80TI6A0P2DU9@0101kNg/0NGUi07UiN@1TI6@205aLG0040410@00i>CT0>CTi
061PH080EEEE00@05QHF00410@010@4030`<0P10@4001017AdL0E5AD05ADE01RHV8205ADE00404Q8
B01ADE40DE5A071`L080OGem00@0IfMW05QHF01HF5P0C4a<0P0k>c/01010@400Cdm?04m?C`1JFUX2
05MGE`0404a<C01IFET0FEUI065QH@80FEUI00@0IFEU06YZJP1ZJVX0J6QX0P1`L700101bLW80QhN7
08N7Q`1mOGd207MgM`0407]kN`1aLG40LG5a06e]K@80P82000@0LW9b065QH@1QHF40MWIf0P1eMGD0
101RHV80I6AT06ATI01hN7P208B4Q00407EeM@1/K6`0K6a/06=SH`80G5aL00@0GEeM05MGE`1GEeL0
IFEU0P1^KVh0101LG5`0C4a<04a<C019BDT204Y:BP0406=SH`1KFe/0Fe]K02/[:`80820P00@05ADE
00H61P061PH07QhN0P1;Bd/01024Q8@0U9BD09BDU01YJFT205IFEP0407]kN`1HF5P0F5QH03/k>`80
?Cdm00@0ADE5034a<@0a<C40>3Ph0P0P8200101>CTh0Ph>308>3P`24Q8@20861P@0407UiN@1oOgl0
Ogmo08N7Q`80SHf=00@0Ti>C09fMW@2MWId0Vi^K0P2NWYh0102RXZ80WIfM09fMW@2CTi<209NGU`04
09FEU@21PH40PH6108R8R080SXj>00@0PH6107AdM01dM7@0MGEe0`1gMgL208n?S`0409:BTP1]KFd0
KFe]04i>CP80Bd];00@0D51@059BDP1BDU80Jf][0P1VIVH01015ADD0IfMW06MWI`2[Zj/20;6a/@04
0:ZZZP2e]KD0]KFe0;6a/@80Y:BT00<0XZ:R0:b/[02/[:`00`2OWil0102PX:00UYJF09JFUP2FUYH2
0:JVYP040::RXP2UYJD0YJFU0:JVYP80WIfM00@0U9BD08f=S@2=SHd0UiNG0P2OWil0102SXj<0XZ:R
0::RXP2NWYh20820P00406EUI@0W9bL09bLW00P820802`/;00@02PX:00820P020P800P820P010@40
100=3@d01@D500D51@0:2PX200P8200400<30`061PH01PH600D51@8020P800@01`L700X:2P0:2PX0
3@d=0P0:2PX0100@41002@T900T92@020P8200@410403`l?0@0410@100@4100000<01`L700820P02
0P800`020P8010051@D00000000000020P8200P8200400T92@0820P020P8014A4@8030`<0`092@T3
00P8200400820P030`<00`<300X:2P801`L700@00`<300L71`071`L000000P0410@0100820P04Q8B
018B4P051@D200820P0400H61P051@D01@D500T92@800P8200@01`L700410@010@4020P80P0410@0
10051@D020P800P820051@D200410@0400l?3`0Z:RX0:RXZ01TI6@805ADE00@0B4Q80451@@11@D40
?Shn0P12@T801014A4@0;Rh^02h^;P0U9BD201hN7P0400X:2P0;2`/02`/;00h>3P805ADE00@03@d=
01@D500D51@04a<C0P0820P401<C4`8071`L00@05aLG01hN7P0N7Qh08B4Q0P0S8b<0100U9BD05QHF
01HF5P0@410201@D500401PH600C4a<04a<C01@D50808B4Q00@0>SXj0492@P12@T80>3Ph0P1=CDd0
101WIfL0NGUi07UiN@2=SHd208j>SP0407IfMP1dM7@0M7Ad05]KF`80D51@00@0>SXj04I6AP16ATH0
MWIf0P1_Kfl0100M7Ad01@D500D51@0B4Q8203hn?P0404m?C`1ADE40DE5A059BDP80D51@00@0DE5A
059BDP1BDU80CDe=0P1TI6@00`1^KVh0Fe]K05]KF`0304m?C`04059BDP1;Bd/0Bd];04A4A080AdM7
00@0C4a<05UIF@1IFET0IVIV0P1TI6@0101KFe/0GemO05mOG`1OGel206][J`0407UiN@1_Kfl0Kfm_
07=cL`80KVi^00@0N7Qh07inOP1nOWh0Ng]k0P20P800101cLg<0J6QX06QXJ01[Jf/206YZJP04051@
D01OGel0GemO071`L080O7al00@0M7Ad05QHF01HF5P0FUYJ0P1ZJVX0101>CTh0A4A404A4A01MGEd2
07=cL`0406EUI@13@d<0@d=304M7A`80GUiN00@0FEUI0410@010@400=3@d0P0[:b/0100@41001`L7
00L71`0K6a/204i>CP0407YjNP2:RXX0RXZ:07IfMP80KFe]00@0IFEU04E5A@15ADD0?Shn0P17AdL0
100g=cL0:BTY02TY:@0e=CD203dm?@0407UiN@2=SHd0SHf=09>CT`80Q8B400@0O7al09>CT`2CTi<0
W9bL0P2DU9@0102IVIT0WIfM09fMW@2PX:0209bLW00409VIV@2SXj<0Xj>S0:BTY080WIfM00@0UiNG
08b<S02<S8`0Ph>30P1nOWh0101aLG40H61P061PH01ZJVX207UiN@0407AdM020P800P8200820P080
EEEE00@0ATI605=CD`1CDe<0CTi>0P1EEED0101[Jf/0Fe]K05]KF`18B4P207QhN0040;Bd]02b/[80
/[:b0:RXZ080/;2`00<0]KFe0;2`/02`/;000`2i^KT0102TY:@0YZJV0:JVYP2XZ:P20:2PX0040::R
XP2VYZH0YZJV0:^[Z`80/k>c00@0YjNW09JFUP2FUYH0S8b<0P21PH40102:RXX0T92@092@T02DU9@2
09bLW00409RHV01cLg<0Lg=c06ATI080;Bd]00@02PX:00/;2`0;2`/01`L70P061PH00`0410@00000
0000000300T92@0400P820010@400@4100L71`800P8200@01@D500L71`071`L02@T90P0;2`/01007
1`L00@4100410@092@T200P8200400<30`0:2PX02PX:00h>3P801@D50000100:2PX010@400@41002
0P8200@4100400410@0410@010@400820P801`L700@020P800H61P061PH03Ph>0P071`L00`030`<0
1`L700L71`0300L71`0400@410020P800P8200@4108030`<00@010@400T92@092@T00`<30P061PH0
100820P03@d=00d=3@00000200T92@0400/;2`051@D01@D500X:2P800`<300@01`L700410@010@40
0@410P020P80100820P00`<300<30`051@D200<30`0400P8200K6a/06a/K01hN7P805ADE00@0@T92
03lo?`0o?cl0B4Q80P1CDe<01019BDT0;2`/02`/;00J6QX202l_;`0401PH600C4a<04a<C01HF5P80
410@00@00@41018B4P0B4Q806ATI0P0@4100100E5AD04a<C01<C4`0;2`/201PH600402HV9P0];Bd0
;Bd]02`/;0809BDU00@05aLG01<C4`0C4a<08B4Q0P0N7Qh0100E5AD0410@010@400820P200h>3P04
02TY:@0e=CD0=CDe03/k>`80De=C00@0Jf][07moO`1oOgl0QXJ60P1kNg/0101iNGT0LG5a075aL@17
AdL20492@P0404I6AP1KFe/0Fe]K07EeM@80N7Qh00@09RHV00L71`071`L0410@0P0c<c<0101>CTh0
E5AD05ADE012@T8204];B`03061PH01[Jf/0Jf][00<0J6QX00@0IFEU05QHF01HF5P0D51@0P1NGUh0
101MGEd0BDU904U9B@1ADE4205YJFP0405EEE@1VIVH0IVIV07EeM@80HF5Q00@0DE5A06UYJ@1YJFT0
J6QX0P1]KFd0101jNWX0HF5Q065QH@1[Jf/206MWI`0407MgM`1oOgl0Ogmo06QXJ080N7Qh00@0Lg=c
06YZJP1ZJVX0E5AD0P1KFe/0101NGUh0Kfm_06m_K`1XJ6P2069RHP0406YZJP1MGEd0GEeM04Y:BP80
Fe]K00@0FEUI04Y:BP1:BTX0DE5A0P1ZJVX0101]KFd0GemO05mOG`1OGel205UIF@0404E5A@0i>CT0
>CTi03Ph>080:b/[00@03Ph>00L71`071`L07alO0P1MGEd01023Ph<0RXZ:08Z:RP23Ph<206a/K004
04=3@`10@400@41004A4A080=3@d00@0:2PX038b<P0b<S808b<S0P1ADE40101`L700Ph>308>3P`2I
VIT20820P00408F5Q@2DU9@0U9BD09nOW`80VYZJ00@0Vi^K0:6QX@2QXJ40YJFU0`2IVIT20:>SX`04
09fMW@2=SHd0SHf=08n?S`80UIFE00@0OWin06i^KP1^KVh0KFe]0P1XJ6P0101WIfL0Jf][06][J`1c
Lg<207moO`0406m_K`16ATH0ATI604I6AP80E5AD00@0Bd];05EEE@1EEED0I6AT0P1<C4`01018B4P0
QHF508F5Q@2f][H20:j^[P<0YZJV00@0[jn_0;Jf]P2f][H0a<C40P2k^k/0102LW9`0WinO09nOW`2U
YJD20:>SX`<0ZJVY0`2VYZH0102QXJ40VYZJ09ZJVP2?Shl207AdM00407YjNP20P800P82008f=S@80
WinO00@0R8R806ATI01TI6@0F5QH0P0Y:BT0100410@00000000000020P8200`<30@00@410P030`<0
0`0<30`010@400@4100300@4100400H61P051@D01@D500410@801PH60`071`L010030`<00@410041
0@061PH200/;2`401`L70@092@T100T92@0000@02PX:00@4100410@00P820P0410@010010@4010@4
00@410020P8200L71`0400P820061PH01PH600h>3P801`L700<00`<300L71`071`L00`071`L01004
10@00P8200820P0410@200`<300400@410092@T02@T900<30`801PH600@020P800d=3@0=3@d00000
0P092@T0100;2`/01@D500D51@0:2PX200<30`0400L71`010@400@4100410@800P8200@020P800<3
0`030`<01@D50P030`<0100820P06a/K01/K6`0N7Qh201DE5@040492@P0o?cl0?clo04Q8B080De=C
00@0BDU902`/;00/;2`06QXJ0P0_;bl0100H61P04a<C01<C4`0F5QH2010@400400410@0B4Q804Q8B
01TI6@80410@00@05ADE01<C4`0C4a<02`/;0P0H61P0100V9RH0;Bd]02d];@0/;2`202DU9@0401LG
5`0C4a<04a<C024Q8@807QhN00@05ADE010@400@410020P80P0>3Ph0100Y:BT0=CDe03De=@0k>c/2
05=CD`0406][J`1oOgl0Ogmo08J6QP80Ng]k00@0NGUi075aL@1aLG40AdM70P12@T801016ATH0Fe]K
05]KF`1eMGD207QhN00402HV9P071`L01`L7010@4080<c<c00@0CTi>05ADE01DE5@0@T920P1;Bd/0
0`1PH600Jf][06][J`0306QXJ00406EUI@1HF5P0F5QH051@D080GUiN00@0GEeM04U9B@19BDT0DE5A
0P1JFUX0101EEED0IVIV06IVIP1eMGD2065QH@04055AD@1YJFT0JFUY06QXJ080KFe]00@0NWYj065Q
H@1QHF40Jf][0P1WIfL0101gMgL0Ogmo07moO`1XJ6P207QhN00407=cL`1ZJVX0JVYZ05ADE080Fe]K
00@0GUiN06m_K`1_Kfl0J6QX0P1RHV80101ZJVX0GEeM05eMG@1:BTX205]KF`0405UIF@1:BTX0BTY:
055AD@80JVYZ00@0KFe]05mOG`1OGel0GemO0P1IFET01015ADD0>CTi03Ti>@0h>3P202/[:`0400h>
3P071`L01`L701lO7`80GEeM00@0Ph>308Z:RP2:RXX0Ph>30P1/K6`01013@d<0@4100410@014A4@2
03@d=00402PX:00b<S80<S8b02<S8`80DE5A00@0L71`08>3P`23Ph<0VIVI0P20P8001025QHD0U9BD
09BDU02OWil209ZJVP0409^KV`2QXJ40XJ6Q0:FUY@<0VIVI0P2SXj<0102MWId0SHf=08f=S@2?Shl2
09FEU@0407inOP1^KVh0KVi^06e]K@80J6QX00@0IfMW06][J`1[Jf/0Lg=c0P1oOgl0101_Kfl0ATI6
04I6AP16ATH205ADE00404];B`1EEED0EEEE06ATI080C4a<00@0B4Q808F5Q@25QHD0][Jf0P2^[Zh3
0:JVYP040:n_[`2f][H0][Jf0<C4a080^k^k00@0W9bL09nOW`2OWil0YJFU0P2SXj<30:VYZ@<0YZJV
00@0XJ6Q09ZJVP2JVYX0Shn?0P1dM7@0101jNWX0P8200820P02=SHd209nOW`0408R8R01TI6@0I6AT
05QHF080:BTY00@010@40000000000000P820P0<30`400410@800`<300<030`<00@4100410@00`04
10@010061PH01@D500D51@010@4200H61P<01`L700@00`<300410@010@401PH60P0;2`/100L71`40
2@T90@092@T0000400L71`020P800P8200H61P8020P800@01@D500@4100410@010@40P051@D01004
10@00`<300<30`010@4200820P0400410@051@D01@D500L71`800P8210030`<200H61P0400L71`08
20P020P800820P800`<300@01PH600D51@051@D010@40P0:2PX010051@D00`<300<30`0410@200L7
1`<01@D50`030`<010051@D01PH600H61P020P8200P8200400<30`0?3`l03`l?028R8P809RHV00@0
>3Ph03lo?`0o?cl0BTY:0P1^KVh0101LG5`0@d=304=3@`0Z:RX202l_;`0302LW9`0D51@051@D00<0
6a/K00@04Q8B00P8200820P02@T90P0@4100100J6QX04a<C01<C4`0B4Q8201DE5@0401PH600R8R80
8R8R02PX:0809RHV00@0820P02PX:00X:2P0<C4a0P0T92@0100B4Q801@D500D51@030`<200X:2P04
01hN7P0a<C40<C4a034a<@80@41000@0E5AD07EeM@1eMGD0Ogmo0P1QHF40101ZJVX0KFe]06e]K@12
@T8204i>CP04051@D01IFET0FEUI07EeM@80NWYj00@0;Bd]00H61P061PH02`/;0P14A4@0101EEED0
AdM704M7A`12@T8205ADE00405EEE@1KFe/0Fe]K06IVIP80MGEe00@0H61P051@D01@D500D51@0P1D
E5@0101NGUh0EeMG05MGE`1IFET2061PH00405YJFP1[Jf/0Jf][07IfMP80HV9R00@0FEUI07=cL`1c
Lg<0NWYj0P1cLg<0101XJ6P0Fe]K05]KF`1aLG4206=SH`0406e]K@1nOWh0OWin05iNGP80J6QX00@0
FUYJ061PH01PH600IfMW0P1mOGd01021PH40O7al07alO01fMWH206ATI00405YJFP1MGEd0GEeM05iN
GP80LW9b00@0Ogmo05iNGP1NGUh0E5AD0P1NGUh0101FEUH0H61P061PH01XJ6P204M7A`0403De=@11
@D40@D5103Lg=`805QHF00@00`<300/;2`0;2`/0;bl_0P1eMGD0102:RXX0QhN708N7Q`27QhL205UI
F@040410@00o?cl0?clo0492@P809BDU00@0=SHf03`l?00l?3`07QhN0P1RHV80101hN7P0TI6A096A
T@2BTY8207]kN`0408J6QP2EUID0UIFE09jNWP80W9bL0`2JVYX0102LW9`0Vi^K09^KV`2KVi/209BD
U00408J6QP24Q8@0Q8B408j>SP80RHV900@0LG5a07MgM`1gMgL0QHF50P1eMGD0101SHf<0K6a/06a/
K020P80208J6QP0406YZJP10@400@4100492@P80ADE500@0A4A405aLG01LG5`0GemO0P11@D40101<
C4`0Vi^K09^KV`2h^;P20:b/[0040;:b/P2f][H0][Jf0;Bd]080][Jf00@0aLG50;6a/@2a/K40Rh^;
0P2EUID0102][Jd0]kNg0;Ng]`2h^;P20:b/[00409^KV`2OWil0WinO0:ZZZP80ZJVY00@0WinO08J6
QP26QXH0QXJ60P2ATI40102QXJ40[jn_0:n_[`1oOgl206IVIP0405iNGP0/;2`0;2`/014A4@800000
00@01@D500P8200820P00`<30`071`L200D51@0400/;2`092@T02@T900D51@801PH600@00`<300P8
200820P02@T90P0=3@d0100;2`/02@T900T92@092@T200H61P0400T92@051@D01@D50000008020P8
000010030`<020P800P8200;2`/200L71`0400T92@020P800P8200@410800`<300@01PH600P82008
20P01`L70P0;2`/0100820P010@400@410030`<200820P0400D51@0820P020P800@41080000000@0
10@400L71`071`L00P820P010@400`030`<00@4100410@0300@4100300820P051@D01@D500@020P8
0P030`<300D51@0400@410092@T02@T900P8208010@400@020P800l?3`0?3`l0:RXZ0P0/;2`0100m
?Cd0F5QH05QHF01=CDd206YZJP04065QH@1BDU80DU9B04Q8B0807alO00@0;2`/01PH600H61P0410@
0P0N7Qh0100W9bL04Q8B018B4P0:2PX200T92@0400h>3P0A4A404A4A018B4P802PX:0`061PH0100>
3Ph061PH01PH600V9RH202LW9`0401PH600N7Qh07QhN02`/;0807QhN00@02PX:00<30`030`<05aLG
0P0^;Rh0100];Bd0?clo03lo?`18B4P205mOG`0407AdM01RHV80HV9R06YZJP80Hf=S00<0?Cdm061P
H01PH6000`1EEED0101eMGD0M7Ad07AdM00/;2`200T92@0400/;2`12@T80@T9204i>CP80ADE500@0
A4A405QHF01HF5P0DE5A0P1;Bd/0101:BTX0IFEU06EUI@1NGUh204];B`0405IFEP1MGEd0GEeM065Q
H@80F5QH00@0Bd];04Y:BP1:BTX0D51@0P1QHF4306=SH`0306IVIP1YJFT0JFUY00<0MGEe00@0Hf=S
05mOG`1OGel0Kfm_0P1YJFT0101[Jf/0O7al07alO01UIFD205mOG`0406EUI@1/K6`0K6a/07=cL`80
P82000@0Q8B40861P@21PH40PX:20P1YJFT01018B4P0E5AD05ADE01/K6`306YZJP80FUYJ00@0IFEU
069RHP1RHV80B4Q80P1;Bd/305eMG@0404I6AP0i>CT0>CTi02l_;`80410@00@00@4100d=3@0=3@d0
=SHf0P20P8001028R8P0QXJ608J6QP20P802059BDP0404a<C015ADD0ADE504i>CP80<S8b00@0A4A4
030`<00`<300;2`/0P1jNWX01026QXH0TY:B09:BTP2;Rh/206QXJ00407=cL`2LW9`0W9bL09jNWP80
UYJF00@0V9RH096AT@2ATI40UIFE0P2FUYH0102;Rh/0QHF508F5Q@21PH4208R8R00408n?S`1hN7P0
N7Qh05iNGP80Lg=c00@0S8b<08B4Q024Q8@0NWYj0P1lO7`01025QHD0QhN708N7Q`1TI6@203hn?P04
04A4A00m?Cd0?Cdm03dm?@80GEeM00@0G5aL03Ph>00h>3P0EUIF0P2][Jd0102m_Kd0/;2`0;2`/02d
];@20<71`@040;Jf]P2g]kL0]kNg0<;2`P80YJFU00@0TY:B0:BTY02TY:@0^;Rh0P2m_Kd0102e]KD0
ZZZZ0:ZZZP2TY:@20:JVYP030:b/[02VYZH0YZJV00<0VYZJ00@0V9RH0:BTY02TY:@0/[:b0P2`/;00
102;Rh/0QXJ608J6QP1bLW8203Xj>P0401hN7P092@T02@T900X:2P800P820`051@D0100410@02`/;
00/;2`051@D200L71`0400H61P0820P020P800410@801PH600@02`/;00d=3@0=3@d01@D50P092@T0
100E5AD02`/;00/;2`092@T200D51@400P820@0410@100@4100000@00`<300P8200820P02`/;0P07
1`L010092@T00P8200820P0410@200<30`0400H61P0820P020P800L71`802`/;00@020P800@41004
10@00`<30P020P8010051@D020P800P8200410@20000000400@410071`L01`L700820P800@4100<0
0`<300410@010@400`0410@00`020P801@D500D51@0400P820800`<30`051@D0100410@02@T900T9
2@0820P200@4100400P8200?3`l03`l?02XZ:P80;2`/00@0?Cdm05QHF01HF5P0CDe=0P1ZJVX0101Q
HF40DU9B059BDP18B4P201lO7`0402`/;00H61P061PH010@40807QhN00@09bLW018B4P0B4Q802PX:
0P092@T0100>3Ph04A4A014A4@0B4Q8200X:2P<01PH600@03Ph>01PH600H61P09RHV0P0W9bL0100H
61P07QhN01hN7P0/;2`201hN7P0400X:2P030`<00`<301LG5`80;Rh^00@0;Bd]03lo?`0o?cl0B4Q8
0P1OGel0101dM7@0HV9R069RHP1ZJVX206=SH`0303dm?@1PH600H61P00<0EEEE00@0MGEe07AdM01d
M7@0;2`/0P092@T0100;2`/0@T920492@P1>CTh204E5A@0404A4A01HF5P0F5QH055AD@80Bd];00@0
BTY:06EUI@1UIFD0GUiN0P1;Bd/0101FEUH0GEeM05eMG@1QHF4205QHF00404];B`1:BTX0BTY:051@
D080HF5Q0`1SHf<00`1VIVH0JFUY06UYJ@0307EeM@0406=SH`1OGel0GemO06m_K`80JFUY00@0Jf][
07alO01lO7`0IFEU0P1OGel0101UIFD0K6a/06a/K01cLg<20820P00408B4Q021PH40PH6108:2PP80
JFUY00@0B4Q805ADE01DE5@0K6a/0`1ZJVX205YJFP0406EUI@1RHV80HV9R04Q8B080Bd];0`1MGEd0
1016ATH0>CTi03Ti>@0_;bl2010@400400410@0=3@d03@d=03Hf=P80P82000@0R8R808J6QP26QXH0
P8200P1BDU80101<C4`0ADE504E5A@1>CTh2038b<P0404A4A00`<300<30`02`/;080NWYj00@0QXJ6
09:BTP2BTY80Rh^;0P1XJ6P0101cLg<0W9bL09bLW02NWYh209JFUP0409RHV02ATI40TI6A09FEU@80
UYJF00@0Rh^;08F5Q@25QHD0PH610P28R8P0102?Shl0N7Qh07QhN01NGUh207=cL`0408b<S024Q8@0
Q8B407YjNP80O7al00@0QHF508N7Q`27QhL0I6AT0P0n?Sh01014A4@0?Cdm03dm?@0m?Cd205eMG@04
05aLG00h>3P0>3Ph05IFEP80[Jf]00@0_Kfm0;2`/02`/;00];Bd0P31`L40102f][H0]kNg0;Ng]`32
`/820:FUY@0409:BTP2TY:@0Y:BT0;Rh^080_Kfm00@0]KFe0:ZZZP2ZZZX0Y:BT0P2VYZH00`2/[:`0
YZJV0:JVYP0309ZJVP0409RHV02TY:@0Y:BT0;:b/P80/;2`00@0Rh^;08J6QP26QXH0LW9b0P0j>SX0
100N7Qh02@T900T92@0:2PX200820P<01@D500@010@400/;2`0;2`/01@D50P071`L010061PH020P8
00P820010@4200H61P0400/;2`0=3@d03@d=00D51@802@T900@05ADE00/;2`0;2`/02@T90P051@D1
00820P4010@40@0410@0000400<30`0:2PX02PX:00T92@800@4100@02`/;00L71`071`L01`L70P05
1@D00`061PH030`<00`<300300/;2`0400H61P071`L01`L700<30`801@D500@01`L700D51@051@D0
10@40P051@D010071`L00P8200820P00000200410@0300<30`061PH01PH600<01PH600@00P8200P8
200820P02@T90P061PH00`092@T00@4100410@0300820P0400410@020P800P8200D51@800P8200@0
1`L700P8200820P09BDU0P0H61P0100l?3`0IVIV06IVIP1ADE4205QHF00405IFEP15ADD0ADE505UI
F@80:RXZ00@061PH02`/;00/;2`04a<C0P0A4A40100S8b<09BDU02DU9@0C4a<200T92@0400L71`0;
2`/02`/;00X:2P803`l?00@04A4A00@4100410@01`L70P0=3@d0100I6AT07AdM01dM7@092@T200X:
2P0401TI6@0E5AD05ADE00P820800`<300@04A4A024Q8@0Q8B40=CDe0P1>CTh0101JFUX0HF5Q065Q
H@1`L702075aL@0407EeM@1MGEd0GEeM04E5A@80JFUY00@0FUYJ05aLG01LG5`0JVYZ0P1YJFT0100/
;2`03Ph>00h>3P0;2`/2030`<00403dm?@15ADD0ADE504E5A@80DE5A00@0Bd];05MGE`1GEeL0EeMG
0P1RHV80101WIfL0GEeM05eMG@1QHF42069RHP0405MGE`1IFET0FEUI069RHP80DU9B00@0B4Q805mO
G`1OGel0HF5Q0P1GEeL0101RHV80IFEU06EUI@1XJ6P206a/K00405eMG@1YJFT0JFUY06i^KP80L71`
00@0P82007UiN@1iNGT0IFEU0P1ZJVX01020P800LG5a075aL@1`L7020861P@0407moO`1`L700L71`
06][J`80NGUi00@0G5aL05MGE`1GEeL0I6AT0`1GEeL205QHF00406IVIP1SHf<0Hf=S059BDP80BTY:
00@0EUIF06][J`1[Jf/0DU9B0P0_;bl0100U9BD03Ph>00h>3P061PH201@D50040451@@20P800P820
08F5Q@80S8b<00@0KFe]05=CD`1CDe<0EeMG0P1ADE401013@d<07alO01lO7`0V9RH2010@400403dm
?@1hN7P0N7Qh0861P@80P82000@0O7al05iNGP1NGUh0KFe]0P2EUID0102LW9`0WIfM09fMW@2LW9`2
08V9R@04096AT@2:RXX0RXZ:07UiN@80NWYj00@0Ogmo08Z:RP2:RXX0U9BD0P1hN7P0101XJ6P0PH61
0861P@2=SHd208N7Q`0408:2PP1nOWh0OWin08J6QP80Q8B400@0GemO03hn?P0n?Sh0?Cdm0P0j>SX0
1014A4@0G5aL05aLG01HF5P203Xj>P0406MWI`2h^;P0^;Rh0<71`@80^;Rh00@0[:b/0;Rh^02h^;P0
Zj^[0P2][Jd0102n_[h0X:2P0:2PX02CTi<20:JVYP040:f][@2d];@0];Bd0:BTY080XZ:R00@0/k>c
0:f][@2][Jd0Xj>S0P2[Zj/0102VYZH0XZ:R0::RXP2JVYX20:2PX0040;:b/P2d];@0];Bd0:2PX080
UiNG00@0N7Qh03hn?P0n?Sh06QXJ0P092@T010061PH020P800P8200:2PX200820P040000000;2`/0
2`/;00820P80000000@00P8200L71`071`L01@D50P0410@0100;2`/02PX:00X:2P051@D200T92@04
014A4@071`L01`L700<30`801PH60@020P8100D51@401@D5000010061PH00@4100410@030`<200@4
100400L71`0820P020P800/;2`802PX:00@01PH600L71`071`L01`L70P051@D01000000010@400@4
10071`L200820P0400H61P020P800P8200820P802PX:00@03@d=00P8200820P01`L70P061PH00`05
1@D02PX:00X:2P0300T92@<01`L70`010@4010020P800`<300<30`00000300820P8010@40`010@40
10051@D03`l?00l?3`0S8b<201@D5004034a<@1=CDd0CDe=04Q8B080Bd];00@0GUiN059BDP1BDU80
FUYJ0P1>CTh0100I6AT0:b/[02/[:`0O7al200T92@03018B4P0K6a/06a/K00<05ADE00@04a<C018B
4P0B4Q801`L70P0820P0100?3`l03Ph>00h>3P0;2`/200410@04014A4@0T92@092@T01`L70804A4A
00@03Ph>00d=3@0=3@d04a<C0P0T92@0100S8b<09BDU02DU9@0j>SX205ADE00406ATI01YJFT0JFUY
06i^KP80LW9b00@0M7Ad05eMG@1MGEd0Fe]K0P1UIFD01018B4P0EUIF05IFEP1CDe<2055AD@04028R
8P0<30`030`<00T92@80?Cdm00@0CDe=0492@P12@T80>3Ph0P19BDT0101<C4`0BTY:04Y:BP1FEUH2
06e]K@0406UYJ@1MGEd0GEeM05QHF080GEeM00@0Fe]K05=CD`1CDe<0FEUI0P1FEUH01016ATH0F5QH
05QHF01/K6`205IFEP0405iNGP1ZJVX0JVYZ06YZJP80GUiN00@0Bd];075aL@1aLG40Ng]k0P1NGUh0
101^KVh0LG5a075aL@1XJ6P206m_K`0406e]K@1PH600H61P06i^KP80P82000@0IVIV05EEE@1EEED0
F5QH0P21PH40101[Jf/0Fe]K05]KF`1YJFT205mOG`0406e]K@1TI6@0I6AT05MGE`80GemO00@0EeMG
04M7A`17AdL0Bd];0P1ADE401011@D40<C4a034a<@0O7al200h>3P0401PH600G5aL05aLG03hn?P80
O7al00@0QHF50861P@21PH40BDU90P10@40304a<C004028R8P030`<00`<300T92@806ATI00@0DU9B
07inOP1nOWh0P8200P1eMGD0101YJFT0LG5a075aL@28R8P209JFUP0409RHV02IVIT0VIVI09FEU@80
QhN700@0PX:207UiN@1iNGT0Lg=c0P1lO7`01023Ph<0RHV908V9R@2:RXX207IfMP0407UiN@2DU9@0
U9BD08n?S`80NWYj00@0MGEe07moO`1oOgl0S8b<0P21PH40101GEeL0@D510451@@0m?Cd203`l?004
04Y:BP1GEeL0EeMG05=CD`80>SXj00@0MgMg0<30`030`<00^[Zj0P2i^KT0102a/K40YZJV0:JVYP2W
YjL20:^[Z`040:VYZ@2JVYX0VYZJ09:BTP80VIVI00@0WIfM0;6a/@2a/K40[:b/0P2[Zj/0102c/k<0
/K6a0;6a/@2VYZH20:^[Z`040:f][@2IVIT0VIVI08j>SP80W9bL00@0];Bd0<30`030`<00]kNg0P2J
VYX0101[Jf/0=cLg03Lg=`0C4a<200X:2P0400820P0820P020P800X:2P800P8200@00@4100L71`07
1`L01PH60P020P8010071`L010@400@4100410@200T92@0400/;2`051@D01@D500P820801`L700@0
1PH600@4100410@00P820P030`<1000000401`L70@071`L0000400H61P010@400@4100<30`8010@4
00@01`L700P8200820P02`/;0P0:2PX010061PH01`L700L71`071`L200D51@040000000410@010@4
00L71`800P8200@01PH600820P020P800P820P0:2PX0100=3@d020P800P820071`L200H61P0300D5
1@0:2PX02PX:00<02@T90`071`L300410@0400820P030`<00`<3000000<00P820P0410@300410@04
00D51@0?3`l03`l?02<S8`8051@D00@0<C4a04e=C@1=CDd0B4Q80P1;Bd/0101NGUh0DU9B059BDP1J
FUX204i>CP0401TI6@0[:b/0:b/[01lO7`802@T900<04Q8B01/K6`0K6a/00`0E5AD0100C4a<04Q8B
018B4P071`L200P8200400l?3`0>3Ph03Ph>00/;2`800@4100@04A4A02@T900T92@071`L0P0A4A40
100>3Ph03@d=00d=3@0C4a<202@T900402<S8`0U9BD09BDU03Xj>P80E5AD00@0I6AT06UYJ@1YJFT0
KVi^0P1bLW80101dM7@0GEeM05eMG@1KFe/206EUI@0404Q8B01FEUH0EUIF05=CD`80DE5A00@08R8R
00`<300<30`02@T90P0m?Cd0101=CDd0@T920492@P0h>3P204U9B@0404a<C01:BTX0BTY:05IFEP80
KFe]00@0JFUY05eMG@1MGEd0F5QH0P1MGEd0101KFe/0De=C05=CD`1IFET205IFEP0404I6AP1HF5P0
F5QH06a/K080EUIF00@0GUiN06YZJP1ZJVX0JVYZ0P1NGUh0101;Bd/0LG5a075aL@1kNg/205iNGP04
06i^KP1aLG40LG5a06QXJ080Kfm_00@0KFe]061PH01PH600KVi^0P20P800101VIVH0EEEE05EEE@1H
F5P20861P@0406][J`1KFe/0Fe]K06UYJ@80GemO00@0KFe]06ATI01TI6@0EeMG0P1OGel0101GEeL0
AdM704M7A`1;Bd/2055AD@040451@@0a<C40<C4a01lO7`803Ph>00@061PH01LG5`0G5aL0?Shn0P1l
O7`01025QHD0PH610861P@19BDT20410@0<0C4a<00@08R8R00<30`030`<02@T90P0I6AT0101BDU80
OWin07inOP20P80207EeM@0406UYJ@1aLG40LG5a08R8R080UYJF00@0V9RH09VIV@2IVIT0UIFE0P27
QhL01022PX80NGUi07UiN@1cLg<207alO00408>3P`29RHT0RHV908Z:RP80MWIf00@0NGUi09BDU02D
U9@0Shn?0P1jNWX0101eMGD0Ogmo07moO`2<S8`20861P@0405MGE`11@D40@D5103dm?@80?3`l00@0
BTY:05MGE`1GEeL0De=C0P0j>SX0101gMgL0`<300<30`02j^[X20;Vi^@040;6a/@2VYZH0YZJV0:NW
Y`80Zj^[00@0ZJVY09ZJVP2JVYX0TY:B0P2IVIT0102MWId0/K6a0;6a/@2/[:`20:^[Z`040;>c/`2a
/K40/K6a0:JVYP80Zj^[00@0[Jf]09VIV@2IVIT0SXj>0P2LW9`0102d];@0`<300<30`02g]kL209ZJ
VP0406][J`0g=cL0=cLg01<C4`802PX:00@00P8200P8200820P02PX:0P020P8010010@401`L700L7
1`061PH200820P0400L71`0410@010@400@410802@T900@02`/;00D51@051@D020P80P071`L01006
1PH010@400@410020P8200<30`4000000@071`L100L71`0000@0410@00/;2`0;2`/010@40P030`<0
10010@401PH600H61P061PH200P820<010@400@02@T900@4100410@01@D50P061PH300D51@<010@4
00@02@T900X:2P0:2PX01@D50P0820P010061PH010@400@410030`<200@4100400<30`051@D01@D5
00@410800P8200@01`L700H61P061PH01@D50P0820P0100000001@D500D51@092@T200`<300400D5
1@020P800P8200<30`80410@00@07QhN01`L700L71`07QhN0P0W9bL0101:BTX0D51@051@D01^KVh2
079bLP0405EEE@1ZJVX0JVYZ04];B`806a/K00@0:RXZ01XJ6P0J6QX020P80P0B4Q800`0T92@09BDU
02DU9@0301hN7P0401@D500=3@d03@d=01<C4`805QHF00@04Q8B01@D500D51@07AdM0P0T92@0100E
5AD04a<C01<C4`0M7Ad200T92@0400d=3@0b<S80<S8b0492@P80AdM700@0D51@06=SH`1SHf<0GEeM
0P1OGel0101bLW80O7al07alO01^KVh205mOG`0405iNGP1CDe<0De=C03@d=080Cdm?00@0DE5A05UI
F@1IFET09BDU0P071`L0100:2PX0ATI604I6AP1UIFD204m?C`040492@P18B4P0B4Q805MGE`80ATI6
00@0CTi>06][J`1[Jf/0GemO0P1LG5`0101HF5P0FEUI05UIF@1UIFD205IFEP0404M7A`1JFUX0FUYJ
059BDP80De=C00@0MWIf05iNGP1NGUh0E5AD0P1RHV80101]KFd0L71`071`L01ZJVX2075aL@0406a/
K01IFET0FEUI061PH080Kfm_00@0Lg=c07IfMP1fMWH0Kfm_0P1YJFT0101_Kfl0Ph>308>3P`1[Jf/2
06i^KP0407=cL`1fMWH0MWIf06a/K080Hf=S00@0KVi^06QXJ01XJ6P0LG5a0P1KFe/0101DE5@0KFe]
06e]K@1_Kfl206][J`0405mOG`17AdL0AdM704E5A@80AdM700@08b<S00T92@092@T071`L0P0B4Q80
100i>CT0NWYj07YjNP1nOWh206QXJ00402/[:`0F5QH05QHF02DU9@809RHV00@01@D501LG5`0G5aL0
;Bd]0P0l?3`0101DE5@0Ph>308>3P`1YJFT206m_K`0406i^KP21PH40PH6109NGU`80X:2P00@0VIVI
08n?S`2?Shl0QXJ60P20P800101aLG40LW9b079bLP1kNg/207moO`030820P01mOGd0OGem00<0N7Qh
00@0QXJ609JFUP2FUYH0Ph>30P1[Jf/0101kNg/0SXj>08j>SP2<S8`207=cL`0404M7A`12@T80@T92
03dm?@80=cLg00@0@T9204];B`1;Bd/0C4a<0P10@4001025QHD0_Kfm0;fm_@2YZJT20:b/[0040;>c
/`2OWil0WinO0:ZZZP80][Jf00@0YJFU09fMW@2MWId0X:2P0P2OWil0102SXj<0ZJVY0:VYZ@2/[:`2
0;Bd]0040:BTY02WYjL0YjNW0;:b/P80YjNW00@0XZ:R09BDU02DU9@0TI6A0P2QXJ40102f][H0`<30
0<30`02j^[X209^KV`0406e]K@12@T80@T9202DU9@803@d=00@01`L700P8200820P00P820P030`<0
10092@T01`L700L71`071`L200@4100300`<300820P020P800<010@400@020P800D51@051@D020P8
0P0:2PX300@4100400D51@000000000000@410802@T90000100:2PX030`<00`<30071`L200<30`04
00410@0410@010@400@410801`L700@01@D500P8200820P03`l?0P051@D010020P801`L700L71`08
20P200H61P0400410@0410@010@400T92@801`L700@00@4100<30`030`<01`L70P061PH010000000
0@4100410@020P8200<30`0400@410030`<00`<300@410802@T90`0<30`00`020P802@T900T92@03
00/;2`0400T92@010@400@4100<30`802@T900@06QXJ028R8P0R8R807AdM0P0J6QX0101BDU80FUYJ
05YJFP1]KFd208>3P`0405mOG`1SHf<0Hf=S07=cL`80;Rh^00@0:BTY02d];@0];Bd04a<C0P0H61P0
100W9bL0;Bd]02d];@0W9bL2024Q8@0402DU9@0Q8B408B4Q01TI6@8071`L00@0:2PX03Ph>00h>3P0
;2`/0P0J6QX0100<30`04A4A014A4@0K6a/200l?3`0401<C4`0H61P061PH02d];@80E5AD00@0GUiN
079bLP1bLW80Hf=S0P1BDU80101cLg<0RHV908V9R@1cLg<206][J`0405IFEP0f=SH0=SHf02LW9`80
E5AD00@0IVIV07AdM01dM7@0;bl_0P051@D010061PH0<c<c03<c<`1:BTX203lo?`0404i>CP1;Bd/0
Bd];05QHF080E5AD00@0BTY:059BDP1BDU80DE5A0P1UIFD0101^KVh0FEUI05UIF@1OGel206IVIP04
04m?C`1GEeL0EeMG05YJFP80GUiN00@0OGem06QXJ01XJ6P0De=C0P1QHF40101gMgL0Q8B408B4Q028
R8P206YZJP0405eMG@1TI6@0I6AT06a/K080KVi^00@0M7Ad08B4Q024Q8@0QHF50P1dM7@0101`L700
T92@092@T01nOWh207UiN@0408:2PP1_Kfl0Kfm_071`L080LW9b00@0Lg=c06m_K`1_Kfl0FUYJ0P19
BDT0101GEeL0IFEU06EUI@1[Jf/207=cL`04065QH@1=CDd0CDe=059BDP80@d=300@071`L00X:2P0:
2PX02`/;0P0A4A401015ADD0OGem07emO@1mOGd2069RHP0402h^;P0:2PX02PX:00P820806QXJ00@0
=CDe04i>CP1>CTh0HF5Q0P1HF5P0101<C4`0Jf][06][J`1@D50206m_K`0407alO02?Shl0Shn?09:B
TP80V9RH00@0U9BD08f=S@2=SHd0Ogmo0P1`L700101ZJVX0Ng]k07]kN`1oOgl207QhN00407]kN`1f
MWH0MWIf07EeM@80OWin00@0QXJ609BDU02DU9@0QXJ60P1YJFT0101nOWh0UiNG09NGU`2<S8`2069R
HP0403dm?@0n?Sh0?Shn03@d=080>3Ph00@0A4A404U9B@19BDT0@T920P18B4P0102EUID0/k>c0;>c
/`2TY:@20:FUY@040:b/[02YZJT0ZJVY09jNWP80][Jf00@0/[:b0:VYZ@2YZJT0YZJV0P2RXZ80102a
/K40[:b/0:b/[02^[Zh20;Zj^P040:j^[P2[Zj/0Zj^[0:ZZZP80T92@00@0VIVI09jNWP2NWYh0WYjN
0P2YZJT0102i^KT0^k^k0;^k^`2TY:@209JFUP0407moO`1?Cdl0Cdm?02h^;P80410@00@01@D500@4
100410@000000P071`L0100=3@d01@D500D51@051@D200H61P0400@410071`L01`L700T92@8010@4
00@01`L700T92@092@T02PX:0P092@T00`010@400P8200820P0300@410<01`L70000100:2PX030`<
00`<30071`L200<30`0400410@0410@010@400@410801`L700@01@D500P8200820P03`l?0P051@D0
10020P801`L700L71`0820P200H61P0400410@0410@010@400T92@801`L700@00@4100<30`030`<0
1`L70P061PH0100000000@4100410@020P8200<30`0400@410030`<00`<300@410802@T90`0<30`0
0`020P802@T900T92@0300/;2`0400T92@010@400@4100<30`802@T900@06QXJ028R8P0R8R807AdM
0P0J6QX0101BDU80FUYJ05YJFP1]KFd208>3P`0405mOG`1SHf<0Hf=S07=cL`80;Rh^00@0:BTY02d]
;@0];Bd04a<C0P0H61P0100W9bL0;Bd]02d];@0W9bL2024Q8@0402DU9@0Q8B408B4Q01TI6@8071`L
00@0:2PX03Ph>00h>3P0;2`/0P0J6QX0100<30`04A4A014A4@0K6a/200l?3`0401<C4`0H61P061PH
02d];@80E5AD00@0GUiN079bLP1bLW80Hf=S0P1BDU80101cLg<0RHV908V9R@1cLg<206][J`0405IF
EP0f=SH0=SHf02LW9`80E5AD00@0IVIV07AdM01dM7@0;bl_0P051@D010061PH0<c<c03<c<`1:BTX2
03lo?`0404i>CP1;Bd/0Bd];05QHF080E5AD00@0BTY:059BDP1BDU80DE5A0P1UIFD0101^KVh0FEUI
05UIF@1OGel206IVIP0404m?C`1GEeL0EeMG05YJFP80GUiN00@0OGem06QXJ01XJ6P0De=C0P1QHF40
101gMgL0Q8B408B4Q028R8P206YZJP0405eMG@1TI6@0I6AT06a/K080KVi^00@0M7Ad08B4Q024Q8@0
QHF50P1dM7@0101`L700T92@092@T01nOWh207UiN@0408:2PP1_Kfl0Kfm_071`L080LW9b00@0Lg=c
06m_K`1_Kfl0FUYJ0P19BDT0101GEeL0IFEU06EUI@1[Jf/207=cL`04065QH@1=CDd0CDe=059BDP80
@d=300@071`L00X:2P0:2PX02`/;0P0A4A401015ADD0OGem07emO@1mOGd2069RHP0402h^;P0:2PX0
2PX:00P820806QXJ00@0=CDe04i>CP1>CTh0HF5Q0P1HF5P0101<C4`0Jf][06][J`1@D50206m_K`04
07alO02?Shl0Shn?09:BTP80V9RH00@0U9BD08f=S@2=SHd0Ogmo0P1`L700101ZJVX0Ng]k07]kN`1o
Ogl207QhN00407]kN`1fMWH0MWIf07EeM@80OWin00@0QXJ609BDU02DU9@0QXJ60P1YJFT0101nOWh0
UiNG09NGU`2<S8`2069RHP0403dm?@0n?Sh0?Shn03@d=080>3Ph00@0A4A404U9B@19BDT0@T920P18
B4P0102EUID0/k>c0;>c/`2TY:@20:FUY@040:b/[02YZJT0ZJVY09jNWP80][Jf00@0/[:b0:VYZ@2Y
ZJT0YZJV0P2RXZ80102a/K40[:b/0:b/[02^[Zh20;Zj^P040:j^[P2[Zj/0Zj^[0:ZZZP80T92@00@0
VIVI09jNWP2NWYh0WYjN0P2YZJT0102i^KT0^k^k0;^k^`2TY:@209JFUP0407moO`1?Cdl0Cdm?02h^
;P80410@00@01@D500@4100410@000000P071`L0100=3@d01@D500D51@051@D200H61P0400@41007
1`L01`L700T92@8010@400@01`L700T92@092@T02PX:0P092@T00`010@400P8200820P0300@410<0
1`L7000010051@D02PX:00X:2P051@D2000000<00P8200@020P800d=3@0=3@d01PH60P030`<01006
1PH00`<300<30`00000200D51@0400T92@030`<00`<300<30`8010@400@00@4100H61P061PH01PH6
0P020P800`0<30`02PX:00X:2P0300D51@0400H61P0410@010@400D51@8010@400@01@D500P82008
20P02`/;0P0=3@d010030`<01`L700L71`0>3Ph200X:2P0400`<30030`<00`<300T92@801@D500@0
4a<C020P800P8200<30`0P0V9RH0100o?cl0A4A404A4A01TI6@207UiN@0406YZJP1DE5@0E5AD07=c
L`80@d=300@06ATI02XZ:P0Z:RX07AdM0P0T92@0100[:b/09bLW02LW9`0S8b<201XJ6P0402@T900S
8b<08b<S01LG5`808B4Q00@0;bl_03@d=00d=3@09RHV0P0P8200100`<3009RHV02HV9P0K6a/203<c
<`040451@@0W9bL09bLW01PH6080>CTi00@0CTi>069RHP1RHV80Hf=S0P1GEeL0101jNWX0SHf=08f=
S@1hN7P206YZJP0405QHF010@400@41004=3@`80I6AT00@0K6a/07MgM`1gMgL0;2`/0P0820P01000
0000=CDe03De=@1?Cdl204E5A@040492@P10@400@410055AD@80EeMG00@0CDe=04];B`1;Bd/0E5AD
0P1SHf<0101cLg<0GEeM05eMG@1FEUH205aLG00404Q8B01ADE40DE5A05mOG`80FUYJ0`1PH600101T
I6@0JFUY06UYJ@1oOgl207QhN00407EeM@1^KVh0KVi^07IfMP80L71`00@0MGEe07IfMP1fMWH0OGem
0P22PX80101cLg<0KVi^06i^KP1lO7`209:BTP0407=cL`1KFe/0Fe]K07MgM`80PH6100@0N7Qh07If
MP1fMWH0Jf][0P1^KVh0101CDe<0BTY:04Y:BP1KFe/205UIF@04061PH01MGEd0GEeM04e=C@80F5QH
00@0DU9B02DU9@0U9BD01@D50P0:2PX010061PH04Q8B018B4P1=CDd207YjNP0408F5Q@1bLW80LW9b
04m?C`80=3@d00@0>3Ph05ADE01DE5@0MgMg0P1mOGd0101hN7P0J6QX06QXJ01QHF4207EeM@04075a
L@22PX80PX:208F5Q@80UIFE0`2FUYH01022PX80MgMg07MgM`1fMWH207EeM@0406e]K@1fMWH0MWIf
07MgM`<0LW9b0P1]KFd0101iNGT0Ph>308>3P`26QXH209FEU@0408Z:RP1bLW80LW9b07inOP80SHf=
00@0PH6105UIF@1IFET0@D510P0h>3P0100];Bd0>3Ph03Ph>00n?Sh2055AD@<0ATI600@0WYjN0;Fe
]@2e]KD0[Zj^1@2][Jd0102KVi/0/[:b0;:b/P2^[Zh20;Fe]@040:n_[`2KVi/0Vi^K0:^[Z`80[Jf]
00@0/[:b0;^k^`2k^k/0_;bl0P2_[jl0102NWYh0TY:B09:BTP2SXj<20:JVYP040:RXZ02c/k<0/k>c
0;>c/`80^k^k00@0Z:RX0:NWY`2WYjL0TI6A0P10@400100J6QX05aLG01LG5`0;2`/200410@0400<3
0`071`L01`L700H61P8010@400@01@D500@4100410@00@410P030`<010071`L020P800P8200410@2
00D51@0300`<300;2`/02`/;00<010@400@00`<300H61P061PH01@D50P030`<0000400H61P0820P0
20P800H61P8010@40`020P8010051@D020P800P820092@T200H61P<00@4100@0000000@4100410@0
0`<30P020P8010061PH01@D500D51@020P8200P8200300T92@020P800P8200<00`<300@00P8200<3
0`030`<01@D50`030`<20000000300L71`0:2PX02PX:00<02`/;00<0000000410@010@400`0:2PX0
100820P00@4100410@0820P200L71`0400h>3P0L71`071`L034a<@80>c/k00@0>CTi02HV9P0V9RH0
De=C0P1FEUH0101LG5`0Fe]K05]KF`1eMGD205YJFP0401lO7`0Q8B408B4Q028R8P809BDU00@0820P
01TI6@0I6AT0820P0P0J6QX0100O7al09BDU02DU9@0K6a/2024Q8@0402`/;00X:2P0:2PX024Q8@80
820P00@0=cLg038b<P0b<S80:b/[0P1:BTX0101HF5P0B4Q804Q8B00U9BD201hN7P040410@01BDU80
DU9B06=SH`80KVi^00@0PX:208Z:RP2:RXX0NGUi0P1RHV80101SHf<0HF5Q065QH@1VIVH206i^KP04
075aL@1lO7`0O7al02d];@804a<C00@00P8203lo?`0o?cl0GEeM0P1DE5@01013@d<0A4A404A4A01=
CDd2051@D00405UIF@1OGel0GemO06MWI`80G5aL00@0GUiN069RHP1RHV80K6a/0P1ZJVX0101?Cdl0
EUIF05IFEP1JFUX204e=C@0405iNGP1aLG40LG5a07UiN@80K6a/00@0MGEe06MWI`1WIfL0HF5Q0P1X
J6P0101fMWH0N7Qh07QhN01iNGT207inOP0407alO01ZJVX0JVYZ05MGE`80K6a/00@0O7al08^;R`2;
Rh/0Jf][0P1PH600101jNWX0PX:208:2PP1gMgL2079bLP0406MWI`1bLW80LW9b05ADE080C4a<00@0
Hf=S05EEE@1EEED0E5AD0P1IFET0101CDe<0CTi>04i>CP10@402030`<00400h>3P030`<00`<300H6
1P805aLG00@0FUYJ07]kN`1kNg/0QhN70P1kNg/0101/K6`0HF5Q065QH@1[Jf/207EeM@0407emO@2A
TI40TI6A07inOP80JFUY00@0NGUi07alO01lO7`0Ogmo0P2>SXh0102CTi<0UIFE09FEU@2>SXh208F5
Q@<0MgMg00@0N7Qh07MgM`1gMgL0Kfm_0P1/K6`306QXJ00406e]K@1iNGT0NGUi08f=S@80Ti>C00<0
U9BD096AT@2ATI400`20P8001029RHT0PH610861P@1]KFd204e=C@0404E5A@0j>SX0>SXj02`/;080
=CDe00<0>SXj05EEE@1EEED00`12@T800`2RXZ80^[Zj0;Zj^P030;2`/0040:n_[`2/[:`0[:b/0:ZZ
ZP80[Zj^00@0YZJV0;Rh^02h^;P0^k^k0P2WYjL0102/[:`0[jn_0:n_[`2`/;020;Fe]@040;no_`2d
];@0];Bd0:f][@80[Zj^00@0YZJV0:FUY@2UYJD0[jn_0P2a/K40102TY:@0[Zj^0:j^[P2SXj<20::R
XP04096AT@15ADD0ADE5020P80806QXJ00@030`<00D51@051@D02`/;0P051@D010061PH02@T900T9
2@051@D200820P0400L71`092@T02@T900D51@<010@40P020P8010071`L020P800P820030`<200L7
1`0300H61P030`<00`<300<00P82000010061PH020P800P820061PH200@410<00P8200@01@D500P8
200820P02@T90P061PH300410@040000000410@010@400<30`800P8200@01PH600D51@051@D00P82
0P0820P00`092@T00P8200820P0300<30`0400820P030`<00`<300D51@<00`<30P0000000`071`L0
2PX:00X:2P0300/;2`03000000010@400@4100<02PX:00@020P800410@010@4020P80P071`L0100>
3Ph071`L01`L700a<C4203/k>`0403Ti>@0V9RH09RHV05=CD`80EUIF00@0G5aL05]KF`1KFe/0MGEe
0P1JFUX0100O7al08B4Q024Q8@0R8R8202DU9@04020P800I6AT06ATI020P80806QXJ00@07alO02DU
9@0U9BD06a/K0P0Q8B40100/;2`0:2PX02PX:00Q8B42020P800403Lg=`0b<S80<S8b02/[:`80BTY:
00@0F5QH04Q8B018B4P09BDU0P0N7Qh01010@400DU9B059BDP1SHf<206i^KP0408:2PP2:RXX0RXZ:
07UiN@80HV9R00@0Hf=S065QH@1QHF40IVIV0P1^KVh0101aLG40O7al07alO00];Bd201<C4`040082
0P0o?cl0?clo05eMG@80E5AD00@0@d=304A4A014A4@0CDe=0P1@D500101IFET0GemO05mOG`1WIfL2
05aLG00405iNGP1RHV80HV9R06a/K080JVYZ00@0Cdm?05IFEP1FEUH0FUYJ0P1=CDd0101NGUh0LG5a
075aL@1iNGT206a/K00407EeM@1WIfL0IfMW065QH@80J6QX00@0MWIf07QhN01hN7P0NGUi0P1nOWh0
101lO7`0JVYZ06YZJP1GEeL206a/K00407alO02;Rh/0Rh^;06][J`80H61P00@0NWYj08:2PP22PX80
MgMg0P1bLW80101WIfL0LW9b079bLP1DE5@204a<C00406=SH`1EEED0EEEE05ADE080FEUI00@0De=C
04i>CP1>CTh0@4100P0`<300100>3Ph00`<300<30`061PH201LG5`0405YJFP1kNg/0Ng]k08N7Q`80
Ng]k00@0K6a/065QH@1QHF40Jf][0P1eMGD0101mOGd0TI6A096AT@1nOWh206UYJ@0407UiN@1lO7`0
O7al07moO`80SXj>00@0Ti>C09FEU@2EUID0SXj>0P25QHD307MgM`0407QhN01gMgL0MgMg06m_K`80
K6a/0`1XJ6P0101]KFd0NGUi07UiN@2=SHd209>CT`0309BDU02ATI40TI6A00<0P82000@0RHV90861
P@21PH40KFe]0P1=CDd01015ADD0>SXj03Xj>P0/;2`203De=@0303Xj>P1EEED0EEEE00<0@T9200<0
XZ:R0;Zj^P2j^[X00`2`/;00102_[jl0[:b/0:b/[02ZZZX20:j^[P040:JVYP2h^;P0^;Rh0;^k^`80
YjNW00@0[:b/0:n_[`2_[jl0/;2`0P2e]KD0102o_kl0];Bd0;Bd]02][Jd20:j^[P040:JVYP2UYJD0
YJFU0:n_[`80/K6a00@0Y:BT0:j^[P2^[Zh0Xj>S0P2RXZ80102ATI40ADE504E5A@0P820201XJ6P04
00`<30051@D01@D500/;2`801@D500@01PH600T92@092@T01@D50P020P8010071`L02@T900T92@05
1@D300@410800P8200@01`L700P8200820P00`<30P071`L00`061PH00`<300<30`0300820P0000<0
1`L700D51@051@D00`0410@010030`<010@400@410010@4200<30`0400L71`092@T02@T900X:2P<0
1PH60P071`L010020P800`<300<30`0410@200820P0400@410061PH01PH600@410800P8200@00`<3
00D51@051@D01PH60P0820P0100410@00P8200820P051@D200@4100400<30`0410@010@400P82080
1`L700@00@4100T92@092@T01`L70P0410@010030`<010@400@4100820P201<C4`0401TI6@0M7Ad0
7AdM01PH6080=SHf00@0ADE502XZ:P0Z:RX0A4A40`1ADE4205aLG00407AdM020P800P82004Q8B080
8R8R00@09BDU02<S8`0S8b<0410@0P0K6a/0100W9bL0820P020P800T92@202/[:`0402PX:00[:b/0
:b/[034a<@809bLW00@03Ph>00/;2`0;2`/04Q8B0P0U9BD01010@400EUIF05IFEP1NGUh205EEE@04
03De=@0S8b<08b<S03Ph>080BDU900@0IfMW07moO`1oOgl0QXJ60P27QhL0101hN7P0J6QX06QXJ01_
Kfl206QXJ00406YZJP1]KFd0KFe]07inOP80Ph>300@0:b/[01DE5@0E5AD030`<0P0b<S801012@T80
C4a<04a<C019BDT204];B`04059BDP1KFe/0Fe]K06UYJ@80JVYZ00@0L71`069RHP1RHV80GUiN0P1^
KVh0101gMgL0LG5a075aL@1JFUX205=CD`0404a<C01ADE40DE5A06i^KP80LG5a00@0NGUi07YjNP1j
NWX0JFUY0P1DE5@0101UIFD0KFe]06e]K@1VIVH2069RHP0406MWI`1mOGd0OGem07]kN`80NGUi00@0
J6QX06EUI@1UIFD0JVYZ0P27QhL0101YJFT0Kfm_06m_K`20P802065QH@0406ATI01eMGD0MGEe07Ui
N@80K6a/00@0BTY:05EEE@1EEED0IFEU0P1CDe<0101GEeL0G5aL05aLG019BDT204=3@`0404Q8B00b
<S80<S8b00d=3@8020P800@02@T901`L700L71`0GUiN0P24Q8@0102:RXX0Ogmo07moO`1hN7P20820
P00407emO@20P800P82008R8R080QHF500@0LG5a06QXJ01XJ6P0Ng]k0P1[Jf/0101bLW80SHf=08f=
S@2EUID209:BTP0408B4Q01iNGT0NGUi07QhN080OWin0`1eMGD0101gMgL0K6a/06a/K01XJ6P207If
MP0408>3P`2<S8`0S8b<09>CT`80V9RH00@0VYZJ08b<S02<S8`0N7Qh0P1gMgL0101mOGd0QHF508F5
Q@1^KVh204A4A00403lo?`0h>3P0>3Ph030`<080<S8b00@0?Cdm05ADE01DE5@0>SXj0P1KFe/0102a
/K40][Jf0;Jf]P2YZJT20:ZZZP040:RXZ02ZZZX0ZZZZ0:j^[P80[:b/00@0[Jf]0;>c/`2c/k<0/k>c
0P2YZJT0102_[jl0/[:b0;:b/P2XZ:P20;2`/0030;^k^`2e]KD0]KFe00<0/k>c00@0YjNW0:ZZZP2Z
ZZX0Zj^[0`2VYZH20:j^[P0409jNWP2DU9@0U9BD08F5Q@80E5AD00@0:2PX01@D500D51@020P80P06
1PH0100;2`/01PH600H61P092@T200/;2`0400H61P051@D01@D500@410802@T900@01@D500000000
00000P820P0410@010071`L010@400@41000000200<30`0400T92@030`<00`<3000000801PH60000
100:2PX01`L700L71`0410@200410@0400@410071`L01`L700820P801`L700@010@400D51@051@D0
1`L70P0410@00`0;2`/01`L700L71`0300<30`0400D51@092@T02@T900D51@800`<300<00P8200<3
0`030`<00`0820P010092@T01`L700L71`051@D300L71`8020P800@01PH600<30`030`<010@40P05
1@D010071`L02@T900T92@0:2PX200D51@0400T92@0=3@d03@d=00D51@802`/;00@04a<C02LW9`0W
9bL06a/K0P0N7Qh01013@d<0C4a<04a<C01CDe<2065QH@04061PH01NGUh0GUiN06YZJP80Rh^;00@0
HF5Q02d];@0];Bd09bLW0P0X:2P0100I6AT071`L01`L700O7al2020P800402LW9`0L71`071`L01hN
7P<0:b/[0P0P8200100D51@061PH01PH600C4a<202<S8`0404M7A`1@D500D51@055AD@80EUIF00@0
BTY:03Xj>P0j>SX0=CDe0P0o?cl0101LG5`0NGUi07UiN@2:RXX208J6QP0407AdM01XJ6P0J6QX06UY
J@80J6QX00@0Hf=S061PH01PH600Ng]k0P1iNGT0100V9RH020P800P8200820P201`L700402h^;P1@
D500D51@051@D080BDU900@0C4a<05ADE01DE5@0KFe]0P1`L700101[Jf/0IFEU06EUI@1MGEd206QX
J00306e]K@1OGel0GemO00<0G5aL00@0DE5A05YJFP1JFUX0H61P0P1HF5P0101WIfL0L71`071`L01S
Hf<2065QH@04075aL@1^KVh0KVi^06UYJ@80FUYJ00@0Jf][08F5Q@25QHD0O7al0P22PX80101WIfL0
JFUY06UYJ@1_Kfl208B4Q00406][J`1YJFT0JFUY0861P@<0Jf][0P1bLW80101lO7`0IfMW06MWI`1H
F5P2065QH@0405ADE01BDU80DU9B05eMG@80C4a<00@0@D5106YZJP1ZJVX0Jf][0P0R8R8010061PH0
1`L700L71`0820P2020P800406][J`2@T900T92@08V9R@80OGem00@0OWin08n?S`2?Shl0R8R80P2;
Rh/0102GUiL0MGEe07EeM@1XJ6P2071`L00407UiN@1[Jf/0Jf][07]kN`80R8R800@0Q8B408N7Q`27
QhL0Q8B40P1mOGd3079bLP0406m_K`1fMWH0MWIf07QhN080LG5a00@0MgMg08B4Q024Q8@0Rh^;0`27
QhL209FEU@03096AT@1jNWX0NWYj00<0Jf][00@0MWIf08V9R@29RHT0Kfm_0P17AdL0100k>c/0;Bd]
02d];@0b<S8203De=@040451@@1CDe<0De=C0410@080Ng]k00@0];Bd0:^[Z`2[Zj/0ZJVY0P2ZZZX0
102QXJ40YZJV0:JVYP2UYJD20:6QX@<0YZJV00@0WIfM09bLW02LW9`0ZZZZ0P2YZJT0102LW9`0Z:RX
0:RXZ02^[Zh20:RXZ0<0/k>c0`2b/[830::RXP040:NWY`2a/K40/K6a09JFUP80MWIf00@0Kfm_05]K
F`1KFe/09RHV0P0>3Ph0100?3`l02@T900T92@0<30`300H61P8020P800@02@T900H61P061PH00P82
0`092@T200H61P<010@400<020P800T92@092@T00`0820P300L71`401PH60@0;2`/100/;2`0000@0
2PX:00L71`071`L010@40P010@40100410@01`L700L71`020P8200L71`0400@410051@D01@D500L7
1`8010@400<02`/;00L71`071`L00`030`<010051@D02@T900T92@051@D200<30`0300820P030`<0
0`<300<020P800@02@T900L71`071`L01@D50`071`L200P8200400H61P030`<00`<300@410801@D5
00@01`L700T92@092@T02PX:0P051@D010092@T03@d=00d=3@051@D200/;2`0401<C4`0W9bL09bLW
01/K6`807QhN00@0@d=304a<C01<C4`0De=C0P1QHF40101PH600GUiN05iNGP1ZJVX208^;R`04065Q
H@0];Bd0;Bd]02LW9`80:2PX00@06ATI01`L700L71`07alO0P0P8200100W9bL071`L01`L700N7Qh3
02/[:`80820P00@051@D01PH600H61P04a<C0P0S8b<01017AdL0D51@051@D01ADE4205IFEP0404Y:
BP0j>SX0>SXj03De=@80?clo00@0G5aL07UiN@1iNGT0RXZ:0P26QXH0101dM7@0J6QX06QXJ01YJFT2
06QXJ00406=SH`1PH600H61P07]kN`80NGUi00@09RHV00P8200820P020P80P0L71`0100^;Rh0D51@
051@D01@D50204U9B@0404a<C01DE5@0E5AD06e]K@80L71`00@0Jf][06EUI@1UIFD0GEeM0P1XJ6P0
0`1]KFd0GemO05mOG`0305aLG004055AD@1JFUX0FUYJ061PH080F5QH00@0IfMW071`L01`L700Hf=S
0P1QHF40101aLG40KVi^06i^KP1YJFT205YJFP0406][J`25QHD0QHF507alO080PX:200@0IfMW06UY
J@1YJFT0Kfm_0P24Q8@0101[Jf/0JFUY06UYJ@21PH4306][J`80LW9b00@0O7al06MWI`1WIfL0F5QH
0P1QHF40101DE5@0DU9B059BDP1MGEd204a<C0040451@@1ZJVX0JVYZ06][J`808R8R00@01PH600L7
1`071`L020P80P0P8200101[Jf/0T92@092@T029RHT207emO@0407inOP2?Shl0Shn?08R8R080Rh^;
00@0UiNG07EeM@1eMGD0J6QX0P1`L700101iNGT0Jf][06][J`1kNg/208R8R00408B4Q027QhL0QhN7
08B4Q080OGem0`1bLW80101_Kfl0MWIf07IfMP1hN7P2075aL@0407MgM`24Q8@0Q8B408^;R`<0QhN7
0P2EUID00`2ATI40NWYj07YjNP0306][J`0407IfMP29RHT0RHV906m_K`80AdM700@0>c/k02d];@0]
;Bd0<S8b0P0e=CD01011@D40De=C05=CD`10@40207]kN`040;Bd]02[Zj/0Zj^[0:VYZ@80ZZZZ00@0
XJ6Q0:JVYP2VYZH0YJFU0P2QXJ430:JVYP0409fMW@2LW9`0W9bL0:ZZZP80ZJVY00@0W9bL0:RXZ02X
Z:P0[Zj^0P2XZ:P30;>c/`<0/[:b0`2RXZ80102WYjL0/K6a0;6a/@2FUYH207IfMP0406m_K`1KFe/0
Fe]K02HV9P803Ph>00@03`l?00T92@092@T030`<0`061PH200P8200400T92@061PH01PH600820P<0
2@T90P061PH300@4100300P820092@T02@T900<020P80`071`L100H61P402`/;0@0;2`/0000400@4
10061PH01PH600H61P<00P820P071`L010092@T03`l?00l?3`0;2`/200@410<00P820`030`<01005
1@D00P8200820P030`<200/;2`0400X:2P061PH01PH600@410800P8200@010@400L71`071`L01@D5
0P030`<010071`L020P800P8200410@200<30`0400H61P071`L01`L700820P800`<300@020P800@4
100410@01PH60P071`L0100:2PX02`/;00/;2`051@D20000000400/;2`0V9RH09RHV02TY:@809RHV
00@0?Shn06a/K01/K6`0OGem0P1RHV80101QHF40HV9R069RHP1ADE4207QhN00406ATI00a<C40<C4a
02h^;P80=3@d00@092@T01XJ6P0J6QX07alO0P0I6AT00`0N7Qh071`L01`L700301`L70<06ATI00<0
7alO02TY:@0Y:BT00`0i>CT0100o?cl0A4A404A4A01?Cdl205iNGP04059BDP0i>CT0>CTi034a<@80
?Cdm00@0CTi>075aL@1aLG40TI6A0P26QXH0101lO7`0LG5a075aL@1_Kfl207UiN@0406QXJ01JFUX0
FUYJ07EeM@80L71`00@09BDU00D51@051@D01PH60P0?3`l0100X:2P0B4Q804Q8B017AdL204i>CP03
04M7A`14A4@0A4A400<0G5aL00@0E5AD05iNGP1NGUh0FUYJ0P1RHV80101YJFT0DE5A055AD@1MGEd2
06YZJP0405aLG01FEUH0EUIF05MGE`80IFEU00@0FEUI04A4A014A4@0GUiN0P20P800101eMGD0GUiN
05iNGP1cLg<207EeM@0407IfMP1bLW80LW9b069RHP80H61P00@0GemO07AdM01dM7@0JVYZ0`1eMGD2
06i^KP0407]kN`1nOWh0OWin07alO080K6a/00@0IfMW05aLG01LG5`0FEUI0P1DE5@0101CDe<0G5aL
05aLG01@D50204E5A@0405MGE`1^KVh0KVi^05=CD`804a<C00@00P8200T92@092@T03@d=0P0U9BD0
101dM7@0U9BD09BDU024Q8@20820P00408B4Q029RHT0RHV908V9R@80R8R800@0VIVI07inOP1nOWh0
M7Ad0P1oOgl0101/K6`0IVIV06IVIP1oOgl208F5Q@0408:2PP1mOGd0OGem07YjNP80Lg=c00@0K6a/
07UiN@1iNGT0LW9b0P1ZJVX0101`L700MWIf07IfMP1jNWX207moO`0408>3P`24Q8@0Q8B408f=S@80
T92@00@0O7al06QXJ01XJ6P0IfMW0P1/K6`0101oOgl0Rh^;08^;R`1SHf<20410@00403Ti>@0_;bl0
;bl_03hn?P80A4A400@0BDU904];B`1;Bd/0BDU90P2<S8`0102b/[80Z:RX0:RXZ02YZJT20:b/[0<0
Y:BT00@0X:2P09RHV02HV9P0WIfM0P2GUiL01028R8P0TY:B09:BTP2[Zj/20:2PX00409>CT`2YZJT0
ZJVY0;>c/`80WinO00@0YjNW0:n_[`2_[jl0[Zj^0P2[Zj/0102WYjL0YZJV0:JVYP2?Shl208>3P`04
07]kN`1gMgL0MgMg07MgM`80H61P00@0<C4a018B4P0B4Q802`/;0P051@D010061PH01@D500D51@00
000200<30`0400T92@061PH01PH60000008010@400@020P800T92@092@T030`<0P0@4100100;2`/0
20P800P8200820P300D51@802PX:0@0<30`100T92@402@T90000100410@030`<00`<300:2PX200D5
1@0400820P030`<00`<300H61P801@D500@01PH600L71`071`L01PH60P071`L010020P8010@400@4
100820P200T92@0300L71`030`<00`<300<010@400@00P8200410@010@4010@40`051@D200@41004
00820P061PH01PH600H61P80000000@00`<300L71`071`L00`<30P020P8300L71`0400<30`051@D0
1@D500<30`801`L700@03Ph>00<30`030`<01@D50P0I6AT0100S8b<07alO01lO7`0X:2P206i^KP04
09ZJVP1XJ6P0J6QX059BDP80Kfm_00@0EeMG069RHP1RHV80LW9b0P0j>SX01010@400A4A404A4A00N
7Qh201lO7`0402DU9@0H61P061PH01DE5@805QHF00@05ADE00P8200820P03Ph>0P0@4100100?3`l0
?Shn03hn?P1/K6`205EEE@040410@01DE5@0E5AD06e]K@80IfMW00@0Bd];02h^;P0^;Rh092@T0P0g
=cL01013@d<0F5QH05QHF02;Rh/2096AT@<0P82000@0PH6107emO@1mOGd0I6AT0P1OGel0101eMGD0
N7Qh07QhN00/;2`200T92@0400D51@0K6a/06a/K03Xj>P80ADE500@0?clo0410@010@400?3`l0P1@
D500101OGel0G5aL05aLG01KFe/205eMG@0405QHF01QHF40HF5Q05iNGP80FEUI00@0IfMW05eMG@1M
GEd0DU9B0P1EEED0101JFUX0HF5Q065QH@1=CDd205MGE`0407alO025QHD0QHF5071`L080EEEE00@0
Kfm_07=cL`1cLg<0I6AT0P1WIfL0101YJFT0I6AT06ATI01YJFT2075aL@0406QXJ01_Kfl0Kfm_06e]
K@80LG5a00@0P82007YjNP1jNWX0Kfm_0P1`L700101mOGd0J6QX06QXJ01?Cdl205ADE004069RHP1U
IFD0IFEU051@D080C4a<00@0FEUI051@D01@D500?3`l0P0E5AD0100000004a<C01<C4`0F5QH203@d
=00407YjNP2?Shl0Shn?08:2PP80RHV900@0Ph>307inOP1nOWh0OWin0P1kNg/0102?Shl0Q8B408B4
Q01oOgl207alO004061PH01^KVh0KVi^08B4Q080RXZ:00@0R8R807moO`1oOgl0MWIf0P1VIVH0101T
I6@0N7Qh07QhN01cLg<206YZJP04079bLP1jNWX0NWYj07inOP80Ogmo00@0OWin08N7Q`27QhL0UIFE
0P2:RXX0101hN7P0M7Ad07AdM01^KVh206ATI00407emO@28R8P0R8R805IFEP80=SHf00@0;bl_03@d
=00d=3@0@4100P14A4@0101>CTh0AdM704M7A`1?Cdl2092@T0040;:b/P2YZJT0ZJVY09RHV080W9bL
00@0WYjN0:2PX02PX:00Y:BT0`2LW9`209>CT`0408Z:RP2BTY80TY:B0:n_[`80ZZZZ00@0WinO0;Bd
]02d];@0/[:b0`2>SXh20:ZZZP040:f][@2VYZH0YZJV0:VYZ@80W9bL00@0Ogmo0861P@21PH40UiNG
0P2TY:@0102>SXh0DU9B059BDP0U9BD200h>3P0400820P051@D01@D500D51@8010@40`030`<01009
2@T01`L700L71`030`<300@410800@4100@020P800d=3@0=3@d01@D50P0410@010051@D00P820082
0P071`L200X:2P402@T90@071`L100L71`0000@010@400`<300<30`02PX:0P051@D010020P800`<3
00<30`061PH200D51@0400H61P071`L01`L700H61P801`L700@00P8200@4100410@020P80P092@T0
0`071`L00`<300<30`0300@4100400820P010@400@4100@410<01@D50P0410@010020P801PH600H6
1P061PH20000000400<30`071`L01`L700<30`800P820`071`L010030`<01@D500D51@030`<200L7
1`0400h>3P030`<00`<300D51@806ATI00@08b<S01lO7`0O7al0:2PX0P1^KVh0102JVYX0J6QX06QX
J01BDU8206m_K`0405MGE`1RHV80HV9R079bLP80>SXj00@0@41004A4A014A4@07QhN0P0O7al0100U
9BD061PH01PH600E5AD201HF5P0401DE5@0820P020P800h>3P80410@00@03`l?03hn?P0n?Sh0K6a/
0P1EEED01010@400E5AD05ADE01]KFd206MWI`0404];B`0^;Rh0;Rh^02@T9080=cLg00@0@d=305QH
F01HF5P0Rh^;0P2ATI430820P0040861P@1mOGd0OGem06ATI080GemO00@0MGEe07QhN01hN7P0;2`/
0P092@T010051@D06a/K01/K6`0j>SX204E5A@0403lo?`10@400@41003`l?080D51@00@0GemO05aL
G01LG5`0Fe]K0P1MGEd0101HF5P0HF5Q065QH@1NGUh205UIF@0406MWI`1MGEd0GEeM059BDP80EEEE
00@0FUYJ065QH@1QHF40CDe=0P1GEeL0101lO7`0QHF508F5Q@1`L70205EEE@0406m_K`1cLg<0Lg=c
06ATI080IfMW00@0JFUY06ATI01TI6@0JFUY0P1aLG40101XJ6P0Kfm_06m_K`1]KFd2075aL@040820
P01jNWX0NWYj06m_K`80L71`00@0OGem06QXJ01XJ6P0Cdm?0P1DE5@0101RHV80IFEU06EUI@1@D502
04a<C00405UIF@1@D500D51@03`l?0805ADE00@0000001<C4`0C4a<05QHF0P0d=3@0101jNWX0Shn?
08n?S`22PX8208V9R@0408>3P`1nOWh0OWin07inOP80Ng]k00@0Shn?08B4Q024Q8@0Ogmo0P1lO7`0
101PH600KVi^06i^KP24Q8@208Z:RP0408R8R01oOgl0Ogmo07IfMP80IVIV00@0I6AT07QhN01hN7P0
Lg=c0P1ZJVX0101bLW80NWYj07YjNP1nOWh207moO`0407inOP27QhL0QhN709FEU@80RXZ:00@0N7Qh
07AdM01dM7@0KVi^0P1TI6@0101mOGd0R8R808R8R01FEUH203Hf=P0402l_;`0d=3@0=3@d0410@080
A4A400@0CTi>04M7A`17AdL0Cdm?0P2@T900102b/[80ZJVY0:VYZ@2HV9P209bLW00409jNWP2PX:00
X:2P0:BTY0<0W9bL0P2CTi<0102:RXX0TY:B09:BTP2_[jl20:ZZZP0409nOW`2d];@0];Bd0;:b/P<0
SXj>0P2ZZZX0102][Jd0YZJV0:JVYP2YZJT209bLW00407moO`21PH40PH6109NGU`80Y:BT00@0SXj>
059BDP1BDU809BDU0P0>3Ph010020P801@D500D51@051@D200@410<00`<300@02@T900L71`071`L0
0`<30`0410@200410@0400P8200=3@d03@d=00D51@8010@400@01@D500820P020P801`L70P0:2PX1
00T92@401`L70@071`L0000400P8200:2PX02PX:00P820800`<300@00@4100820P020P800`<30P01
0@4300@4100400H61P071`L01`L700L71`801@D500@010@400D51@051@D00P820P00000300D51@04
000000051@D01@D500P820<010@40P030`<010061PH020P800P820030`<200@4100400L71`051@D0
1@D500L71`8020P800@01`L700H61P061PH000000P020P8010030`<010@400@4100:2PX200D51@04
00<30`0I6AT06ATI02@T90805ADE00@09BDU069RHP1RHV80UIFE0P20P800101QHF40N7Qh07QhN01_
Kfl204E5A@03071`L010@400@41000<0?Shn00<05QHF01lO7`0O7al00`0O7al0100M7Ad03@d=00d=
3@0:2PX200@4100400T92@0@4100410@00`<3080B4Q800@0Rh^;06QXJ01XJ6P0BTY:0P1SHf<0101b
LW80IFEU06EUI@1<C4`203Hf=P0402`/;00e=CD0=CDe03Ph>080>SXj00@0LG5a09JFUP2FUYH0P820
0P1nOWh0101dM7@0JFUY06UYJ@1OGel2061PH00406i^KP1fMWH0MWIf02l_;`801@D500@00`<301`L
700L71`0AdM70P1ADE401019BDT0?Shn03hn?P12@T8205YJFP0405mOG`1WIfL0IfMW06i^KP80I6AT
00@0G5aL065QH@1QHF40GEeM0P1ZJVX0101UIFD0A4A404A4A01<C4`206ATI00406YZJP1QHF40HF5Q
05YJFP80LW9b00@0MgMg075aL@1aLG40KVi^0`1LG5`206=SH`0406ATI01dM7@0M7Ad06i^KP80IfMW
00<0KVi^07AdM01dM7@00`1OGel0101^KVh0K6a/06a/K01eMGD206IVIP0405aLG01dM7@0M7Ad07mo
O`80F5QH00@0CTi>06=SH`1SHf<0EUIF0P1GEeL0101LG5`0CDe=04e=C@15ADD204Q8B00404M7A`0L
71`071`L00D51@804a<C00@051@D0451@@11@D40QHF50P2@T9001028R8P0QXJ608J6QP1hN7P30820
P080PX:200@0RHV907moO`1oOgl0MgMg0P1YJFT0101GEeL0HF5Q065QH@1hN7P207UiN@0406i^KP1Z
JVX0JVYZ06IVIP80HV9R00@0JFUY075aL@1aLG40M7Ad0P1bLW80101eMGD0Ogmo07moO`23Ph<208:2
PP0408N7Q`2@T900T92@08b<S080PX:200@0Rh^;08V9R@29RHT0Kfm_0P1VIVH01027QhL0OWin07in
OP18B4P203Lg=`0402`/;00h>3P0>3Ph03dm?@80=SHf0`1=CDd0101HF5P0SXj>08j>SP2UYJD20:>S
X`0409RHV02IVIT0VIVI09fMW@<0WYjN0P2ATI40102@T900U9BD09BDU02IVIT209nOW`040;>c/`2g
]kL0]kNg0:f][@80YjNW00@0UiNG09:BTP2BTY80XZ:R0P2b/[80102^[Zh0ZZZZ0:ZZZP2^[Zh209NG
U`0408b<S02WYjL0YjNW0;>c/`80Y:BT00@0Rh^;05=CD`1CDe<06QXJ0P0820P010020P802`/;00/;
2`0<30`200H61P0400`<300820P020P800T92@802`/;00@02@T900L71`071`L010@40P0000001001
0@4010@400@410051@D200L71`<00@4100@02@T900H61P061PH01@D50P092@T000<01@D500<010@4
00L71`071`L00`010@40100410@01@D500D51@051@D200<30`0300@410030`<00`<300<010@400@0
0`<300D51@051@D01@D50P071`L0100:2PX01`L700L71`020P8200H61P0400@410020P800P8200<3
0`801@D500@030`<00T92@092@T010@40P0820P010071`L00`<300<30`0820P200X:2P0400H61P05
1@D01@D5000000800@410`0410@010030`<01@D500D51@071`L2018B4P0402HV9P0O7al07alO02<S
8`80Bd];00@0P82008F5Q@25QHD0Lg=c0`1eMGD204];B`04079bLP1BDU80DU9B02`/;080=SHf00@0
8b<S01dM7@0M7Ad08B4Q0P0V9RH0100O7al03@d=00d=3@0A4A4201@D5004010@400D51@051@D00H6
1P80<C4a00@0Ng]k06QXJ01XJ6P0D51@0P1TI6@0101bLW80M7Ad07AdM018B4P202LW9`0403hn?P10
@400@41003<c<`80@41000@0L71`092@T02@T900OWin0P1hN7P0101/K6`0KVi^06i^KP1_Kfl206EU
I@04079bLP20P800P82003Xj>P80000000@00@4101DE5@0E5AD0BTY:0P1BDU801012@T80BDU904U9
B@1NGUh205aLG00405]KF`1NGUh0GUiN05EEE@80De=C00@0FUYJ06m_K`1_Kfl0Lg=c0P1YJFT0101E
EED0Bd];04];B`1PH60206e]K@0406i^KP1`L700L71`065QH@80Fe]K00@0I6AT075aL@1aLG40L71`
0P1MGEd0101GEeL0GUiN05iNGP1TI6@206m_K`04065QH@1NGUh0GUiN06ATI080Ph>300@0I6AT05IF
EP1FEUH0M7Ad0P1OGel0101HF5P0Hf=S06=SH`1hN7P2071`L00405MGE`1BDU80DU9B069RHP80IFEU
00@0E5AD05EEE@1EEED0EEEE0`14A4@205QHF00404E5A@0=3@d03@d=00/;2`803Ph>00@04A4A04Q8
B018B4P0Rh^;0P2>SXh0102:RXX0P8200820P01_Kfl207alO004079bLP1kNg/0Ng]k0820P080MWIf
00@0LW9b07=cL`1cLg<0K6a/0P1LG5`0101SHf<0GemO05mOG`1OGel206QXJ00406EUI@1ZJVX0JVYZ
06m_K`80Jf][00@0Kfm_071`L01`L700LG5a0P1kNg/01020P800QHF508F5Q@2<S8`209>CT`0408Z:
RP26QXH0QXJ609FEU@80SHf=0`1`L700102ATI40OWin07inOP1=CDd204A4A00403Ph>00j>SX0>SXj
03hn?P80>3Ph0`18B4P0101NGUh0TI6A096AT@2KVi/309FEU@80VYZJ00@0Xj>S0:6QX@2QXJ40Shn?
0P1oOgl01029RHT0X:2P0:2PX02_[jl20;Jf]P040;Zj^P2g]kL0]kNg0:FUY@80U9BD00@0UIFE0:VY
Z@2YZJT0]KFe0P2j^[X0102d];@0[:b/0:b/[02[Zj/209RHV00409:BTP2][Jd0[Jf]0;^k^`80Z:RX
00@0SHf=06YZJP1ZJVX0:b/[0P092@T300@4100400P820061PH01PH600H61P801@D500<02@T900X:
2P0:2PX0100820P200@4100400820P071`L01`L700d=3@8030`<00@00P8200T92@092@T03@d=0P07
1`L100410@401PH60@061PH000<01@D500<010@400L71`071`L00`010@40100410@01@D500D51@05
1@D200<30`0300@410030`<00`<300<010@400@00`<300D51@051@D01@D50P071`L0100:2PX01`L7
00L71`020P8200H61P0400@410020P800P8200<30`801@D500@030`<00T92@092@T010@40P0820P0
10071`L00`<300<30`0820P200X:2P0400H61P051@D01@D5000000800@410`0410@010030`<01@D5
00D51@071`L2018B4P0402HV9P0O7al07alO02<S8`80Bd];00@0P82008F5Q@25QHD0Lg=c0`1eMGD2
04];B`04079bLP1BDU80DU9B02`/;080=SHf00@08b<S01dM7@0M7Ad08B4Q0P0V9RH0100O7al03@d=
00d=3@0A4A4201@D5004010@400D51@051@D00H61P80<C4a00@0Ng]k06QXJ01XJ6P0D51@0P1TI6@0
101bLW80M7Ad07AdM018B4P202LW9`0403hn?P10@400@41003<c<`80@41000@0L71`092@T02@T900
OWin0P1hN7P0101/K6`0KVi^06i^KP1_Kfl206EUI@04079bLP20P800P82003Xj>P80000000@00@41
01DE5@0E5AD0BTY:0P1BDU801012@T80BDU904U9B@1NGUh205aLG00405]KF`1NGUh0GUiN05EEE@80
De=C00@0FUYJ06m_K`1_Kfl0Lg=c0P1YJFT0101EEED0Bd];04];B`1PH60206e]K@0406i^KP1`L700
L71`065QH@80Fe]K00@0I6AT075aL@1aLG40L71`0P1MGEd0101GEeL0GUiN05iNGP1TI6@206m_K`04
065QH@1NGUh0GUiN06ATI080Ph>300@0I6AT05IFEP1FEUH0M7Ad0P1OGel0101HF5P0Hf=S06=SH`1h
N7P2071`L00405MGE`1BDU80DU9B069RHP80IFEU00@0E5AD05EEE@1EEED0EEEE0`14A4@205QHF004
04E5A@0=3@d03@d=00/;2`803Ph>00@04A4A04Q8B018B4P0Rh^;0P2>SXh0102:RXX0P8200820P01_
Kfl207alO004079bLP1kNg/0Ng]k0820P080MWIf00@0LW9b07=cL`1cLg<0K6a/0P1LG5`0101SHf<0
GemO05mOG`1OGel206QXJ00406EUI@1ZJVX0JVYZ06m_K`80Jf][00@0Kfm_071`L01`L700LG5a0P1k
Ng/01020P800QHF508F5Q@2<S8`209>CT`0408Z:RP26QXH0QXJ609FEU@80SHf=0`1`L700102ATI40
OWin07inOP1=CDd204A4A00403Ph>00j>SX0>SXj03hn?P80>3Ph0`18B4P0101NGUh0TI6A096AT@2K
Vi/309FEU@80VYZJ00@0Xj>S0:6QX@2QXJ40Shn?0P1oOgl01029RHT0X:2P0:2PX02_[jl20;Jf]P04
0;Zj^P2g]kL0]kNg0:FUY@80U9BD00@0UIFE0:VYZ@2YZJT0]KFe0P2j^[X0102d];@0[:b/0:b/[02[
Zj/209RHV00409:BTP2][Jd0[Jf]0;^k^`80Z:RX00@0SHf=06YZJP1ZJVX0:b/[0P092@T300@41004
00P820061PH01PH600H61P801@D500<02@T900X:2P0:2PX0100820P200@4100400820P071`L01`L7
00d=3@8030`<00@00P8200T92@092@T03@d=0P071`L100410@401PH60@061PH000<00`<300@010@4
00L71`071`L01PH60P020P8010061PH00P8200820P00000200<30`0400820P0410@010@400820P80
10@400<02@T900H61P061PH00`061PH010071`L010@400@410061PH200P820<00P8200@00`<300H6
1P061PH020P80P051@D0100410@00`<300<30`051@D200@4100300<30`051@D01@D500<020P800@0
10@400820P020P800P820P061PH010051@D020P800P820061PH200T92@0402@T900S8b<08b<S01`L
7080>3Ph00@0KFe]08J6QP26QXH0NGUi0P1bLW801020P800Jf][06][J`1fMWH206QXJ00402h^;P0f
=SH0=SHf03De=@804a<C00@071`L01lO7`0O7al07QhN0P0A4A40100C4a<05aLG01LG5`0D51@2014A
4@0400410@0S8b<08b<S06MWI`80J6QX00@0DU9B05YJFP1JFUX0KVi^0P1`L7001011@D408B4Q024Q
8@0l?3`20492@P0403De=@19BDT0BDU9071`L080QHF500@0NGUi07AdM01dM7@0MgMg0P1iNGT0101k
Ng/0K6a/06a/K01bLW8208N7Q`040451@@020P800P8200X:2P805ADE00@0@41004Q8B018B4P0?clo
0P10@400101IFET0F5QH05QHF01GEeL205]KF`0405=CD`1<C4`0C4a<05ADE080LW9b00<0MgMg061P
H01PH600101HF5P205=CD`0405iNGP1/K6`0K6a/05MGE`80FUYJ00@0LW9b06UYJ@1YJFT0De=C0P1>
CTh0101MGEd0JVYZ06YZJP1UIFD206][J`04069RHP1WIfL0IfMW061PH080PH6100@0K6a/05=CD`1C
De<0HV9R0P1XJ6P0101YJFT0MGEe07EeM@1jNWX205UIF@04061PH022PX80PX:206e]K@80@T9200@0
CDe=065QH@1QHF40F5QH0P1=CDd0101;Bd/0DU9B059BDP0g=cL200@4100400H61P0=3@d03@d=01DE
5@80DE5A00@0S8b<08J6QP26QXH0Q8B40P1nOWh0101`L700N7Qh07QhN01^KVh206e]K@0407EeM@1g
MgL0MgMg07MgM`80MGEe00<0Ng]k07IfMP1fMWH00`1fMWH0101kNg/0NWYj07YjNP1]KFd206i^KP03
071`L01]KFd0KFe]00<0KVi^00@0JVYZ06][J`1[Jf/0N7Qh0P23Ph<01029RHT0Rh^;08^;R`2:RXX2
08R8R00408Z:RP20P800P820075aL@80OWin00@0Shn?07UiN@1iNGT0E5AD0P14A4@0100j>SX0<c<c
03<c<`0g=cL204A4A00404i>CP13@d<0@d=306=SH`80U9BD00@0Ti>C092@T02@T900T92@0P2GUiL0
102QXJ40WYjN09jNWP24Q8@208J6QP040:RXZ02h^;P0^;Rh0;Jf]P80/k>c00@0_;bl0:f][@2][Jd0
S8b<0P2BTY80102[Zj/0];Bd0;Bd]02_[jl20:b/[0040:ZZZP2TY:@0Y:BT09ZJVP80SXj>00@0Ti>C
0:FUY@2UYJD0]kNg0P2`/;00102FUYH0MWIf07IfMP0e=CD200d=3@04010@40061PH01PH600410@<0
0`<30P0410@300/;2`0300@410061PH01PH600<01PH60`020P8010051@D020P800P820051@D200/;
2`0400`<30061PH01PH600820P800`<3000010030`<01@D500D51@010@4200820P0400D51@020P80
0P8200<30`801PH600@00`<300H61P061PH01PH60`030`<200H61P0400/;2`0410@010@400410@80
0P8200@01@D500820P020P8010@41@051@D400410@801`L700@02PX:00L71`071`L01@D50P061PH0
10020P8010@400@410071`L500D51@0300P8200:2PX02PX:00<01PH600@020P800l?3`0?3`l0820P
0P0Q8B40100N7Qh0<S8b038b<P1NGUh208:2PP0307inOP1YJFT0JFUY00<0P82000@0LG5a07inOP1n
OWh0=cLg0P0R8R801016ATH0410@010@400820P2010@400402XZ:P0N7Qh07QhN010@40806ATI00@0
6QXJ00P8200820P02PX:0P0^;Rh0101PH600GEeM05eMG@1?Cdl205UIF@0406EUI@1FEUH0EUIF04Y:
BP80?clo0`0b<S80100g=cL0D51@051@D01bLW8307emO@80Ogmo00@0P82007UiN@1iNGT0P8200P1Z
JVX0101/K6`0QhN708N7Q`10@4020000000400`<300@4100410@02XZ:P80>c/k00@0@d=303lo?`0o
?cl0DU9B0P1FEUH00`19BDT0DU9B059BDP0305aLG00405IFEP1KFe/0Fe]K06ATI080LG5a00@0Lg=c
05QHF01HF5P0DU9B0P1MGEd0101HF5P0BDU904U9B@18B4P2065QH@0406a/K01WIfL0IfMW061PH080
IVIV00@0H61P06UYJ@1YJFT0I6AT0P1SHf<0101IFET0HF5Q065QH@1LG5`207alO00405mOG`1;Bd/0
Bd];05mOG`80OGem00@0OWin07QhN01hN7P0LG5a0P1OGel306][J`04051@D019BDT0BDU905QHF080
D51@00@0AdM7061PH01PH600JFUY0P1CDe<0100W9bL000000000000>3Ph200/;2`04018B4P1EEED0
EEEE08B4Q080QhN700@0QXJ607IfMP1fMWH0N7Qh0P1mOGd01027QhL0P8200820P01`L70207inOP04
07IfMP1SHf<0Hf=S079bLP80QHF500@0Ti>C09FEU@2EUID0Ph>30P1dM7@0101/K6`0LG5a075aL@1d
M7@206i^KP0406YZJP1^KVh0KVi^06][J`80IVIV00@0MGEe08J6QP26QXH0S8b<0P27QhL01026QXH0
RXZ:08Z:RP22PX8207IfMP0407=cL`23Ph<0Ph>308V9R@80KFe]00@0D51@0410@010@400<c<c0P0b
<S80100k>c/0BDU904U9B@1@D50204a<C00406m_K`2ATI40TI6A096AT@80UiNG00@0TY:B09BDU02D
U9@0UiNG0P2BTY80102:RXX0YJFU0:FUY@2j^[X20;>c/`040:n_[`2/[:`0[:b/0;no_`80/K6a00@0
T92@0:>SX`2SXj<0/K6a0P2b/[80102h^;P0Xj>S0:>SX`2DU9@209fMW@0409:BTP1oOgl0Ogmo096A
T@80/K6a00@0_[jn0;:b/P2b/[80WIfM0P20P8001014A4@06QXJ01XJ6P0A4A4200`<300400P82000
0000000000L71`802@T900@01`L7010@400@41001@D50P061PH010051@D00P8200820P061PH200<3
0`040000000410@010@400410@802PX:00@010@400<30`030`<010@40P030`<0000400<30`051@D0
1@D500410@800P8200@01@D500820P020P800`<30P061PH010030`<01PH600H61P061PH300<30`80
1PH600@02`/;00@4100410@00@410P020P8010051@D00P8200820P0410@500D51@@00@410P071`L0
100:2PX01`L700L71`051@D200H61P0400820P0410@010@400L71`D01@D500<020P800X:2P0:2PX0
0`061PH0100820P03`l?00l?3`0P8202024Q8@0401hN7P0b<S80<S8b05iNGP80PX:200<0OWin06UY
J@1YJFT00`20P800101aLG40OWin07inOP0g=cL2028R8P0404I6AP0@4100410@00P82080410@00@0
:RXZ01hN7P0N7Qh0410@0P0I6AT0100J6QX020P800P8200:2PX202h^;P04061PH01MGEd0GEeM04m?
C`80FEUI00@0IFEU05IFEP1FEUH0BTY:0P0o?cl3038b<P0403Lg=`1@D500D51@079bLP<0OGem0P1o
Ogl01020P800NGUi07UiN@20P80206YZJP0406a/K027QhL0QhN70410@080000000@030`<010@400@
4100:RXZ0P0k>c/01013@d<0?clo03lo?`1BDU8205IFEP0304U9B@1BDU80DU9B00<0G5aL00@0EUIF
05]KF`1KFe/0I6AT0P1aLG40101cLg<0F5QH05QHF01BDU8205eMG@0405QHF019BDT0BDU904Q8B080
HF5Q00@0K6a/06MWI`1WIfL0H61P0P1VIVH0101PH600JFUY06UYJ@1TI6@206=SH`0405UIF@1QHF40
HF5Q05aLG080O7al00@0GemO04];B`1;Bd/0GemO0P1mOGd0101nOWh0N7Qh07QhN01aLG4205mOG`<0
Jf][00@0D51@04U9B@19BDT0F5QH0P1@D5001017AdL0H61P061PH01YJFT205=CD`0402LW9`000000
000000h>3P802`/;00@04Q8B05EEE@1EEED0Q8B40P27QhL01026QXH0MWIf07IfMP1hN7P207emO@04
08N7Q`20P800P820071`L080OWin00@0MWIf06=SH`1SHf<0LW9b0P25QHD0102CTi<0UIFE09FEU@23
Ph<207AdM00406a/K01aLG40LG5a07AdM080KVi^00@0JVYZ06i^KP1^KVh0Jf][0P1VIVH0101eMGD0
QXJ608J6QP2<S8`208N7Q`0408J6QP2:RXX0RXZ:08:2PP80MWIf00@0Lg=c08>3P`23Ph<0RHV90P1]
KFd0101@D500@4100410@00c<c<2038b<P0403/k>`19BDT0BDU9051@D080C4a<00@0Kfm_096AT@2A
TI40TI6A0P2GUiL0102BTY80U9BD09BDU02GUiL209:BTP0408Z:RP2UYJD0YJFU0;Zj^P80/k>c00@0
[jn_0:b/[02/[:`0_kno0P2a/K40102@T900Xj>S0:>SX`2a/K420;:b/P040;Rh^02SXj<0Xj>S09BD
U080WIfM00@0TY:B07moO`1oOgl0TI6A0P2a/K40102n_[h0/[:b0;:b/P2MWId20820P00404A4A00J
6QX06QXJ014A4@8030`<00@020P80000000000001`L70P092@T010071`L0410@010@40051@D200H6
1P0400D51@020P800P8200H61P800`<300@0000000@4100410@00@410P0:2PX0100410@00`<300<3
0`0410@200<30`0000@01@D500@4100410@00P820P051@D0100410@00P8200820P0410@200H61P04
00P820071`L01`L700T92@801`L70`030`<0100820P01`L700L71`061PH300P8208010@400@00000
00410@010@400`<30P071`L010030`<00P8200820P020P8200L71`0400D51@092@T02@T900X:2P80
1`L700@010@400820P020P8000000`030`<200@4100300H61P071`L01`L700<01@D500@01`L700`<
300<30`071`L0P0P8200100T92@0=CDe03De=@1>CTh2075aL@0407inOP1TI6@0I6AT06m_K`80Rh^;
00@0MGEe08B4Q024Q8@0@4100P0B4Q80101=CDd04A4A014A4@030`<200L71`0401HF5P0G5aL05aLG
01@D50<08B4Q0P0?3`l0100O7al0:2PX02PX:01@D502061PH00406ATI01/K6`0K6a/05iNGP80@d=3
00@0DU9B05aLG01LG5`0=cLg0P0T92@0100a<C40Cdm?04m?C`1_Kfl207MgM`0407moO`23Ph<0Ph>3
0820P080OGem00@0P820075aL@1aLG40MgMg0P23Ph<0100m?Cd00000000000051@D200P8200403Hf
=P18B4P0B4Q804=3@`80<S8b00@0@d=3055AD@1ADE40FUYJ0P1OGel0101PH600HF5Q065QH@1EEED2
04e=C@0405ADE01hN7P0N7Qh07IfMP80DU9B00@0EeMG06YZJP1ZJVX0Hf=S0P1NGUh0101/K6`0KFe]
06e]K@1MGEd206MWI`04075aL@1fMWH0MWIf06a/K080LG5a00@0JFUY06MWI`1WIfL0F5QH0`1OGel2
07]kN`0406UYJ@1ZJVX0JVYZ07IfMP80Kfm_00@0MGEe06a/K01/K6`0Q8B40P1eMGD0101XJ6P0G5aL
05aLG01JFUX206i^KP0405]KF`0d=3@0=3@d03<c<`80Cdm?00@0HV9R04];B`1;Bd/07AdM0P0410@0
100A4A4020P800P8200D51@206ATI0040861P@24Q8@0Q8B408F5Q@80MGEe00@0O7al07QhN01hN7P0
QHF50P1kNg/0101aLG40OGem07emO@1WIfL206m_K`0408:2PP24Q8@0Q8B409:BTP80RHV900@0KVi^
06QXJ01XJ6P0K6a/0P1^KVh0101/K6`0I6AT06ATI01RHV8206YZJP0406i^KP1UIFD0IFEU06][J`80
PH6100@0Rh^;08B4Q024Q8@0NGUi0P1kNg/0101nOWh0P8200820P023Ph<20861P@0407moO`1]KFd0
KFe]051@D080Bd];00@0=cLg034a<@0a<C40@4100P1:BTX0101;Bd/0De=C05=CD`1iNGT208^;R`04
09>CT`2GUiL0UiNG09RHV080VIVI0`29RHT0102SXj<0^;Rh0;Rh^02ZZZX209nOW`040:NWY`2c/k<0
/k>c0;jn_P80Zj^[00@0UYJF0:ZZZP2ZZZX0/;2`0P2][Jd0102ZZZX0RXZ:08Z:RP29RHT209jNWP04
08b<S01cLg<0Lg=c08:2PP80[jn_00@0_;bl0:JVYP2VYZH0V9RH0P1iNGT01018B4P09BDU02DU9@0<
30`200X:2P0400/;2`061PH01PH600`<30803`l?00@010@400/;2`0;2`/02@T90P0=3@d010092@T0
0`<300<30`061PH200D51@0400410@0410@010@400H61PD010@40@020P8100@4104010@400001001
0@401`L700L71`010@4200P8200400H61P071`L01`L700P820800P8200@0000000D51@051@D020P8
0P0=3@d010010@401PH600H61P0=3@d200L71`0400T92@061PH01PH600L71`801@D500@0000000`<
300<30`03Ph>0P061PH010020P802PX:00X:2P0:2PX200L71`04000000020P800P8200L71`800`<3
00<01`L700D51@051@D00`0410@010030`<010@400@4100410@300P820801PH600@020P800H61P06
1PH051@D0P0X:2P0100c<c<0@T920492@P1@D50207=cL`0408V9R@1hN7P0N7Qh06QXJ080Ng]k00@0
Kfm_07EeM@1eMGD0AdM70P0D51@0100n?Sh02@T900T92@071`L20000000400L71`0B4Q804Q8B028R
8P806QXJ00@0820P02DU9@0U9BD06a/K0P020P80100j>SX0MWIf07IfMP1^KVh3065QH@80EUIF00@0
G5aL06][J`1[Jf/0@d=30P0T92@0100];Bd0A4A404A4A01RHV82075aL@0407YjNP1iNGT0NGUi07Qh
N080P82000@0NWYj07AdM01dM7@0MGEe0P1nOWh00`0o?cl000000000000300L71`0403`l?01CDe<0
De=C04a<C080@d=300@0DU9B05YJFP1JFUX0Hf=S0P1GEeL0101HF5P0GEeM05eMG@1KFe/2061PH004
055AD@1NGUh0GUiN05EEE@80A4A400@0EUIF061PH01PH600GEeM0P1aLG40101lO7`0KVi^06i^KP1`
L70206YZJP0406ATI01bLW80LW9b079bLP80Lg=c00@0Hf=S075aL@1aLG40JVYZ0P1WIfL0101UIFD0
JFUY06UYJ@1YJFT2075aL@0406YZJP1GEeL0EeMG079bLP80GemO00@0MGEe06i^KP1^KVh0Kfm_0P1/
K6`0101DE5@0EEEE05EEE@14A4@203dm?@0303lo?`0Z:RX0:RXZ00<0>3Ph00@04A4A00<30`030`<0
2PX:0P0;2`/0100P8200LG5a075aL@24Q8@207inOP0407QhN01fMWH0MWIf07emO@<0MGEe0P1YJFT0
101dM7@0LG5a075aL@1QHF4208>3P`0408N7Q`1eMGD0MGEe07moO`80N7Qh0`1WIfL0101XJ6P0Jf][
06][J`1SHf<2061PH00406a/K01aLG40LG5a07=cL`80LG5a00@0LW9b07alO01lO7`0MGEe0P1cLg<0
101fMWH0LW9b079bLP22PX8208>3P`0408:2PP1nOWh0OWin07UiN@80J6QX00@0Cdm?04e=C@1=CDd0
>3Ph0P0c<c<01012@T80Bd];04];B`1>CTh205MGE`0407EeM@1kNg/0Ng]k08R8R080UYJF00@0WIfM
08Z:RP2:RXX0O7al0P2?Shl0102ZZZX0[Zj^0:j^[P2ZZZX20:f][@040:6QX@2^[Zh0[Zj^0;Jf]P80
YJFU00@0X:2P0:FUY@2UYJD0WinO0P2EUID0102;Rh/0LW9b079bLP1nOWh20:2PX00409>CT`20P800
P82008Z:RP80ZZZZ00@0[:b/09JFUP2FUYH0U9BD0P1hN7P01014A4@09bLW02LW9`0C4a<200/;2`04
00820P0:2PX02PX:010@40803`l?00@01`L700l?3`0?3`l04A4A0P0@410010061PH02PX:00X:2P0:
2PX200D51@0400T92@010@400@4100P8208010@400@020P800D51@051@D00P820P0410@000040041
0@071`L01`L700410@8020P800@01PH600L71`071`L020P80P020P80100000001@D500D51@0820P2
00d=3@0400410@061PH01PH600d=3@801`L700@02@T900H61P061PH01`L70P051@D01000000030`<
00`<300>3Ph200H61P0400820P0:2PX02PX:00X:2P801`L700@0000000820P020P801`L70P030`<0
0`071`L01@D500D51@0300@4100400<30`0410@010@400@410<020P80P061PH0100820P01PH600H6
1P0D51@202PX:00403<c<`12@T80@T92051@D080Lg=c00@0RHV907QhN01hN7P0J6QX0P1kNg/0101_
Kfl0MGEe07EeM@17AdL201@D500403hn?P092@T02@T900L71`80000000@01`L7018B4P0B4Q808R8R
0P0J6QX0100P82009BDU02DU9@0K6a/200820P0403Xj>P1fMWH0MWIf06i^KP<0HF5Q0P1FEUH0101L
G5`0Jf][06][J`13@d<202@T900402d];@14A4@0A4A4069RHP80LG5a00@0NWYj07UiN@1iNGT0N7Qh
0P20P800101jNWX0M7Ad07AdM01eMGD207inOP0303lo?`000000000000<01`L700@0?3`l05=CD`1C
De<0C4a<0P13@d<0101BDU80FUYJ05YJFP1SHf<205MGE`0405QHF01MGEd0GEeM05]KF`80H61P00@0
DE5A05iNGP1NGUh0EEEE0P14A4@0101FEUH0H61P061PH01MGEd2075aL@0407alO01^KVh0KVi^071`
L080JVYZ00@0I6AT079bLP1bLW80LW9b0P1cLg<0101SHf<0LG5a075aL@1ZJVX206MWI`0406EUI@1Y
JFT0JFUY06UYJ@80LG5a00@0JVYZ05MGE`1GEeL0LW9b0P1OGel0101eMGD0KVi^06i^KP1_Kfl206a/
K00405ADE01EEED0EEEE04A4A080?Cdm00<0?clo02XZ:P0Z:RX00`0h>3P0100A4A400`<300<30`0:
2PX200/;2`04020P801aLG40LG5a08B4Q080OWin00@0N7Qh07IfMP1fMWH0OGem0`1eMGD206UYJ@04
07AdM01aLG40LG5a065QH@80Ph>300@0QhN707EeM@1eMGD0Ogmo0P1hN7P306MWI`0406QXJ01[Jf/0
Jf][06=SH`80H61P00@0K6a/075aL@1aLG40Lg=c0P1aLG40101bLW80O7al07alO01eMGD207=cL`04
07IfMP1bLW80LW9b08:2PP80Ph>300@0PX:207inOP1nOWh0NGUi0P1XJ6P0101?Cdl0CDe=04e=C@0h
>3P203<c<`040492@P1;Bd/0Bd];04i>CP80EeMG00@0MGEe07]kN`1kNg/0R8R80P2FUYH0102MWId0
RXZ:08Z:RP1lO7`208n?S`040:ZZZP2^[Zh0[Zj^0:ZZZP80[Jf]00@0XJ6Q0:j^[P2^[Zh0][Jf0P2U
YJD0102PX:00YJFU0:FUY@2OWil209FEU@0408^;R`1bLW80LW9b07inOP80X:2P00@0Ti>C0820P020
P800RXZ:0P2ZZZX0102/[:`0UYJF09JFUP2DU9@207QhN00404A4A00W9bL09bLW01<C4`802`/;00@0
0P8200X:2P0:2PX0410@0P0?3`l010071`L03`l?00l?3`0A4A42010@400400H61P0:2PX02PX:00X:
2P801@D500@02@T900410@010@4020P80P0410@0100820P01@D500D51@020P8200@4100000@00P82
00P8200820P010@40P0:2PX010051@D010@400@410071`L200T92@0400H61P0410@010@400H61P80
1`L700@01PH600/;2`0;2`/01PH60`051@D200820P0400X:2P0=3@d03@d=00<30`801`L700@02PX:
00410@010@400P820P051@D00`0410@00`<300<30`0300@4100400410@000000000000820P801@D5
00@01PH600@4100410@010@40P061PH010051@D01PH600H61P061PH200D51@0400X:2P0820P020P8
01PH6080:2PX00@09BDU03`l?00l?3`0CDe=0P1QHF401028R8P0S8b<08b<S01iNGT207=cL`04071`
L01]KFd0KFe]051@D0808R8R00<0=cLg00d=3@0=3@d00`071`L010020P803Ph>00h>3P0I6AT201lO
7`0402LW9`0S8b<08b<S00/;2`800@4100<0<S8b06=SH`1SHf<00`1HF5P0101_Kfl0Hf=S06=SH`1H
F5P206MWI`0404E5A@0W9bL09bLW02`/;080>c/k00@0F5QH06][J`1[Jf/0L71`0P1gMgL0101mOGd0
Ng]k07]kN`1`L70207AdM00407=cL`1jNWX0NWYj03Ti>@80000000@01@D500L71`071`L0@4100P1E
EED01012@T80DE5A055AD@1FEUH2061PH00306UYJ@1CDe<0De=C00<0EEEE00@0FEUI06IVIP1VIVH0
HF5Q0P1CDe<01010@400A4A404A4A01LG5`206QXJ00405]KF`1@D500D51@05=CD`80G5aL00@0MgMg
079bLP1bLW80IVIV0P1ZJVX0101NGUh0I6AT06ATI01PH602075aL@0407EeM@1JFUX0FUYJ061PH080
IVIV00@0Hf=S06QXJ01XJ6P0JFUY0P1UIFD0101_Kfl0GUiN05iNGP1^KVh207=cL`0406e]K@1FEUH0
EUIF0492@P80BTY:00@0ATI604i>CP1>CTh0BTY:0P0g=cL0101BDU80F5QH05QHF00];Bd200d=3@04
00l?3`0E5AD05ADE02TY:@80M7Ad00@0P82008:2PP22PX80MGEe0P1aLG40101fMWH0K6a/06a/K01b
LW8206m_K`0406YZJP1YJFT0JFUY07AdM080RHV900@0QhN707inOP1nOWh0OWin0P1jNWX0101[Jf/0
F5QH05QHF01IFET206][J`0406e]K@1[Jf/0Jf][06m_K`80K6a/00@0M7Ad07moO`1oOgl0MgMg0`1c
Lg<207QhN00408:2PP1nOWh0OWin0820P080MgMg00@0Ng]k08:2PP22PX80O7al0P1IFET01019BDT0
C4a<04a<C00k>c/203Hf=P0404A4A01DE5@0E5AD05IFEP80GEeM00@0L71`06m_K`1_Kfl0RHV90P2J
VYX0102LW9`0RHV908V9R@2;Rh/209bLW0040:ZZZP2VYZH0YZJV09jNWP80[jn_00@0XZ:R0:>SX`2S
Xj<0/k>c0P2/[:`0102ZZZX0XJ6Q0:6QX@2EUID208n?S`0408b<S024Q8@0Q8B409>CT`80^KVi00@0
/[:b09^KV`2KVi/0VIVI0P2UYJD0102IVIT0RXZ:08Z:RP2OWil208b<S00403lo?`0G5aL05aLG01PH
6080410@00@00`<300X:2P0:2PX04Q8B0P0=3@d0100?3`l05ADE01DE5@0?3`l200`<300400/;2`0A
4A404A4A00L71`800`<30`0820P010071`L01PH600H61P0820P200@410401PH60@0410@100@41000
00@01@D500820P020P802PX:0P0410@00`0;2`/00P8200820P0400D51@8010@400@01PH600820P02
0P801`L70P0410@010051@D00`<300<30`0820P200L71`0400D51@092@T02@T900D51@800@4100@0
000000L71`071`L00`<30P00000010030`<00P8200820P030`<200D51@0400/;2`092@T02@T90041
0@801@D500@00`<300820P020P800P820P0820P0100410@00@4100410@051@D200H61P0400D51@04
10@010@401LG5`80820P00@05aLG03/k>`0k>c/0EEEE0P1<C4`0101cLg<0Shn?08n?S`25QHD207Ad
M00406IVIP1/K6`0K6a/04e=C@80<30`00@0@410010@400@41001PH60P092@T010030`<00P820082
0P0D51@202HV9P0401LG5`0;2`/02`/;014A4@809RHV00@0>3Ph04U9B@19BDT0De=C0P1QHF40101Y
JFT0CDe=04e=C@13@d<205EEE@0403De=@0W9bL09bLW03Hf=P80>c/k00@0Fe]K07EeM@1eMGD0LG5a
0P1iNGT0101mOGd0LG5a075aL@1_Kfl307QhN080Lg=c00@0=3@d0000000000000P820P071`L0100d
=3@0E5AD05ADE00k>c/204A4A00403`l?01DE5@0E5AD06i^KP80EeMG00@0Bd];04M7A`17AdL0GEeM
0P1SHf<0101IFET0?3`l03`l?00l?3`305YJFP80GEeM00@0H61P04i>CP1>CTh0Fe]K0P1_Kfl0101[
Jf/0HF5Q065QH@1OGel205aLG00405MGE`1TI6@0I6AT06a/K080FUYJ00@0G5aL05EEE@1EEED0HV9R
0P1UIFD0101JFUX0HF5Q065QH@1QHF4206][J`0406ATI01]KFd0KFe]07alO080K6a/00@0IFEU05aL
G01LG5`0Fe]K0P1PH600101CDe<0CTi>04i>CP11@D4203@d=00404i>CP1ADE40DE5A02XZ:P8030`<
00@04a<C01DE5@0E5AD0:2PX0P1]KFd0101gMgL0MGEe07EeM@1jNWX207=cL`0407EeM@1ZJVX0JVYZ
06MWI`80L71`00@0JFUY06YZJP1ZJVX0NGUi0P23Ph<01022PX80O7al07alO01dM7@206e]K@04069R
HP1BDU80DU9B059BDP80IFEU00@0MGEe079bLP1bLW80IFEU0P1WIfL0101eMGD0NGUi07UiN@1[Jf/2
06ATI0040820P025QHD0QHF50861P@80Ogmo00@0MWIf075aL@1aLG40Q8B40P29RHT01022PX80GEeM
05eMG@1:BTX204m?C`0404I6AP10@400@4100492@P80F5QH00@0Fe]K05YJFP1JFUX0IfMW0P1bLW80
102:RXX0SXj>08j>SP2>SXh209NGU`040:>SX`2QXJ40XJ6Q0:j^[P80ZJVY00@0S8b<09NGU`2GUiL0
WinO0P2UYJD0102g]kL0/[:b0;:b/P2VYZH2092@T0040820P01lO7`0O7al07AdM080IfMW00@0PH61
0;Vi^@2i^KT0]KFe0P2PX:00102RXZ80WYjN09jNWP2>SXh2092@T0040:RXZ02<S8`0S8b<0410@080
7alO00@061PH00l?3`0?3`l020P80P0;2`/0100H61P03@d=00d=3@0F5QH201@D500400T92@0;2`/0
2`/;018B4P803Ph>00@00P8200L71`071`L01@D50P071`L00`051@D01PH600H61P0300H61P4030`<
0@092@T100T92@0000@01@D500820P020P802PX:0P0410@00`0;2`/00P8200820P0400D51@8010@4
00@01PH600820P020P801`L70P0410@010051@D00`<300<30`0820P200L71`0400D51@092@T02@T9
00D51@800@4100@0000000L71`071`L00`<30P00000010030`<00P8200820P030`<200D51@0400/;
2`092@T02@T900410@801@D500@00`<300820P020P800P820P0820P0100410@00@4100410@051@D2
00H61P0400D51@0410@010@401LG5`80820P00@05aLG03/k>`0k>c/0EEEE0P1<C4`0101cLg<0Shn?
08n?S`25QHD207AdM00406IVIP1/K6`0K6a/04e=C@80<30`00@0@410010@400@41001PH60P092@T0
10030`<00P8200820P0D51@202HV9P0401LG5`0;2`/02`/;014A4@809RHV00@0>3Ph04U9B@19BDT0
De=C0P1QHF40101YJFT0CDe=04e=C@13@d<205EEE@0403De=@0W9bL09bLW03Hf=P80>c/k00@0Fe]K
07EeM@1eMGD0LG5a0P1iNGT0101mOGd0LG5a075aL@1_Kfl307QhN080Lg=c00@0=3@d000000000000
0P820P071`L0100d=3@0E5AD05ADE00k>c/204A4A00403`l?01DE5@0E5AD06i^KP80EeMG00@0Bd];
04M7A`17AdL0GEeM0P1SHf<0101IFET0?3`l03`l?00l?3`305YJFP80GEeM00@0H61P04i>CP1>CTh0
Fe]K0P1_Kfl0101[Jf/0HF5Q065QH@1OGel205aLG00405MGE`1TI6@0I6AT06a/K080FUYJ00@0G5aL
05EEE@1EEED0HV9R0P1UIFD0101JFUX0HF5Q065QH@1QHF4206][J`0406ATI01]KFd0KFe]07alO080
K6a/00@0IFEU05aLG01LG5`0Fe]K0P1PH600101CDe<0CTi>04i>CP11@D4203@d=00404i>CP1ADE40
DE5A02XZ:P8030`<00@04a<C01DE5@0E5AD0:2PX0P1]KFd0101gMgL0MGEe07EeM@1jNWX207=cL`04
07EeM@1ZJVX0JVYZ06MWI`80L71`00@0JFUY06YZJP1ZJVX0NGUi0P23Ph<01022PX80O7al07alO01d
M7@206e]K@04069RHP1BDU80DU9B059BDP80IFEU00@0MGEe079bLP1bLW80IFEU0P1WIfL0101eMGD0
NGUi07UiN@1[Jf/206ATI0040820P025QHD0QHF50861P@80Ogmo00@0MWIf075aL@1aLG40Q8B40P29
RHT01022PX80GEeM05eMG@1:BTX204m?C`0404I6AP10@400@4100492@P80F5QH00@0Fe]K05YJFP1J
FUX0IfMW0P1bLW80102:RXX0SXj>08j>SP2>SXh209NGU`040:>SX`2QXJ40XJ6Q0:j^[P80ZJVY00@0
S8b<09NGU`2GUiL0WinO0P2UYJD0102g]kL0/[:b0;:b/P2VYZH2092@T0040820P01lO7`0O7al07Ad
M080IfMW00@0PH610;Vi^@2i^KT0]KFe0P2PX:00102RXZ80WYjN09jNWP2>SXh2092@T0040:RXZ02<
S8`0S8b<0410@0807alO00@061PH00l?3`0?3`l020P80P0;2`/0100H61P03@d=00d=3@0F5QH201@D
500400T92@0;2`/02`/;018B4P803Ph>00@00P8200L71`071`L01@D50P071`L00`051@D01PH600H6
1P0300H61P4030`<0@092@T100T92@0010071`L200410@0400@410010@400@4100820P801@D500@0
10@400<30`030`<010@40P020P80100;2`/01`L700L71`020P8200<30`0400P8200410@010@400P8
2080000000@01@D500L71`071`L020P80P0:2PX010030`<01`L700L71`061PH200L71`0300<30`07
1`L01`L700<01PH600@00`<300410@010@402PX:0P0820P010051@D00`<300<30`0410@200T92@<0
1@D500@010@400820P020P803`l?0P0Q8B40100N7Qh0=CDe03De=@1IFET205QHF00406EUI@1hN7P0
N7Qh08>3P`80N7Qh00@0H61P06i^KP1^KVh0EEEE0P11@D401012@T8020P800P820061PH200@41004
00X:2P0?3`l03`l?00d=3@807AdM00@03`l?00P8200820P06ATI0P0W9bL0100^;Rh0<30`030`<015
ADD205aLG00406IVIP17AdL0AdM704A4A080Cdm?00@09bLW02TY:@0Y:BT0B4Q80P1;Bd/0101NGUh0
M7Ad07AdM01dM7@2075aL@0406YZJP1JFUX0FUYJ05MGE`80IFEU00@0Lg=c06a/K01/K6`0>c/k0P00
0000100410@0410@010@400`<30205MGE`0404Y:BP1DE5@0E5AD04E5A@80@d=300@0GUiN05eMG@1M
GEd0Fe]K0P17AdL0101DE5@0HF5Q065QH@1JFUX205EEE@0405MGE`1HF5P0F5QH05IFEP80DE5A00@0
BDU905ADE01DE5@0M7Ad0P1cLg<0101JFUX0Fe]K05]KF`1JFUX205iNGP0405mOG`1RHV80HV9R06m_
K`80EEEE00@0G5aL06QXJ01XJ6P0G5aL0P1NGUh0101ADE40Hf=S06=SH`1KFe/206m_K`04079bLP1g
MgL0MgMg06e]K@80EEEE00@0M7Ad07alO01lO7`0Fe]K0P1<C4`0101ADE40CDe=04e=C@0m?Cd20410
@00405ADE016ATH0ATI601TI6@802PX:00@061PH010@400@4100;2`/0P1/K6`01023Ph<0N7Qh07Qh
N021PH42071`L00406IVIP1UIFD0IFEU05IFEP80I6AT00@0KFe]06EUI@1UIFD0JFUY0P1_Kfl0101Y
JFT0Jf][06][J`1/K6`2061PH004069RHP1UIFD0IFEU05iNGP80GEeM00@0JFUY06i^KP1^KVh0GUiN
0P1PH6000`1aLG40L71`071`L00305eMG@0408:2PP25QHD0QHF507moO`80P82000@0O7al07IfMP1f
MWH0OWin0P1kNg/0101gMgL0Hf=S06=SH`1ADE4204=3@`0403Ph>013@d<0@d=304E5A@80CDe=00@0
DE5A05]KF`1KFe/0KVi^0P21PH40102EUID0U9BD09BDU02CTi<209fMW@040:NWY`2UYJD0YJFU0:n_
[`80ZJVY00@0UYJF09nOW`2OWil0YJFU0P2VYZH0102_[jl0^[Zj0;Zj^P2f][H2092@T00406e]K@1=
CDd0CDe=03De=@80:2PX00@0@T92092@T02@T900XJ6Q0P2LW9`40:JVYP80ZJVY00@0ZZZZ0820P020
P800De=C0P0a<C40100F5QH03Ph>00h>3P061PH200@4100401<C4`092@T02@T901<C4`8051@D00@0
2`/;014A4@0A4A40410@0P061PH010051@D02@T900T92@061PH200@4100400P820000000000000L7
1`8020P80`071`L0000400820P061PH01PH600<30`801@D500@00P8200H61P061PH01PH60P0:2PX3
00@4100400L71`051@D01@D500L71`801PH600@010@400h>3P0>3Ph02PX:0P020P80100A4A402PX:
00X:2P030`<200D51@<01PH600@010@400L71`071`L010@40P061PH0100410@00`<300<30`020P82
00410@0400H61P020P800P8200T92@802`/;00@01`L700@4100410@01@D50P0:2PX010030`<02@T9
00T92@0:2PX200820P0400`<300T92@092@T01lO7`80;Bd]00@0E5AD06EUI@1UIFD0LW9b0P1^KVh0
101mOGd0RXZ:08Z:RP1]KFd206QXJ00405iNGP1@D500D51@0451@@<01`L70P061PH0100>3Ph030`<
00`<300410@3014A4@804a<C00@06a/K01HF5P0F5QH07alO0P0D51@0100d=3@0Cdm?04m?C`1RHV83
04M7A`80BTY:00@0:BTY034a<@0a<C40ATI60P1EEED0101VIVH0LG5a075aL@1kNg/207alO00407If
MP1WIfL0IfMW05eMG@80JVYZ00@0Kfm_06MWI`1WIfL0@4100P00000010030`<02`/;00/;2`0N7Qh2
04=3@`0403lo?`1DE5@0E5AD05UIF@80DU9B0`1IFET0101NGUh0C4a<04a<C01FEUH206YZJP0406MW
I`1]KFd0KFe]055AD@80CDe=00@0LG5a06UYJ@1YJFT0De=C0P1NGUh0101^KVh0JFUY06UYJ@1MGEd2
061PH00405iNGP1VIVH0IVIV06i^KP80GEeM00@0J6QX06IVIP1VIVH0JFUY0P1XJ6P0101=CDd0E5AD
05ADE016ATH206EUI@0306=SH`1VIVH0IVIV00<0FUYJ00@0GemO04m?C`1?Cdl0JVYZ0P1XJ6P0101<
C4`0AdM704M7A`1BDU8204];B`0403Ti>@17AdL0AdM705MGE`80@41000@061PH00P8200820P03@d=
0P0820P0100h>3P0JVYZ06YZJP21PH4207inOP0407AdM01[Jf/0Jf][06a/K080I6AT00@0GUiN06][
J`1[Jf/0JVYZ0P1KFe/3065QH@0405eMG@1/K6`0K6a/07AdM080IFEU00@0H61P05aLG01LG5`0EeMG
0P1LG5`0101VIVH0JVYZ06YZJP1UIFD206MWI`0406e]K@1SHf<0Hf=S05=CD`80J6QX00@0Q8B408:2
PP22PX80N7Qh0P1mOGd30820P00407]kN`1gMgL0MgMg06ATI080EUIF00@0DU9B04=3@`13@d<0>3Ph
0P11@D401015ADD0CDe=04e=C@1@D502061PH00407EeM@29RHT0RHV909NGU`80UIFE00@0XZ:R0;2`
/02`/;00[:b/0P2NWYh0102VYZH0ZZZZ0:ZZZP2SXj<20:NWY`040::RXP2PX:00X:2P0:ZZZP80/k>c
00@0];Bd0:2PX02PX:00RXZ:0P1cLg<0101[Jf/0K6a/06a/K01bLW8209NGU`040:JVYP2WYjL0YjNW
0:6QX@80YjNW00@0/;2`0:f][@2][Jd0YZJV0P1oOgl0101TI6@0=3@d03@d=00@410200`<300400H6
1P0410@010@400d=3@804Q8B00@06ATI01DE5@0E5AD03@d=0`0?3`l200T92@0400H61P0;2`/02`/;
00X:2P801PH600@02@T900H61P061PH030`<0P020P810000004030`<0@0<30`0000400820P061PH0
1PH600<30`801@D500@00P8200H61P061PH01PH60P0:2PX300@4100400L71`051@D01@D500L71`80
1PH600@010@400h>3P0>3Ph02PX:0P020P80100A4A402PX:00X:2P030`<200D51@<01PH600@010@4
00L71`071`L010@40P061PH0100410@00`<300<30`020P8200410@0400H61P020P800P8200T92@80
2`/;00@01`L700@4100410@01@D50P0:2PX010030`<02@T900T92@0:2PX200820P0400`<300T92@0
92@T01lO7`80;Bd]00@0E5AD06EUI@1UIFD0LW9b0P1^KVh0101mOGd0RXZ:08Z:RP1]KFd206QXJ004
05iNGP1@D500D51@0451@@<01`L70P061PH0100>3Ph030`<00`<300410@3014A4@804a<C00@06a/K
01HF5P0F5QH07alO0P0D51@0100d=3@0Cdm?04m?C`1RHV8304M7A`80BTY:00@0:BTY034a<@0a<C40
ATI60P1EEED0101VIVH0LG5a075aL@1kNg/207alO00407IfMP1WIfL0IfMW05eMG@80JVYZ00@0Kfm_
06MWI`1WIfL0@4100P00000010030`<02`/;00/;2`0N7Qh204=3@`0403lo?`1DE5@0E5AD05UIF@80
DU9B0`1IFET0101NGUh0C4a<04a<C01FEUH206YZJP0406MWI`1]KFd0KFe]055AD@80CDe=00@0LG5a
06UYJ@1YJFT0De=C0P1NGUh0101^KVh0JFUY06UYJ@1MGEd2061PH00405iNGP1VIVH0IVIV06i^KP80
GEeM00@0J6QX06IVIP1VIVH0JFUY0P1XJ6P0101=CDd0E5AD05ADE016ATH206EUI@0306=SH`1VIVH0
IVIV00<0FUYJ00@0GemO04m?C`1?Cdl0JVYZ0P1XJ6P0101<C4`0AdM704M7A`1BDU8204];B`0403Ti
>@17AdL0AdM705MGE`80@41000@061PH00P8200820P03@d=0P0820P0100h>3P0JVYZ06YZJP21PH42
07inOP0407AdM01[Jf/0Jf][06a/K080I6AT00@0GUiN06][J`1[Jf/0JVYZ0P1KFe/3065QH@0405eM
G@1/K6`0K6a/07AdM080IFEU00@0H61P05aLG01LG5`0EeMG0P1LG5`0101VIVH0JVYZ06YZJP1UIFD2
06MWI`0406e]K@1SHf<0Hf=S05=CD`80J6QX00@0Q8B408:2PP22PX80N7Qh0P1mOGd30820P00407]k
N`1gMgL0MgMg06ATI080EUIF00@0DU9B04=3@`13@d<0>3Ph0P11@D401015ADD0CDe=04e=C@1@D502
061PH00407EeM@29RHT0RHV909NGU`80UIFE00@0XZ:R0;2`/02`/;00[:b/0P2NWYh0102VYZH0ZZZZ
0:ZZZP2SXj<20:NWY`040::RXP2PX:00X:2P0:ZZZP80/k>c00@0];Bd0:2PX02PX:00RXZ:0P1cLg<0
101[Jf/0K6a/06a/K01bLW8209NGU`040:JVYP2WYjL0YjNW0:6QX@80YjNW00@0/;2`0:f][@2][Jd0
YZJV0P1oOgl0101TI6@0=3@d03@d=00@410200`<300400H61P0410@010@400d=3@804Q8B00@06ATI
01DE5@0E5AD03@d=0`0?3`l200T92@0400H61P0;2`/02`/;00X:2P801PH600@02@T900H61P061PH0
30`<0P020P810000004030`<0@0<30`000<00P8200@01@D500H61P061PH01`L70P0410@0100820P0
1`L700L71`010@4200<30`<01@D50`010@4010092@T020P800P820071`L200410@0400H61P030`<0
0`<300L71`8020P800@00`<300D51@051@D01@D50P020P800`051@D00P8200820P0300820P040041
0@000000000000<30`801@D500@010@400X:2P0:2PX02PX:0`020P8200L71`0400H61P092@T02@T9
00P82080000000@0410@02TY:@0Y:BT08B4Q0P0f=SH0101FEUH0Fe]K05]KF`1hN7P207AdM00406AT
I022PX80PX:207IfMP<0HF5Q0P1KFe/0101>CTh03Ph>00h>3P0820P200/;2`0400X:2P0410@010@4
00D51@802`/;00@02PX:01<C4`0C4a<08b<S0P0I6AT0100D51@06ATI01TI6@0`<3020451@@0305QH
F00o?cl0?clo00<0@41000@0;Rh^034a<@0a<C40;bl_0P1DE5@0101bLW80MWIf07IfMP20P80207al
O004071`L01YJFT0JFUY071`L080MgMg00@0L71`06YZJP1ZJVX0@4100P000000100410@02@T900T9
2@0D51@20410@0040451@@1CDe<0De=C05eMG@80H61P00@0IVIV069RHP1RHV80FUYJ0P1IFET00`1P
H600HF5Q065QH@0305UIF@0403lo?`1>CTh0CTi>06IVIP80Fe]K0`1RHV80101OGel0KVi^06i^KP1Z
JVX206ATI00405eMG@1OGel0GemO07]kN`<0Kfm_0P1gMgL0101ZJVX0FUYJ05YJFP12@T8204];B`04
04Q8B01HF5P0F5QH059BDP<0Cdm?0P1LG5`0101XJ6P0F5QH05QHF01NGUh205=CD`04059BDP1IFET0
FEUI05EEE@80DU9B00@0@D5103@d=00d=3@0?Shn0P12@T80100Q8B401`L700L71`0820P200l?3`04
038b<P1VIVH0IVIV06YZJP80N7Qh00@0IfMW061PH01PH600IVIV0P1RHV80101]KFd0LG5a075aL@1R
HV8205eMG@0406a/K01_Kfl0Kfm_06UYJ@80LW9b00@0MgMg06QXJ01XJ6P0Fe]K0P1EEED0101CDe<0
FEUI05UIF@1KFe/205aLG004069RHP1WIfL0IfMW06MWI`80GUiN00<0IfMW07YjNP1jNWX00`1nOWh0
0`1gMgL0OWin07inOP0307inOP0407IfMP1gMgL0MgMg061PH080E5AD00@0DU9B04a<C01<C4`0BTY:
0P12@T80100m?Cd0D51@051@D01FEUH206QXJ00407YjNP27QhL0QhN709>CT`80V9RH00@0YZJV0:^[
Z`2[Zj/0Xj>S0P2OWil0102WYjL0Y:BT0:BTY02MWId20:>SX`0409fMW@2HV9P0V9RH0:BTY080[Zj^
00@0ZZZZ0::RXP2RXZ80YjNW0P2/[:`0102c/k<0^[Zj0;Zj^P2d];@20:n_[`040:JVYP2UYJD0YJFU
09jNWP80[jn_00@0]KFe0;>c/`2c/k<0[Zj^0P22PX80101XJ6P0>c/k03/k>`0S8b<201XJ6P0400T9
2@0820P020P800d=3@805ADE00@051@D00d=3@0=3@d03@d=0P0;2`/0100G5aL04A4A014A4@0820P2
00d=3@<020P80`061PH0100:2PX030`<00`<30092@T200L71`0000<01PH600820P020P800`051@D3
00H61P0400X:2P0410@010@400@410800@4100@01PH600L71`071`L00P820P0410@0100;2`/00@41
00410@0410@200D51@0400h>3P051@D01@D500L71`802PX:00@0000000<30`030`<01PH60P0;2`/0
100000002@T900T92@0820P200@4100400T92@0<30`030`<00<30`801@D500@01PH600T92@092@T0
1`L70P0<30`0100>3Ph010@400@4100410@200H61P0400<30`0000000000014A4@80;Bd]00@0820P
02TY:@0Y:BT0F5QH0P1QHF40101gMgL0Ng]k07]kN`1CDe<206UYJ@0407inOP1eMGD0MGEe06QXJ080
EUIF00@0H61P02/[:`0[:b/01`L70P092@T0100820P01PH600H61P0410@300l?3`804Q8B00@06ATI
01<C4`0C4a<03Ph>0P0N7Qh0100U9BD0:2PX02PX:014A4@204I6AP040410@00b<S80<S8b03Lg=`80
<S8b00@08R8R05YJFP1JFUX0Lg=c0P1`L700101nOWh0NGUi07UiN@1[Jf/206MWI`0406a/K01eMGD0
MGEe07]kN`80LW9b00@0?3`l0000000000002@T90P0F5QH0100^;Rh0CTi>04i>CP1>CTh205=CD`03
05ADE01HF5P0F5QH00<0GemO00@0F5QH069RHP1RHV80FUYJ0P1CDe<0101FEUH0GemO05mOG`1LG5`2
05IFEP0404U9B@1@D500D51@06=SH`80GUiN00@0I6AT06e]K@1]KFd0H61P0P1OGel0101GEeL0EEEE
05EEE@1]KFd206MWI`04061PH01VIVH0IVIV06MWI`80GemO00@0BTY:04m?C`1?Cdl0EUIF0P1EEED0
101OGel0H61P061PH01ZJVX2069RHP0405EEE@1CDe<0De=C05MGE`80G5aL00@0Hf=S055AD@1ADE40
@D510P1=CDd0100o?cl092@T02@T900k>c/204A4A00401<C4`061PH01PH600T92@804A4A00@0>3Ph
06e]K@1]KFd0J6QX0P1nOWh0101dM7@0IVIV06IVIP1QHF4206EUI@0406i^KP1WIfL0IfMW06QXJ080
MGEe00@0MgMg075aL@1aLG40K6a/0`1aLG4206UYJ@0405iNGP1?Cdl0Cdm?04M7A`80EUIF00@0Hf=S
065QH@1QHF40H61P0P1OGel0101SHf<0FEUI05UIF@1VIVH207emO@040820P024Q8@0Q8B407emO@80
O7al00@0OGem07UiN@1iNGT0LG5a0P20P800101cLg<0GemO05mOG`1HF5P2059BDP04055AD@15ADD0
ADE503hn?P80DU9B00@0F5QH06i^KP1^KVh0NGUi0P20P800102DU9@0Xj>S0:>SX`2VYZH209nOW`04
0:>SX`2b/[80/[:b0:VYZ@80SXj>00@0U9BD0:ZZZP2ZZZX0YjNW0P2@T9001026QXH0YjNW0:NWY`2`
/;020:BTY0040:ZZZP2`/;00/;2`0:j^[P80/K6a00@0]kNg0;Fe]@2e]KD0ZZZZ0P2OWil0102JVYX0
ZZZZ0:ZZZP2][Jd20;Rh^0040;Fe]@28R8P0R8R807IfMP80B4Q800@092@T010@400@41001PH60P07
1`L0100B4Q8051@D01@D500;2`/2014A4@04010@400>3Ph03Ph>01hN7P805ADE0`0A4A40100<30`0
1@D500D51@030`<200@4100400H61P0820P020P800/;2`801@D500000`061PH00P8200820P0300D5
1@<01PH600@02PX:00@4100410@010@40P010@4010061PH01`L700L71`020P8200@4100400/;2`01
0@400@4100@410801@D500@03Ph>00D51@051@D01`L70P0:2PX0100000000`<300<30`061PH200/;
2`04000000092@T02@T900P8208010@400@02@T900`<300<30`00`<30P051@D010061PH02@T900T9
2@071`L200`<300400h>3P0410@010@400@410801PH600@00`<30000000000004A4A0P0];Bd0100P
8200:BTY02TY:@1HF5P2065QH@0407MgM`1kNg/0Ng]k05=CD`80JFUY00@0OWin07EeM@1eMGD0J6QX
0P1FEUH0101PH600:b/[02/[:`071`L200T92@0400P820061PH01PH600@410<03`l?0P0B4Q80100I
6AT04a<C01<C4`0>3Ph201hN7P0402DU9@0X:2P0:2PX04A4A080ATI600@0@410038b<P0b<S80=cLg
0P0b<S80100R8R80FUYJ05YJFP1cLg<2071`L00407inOP1iNGT0NGUi06][J`80IfMW00@0K6a/07Ee
M@1eMGD0Ng]k0P1bLW80100l?3`00000000000092@T201HF5P0402h^;P1>CTh0CTi>04i>CP80De=C
00<0E5AD05QHF01HF5P00`1OGel0101HF5P0HV9R069RHP1JFUX205=CD`0405IFEP1OGel0GemO05aL
G080EUIF00@0BDU9051@D01@D500Hf=S0P1NGUh0101TI6@0KFe]06e]K@1PH60205mOG`0405MGE`1E
EED0EEEE06e]K@80IfMW00@0H61P06IVIP1VIVH0IfMW0P1OGel0101:BTX0Cdm?04m?C`1FEUH205EE
E@0405mOG`1PH600H61P06YZJP80HV9R00@0EEEE05=CD`1CDe<0EeMG0P1LG5`0101SHf<0DE5A055A
D@11@D4204e=C@0403lo?`0T92@092@T03/k>`80A4A400@04a<C00H61P061PH02@T90P0A4A40100h
>3P0KFe]06e]K@1XJ6P207inOP0407AdM01VIVH0IVIV065QH@80IFEU00@0KVi^06MWI`1WIfL0J6QX
0P1eMGD0101gMgL0LG5a075aL@1/K6`3075aL@80JFUY00@0GUiN04m?C`1?Cdl0AdM70P1FEUH0101S
Hf<0HF5Q065QH@1PH60205mOG`0406=SH`1IFET0FEUI06IVIP80OGem00@0P82008B4Q024Q8@0OGem
0P1lO7`0101mOGd0NGUi07UiN@1aLG420820P00407=cL`1OGel0GemO05QHF080DU9B00@0DE5A04E5
A@15ADD0?Shn0P1BDU80101HF5P0KVi^06i^KP1iNGT20820P00409BDU02SXj<0Xj>S0:JVYP80WinO
00@0Xj>S0;:b/P2b/[80ZJVY0P2>SXh0102DU9@0ZZZZ0:ZZZP2WYjL2092@T00408J6QP2WYjL0YjNW
0;2`/080Y:BT00@0ZZZZ0;2`/02`/;00[Zj^0P2a/K40102g]kL0]KFe0;Fe]@2ZZZX209nOW`0409ZJ
VP2ZZZX0ZZZZ0:f][@80^;Rh00@0]KFe08R8R028R8P0MWIf0P18B4P0100T92@0410@010@40061PH2
00L71`04018B4P0D51@051@D00/;2`804A4A00@0410@00h>3P0>3Ph07QhN0P0E5AD3014A4@0400`<
30051@D01@D500<30`8010@400@01PH600P8200820P02`/;0P051@D000<00P8200<020P800H61P06
1PH00`0410@00`0:2PX000000000000300<30`0400H61P0820P020P800410@8010@400@02@T90041
0@010@4010@40P030`<400H61P801@D500@01PH600820P020P801PH60P0:2PX010020P8010@400@4
10030`<200410@0400H61P071`L01`L700<30`800P8200@01`L700@4100410@01PH60P0<30`0100;
2`/01`L700L71`061PH200d=3@0400`<30030`<00`<300X:2P809bLW00@07alO00d=3@0=3@d0@d=3
0P1SHf<00`1bLW80QHF508F5Q@0306i^KP0407inOP21PH40PH6107UiN@80E5AD00@0Hf=S0492@P12
@T801PH60P092@T010051@D00`<300<30`0<30`201@D500400l?3`0E5AD05ADE01DE5@804Q8B00<0
2`/;014A4@0A4A400`0J6QX0100O7al0?clo03lo?`11@D4202l_;`0403Hf=P0_;bl0;bl_02l_;`80
IFEU00@0MgMg07=cL`1cLg<0OWin0P1eMGD0101]KFd0LG5a075aL@1VIVH206UYJ@0407]kN`1iNGT0
NGUi0410@080000000@020P801TI6@0I6AT0<S8b0P1:BTX01010@400=SHf03Hf=P10@40204e=C@04
04];B`1FEUH0EUIF069RHP80GUiN00@0D51@05IFEP1FEUH0GemO0P1RHV80101IFET0F5QH05QHF01O
Gel205aLG00405QHF01PH600H61P06YZJP80Jf][00@0K6a/07IfMP1fMWH0LW9b0P1TI6@0101OGel0
Fe]K05]KF`1KFe/205UIF@0405eMG@1XJ6P0J6QX05mOG`80GUiN00@0FUYJ059BDP1BDU80L71`0P1K
Fe/0101TI6@0Hf=S06=SH`1EEED205eMG@<0D51@00@0I6AT04e=C@1=CDd0?3`l0P1;Bd/0100h>3P0
9BDU02DU9@13@d<203Ph>004000000030`<00`<300<30`802PX:00@0<S8b071`L01`L700Lg=c0P1n
OWh0101ZJVX0EUIF05IFEP1SHf<206EUI@04069RHP1QHF40HF5Q07=cL`80Ng]k00@0M7Ad06a/K01/
K6`0IfMW0P1aLG40101dM7@0J6QX06QXJ01GEeL204U9B@0404i>CP1UIFD0IFEU06YZJP80J6QX00@0
Jf][065QH@1QHF40F5QH0P1@D500101IFET0N7Qh07QhN01kNg/307MgM`80MWIf00@0OWin07YjNP1j
NWX0NGUi0P20P800101aLG40HV9R069RHP1KFe/204m?C`0404I6AP15ADD0ADE504I6AP80EUIF00@0
Fe]K06][J`1[Jf/0KFe]0P1gMgL01027QhL0Shn?08n?S`2GUiL209RHV00409bLW02PX:00X:2P08f=
S@80QHF500@0VYZJ0:>SX`2SXj<0YZJV0P2PX:001028R8P0VIVI09VIV@2XZ:P20:JVYP040:RXZ02/
[:`0[:b/0:n_[`80Zj^[00@0[Zj^0;6a/@2a/K40[:b/0P2MWId0102KVi/0ZJVY0:VYZ@2f][H30;Rh
^080VIVI00@0Ogmo04i>CP1>CTh0820P0P0<30`0100;2`/02@T900T92@0@410201LG5`04014A4@0G
5aL05aLG01<C4`80410@00@08B4Q014A4@0A4A402PX:0P0B4Q8300l?3`0400P820030`<00`<300/;
2`800`<30`020P80000300@410030`<00`<300<01PH600@010@400820P020P801PH60P0820P01003
0`<01`L700L71`051@D200T92@0400@410020P800P8200D51@801`L700@00`<300410@010@400000
0P0410@0100820P01PH600H61P030`<200D51@0400<30`0410@010@400<30`8010@400@00P820041
0@010@4010@40P030`<00`071`L00P8200820P0300<30`0400L71`0820P020P800@4108020P800@0
1PH600T92@092@T02@T90P020P8010010@406a/K01/K6`0S8b<200`<300403Ph>01JFUX0FUYJ04m?
C`80I6AT00@0KVi^06][J`1[Jf/0HV9R0P1TI6@0101jNWX0H61P061PH01OGel2059BDP04010@4007
1`L01`L700@410802PX:0`0>3Ph010092@T0410@010@400G5aL201PH6004010@400>3Ph03Ph>01TI
6@809bLW00@061PH02`/;00/;2`0ADE50P11@D40100f=SH0>CTi03Ti>@11@D4205mOG`0407MgM`1c
Lg<0Lg=c07YjNP80MgMg00@0MWIf07=cL`1cLg<0FEUI0P1HF5P0101[Jf/0MWIf07IfMP17AdL20000
000400<30`0C4a<04a<C02DU9@80@T9200@0?Shn03Lg=`0g=cL0BTY:0P1VIVH0101JFUX0GEeM05eM
G@1XJ6P205aLG00405UIF@1UIFD0IFEU069RHP80GEeM00@0CTi>05YJFP1JFUX0Jf][0`1ADE4206m_
K`03079bLP1dM7@0M7Ad00<0NGUi00@0NWYj06ATI01TI6@0Fe]K0P1PH600101IFET0HF5Q065QH@1U
IFD206YZJP0406ATI01FEUH0EUIF05MGE`80C4a<00@0GUiN04U9B@19BDT0De=C0P1]KFd0101OGel0
HV9R069RHP1GEeL204e=C@0405eMG@1<C4`0C4a<04A4A080D51@00@0<C4a02PX:00X:2P0C4a<0P0i
>CT00`0000000`<300<30`0300<30`0402TY:@1WIfL0IfMW079bLP80M7Ad00@0LW9b059BDP1BDU80
CTi>0P1IFET0101QHF40GEeM05eMG@1/K6`207EeM@<0LG5a00@0J6QX06a/K01/K6`0JFUY0P1EEED0
101?Cdl0EeMG05MGE`1QHF4206YZJP04065QH@1LG5`0G5aL06QXJ080H61P00@0Fe]K07QhN01hN7P0
N7Qh0P1kNg/0101nOWh0NWYj07YjNP1dM7@207UiN@0407inOP1iNGT0NGUi08>3P`80O7al00@0IVIV
069RHP1RHV80HF5Q0P1ADE4404A4A080EEEE00@0G5aL061PH01PH600KFe]0P27QhL308n?S`0409ZJ
VP2IVIT0VIVI09NGU`80UIFE00@0PH6108>3P`23Ph<0Y:BT0P2VYZH0102NWYh0X:2P0:2PX02IVIT2
0:BTY0040:RXZ02TY:@0Y:BT0:RXZ080[Zj^00@0^;Rh0;Jf]P2f][H0]kNg0P2a/K40102TY:@0WIfM
09fMW@2IVIT20:2PX0040;no_`30`<00`<300<K6aP80Zj^[00@0P82005ADE01DE5@0;bl_0P0M7Ad0
100B4Q803Ph>00h>3P0<30`201<C4`0401PH600Q8B408B4Q020P80805ADE00@08R8R014A4@0A4A40
1@D50P0>3Ph0100C4a<05QHF01HF5P0:2PX200@4100400X:2P061PH01PH600<30`800P8200000`04
10@00`<300<30`0300H61P0400@410020P800P8200H61P8020P800@00`<300L71`071`L01@D50P09
2@T0100410@00P8200820P051@D200L71`0400<30`010@400@410000008010@400@020P800H61P06
1PH00`<30P051@D010030`<010@400@410030`<200@4100400820P010@400@4100@410800`<300<0
1`L700820P020P800`030`<010071`L020P800P8200410@200P8200400H61P092@T02@T900T92@80
0P8200@00@4101/K6`0K6a/08b<S0P0<30`0100h>3P0FUYJ05YJFP1?Cdl206ATI00406i^KP1[Jf/0
Jf][069RHP80I6AT00@0NWYj061PH01PH600GemO0P1BDU80100@41001`L700L71`0410@200X:2P<0
3Ph>00@02@T9010@400@41005aLG0P0H61P0100@41003Ph>00h>3P0I6AT202LW9`0401PH600/;2`0
;2`/04E5A@80@D5100@0=SHf03Ti>@0i>CT0@D510P1OGel0101gMgL0Lg=c07=cL`1jNWX207MgM`04
07IfMP1cLg<0Lg=c05UIF@80F5QH00@0Jf][07IfMP1fMWH0AdM70P00000010030`<04a<C01<C4`0U
9BD20492@P0403hn?P0g=cL0=cLg04Y:BP80IVIV00@0FUYJ05eMG@1MGEd0J6QX0P1LG5`0101IFET0
IFEU06EUI@1RHV8205eMG@0404i>CP1JFUX0FUYJ06][J`<0DE5A0P1_Kfl00`1bLW80M7Ad07AdM003
07UiN@0407YjNP1TI6@0I6AT05]KF`80H61P00@0FEUI065QH@1QHF40IFEU0P1ZJVX0101TI6@0EUIF
05IFEP1GEeL204a<C00405iNGP19BDT0BDU905=CD`80KFe]00@0GemO069RHP1RHV80EeMG0P1=CDd0
101MGEd0C4a<04a<C014A4@2051@D004034a<@0X:2P0:2PX04a<C080>CTi00<0000000<30`030`<0
0`030`<0100Y:BT0IfMW06MWI`1bLW8207AdM004079bLP1BDU80DU9B04i>CP80FEUI00@0HF5Q05eM
G@1MGEd0K6a/0P1eMGD3075aL@0406QXJ01/K6`0K6a/06UYJ@80EEEE00@0Cdm?05MGE`1GEeL0HF5Q
0P1ZJVX0101QHF40G5aL05aLG01XJ6P2061PH00405]KF`1hN7P0N7Qh07QhN080Ng]k00@0OWin07Yj
NP1jNWX0M7Ad0P1iNGT0101nOWh0NGUi07UiN@23Ph<207alO00406IVIP1RHV80HV9R065QH@80DE5A
1014A4@205EEE@0405aLG01PH600H61P06e]K@80QhN70`2?Shl0102JVYX0VIVI09VIV@2GUiL209FE
U@040861P@23Ph<0Ph>30:BTY080YZJV00@0WYjN0:2PX02PX:00VIVI0P2TY:@0102XZ:P0Y:BT0:BT
Y02XZ:P20:j^[P040;Rh^02f][H0][Jf0;Ng]`80/K6a00@0Y:BT09fMW@2MWId0VIVI0P2PX:00102o
_kl0`<300<30`036a/H20:^[Z`040820P01DE5@0E5AD02l_;`807AdM00@04Q8B00h>3P0>3Ph030`<
0P0C4a<0100H61P08B4Q024Q8@0P820201DE5@04028R8P0A4A404A4A00D51@803Ph>00@04a<C01HF
5P0F5QH02PX:0P0410@0100:2PX01PH600H61P030`<200820P0000<02@T900L71`071`L00`061PH0
10071`L00000000000030`<200T92@0400@410061PH01PH600<30`801@D500@00`<300D51@051@D0
10@40P071`L0100820P00P8200820P020P8300P820802`/;00@01@D500@4100410@000000P0410@0
10030`<020P800P820051@D300X:2P800@410`020P80100000002@T900T92@020P8200@410<00`<3
00<00P8200L71`071`L00`0<30`010051@D04a<C01<C4`0T92@201XJ6P0403Xj>P1cLg<0Lg=c05QH
F080B4Q80`1DE5@0101FEUH0GEeM05eMG@1^KVh205QHF00404e=C@1?Cdl0Cdm?01/K6`803`l?00<0
3Ph>00X:2P0:2PX00`0?3`l0100B4Q804a<C01<C4`0F5QH201TI6@0401LG5`0B4Q804Q8B00d=3@80
9RHV00@09BDU01/K6`0K6a/0>SXj0P17AdL0100f=SH0@4100410@017AdL205YJFP0406m_K`1WIfL0
IfMW06][J`80IfMW00@0KVi^06m_K`1_Kfl0DE5A0P1FEUH0101[Jf/0Kfm_06m_K`12@T8200000004
00<30`0>3Ph03Ph>01`L7080@D510`1:BTX0101BDU80K6a/06a/K01YJFT204a<C00405ADE01>CTh0
CTi>05UIF@80HF5Q00<0CDe=04m?C`1?Cdl00`1ADE40101KFe/0EEEE05EEE@1KFe/206QXJ00406a/
K01hN7P0N7Qh07EeM@80K6a/00@0KVi^065QH@1QHF40H61P0P1XJ6P0101TI6@0J6QX06QXJ01UIFD2
05mOG`0406=SH`1@D500D51@055AD@80Bd];00@0@410051@D01@D500H61P0P1bLW80101QHF40EeMG
05MGE`1HF5P205IFEP0405iNGP1IFET0FEUI04e=C@80ATI600@0<30`02HV9P0V9RH0?clo0P0k>c/0
10092@T00@4100410@0820P200`<30030410@01PH600H61P00<0Jf][00@0LW9b05eMG@1MGEd0AdM7
0P1ADE40101HF5P0FEUI05UIF@1YJFT207MgM`0407QhN01eMGD0MGEe06][J`80JVYZ00@0FEUI04Y:
BP1:BTX0FUYJ0P1RHV8305]KF`0405eMG@1TI6@0I6AT06QXJ080GemO00@0IVIV08J6QP26QXH0P820
0P1nOWh01020P800OWin07inOP1gMgL207emO@040820P021PH40PH610820P080Lg=c00@0IFEU065Q
H@1QHF40Fe]K0P1=CDd01016ATH0B4Q804Q8B00k>c/204a<C00406=SH`1WIfL0IfMW07alO080UiNG
0`2CTi<0102NWYh0Vi^K09^KV`2NWYh20:6QX@0408^;R`1lO7`0O7al09^KV`80ZZZZ00@0X:2P0:JV
YP2VYZH0YZJV0P2XZ:P0102ZZZX0[:b/0:b/[02^[Zh20:RXZ0040:b/[02VYZH0YZJV0;>c/`80];Bd
00<0YjNW0:FUY@2UYJD00`2OWil0102g]kL0^;Rh0;Rh^035aLD20:b/[00408B4Q01SHf<0Hf=S03Ti
>@808B4Q00@071`L01@D500D51@02`/;0P0C4a<0100F5QH071`L01`L700V9RH202DU9@0402HV9P0M
7Ad07AdM014A4@8030`<00@05aLG01dM7@0M7Ad03Ph>0P0820P00`051@D010@400@4100300`<3000
00@010@400T92@092@T02@T90`061PH200@4100400P820061PH01PH600820P801@D500@010@40041
0@010@401@D50P030`<010010@400P8200820P030`<200D51@0400<30`071`L01`L700D51@801`L7
00@0000000820P020P801`L70P0820P010051@D00`<300<30`010@4200D51@<010@400@0000000L7
1`071`L00@410P071`L00`0410@01`L700L71`0300410@0300L71`0:2PX02PX:00@020P80P0B4Q80
100X:2P09RHV02HV9P0[:b/206QXJ004071`L01DE5@0E5AD04m?C`80ADE500@0ATI604e=C@1=CDd0
E5AD0P1BDU801011@D40;Bd]02d];@0:2PX200d=3@0401DE5@0A4A404A4A01@D50<04Q8B0P0>3Ph0
100B4Q806ATI01TI6@0O7al201`L7004018B4P0J6QX06QXJ02PX:0807QhN00@0>c/k04i>CP1>CTh0
?Shn0P1:BTX0101CDe<0HF5Q065QH@1KFe/205mOG`04071`L01DE5@0E5AD05iNGP80LW9b00@0FUYJ
05iNGP1NGUh0KVi^0P1_Kfl01010@4000000000000071`L200T92@04024Q8@18B4P0B4Q804m?C`80
CTi>00@0DE5A05IFEP1FEUH0EEEE0P1?Cdl0101KFe/0F5QH05QHF01JFUX2059BDP04055AD@1FEUH0
EUIF05ADE080EEEE00@0GEeM06=SH`1SHf<0HV9R0P1SHf<0101WIfL0Jf][06][J`1`L70206a/K004
06EUI@1ZJVX0JVYZ06YZJP80LG5a00@0JVYZ05iNGP1NGUh0GEeM0P1TI6@0101UIFD0F5QH05QHF01F
EUH206ATI00404a<C01TI6@0I6AT06MWI`<0GEeM0P1EEED0101GEeL0EEEE05EEE@1;Bd/2059BDP04
051@D00j>SX0>SXj02TY:@806QXJ00@07QhN02`/;00/;2`020P80P0410@0100;2`/05aLG01LG5`1H
F5P205aLG0<0J6QX00<0GemO059BDP1BDU800`19BDT01015ADD0FUYJ05YJFP1/K6`207=cL`0407]k
N`1ZJVX0JVYZ05aLG080GEeM00<0DU9B055AD@1ADE400`1RHV8305YJFP04061PH01^KVh0KVi^06=S
H`80GUiN00@0OGem08:2PP22PX80M7Ad0P1kNg/0101lO7`0LW9b079bLP1bLW8207MgM`0307]kN`21
PH40PH6100<0Ng]k00@0JFUY05mOG`1OGel0GUiN0P1ADE401016ATH0@d=304=3@`0j>SX204];B`04
05iNGP1PH600H61P07QhN080T92@00@0S8b<08f=S@2=SHd0V9RH0P2LW9`0102NWYh0VYZJ09ZJVP2C
Ti<308:2PP80Shn?00@0UIFE0:ZZZP2ZZZX0[:b/0P2WYjL30:JVYP040:f][@2WYjL0YjNW0:j^[P80
[Jf]00@0/K6a0;2`/02`/;00ZJVY0P2MWId0102LW9`0X:2P0:2PX02b/[820;Bd]0040;Ng]`2VYZH0
YZJV08B4Q080I6AT00@0@41002/[:`0[:b/08B4Q0P0F5QH0100=3@d05QHF01HF5P0O7al201LG5`04
01PH600[:b/0:b/[02`/;0807QhN00@05aLG01PH600H61P0820P0P0N7Qh0100C4a<02PX:00X:2P04
10@300D51@800`<30000100410@02@T900T92@092@T300H61P8010@400@020P800H61P061PH00P82
0P051@D0100410@00@4100410@051@D200<30`0400410@020P800P8200<30`801@D500@00`<300L7
1`071`L01@D50P071`L0100000000P8200820P071`L200P8200400D51@030`<00`<300410@801@D5
0`0410@0100000001`L700L71`010@4200L71`0300@410071`L01`L700<00@4100<01`L700X:2P0:
2PX0100820P2018B4P0402PX:00V9RH09RHV02/[:`80J6QX00@0L71`05ADE01DE5@0Cdm?0P15ADD0
1016ATH0CDe=04e=C@1DE5@2059BDP040451@@0];Bd0;Bd]00X:2P803@d=00@05ADE014A4@0A4A40
51@D0`0B4Q8200h>3P04018B4P0I6AT06ATI01lO7`8071`L00@04Q8B01XJ6P0J6QX0:2PX0P0N7Qh0
100k>c/0CTi>04i>CP0n?Sh204Y:BP0405=CD`1QHF40HF5Q05]KF`80GemO00@0L71`05ADE01DE5@0
GUiN0P1bLW80101JFUX0GUiN05iNGP1^KVh206m_K`040410@0000000000000L71`802@T900@08B4Q
04Q8B018B4P0Cdm?0P1>CTh0101ADE40EUIF05IFEP1EEED204m?C`0405]KF`1HF5P0F5QH05YJFP80
DU9B00@0DE5A05IFEP1FEUH0E5AD0P1EEED0101MGEd0Hf=S06=SH`1RHV8206=SH`0406MWI`1[Jf/0
Jf][071`L080K6a/00@0IFEU06YZJP1ZJVX0JVYZ0P1aLG40101ZJVX0GUiN05iNGP1MGEd206ATI004
06EUI@1HF5P0F5QH05IFEP80I6AT00@0C4a<06ATI01TI6@0IfMW0`1MGEd205EEE@0405MGE`1EEED0
EEEE04];B`80DU9B00@0D51@03Xj>P0j>SX0:BTY0P0J6QX0100N7Qh0;2`/02`/;00820P200@41004
00/;2`0G5aL05aLG05QHF080G5aL0`1XJ6P00`1OGel0DU9B059BDP0304U9B@0404E5A@1JFUX0FUYJ
06a/K080Lg=c00@0Ng]k06YZJP1ZJVX0G5aL0P1MGEd00`1BDU80DE5A055AD@03069RHP<0FUYJ00@0
H61P06i^KP1^KVh0Hf=S0P1NGUh0101mOGd0PX:208:2PP1dM7@207]kN`0407alO01bLW80LW9b079b
LP80MgMg00<0Ng]k0861P@21PH400`1kNg/0101YJFT0GemO05mOG`1NGUh2055AD@0404I6AP13@d<0
@d=303Xj>P80Bd];00@0GUiN061PH01PH600N7Qh0P2@T900102<S8`0SHf=08f=S@2HV9P209bLW004
09jNWP2JVYX0VYZJ09>CT`<0PX:20P2?Shl0102EUID0ZZZZ0:ZZZP2/[:`20:NWY`<0YZJV00@0[Jf]
0:NWY`2WYjL0[Zj^0P2][Jd0102a/K40/;2`0;2`/02YZJT209fMW@0409bLW02PX:00X:2P0;:b/P80
];Bd00@0]kNg0:JVYP2VYZH0Q8B40P1TI6@01010@400:b/[02/[:`0Q8B4201HF5P0400d=3@0F5QH0
5QHF01lO7`805aLG00@061PH02/[:`0[:b/0;2`/0P0N7Qh0100G5aL061PH01PH600P820201hN7P04
01<C4`0:2PX02PX:00@410<01@D50P030`<0000400<30`051@D01@D500D51@800`<300@01@D500X:
2P0:2PX020P80P010@4010020P801@D500D51@030`<200410@0400820P051@D01@D500@410800000
00@00@4100P8200820P020P80P0410@010051@D01PH600H61P0410@200<30`0400P820051@D01@D5
00D51@8020P800@00`<300000000000000000P030`<010051@D02`/;00/;2`092@T200X:2P0400`<
30071`L01`L700D51@802@T900@01PH600L71`071`L01@D50P0410@010071`L0820P020P800Y:BT2
020P800402HV9P18B4P0B4Q805eMG@80D51@00@0EEEE03/k>`0k>c/0=SHf0P0m?Cd0100c<c<0E5AD
05ADE01;Bd/301DE5@804a<C00@020P8018B4P0B4Q804a<C0P0B4Q80100A4A403@d=00d=3@0<30`2
00h>3P0401HF5P0G5aL05aLG01TI6@803@d=00@08R8R038b<P0b<S80?3`l0P0m?Cd0100j>SX0EUIF
05IFEP1@D50205YJFP04059BDP1WIfL0IfMW07]kN`80Fe]K00@0I6AT07IfMP1fMWH0IfMW0P1SHf<0
101]KFd0O7al07alO013@d<20000000400P8200;2`/02`/;02HV9P80@41000@0?3`l03lo?`0o?cl0
Cdm?0P1UIFD0101SHf<0K6a/06a/K01`L702061PH00405EEE@12@T80@T9205UIF@80F5QH00@0E5AD
06ATI01TI6@0I6AT0P1OGel0101[Jf/0MGEe07EeM@1VIVH205iNGP04071`L01YJFT0JFUY05]KF`80
IFEU00@0K6a/075aL@1aLG40HF5Q0P1FEUH0101HF5P0JFUY06UYJ@1UIFD2069RHP0305UIF@1JFUX0
FUYJ00<0EUIF00@0DU9B04];B`1;Bd/0EeMG0P1IFET3069RHP0404E5A@10@400@41005EEE@80C4a<
00@0;bl_02@T900T92@09BDU0P0L71`010071`L02`/;00/;2`0:2PX2028R8P0406ATI01FEUH0EUIF
061PH080JFUY00@0FUYJ04i>CP1>CTh0AdM70P11@D401017AdL0GEeM05eMG@1WIfL206EUI@04075a
L@1RHV80HV9R05ADE080DE5A00@0De=C05iNGP1NGUh0IfMW0P1TI6@0101JFUX0GemO05mOG`1_Kfl2
075aL@0405UIF@1RHV80HV9R08:2PP80Ng]k00@0Kfm_075aL@1aLG40NGUi0P1eMGD307AdM00407Qh
N01kNg/0Ng]k07alO080Ph>300@0KFe]06EUI@1UIFD0Hf=S0P1ADE401014A4@0@4100410@010@402
04e=C@0405ADE01MGEd0GEeM07QhN080Rh^;00@0SXj>09NGU`2GUiL0XZ:R0P2OWil0102HV9P0VIVI
09VIV@2MWId208N7Q`0407IfMP25QHD0QHF509bLW080XZ:R00@0Z:RX0;6a/@2a/K40YjNW0P2NWYh0
0`2_[jl0[Jf]0:f][@030;Jf]P040:JVYP2HV9P0V9RH0:JVYP<0XJ6Q0P2WYjL30;Ng]`040;:b/P2_
[jl0[jn_08B4Q080GUiN00@0?clo02TY:@0Y:BT061PH0P0G5aL0100B4Q80410@010@400O7al302LW
9`80:2PX00@08b<S01`L700L71`07AdM0P0U9BD0100R8R806QXJ01XJ6P0J6QX2010@400400H61P04
10@010@400H61P802@T900000`0410@01@D500D51@0300<30`<02@T900<00@410000000000000`01
0@4010020P800`<300<30`071`L300@410801@D500@00@4100L71`071`L03Ph>0P092@T0100;2`/0
2PX:00X:2P071`L200820P0400L71`061PH01PH600H61P800`<300<01PH600@4100410@00`030`<0
100820P01PH600H61P0:2PX200P8200400@410030`<00`<300L71`801PH600@00P8200@4100410@0
1PH60P010@40100000008B4Q024Q8@0T92@201LG5`04030`<014A4@0A4A405iNGP80HF5Q00@0JVYZ
055AD@1ADE40?Cdm0P16ATH0100U9BD0>3Ph03Ph>01>CTh202HV9P0402d];@0Q8B408B4Q00000080
3`l?00@05ADE01@D500D51@0410@0P0E5AD300h>3P04010@400B4Q804Q8B01dM7@801PH600@0410@
02l_;`0_;bl0?Shn0P0b<S80100d=3@0DE5A055AD@1:BTX205YJFP0405UIF@1ZJVX0JVYZ07EeM@80
IVIV0`1`L700101WIfL0Hf=S06=SH`1XJ6P207UiN@040492@P000000000000820P8030`<00@0<C4a
05=CD`1CDe<0B4Q80P1>CTh0101HF5P0KFe]06e]K@1[Jf/206e]K@0306a/K01IFET0FEUI00<0Fe]K
00@0IfMW05mOG`1OGel0F5QH0P1IFET0101HF5P0G5aL05aLG01WIfL206e]K@0406IVIP1TI6@0I6AT
06a/K0<0Jf][0P1/K6`0101VIVH0I6AT06ATI01NGUh205eMG@0405YJFP1KFe/0Fe]K05YJFP80I6AT
00@0EEEE0451@@11@D40D51@0P1=CDd0101OGel0Hf=S06=SH`1LG5`205iNGP0406=SH`1QHF40HF5Q
055AD@80A4A400@0ADE504Q8B018B4P0ADE50P10@400100/;2`0410@010@400;2`/200D51@0400P8
200R8R808R8R06ATI080FUYJ00@0E5AD05YJFP1JFUX0DE5A0P17AdL303/k>`0404];B`1?Cdl0Cdm?
05=CD`80EeMG00@0H61P05UIF@1IFET0FUYJ0P1QHF40101NGUh0Fe]K05]KF`1OGel205iNGP0405=C
D`1JFUX0FUYJ06i^KP80Jf][00@0HF5Q07YjNP1jNWX0OWin0P1^KVh0101_Kfl0MgMg07MgM`1jNWX3
07EeM@80LW9b00@0MWIf07UiN@1iNGT0OWin0P1iNGT0101OGel0F5QH05QHF01GEeL204I6AP040451
@@14A4@0A4A404U9B@<0DE5A0P1PH6001022PX80Ti>C09>CT`2@T90209FEU@040:2PX02OWil0WinO
09BDU080T92@00@0TY:B08V9R@29RHT0MWIf0P22PX80102QXJ40Vi^K09^KV`2MWId20:^[Z`040:FU
Y@2IVIT0VIVI0:2PX080WYjN00@0YZJV0:VYZ@2YZJT0ZZZZ0P2EUID0102LW9`0Xj>S0:>SX`2PX:02
0:NWY`040;Rh^02i^KT0^KVi0:b/[080W9bL00@0Jf][05]KF`1KFe/0@T920P0Z:RX0100P82007AdM
01dM7@0C4a<201@D500402PX:00b<S80<S8b03<c<`80;Bd]100W9bL202PX:00402HV9P0S8b<08b<S
01`L70803Ph>00@010@40000000000001`L70P0:2PX0000300@410051@D01@D500<00`<30`092@T0
0`010@4000000000000300410@0400820P030`<00`<300L71`<010@40P051@D010010@401`L700L7
1`0>3Ph200T92@0400/;2`0:2PX02PX:00L71`800P8200@01`L700H61P061PH01PH60P030`<00`06
1PH010@400@4100300<30`0400P820061PH01PH600X:2P8020P800@010@400<30`030`<01`L70P06
1PH010020P8010@400@410061PH200410@040000000Q8B408B4Q02@T90805aLG00@0<30`04A4A014
A4@0GUiN0P1QHF40101ZJVX0DE5A055AD@0m?Cd204I6AP0402DU9@0h>3P0>3Ph04i>CP809RHV00@0
;Bd]024Q8@0Q8B4000000P0?3`l0100E5AD051@D01@D500@410201DE5@<03Ph>00@0410@018B4P0B
4Q807AdM0P061PH0100@4100;bl_02l_;`0n?Sh2038b<P0403@d=01ADE40DE5A04Y:BP80FUYJ00@0
FEUI06YZJP1ZJVX0MGEe0P1VIVH3071`L00406MWI`1SHf<0Hf=S06QXJ080NGUi00@0@T9200000000
00000P820P0<30`0100a<C40De=C05=CD`18B4P204i>CP0405QHF01]KFd0KFe]06][J`80KFe]00<0
K6a/05UIF@1IFET00`1KFe/0101WIfL0GemO05mOG`1HF5P205UIF@0405QHF01LG5`0G5aL06MWI`80
KFe]00@0IVIV06ATI01TI6@0K6a/0`1[Jf/206a/K00406IVIP1TI6@0I6AT05iNGP80GEeM00@0FUYJ
05]KF`1KFe/0FUYJ0P1TI6@0101EEED0@D510451@@1@D50204e=C@0405mOG`1SHf<0Hf=S05aLG080
GUiN00@0Hf=S065QH@1QHF40DE5A0P14A4@01015ADD0B4Q804Q8B015ADD20410@00402`/;00@4100
410@00/;2`801@D500@020P8028R8P0R8R80I6AT0P1JFUX0101DE5@0FUYJ05YJFP1ADE4204M7A`<0
>c/k00@0Bd];04m?C`1?Cdl0De=C0P1GEeL0101PH600FEUI05UIF@1JFUX2065QH@0405iNGP1KFe/0
Fe]K05mOG`80GUiN00@0De=C05YJFP1JFUX0KVi^0P1[Jf/0101QHF40NWYj07YjNP1nOWh206i^KP04
06m_K`1gMgL0MgMg07YjNP<0MGEe0P1bLW80101fMWH0NGUi07UiN@1nOWh207UiN@0405mOG`1HF5P0
F5QH05MGE`80ATI600@0@D5104A4A014A4@0BDU90`1ADE42061PH00408:2PP2CTi<0Ti>C092@T080
UIFE00@0X:2P09nOW`2OWil0U9BD0P2@T900102BTY80RHV908V9R@1fMWH208:2PP040:6QX@2KVi/0
Vi^K09fMW@80Zj^[00@0YJFU09VIV@2IVIT0X:2P0P2NWYh0102VYZH0ZJVY0:VYZ@2ZZZX209FEU@04
09bLW02SXj<0Xj>S0:2PX080YjNW00@0^;Rh0;Vi^@2i^KT0[:b/0P2LW9`0101[Jf/0Fe]K05]KF`12
@T8202XZ:P04020P800M7Ad07AdM01<C4`8051@D00@0:2PX038b<P0b<S80<c<c0P0];Bd402LW9`80
:2PX00@09RHV02<S8`0S8b<071`L0P0>3Ph0100410@00000000000071`L200X:2P0000@010@40082
0P020P8010@40P0:2PX0100820P00`<300<30`0410@200<30`0400820P0820P020P800H61P802PX:
00@04a<C00L71`071`L000000P061PH300D51@<00`<300@010@400<30`030`<01PH60P051@D01003
0`<01`L700L71`0820P200@41004000000010@400@4100@410800P8200@01PH600X:2P0:2PX02@T9
0P0;2`/0100:2PX01`L700L71`0410@200L71`0400<30`020P800P8200410@800`<300@0000001`L
700L71`07alO0P0:2PX0100Y:BT0A4A404A4A01HF5P206e]K@0407emO@1jNWX0NWYj05IFEP80Fe]K
00@0Bd];02LW9`0W9bL0=CDe0P0l?3`0100j>SX08b<S02<S8`00000200<30`04014A4@0G5aL05aLG
00`<30<03Ph>0P0;2`/010071`L04A4A014A4@0K6a/200h>3P0400L71`0G5aL05aLG02d];@80=SHf
00@0?clo05EEE@1EEED0EUIF0P1RHV80101QHF40K6a/06a/K01aLG4206MWI`0406IVIP1RHV80HV9R
069RHP80Hf=S00@0IfMW079bLP1bLW80@4100P00000010071`L03Ph>00h>3P0R8R820410@00404I6
AP1LG5`0G5aL069RHP<0GUiN0P1JFUX305]KF`<0Kfm_00@0JVYZ06][J`1[Jf/0KFe]0P1MGEd00`1D
E5@0I6AT06ATI00306QXJ00407AdM01aLG40LG5a06EUI@80GemO00@0I6AT06m_K`1_Kfl0KFe]0P1V
IVH0101XJ6P0IVIV06IVIP1JFUX2051@D00405UIF@1QHF40HF5Q055AD@80ATI600@0Bd];05ADE01D
E5@0Kfm_0P1XJ6P0101HF5P0Hf=S06=SH`1PH60205EEE@0404i>CP13@d<0@d=303Lg=`80>SXj00@0
Bd];0410@010@4007QhN0P071`L010092@T01@D500D51@0@410202PX:00406e]K@1WIfL0IfMW04m?
C`80De=C00@0E5AD04Y:BP1:BTX0?Shn0P16ATH0101;Bd/0@4100410@01BDU8205mOG`0404i>CP1;
Bd/0Bd];05eMG@80HF5Q00@0Fe]K05YJFP1JFUX0EEEE0P1DE5@0101IFET0HF5Q065QH@1aLG4306AT
I080OWin00@0MWIf06YZJP1ZJVX0IFEU0P1fMWH0101jNWX0MGEe07EeM@1fMWH207AdM00407=cL`1i
NGT0NGUi07moO`80Kfm_00@0Fe]K05=CD`1CDe<0Bd];0P0h>3P0100a<C40=cLg03Lg=`13@d<2059B
DP0405MGE`1RHV80HV9R07inOP80U9BD00@0Ti>C08j>SP2>SXh0UYJF0P2NWYh0102LW9`0Shn?08n?
S`2?Shl208j>SP040820P02@T900T92@0:6QX@<0W9bL0P2KVi/0102NWYh0UiNG09NGU`2<S8`2092@
T0040:>SX`2RXZ80XZ:R0:>SX`80X:2P0`2ZZZX00`2FUYH0XJ6Q0:6QX@030;Jf]P040:2PX028R8P0
R8R807YjNP80MGEe00@0CTi>02HV9P0V9RH06QXJ0P0G5aL0100C4a<07QhN01hN7P0_;bl202h^;P04
02XZ:P0b<S80<S8b03Ti>@80=SHf00@0<S8b030`<00`<300<30`0P0/;2`0100D51@02`/;00/;2`0<
30`200@410<00P82000010030`<01@D500D51@051@D200P820<00`<30`061PH010020P802@T900T9
2@0:2PX200D51@0400T92@071`L01`L700820P801@D500<00P820000000000000`051@D00`000000
10@400@4100300P8200400D51@061PH01PH600D51@8010@400@00`<300H61P061PH00`<30P020P80
10051@D010@400@410071`L200/;2`0400@410020P800P8200410@800`<300@0000000H61P061PH0
10@40P030`<010010@405aLG01LG5`0Y:BT200l?3`0401lO7`1CDe<0De=C06IVIP80G5aL00@0HF5Q
07]kN`1kNg/0K6a/0P1`L700101[Jf/0;Rh^02h^;P0X:2P204=3@`0303`l?00V9RH09RHV00<030`<
00@05QHF01XJ6P0J6QX04Q8B0P0:2PX0100D51@03`l?00l?3`0820P2014A4@0301`L700K6a/06a/K
00<03Ph>00@07alO03Lg=`0g=cL0C4a<0P1VIVH0101OGel0J6QX06QXJ01_Kfl206e]K@0406YZJP1R
HV80HV9R05iNGP80J6QX00@0MGEe06a/K01/K6`0I6AT0P1WIfL0100h>3P000000000000;2`/201DE
5@0401XJ6P0c<c<0<c<c03Xj>P80DE5A00@0Hf=S05aLG01LG5`0IFEU0P1MGEd0101LG5`0D51@051@
D01PH602069RHP0405MGE`1LG5`0G5aL05aLG080E5AD00@0De=C06EUI@1UIFD0L71`0P1_Kfl0101]
KFd0J6QX06QXJ01XJ6P206][J`04061PH01OGel0GemO06=SH`80G5aL00@0Hf=S06UYJ@1YJFT0F5QH
0P1:BTX0101@D500FUYJ05YJFP1IFET2055AD@0405EEE@1OGel0GemO06QXJ080IFEU00@0EeMG05IF
EP1FEUH0E5AD0P1EEED0101ADE40Cdm?04m?C`1>CTh204M7A`0404U9B@0l?3`0?3`l01XJ6P801PH6
00@030`<00/;2`0;2`/051@D0P0/;2`0101[Jf/0JFUY06UYJ@1LG5`2055AD@04059BDP1DE5@0E5AD
0410@080AdM700@0A4A403hn?P0n?Sh0FUYJ0P1WIfL0101>CTh0BDU904U9B@1LG5`205eMG@0405EE
E@1CDe<0De=C04U9B@80C4a<00@0H61P06UYJ@1YJFT0M7Ad0P1VIVH0101]KFd0N7Qh07QhN01`L702
07AdM00406QXJ01aLG40LG5a079bLP80Kfm_00@0Jf][06i^KP1^KVh0L71`0P1mOGd01020P800GemO
05mOG`1BDU8204U9B@0403Ph>00d=3@0=3@d03hn?P80B4Q800@0CDe=04];B`1;Bd/0Cdm?0P1NGUh0
101mOGd0VIVI09VIV@2EUID208n?S`0409VIV@2JVYX0VYZJ092@T080RXZ:00@0Shn?0861P@21PH40
Ng]k0P2JVYX30:FUY@0409nOW`2NWYh0WYjN0::RXP80WinO00@0UIFE09BDU02DU9@0WIfM0P2UYJD0
102XZ:P0/K6a0;6a/@2c/k<209jNWP0408f=S@2YZJT0ZJVY0;Bd]080/k>c00@0]KFe0;Jf]P2f][H0
Y:BT0P22PX80101IFET0:b/[02/[:`0D51@201LG5`0401XJ6P0L71`071`L02HV9P<0;2`/0P0c<c<0
100h>3P0>SXj03Xj>P0j>SX303@d=080<C4a00@05QHF00X:2P0:2PX02`/;0`010@420000000000@0
0`<300D51@051@D01@D50P0820P300<30`<01PH600@00P8200T92@092@T02PX:0P051@D010092@T0
1`L700L71`020P8200D51@0300820P000000000000<01@D500<0000000@4100410@00`0820P01005
1@D01PH600H61P051@D200@4100400<30`061PH01PH600<30`800P8200@01@D500@4100410@01`L7
0P0;2`/0100410@00P8200820P010@4200<30`04000000061PH01PH600@410800`<300@00@4101LG
5`0G5aL0:BTY0P0?3`l0100O7al0De=C05=CD`1VIVH205aLG004065QH@1kNg/0Ng]k06a/K080L71`
00@0Jf][02h^;P0^;Rh0:2PX0P13@d<00`0l?3`09RHV02HV9P0300`<300401HF5P0J6QX06QXJ018B
4P802PX:00@051@D00l?3`0?3`l020P80P0A4A400`0L71`06a/K01/K6`0300h>3P0401lO7`0g=cL0
=cLg04a<C080IVIV00@0GemO06QXJ01XJ6P0Kfm_0P1]KFd0101ZJVX0HV9R069RHP1NGUh206QXJ004
07EeM@1/K6`0K6a/06ATI080IfMW00@0>3Ph0000000000002`/;0P0E5AD0100J6QX0<c<c03<c<`0j
>SX2055AD@0406=SH`1LG5`0G5aL06EUI@80GEeM00@0G5aL051@D01@D500H61P0P1RHV80101GEeL0
G5aL05aLG01LG5`205ADE00405=CD`1UIFD0IFEU071`L080Kfm_00@0KFe]06QXJ01XJ6P0J6QX0P1[
Jf/0101PH600GemO05mOG`1SHf<205aLG00406=SH`1YJFT0JFUY05QHF080BTY:00@0D51@05YJFP1J
FUX0FEUI0P1ADE40101EEED0GemO05mOG`1XJ6P206EUI@0405MGE`1FEUH0EUIF05ADE080EEEE00@0
DE5A04m?C`1?Cdl0CTi>0P17AdL01019BDT0?3`l03`l?00J6QX200H61P0400`<300;2`/02`/;01@D
5080;2`/00@0Jf][06UYJ@1YJFT0G5aL0P1ADE40101BDU80E5AD05ADE010@40204M7A`0404A4A00n
?Sh0?Shn05YJFP80IfMW00@0CTi>04U9B@19BDT0G5aL0P1MGEd0101EEED0De=C05=CD`19BDT204a<
C004061PH01YJFT0JFUY07AdM080IVIV00@0KFe]07QhN01hN7P0L71`0P1dM7@0101XJ6P0LG5a075a
L@1bLW8206m_K`0406][J`1^KVh0KVi^071`L080OGem00@0P82005mOG`1OGel0DU9B0P19BDT0100h
>3P0=3@d03@d=00n?Sh204Q8B00404e=C@1;Bd/0Bd];04m?C`80GUiN00@0OGem09VIV@2IVIT0UIFE
0P2?Shl0102IVIT0VYZJ09ZJVP2@T90208Z:RP0408n?S`21PH40PH6107]kN`80VYZJ0`2UYJD0102O
Wil0WYjN09jNWP2RXZ8209nOW`0409FEU@2DU9@0U9BD09fMW@80YJFU00@0Z:RX0;6a/@2a/K40/k>c
0P2NWYh0102=SHd0ZJVY0:VYZ@2d];@20;>c/`040;Fe]@2f][H0][Jf0:BTY080PX:200@0FEUI02/[
:`0[:b/051@D0P0G5aL0100J6QX071`L01`L700V9RH302`/;080<c<c00@0>3Ph03Xj>P0j>SX0>SXj
0`0d=3@2034a<@0401HF5P0:2PX02PX:00/;2`<00@410P000000000400820P092@T02@T900D51@80
000000@00P8200P8200820P01@D50P030`<010071`L030`<00`<300:2PX200<30`0400@410071`L0
1`L700L71`800@4100@00`<300@4100410@01@D50P071`L00`051@D010@400@4100300L71`<01@D5
00@00`<300T92@092@T03`l?0P0B4Q80100>3Ph01@D500D51@020P820000000400D51@092@T02@T9
000000801PH600@010@400H61P061PH03@d=0P0820P010030`<01@D500D51@030`<200`<300401dM
7@0B4Q804Q8B014A4@80?Cdm00@0L71`06][J`1[Jf/0FUYJ0P1`L700101fMWH0LW9b079bLP1cLg<2
04Y:BP0402DU9@0^;Rh0;Rh^03hn?P80?Cdm00@07alO00P8200820P03`l?0P0A4A40100I6AT04A4A
014A4@0D51@300h>3P803@d=00@02@T900l?3`0?3`l02@T90P0820P0100K6a/0<30`030`<01>CTh2
06][J`04069RHP1PH600H61P06a/K080IVIV00@0J6QX06m_K`1_Kfl0Kfm_0P1eMGD00`1gMgL0JFUY
06UYJ@0306MWI`0403@d=0000000000000T92@802`/;00@06a/K04I6AP16ATH0@4100P15ADD0101J
FUX0F5QH05QHF01KFe/204e=C@0406EUI@1@D500D51@04m?C`80H61P00@0DE5A04m?C`1?Cdl0F5QH
0P1MGEd0101KFe/0IFEU06EUI@1eMGD2071`L0<0J6QX00@0IfMW06][J`1[Jf/0J6QX0P1[Jf/0101/
K6`0GUiN05iNGP1UIFD206i^KP<0C4a<00@0ADE504U9B@19BDT0GUiN0P1:BTX0101?Cdl0I6AT06AT
I01XJ6P2079bLP0406IVIP1@D500D51@04m?C`80HF5Q00@0H61P051@D01@D500BTY:0P19BDT01013
@d<0<S8b038b<P0B4Q8200410@0400L71`051@D01@D501DE5@80;2`/00@0HV9R065QH@1QHF40D51@
0P16ATH01017AdL0ADE504E5A@0l?3`20410@00404=3@`1=CDd0CDe=05aLG080Fe]K00@0Cdm?051@
D01@D500GemO0P1SHf<0101HF5P0BTY:04Y:BP11@D4204Q8B00405IFEP1VIVH0IVIV06QXJ080HV9R
00@0L71`07=cL`1cLg<0K6a/0P1eMGD0101cLg<0L71`071`L01bLW82075aL@04069RHP1aLG40LG5a
07IfMP80MGEe00@0Lg=c05eMG@1MGEd0EEEE0P13@d<0100f=SH0@4100410@016ATH204a<C00404m?
C`15ADD0ADE504a<C080HF5Q00@0OGem09RHV02HV9P0Shn?0P27QhL0102EUID0Shn?08n?S`23Ph<2
08R8R00408j>SP1iNGT0NGUi07UiN@80WIfM00@0XZ:R0:BTY02TY:@0XZ:R0P2VYZH0102SXj<0WYjN
09jNWP2LW9`209JFUP0408Z:RP2IVIT0VIVI0;6a/@80_[jn00@0/[:b09fMW@2MWId0UYJF0P2_[jl0
102e]KD0_;bl0;bl_030`<020<C4a0040:^[Z`1kNg/0Ng]k05iNGP80@D5100@092@T01LG5`0G5aL0
5aLG0P0P8200100`<300>3Ph03Ph>00d=3@203<c<`04030`<00k>c/0>c/k0492@P80?Cdm00@0@410
03De=@0e=CD06QXJ0P0;2`/010051@D010@400@410061PH200<30`0000@00`<300@4100410@00@41
0`030`<200L71`<01@D500@01PH600P8200820P010@40P061PH300P8200400L71`0410@010@400P8
20802`/;00@020P800<30`030`<010@40P0820P00`030`<000000000000300L71`0400410@0410@0
10@400T92@<01`L70P0820P00`020P8020P800P8200300<30`0400410@051@D01@D500P820801PH6
00@030`<00L71`071`L00P820P051@D010061PH03Ph>00h>3P0W9bL201HF5P04028R8P0o?cl0?clo
06EUI@80N7Qh00@0H61P06IVIP1VIVH0OGem0P1_Kfl0101/K6`0JFUY06UYJ@0l?3`202TY:@0403Ph
>01;Bd/0Bd];030`<0800@4100@02@T901XJ6P0J6QX08B4Q0P0F5QH0100?3`l03Ph>00h>3P0:2PX2
00`<300400L71`0C4a<04a<C00P820800P8200@0410@01TI6@0I6AT0@d=30P1RHV80101PH600Fe]K
05]KF`1_Kfl206i^KP04065QH@1MGEd0GEeM06YZJP80KVi^00@0I6AT06EUI@1UIFD0JVYZ0P1UIFD0
100l?3`02PX:00X:2P071`L200T92@0401LG5`10@400@41003lo?`80@41000@0GemO06][J`1[Jf/0
Jf][0P1SHf<0101`L700K6a/06a/K01OGel305eMG@80G5aL00@0KFe]071`L01`L700H61P0P1HF5P0
101SHf<0HF5Q065QH@1VIVH2071`L00306UYJ@1XJ6P0J6QX00<0JFUY00@0J6QX065QH@1QHF40Hf=S
0P1PH6001015ADD0G5aL05aLG01IFET204A4A00404m?C`0d=3@0=3@d03`l?080FEUI00@0J6QX06][
J`1[Jf/0DE5A0P14A4@0101IFET0G5aL05aLG01DE5@204A4A004030`<00j>SX0>SXj04E5A@80<30`
00@051@D00L71`071`L020P80P0?3`l0100H61P0;Rh^02h^;P1?Cdl205EEE@0404=3@`0i>CT0>CTi
0410@080@D5100@0BTY:0410@010@400>3Ph0P1MGEd0101VIVH0EUIF05IFEP1CDe<205aLG004065Q
H@1LG5`0G5aL05=CD`80ATI600@0@T9204Y:BP1:BTX0EeMG0P1TI6@0101JFUX0HF5Q065QH@1[Jf/2
06QXJ00406a/K01YJFT0JFUY079bLP80Kfm_00@0Jf][071`L01`L700GemO0P1UIFD0101[Jf/0J6QX
06QXJ01SHf<205aLG004065QH@1EEED0EEEE04U9B@80A4A400@0?clo04M7A`17AdL0Cdm?0P1=CDd0
101JFUX0IfMW06MWI`1_Kfl208N7Q`0408^;R`25QHD0QHF508Z:RP80PH6100@0OWin08b<S02<S8`0
UYJF0P24Q8@01021PH40Z:RX0:RXZ02RXZ8209RHV00409ZJVP2PX:00X:2P09fMW@80XJ6Q0`2NWYh0
102>SXh0S8b<08b<S02[Zj/20;Fe]@040:b/[02^[Zh0[Zj^0:NWY`80YZJV00@0/K6a0<S8b038b<P0
bl_;0P30`<00102^[Zh0P8200820P01JFUX204U9B@04034a<@0G5aL05aLG01HF5P8092@T00@0;bl_
03@d=00d=3@0=CDe0P0j>SX0100^;Rh0>CTi03Ti>@13@d<203dm?@040492@P0e=CD0=CDe01LG5`80
3@d=00@00P8200`<300<30`01PH60P020P80000400<30`0410@010@400410@<00`<30P071`L300D5
1@0400H61P0820P020P800@410801PH60`0820P010071`L010@400@4100820P200/;2`0400P82003
0`<00`<300@4108020P800<00`<30000000000000`071`L010010@4010@400@410092@T300L71`80
20P800<00P8200P8200820P00`030`<010010@401@D500D51@0820P200H61P0400`<30071`L01`L7
00820P801@D500@01PH600h>3P0>3Ph09bLW0P0F5QH0100R8R80?clo03lo?`1UIFD207QhN004061P
H01VIVH0IVIV07emO@80Kfm_00@0K6a/06UYJ@1YJFT0?3`l0P0Y:BT0100h>3P0Bd];04];B`0`<302
00410@0400T92@0J6QX06QXJ024Q8@805QHF00@03`l?00h>3P0>3Ph02PX:0P0<30`010071`L04a<C
01<C4`0820P200820P04010@400I6AT06ATI04=3@`80HV9R00@0H61P05]KF`1KFe/0Kfm_0P1^KVh0
101QHF40GEeM05eMG@1ZJVX206i^KP0406ATI01UIFD0IFEU06YZJP80IFEU00@0?3`l00X:2P0:2PX0
1`L70P092@T0100G5aL0@4100410@00o?cl20410@00405mOG`1[Jf/0Jf][06][J`80Hf=S00@0L71`
06a/K01/K6`0GemO0`1MGEd205aLG00406e]K@1`L700L71`061PH080F5QH00@0Hf=S065QH@1QHF40
IVIV0P1`L7000`1YJFT0J6QX06QXJ00306UYJ@0406QXJ01QHF40HF5Q06=SH`80H61P00@0ADE505aL
G01LG5`0FEUI0P14A4@0101?Cdl0=3@d03@d=00l?3`205UIF@0406QXJ01[Jf/0Jf][055AD@80A4A4
00@0FEUI05aLG01LG5`0E5AD0P14A4@0100`<300>SXj03Xj>P15ADD2030`<00401@D50071`L01`L7
00P820803`l?00@061PH02h^;P0^;Rh0Cdm?0P1EEED01013@d<0>CTi03Ti>@10@4020451@@0404Y:
BP10@400@41003Ph>080GEeM00@0IVIV05IFEP1FEUH0De=C0P1LG5`0101QHF40G5aL05aLG01CDe<2
04I6AP040492@P1:BTX0BTY:05MGE`80I6AT00@0FUYJ065QH@1QHF40Jf][0P1XJ6P0101/K6`0JFUY
06UYJ@1bLW8206m_K`0406][J`1`L700L71`05mOG`80IFEU00@0Jf][06QXJ01XJ6P0Hf=S0P1LG5`0
101QHF40EEEE05EEE@19BDT204A4A00403lo?`17AdL0AdM704m?C`80CDe=00@0FUYJ06MWI`1WIfL0
Kfm_0P27QhL0102;Rh/0QHF508F5Q@2:RXX20861P@0407inOP2<S8`0S8b<09JFUP80Q8B400@0PH61
0:RXZ02XZ:P0XZ:R0P2HV9P0102JVYX0X:2P0:2PX02MWId20:6QX@<0WYjN00@0SXj>08b<S02<S8`0
Zj^[0P2e]KD0102/[:`0[Zj^0:j^[P2WYjL20:JVYP040;6a/@38b<P0b<S80<_;b`80`<3000@0[Zj^
0820P020P800FUYJ0P19BDT0100a<C405aLG01LG5`0F5QH202@T900402l_;`0d=3@0=3@d03De=@80
>SXj00@0;Rh^03Ti>@0i>CT0@d=30P0m?Cd01012@T80=CDe03De=@0G5aL200d=3@0400820P0<30`0
30`<00H61P800P8200000`071`L00@4100410@0300<30`0400410@051@D01@D500X:2P8010@41008
20P200T92@0400L71`0820P020P800@410<01PH60P0;2`/010071`L00`<300<30`061PH200<30`04
00@410051@D01@D500820P8010@40`071`L010051@D010@400@410030`<200820P0400H61P092@T0
2@T900820P800@410`0410@010061PH01@D500D51@051@D200H61P0400820P061PH01PH600D51@80
1`L700@09BDU01/K6`0K6a/04Q8B0P12@T80101WIfL0M7Ad07AdM01^KVh206][J`0407alO01jNWX0
NWYj07UiN@80MgMg00@0BTY:02h^;P0^;Rh0<S8b0P1<C4`0100l?3`02@T900T92@0=3@d2028R8P04
024Q8@0L71`071`L014A4@803Ph>00@02PX:00d=3@0=3@d01PH60P0E5AD00`0C4a<02@T900T92@03
00/;2`0303Ti>@1GEeL0EeMG00<0FEUI00@0Kfm_075aL@1aLG40J6QX0P1ADE40101GEeL0HV9R069R
HP1JFUX2065QH@0406=SH`1HF5P0F5QH03Lg=`<020P80P0:2PX0100B4Q80@4100410@011@D4203<c
<`0405UIF@1/K6`0K6a/06IVIP80MgMg00@0Jf][06EUI@1UIFD0De=C0P1ADE40101SHf<0I6AT06AT
I01RHV82061PH00406EUI@1SHf<0Hf=S06QXJ080HV9R00@0Fe]K06=SH`1SHf<0Hf=S0P1WIfL0101V
IVH0Fe]K05]KF`1SHf<206MWI`0406][J`1VIVH0IVIV04a<C080CDe=00<0FEUI04A4A014A4@00`1;
Bd/0101=CDd0Cdm?04m?C`1KFe/205YJFP0404I6AP14A4@0A4A405QHF080DU9B00@0@D5103hn?P0n
?Sh0<C4a0P0h>3P01019BDT0>3Ph03Ph>00M7Ad200<30`04010@400E5AD05ADE01<C4`80=SHf00@0
DE5A04e=C@1=CDd0=cLg0P0[:b/0100g=cL0@d=304=3@`1<C4`20451@@0403<c<`1=CDd0CDe=05]K
F`80DE5A00@0Cdm?05]KF`1KFe/0FUYJ0P16ATH0100n?Sh0@D510451@@1<C4`205=CD`04065QH@1P
H600H61P04a<C080Hf=S00@0JFUY069RHP1RHV80LG5a0`1WIfL206i^KP0306IVIP1SHf<0Hf=S00<0
HF5Q00@0HV9R05mOG`1OGel0GEeM0P1LG5`0101OGel0CTi>04i>CP11@D420410@0040492@P1:BTX0
BTY:04a<C080DU9B0`1JFUX0101]KFd0QHF508F5Q@28R8P208>3P`0407alO01jNWX0NWYj08F5Q@80
T92@00@0RXZ:0820P020P800Ng]k0P2IVIT0102LW9`0T92@092@T02HV9P20:NWY`0409bLW02IVIT0
VIVI09NGU`80YJFU00@0SHf=079bLP1bLW80VYZJ0P2][Jd0102WYjL0Y:BT0:BTY02?Shl209>CT`04
0;Jf]P3@d=00d=3@0<W9b@80];Bd00@0Zj^[08^;R`2;Rh/0GemO0P1:BTX0100b<S805aLG01LG5`0C
4a<201`L7004030`<00o?cl0?clo03hn?P80@41000@0<30`03Hf=P0f=SH0@d=30P10@4001014A4@0
>3Ph03Ph>00E5AD200T92@0300@410061PH01PH600<01PH6000010030`<01`L700L71`061PH20082
0P<010@400@01@D500410@010@4010@40P061PH0100820P02`/;00/;2`071`L200@4100300<30`02
0P800P8200<01PH600@00`<300H61P061PH01@D50P00000010061PH020P800P820010@4200000004
00D51@0820P020P800D51@801PH600@020P800820P020P8000000P030`<300@4100400T92@0;2`/0
2`/;0000008010@400<00`<300P8200820P00`0410@010092@T000000000000M7Ad202`/;00400`<
300U9BD09BDU05ADE080GUiN00<0KFe]07=cL`1cLg<00`1jNWX307UiN@0405iNGP0o?cl0?clo0492
@P80Cdm?00@0?Shn01TI6@0I6AT051@D0P0G5aL0100D51@0820P020P800D51@200H61P0400L71`05
1@D01@D500<30`805ADE00<061PH00`<300<30`00`0@4100100f=SH0FUYJ05YJFP1KFe/205QHF004
06YZJP1^KVh0KVi^079bLP80EUIF00@0Bd];05iNGP1NGUh0GUiN0P1TI6@0101NGUh0DU9B059BDP0d
=3@200D51@0400L71`0>3Ph03Ph>01@D5080>SXj00@0>c/k03`l?00l?3`0EUIF0P1LG5`0101CDe<0
KVi^06i^KP1_Kfl206=SH`0405ADE01RHV80HV9R06IVIP80I6AT00@0G5aL05ADE01DE5@0JFUY0P1b
LW80101`L700IVIV06IVIP1QHF4206QXJ00405mOG`1IFET0FEUI061PH080IfMW00@0L71`06=SH`1S
Hf<0Jf][0P1^KVh0101@D500BDU904U9B@1BDU8203Ti>@0404I6AP1OGel0GemO05MGE`80CDe=00@0
EUIF05ADE01DE5@0CDe=0P11@D40100o?cl0Bd];04];B`13@d<203Ph>0<0>CTi00@0@D5103Lg=`0g
=cL08B4Q0P051@D0100>3Ph04A4A014A4@0C4a<203lo?`0404i>CP14A4@0A4A402TY:@809bLW00@0
>c/k0492@P12@T80?Cdm0P0V9RH0100R8R80?Cdm03dm?@1@D50304a<C080EUIF00@0DU9B04U9B@19
BDT0ADE50P1>CTh0101RHV80F5QH05QHF01@D50205IFEP0405=CD`1YJFT0JFUY06e]K@80JFUY00@0
KVi^06EUI@1UIFD0GUiN0`1TI6@2069RHP0406ATI01SHf<0Hf=S061PH080HF5Q00@0IfMW06IVIP1V
IVH0GemO0P19BDT0100l?3`0@4100410@018B4P204e=C@0404A4A01:BTX0BTY:05QHF080EUIF00@0
J6QX07]kN`1kNg/0Ogmo0P1mOGd0101iNGT0PH610861P@28R8P208V9R@040820P01iNGT0NGUi07Ee
M@80T92@00@0V9RH08b<S02<S8`0Ti>C0P2OWil0102ATI40Shn?08n?S`2BTY820:>SX`0409FEU@1_
Kfl0Kfm_08Z:RP80ZJVY00@0YJFU09bLW02LW9`0QHF50P26QXH0102YZJT0`L710<71`@30`<020;>c
/`040::RXP1kNg/0Ng]k05aLG080E5AD00<0>SXj024Q8@0Q8B400`0H61P0100e=CD0BTY:04Y:BP13
@d<204A4A00403hn?P10@400@41003hn?P80?3`l00@0@d=303`l?00l?3`07AdM0P0H61P0100?3`l0
1@D500D51@0<30`200D51@0000@00`<300L71`071`L01PH60P020P8300@4100400D51@010@400@41
00@410801PH600@020P800/;2`0;2`/01`L70P0410@00`030`<00P8200820P0300H61P0400<30`06
1PH01PH600D51@80000000@01PH600P8200820P00@410P00000010051@D020P800P820051@D200H6
1P0400P820020P800P82000000800`<30`0410@010092@T02`/;00/;2`00000200@4100300<30`08
20P020P800<010@400@02@T90000000000007AdM0P0/;2`0100<30`09BDU02DU9@1DE5@205iNGP03
06e]K@1cLg<0Lg=c00<0NWYj0`1iNGT0101NGUh0?clo03lo?`12@T8204m?C`0403hn?P0I6AT06ATI
01@D50805aLG00@051@D020P800P820051@D0P061PH010071`L01@D500D51@030`<201DE5@0301PH
600<30`030`<00<0410@00@0=SHf05YJFP1JFUX0Fe]K0P1HF5P0101ZJVX0KVi^06i^KP1bLW8205IF
EP0404];B`1NGUh0GUiN05iNGP80I6AT00@0GUiN059BDP1BDU80=3@d0P051@D010071`L03Ph>00h>
3P0D51@203Xj>P0403/k>`0l?3`0?3`l05IFEP80G5aL00@0De=C06i^KP1^KVh0Kfm_0P1SHf<0101D
E5@0HV9R069RHP1VIVH206ATI00405aLG01DE5@0E5AD06UYJ@80LW9b00@0L71`06IVIP1VIVH0HF5Q
0P1XJ6P0101OGel0FEUI05UIF@1PH60206MWI`04071`L01SHf<0Hf=S06][J`80KVi^00@0D51@04U9
B@19BDT0DU9B0P0i>CT01016ATH0GemO05mOG`1GEeL204e=C@0405IFEP1DE5@0E5AD04e=C@80@D51
00@0?clo04];B`1;Bd/0@d=30P0h>3P303Ti>@040451@@0g=cL0=cLg024Q8@801@D500@03Ph>014A
4@0A4A404a<C0P0o?cl0101>CTh0A4A404A4A00Y:BT202LW9`0403/k>`12@T80@T9203dm?@809RHV
00@08R8R03dm?@0m?Cd0D51@0`1<C4`205IFEP04059BDP19BDT0BDU904E5A@80CTi>00@0HV9R05QH
F01HF5P0D51@0P1FEUH0101CDe<0JFUY06UYJ@1]KFd206UYJ@0406i^KP1UIFD0IFEU05iNGP<0I6AT
0P1RHV80101TI6@0Hf=S06=SH`1PH602065QH@0406MWI`1VIVH0IVIV05mOG`80BDU900@0?3`l0410
@010@400B4Q80P1=CDd01014A4@0BTY:04Y:BP1HF5P205IFEP0406QXJ01kNg/0Ng]k07moO`80OGem
00@0NGUi0861P@21PH40R8R80P29RHT01020P800NGUi07UiN@1eMGD2092@T00409RHV02<S8`0S8b<
09>CT`80WinO00@0TI6A08n?S`2?Shl0TY:B0P2SXj<0102EUID0Kfm_06m_K`2:RXX20:VYZ@040:FU
Y@2LW9`0W9bL08F5Q@80QXJ600@0ZJVY0<71`@31`L40`<300P2c/k<0102RXZ80Ng]k07]kN`1LG5`2
05ADE00303Xj>P0Q8B408B4Q00<061PH00@0=CDe04Y:BP1:BTX0@d=30P14A4@0100n?Sh0@4100410
@00n?Sh203`l?00404=3@`0l?3`0?3`l01dM7@8061PH00@03`l?00D51@051@D030`<0P051@D00004
00D51@030`<00`<300D51@800@4100@01PH600@4100410@00`<30P0410@010010@401@D500D51@05
1@D200820P0400P8200410@010@400@410800@4100@00`<300T92@092@T01`L70P0410@010061PH0
1@D500D51@020P8200410@@00P820P061PH010092@T030`<00`<300820P200410@0400<30`061PH0
1PH600H61P801`L700@00`<300820P020P800`<30`051@D300L71`801@D500@010@400T92@092@T0
6a/K0P0R8R80100<30`05aLG01LG5`1EEED206EUI@0405EEE@1SHf<0Hf=S08:2PP80P82000@0Kfm_
079bLP1bLW80NGUi0P1@D5001016ATH0BDU904U9B@0h>3P2020P800400l?3`071`L01`L7010@4080
8B4Q00@061PH00X:2P0:2PX02`/;0P0:2PX010071`L02PX:00X:2P092@T200P82004010@400A4A40
4A4A02PX:080DU9B00@0GemO055AD@1ADE40I6AT0P1^KVh0101WIfL0FEUI05UIF@1?Cdl2051@D004
05EEE@1VIVH0IVIV05IFEP80A4A400@0<C4a00/;2`0;2`/01`L70P0=3@d0100G5aL0;Bd]02d];@0n
?Sh2061PH00406YZJP1OGel0GemO05iNGP80JFUY00@0Jf][05aLG01LG5`0AdM70P1JFUX0101HF5P0
HF5Q065QH@1UIFD205YJFP04065QH@1RHV80HV9R05aLG080HV9R00@0K6a/06UYJ@1YJFT0Fe]K0P1N
GUh0101^KVh0KFe]06e]K@1/K6`205MGE`04069RHP1]KFd0KFe]06=SH`80IVIV00@0Fe]K04=3@`13
@d<0Bd];0P1JFUX0101BDU80DE5A055AD@1EEED204E5A@0404=3@`15ADD0ADE504M7A`80EUIF00@0
@d=303Lg=`0g=cL0ADE50P10@4001013@d<0?clo03lo?`0Q8B4200@410<03`l?00@051@D04A4A014
A4@0>SXj0P0h>3P0100^;Rh0<S8b038b<P0o?cl203`l?00402@T90051@D01@D501lO7`80BDU900@0
C4a<04E5A@15ADD0Cdm?0P1@D500101:BTX0EEEE05EEE@1JFUX2059BDP0405]KF`1BDU80DU9B03Ti
>@80B4Q800@0KFe]06a/K01/K6`0IfMW0P1YJFT0101OGel0GEeM05eMG@1QHF4205eMG@0405IFEP1M
GEd0GEeM05iNGP80FEUI00@0HV9R06QXJ01XJ6P0JVYZ0P1VIVH0101EEED0@d=304=3@`12@T820451
@@0403lo?`11@D40@D5103/k>`80ATI60`1HF5P0101PH600LG5a075aL@1mOGd207MgM`0407alO020
P800P82007UiN@80Ogmo00@0Rh^;08:2PP22PX80LG5a0P21PH40102ATI40SHf=08f=S@2ATI4209NG
U`0309FEU@2FUYH0UYJF00<0Vi^K00@0Ti>C07moO`1oOgl0MGEe0`1nOWh207QhN00407MgM`24Q8@0
Q8B40:>SX`80^k^k00@0`<300;Ng]`2g]kL0Vi^K0P1iNGT0101YJFT0FEUI05UIF@0b<S8201/K6`04
01lO7`0N7Qh07QhN03De=@80BTY:00<0ATI604A4A014A4@00`0i>CT0100k>c/0@D510451@@1>CTh2
04Y:BP04038b<P0T92@092@T00h>3P803@d=0`051@D000<01PH600@00`<300H61P061PH01PH60P09
2@T300H61P040000000410@010@400<30`801@D500@02@T900410@010@402@T90P030`<010000000
2PX:00X:2P0<30`200L71`@01@D50P071`L010061PH00`<300<30`030`<200H61P0300@410020P80
0P8200<01`L700@00P8200D51@051@D010@40P00000010030`<010@400@410051@D200X:2P0400T9
2@030`<00`<300H61P8010@400@00@4100@4100410@061PH0P0M7Ad0100H61P0;Rh^02h^;P1<C4`2
05iNGP0405ADE01=CDd0CDe=071`L080Ng]k00@0Kfm_06][J`1[Jf/0N7Qh0P1EEED0100o?cl0AdM7
04M7A`12@T8202d];@0401<C4`061PH01PH601@D50808R8R00@06QXJ00h>3P0>3Ph03Ph>0P0;2`/0
10071`L00P8200820P061PH200X:2P0400d=3@0;2`/02`/;01@D5080A4A400@0Hf=S04I6AP16ATH0
FUYJ0P1^KVh0101ZJVX0K6a/06a/K01TI6@205]KF`0405eMG@1NGUh0GUiN04I6AP80@T9200@0<c<c
014A4@0A4A40410@0P0<30`0100G5aL0>SXj03Xj>P1>CTh206e]K@0407inOP1XJ6P0J6QX06IVIP80
Hf=S00@0G5aL05mOG`1OGel0ATI60P1CDe<0101KFe/0HV9R069RHP1JFUX205IFEP0405mOG`1UIFD0
IFEU05]KF`80GUiN00@0IFEU05eMG@1MGEd0HV9R0P1jNWX00`1gMgL0GEeM05eMG@0305iNGP0406][
J`1VIVH0IVIV06EUI@80K6a/00@0Fe]K04];B`1;Bd/0?clo0P1>CTh0101DE5@0F5QH05QHF01FEUH2
0410@0040492@P1ADE40DE5A05ADE080De=C00@0?clo03Ph>00h>3P0AdM70P0o?cl0100n?Sh0>3Ph
03Ph>00H61P200d=3@@04a<C0P0h>3P0100c<c<0>c/k03/k>`0h>3P203Ti>@0403`l?00c<c<0<c<c
01@D50809BDU00@0ATI604m?C`1?Cdl0A4A40`16ATH203Xj>P040410@01;Bd/0Bd];04m?C`80E5AD
00@0EeMG051@D01@D500;Rh^0P0h>3P0101fMWH0J6QX06QXJ01GEeL205aLG00405ADE01ADE40DE5A
05QHF080EeMG00@0De=C05UIF@1IFET0FEUI0P1DE5@00`1NGUh0GEeM05eMG@0305EEE@0404];B`10
@400@41004A4A080@T9200@0?3`l03lo?`0o?cl0AdM70P1GEeL0101CDe<0FEUI05UIF@1]KFd206i^
KP0406m_K`1`L700L71`07YjNP80P82000@0Q8B408^;R`2;Rh/0UiNG0P27QhL0101fMWH0N7Qh07Qh
N023Ph<2096AT@0409FEU@2IVIT0VIVI09^KV`80Ti>C00@0UiNG09ZJVP2JVYX0UYJF0P2>SXh0101g
MgL0KVi^06i^KP1kNg/208>3P`0408J6QP2@T900T92@0:^[Z`80_[jn00@0^KVi0;6a/@2a/K40Xj>S
0P2ATI401022PX80H61P061PH00h>3P201dM7@0401lO7`0R8R808R8R03Lg=`80ATI600@0BDU904M7
A`17AdL0>SXj0P14A4@01016ATH0B4Q804Q8B01@D50205EEE@0403hn?P0K6a/06a/K00P820<01`L7
0P0:2PX000<01PH600@00`<300H61P061PH01PH60P092@T300H61P040000000410@010@400<30`80
1@D500@02@T900410@010@402@T90P030`<0100000002PX:00X:2P0<30`200L71`@01@D50P071`L0
10061PH00`<300<30`030`<200H61P0300@410020P800P8200<01`L700@00P8200D51@051@D010@4
0P00000010030`<010@400@410051@D200X:2P0400T92@030`<00`<300H61P8010@400@00@4100@4
100410@061PH0P0M7Ad0100H61P0;Rh^02h^;P1<C4`205iNGP0405ADE01=CDd0CDe=071`L080Ng]k
00@0Kfm_06][J`1[Jf/0N7Qh0P1EEED0100o?cl0AdM704M7A`12@T8202d];@0401<C4`061PH01PH6
01@D50808R8R00@06QXJ00h>3P0>3Ph03Ph>0P0;2`/010071`L00P8200820P061PH200X:2P0400d=
3@0;2`/02`/;01@D5080A4A400@0Hf=S04I6AP16ATH0FUYJ0P1^KVh0101ZJVX0K6a/06a/K01TI6@2
05]KF`0405eMG@1NGUh0GUiN04I6AP80@T9200@0<c<c014A4@0A4A40410@0P0<30`0100G5aL0>SXj
03Xj>P1>CTh206e]K@0407inOP1XJ6P0J6QX06IVIP80Hf=S00@0G5aL05mOG`1OGel0ATI60P1CDe<0
101KFe/0HV9R069RHP1JFUX205IFEP0405mOG`1UIFD0IFEU05]KF`80GUiN00@0IFEU05eMG@1MGEd0
HV9R0P1jNWX00`1gMgL0GEeM05eMG@0305iNGP0406][J`1VIVH0IVIV06EUI@80K6a/00@0Fe]K04];
B`1;Bd/0?clo0P1>CTh0101DE5@0F5QH05QHF01FEUH20410@0040492@P1ADE40DE5A05ADE080De=C
00@0?clo03Ph>00h>3P0AdM70P0o?cl0100n?Sh0>3Ph03Ph>00H61P200d=3@@04a<C0P0h>3P0100c
<c<0>c/k03/k>`0h>3P203Ti>@0403`l?00c<c<0<c<c01@D50809BDU00@0ATI604m?C`1?Cdl0A4A4
0`16ATH203Xj>P040410@01;Bd/0Bd];04m?C`80E5AD00@0EeMG051@D01@D500;Rh^0P0h>3P0101f
MWH0J6QX06QXJ01GEeL205aLG00405ADE01ADE40DE5A05QHF080EeMG00@0De=C05UIF@1IFET0FEUI
0P1DE5@00`1NGUh0GEeM05eMG@0305EEE@0404];B`10@400@41004A4A080@T9200@0?3`l03lo?`0o
?cl0AdM70P1GEeL0101CDe<0FEUI05UIF@1]KFd206i^KP0406m_K`1`L700L71`07YjNP80P82000@0
Q8B408^;R`2;Rh/0UiNG0P27QhL0101fMWH0N7Qh07QhN023Ph<2096AT@0409FEU@2IVIT0VIVI09^K
V`80Ti>C00@0UiNG09ZJVP2JVYX0UYJF0P2>SXh0101gMgL0KVi^06i^KP1kNg/208>3P`0408J6QP2@
T900T92@0:^[Z`80_[jn00@0^KVi0;6a/@2a/K40Xj>S0P2ATI401022PX80H61P061PH00h>3P201dM
7@0401lO7`0R8R808R8R03Lg=`80ATI600@0BDU904M7A`17AdL0>SXj0P14A4@01016ATH0B4Q804Q8
B01@D50205EEE@0403hn?P0K6a/06a/K00P820<01`L70P0:2PX0000300@410051@D01@D500<01PH6
00@010@400<30`030`<01`L70P051@D300<30`0400D51@0410@010@400@410801@D500@01PH60082
0P020P800P820P0:2PX0100820P00`<300<30`051@D200410@0400<30`0820P020P800X:2P801`L7
00@01PH600T92@092@T00`<30`0410@200410@<00`<300@01@D500H61P061PH01PH60P0:2PX300L7
1`<02PX:00@01`L700P8200820P00`<30P061PH0100M7Ad09BDU02DU9@0I6AT202h^;P04055AD@1N
GUh0GUiN05ADE080EeMG00@0L71`07=cL`1cLg<0JFUY0P1OGel0101^KVh0JVYZ06YZJP1=CDd205AD
E004051@D00f=SH0=SHf01/K6`80410@00@061PH02DU9@0U9BD09BDU0P0C4a<0100410@00@410041
0@0820P200`<30@020P80P0410@0100=3@d0;Rh^02h^;P1QHF420492@P0404i>CP1UIFD0IFEU069R
HP80I6AT00@0IFEU06MWI`1WIfL0IFEU0P1DE5@0100k>c/0@D510451@@0e=CD200`<3004010@400F
5QH05QHF01`L7080BTY:00@0GemO06][J`1[Jf/0NGUi0P1RHV80101^KVh0IVIV06IVIP1DE5@205]K
F`04055AD@18B4P0B4Q805EEE@80JFUY00<0EEEE05IFEP1FEUH00`1UIFD0101LG5`0IVIV06IVIP1W
IfL2061PH00406a/K01`L700L71`06EUI@80IVIV00@0KVi^06ATI01TI6@0HF5Q0P1FEUH0101GEeL0
GemO05mOG`1QHF42051@D00403@d=016ATH0ATI605EEE@80I6AT00@0IfMW04];B`1;Bd/0>SXj0P12
@T80101:BTX0Cdm?04m?C`13@d<203Xj>P040492@P0l?3`0?3`l03@d=080<c<c0`0H61P0100E5AD0
4Q8B018B4P0I6AT203@d=00404Q8B01<C4`0C4a<03Xj>P80>c/k00@0?3`l02TY:@0Y:BT06QXJ0P0k
>c/0101BDU80@d=304=3@`0h>3P20451@@040410@00l?3`0?3`l04M7A`80BDU900@0CDe=05MGE`1G
EeL0Cdm?0P0o?cl0100>3Ph07QhN01hN7P1^KVh206MWI`0405UIF@1GEeL0EeMG05ADE080CTi>00@0
GUiN04i>CP1>CTh0CTi>0P1JFUX0101HF5P0CTi>04i>CP1CDe<205IFEP0404a<C01?Cdl0Cdm?05=C
D`80BTY:00@0@D5103Lg=`0g=cL0?Cdm0P17AdL01014A4@0BTY:04Y:BP1:BTX2059BDP<0Jf][00@0
K6a/07EeM@1eMGD0KVi^0P1cLg<01026QXH0QhN708N7Q`2>SXh208V9R@0408^;R`29RHT0RHV908F5
Q@80Shn?00@0T92@08j>SP2>SXh0TI6A0P2DU9@0102BTY80SXj>08j>SP2ATI4208j>SP0408F5Q@2C
Ti<0Ti>C0:JVYP80YjNW00@0VYZJ09:BTP2BTY80YjNW0P2l_;`0102b/[80[jn_0:n_[`2YZJT20:2P
X00408^;R`1@D500D51@03De=@<0;2`/0P0X:2P01013@d<0DU9B059BDP1BDU8204Q8B00403<c<`13
@d<0@d=303lo?`80@41000@0BTY:04e=C@1=CDd0ATI60P0O7al0100D51@020P800P8200:2PX200P8
200000@00`<300D51@051@D01`L70P010@400`020P8020P800P8200300T92@0400H61P051@D01@D5
00L71`801@D500@010@400L71`071`L00`<30P0820P010020P8010@400@410020P8200L71`040082
0P092@T02@T900P820800P8200@00`<300@4100410@00@410P0410@0100:2PX01`L700L71`051@D2
00@4100400H61P0>3Ph03Ph>00d=3@800`<300@010@400L71`071`L00`<30P020P800`061PH020P8
00P8200300820P0400T92@0<30`030`<01LG5`808B4Q00@051@D02@T900T92@0JVYZ0P1kNg/0101>
CTh0F5QH05QHF01_Kfl206a/K00406UYJ@1OGel0GemO06=SH`80LW9b00@0FUYJ05MGE`1GEeL0Bd];
0P0b<S80100H61P03@d=00d=3@0>3Ph201/K6`0402<S8`0H61P061PH00d=3@801@D500@00`<300P8
200820P010@40P0:2PX0100=3@d01`L700L71`071`L201`L700405mOG`11@D40@D5103Lg=`80G5aL
00@0GemO05iNGP1NGUh0I6AT0P1VIVH0101@D500ADE504E5A@16ATH2051@D00403Lg=`0:2PX02PX:
014A4@806a/K00@07QhN04m?C`1?Cdl0J6QX0P1WIfL0101^KVh0IfMW06MWI`1cLg<206e]K@0406MW
I`1FEUH0EUIF059BDP80BDU900@0De=C06EUI@1UIFD0Bd];0P1@D500101ZJVX0GUiN05iNGP1@D502
06EUI@0406e]K@1UIFD0IFEU06IVIP80G5aL00@0Fe]K06i^KP1^KVh0K6a/0P1GEeL0101FEUH0H61P
061PH01TI6@205IFEP0405mOG`1?Cdl0Cdm?03Ph>080BDU900@0G5aL06a/K01/K6`0H61P0P19BDT0
100g=cL0?3`l03`l?015ADD204A4A00403Xj>P0d=3@0=3@d03lo?`80>SXj00@0<c<c038b<P0b<S80
3@d=0P0E5AD0100C4a<051@D01@D500F5QH20410@004051@D01;Bd/0Bd];03Ti>@<0@d=30P0P8200
100W9bL0AdM704M7A`16ATH203hn?P040410@00k>c/0>c/k0410@080Bd];00@0@d=303`l?00l?3`0
BDU90P1=CDd01017AdL0ADE504E5A@0A4A4201hN7P0405iNGP1MGEd0GEeM051@D080BTY:0`1>CTh0
101SHf<0Cdm?04m?C`1>CTh204m?C`0404Q8B01=CDd0CDe=05UIF@80EUIF00@0AdM704U9B@19BDT0
CDe=0P11@D40100f=SH0;2`/02`/;00a<C430410@080CDe=00@0F5QH05YJFP1JFUX0JVYZ0`1[Jf/2
079bLP0406m_K`1ZJVX0JVYZ07EeM@80OWin00@0PH6107moO`1oOgl0QHF50P26QXH01021PH40RXZ:
08Z:RP2ATI4208n?S`0408V9R@2?Shl0Shn?09>CT`80SHf=00@0Ti>C09^KV`2KVi/0V9RH0P2PX:00
102WYjL0WIfM09fMW@2LW9`20:2PX0040:^[Z`2g]kL0]kNg0;Ng]`80/[:b00@0Xj>S0:2PX02PX:00
PX:20P1BDU80100i>CT08b<S02<S8`0P820202DU9@040492@P1EEED0EEEE04e=C@80C4a<00@0=SHf
03De=@0e=CD0:BTY0P0V9RH01017AdL0Fe]K05]KF`1=CDd201PH600401@D50020P800P8200X:2P80
1PH6000010030`<01@D500D51@071`L200410@0300820P0820P020P800<02@T900@01PH600D51@05
1@D01`L70P051@D0100410@01`L700L71`030`<200P8200400820P0410@010@400820P801`L700@0
0P8200T92@092@T020P80P020P8010030`<010@400@410010@4200@4100400X:2P071`L01`L700D5
1@8010@400@01PH600h>3P0>3Ph03@d=0P030`<0100410@01`L700L71`030`<200820P0300H61P08
20P020P800<00P8200@02@T900`<300<30`05aLG0P0Q8B40100D51@092@T02@T901ZJVX207]kN`04
04i>CP1HF5P0F5QH06m_K`80K6a/00@0JFUY05mOG`1OGel0Hf=S0P1bLW80101JFUX0EeMG05MGE`1;
Bd/2038b<P0401PH600=3@d03@d=00h>3P806a/K00@08b<S01PH600H61P03@d=0P051@D010030`<0
20P800P8200410@200X:2P0400d=3@071`L01`L700L71`8071`L00@0GemO0451@@11@D40=cLg0P1L
G5`0101OGel0GUiN05iNGP1TI6@206IVIP04051@D015ADD0ADE504I6AP80D51@00@0=cLg00X:2P0:
2PX04A4A0P0K6a/0100N7Qh0Cdm?04m?C`1XJ6P206MWI`0406i^KP1WIfL0IfMW07=cL`80KFe]00@0
IfMW05IFEP1FEUH0DU9B0P19BDT0101CDe<0IFEU06EUI@1;Bd/2051@D00406YZJP1NGUh0GUiN051@
D080IFEU00@0KFe]06EUI@1UIFD0IVIV0P1LG5`0101KFe/0KVi^06i^KP1/K6`205MGE`0405IFEP1P
H600H61P06ATI080EUIF00@0GemO04m?C`1?Cdl0>3Ph0P19BDT0101LG5`0K6a/06a/K01PH60204U9
B@0403Lg=`0l?3`0?3`l04E5A@80A4A400@0>SXj03@d=00d=3@0?clo0P0j>SX0100c<c<0<S8b038b
<P0=3@d201DE5@0401<C4`0D51@051@D01HF5P80@41000@0D51@04];B`1;Bd/0>CTi0`13@d<2020P
800402LW9`17AdL0AdM704I6AP80?Shn00@0@41003/k>`0k>c/0@4100P1;Bd/01013@d<0?3`l03`l
?019BDT204e=C@0404M7A`15ADD0ADE5014A4@807QhN00@0GUiN05eMG@1MGEd0D51@0P1:BTX304i>
CP0406=SH`1?Cdl0Cdm?04i>CP80Cdm?00@0B4Q804e=C@1=CDd0FEUI0P1FEUH01017AdL0BDU904U9
B@1=CDd20451@@0403Hf=P0/;2`0;2`/034a<@<0@4100P1=CDd0101HF5P0FUYJ05YJFP1ZJVX306][
J`80LW9b00@0Kfm_06YZJP1ZJVX0MGEe0P1nOWh01021PH40Ogmo07moO`25QHD208J6QP040861P@2:
RXX0RXZ:096AT@80Shn?00@0RHV908n?S`2?Shl0Ti>C0P2=SHd0102CTi<0Vi^K09^KV`2HV9P20:2P
X0040:NWY`2MWId0WIfM09bLW080X:2P00@0Zj^[0;Ng]`2g]kL0]kNg0P2b/[80102SXj<0X:2P0:2P
X022PX82059BDP0403Ti>@0S8b<08b<S020P80809BDU00@0@T9205EEE@1EEED0CDe=0P1<C4`0100f
=SH0=CDe03De=@0Y:BT202HV9P0404M7A`1KFe/0Fe]K04e=C@8061PH00@051@D00820P020P802PX:
0P061PH0000400L71`0:2PX02PX:000000801@D500@0000000P8200820P01PH60P092@T010071`L0
1@D500D51@020P8200`<300400<30`051@D01@D500<30`801`L700@0000000P8200820P00@410P03
0`<0100410@00`<300<30`051@D200<30`0400L71`0410@010@400D51@<020P80`0410@200<30`03
00410@030`<00`<300<01@D500@01PH600P8200820P02@T90P051@D0100410@00`<300<30`000002
00@41004000000061PH01PH601`L70808B4Q00@06a/K02<S8`0S8b<0GUiN0P1iNGT0101BDU80BDU9
04U9B@1UIFD206a/K00406IVIP1QHF40HF5Q05aLG080Hf=S00@0FEUI05aLG01LG5`0B4Q80P0b<S80
100S8b<061PH01PH600?3`l2014A4@<05QHF00@03Ph>00410@010@4010@40P0;2`/0100410@03`l?
00l?3`0C4a<200`<300400D51@0O7al07alO061PH080CDe=00@0>c/k05MGE`1GEeL0GemO0P1WIfL0
101RHV80JFUY06UYJ@1KFe/204i>CP0405UIF@1[Jf/0Jf][04=3@`802PX:00@03`l?01PH600H61P0
6a/K0P1=CDd0101XJ6P0K6a/06a/K01kNg/207YjNP0407EeM@1TI6@0I6AT06][J`80FUYJ00@0EeMG
05EEE@1EEED0C4a<0P1CDe<01013@d<0ATI604I6AP1JFUX205UIF@0405MGE`1RHV80HV9R05mOG`80
Fe]K0`1ZJVX0101OGel0L71`071`L01cLg<205EEE@04051@D01KFe/0Fe]K06ATI080@T9200@0ATI6
04a<C01<C4`0CTi>0`1KFe/206UYJ@0405=CD`13@d<0@d=304E5A@80BDU900@0@T920410@010@400
@4100P0i>CT0100e=CD0=cLg03Lg=`0m?Cd2030`<0040000000G5aL05aLG00l?3`<04Q8B0P14A4@0
101<C4`0>c/k03/k>`0g=cL304Y:BP806ATI00@0:BTY04=3@`13@d<0>3Ph0P0o?cl0101>CTh0@T92
0492@P0f=SH203Xj>P0403Ph>00a<C40<C4a03hn?P80B4Q800@0ATI604m?C`1?Cdl0@D510P16ATH0
101MGEd0FUYJ05YJFP1;Bd/204U9B@0404Q8B01>CTh0CTi>05YJFP80DE5A00@0De=C04Q8B018B4P0
AdM70P1EEED0101GEeL0C4a<04a<C018B4P204];B`0404A4A00e=CD0=CDe02l_;`80<S8b00@0=CDe
0492@P12@T80ATI60P1=CDd0101ADE40EUIF05IFEP1RHV8206ATI0<0JFUY00@0Lg=c075aL@1aLG40
L71`0`1jNWX207MgM`0407emO@22PX80PX:207YjNP80N7Qh00@0Ph>308R8R028R8P0Ph>30P25QHD0
102;Rh/0SHf=08f=S@29RHT208Z:RP0409>CT`2LW9`0W9bL0:6QX@80Vi^K00@0UIFE08f=S@2=SHd0
SHf=0P2PX:00102i^KT0^[Zj0;Zj^P2][Jd20:2PX0040861P@1ZJVX0JVYZ04];B`80;Bd]00@0:RXZ
02d];@0];Bd0?Cdm0P1HF5P0101DE5@0C4a<04a<C010@40203`l?004030`<00K6a/06a/K03hn?P80
KVi^00@0GemO01hN7P0N7Qh03Ph>0P061PH100D51@400`<30@030`<0000400<30`020P800P8200@4
10801PH600@01`L700@4100410@00P820P0410@00`061PH010@400@4100300<30`0400H61P0410@0
10@400L71`8020P800@030`<00P8200820P01`L70P0:2PX0100>3Ph02PX:00X:2P051@D200820P@0
10@40P0;2`/010061PH00`<300<30`030`<300@410801PH60`010@4300D51@0400X:2P092@T02@T9
00@410801PH600<01`L700D51@051@D00`071`L0100H61P071`L01`L700>3Ph201/K6`0404m?C`1i
NGT0NGUi06QXJ080Cdm?00@0G5aL06e]K@1]KFd0Jf][0P1RHV80101IFET0Fe]K05]KF`1DE5@205iN
GP0405QHF00k>c/0>c/k02@T9080820P00@06a/K01@D500D51@05ADE0P0D51@0100=3@d010@400@4
100820P200d=3@0400D51@0:2PX02PX:00/;2`803Ph>00@02@T901TI6@0I6AT0Bd];0P1<C4`0100g
=cL0BTY:04Y:BP1JFUX206EUI@0405mOG`1PH600H61P05MGE`80ATI600@0C4a<06=SH`1SHf<0?Cdm
0P0;2`/0100C4a<0410@010@400@410204I6AP04069RHP1KFe/0Fe]K06QXJ080JFUY00@0IVIV06QX
J01XJ6P0HF5Q0P1JFUX0101DE5@0Cdm?04m?C`11@D4204a<C00405QHF01EEED0EEEE05UIF@80EEEE
00@0EeMG069RHP1RHV80G5aL0P1JFUX0101YJFT0K6a/06a/K01VIVH206UYJ@0406QXJ01DE5@0E5AD
051@D080@T9200@0DE5A0410@010@400BDU90P1FEUH0101DE5@0H61P061PH01JFUX206IVIP0304i>
CP0m?Cd0?Cdm00<0@41000@0>c/k03lo?`0o?cl0@T920P0m?Cd0100i>CT0<c<c03<c<`0b<S8202`/
;00400`<300H61P061PH01@D50807alO00@06QXJ03/k>`0k>c/0?Shn0P0`<300100f=SH0C4a<04a<
C010@402024Q8@0402h^;P0`<300<30`034a<@80A4A400@0C4a<03dm?@0m?Cd0:RXZ0P0^;Rh0100c
<c<0<30`030`<00e=CD203`l?00403lo?`10@400@41004Y:BP80De=C00@0I6AT06UYJ@1YJFT0HF5Q
0P1FEUH0100j>SX0De=C05=CD`1NGUh204Q8B00404=3@`15ADD0ADE504];B`80DE5A00@0Cdm?04I6
AP16ATH0@T920P10@400100h>3P0>c/k03/k>`0n?Sh203`l?004034a<@0i>CT0>CTi04A4A080AdM7
00@0CTi>05ADE01DE5@0HF5Q0P1SHf<3075aL@0407IfMP1/K6`0K6a/06EUI@80Kfm_00@0MGEe07Ui
N@1iNGT0MgMg0P1hN7P0101fMWH0MgMg07MgM`20P80208:2PP0408B4Q02;Rh/0Rh^;08Z:RP80Ti>C
00@0U9BD08F5Q@25QHD0T92@0P2ATI401026QXH0TI6A096AT@2@T90207QhN0040820P02OWil0WinO
0;2`/080[:b/00@0YZJV09BDU02DU9@0PH610P1bLW801018B4P0<c<c03<c<`0];Bd202@T900403Ph
>01KFe/0Fe]K05YJFP80E5AD00@0FUYJ03hn?P0n?Sh0:BTY0P0N7Qh0100e=CD0IFEU06EUI@1QHF42
038b<P04010@400;2`/02`/;00X:2P802`/;000010030`<00P8200820P0410@200H61P0400L71`04
10@010@400820P8010@400<01PH600@4100410@00`030`<010061PH010@400@410071`L200P82004
00`<300820P020P800L71`802PX:00@03Ph>00X:2P0:2PX01@D50P020P8400@410802`/;00@01PH6
00<30`030`<00`<30`0410@200H61P<00@410`051@D0100:2PX02@T900T92@0410@200H61P0300L7
1`051@D01@D500<01`L700@061PH01`L700L71`03Ph>0P0K6a/0101?Cdl0NGUi07UiN@1XJ6P204m?
C`0405aLG01]KFd0KFe]06][J`80HV9R00@0FEUI05]KF`1KFe/0E5AD0P1NGUh0101HF5P0>c/k03/k
>`0T92@2020P800401/K6`0D51@051@D01DE5@8051@D00@03@d=00@4100410@020P80P0=3@d01005
1@D02PX:00X:2P0;2`/200h>3P0400T92@0I6AT06ATI04];B`80C4a<00@0=cLg04Y:BP1:BTX0FUYJ
0P1UIFD0101OGel0H61P061PH01GEeL204I6AP0404a<C01SHf<0Hf=S03dm?@802`/;00@04a<C010@
400@4100410@0P16ATH0101RHV80Fe]K05]KF`1XJ6P206UYJ@0406IVIP1XJ6P0J6QX065QH@80FUYJ
00@0E5AD04m?C`1?Cdl0@D510P1<C4`0101HF5P0EEEE05EEE@1IFET205EEE@0405MGE`1RHV80HV9R
05aLG080FUYJ00@0JFUY06a/K01/K6`0IVIV0P1YJFT0101XJ6P0E5AD05ADE01@D5020492@P04055A
D@10@400@41004U9B@80EUIF00@0E5AD061PH01PH600FUYJ0P1VIVH00`1>CTh0?Cdm03dm?@030410
@00403/k>`0o?cl0?clo0492@P80?Cdm00@0>CTi03<c<`0c<c<0<S8b0P0/;2`0100<30`061PH01PH
600D51@201lO7`0401XJ6P0k>c/0>c/k03hn?P80<30`00@0=SHf04a<C01<C4`0@4100P0Q8B40100^
;Rh0<30`030`<00a<C4204A4A00404a<C00m?Cd0?Cdm02XZ:P80;Rh^00@0<c<c030`<00`<300=CDe
0P0l?3`0100o?cl0@4100410@01:BTX205=CD`0406ATI01YJFT0JFUY065QH@80EUIF00@0>SXj05=C
D`1CDe<0GUiN0P18B4P01013@d<0ADE504E5A@1;Bd/2055AD@0404m?C`16ATH0ATI60492@P80@410
00@0>3Ph03/k>`0k>c/0?Shn0P0l?3`0100a<C40>CTi03Ti>@14A4@204M7A`0404i>CP1DE5@0E5AD
065QH@80Hf=S0`1aLG40101fMWH0K6a/06a/K01UIFD206m_K`0407EeM@1iNGT0NGUi07MgM`80N7Qh
00@0MWIf07MgM`1gMgL0P8200P22PX801024Q8@0Rh^;08^;R`2:RXX209>CT`0409BDU025QHD0QHF5
092@T080TI6A00@0QXJ6096AT@2ATI40T92@0P1hN7P01020P800WinO09nOW`2`/;020:b/[0040:JV
YP2DU9@0U9BD0861P@80LW9b00@0B4Q803<c<`0c<c<0;Bd]0P0T92@0100h>3P0Fe]K05]KF`1JFUX2
05ADE00405YJFP0n?Sh0?Shn02TY:@807QhN00@0=CDe06EUI@1UIFD0HF5Q0P0b<S80100@41002`/;
00/;2`0:2PX200/;2`0000@01`L700<30`030`<000000P0410@010051@D00P8200820P0410@20041
0@0400L71`020P800P8200410@8020P800@00@410000000000000@410P020P8010071`L00@410041
0@0410@200820P0400L71`0820P020P800@410800`<300<0000000P8200820P010051@D200H61P04
00T92@020P800P8200@410801PH600@01`L700<30`030`<000000P010@4300H61P0300<30`0410@0
10@400<010@400@01`L700P8200820P051@D0P0L71`0100?3`l0820P020P801<C4`206m_K`04071`
L01MGEd0GEeM05EEE@80F5QH00@0Kfm_06=SH`1SHf<0EUIF0P1>CTh01017AdL0Cdm?04m?C`1PH602
04a<C00402@T900E5AD05ADE01HF5P807AdM00@0:RXZ02<S8`0S8b<04A4A0`061PH2010@400400d=
3@0820P020P800`<30802PX:00@01PH600/;2`0;2`/0?Shn0P1<C4`0100V9RH0@4100410@01IFET2
065QH@0406QXJ01QHF40HF5Q05EEE@80EUIF00@0EEEE05mOG`1OGel0?Shn0`0C4a<200h>3P0401@D
5017AdL0AdM706MWI`80I6AT00@0JVYZ05YJFP1JFUX0E5AD0P1bLW80101YJFT0H61P061PH01@D502
04M7A`0404Y:BP1@D500D51@05UIF@80EEEE00@0GUiN05YJFP1JFUX0EEEE0P1WIfL0101ZJVX0HF5Q
065QH@1NGUh2069RHP04065QH@1DE5@0E5AD05YJFP80GEeM00@0H61P04a<C01<C4`0EEEE0P19BDT0
101:BTX0EUIF05IFEP19BDT205iNGP0406MWI`1`L700L71`05mOG`80D51@00@0@D51038b<P0b<S80
<C4a0P14A4@0101;Bd/0>c/k03/k>`0e=CD203Hf=P0403<c<`0X:2P0:2PX00h>3P805aLG00@04a<C
01lO7`0O7al08R8R0P0k>c/0100d=3@0>3Ph03Ph>00j>SX204=3@`04034a<@0W9bL09bLW02d];@80
9BDU00@0=3@d04=3@`13@d<0>c/k0P0a<C40100c<c<0>SXj03Xj>P0/;2`202XZ:P0403Hf=P0a<C40
<C4a038b<P80;Rh^00@0@d=305]KF`1KFe/0IVIV0P1^KVh0101/K6`0GemO05mOG`0d=3@204i>CP04
05mOG`0m?Cd0?Cdm03Hf=P80ADE50`19BDT01010@400>c/k03/k>`19BDT204m?C`0404E5A@10@400
@41003hn?P80<c<c00@0;Bd]03/k>`0k>c/0AdM70P1;Bd/0101BDU80DE5A055AD@1LG5`206=SH`04
075aL@1^KVh0KVi^06i^KP80J6QX00@0IfMW071`L01`L700Kfm_0P1bLW80101eMGD0O7al07alO020
P80307QhN080P82000@0RXZ:096AT@2ATI40Rh^;0P1oOgl0101eMGD0IfMW06MWI`1[Jf/307IfMP80
MgMg00@0NGUi07AdM01dM7@0Ph>30P2LW9`0102UYJD0WinO09nOW`2MWId209:BTP0408>3P`1mOGd0
OGem05ADE080@d=300@0<30`01/K6`0K6a/0@4100P1KFe/0101:BTX0FEUI05UIF@1^KVh203dm?@04
024Q8@0P8200820P03Ti>@80IFEU00@0E5AD03<c<`0c<c<05aLG0P0820P100<30`402PX:0@0:2PX0
000400L71`0820P020P800820P8010@40`051@D0100<30`02PX:00X:2P061PH200P8200300<30`05
1@D01@D500<01@D500@010@400T92@092@T01@D50P0410@010051@D00`<300<30`051@D200<30`04
00820P030`<00`<300<30`801PH600@00`<300@4100410@01PH60P020P80100:2PX01PH600H61P02
0P82000000<00`<300@02@T900820P020P801PH60P051@D0100000000@4100410@0410@300<30`80
000000@02PX:01TI6@0I6AT030`<0P0G5aL01014A4@0GUiN05iNGP1VIVH206i^KP0406UYJ@1ADE40
DE5A06IVIP80J6QX00@0FUYJ03Hf=P0f=SH0<S8b0P16ATH0101KFe/0B4Q804Q8B00O7al201@D5004
01`L700S8b<08b<S02TY:@806ATI00@02@T900H61P061PH00`<30P0;2`/0100=3@d01@D500D51@09
2@T200H61P0400@4100=3@d03@d=02`/;080ADE500@06a/K03@d=00d=3@0EUIF0P1LG5`0101PH600
FEUI05UIF@1<C4`205mOG`04061PH01XJ6P0J6QX0451@@805QHF00@05ADE01PH600H61P08b<S0P1;
Bd/0101/K6`0KVi^06i^KP1_Kfl205iNGP04059BDP1ZJVX0JVYZ05QHF080EeMG00@0De=C04A4A014
A4@0AdM70P1@D500101CDe<0BTY:04Y:BP1=CDd205UIF@0406UYJ@1]KFd0KFe]05iNGP80EEEE00@0
EUIF061PH01PH600IFEU0P1NGUh0101ZJVX0IFEU06EUI@1MGEd205YJFP04055AD@0m?Cd0?Cdm03Lg
=`80CDe=00@0CTi>06=SH`1SHf<0MGEe0P1YJFT0101GEeL0@T920492@P0`<302034a<@0403@d=013
@d<0@d=304Y:BP80>SXj00@0=CDe03Hf=P0f=SH0<c<c0P0Q8B40100B4Q806QXJ01XJ6P0C4a<201XJ
6P04020P800e=CD0=CDe02`/;080>SXj00@0=3@d03Ph>00h>3P07AdM0P0K6a/0100/;2`0;Bd]02d]
;@0c<c<203Ti>@0403Lg=`0j>SX0>SXj03Xj>P80<C4a00@0:RXZ02HV9P0V9RH0:RXZ0P0`<300100^
;Rh09RHV02HV9P0d=3@2059BDP0406ATI01WIfL0IfMW05eMG@80HF5Q0`16ATH0101EEED0>3Ph03Ph
>00c<c<204Q8B00404Y:BP10@400@41003Ph>080?clo00@0BDU90410@010@400=cLg0P0`<300100d
=3@0=cLg03Lg=`0f=SH203/k>`0403dm?@12@T80@T9204I6AP80A4A400@0EEEE069RHP1RHV80Kfm_
0P1VIVH0101TI6@0JVYZ06YZJP1XJ6P206IVIP04065QH@1VIVH0IVIV06UYJ@80K6a/00@0MWIf07Ad
M01dM7@0K6a/0P1`L700101lO7`0QHF508F5Q@22PX8207AdM00406UYJ@1WIfL0IfMW06=SH`80Jf][
00@0NGUi07YjNP1jNWX0OWin0P24Q8@01023Ph<0UiNG09NGU`2WYjL20:BTY0040:^[Z`2ZZZX0ZZZZ
09ZJVP80QhN700@0HF5Q059BDP1BDU80<30`0P0P8200101>CTh0GEeM05eMG@1ADE4206ATI00406m_
K`18B4P0B4Q802@T90808R8R00@0@41006MWI`1WIfL0E5AD0P0f=SH00`0S8b<03`l?00l?3`0300D5
1@0000@01`L700P8200820P00P820P0410@300D51@0400`<300:2PX02PX:00H61P8020P800<00`<3
00D51@051@D00`051@D0100410@02@T900T92@051@D200@4100400D51@030`<00`<300D51@800`<3
00@00P8200<30`030`<00`<30P061PH010030`<010@400@410061PH200820P0400X:2P061PH01PH6
00820P8000000`030`<010092@T00P8200820P061PH200D51@04000000010@400@4100@410<00`<3
0P000000100:2PX06ATI01TI6@0<30`201LG5`0404A4A01NGUh0GUiN06IVIP80KVi^00@0JFUY055A
D@1ADE40IVIV0P1XJ6P0101JFUX0=SHf03Hf=P0b<S8204I6AP0405]KF`18B4P0B4Q801lO7`8051@D
00@071`L02<S8`0S8b<0:BTY0P0I6AT010092@T01PH600H61P030`<200/;2`0400d=3@051@D01@D5
00T92@801PH600@010@400d=3@0=3@d0;2`/0P15ADD0100K6a/0=3@d03@d=01FEUH205aLG004061P
H01IFET0FEUI04a<C080GemO00@0H61P06QXJ01XJ6P0@D510P0F5QH0100E5AD061PH01PH600S8b<2
04];B`0406a/K01^KVh0KVi^06m_K`80GUiN00@0DU9B06YZJP1ZJVX0F5QH0P1GEeL0101CDe<0A4A4
04A4A017AdL2051@D00405=CD`1:BTX0BTY:04e=C@80FEUI00@0JFUY06e]K@1]KFd0GUiN0P1EEED0
101FEUH0H61P061PH01UIFD205iNGP0406YZJP1UIFD0IFEU05eMG@80FUYJ00@0DE5A03dm?@0m?Cd0
=cLg0P1=CDd0101>CTh0Hf=S06=SH`1eMGD206UYJ@0405MGE`12@T80@T92030`<080<C4a00@0=3@d
04=3@`13@d<0BTY:0P0j>SX0100e=CD0=SHf03Hf=P0c<c<2024Q8@04018B4P0J6QX06QXJ01<C4`80
6QXJ00@0820P03De=@0e=CD0;2`/0P0j>SX0100d=3@0>3Ph03Ph>00M7Ad201/K6`0402`/;00];Bd0
;Bd]03<c<`80>CTi00@0=cLg03Xj>P0j>SX0>SXj0P0a<C40100Z:RX09RHV02HV9P0Z:RX2030`<004
02h^;P0V9RH09RHV03@d=080DU9B00@0I6AT06MWI`1WIfL0GEeM0P1QHF4304I6AP0405EEE@0h>3P0
>3Ph03<c<`80B4Q800@0BTY:0410@010@400>3Ph0P0o?cl01019BDT0@4100410@00g=cL2030`<004
03@d=00g=cL0=cLg03Hf=P80>c/k00@0?Cdm0492@P12@T80ATI60P14A4@0101EEED0HV9R069RHP1_
Kfl206IVIP0406ATI01ZJVX0JVYZ06QXJ080IVIV00@0HF5Q06IVIP1VIVH0JFUY0P1/K6`0101fMWH0
M7Ad07AdM01/K6`2071`L00407alO025QHD0QHF508:2PP80M7Ad00@0JFUY06MWI`1WIfL0Hf=S0P1[
Jf/0101iNGT0NWYj07YjNP1nOWh208B4Q00408>3P`2GUiL0UiNG0:NWY`80Y:BT00@0Zj^[0:ZZZP2Z
ZZX0VYZJ0P27QhL0101QHF40DU9B059BDP0`<302020P800404i>CP1MGEd0GEeM055AD@80I6AT00@0
Kfm_04Q8B018B4P092@T0P0R8R801010@400IfMW06MWI`1DE5@203Hf=P0302<S8`0?3`l03`l?00<0
1@D50000100820P02`/;00/;2`030`<200410@0400<30`061PH01PH600X:2P800P8200@00@4100H6
1P061PH02@T90P0820P010051@D010@400@4100820P200410@0400H61P071`L01`L700820P801@D5
10030`<200D51@0400<30`0410@010@400H61P800`<300@010@400L71`071`L020P80P061PH01004
10@01@D500D51@020P8200D51@0400@410000000000000<30`800@4100@0000000820P020P8020P8
0P061PH30000000400`<300O7al07alO01<C4`805aLG00@0@T9205]KF`1KFe/0Fe]K0P1XJ6P0101W
IfL0BTY:04Y:BP1?Cdl205MGE`0404=3@`0T92@092@T02HV9P80;Rh^00@0ATI60451@@11@D4092@T
0P0L71`0100I6AT04A4A014A4@0F5QH201DE5@0400h>3P0A4A404A4A00d=3@801PH600@01`L700P8
200820P020P80P030`<010061PH04Q8B018B4P0P820203`l?00402XZ:P0f=SH0=SHf04M7A`80E5AD
00@0G5aL05QHF01HF5P0@T920P1>CTh0101CDe<0Jf][06][J`13@d<201PH600401<C4`0H61P061PH
02`/;080DU9B00<0L71`06IVIP1VIVH00`1OGel0101CDe<0GUiN05iNGP1HF5P204e=C@0404U9B@1;
Bd/0Bd];04I6AP80CTi>00@0DU9B04e=C@1=CDd0BDU90P17AdL0101LG5`0J6QX06QXJ01GEeL2055A
D@0405MGE`1KFe/0Fe]K061PH080HV9R00@0K6a/065QH@1QHF40EUIF0P1EEED0101:BTX0?3`l03`l
?00l?3`20410@00404A4A017AdL0AdM705MGE`80E5AD00@0CTi>0410@010@400>SXj0P10@400100l
?3`0>c/k03/k>`0i>CT202d];@0402h^;P0Z:RX0:RXZ02PX:0807AdM00@08B4Q02<S8`0S8b<06a/K
0P0M7Ad0100I6AT0>3Ph03Ph>00d=3@2034a<@04030`<00^;Rh0;Rh^01TI6@807QhN00@0=CDe03Hf
=P0f=SH0=3@d0`0f=SH203`l?00403Lg=`0V9RH09RHV02PX:0<08R8R0P0g=cL0100T92@05QHF01HF
5P0d=3@204e=C@04069RHP1XJ6P0J6QX06=SH`80HF5Q00@0D51@04A4A014A4@0EEEE0P0o?cl0100a
<C40ATI604I6AP11@D42038b<P0403De=@12@T80@T9204Y:BP80?Shn00@0<S8b02PX:00X:2P09BDU
0P0Y:BT0100X:2P0<c<c03<c<`0a<C4203`l?00404Q8B01ADE40DE5A05UIF@80FUYJ00@0HF5Q06=S
H`1SHf<0GemO0P1MGEd0101KFe/0G5aL05aLG01NGUh206MWI`0406=SH`1MGEd0GEeM06][J`80LW9b
00@0KFe]06UYJ@1YJFT0MGEe0P21PH40101dM7@0H61P061PH01BDU82051@D00404a<C01GEeL0EeMG
06EUI@80Ng]k00@0T92@09BDU02DU9@0TI6A0P2NWYh0102ZZZX0Xj>S0:>SX`2_[jl20;:b/P040:FU
Y@2;Rh/0Rh^;06EUI@80EEEE00@0=SHf01lO7`0O7al0ADE50P1GEeL0101NGUh0K6a/06a/K01_Kfl2
059BDP0402LW9`0Q8B408B4Q04U9B@80JFUY00@0G5aL03Lg=`0g=cL06QXJ0P092@T100820P401`L7
0@071`L0000400P820061PH01PH600H61P8010@400@01@D500@4100410@00`<30P071`L300T92@04
00L71`0410@010@400<30`8020P800@010@400410@010@401`L70P0820P010020P801PH600H61P07
1`L200H61P0400820P092@T02@T900410@801@D500@00P8200H61P061PH000000P0410@0100<30`0
10@400@410051@D200<30`030000000:2PX02PX:00<010@400@01PH600P8200820P030`<0P092@T0
10020P800@4100410@0410@200<30`04018B4P0Q8B408B4Q01HF5P806a/K00<0@d=306=SH`1SHf<0
0`1OGel0101VIVH0G5aL05aLG01<C4`205IFEP040492@P0_;bl0;bl_03/k>`80?3`l00@0BDU90492
@P12@T80:RXZ0P0H61P010092@T00`<300<30`0N7Qh202PX:00401PH600I6AT06ATI01<C4`800`<3
00@00@4100@4100410@01`L70P0<30`0100:2PX01PH600H61P0B4Q8203@d=0<0=SHf00@0=3@d04a<
C01<C4`0EeMG0P1?Cdl01019BDT0Cdm?04m?C`1=CDd206][J`0404U9B@0H61P061PH014A4@809bLW
00@0@41005=CD`1CDe<0HV9R0P1NGUh0101OGel0J6QX06QXJ01IFET205QHF00406QXJ01>CTh0CTi>
03Xj>P80DE5A00@0DU9B04i>CP1>CTh0AdM70P1BDU80101FEUH0BDU904U9B@1ADE4206QXJ004065Q
H@1EEED0EEEE05IFEP80F5QH00@0G5aL05YJFP1JFUX0GUiN0P1HF5P01019BDT0ATI604I6AP1>CTh2
0410@00404=3@`0n?Sh0?Shn04=3@`80A4A400@0@T9204e=C@1=CDd0De=C0P13@d<0100i>CT0>3Ph
03Ph>00f=SH203Ph>00303<c<`0Y:BT0:BTY00@09RHV0P0D51@0100R8R809bLW02LW9`0O7al201hN
7P0400P8200f=SH0=SHf03Ph>0<0<S8b0P0P8200100D51@092@T02@T900f=SH203De=@<0;bl_00@0
<S8b03/k>`0k>c/0<C4a0P0O7al0100X:2P06QXJ01XJ6P0O7al203`l?00402DU9@0K6a/06a/K030`
<080>SXj00@0C4a<05aLG01LG5`0H61P0P1FEUH01013@d<0@4100410@01FEUH203lo?`0402LW9`0i
>CT0>CTi03`l?080=CDe00@0>SXj03`l?00l?3`0@T920P15ADD01010@400;2`/02`/;00N7Qh202PX
:00402TY:@0/;2`0;2`/034a<@80@T9200@0CDe=05=CD`1CDe<0De=C0P1HF5P0101JFUX0FEUI05UI
F@1IFET205QHF00405MGE`1EEED0EEEE05MGE`<0GemO0P1QHF4406YZJP80IfMW00@0K6a/07emO@1m
OGd0Jf][0P1=CDd01018B4P0DU9B059BDP1EEED206m_K`0407inOP2:RXX0RXZ:08f=S@80Q8B400@0
QHF508b<S02<S8`0U9BD0P2BTY80102SXj<0YZJV0:JVYP2EUID208N7Q`0406MWI`1>CTh0CTi>03dm
?@808R8R00@0@41005iNGP1NGUh0K6a/0P1eMGD0101iNGT0HF5Q065QH@0c<c<202DU9@0403lo?`1R
HV80HV9R06i^KP80BDU900@06QXJ00/;2`0;2`/01PH60P010@40000400P820061PH01PH600H61P80
10@400@01@D500@4100410@00`<30P071`L300T92@0400L71`0410@010@400<30`8020P800@010@4
00410@010@401`L70P0820P010020P801PH600H61P071`L200H61P0400820P092@T02@T900410@80
1@D500@00P8200H61P061PH000000P0410@0100<30`010@400@410051@D200<30`030000000:2PX0
2PX:00<010@400@01PH600P8200820P030`<0P092@T010020P800@4100410@0410@200<30`04018B
4P0Q8B408B4Q01HF5P806a/K00<0@d=306=SH`1SHf<00`1OGel0101VIVH0G5aL05aLG01<C4`205IF
EP040492@P0_;bl0;bl_03/k>`80?3`l00@0BDU90492@P12@T80:RXZ0P0H61P010092@T00`<300<3
0`0N7Qh202PX:00401PH600I6AT06ATI01<C4`800`<300@00@4100@4100410@01`L70P0<30`0100:
2PX01PH600H61P0B4Q8203@d=0<0=SHf00@0=3@d04a<C01<C4`0EeMG0P1?Cdl01019BDT0Cdm?04m?
C`1=CDd206][J`0404U9B@0H61P061PH014A4@809bLW00@0@41005=CD`1CDe<0HV9R0P1NGUh0101O
Gel0J6QX06QXJ01IFET205QHF00406QXJ01>CTh0CTi>03Xj>P80DE5A00@0DU9B04i>CP1>CTh0AdM7
0P1BDU80101FEUH0BDU904U9B@1ADE4206QXJ004065QH@1EEED0EEEE05IFEP80F5QH00@0G5aL05YJ
FP1JFUX0GUiN0P1HF5P01019BDT0ATI604I6AP1>CTh20410@00404=3@`0n?Sh0?Shn04=3@`80A4A4
00@0@T9204e=C@1=CDd0De=C0P13@d<0100i>CT0>3Ph03Ph>00f=SH203Ph>00303<c<`0Y:BT0:BTY
00@09RHV0P0D51@0100R8R809bLW02LW9`0O7al201hN7P0400P8200f=SH0=SHf03Ph>0<0<S8b0P0P
8200100D51@092@T02@T900f=SH203De=@<0;bl_00@0<S8b03/k>`0k>c/0<C4a0P0O7al0100X:2P0
6QXJ01XJ6P0O7al203`l?00402DU9@0K6a/06a/K030`<080>SXj00@0C4a<05aLG01LG5`0H61P0P1F
EUH01013@d<0@4100410@01FEUH203lo?`0402LW9`0i>CT0>CTi03`l?080=CDe00@0>SXj03`l?00l
?3`0@T920P15ADD01010@400;2`/02`/;00N7Qh202PX:00402TY:@0/;2`0;2`/034a<@80@T9200@0
CDe=05=CD`1CDe<0De=C0P1HF5P0101JFUX0FEUI05UIF@1IFET205QHF00405MGE`1EEED0EEEE05MG
E`<0GemO0P1QHF4406YZJP80IfMW00@0K6a/07emO@1mOGd0Jf][0P1=CDd01018B4P0DU9B059BDP1E
EED206m_K`0407inOP2:RXX0RXZ:08f=S@80Q8B400@0QHF508b<S02<S8`0U9BD0P2BTY80102SXj<0
YZJV0:JVYP2EUID208N7Q`0406MWI`1>CTh0CTi>03dm?@808R8R00@0@41005iNGP1NGUh0K6a/0P1e
MGD0101iNGT0HF5Q065QH@0c<c<202DU9@0403lo?`1RHV80HV9R06i^KP80BDU900@06QXJ00/;2`0;
2`/01PH60P010@40000400820P0410@010@400<30`801PH600@00`<300410@010@4010@40P092@T0
100:2PX020P800P820071`L200820P0400<30`010@400@4100410@801PH600@01`L700<30`030`<0
0P820P030`<0100410@00`<300<30`030`<200`<300400D51@071`L01`L700@410800`<300<010@4
00H61P061PH010020P820000000400@410061PH01PH600410@801`L700@010@400820P020P801@D5
0P0820P010030`<01@D500D51@051@D200L71`0401<C4`0I6AT06ATI014A4@804Q8B00@0=CDe05aL
G01LG5`0G5aL0P1?Cdl0101HF5P0I6AT06ATI01@D50204m?C`04055AD@17AdL0AdM704a<C080Bd];
00@0DE5A04i>CP1>CTh0>SXj0P0O7al0100E5AD04a<C01<C4`0O7al201TI6@04014A4@0B4Q804Q8B
00/;2`800P820`030`<0100410@030`<00`<30071`L200<30`0400`<300/;2`0;2`/038b<P80:RXZ
00@0<S8b04];B`1;Bd/0ATI60P0g=cL0101CDe<0G5aL05aLG01<C4`205iNGP0403dm?@0E5AD05ADE
01dM7@80>c/k00@0Bd];04a<C01<C4`0EUIF0P1IFET00`1;Bd/0CDe=04e=C@03051@D004061PH01A
DE40DE5A03Ph>080ADE500@0CTi>05ADE01DE5@0BTY:0P1EEED0101LG5`0Fe]K05]KF`1CDe<205AD
E00405EEE@1DE5@0E5AD05EEE@80H61P00@0J6QX05EEE@1EEED0Bd];0P19BDT0100m?Cd0>3Ph03Ph
>014A4@203`l?0<0ATI600@0EUIF05eMG@1MGEd0C4a<0P19BDT01012@T80:RXZ02XZ:P0Q8B4202`/
;00403Ph>00k>c/0>c/k03De=@80=3@d00@0<S8b02DU9@0U9BD08b<S0P0L71`0100R8R809BDU02DU
9@0[:b/2024Q8@04010@400a<C40<C4a03Hf=P80;Bd]00@092@T00h>3P0>3Ph04A4A0P0[:b/0100^
;Rh0:BTY02TY:@0V9RH202<S8`0402/[:`0_;bl0;bl_01lO7`80410@00@07QhN01LG5`0G5aL09RHV
0P0];Bd0100P82009BDU02DU9@0];Bd2034a<@0404M7A`1EEED0EEEE0492@P<0?Cdm0P19BDT0101I
FET0>3Ph03Ph>00Q8B4202l_;`0403Ph>00o?cl0?clo03/k>`80;bl_00@0>SXj0410@010@400=CDe
0P0P8200100N7Qh0<30`030`<00/;2`202@T900402XZ:P0l?3`0?3`l04A4A080BTY:00@0Bd];05MG
E`1GEeL0E5AD0P1<C4`0101>CTh0E5AD05ADE01GEeL205EEE@0405ADE01FEUH0EUIF05IFEP80GemO
00@0IfMW05iNGP1NGUh0FUYJ0P1OGel0101UIFD0Hf=S06=SH`1GEeL205YJFP0407AdM022PX80PX:2
07alO0<0Q8B40P2:RXX0102;Rh/0PH610861P@1lO7`208R8R00408f=S@2@T900T92@09nOW`80V9RH
00@0RXZ:096AT@2ATI40P8200P1KFe/0100n?Sh08b<S02<S8`0o?cl206IVIP0407EeM@1mOGd0OGem
08>3P`80LW9b00@0A4A402PX:00X:2P0@4100P1fMWH0102=SHd0FEUI05UIF@0F5QH200L71`401@D5
0@030`<100<30`0000@00`<300P8200820P010@40P071`L010092@T00`<300<30`00000600D51@<0
0P820P030`<0100410@01@D500D51@0410@200<30`0300H61P071`L01`L700<00P8200@01PH600L7
1`071`L010@40P092@T010030`<00P8200820P0410@300H61PH00`<30P010@4300D51@0400@41008
20P020P800<30`800P820`061PH300000004010@400M7Ad07AdM018B4P8051@D00@0>c/k05ADE01D
E5@0C4a<0P0n?Sh01016ATH0GUiN05iNGP1OGel204e=C@0404Y:BP1IFET0FEUI05UIF@80D51@00@0
CDe=04m?C`1?Cdl0@4100P0T92@0100K6a/06QXJ01XJ6P0A4A4200d=3@04014A4@0?3`l03`l?00H6
1P801@D500@03@d=00`<300<30`01@D50P092@T0100=3@d01@D500D51@071`L202DU9@0402h^;P0V
9RH09RHV03@d=080B4Q800@0@D5103/k>`0k>c/0EeMG0P1CDe<01018B4P0HV9R069RHP0k>c/201`L
700402LW9`0f=SH0=SHf04A4A080CTi>00@0FUYJ05eMG@1MGEd0ADE50P11@D40101EEED0E5AD05AD
E01<C4`204U9B@0403<c<`0b<S80<S8b03dm?@80CDe=00@0BDU904Y:BP1:BTX0ADE50P1<C4`0101B
DU80CDe=04e=C@18B4P204e=C@0404m?C`1JFUX0FUYJ06MWI`80FUYJ00@0BTY:04=3@`13@d<0A4A4
0P13@d<0101<C4`0?clo03lo?`0i>CT20492@P0405UIF@1RHV80HV9R055AD@80@41000@0>SXj02@T
900T92@071`L0P0/;2`0100a<C40;bl_02l_;`0];Bd302TY:@808b<S00@0:RXZ02LW9`0W9bL0;Bd]
0P0X:2P0100Z:RX06QXJ01XJ6P0E5AD202l_;`04034a<@0T92@092@T01dM7@803@d=00@07AdM03De
=@0e=CD0:RXZ0P0U9BD0100X:2P0820P020P800U9BD2028R8P0401DE5@0I6AT06ATI01hN7P80820P
00@0:RXZ01hN7P0N7Qh071`L0P0W9bL0100^;Rh0;bl_02l_;`0i>CT204I6AP0403lo?`0m?Cd0?Cdm
03Ph>080>c/k00@0AdM702h^;P0^;Rh07alO0P0f=SH303hn?P0403Ti>@0`<300<30`03`l?080>c/k
00<09bLW01hN7P0N7Qh00`0R8R80100Y:BT0:RXZ02XZ:P0[:b/203<c<`0403hn?P19BDT0BDU904M7
A`80D51@00@0C4a<04];B`1;Bd/0DE5A0P1>CTh3051@D00304I6AP19BDT0BDU900<0E5AD00@0EUIF
05EEE@1EEED0EUIF0P1TI6@0101XJ6P0E5AD05ADE01EEED206QXJ00407inOP24Q8@0Q8B407QhN080
Kfm_00@0L71`08B4Q024Q8@0PX:20P20P8001023Ph<0R8R808R8R027QhL209>CT`040:6QX@2KVi/0
Vi^K09bLW080XJ6Q00@0T92@06UYJ@1YJFT0>3Ph0P0W9bL01016ATH0KVi^06i^KP1lO7`207inOP04
08:2PP1iNGT0NGUi04m?C`8092@T00@0?clo08R8R028R8P0V9RH0P1KFe/0100P82003@d=00d=3@05
1@D200820P0000@00`<300P8200820P010@40P071`L010092@T00`<300<30`00000600D51@<00P82
0P030`<0100410@01@D500D51@0410@200<30`0300H61P071`L01`L700<00P8200@01PH600L71`07
1`L010@40P092@T010030`<00P8200820P0410@300H61PH00`<30P010@4300D51@0400@4100820P0
20P800<30`800P820`061PH300000004010@400M7Ad07AdM018B4P8051@D00@0>c/k05ADE01DE5@0
C4a<0P0n?Sh01016ATH0GUiN05iNGP1OGel204e=C@0404Y:BP1IFET0FEUI05UIF@80D51@00@0CDe=
04m?C`1?Cdl0@4100P0T92@0100K6a/06QXJ01XJ6P0A4A4200d=3@04014A4@0?3`l03`l?00H61P80
1@D500@03@d=00`<300<30`01@D50P092@T0100=3@d01@D500D51@071`L202DU9@0402h^;P0V9RH0
9RHV03@d=080B4Q800@0@D5103/k>`0k>c/0EeMG0P1CDe<01018B4P0HV9R069RHP0k>c/201`L7004
02LW9`0f=SH0=SHf04A4A080CTi>00@0FUYJ05eMG@1MGEd0ADE50P11@D40101EEED0E5AD05ADE01<
C4`204U9B@0403<c<`0b<S80<S8b03dm?@80CDe=00@0BDU904Y:BP1:BTX0ADE50P1<C4`0101BDU80
CDe=04e=C@18B4P204e=C@0404m?C`1JFUX0FUYJ06MWI`80FUYJ00@0BTY:04=3@`13@d<0A4A40P13
@d<0101<C4`0?clo03lo?`0i>CT20492@P0405UIF@1RHV80HV9R055AD@80@41000@0>SXj02@T900T
92@071`L0P0/;2`0100a<C40;bl_02l_;`0];Bd302TY:@808b<S00@0:RXZ02LW9`0W9bL0;Bd]0P0X
:2P0100Z:RX06QXJ01XJ6P0E5AD202l_;`04034a<@0T92@092@T01dM7@803@d=00@07AdM03De=@0e
=CD0:RXZ0P0U9BD0100X:2P0820P020P800U9BD2028R8P0401DE5@0I6AT06ATI01hN7P80820P00@0
:RXZ01hN7P0N7Qh071`L0P0W9bL0100^;Rh0;bl_02l_;`0i>CT204I6AP0403lo?`0m?Cd0?Cdm03Ph
>080>c/k00@0AdM702h^;P0^;Rh07alO0P0f=SH303hn?P0403Ti>@0`<300<30`03`l?080>c/k00<0
9bLW01hN7P0N7Qh00`0R8R80100Y:BT0:RXZ02XZ:P0[:b/203<c<`0403hn?P19BDT0BDU904M7A`80
D51@00@0C4a<04];B`1;Bd/0DE5A0P1>CTh3051@D00304I6AP19BDT0BDU900<0E5AD00@0EUIF05EE
E@1EEED0EUIF0P1TI6@0101XJ6P0E5AD05ADE01EEED206QXJ00407inOP24Q8@0Q8B407QhN080Kfm_
00@0L71`08B4Q024Q8@0PX:20P20P8001023Ph<0R8R808R8R027QhL209>CT`040:6QX@2KVi/0Vi^K
09bLW080XJ6Q00@0T92@06UYJ@1YJFT0>3Ph0P0W9bL01016ATH0KVi^06i^KP1lO7`207inOP0408:2
PP1iNGT0NGUi04m?C`8092@T00@0?clo08R8R028R8P0V9RH0P1KFe/0100P82003@d=00d=3@051@D2
00820P0000@00@4100L71`071`L01@D50P071`L010020P8010@400@410010@4200@4100300P82002
0P800P8200<02`/;0`00000010010@401PH600H61P0:2PX300H61P801@D500@0000000D51@051@D0
0`<30`020P8200L71`0400<30`000000000000<30`<01@D50P0:2PX010010@401@D500D51@030`<2
00L71`0400H61P051@D01@D500`<30800`<300@0000000H61P061PH01PH60P071`L010051@D00`<3
00<30`0A4A4201TI6@0400X:2P0J6QX06QXJ04E5A@80CTi>00@0@41003Xj>P0j>SX0?clo0P1;Bd/0
101GEeL0EEEE05EEE@14A4@2051@D00404e=C@1:BTX0BTY:04M7A`80ATI600@0@D5102DU9@0U9BD0
4Q8B0P0G5aL0100I6AT06a/K01/K6`0F5QH200/;2`0400<30`061PH01PH600/;2`8020P800@00`<3
00D51@051@D02`/;0P0410@010061PH08b<S02<S8`0c<c<202d];@0403<c<`10@400@41003dm?@80
?clo00@0CTi>04];B`1;Bd/0ATI60P1LG5`0100k>c/06a/K01/K6`0V9RH203Ph>0040451@@12@T80
@T9204Y:BP80EUIF0`1@D500101BDU80CDe=04e=C@15ADD204a<C00403Lg=`10@400@41004=3@`80
Bd];00@0D51@04];B`1;Bd/0B4Q80P1FEUH0101NGUh0DE5A055AD@17AdL204A4A00403hn?P18B4P0
B4Q8065QH@80GemO00@0B4Q803lo?`0o?cl0A4A40P0k>c/00`13@d<0?3`l03`l?00302/[:`0403Ph
>013@d<0@d=30492@P80:RXZ00@0:2PX02XZ:P0Z:RX08B4Q0P0[:b/0100P82004Q8B018B4P0X:2P2
038b<P0402`/;00K6a/06a/K00l?3`804A4A0`0c<c<0100/;2`09BDU02DU9@0P820202XZ:P0402TY
:@0P8200820P01LG5`804Q8B00@06QXJ02HV9P0V9RH09RHV0P0Q8B40100R8R8092@T02@T900U9BD2
01/K6`0401@D500O7al07alO01LG5`806a/K00@09RHV01/K6`0K6a/06QXJ0P0N7Qh0100U9BD0<C4a
034a<@0/;2`203@d=00403Xj>P0d=3@0=3@d02PX:080;2`/00@0ATI603Ti>@0i>CT07AdM0P0_;bl0
100l?3`0=cLg03Lg=`0d=3@2030`<00403Xj>P0d=3@0=3@d02@T90808b<S00@08R8R01lO7`0O7al0
:b/[0P0V9RH0100R8R80;Bd]02d];@0e=CD203lo?`0404=3@`1:BTX0BTY:04Y:BP80CDe=00@0Cdm?
04];B`1;Bd/0AdM70P19BDT01014A4@0?clo03lo?`16ATH204i>CP0305QHF01QHF40HF5Q00<0I6AT
00@0C4a<04];B`1;Bd/0IVIV0P1^KVh307UiN@0407IfMP1bLW80LW9b07EeM@80R8R800@0Ogmo07Ee
M@1eMGD0Q8B40P26QXH0101nOWh0SHf=08f=S@2FUYH209RHV00409ZJVP2MWId0WIfM09jNWP80MgMg
00@0=SHf01hN7P0N7Qh0?3`l0P1XJ6P0101kNg/0P8200820P026QXH207YjNP0405UIF@0k>c/0>c/k
04];B`80P82000@0RXZ:05aLG01LG5`0820P0P0410@100T92@4030`<0@0<30`0000400P820010@40
0@4100@410H00P820P061PH010071`L010@400@4100820P200H61P0400410@0410@010@400L71`80
10@400@00@4100D51@051@D01@D50P0410@010061PH00P8200820P020P8200410@0400820P0410@0
10@400L71`8010@400@01`L700<30`030`<00@410P092@T00`061PH000000000000400L71`8010@4
00@01@D500P8200820P02@T90P0410@010030`<01PH600H61P0410@200`<300401@D500<30`030`<
00X:2P808B4Q00@0B4Q805ADE01DE5@0?3`l0`0S8b<203De=@040492@P1EEED0EEEE04a<C080@T92
00@0@41004Q8B018B4P0BTY:0P18B4P01013@d<0:b/[02/[:`0@410200<30`0400h>3P0K6a/06a/K
01HF5P802@T900@0000000<30`030`<01PH60P030`<0100410@020P800P820071`L200<30`0400T9
2@0Q8B408B4Q038b<P80;2`/00@0>CTi04A4A014A4@0B4Q80P13@d<01012@T80B4Q804Q8B017AdL2
05aLG00403Lg=`0H61P061PH02d];@80?Shn00@0?clo03dm?@0m?Cd0ADE50`1ADE4205=CD`0404i>
CP12@T80@T920410@080DE5A00@0?Shn04m?C`1?Cdl0Bd];0P16ATH0101>CTh0Bd];04];B`1=CDd2
05aLG00405=CD`15ADD0ADE504e=C@80Bd];00@0@D5104a<C01<C4`0FEUI0P1FEUH304e=C@0405EE
E@10@400@4100451@@80@41000@0<S8b02TY:@0Y:BT0:b/[0P0k>c/0100j>SX092@T02@T900T92@2
02LW9`04024Q8@0Y:BT0:BTY028R8P806a/K00@0<C4a03Ti>@0i>CT0<S8b0P0T92@0100I6AT08B4Q
024Q8@0d=3@2030`<00402d];@0Y:BT0:BTY028R8P808B4Q00@0;Rh^02HV9P0V9RH051@D0P0C4a<0
100M7Ad08R8R028R8P0Y:BT202PX:00401hN7P0R8R808R8R028R8P805aLG00@05QHF01PH600H61P0
51@D0P0L71`0100N7Qh051@D01@D500G5aL201PH600301@D500K6a/06a/K00<0:2PX00@0;Bd]02`/
;00/;2`0:b/[0P0h>3P01019BDT0=CDe03De=@0I6AT202XZ:P0403/k>`0j>SX0>SXj03Lg=`80<c<c
00@0<S8b02/[:`0[:b/08R8R0P0O7al0100K6a/07alO01lO7`0Y:BT202HV9P0402@T900^;Rh0;Rh^
034a<@80=SHf00@0@D510410@010@400?clo0P10@4001012@T80@d=304=3@`11@D4204Q8B00404i>
CP17AdL0AdM704Y:BP80EEEE00@0F5QH05MGE`1GEeL0FEUI0P1@D500100`<300B4Q804Q8B01XJ6P2
06UYJ@0407AdM01fMWH0MWIf07EeM@80MWIf00@0NWYj07QhN01hN7P0O7al0P1eMGD0101kNg/0P820
0820P01kNg/308^;R`80QXJ600@0T92@09RHV02HV9P0UiNG0P1_Kfl0100i>CT09BDU02DU9@10@402
07IfMP0408N7Q`23Ph<0Ph>308V9R@80O7al00@0HV9R059BDP1BDU80IFEU0P2?Shl0102LW9`0JVYZ
06YZJP0O7al200<30`403`l?0@0<30`100`<300000@020P800410@010@4010@41P020P8200H61P04
00L71`0410@010@400P820801PH600@00@4100@4100410@01`L70P0410@010010@401@D500D51@05
1@D200@4100400H61P020P800P8200820P800@4100@00P8200@4100410@01`L70P0410@010071`L0
0`<300<30`010@4200T92@0300H61P000000000000@01`L70P0410@010051@D020P800P820092@T2
00@4100400<30`061PH01PH600@4108030`<00@051@D00`<300<30`02PX:0P0Q8B401018B4P0E5AD
05ADE00l?3`302<S8`80=CDe00@0@T9205EEE@1EEED0C4a<0P12@T801010@400B4Q804Q8B01:BTX2
04Q8B00404=3@`0[:b/0:b/[010@40800`<300@03Ph>01/K6`0K6a/05QHF0P092@T0100000000`<3
00<30`061PH200<30`0400@4100820P020P800L71`800`<300@02@T9024Q8@0Q8B40<S8b0P0/;2`0
100i>CT0A4A404A4A018B4P204=3@`040492@P18B4P0B4Q804M7A`80G5aL00@0=cLg01PH600H61P0
;Bd]0P0n?Sh0100o?cl0?Cdm03dm?@15ADD3055AD@80De=C00@0CTi>0492@P12@T80@4100P1ADE40
100n?Sh0Cdm?04m?C`1;Bd/204I6AP0404i>CP1;Bd/0Bd];04e=C@80G5aL00@0De=C04E5A@15ADD0
CDe=0P1;Bd/01011@D40C4a<04a<C01IFET205IFEP<0CDe=00@0EEEE0410@010@400@D510P10@400
100b<S80:BTY02TY:@0[:b/203/k>`0403Xj>P0T92@092@T02@T90809bLW00@08B4Q02TY:@0Y:BT0
8R8R0P0K6a/0100a<C40>CTi03Ti>@0b<S8202@T900401TI6@0Q8B408B4Q03@d=080<30`00@0;Bd]
02TY:@0Y:BT08R8R0P0Q8B40100^;Rh09RHV02HV9P0D51@201<C4`0401dM7@0R8R808R8R02TY:@80
:2PX00@07QhN028R8P0R8R808R8R0P0G5aL0100F5QH061PH01PH600D51@201`L700401hN7P0D51@0
51@D01LG5`8061PH00<051@D01/K6`0K6a/00`0X:2P0100];Bd0;2`/02`/;00[:b/203Ph>00404U9
B@0e=CD0=CDe01TI6@80:RXZ00@0>c/k03Xj>P0j>SX0=cLg0P0c<c<0100b<S80:b/[02/[:`0R8R82
01lO7`0401/K6`0O7al07alO02TY:@809RHV00@092@T02h^;P0^;Rh0<C4a0P0f=SH01011@D40@410
0410@00o?cl20410@0040492@P13@d<0@d=30451@@80B4Q800@0CTi>04M7A`17AdL0BTY:0P1EEED0
101HF5P0EeMG05MGE`1IFET2051@D004030`<018B4P0B4Q806QXJ080JFUY00@0M7Ad07IfMP1fMWH0
MGEe0P1fMWH0101jNWX0N7Qh07QhN01lO7`207EeM@0407]kN`20P800P82007]kN`<0Rh^;0P26QXH0
102@T900V9RH09RHV02GUiL206m_K`0403Ti>@0U9BD09BDU0410@080MWIf00@0QhN708>3P`23Ph<0
RHV90P1lO7`0101RHV80DU9B059BDP1UIFD208n?S`0409bLW01ZJVX0JVYZ01lO7`800`<30@0?3`l1
00`<304030`<000010061PH020P800P8200410@200H61P0400P820061PH01PH600<30`801PH600@0
1`L700D51@051@D00P820P030`<300@4100400820P000000000000D51@8010@400@0000000<30`03
0`<01PH60P0:2PX010071`L010@400@4100;2`/200D51@0300820P0410@010@400<00`<300@00000
00820P020P801`L70P020P8010051@D01PH600H61P0410@200410@0400<30`020P800P8200<30`80
2@T900@01@D500<30`030`<01@D50P0410@0100@41005QHF01HF5P0<30`2024Q8@0404=3@`17AdL0
AdM702PX:0804Q8B00@06QXJ02XZ:P0Z:RX0@4100P1=CDd0101:BTX0>CTi03Ti>@0j>SX20492@P04
04E5A@17AdL0AdM70451@@80;Bd]00@05QHF00P8200820P02`/;0P0C4a<0100F5QH04Q8B018B4P0:
2PX200@410<01`L700@00@4100X:2P0:2PX04A4A0P0820P010071`L05QHF01HF5P0_;bl2030`<004
03Hf=P10@400@41004];B`80B4Q800@0@T9204U9B@19BDT0B4Q80P1RHV80100o?cl08b<S02<S8`0f
=SH20492@P040410@012@T80@T9204Y:BP80Bd];00@0ADE504Y:BP1:BTX0DU9B0P11@D40100f=SH0
?Shn03hn?P0_;bl20410@00403lo?`0j>SX0>SXj03lo?`80@D5100@0@T92055AD@1ADE40De=C0P16
ATH01015ADD0?Shn03hn?P0i>CT204I6AP0404a<C01>CTh0CTi>04a<C080AdM700@0CTi>04=3@`13
@d<0B4Q80`12@T820451@@0403Lg=`0m?Cd0?Cdm03@d=080:b/[00@0<S8b02XZ:P0Z:RX08b<S0P0^
;Rh0100`<300;2`/02`/;00a<C4302h^;P80:b/[00@08b<S02XZ:P0Z:RX0;bl_0P0e=CD0100f=SH0
9bLW02LW9`0I6AT201lO7`0402XZ:P0T92@092@T01HF5P804Q8B00@06a/K024Q8@0Q8B40:2PX0P0U
9BD301XJ6P0401LG5`0D51@051@D018B4P801PH600@02PX:01@D500D51@051@D0P0=3@d0100?3`l0
4A4A014A4@0@410200l?3`0402@T900Y:BT0:BTY02DU9@808R8R00@0820P034a<@0a<C40@D510P0R
8R80100@4100=3@d03@d=00k>c/203Hf=P0403dm?@0h>3P0>3Ph02/[:`8092@T00@09BDU02XZ:P0Z
:RX08R8R0P0D51@00`0F5QH09RHV02HV9P0302/[:`04030`<00d=3@0=3@d03Xj>P80>CTi00<0?Cdm
0410@010@4000`11@D400`0m?Cd0@4100410@00304I6AP0404U9B@1BDU80DU9B059BDP80@T9200@0
?clo03/k>`0k>c/0<c<c0P1?Cdl0101UIFD0I6AT06ATI01ZJVX2071`L00406i^KP1XJ6P0J6QX06][
J`80I6AT00@0Jf][06a/K01/K6`0Kfm_0P1mOGd0101iNGT0QhN708N7Q`2?Shl207moO`0408>3P`2@
T900T92@07UiN@80CDe=00@0=SHf02d];@0];Bd0B4Q80P1nOWh01027QhL0RXZ:08Z:RP2EUID208V9
R@04079bLP1QHF40HF5Q07EeM@80W9bL00@0Zj^[06e]K@1]KFd0;Bd]0P0?3`l100T92@400`<30@03
0`<004D0000000@00@4100820P020P8000000P020P8010061PH01`L700L71`030`<300410@800`<3
00@01PH600L71`071`L01`L70P061PH0100410@01@D500D51@061PH300L71`801@D500<00P820041
0@010@400`00000300410@T0000000@00P8200000000000000000P010@40100410@01@D500D51@05
1@D200P820<02PX:00@02@T900X:2P0:2PX02PX:0P0>3Ph0100:2PX01PH600H61P092@T200/;2`<0
2@T9100:2PX300/;2`<02@T90P0820P00`061PH02@T900T92@0400T92@802`/;00@02PX:00/;2`0;
2`/03@d=0P0;2`/0100:2PX02@T900T92@0:2PX200`<300300d=3@0<30`030`<00<02PX:0`0<30`0
100=3@d02PX:00X:2P092@T200X:2P0400P8200:2PX02PX:00/;2`8020P800@01@D500@4100410@0
10@40P061PH010071`L01PH600H61P051@D300H61P801`L71P061PH0100820P010@400@410030`<2
00D51@0400@410030`<00`<300820P800@4100@00`<300@4100410@00`<30P020P8010030`<00P82
00820P010@4200820P<00@4100<00P8200410@010@400`00000300410@04000000010@400@4100@4
10801PH600@01@D500<30`030`<00@410P0410@010071`L010@400@410010@4300H61P801@D500<0
1`L700D51@051@D00`0410@400<30`<00@411P030`<200@410L01@D50P0410@300D51@@01PH60`05
1@D300@410800`<300<010@400L71`071`L00`071`L400P820801`L700<01PH600L71`071`L01007
1`L300P820<02@T90P0820P010071`L020P800P820071`L200D51@0400@410030`<00`<300@410<0
1`L70`0820P300L71`801PH600@01`L700P8200820P020P80P0410@00`010@400000000000030000
0000A@00000010010@400P8200820P00000200820P0400H61P071`L01`L700<30`<00@410P030`<0
10061PH01`L700L71`071`L200H61P0400@410051@D01@D500H61P<01`L70P051@D00`020P800@41
00410@03000000<00@412@00000010020P80000000000000000200410@0400@410051@D01@D500D5
1@8020P80`0:2PX010092@T02PX:00X:2P0:2PX200h>3P0400X:2P061PH01PH600T92@802`/;0`09
2@T400X:2P<02`/;0`092@T200P8200300H61P092@T02@T900@02@T90P0;2`/0100:2PX02`/;00/;
2`0=3@d200/;2`0400X:2P092@T02@T900X:2P8030`<00<03@d=00`<300<30`00`0:2PX300`<3004
00d=3@0:2PX02PX:00T92@802PX:00@020P800X:2P0:2PX02`/;0P0820P010051@D010@400@41004
10@200H61P0400L71`061PH01PH600D51@<01PH60P071`L600H61P0400P8200410@010@400<30`80
1@D500@010@400<30`030`<00P820P010@4010030`<010@400@410030`<200820P0400<30`020P80
0P8200410@800P820`010@400`020P800@4100410@03000000<00@4100@0000000410@010@4010@4
0P061PH010051@D00`<300<30`010@4200@4100400L71`0410@010@400410@<01PH60P051@D00`07
1`L01@D500D51@0300@410@00`<30`010@4600<30`8010@41`051@D200@410<01@D510061PH300D5
1@<010@40P030`<00`0410@01`L700L71`0300L71`@020P80P071`L00`061PH01`L700L71`0400L7
1`<020P80`092@T200P8200400L71`0820P020P800L71`801@D500@010@400<30`030`<010@40`07
1`L300P820<01`L70P061PH010071`L020P800P8200820P200@4100300410@000000000000<00000
00150000000400410@020P800P82000000800P8200@01PH600L71`071`L00`<30`010@4200820P04
00H61P071`L01`L700L71`801PH600<010@400D51@051@D010061PH200D51@0300820P010@400@41
00<0000000<00@410000000000002@00000010020P80000000000000000200410@0400@410051@D0
1@D500D51@801`L700@02@T900X:2P0:2PX020P80`0:2PX200h>3P0400X:2P061PH01PH600T92@80
2`/;0`092@T400X:2P<02`/;0`092@T200P8200400H61P092@T02@T900T92@<02PX:0P0;2`/0100:
2PX02`/;00/;2`0=3@d200`<300400X:2P092@T02@T900X:2P8030`<00<03@d=00`<300<30`00`0:
2PX300`<300400d=3@0:2PX02PX:00T92@802PX:00@020P800/;2`0;2`/030`<0P0820P010051@D0
0`<300<30`0410@200H61P0300L71`061PH01PH600<01@D500<01PH600L71`071`L00`061PH01005
1@D01PH600H61P0820P200@4100400<30`051@D01@D500@410800`<30`010@400`030`<010@400@4
100300820P0400<30`020P800P8200410@800P8200@00@4100820P020P800P820P010@43000000<0
0@4100@0000000410@010@4010@40`061PH200<30`0400410@030`<00`<300L71`8010@400@00@41
00H61P061PH01PH60P051@D00`071`L01@D500D51@0300@410@00`<30`010@4600<30`8010@41`05
1@D200@410<01@D50`061PH400D51@<010@40P030`<00`0410@01`L700L71`0300L71`@020P80P07
1`L00`061PH01`L700L71`0400L71`<020P80`092@T200P8200400L71`0820P020P800L71`801@D5
00@010@400<30`030`<010@40`071`L300P820<01`L70P061PH010071`L020P800P8200820P200@4
100300410@000000000000<000000000\
\>"],
  ImageRangeCache->{{{0, 383}, {383, 0}} -> {-0.00127501, 0.998725, 0.998704, \
0.998704}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: SVG Export Vector Graphics", "Subsection"],

Cell[TextData[{
  "This defines a red disk in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ 
      Show[\ Graphics[\ {\ RGBColor[1, 0, 0], \ Disk[\ {0, 0}, \ 1\ ]\ }, \ 
          AspectRatio \[Rule] Automatic\ ]\ ]\)], "Input",
  CellLabel->"In[56]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 .5 m
.5 .5 .47619 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/2000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00a@3ooolT0?l00<L0oooo002k0?ooocP0o`00_@3oool00;<0ooooB03o
002e0?ooo`00[P3ooomB0?l00;00oooo002Y0?oooe`0o`00Z`3oool00:@0ooooH`3o002Y0?ooo`00
XP3ooomZ0?l00:@0oooo002M0?ooog@0o`00W`3oool009/0ooooN@3o002L0?ooo`00V03ooomn0?l0
09X0oooo002C0?ooohP0o`00U@3oool00940ooooS03o002C0?ooo`00SP3ooonB0?l00900oooo002<
0?oooiH0o`00SP3oool008X0ooooVP3o002<0?ooo`00Q`3ooonP0?l008T0oooo00250?oooj@0o`00
Q`3oool008<0ooooZ03o00250?ooo`00P03ooon^0?l00880oooo001n0?oook80o`00P03oool007`0
oooo]P3o001n0?ooo`00N@3ooonl0?l007/0oooo001h0?oookh0o`00NP3oool007L0oooo`03o001i
0?ooo`00M@3oooo40?l007L0oooo001c0?ooolP0o`00M@3oool00700oooocP3o001b0?ooo`00K`3o
ooo@0?l00740oooo001^0?ooom80o`00L03oool006`0ooooeP3o001^0?ooo`00JP3ooooJ0?l006`0
oooo001Y0?ooom`0o`00J`3oool006P0oooogP3o001Z0?ooo`00IP3ooooS0?l006L0oooo001S0?oo
onP0o`00I@3oool00680oooojP3o001T0?ooo`00H@3oooo/0?l006<0oooo001O0?oooo00o`00H@3o
ool005h0oooolP3o001P0?ooo`00G@3ooood0?l005l0oooo001K0?ooooP0o`00G@3oool005X0oooo
nP3o001L0?ooo`00F@3ooool0?l005/0oooo001H0?ooooh0o`00FP3oool005L0ooooo`3o00010?l0
05T0oooo001E0?ooool0o`001@3o001G0?ooo`00E03ooooo0?l000L0o`00EP3oool005<0ooooo`3o
00090?l005D0oooo001A0?ooool0o`003@3o001C0?ooo`00D03ooooo0?l000l0o`00DP3oool004l0
ooooo`3o000A0?l00540oooo001>0?ooool0o`004`3o001@0?ooo`00C@3ooooo0?l001D0o`00C`3o
ool004`0ooooo`3o000G0?l004h0oooo001;0?ooool0o`006@3o001=0?ooo`00BP3ooooo0?l001/0
o`00C03oool004T0ooooo`3o000M0?l004/0oooo00180?ooool0o`007`3o001:0?ooo`00A`3ooooo
0?l00240o`00B@3oool004H0ooooo`3o000S0?l004P0oooo00150?ooool0o`009@3o00170?ooo`00
A03ooooo0?l002L0o`00AP3oool004<0ooooo`3o000Y0?l004D0oooo00120?ooool0o`00:`3o0014
0?ooo`00@@3ooooo0?l002d0o`00@`3oool00400ooooo`3o000_0?l00480oooo000o0?ooool0o`00
<@3o00110?ooo`00?P3ooooo0?l003<0o`00@03oool003d0ooooo`3o000e0?l003l0oooo000l0?oo
ool0o`00=`3o000n0?ooo`00>`3ooooo0?l003T0o`00?@3oool003/0ooooo`3o000j0?l003`0oooo
000j0?ooool0o`00>`3o000l0?ooo`00>@3ooooo0?l003d0o`00>`3oool003P0ooooo`3o000o0?l0
03X0oooo000h0?ooool0o`00@03o000i0?ooo`00=`3ooooo0?l00440o`00>@3oool003H0ooooo`3o
00130?l003P0oooo000e0?ooool0o`00A@3o000g0?ooo`00=03ooooo0?l004L0o`00=P3oool003<0
ooooo`3o00190?l003D0oooo000c0?ooool0o`00BP3o000d0?ooo`00<P3ooooo0?l004/0o`00=03o
ool00340ooooo`3o001=0?l003<0oooo000`0?ooool0o`00C`3o000b0?ooo`00<03ooooo0?l00500
o`00<@3oool002l0ooooo`3o001A0?l00340oooo000^0?ooool0o`00D`3o000`0?ooo`00;@3ooooo
0?l005D0o`00;`3oool002d0ooooo`3o001F0?l002h0oooo000/0?ooool0o`00E`3o000^0?ooo`00
;03ooooo0?l005L0o`00;P3oool002`0ooooo`3o001H0?l002d0oooo000[0?ooool0o`00F@3o000]
0?ooo`00:P3ooooo0?l005/0o`00;03oool002T0ooooo`3o001M0?l002/0oooo000Y0?ooool0o`00
GP3o000Z0?ooo`00:03ooooo0?l005l0o`00:P3oool002P0ooooo`3o001P0?l002T0oooo000W0?oo
ool0o`00H@3o000Y0?ooo`009P3ooooo0?l006<0o`00:03oool002D0ooooo`3o001U0?l002L0oooo
000U0?ooool0o`00IP3o000V0?ooo`009@3ooooo0?l006H0o`009P3oool002@0ooooo`3o001W0?l0
02H0oooo000T0?ooool0o`00J03o000U0?ooo`008`3ooooo0?l006T0o`009@3oool002<0ooooo`3o
001Z0?l002@0oooo000R0?ooool0o`00J`3o000T0?ooo`008@3ooooo0?l006d0o`008`3oool00200
ooooo`3o001_0?l00280oooo000P0?ooool0o`00L03o000Q0?ooo`00803ooooo0?l00700o`008@3o
ool001l0ooooo`3o001a0?l00240oooo000O0?ooool0o`00LP3o000P0?ooo`007P3ooooo0?l007<0
o`00803oool001h0ooooo`3o001d0?l001l0oooo000M0?ooool0o`00M@3o000O0?ooo`007@3ooooo
0?l007H0o`007P3oool001d0ooooo`3o001f0?l001h0oooo000L0?ooool0o`00M`3o000N0?ooo`00
703ooooo0?l007P0o`007@3oool001/0ooooo`3o001i0?l001d0oooo000K0?ooool0o`00NP3o000L
0?ooo`006P3ooooo0?l007/0o`00703oool001X0ooooo`3o001l0?l001/0oooo000J0?ooool0o`00
O03o000K0?ooo`006@3ooooo0?l007d0o`006`3oool001T0ooooo`3o001n0?l001X0oooo000H0?oo
ool0o`00O`3o000J0?ooo`00603ooooo0?l00800o`006@3oool001L0ooooo`3o00210?l001T0oooo
000G0?ooool0o`00PP3o000H0?ooo`005`3ooooo0?l00880o`00603oool001H0ooooo`3o00230?l0
01P0oooo000F0?ooool0o`00Q03o000G0?ooo`005@3ooooo0?l008D0o`005`3oool001D0ooooo`3o
00260?l001H0oooo000E0?ooool0o`00QP3o000F0?ooo`00503ooooo0?l008L0o`005P3oool001@0
ooooo`3o00270?l001H0oooo000D0?ooool0o`00Q`3o000F0?ooo`00503ooooo0?l008P0o`005@3o
ool001<0ooooo`3o00290?l001D0oooo000C0?ooool0o`00R@3o000E0?ooo`004`3ooooo0?l008X0
o`00503oool00180ooooo`3o002;0?l001@0oooo000B0?ooool0o`00S03o000C0?ooo`004@3ooooo
0?l008d0o`004`3oool00140ooooo`3o002=0?l001<0oooo000A0?ooool0o`00S@3o000C0?ooo`00
4@3ooooo0?l008d0o`004`3oool00140ooooo`3o002>0?l00180oooo000@0?ooool0o`00S`3o000B
0?ooo`00403ooooo0?l00900o`004@3oool00100ooooo`3o002@0?l00140oooo000@0?ooool0o`00
T03o000A0?ooo`00403ooooo0?l00900o`004@3oool000l0ooooo`3o002A0?l00140oooo000?0?oo
ool0o`00TP3o000@0?ooo`003`3ooooo0?l00980o`00403oool000h0ooooo`3o002C0?l00100oooo
000>0?ooool0o`00T`3o000@0?ooo`003P3ooooo0?l009<0o`00403oool000h0ooooo`3o002D0?l0
00l0oooo000>0?ooool0o`00U03o000?0?ooo`003@3ooooo0?l009D0o`003`3oool000d0ooooo`3o
002E0?l000l0oooo000=0?ooool0o`00U@3o000?0?ooo`003@3ooooo0?l009H0o`003P3oool000d0
ooooo`3o002F0?l000h0oooo000<0?ooool0o`00U`3o000>0?ooo`00303ooooo0?l009L0o`003P3o
ool000`0ooooo`3o002G0?l000h0oooo000<0?ooool0o`00U`3o000>0?ooo`00303ooooo0?l009L0
o`003P3oool000`0ooooo`3o002G0?l000h0oooo000<0?ooool0o`00V03o000=0?ooo`002`3ooooo
0?l009T0o`003@3oool000/0ooooo`3o002I0?l000d0oooo000;0?ooool0o`00V@3o000=0?ooo`00
2`3ooooo0?l009T0o`003@3oool000/0ooooo`3o002I0?l000d0oooo000;0?ooool0o`00V@3o000=
0?ooo`002`3ooooo0?l009T0o`003@3oool000/0ooooo`3o002I0?l000d0oooo000;0?ooool0o`00
V@3o000=0?ooo`002`3ooooo0?l009X0o`00303oool000/0ooooo`3o002J0?l000`0oooo000:0?oo
ool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0o`00303oool000X0ooooo`3o002K0?l000`0oooo
000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0o`00303oool000X0ooooo`3o002K0?l0
00`0oooo000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0o`00303oool000X0ooooo`3o
002K0?l000`0oooo000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0o`00303oool000X0
ooooo`3o002K0?l000`0oooo000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0o`00303o
ool000X0ooooo`3o002K0?l000`0oooo000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo0?l009/0
o`00303oool000X0ooooo`3o002K0?l000`0oooo000:0?ooool0o`00V`3o000<0?ooo`002P3ooooo
0?l009/0o`00303oool000X0ooooo`3o002K0?l000`0oooo000:0?ooool0o`00V`3o000<0?ooo`00
2P3ooooo0?l009/0o`00303oool000X0ooooo`3o002K0?l000`0oooo000:0?ooool0o`00V`3o000<
0?ooo`002P3ooooo0?l009/0o`00303oool000X0ooooo`3o002K0?l000`0oooo000:0?ooool0o`00
V`3o000<0?ooo`002P3ooooo0?l009/0o`00303oool000X0ooooo`3o002K0?l000`0oooo000:0?oo
ool0o`00V`3o000<0?ooo`002`3ooooo0?l009X0o`00303oool000/0ooooo`3o002J0?l000`0oooo
000;0?ooool0o`00V@3o000=0?ooo`002`3ooooo0?l009T0o`003@3oool000/0ooooo`3o002I0?l0
00d0oooo000;0?ooool0o`00V@3o000=0?ooo`002`3ooooo0?l009T0o`003@3oool000/0ooooo`3o
002I0?l000d0oooo000;0?ooool0o`00V@3o000=0?ooo`002`3ooooo0?l009T0o`003@3oool000`0
ooooo`3o002H0?l000d0oooo000<0?ooool0o`00V03o000=0?ooo`00303ooooo0?l009L0o`003P3o
ool000`0ooooo`3o002G0?l000h0oooo000<0?ooool0o`00U`3o000>0?ooo`00303ooooo0?l009L0
o`003P3oool000`0ooooo`3o002G0?l000h0oooo000<0?ooool0o`00U`3o000>0?ooo`003@3ooooo
0?l009H0o`003P3oool000d0ooooo`3o002F0?l000h0oooo000=0?ooool0o`00U@3o000?0?ooo`00
3@3ooooo0?l009D0o`003`3oool000d0ooooo`3o002E0?l000l0oooo000>0?ooool0o`00U03o000?
0?ooo`003P3ooooo0?l009@0o`003`3oool000h0ooooo`3o002C0?l00100oooo000>0?ooool0o`00
T`3o000@0?ooo`003P3ooooo0?l009<0o`00403oool000l0ooooo`3o002B0?l00100oooo000?0?oo
ool0o`00TP3o000@0?ooo`003`3ooooo0?l00940o`004@3oool000l0ooooo`3o002A0?l00140oooo
000?0?ooool0o`00T@3o000A0?ooo`00403ooooo0?l00900o`004@3oool00100ooooo`3o002@0?l0
0140oooo000@0?ooool0o`00S`3o000B0?ooo`004@3ooooo0?l008h0o`004P3oool00140ooooo`3o
002=0?l001<0oooo000A0?ooool0o`00S@3o000C0?ooo`004@3ooooo0?l008d0o`004`3oool00140
ooooo`3o002=0?l001<0oooo000B0?ooool0o`00S03o000C0?ooo`004P3ooooo0?l008/0o`00503o
ool001<0ooooo`3o002:0?l001@0oooo000C0?ooool0o`00R@3o000E0?ooo`00503ooooo0?l008P0
o`005@3oool001@0ooooo`3o00280?l001D0oooo000D0?ooool0o`00Q`3o000F0?ooo`00503ooooo
0?l008L0o`005P3oool001@0ooooo`3o00270?l001H0oooo000E0?ooool0o`00QP3o000F0?ooo`00
5@3ooooo0?l008H0o`005P3oool001D0ooooo`3o00250?l001L0oooo000F0?ooool0o`00Q03o000G
0?ooo`005P3ooooo0?l008<0o`00603oool001L0ooooo`3o00220?l001P0oooo000G0?ooool0o`00
PP3o000H0?ooo`005`3ooooo0?l00840o`006@3oool001P0ooooo`3o00200?l001T0oooo000H0?oo
ool0o`00O`3o000J0?ooo`006@3ooooo0?l007h0o`006P3oool001T0ooooo`3o001m0?l001/0oooo
000J0?ooool0o`00O03o000K0?ooo`006P3ooooo0?l007`0o`006`3oool001X0ooooo`3o001k0?l0
01`0oooo000K0?ooool0o`00NP3o000L0?ooo`006`3ooooo0?l007T0o`007@3oool001`0ooooo`3o
001h0?l001d0oooo000L0?ooool0o`00M`3o000N0?ooo`007@3ooooo0?l007H0o`007P3oool001d0
ooooo`3o001f0?l001h0oooo000M0?ooool0o`00M@3o000O0?ooo`007P3ooooo0?l007@0o`007`3o
ool001h0ooooo`3o001c0?l00200oooo000O0?ooool0o`00LP3o000P0?ooo`007`3ooooo0?l00740
o`008@3oool00200ooooo`3o001`0?l00240oooo000P0?ooool0o`00L03o000Q0?ooo`00803ooooo
0?l006l0o`008P3oool00240ooooo`3o001]0?l002<0oooo000R0?ooool0o`00J`3o000T0?ooo`00
8`3ooooo0?l006X0o`00903oool002<0ooooo`3o001Y0?l002D0oooo000T0?ooool0o`00J03o000U
0?ooo`00903ooooo0?l006L0o`009P3oool002D0ooooo`3o001V0?l002H0oooo000U0?ooool0o`00
IP3o000V0?ooo`009@3ooooo0?l006D0o`009`3oool002H0ooooo`3o001S0?l002P0oooo000W0?oo
ool0o`00H@3o000Y0?ooo`00:03ooooo0?l00600o`00:@3oool002P0ooooo`3o001O0?l002X0oooo
000Y0?ooool0o`00GP3o000Z0?ooo`00:@3ooooo0?l005d0o`00:`3oool002X0ooooo`3o001K0?l0
02`0oooo000[0?ooool0o`00F@3o000]0?ooo`00;03ooooo0?l005P0o`00;@3oool002`0ooooo`3o
001G0?l002h0oooo000]0?ooool0o`00EP3o000^0?ooo`00;@3ooooo0?l005H0o`00;P3oool002d0
ooooo`3o001E0?l002l0oooo000^0?ooool0o`00D`3o000`0?ooo`00;`3ooooo0?l00540o`00<@3o
ool00300ooooo`3o001@0?l00340oooo000`0?ooool0o`00C`3o000b0?ooo`00<@3ooooo0?l004d0
o`00<`3oool00380ooooo`3o001;0?l003@0oooo000c0?ooool0o`00BP3o000d0?ooo`00<`3ooooo
0?l004T0o`00=@3oool003@0ooooo`3o00170?l003H0oooo000e0?ooool0o`00A@3o000g0?ooo`00
=P3ooooo0?l004<0o`00>03oool003L0ooooo`3o00110?l003T0oooo000h0?ooool0o`00@03o000i
0?ooo`00>03ooooo0?l003l0o`00>P3oool003T0ooooo`3o000m0?l003/0oooo000j0?ooool0o`00
>`3o000l0?ooo`00>`3ooooo0?l003X0o`00?03oool003/0ooooo`3o000i0?l003d0oooo000l0?oo
ool0o`00=`3o000n0?ooo`00?@3ooooo0?l003D0o`00?`3oool003h0ooooo`3o000c0?l00400oooo
000o0?ooool0o`00<@3o00110?ooo`00@03ooooo0?l002l0o`00@P3oool00440ooooo`3o000]0?l0
04<0oooo00120?ooool0o`00:`3o00140?ooo`00@`3ooooo0?l002T0o`00A@3oool004@0ooooo`3o
000W0?l004H0oooo00150?ooool0o`009@3o00170?ooo`00AP3ooooo0?l002<0o`00B03oool004L0
ooooo`3o000Q0?l004T0oooo00180?ooool0o`007`3o001:0?ooo`00B@3ooooo0?l001d0o`00B`3o
ool004X0ooooo`3o000K0?l004`0oooo001;0?ooool0o`006@3o001=0?ooo`00C03ooooo0?l001L0
o`00CP3oool004d0ooooo`3o000E0?l004l0oooo001>0?ooool0o`004`3o001@0?ooo`00C`3ooooo
0?l00140o`00D@3oool00500ooooo`3o000?0?l00580oooo001A0?ooool0o`003@3o001C0?ooo`00
D`3ooooo0?l000T0o`00E@3oool005@0ooooo`3o00070?l005H0oooo001E0?ooool0o`001@3o001G
0?ooo`00E`3ooooo0?l00040o`00F@3oool005P0oooooP3o001J0?ooo`00F@3ooool0?l005/0oooo
001J0?ooooX0o`00G03oool005/0oooon03o001M0?ooo`00G@3ooood0?l005l0oooo001N0?oooo80
o`00H03oool005l0ooool03o001Q0?ooo`00H@3oooo/0?l006<0oooo001R0?ooonX0o`00I03oool0
06<0ooooj03o001U0?ooo`00I@3ooooS0?l006P0oooo001X0?ooomh0o`00JP3oool006T0oooog03o
001[0?ooo`00JP3ooooJ0?l006`0oooo001/0?ooomH0o`00KP3oool006h0oooodP3o001`0?ooo`00
K`3oooo@0?l00740oooo001`0?ooolh0o`00LP3oool007<0oooob03o001e0?ooo`00M@3oooo40?l0
07L0oooo001g0?oool00o`00N@3oool007P0oooo_P3o001j0?ooo`00N@3ooonl0?l007/0oooo001l
0?oookH0o`00OP3oool007h0oooo/P3o00200?ooo`00P03ooon^0?l00880oooo00230?ooojP0o`00
Q@3oool008D0ooooY03o00270?ooo`00Q`3ooonP0?l008T0oooo002:0?oooiX0o`00S03oool008`0
ooooUP3o002>0?ooo`00SP3ooonB0?l00900oooo002A0?oooh`0o`00T`3oool009<0ooooR03o002E
0?ooo`00UP3ooon20?l009P0oooo002J0?ooogT0o`00W@3oool009d0ooooM03o002O0?ooo`00W`3o
oom`0?l00:40oooo002T0?ooofH0o`00YP3oool00:T0ooooGP3o002Y0?ooo`00[03ooomF0?l00:h0
oooo002a0?oood`0o`00/`3oool00;H0oooo@P3o002h0?ooo`00_@3ooold0?l00;l0oooo00380?oo
oah0o`00bP3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-1.05001, -1.05001, 0.00730867, \
0.00730867}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["\<\
The SVG version of that preserves the vector nature of the graphics, here you \
can see the XML nature of the format.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExportString[\ g, \ "\<SVG\>"\ ]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \("<?xml version='1.0' encoding='UTF-8'?>\n<!DOCTYPE svg PUBLIC \
'-//W3C//DTD SVG 1.0//EN' \
'http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd'>\n<svg \
xmlns='http://www.w3.org/2000/svg'\n    width='288.0pt'\n    height='288.0pt'\
\n    viewBox='-1.05 -1.05 2.1 2.1'\n    preserveAspectRatio='xMidYMid meet'>\
\n <g transform='scale(1, -1) translate(0,0)'\n     style='fill:black; \
font-family:&apos;Courier New&apos;, Courier, Symbol, monospace; \
font-size:0.0729167pt; stroke:black; stroke-width:0.00182292pt'>\n  <ellipse \
fill='#f00'\n      cx='0'\n      cy='0'\n      rx='1.0'\n      ry='1.0'\n     \
 stroke='none'/>\n </g>\n</svg>"\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
This exports it to a file, allowing you to view in a web browser using a \
plug-in.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export[\ "\<g.svg\>", \ g\ ]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \("g.svg"\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Tabular Import / Export", "Subsection"],

Cell[TextData[{
  StyleBox["Import", "MR"],
  " and ",
  StyleBox["Export", "MR"],
  " of ",
  StyleBox["\"Table\"", "MR"],
  ", ",
  StyleBox["\"List\"", "MR"],
  " and ",
  StyleBox["\"CSV\"", "MR"],
  " formats has been speeded up. "
}], "BulletText"],

Cell["\<\
Import speedups about 10x to 100x. \
\>", "BulletText"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2"
}], "MathCaption"],

Cell[BoxData[
    \(R[\ \(data1 = Table[Random[], {5000}, {10}];\), \ M42\ ]\)], "Input",
  CellLabel->"In[31]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ Export[\ "\<data.dat\>", \ data1, \ "\<Table\>"\ ], \ 
      M42\ ]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \("data.dat"\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ AbsoluteTiming[\ \(data2\  = \ 
            Import[\ "\<data.dat\>", \ "\<Table\>"\ ];\)], M42\ ]\)], "Input",\

  CellLabel->"In[33]:="],

Cell[BoxData[
    \({8.`6.622699999999999, Null}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ data1\  === \ data2, \ M42\ ]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.0"
}], "MathCaption"],

Cell[BoxData[
    \(R[\ \(data1 = Table[Random[], {5000}, {10}];\), \ M50\ ]\)], "Input",
  CellLabel->"In[35]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ Export[\ "\<data.dat\>", \ data1, \ "\<Table\>"\ ], \ 
      M50\ ]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \("data.dat"\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ AbsoluteTiming[\ \(data2\  = \ 
            Import[\ "\<data.dat\>", \ "\<Table\>"\ ];\)], M50\ ]\)], "Input",\

  CellLabel->"In[37]:="],

Cell[BoxData[
    \({0.6909936`7.29101901844245\ Second, Null}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[\ data1\  === \ data2, \ M50\ ]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["Speedups ... ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Speedup\  = \ 8/0.64\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(12.5`\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Communication Technology", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " "
}], "Subsection"],

Cell[TextData[{
  "Major performance improvement with new ",
  StyleBox["TCPIP", "MR"],
  " protocol. Latency 200x improvement. Bandwidth 10x improvement."
}], "BulletText"],

Cell["\<\
Now better support tunneling through firewalls.\
\>", "BulletText"],

Cell[TextData[{
  "Major performance improvement with new ",
  StyleBox["SharedMemory", "MR"],
  " protocol for Windows platforms. Bandwidth 10x improvement."
}], "BulletText"],

Cell[TextData[{
  "Since all ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " bindings (JLink, .netLink, PythonLink, etc) and almost all ",
  StyleBox["Import", "MR"],
  " / ",
  StyleBox["Export", "MR"],
  " formats rely on ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " these will also improve as a result of improvements in ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  ". "
}], "BulletText"],

Cell[CellGroupData[{

Cell["Examples: TCPIP Protocol", "Subsubsection",
  ShowGroupOpenCloseIcon->True],

Cell[TextData[{
  "This affects you when running remote kernels, e.g. grid",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " relies heavily on this."
}], "BulletText"],

Cell[TextData[{
  "New TCPIP communication device, means ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " communicates at the speed of the underlying network. Typical speedup on a \
lightly loaded 100Base-T network are 10x ",
  StyleBox["bandwidth",
    FontSlant->"Italic"],
  " improvement and 200x ",
  StyleBox["latency",
    FontSlant->"Italic"],
  " improvement. "
}], "BulletText"],

Cell["\<\
Speedups are expected to increase on a gigabit network (our measurements for \
that case are not in yet).\
\>", "BulletText"],

Cell[TextData[{
  "Bandwidth speedups on 100Mb/s network. Command: ",
  StyleBox["Plot3D[Sin[x y],{x,0,2Pi},{y,0,-2Pi},PlotPoints\[Rule]500, Mesh\
\[Rule]False]//AbsoluteTiming", "Program"]
}], "MathCaption"],

Cell[BoxData[GridBox[{
        {\(FE/Kernel\), "Windows", "Linux", "MacOSX"},
        {"Windows", 
          "\[Placeholder]", \(140.2/15.6 = 8.9\), \(136.0/15.1 = 9.0\)},
        {"Linux", \(96.8/14.2 = 6.8\), "\[Placeholder]", \(63.3/9.8 = 6.4\)},
        {"MacOSX", \(123.3/14.1 = 8.7\), \(134.5/12.6 = 10.6\), 
          "\[Placeholder]"}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "Text"],

Cell[TextData[{
  "Latency improvements on 100Mb/s network. Command: ",
  StyleBox["Do[RemoteEvaluate[$MachineName],{10000}]//AbsoluteTiming", 
    "Program"]
}], "MathCaption"],

Cell[BoxData[GridBox[{
        {\(Kernel/Kernel\), "Windows", "Linux", "MacOSX"},
        {"Windows", 
          "\[Placeholder]", \(1999.7/10.0 = 199.9\), \(2009.9/9.0 = 223.3\)},
        {"Linux", \(2001.3/11.7 = 171.0\), 
          "\[Placeholder]", \(1981.2/11.4 = 173.7\)},
        {"MacOSX", \(2013.4/9.0 = 223.7\), \(1999.9/9.9 = 202.010101010101`\),
           "\[Placeholder]"}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[".netLink",
  FontSlant->"Italic"]], "Subsection"],

Cell[TextData[{
  "New ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " framework to support .Net in a similar way that we support Java. "
}], "BulletText"],

Cell[TextData[{
  "Allows you to load any .Net object into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and extend it. "
}], "BulletText"],

Cell[TextData[{
  "Allows with slight extra effort call any DLL and COM object from within ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "BulletText"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox[ButtonBox["J/Link",
    ButtonData:>{
      URL[ "http://www.wolfram.com/solutions/mathlink/jlink/"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" (Java Toolkit)",
    FontSlant->"Italic"]
}], "Subsection"],

Cell["Updated release, and new Java runtimes. ", "BulletText"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Web Services",
  FontSlant->"Italic"]], "Subsection"],

Cell[TextData[{
  "Programmatic interfaces made available over the Web. [",
  ButtonBox["examples",
    ButtonData:>"Web Services 1.1 Introduction",
    ButtonStyle->"AddOnsLink"],
  "]"
}], "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["User Interface", "Section"],

Cell[CellGroupData[{

Cell["Help Browser Redesign", "Subsection"],

Cell["Closer to current web and platform interfaces.", "BulletText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Improved Copy / Paste", "Subsection"],

Cell[TextData[{
  "Better interaction between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and other programs. "
}], "BulletText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slide Show Enhancements", "Subsection"],

Cell["New authoring palette. ", "BulletText"],

Cell["More complete slide environment for all of our style sheets.", \
"BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["64-bit Platform Support", "Section"],

Cell["Linux IA64", "BulletText"],

Cell["Sun Solaris UltraSPARC", "BulletText"],

Cell["HP HP-UX PA-RISC", "BulletText"],

Cell["IBM AIX POWER", "BulletText"],

Cell["Compaq Tru64 Alpha", "BulletText"],

Cell["Linux Alpha", "BulletText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Last Slide"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Gulf Conference \[Bullet] January 2004"
}], "Banner"],

Cell[" ", "Text",
  CellFrame->{{0, 0}, {0, 4}},
  CellMargins->{{0, 0}, {0, 0}},
  CellFrameColor->RGBColor[0.54902, 0.745098, 0.254902],
  Background->None],

Cell[CellGroupData[{

Cell["Additional Resources", "Section",
  CellTags->"LastSlide"],

Cell[TextData[{
  "\[Bullet]",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ButtonBox[" Information Centre",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "\[Bullet] ",
  StyleBox[ButtonBox["The Mathematica Journal",
    ButtonData:>{
      URL[ "http://www.mathematica-journal.com/issue/v9i1/"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\[Bullet] ",
  ButtonBox["Online Forums",
    ButtonData:>{
      URL[ "http://forums.wolfram.com/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "\[Bullet]",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{
      URL[ "http://www.wolfram.com/services/education"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ButtonBox[" Certified Training",
    ButtonData:>{
      URL[ "http://www.wolfram.com/services/education"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style. Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Presentation"],
    FontSize->12]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{0.95, 11},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{25, 30}, {40, 18}},
    CellFrameMargins->{{6, 10}, {10, 14}},
    FontSize->54],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{25, 40}, {55, 10}},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 8}},
    CellMargins->{{25, 30}, {65, 10}},
    FontSize->27],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{25, 30}, {30, 15}},
    FontSize->27],
  
  Cell[StyleData["Section", "SlideShow"],
    CellMargins->{{24, 30}, {24, 6}},
    FontSize->27],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{25, 30}, {30, 20}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellMargins->{{24, 30}, {10, 20}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{25, 30}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "SlideShow"],
    CellMargins->{{24, 30}, {10, 10}},
    FontSize->14],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Banner"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphSpacing->{0, 0},
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[StyleData["Banner", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["Banner", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontSize->8],
  
  Cell[StyleData["Banner", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["Banner", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    Hyphenation->True,
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    TextJustification->1,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{25, 10}, {6, 20}},
    FontSize->18],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{24, 10}, {12, 0}},
    FontFamily->"Georgia",
    FontSize->16],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletText"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["BulletText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BulletText", "SlideShow"],
    CellMargins->{{48, 10}, {6, 20}},
    FontFamily->"Georgia",
    FontSize->16],
  
  Cell[StyleData["BulletText", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{20, 12}, {2, 20}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontFamily->"Times",
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    CellMargins->{{80, 50}, {8, 14}},
    FontSize->15],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    CellMargins->{{24, 50}, {8, 24}},
    FontFamily->"Georgia",
    FontSize->16],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{80, 10}, {8, 15}},
    FontSize->18],
  
  Cell[StyleData["Input", "SlideShow"],
    CellMargins->{{80, 10}, {0, 15}},
    FontSize->15],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{80, 10}, {30, 12}},
    FontSize->16],
  
  Cell[StyleData["Output", "SlideShow"],
    CellMargins->{{80, 10}, {30, 12}},
    FontSize->15],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{80, 10}, {15, 8}},
    FontSize->15],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{80, 10}, {12, 8}},
    FontSize->16],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{80, 10}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{65, 30}, {4, 30}},
    FontSize->21],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    CellMargins->{{65, 30}, {40, 2}},
    FontSize->18],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellMargins->{{65, 30}, {8, 25}},
    FontSize->18],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{25, 40}, {2, 2}},
    FontSize->18],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    Hyphenation->True,
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["DemosLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["TourLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {10, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"],
    FontSize->26],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {15, 12}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{80, 10}, {0, 20}},
    FontSize->18],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultTraditionalFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{80, 10}, {5, 25}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{80, 10}, {5, 15}},
    FontSize->18],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{25, 10}, {8, 20}},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SlideShowHeader"->{
    Cell[1776, 53, 1717, 45, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10011, 336, 1717, 45, 29, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[13195, 459, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[15881, 549, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[22467, 797, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[28810, 1066, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[33596, 1256, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[36723, 1368, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[39227, 1457, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[44450, 1640, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[270244, 5679, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[449598, 8914, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[648646, 12476, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[975304, 34350, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[1236517, 40633, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9033942, 209121, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9042169, 209427, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9053033, 209794, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9059659, 210032, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9120239, 211578, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9124730, 211735, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9135357, 212036, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9141776, 212297, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9254838, 215872, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[9260283, 216089, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10151217, 227878, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10157752, 228112, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10160460, 228208, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10162822, 228287, 1717, 45, 28, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"]},
  "LastSlide"->{
    Cell[10164853, 228348, 64, 1, 84, "Section",
      CellTags->"LastSlide"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SlideShowHeader", 10208840, 229770},
  {"LastSlide", 10211762, 229829}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1717, 45, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[3496, 100, 286, 9, 120, "Text"],
Cell[3785, 111, 158, 4, 51, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3980, 120, 108, 4, 124, "Title"],
Cell[4091, 126, 87, 4, 111, "Author"],
Cell[4181, 132, 559, 13, 216, "Text"],

Cell[CellGroupData[{
Cell[4765, 149, 100, 2, 56, "Subsubsection",
  InitializationCell->True],
Cell[4868, 153, 169, 4, 113, "MathCaption",
  InitializationCell->True],
Cell[5040, 159, 202, 5, 69, "Input",
  InitializationCell->True],
Cell[5245, 166, 165, 4, 43, "Input",
  InitializationCell->True],
Cell[5413, 172, 97, 3, 43, "Input",
  InitializationCell->True],
Cell[5513, 177, 132, 3, 82, "MathCaption",
  InitializationCell->True],
Cell[5648, 182, 109, 3, 43, "Input",
  InitializationCell->True],
Cell[5760, 187, 183, 4, 43, "Input",
  InitializationCell->True],
Cell[5946, 193, 75, 1, 82, "MathCaption",
  InitializationCell->True],
Cell[6024, 196, 513, 10, 147, "Input",
  InitializationCell->True],
Cell[6540, 208, 113, 3, 43, "Input",
  InitializationCell->True],
Cell[6656, 213, 245, 5, 121, "Input",
  InitializationCell->True],
Cell[6904, 220, 366, 7, 95, "Input",
  InitializationCell->True],
Cell[7273, 229, 98, 1, 34, "SubsubsectionIcon",
  InitializationCell->True],
Cell[7374, 232, 88, 1, 82, "MathCaption",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7487, 237, 98, 3, 43, "Input",
  InitializationCell->True],
Cell[7588, 242, 112, 2, 70, "Print"],
Cell[7703, 246, 91, 2, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7831, 253, 245, 6, 95, "Input",
  InitializationCell->True],
Cell[8079, 261, 82, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8198, 268, 245, 6, 95, "Input",
  InitializationCell->True],
Cell[8446, 276, 82, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8565, 283, 130, 3, 43, "Input",
  InitializationCell->True],
Cell[8698, 288, 162, 3, 70, "Output"]
}, Open  ]],
Cell[8875, 294, 113, 3, 43, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[9013, 301, 103, 3, 43, "Input",
  InitializationCell->True],
Cell[9119, 306, 162, 3, 70, "Output"]
}, Open  ]],
Cell[9296, 312, 121, 3, 82, "MathCaption",
  InitializationCell->True],
Cell[9420, 317, 173, 5, 43, "Input",
  InitializationCell->True],
Cell[9596, 324, 378, 7, 147, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10011, 336, 1717, 45, 29, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[11731, 383, 125, 4, 41, "Banner"],
Cell[11859, 389, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[12042, 397, 26, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[12093, 401, 76, 1, 62, "Subsection"],
Cell[12172, 404, 71, 0, 39, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12280, 409, 34, 0, 62, "Subsection"],
Cell[12317, 411, 154, 5, 39, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12508, 421, 29, 0, 62, "Subsection"],
Cell[12540, 423, 125, 5, 39, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12702, 433, 41, 0, 62, "Subsection"],
Cell[12746, 435, 150, 5, 87, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12933, 445, 37, 0, 62, "Subsection"],
Cell[12973, 447, 161, 5, 87, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13195, 459, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[14915, 506, 125, 4, 41, "Banner"],
Cell[15043, 512, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[15226, 520, 73, 1, 84, "Section"],
Cell[15302, 523, 144, 4, 62, "Subsection"],
Cell[15449, 529, 188, 6, 62, "Subsection"],
Cell[15640, 537, 192, 6, 62, "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15881, 549, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[17601, 596, 125, 4, 41, "Banner"],
Cell[17729, 602, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[17912, 610, 31, 0, 84, "Section"],
Cell[17946, 612, 154, 5, 39, "Text"],

Cell[CellGroupData[{
Cell[18125, 621, 42, 0, 62, "Subsection"],
Cell[18170, 623, 177, 5, 41, "Subsubsection"],
Cell[18350, 630, 168, 5, 41, "Subsubsection"],
Cell[18521, 637, 181, 5, 41, "Subsubsection"],
Cell[18705, 644, 179, 5, 41, "Subsubsection"],
Cell[18887, 651, 181, 5, 41, "Subsubsection"],
Cell[19071, 658, 178, 5, 41, "Subsubsection"],
Cell[19252, 665, 164, 5, 41, "Subsubsection"],
Cell[19419, 672, 321, 8, 41, "Subsubsection"]
}, Closed]],

Cell[CellGroupData[{
Cell[19777, 685, 46, 0, 36, "Subsection"],
Cell[19826, 687, 167, 5, 41, "Subsubsection"],
Cell[19996, 694, 181, 5, 41, "Subsubsection"],
Cell[20180, 701, 179, 5, 41, "Subsubsection"],
Cell[20362, 708, 172, 5, 41, "Subsubsection"],
Cell[20537, 715, 172, 5, 41, "Subsubsection"],
Cell[20712, 722, 166, 5, 41, "Subsubsection"],
Cell[20881, 729, 168, 5, 41, "Subsubsection"],
Cell[21052, 736, 174, 5, 41, "Subsubsection"],
Cell[21229, 743, 172, 5, 41, "Subsubsection"],
Cell[21404, 750, 161, 5, 41, "Subsubsection"],
Cell[21568, 757, 158, 5, 41, "Subsubsection"],
Cell[21729, 764, 168, 5, 41, "Subsubsection"],
Cell[21900, 771, 165, 5, 41, "Subsubsection"],
Cell[22068, 778, 169, 5, 41, "Subsubsection"],
Cell[22240, 785, 166, 5, 41, "Subsubsection"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22467, 797, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[24187, 844, 125, 4, 41, "Banner"],
Cell[24315, 850, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[24498, 858, 26, 0, 84, "Section"],
Cell[24527, 860, 125, 5, 39, "Text"],

Cell[CellGroupData[{
Cell[24677, 869, 45, 0, 62, "Subsection"],
Cell[24725, 871, 49, 0, 39, "Text"],
Cell[24777, 873, 83, 2, 36, "BulletText"],
Cell[24863, 877, 166, 5, 36, "BulletText"],
Cell[25032, 884, 178, 3, 36, "BulletText"],
Cell[25213, 889, 78, 2, 36, "BulletText"],
Cell[25294, 893, 232, 8, 36, "BulletText"],
Cell[25529, 903, 69, 2, 36, "BulletText"],
Cell[25601, 907, 50, 0, 36, "BulletText"],
Cell[25654, 909, 81, 2, 36, "BulletText"],
Cell[25738, 913, 60, 0, 36, "BulletText"],
Cell[25801, 915, 53, 4, 87, "Text"],
Cell[25857, 921, 92, 2, 36, "BulletText"],
Cell[25952, 925, 82, 2, 36, "BulletText"],
Cell[26037, 929, 146, 3, 36, "BulletText"],
Cell[26186, 934, 175, 3, 60, "BulletText"],
Cell[26364, 939, 43, 0, 36, "BulletText"],
Cell[26410, 941, 189, 4, 60, "BulletText"],
Cell[26602, 947, 341, 14, 36, "BulletText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26980, 966, 29, 0, 62, "Subsection"],
Cell[27012, 968, 59, 0, 39, "Text"],
Cell[27074, 970, 128, 5, 36, "BulletText"],
Cell[27205, 977, 127, 5, 36, "BulletText"],
Cell[27335, 984, 133, 5, 36, "BulletText"],
Cell[27471, 991, 124, 5, 36, "BulletText"],
Cell[27598, 998, 63, 2, 36, "BulletText"],
Cell[27664, 1002, 67, 2, 36, "BulletText"],
Cell[27734, 1006, 50, 0, 36, "BulletText"],
Cell[27787, 1008, 88, 2, 36, "BulletText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27912, 1015, 38, 0, 62, "Subsection"],
Cell[27953, 1017, 60, 0, 51, "Text"],
Cell[28016, 1019, 29, 0, 72, "BulletText"],
Cell[28048, 1021, 35, 0, 72, "BulletText"],
Cell[28086, 1023, 28, 0, 72, "BulletText"],
Cell[28117, 1025, 33, 0, 72, "BulletText"]
}, Closed]],

Cell[CellGroupData[{
Cell[28187, 1030, 31, 0, 36, "Subsection"],
Cell[28221, 1032, 128, 3, 39, "Text"],
Cell[28352, 1037, 31, 0, 36, "BulletText"],
Cell[28386, 1039, 29, 0, 36, "BulletText"],
Cell[28418, 1041, 28, 0, 36, "BulletText"],
Cell[28449, 1043, 29, 0, 36, "BulletText"],
Cell[28481, 1045, 29, 0, 36, "BulletText"],
Cell[28513, 1047, 29, 0, 36, "BulletText"],
Cell[28545, 1049, 29, 0, 36, "BulletText"],
Cell[28577, 1051, 28, 0, 36, "BulletText"],
Cell[28608, 1053, 28, 0, 36, "BulletText"],
Cell[28639, 1055, 33, 0, 36, "BulletText"],
Cell[28675, 1057, 36, 0, 36, "BulletText"],
Cell[28714, 1059, 35, 0, 36, "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28810, 1066, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[30530, 1113, 125, 4, 41, "Banner"],
Cell[30658, 1119, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[30841, 1127, 38, 0, 84, "Section"],
Cell[30882, 1129, 150, 5, 87, "Text"],

Cell[CellGroupData[{
Cell[31057, 1138, 105, 5, 62, "Subsection"],
Cell[31165, 1145, 201, 7, 72, "BulletText"],
Cell[31369, 1154, 116, 5, 72, "BulletText"],
Cell[31488, 1161, 113, 5, 72, "BulletText"]
}, Closed]],

Cell[CellGroupData[{
Cell[31638, 1171, 254, 9, 36, "Subsection"],
Cell[31895, 1182, 207, 7, 72, "BulletText"],
Cell[32105, 1191, 265, 9, 72, "BulletText"],
Cell[32373, 1202, 565, 19, 72, "BulletText"]
}, Closed]],

Cell[CellGroupData[{
Cell[32975, 1226, 94, 4, 36, "Subsection"],
Cell[33072, 1232, 206, 7, 72, "BulletText"],
Cell[33281, 1241, 254, 8, 72, "BulletText"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33596, 1256, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[35316, 1303, 125, 4, 41, "Banner"],
Cell[35444, 1309, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[35627, 1317, 34, 0, 84, "Section"],
Cell[35664, 1319, 161, 5, 63, "Text"],
Cell[35828, 1326, 148, 5, 62, "Subsection"],
Cell[35979, 1333, 103, 1, 62, "Subsection"],
Cell[36085, 1336, 141, 5, 62, "Subsection"],
Cell[36229, 1343, 149, 5, 62, "Subsection"],
Cell[36381, 1350, 154, 5, 62, "Subsection"],
Cell[36538, 1357, 136, 5, 62, "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36723, 1368, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[38443, 1415, 125, 4, 41, "Banner"],
Cell[38571, 1421, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[38754, 1429, 127, 4, 84, "Section"],
Cell[38884, 1435, 94, 4, 62, "Subsection"],
Cell[38981, 1441, 94, 4, 62, "Subsection"],
Cell[39078, 1447, 100, 4, 62, "Subsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39227, 1457, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[40947, 1504, 125, 4, 41, "Banner"],
Cell[41075, 1510, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[41258, 1518, 49, 0, 84, "Section"],
Cell[41310, 1520, 83, 2, 36, "BulletText"],
Cell[41396, 1524, 82, 2, 36, "BulletText"],
Cell[41481, 1528, 248, 6, 60, "BulletText"],
Cell[41732, 1536, 172, 6, 36, "BulletText"],

Cell[CellGroupData[{
Cell[41929, 1546, 30, 0, 62, "Subsection"],
Cell[41962, 1548, 244, 8, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[42231, 1560, 73, 2, 43, "Input"],
Cell[42307, 1564, 162, 3, 67, "Output"]
}, Open  ]],
Cell[42484, 1570, 103, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[42612, 1576, 394, 10, 44, "Input"],
Cell[43009, 1588, 107, 2, 42, "Output"]
}, Open  ]],
Cell[43131, 1593, 78, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[43234, 1597, 398, 9, 70, "Input"],
Cell[43635, 1608, 129, 3, 42, "Output"]
}, Open  ]],
Cell[43779, 1614, 67, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[43871, 1618, 395, 10, 44, "Input"],
Cell[44269, 1630, 108, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44450, 1640, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[46170, 1687, 125, 4, 41, "Banner"],
Cell[46298, 1693, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[46481, 1701, 61, 0, 62, "Subsection"],
Cell[46545, 1703, 223650, 3970, 603, 31842, 1597, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[270244, 5679, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[271964, 5726, 125, 4, 41, "Banner"],
Cell[272092, 5732, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[272275, 5740, 43, 0, 62, "Subsection"],
Cell[272321, 5742, 177228, 3166, 608, 25859, 1293, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[449598, 8914, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[451318, 8961, 125, 4, 41, "Banner"],
Cell[451446, 8967, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[451629, 8975, 105, 2, 62, "Subsection"],
Cell[451737, 8979, 196860, 3491, 600, 28194, 1404, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[648646, 12476, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[650366, 12523, 125, 4, 41, "Banner"],
Cell[650494, 12529, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[650677, 12537, 50, 0, 84, "Section"],
Cell[650730, 12539, 103, 2, 36, "BulletText"],
Cell[650836, 12543, 113, 3, 36, "BulletText"],
Cell[650952, 12548, 210, 6, 36, "BulletText"],
Cell[651165, 12556, 173, 6, 36, "BulletText"],

Cell[CellGroupData[{
Cell[651363, 12566, 30, 0, 62, "Subsection"],
Cell[651396, 12568, 69, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[651490, 12572, 186, 4, 43, "Input"],
Cell[651679, 12578, 323, 9, 42, "Output"]
}, Open  ]],
Cell[652017, 12590, 178, 6, 59, "MathCaption"],

Cell[CellGroupData[{
Cell[652220, 12600, 87, 2, 43, "Input"],
Cell[652310, 12604, 691, 14, 125, "Output"]
}, Open  ]],
Cell[653016, 12621, 197, 6, 59, "MathCaption"],
Cell[653216, 12629, 140, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[653381, 12636, 119, 3, 43, "Input"],
Cell[653503, 12641, 331, 9, 42, "Output"]
}, Open  ]],
Cell[653849, 12653, 127, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[654001, 12660, 80, 2, 43, "Input"],
Cell[654084, 12664, 319085, 21589, 351, 279125, 21091, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[973184, 34256, 122, 3, 58, "MathCaption"],
Cell[973309, 34261, 72, 2, 44, "Input"],

Cell[CellGroupData[{
Cell[973406, 34267, 197, 5, 43, "Input"],
Cell[973606, 34274, 354, 11, 42, "Output"]
}, Open  ]],
Cell[973975, 34288, 95, 2, 43, "Input"],
Cell[974073, 34292, 184, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[974282, 34299, 106, 2, 43, "Input"],
Cell[974391, 34303, 77, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[974505, 34310, 104, 2, 44, "Input"],
Cell[974612, 34314, 72, 2, 44, "Output"]
}, Open  ]],
Cell[974699, 34319, 97, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[974821, 34325, 98, 2, 43, "Input"],
Cell[974922, 34329, 94, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[975053, 34336, 80, 2, 43, "Input"],
Cell[975136, 34340, 95, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[975304, 34350, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[977024, 34397, 125, 4, 41, "Banner"],
Cell[977152, 34403, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[977335, 34411, 72, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[977432, 34415, 47, 0, 62, "Subsection"],
Cell[977482, 34417, 54, 0, 36, "BulletText"],
Cell[977539, 34419, 79, 0, 36, "BulletText"],

Cell[CellGroupData[{
Cell[977643, 34423, 89, 1, 46, "Subsubsection"],
Cell[977735, 34426, 67, 0, 58, "MathCaption"],
Cell[977805, 34428, 89, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[977919, 34434, 119, 3, 43, "Input"],
Cell[978041, 34439, 147, 3, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[978249, 34449, 29, 0, 62, "Subsection"],
Cell[978281, 34451, 151, 5, 37, "BulletText"],
Cell[978435, 34458, 54, 0, 36, "BulletText"],

Cell[CellGroupData[{
Cell[978514, 34462, 82, 1, 46, "Subsubsection"],
Cell[978599, 34465, 74, 0, 58, "MathCaption"],
Cell[978676, 34467, 193, 5, 69, "Input"],

Cell[CellGroupData[{
Cell[978894, 34476, 183, 4, 69, "Input"],
Cell[979080, 34482, 86085, 2064, 443, 25130, 1306, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1065180, 36549, 269, 10, 62, "MathCaption"],
Cell[1065452, 36561, 83, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[1065560, 36567, 152, 4, 44, "Input"],
Cell[1065715, 36573, 158, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1065910, 36581, 323, 7, 96, "Input"],
Cell[1066236, 36590, 69630, 1633, 444, 19251, 1006, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1135881, 38226, 66, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[1135972, 38230, 105, 2, 43, "Input"],
Cell[1136080, 38234, 96611, 2248, 443, 26167, 1373, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1232752, 40489, 30, 0, 62, "Subsection"],
Cell[1232785, 40491, 54, 0, 36, "BulletText"],
Cell[1232842, 40493, 79, 0, 36, "BulletText"],

Cell[CellGroupData[{
Cell[1232946, 40497, 104, 1, 46, "Subsubsection"],
Cell[1233053, 40500, 61, 0, 58, "MathCaption"],
Cell[1233117, 40502, 85, 2, 43, "Input"],
Cell[1233205, 40506, 368, 11, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[1233598, 40521, 159, 3, 43, "Input"],
Cell[1233760, 40526, 171, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1233968, 40535, 177, 4, 43, "Input"],
Cell[1234148, 40541, 175, 4, 42, "Output"]
}, Open  ]],
Cell[1234338, 40548, 73, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[1234436, 40552, 213, 4, 69, "Input"],
Cell[1234652, 40558, 171, 4, 42, "Output"]
}, Open  ]],
Cell[1234838, 40565, 73, 0, 58, "MathCaption"],
Cell[1234914, 40567, 94, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[1235033, 40573, 321, 6, 95, "Input"],
Cell[1235357, 40581, 172, 4, 42, "Output"]
}, Open  ]],
Cell[1235544, 40588, 170, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[1235739, 40597, 83, 2, 43, "Input"],
Cell[1235825, 40601, 105, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1235967, 40608, 84, 2, 43, "Input"],
Cell[1236054, 40612, 165, 3, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1236280, 40622, 43, 0, 62, "Subsection"],
Cell[1236326, 40624, 67, 0, 36, "BulletText"],
Cell[1236396, 40626, 60, 0, 36, "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1236517, 40633, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[1238237, 40680, 125, 4, 41, "Banner"],
Cell[1238365, 40686, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[1238548, 40694, 41, 0, 84, "Section"],
Cell[1238592, 40696, 131, 3, 37, "BulletText"],
Cell[1238726, 40701, 123, 3, 37, "BulletText"],
Cell[1238852, 40706, 195, 6, 37, "BulletText"],
Cell[1239050, 40714, 129, 3, 37, "BulletText"],
Cell[1239182, 40719, 125, 3, 39, "Text"],

Cell[CellGroupData[{
Cell[1239332, 40726, 47, 0, 62, "Subsection"],
Cell[1239382, 40728, 384, 9, 80, "MathCaption"],
Cell[1239769, 40739, 95, 2, 43, "Input"],
Cell[1239867, 40743, 1521, 26, 459, "Input"],
Cell[1241391, 40771, 346, 7, 95, "Input"],
Cell[1241740, 40780, 94, 2, 58, "MathCaption"],
Cell[1241837, 40784, 75, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[1241937, 40790, 161, 3, 43, "Input"],
Cell[1242101, 40795, 86978, 3025, 348, 35044, 2379, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1329116, 43825, 159, 3, 43, "Input"],
Cell[1329278, 43830, 90650, 2381, 341, 27837, 1601, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1419977, 46217, 47, 0, 62, "Subsection"],
Cell[1420027, 46219, 258, 8, 58, "MathCaption"],
Cell[1420288, 46229, 113, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[1420426, 46235, 189, 4, 43, "Input"],
Cell[1420618, 46241, 249, 7, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1420904, 46253, 96, 2, 43, "Input"],
Cell[1421003, 46257, 144, 4, 42, "Output"]
}, Open  ]],
Cell[1421162, 46264, 98, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[1421285, 46270, 230, 5, 69, "Input"],
Cell[1421518, 46277, 365, 6, 56, "Message"],
Cell[1421886, 46285, 54441, 1313, 279, 19670, 879, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1476376, 47604, 85, 2, 62, "Subsection"],
Cell[1476464, 47608, 561, 14, 102, "MathCaption"],

Cell[CellGroupData[{
Cell[1477050, 47626, 449, 12, 43, "Input"],
Cell[1477502, 47640, 438, 12, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1477977, 47657, 156, 4, 43, "Input"],
Cell[1478136, 47663, 31130, 799, 279, 12163, 560, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1509315, 48468, 119, 3, 62, "Subsection"],
Cell[1509437, 48473, 300, 7, 63, "Text"],
Cell[1509740, 48482, 100, 2, 58, "MathCaption"],
Cell[1509843, 48486, 253, 5, 44, "Input"],
Cell[1510099, 48493, 84, 1, 58, "MathCaption"],
Cell[1510186, 48496, 194, 4, 84, "Input"],
Cell[1510383, 48502, 164, 3, 80, "MathCaption"],
Cell[1510550, 48507, 256, 5, 120, "Input"],

Cell[CellGroupData[{
Cell[1510831, 48516, 201, 4, 43, "Input"],
Cell[1511035, 48522, 63, 2, 42, "Output"]
}, Open  ]],
Cell[1511113, 48527, 74, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[1511212, 48531, 367, 8, 69, "Input"],
Cell[1511582, 48541, 81, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1511700, 48548, 237, 5, 69, "Input"],
Cell[1511940, 48555, 903065, 19167, 339, 734942, 17086, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2415020, 67725, 84, 1, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[2415129, 67730, 120, 3, 43, "Input"],
Cell[2415252, 67735, 851227, 18352, 373, 729179, 16840, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3266528, 86093, 93, 2, 62, "Subsection"],
Cell[3266624, 86097, 116, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3266765, 86104, 1210, 27, 216, "Input"],
Cell[3267978, 86133, 346, 9, 67, "Output"]
}, Open  ]],
Cell[3268339, 86145, 84, 1, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[3268448, 86150, 284, 6, 69, "Input"],

Cell[CellGroupData[{
Cell[3268757, 86160, 217433, 4256, 295, 177648, 3759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3486193, 90418, 217322, 4285, 295, 178309, 3797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3703518, 94705, 218211, 4346, 295, 179227, 3859, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3921732, 99053, 219999, 4401, 295, 180043, 3902, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4141734, 103456, 221826, 4473, 295, 181088, 3964, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4363563, 107931, 223593, 4535, 295, 182098, 4017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4587159, 112468, 224520, 4573, 295, 182713, 4051, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4811682, 117043, 225661, 4628, 295, 183538, 4102, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5037346, 121673, 228663, 4733, 295, 184936, 4187, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5266012, 126408, 232994, 4887, 295, 187052, 4314, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5499009, 131297, 235967, 4990, 295, 188316, 4396, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5734979, 136289, 239428, 5117, 295, 189966, 4500, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5974410, 141408, 243975, 5276, 295, 192083, 4629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6218388, 146686, 248553, 5435, 295, 194320, 4759, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6466944, 152123, 253309, 5594, 295, 196480, 4886, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6720256, 157719, 257064, 5724, 295, 198210, 4991, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6977323, 163445, 259262, 5796, 295, 199096, 5047, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7236588, 169243, 260180, 5842, 295, 199706, 5089, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7496771, 175087, 259403, 5799, 295, 199140, 5049, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7756177, 180888, 257080, 5712, 295, 197696, 4973, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8013260, 186602, 256697, 5692, 295, 197438, 4954, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8269960, 192296, 253320, 5580, 295, 195888, 4865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8523283, 197878, 253217, 5544, 295, 195299, 4823, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8776503, 203424, 257354, 5688, 295, 197026, 4937, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9033942, 209121, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9035662, 209168, 125, 4, 41, "Banner"],
Cell[9035790, 209174, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9035973, 209182, 40, 0, 84, "Section"],
Cell[9036016, 209184, 71, 0, 36, "BulletText"],
Cell[9036090, 209186, 135, 3, 36, "BulletText"],

Cell[CellGroupData[{
Cell[9036250, 209193, 27, 0, 62, "Subsection"],
Cell[9036280, 209195, 146, 3, 36, "BulletText"],
Cell[9036429, 209200, 160, 3, 60, "BulletText"],

Cell[CellGroupData[{
Cell[9036614, 209207, 65, 1, 46, "Subsubsection"],
Cell[9036682, 209210, 175, 6, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9036882, 209220, 71, 2, 43, "Input"],
Cell[9036956, 209224, 162, 3, 67, "Output"]
}, Open  ]],
Cell[9037133, 209230, 102, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9037260, 209236, 160, 3, 70, "Input"],
Cell[9037423, 209241, 144, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9037604, 209249, 160, 3, 70, "Input"],
Cell[9037767, 209254, 143, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9037947, 209262, 160, 3, 70, "Input"],
Cell[9038110, 209267, 129, 3, 42, "Output"]
}, Open  ]],
Cell[9038254, 209273, 92, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9038371, 209279, 163, 3, 98, "Input"],
Cell[9038537, 209284, 143, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9038717, 209292, 159, 3, 80, "Input"],
Cell[9038879, 209297, 143, 3, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9039083, 209307, 30, 0, 62, "Subsection"],
Cell[9039116, 209309, 84, 2, 36, "BulletText"],
Cell[9039203, 209313, 145, 3, 36, "BulletText"],
Cell[9039351, 209318, 160, 3, 60, "BulletText"],

Cell[CellGroupData[{
Cell[9039536, 209325, 65, 1, 46, "Subsubsection"],
Cell[9039604, 209328, 84, 1, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9039713, 209333, 71, 2, 43, "Input"],
Cell[9039787, 209337, 158, 3, 92, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9039982, 209345, 214, 5, 72, "Input"],
Cell[9040199, 209352, 143, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9040379, 209360, 214, 5, 80, "Input"],
Cell[9040596, 209367, 142, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9040775, 209375, 214, 5, 80, "Input"],
Cell[9040992, 209382, 141, 3, 42, "Output"]
}, Open  ]],
Cell[9041148, 209388, 144, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9041317, 209395, 236, 4, 112, "Input"],
Cell[9041556, 209401, 144, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9041737, 209409, 225, 4, 85, "Input"],
Cell[9041965, 209415, 119, 3, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9042169, 209427, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9043889, 209474, 125, 4, 41, "Banner"],
Cell[9044017, 209480, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9044200, 209488, 25, 0, 84, "Section"],
Cell[9044228, 209490, 172, 6, 37, "BulletText"],
Cell[9044403, 209498, 309, 9, 61, "BulletText"],
Cell[9044715, 209509, 200, 6, 37, "BulletText"],
Cell[9044918, 209517, 211, 4, 61, "BulletText"],
Cell[9045132, 209523, 149, 5, 36, "BulletText"],

Cell[CellGroupData[{
Cell[9045306, 209532, 30, 0, 62, "Subsection"],
Cell[9045339, 209534, 504, 9, 111, "Text"],
Cell[9045846, 209545, 69, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9045940, 209549, 120, 3, 44, "Input"],
Cell[9046063, 209554, 137, 3, 73, "Output"]
}, Closed]],
Cell[9046215, 209560, 122, 3, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9046362, 209567, 114, 2, 44, "Input"],
Cell[9046479, 209571, 309, 6, 140, "Output"]
}, Closed]],
Cell[9046803, 209580, 134, 3, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9046962, 209587, 126, 3, 44, "Input"],
Cell[9047091, 209592, 944, 16, 381, "Output"]
}, Closed]],
Cell[9048050, 209611, 76, 0, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9048151, 209615, 140, 3, 44, "Input"],
Cell[9048294, 209620, 414, 7, 217, "Output"]
}, Closed]],
Cell[9048723, 209630, 148, 3, 34, "Text"],
Cell[9048874, 209635, 93, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9048992, 209641, 177, 4, 44, "Input"],
Cell[9049172, 209647, 492, 10, 255, "Output"]
}, Closed]],
Cell[9049679, 209660, 156, 3, 58, "Text"],
Cell[9049838, 209665, 129, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9049992, 209672, 101, 2, 43, "Input"],
Cell[9050096, 209676, 192, 4, 84, "Output"]
}, Closed]],
Cell[9050303, 209683, 212, 4, 55, "MathCaption"],

Cell[CellGroupData[{
Cell[9050540, 209691, 156, 4, 44, "Input"],
Cell[9050699, 209697, 199, 4, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9050935, 209706, 141, 3, 36, "Input"],
Cell[9051079, 209711, 97, 2, 60, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9051213, 209718, 151, 4, 36, "Input"],
Cell[9051367, 209724, 64, 2, 42, "Output"]
}, Closed]],
Cell[9051446, 209729, 99, 2, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9051570, 209735, 189, 4, 44, "Input"],
Cell[9051762, 209741, 266, 5, 143, "Output"]
}, Closed]],
Cell[9052043, 209749, 269, 9, 34, "Text"],
Cell[9052315, 209760, 294, 11, 58, "MathCaption"],
Cell[9052612, 209773, 72, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[9052709, 209779, 164, 3, 44, "Input"],
Cell[9052876, 209784, 84, 2, 63, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9053033, 209794, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9054753, 209841, 125, 4, 41, "Banner"],
Cell[9054881, 209847, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9055064, 209855, 32, 0, 84, "Section"],
Cell[9055099, 209857, 239, 6, 61, "BulletText"],
Cell[9055341, 209865, 149, 5, 36, "BulletText"],

Cell[CellGroupData[{
Cell[9055515, 209874, 30, 0, 62, "Subsection"],
Cell[9055548, 209876, 331, 8, 64, "Text"],
Cell[9055882, 209886, 69, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9055976, 209890, 126, 3, 44, "Input"],
Cell[9056105, 209895, 302, 5, 75, "Output"]
}, Open  ]],
Cell[9056422, 209903, 64, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9056511, 209907, 132, 3, 44, "Input"],
Cell[9056646, 209912, 144, 3, 75, "Output"]
}, Open  ]],
Cell[9056805, 209918, 67, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9056897, 209922, 137, 3, 44, "Input"],
Cell[9057037, 209927, 318, 8, 142, "Output"]
}, Open  ]],
Cell[9057370, 209938, 76, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9057471, 209942, 151, 3, 44, "Input"],
Cell[9057625, 209947, 115, 2, 42, "Output"]
}, Open  ]],
Cell[9057755, 209952, 54, 0, 39, "Text"],
Cell[9057812, 209954, 93, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9057930, 209960, 188, 4, 44, "Input"],
Cell[9058121, 209966, 146, 3, 75, "Output"]
}, Open  ]],
Cell[9058282, 209972, 99, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9058406, 209978, 195, 4, 70, "Input"],
Cell[9058604, 209984, 88, 2, 58, "Output"]
}, Open  ]],
Cell[9058707, 209989, 269, 9, 39, "Text"],
Cell[9058979, 210000, 294, 11, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9059298, 210015, 194, 5, 44, "Input"],
Cell[9059495, 210022, 91, 2, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9059659, 210032, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9061379, 210079, 125, 4, 41, "Banner"],
Cell[9061507, 210085, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9061690, 210093, 25, 0, 84, "Section"],
Cell[9061718, 210095, 133, 3, 37, "BulletText"],
Cell[9061854, 210100, 123, 3, 37, "BulletText"],
Cell[9061980, 210105, 128, 3, 37, "BulletText"],
Cell[9062111, 210110, 106, 3, 37, "BulletText"],
Cell[9062220, 210115, 104, 3, 37, "BulletText"],
Cell[9062327, 210120, 189, 6, 37, "BulletText"],
Cell[9062519, 210128, 155, 5, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9062699, 210137, 30, 0, 62, "Subsection"],
Cell[9062732, 210139, 218, 6, 64, "Text"],
Cell[9062953, 210147, 261, 8, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9063239, 210159, 119, 3, 43, "Input"],
Cell[9063361, 210164, 106, 2, 42, "Output"]
}, Open  ]],
Cell[9063482, 210169, 271, 8, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9063778, 210181, 154, 4, 43, "Input"],
Cell[9063935, 210187, 100, 2, 42, "Output"]
}, Open  ]],
Cell[9064050, 210192, 115, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9064190, 210199, 146, 3, 43, "Input"],
Cell[9064339, 210204, 65, 2, 42, "Output"]
}, Open  ]],
Cell[9064419, 210209, 119, 3, 40, "Text"],
Cell[9064541, 210214, 173, 3, 38, "DisplayFormula"],
Cell[9064717, 210219, 149, 6, 40, "Text"],
Cell[9064869, 210227, 165, 3, 38, "DisplayFormula"],
Cell[9065037, 210232, 249, 8, 64, "Text"],
Cell[9065289, 210242, 109, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9065423, 210249, 221, 5, 43, "Input"],
Cell[9065647, 210256, 159, 4, 44, "Output"]
}, Open  ]],
Cell[9065821, 210263, 113, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9065959, 210270, 211, 4, 69, "Input"],
Cell[9066173, 210276, 46838, 1056, 279, 13528, 640, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9113026, 211335, 339, 8, 64, "Text"],
Cell[9113368, 211345, 76, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9113469, 211349, 165, 4, 43, "Input"],
Cell[9113637, 211355, 308, 6, 68, "Output"]
}, Open  ]],
Cell[9113960, 211364, 58, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9114043, 211368, 132, 3, 43, "Input"],
Cell[9114178, 211373, 116, 2, 58, "Output"]
}, Open  ]],
Cell[9114309, 211378, 59, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9114393, 211382, 119, 3, 44, "Input"],
Cell[9114515, 211387, 134, 3, 43, "Output"]
}, Closed]],
Cell[9114664, 211393, 62, 0, 34, "Text"],
Cell[9114729, 211395, 93, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9114847, 211401, 212, 5, 43, "Input"],
Cell[9115062, 211408, 311, 7, 117, "Output"]
}, Closed]],
Cell[9115388, 211418, 92, 2, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9115505, 211424, 413, 7, 179, "Input"],
Cell[9115921, 211433, 218, 4, 93, "Output"]
}, Closed]],
Cell[9116154, 211440, 74, 0, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9116253, 211444, 425, 8, 173, "Input"],
Cell[9116681, 211454, 856, 18, 244, "Output"]
}, Open  ]],
Cell[9117552, 211475, 199, 4, 63, "Text"],
Cell[9117754, 211481, 183, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9117962, 211490, 129, 3, 43, "Input"],
Cell[9118094, 211495, 154, 4, 43, "Output"]
}, Closed]],
Cell[9118263, 211502, 224, 7, 35, "Text"],
Cell[9118490, 211511, 115, 2, 35, "DisplayMath"],
Cell[9118608, 211515, 73, 0, 39, "Text"],
Cell[9118684, 211517, 110, 2, 35, "DisplayMath"],
Cell[9118797, 211521, 399, 10, 87, "Text"],
Cell[9119199, 211533, 132, 3, 39, "Text"],
Cell[9119334, 211538, 145, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9119504, 211545, 126, 3, 43, "Input"],
Cell[9119633, 211550, 115, 2, 60, "Output"]
}, Closed]],
Cell[9119763, 211555, 110, 3, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9119898, 211562, 109, 2, 43, "Input"],
Cell[9120010, 211566, 156, 4, 61, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9120239, 211578, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9121959, 211625, 125, 4, 41, "Banner"],
Cell[9122087, 211631, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9122270, 211639, 38, 0, 84, "Section"],
Cell[9122311, 211641, 211, 6, 37, "BulletText"],
Cell[9122525, 211649, 68, 0, 36, "BulletText"],

Cell[CellGroupData[{
Cell[9122618, 211653, 30, 0, 62, "Subsection"],
Cell[9122651, 211655, 102, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9122778, 211661, 112, 2, 43, "Input"],
Cell[9122893, 211665, 100, 2, 58, "Output"]
}, Open  ]],
Cell[9123008, 211670, 166, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9123199, 211679, 286, 5, 70, "Input"],
Cell[9123488, 211686, 148, 3, 65, "Output"]
}, Open  ]],
Cell[9123651, 211692, 169, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9123845, 211701, 242, 5, 44, "Input"],
Cell[9124090, 211708, 98, 2, 42, "Output"]
}, Open  ]],
Cell[9124203, 211713, 71, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9124299, 211717, 265, 6, 98, "Input"],
Cell[9124567, 211725, 90, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9124730, 211735, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9126450, 211782, 125, 4, 41, "Banner"],
Cell[9126578, 211788, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9126761, 211796, 25, 0, 84, "Section"],
Cell[9126789, 211798, 173, 4, 37, "BulletText"],
Cell[9126965, 211804, 155, 4, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9127145, 211812, 30, 0, 62, "Subsection"],
Cell[9127178, 211814, 114, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9127317, 211821, 1149, 22, 309, "Input"],
Cell[9128469, 211845, 284, 7, 114, "Output"]
}, Open  ]],
Cell[9128768, 211855, 197, 5, 64, "Text"],
Cell[9128968, 211862, 174, 3, 38, "DisplayFormula"],
Cell[9129145, 211867, 188, 6, 39, "Text"],
Cell[9129336, 211875, 283, 5, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[9129644, 211884, 2023, 46, 251, "Input"],
Cell[9131670, 211932, 685, 15, 146, "Output"]
}, Open  ]],
Cell[9132370, 211950, 99, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9132494, 211956, 2118, 47, 277, "Input"],
Cell[9134615, 212005, 400, 10, 102, "Output"]
}, Open  ]],
Cell[9135030, 212018, 70, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9135125, 212022, 83, 2, 43, "Input"],
Cell[9135211, 212026, 73, 2, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9135357, 212036, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9137077, 212083, 125, 4, 41, "Banner"],
Cell[9137205, 212089, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9137388, 212097, 36, 0, 84, "Section"],
Cell[9137427, 212099, 90, 2, 36, "BulletText"],
Cell[9137520, 212103, 194, 6, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9137739, 212113, 30, 0, 62, "Subsection"],
Cell[9137772, 212115, 161, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[9137958, 212122, 71, 2, 43, "Input"],
Cell[9138032, 212126, 72, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9138141, 212133, 91, 2, 44, "Input"],
Cell[9138235, 212137, 68, 2, 42, "Output"]
}, Open  ]],
Cell[9138318, 212142, 116, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9138459, 212149, 75, 2, 43, "Input"],
Cell[9138537, 212153, 60, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9138634, 212160, 102, 2, 43, "Input"],
Cell[9138739, 212164, 60, 2, 42, "Output"]
}, Open  ]],
Cell[9138814, 212169, 82, 1, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9138921, 212174, 102, 2, 56, "Input"],
Cell[9139026, 212178, 77, 2, 44, "Output"]
}, Open  ]],
Cell[9139118, 212183, 100, 2, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9139243, 212189, 81, 2, 55, "Input"],
Cell[9139327, 212193, 78, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9139442, 212200, 92, 2, 43, "Input"],
Cell[9139537, 212204, 80, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9139654, 212211, 101, 2, 43, "Input"],
Cell[9139758, 212215, 78, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9139873, 212222, 116, 2, 43, "Input"],
Cell[9139992, 212226, 76, 2, 45, "Output"]
}, Open  ]],
Cell[9140083, 212231, 175, 3, 80, "MathCaption"],

Cell[CellGroupData[{
Cell[9140283, 212238, 310, 6, 144, "Input"],
Cell[9140596, 212246, 112, 2, 69, "Output"]
}, Open  ]],
Cell[9140723, 212251, 111, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9140859, 212258, 128, 3, 43, "Input"],
Cell[9140990, 212263, 60, 2, 42, "Output"]
}, Open  ]],
Cell[9141065, 212268, 175, 6, 59, "MathCaption"],

Cell[CellGroupData[{
Cell[9141265, 212278, 375, 7, 171, "Input"],
Cell[9141643, 212287, 60, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9141776, 212297, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9143496, 212344, 125, 4, 41, "Banner"],
Cell[9143624, 212350, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9143807, 212358, 26, 0, 84, "Section"],
Cell[9143836, 212360, 163, 4, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9144024, 212368, 30, 0, 62, "Subsection"],
Cell[9144057, 212370, 118, 3, 39, "Text"],
Cell[9144178, 212375, 240, 8, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9144443, 212387, 138, 3, 45, "Input"],
Cell[9144584, 212392, 63, 2, 42, "Output"]
}, Open  ]],
Cell[9144662, 212397, 72, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9144759, 212401, 561, 11, 173, "Input"],
Cell[9145323, 212414, 108856, 3427, 444, 52122, 2721, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9254194, 215844, 99, 2, 58, "MathCaption"],
Cell[9254296, 215848, 77, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[9254398, 215854, 167, 4, 44, "Input"],
Cell[9254568, 215860, 197, 4, 64, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9254838, 215872, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9256558, 215919, 125, 4, 41, "Banner"],
Cell[9256686, 215925, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9256869, 215933, 24, 0, 84, "Section"],
Cell[9256896, 215935, 187, 5, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9257108, 215944, 30, 0, 62, "Subsection"],
Cell[9257141, 215946, 160, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9257326, 215955, 103, 2, 43, "Input"],
Cell[9257432, 215959, 100, 2, 42, "Output"]
}, Open  ]],
Cell[9257547, 215964, 151, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9257723, 215973, 140, 3, 43, "Input"],
Cell[9257866, 215978, 70, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9257973, 215985, 141, 3, 62, "Input"],
Cell[9258117, 215990, 61, 2, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9258215, 215997, 158, 3, 54, "Input"],
Cell[9258376, 216002, 61, 2, 42, "Output"]
}, Closed]],
Cell[9258452, 216007, 162, 5, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9258639, 216016, 155, 3, 62, "Input"],
Cell[9258797, 216021, 61, 2, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9258895, 216028, 151, 3, 54, "Input"],
Cell[9259049, 216033, 71, 2, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9259157, 216040, 158, 3, 54, "Input"],
Cell[9259318, 216045, 61, 2, 42, "Output"]
}, Closed]],
Cell[9259394, 216050, 201, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9259620, 216060, 245, 5, 99, "Input"],
Cell[9259868, 216067, 112, 2, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9260017, 216074, 130, 3, 43, "Input"],
Cell[9260150, 216079, 60, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9260283, 216089, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9262003, 216136, 125, 4, 41, "Banner"],
Cell[9262131, 216142, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[9262314, 216150, 34, 0, 84, "Section"],
Cell[9262351, 216152, 70, 2, 36, "BulletText"],
Cell[9262424, 216156, 66, 2, 36, "BulletText"],
Cell[9262493, 216160, 67, 2, 36, "BulletText"],
Cell[9262563, 216164, 75, 2, 36, "BulletText"],
Cell[9262641, 216168, 78, 2, 36, "BulletText"],
Cell[9262722, 216172, 77, 2, 36, "BulletText"],
Cell[9262802, 216176, 129, 4, 37, "BulletText"],
Cell[9262934, 216182, 102, 2, 36, "BulletText"],
Cell[9263039, 216186, 98, 2, 36, "BulletText"],
Cell[9263140, 216190, 158, 6, 37, "BulletText"],

Cell[CellGroupData[{
Cell[9263323, 216200, 87, 2, 62, "Input"],
Cell[9263413, 216204, 62, 2, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[9263512, 216211, 87, 2, 54, "Input"],
Cell[9263602, 216215, 62, 2, 42, "Output"]
}, Closed]],
Cell[9263679, 216220, 68, 2, 34, "BulletText"],

Cell[CellGroupData[{
Cell[9263772, 216226, 71, 0, 62, "Subsection"],
Cell[9263846, 216228, 127, 3, 58, "MathCaption"],
Cell[9263976, 216233, 346, 7, 95, "Input"],
Cell[9264325, 216242, 123, 4, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9264473, 216250, 73, 2, 43, "Input"],
Cell[9264549, 216254, 256, 7, 42, "Output"]
}, Open  ]],
Cell[9264820, 216264, 72, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9264917, 216268, 110, 2, 43, "Input"],
Cell[9265030, 216272, 73, 2, 42, "Output"]
}, Open  ]],
Cell[9265118, 216277, 188, 6, 39, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9265343, 216288, 64, 0, 62, "Subsection"],
Cell[9265410, 216290, 74, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[9265509, 216294, 113, 2, 43, "Input"],
Cell[9265625, 216298, 155, 4, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9265817, 216307, 74, 2, 43, "Input"],
Cell[9265894, 216311, 867927, 11165, 396, 133919, 2099, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10133870, 227482, 57, 0, 62, "Subsection"],
Cell[10133930, 227484, 134, 5, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[10134089, 227493, 189, 4, 69, "Input"],
Cell[10134281, 227499, 12886, 197, 444, 613, 40, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10147170, 227698, 155, 4, 42, "Output"]
}, Open  ]],
Cell[10147340, 227705, 148, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[10147513, 227712, 90, 2, 43, "Input"],
Cell[10147606, 227716, 708, 11, 517, "Output"]
}, Open  ]],
Cell[10148329, 227730, 114, 3, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[10148468, 227737, 86, 2, 43, "Input"],
Cell[10148557, 227741, 66, 2, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10148672, 227749, 54, 0, 62, "Subsection"],
Cell[10148729, 227751, 254, 11, 37, "BulletText"],
Cell[10148986, 227764, 65, 2, 36, "BulletText"],
Cell[10149054, 227768, 95, 4, 58, "MathCaption"],
Cell[10149152, 227774, 114, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[10149291, 227780, 129, 3, 43, "Input"],
Cell[10149423, 227785, 69, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10149529, 227792, 161, 4, 43, "Input"],
Cell[10149693, 227798, 87, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10149817, 227805, 91, 2, 43, "Input"],
Cell[10149911, 227809, 63, 2, 42, "Output"]
}, Open  ]],
Cell[10149989, 227814, 95, 4, 58, "MathCaption"],
Cell[10150087, 227820, 114, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[10150226, 227826, 129, 3, 43, "Input"],
Cell[10150358, 227831, 69, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10150464, 227838, 161, 4, 43, "Input"],
Cell[10150628, 227844, 101, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10150766, 227851, 91, 2, 43, "Input"],
Cell[10150860, 227855, 63, 2, 42, "Output"]
}, Open  ]],
Cell[10150938, 227860, 36, 0, 58, "MathCaption"],

Cell[CellGroupData[{
Cell[10150999, 227864, 78, 2, 43, "Input"],
Cell[10151080, 227868, 64, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10151217, 227878, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10152937, 227925, 125, 4, 41, "Banner"],
Cell[10153065, 227931, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[10153248, 227939, 43, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[10153316, 227943, 88, 4, 62, "Subsection"],
Cell[10153407, 227949, 173, 4, 37, "BulletText"],
Cell[10153583, 227955, 77, 2, 36, "BulletText"],
Cell[10153663, 227959, 176, 4, 37, "BulletText"],
Cell[10153842, 227965, 419, 15, 61, "BulletText"],

Cell[CellGroupData[{
Cell[10154286, 227984, 81, 1, 46, "Subsubsection"],
Cell[10154370, 227987, 175, 5, 36, "BulletText"],
Cell[10154548, 227994, 395, 12, 60, "BulletText"],
Cell[10154946, 228008, 135, 3, 36, "BulletText"],
Cell[10155084, 228013, 208, 4, 81, "MathCaption"],
Cell[10155295, 228019, 433, 10, 115, "Text"],
Cell[10155731, 228031, 177, 4, 80, "MathCaption"],
Cell[10155911, 228037, 477, 11, 115, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10156437, 228054, 73, 1, 62, "Subsection"],
Cell[10156513, 228057, 163, 5, 36, "BulletText"],
Cell[10156679, 228064, 152, 5, 36, "BulletText"],
Cell[10156834, 228071, 169, 5, 36, "BulletText"]
}, Closed]],

Cell[CellGroupData[{
Cell[10157040, 228081, 265, 8, 36, "Subsection"],
Cell[10157308, 228091, 62, 0, 36, "BulletText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10157407, 228096, 77, 1, 62, "Subsection"],
Cell[10157487, 228099, 204, 6, 36, "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10157752, 228112, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10159472, 228159, 125, 4, 41, "Banner"],
Cell[10159600, 228165, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[10159783, 228173, 33, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[10159841, 228177, 43, 0, 62, "Subsection"],
Cell[10159887, 228179, 68, 0, 36, "BulletText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10159992, 228184, 43, 0, 62, "Subsection"],
Cell[10160038, 228186, 144, 5, 36, "BulletText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10160219, 228196, 45, 0, 62, "Subsection"],
Cell[10160267, 228198, 45, 0, 36, "BulletText"],
Cell[10160315, 228200, 84, 1, 36, "BulletText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10160460, 228208, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10162180, 228255, 125, 4, 41, "Banner"],
Cell[10162308, 228261, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[10162491, 228269, 42, 0, 84, "Section"],
Cell[10162536, 228271, 32, 0, 36, "BulletText"],
Cell[10162571, 228273, 44, 0, 36, "BulletText"],
Cell[10162618, 228275, 38, 0, 36, "BulletText"],
Cell[10162659, 228277, 35, 0, 36, "BulletText"],
Cell[10162697, 228279, 40, 0, 36, "BulletText"],
Cell[10162740, 228281, 33, 0, 36, "BulletText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10162822, 228287, 1717, 45, 28, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[10164542, 228334, 125, 4, 41, "Banner"],
Cell[10164670, 228340, 158, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[10164853, 228348, 64, 1, 84, "Section",
  CellTags->"LastSlide"],
Cell[10164920, 228351, 398, 13, 39, "Text"],
Cell[10165321, 228366, 234, 7, 39, "Text"],
Cell[10165558, 228375, 169, 6, 39, "Text"],
Cell[10165730, 228383, 406, 13, 39, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

